(function(e){var n={};function t(r){if(n[r])return n[r].exports;var a=n[r]={i:r,l:!1,exports:{}};return e[r].call(a.exports,a,a.exports,t),a.l=!0,a.exports}t.m=e,t.c=n,t.d=function(e,n,r){t.o(e,n)||Object.defineProperty(e,n,{enumerable:!0,get:r})},t.r=function(e){"undefined"!==typeof Symbol&&Symbol.toStringTag&&Object.defineProperty(e,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(e,"__esModule",{value:!0})},t.t=function(e,n){if(1&n&&(e=t(e)),8&n)return e;if(4&n&&"object"===typeof e&&e&&e.__esModule)return e;var r=Object.create(null);if(t.r(r),Object.defineProperty(r,"default",{enumerable:!0,value:e}),2&n&&"string"!=typeof e)for(var a in e)t.d(r,a,function(n){return e[n]}.bind(null,a));return r},t.n=function(e){var n=e&&e.__esModule?function(){return e["default"]}:function(){return e};return t.d(n,"a",n),n},t.o=function(e,n){return Object.prototype.hasOwnProperty.call(e,n)},t.p="dist/",t(t.s="d0c7")})({"30db":function(e,n,t){"use strict";(function(e,r){var a;t.d(n,"a",(function(){return y})),t.d(n,"d",(function(){return T})),t.d(n,"b",(function(){return S})),t.d(n,"c",(function(){return x})),t.d(n,"e",(function(){return L}));const i="en";let o=!1,s=!1,c=!1,l=!1,u=!1,d=!1,p=!1,f=void 0,m=i,_=void 0,g=void 0;const y="object"===typeof self?self:"object"===typeof e?e:{};let h=void 0;"undefined"!==typeof y.vscode&&"undefined"!==typeof y.vscode.process?h=y.vscode.process:"undefined"!==typeof r&&(h=r);const v="string"===typeof(null===(a=null===h||void 0===h?void 0:h.versions)||void 0===a?void 0:a.electron)&&"renderer"===h.type,b=v&&(null===h||void 0===h?void 0:h.sandboxed);(()=>{if(b)return"bypassHeatCheck";const e=null===h||void 0===h?void 0:h.env["VSCODE_BROWSER_CODE_LOADING"]})();if("object"!==typeof navigator||v)if("object"===typeof h){o="win32"===h.platform,s="darwin"===h.platform,c="linux"===h.platform,l=c&&!!h.env["SNAP"]&&!!h.env["SNAP_REVISION"],f=i,m=i;const e=h.env["VSCODE_NLS_CONFIG"];if(e)try{const n=JSON.parse(e),t=n.availableLanguages["*"];f=n.locale,m=t||i,_=n._translationsConfigFile}catch(D){}u=!0}else console.error("Unable to resolve platform.");else g=navigator.userAgent,o=g.indexOf("Windows")>=0,s=g.indexOf("Macintosh")>=0,p=(g.indexOf("Macintosh")>=0||g.indexOf("iPad")>=0||g.indexOf("iPhone")>=0)&&!!navigator.maxTouchPoints&&navigator.maxTouchPoints>0,c=g.indexOf("Linux")>=0,d=!0,f=navigator.language,m=f;let E=0;s?E=1:o?E=3:c&&(E=2);const T=o,S=s,x=d,L=function(){if(y.setImmediate)return y.setImmediate.bind(y);if("function"===typeof y.postMessage&&!y.importScripts){let e=[];y.addEventListener("message",n=>{if(n.data&&n.data.vscodeSetImmediateId)for(let t=0,r=e.length;t<r;t++){const r=e[t];if(r.id===n.data.vscodeSetImmediateId)return e.splice(t,1),void r.callback()}});let n=0;return t=>{const r=++n;e.push({id:r,callback:t}),y.postMessage({vscodeSetImmediateId:r},"*")}}if("function"===typeof(null===h||void 0===h?void 0:h.nextTick))return h.nextTick.bind(h);const e=Promise.resolve();return n=>e.then(n)}()}).call(this,t("c8ba"),t("f28c"))},"973d":function(e,n,t){"use strict";t.r(n),function(e,r,a){t.d(n,"createClassifier",(function(){return f})),t.d(n,"createLanguageService",(function(){return m})),t.d(n,"displayPartsToString",(function(){return _})),t.d(n,"EndOfLineState",(function(){return g})),t.d(n,"flattenDiagnosticMessageText",(function(){return y})),t.d(n,"IndentStyle",(function(){return h})),t.d(n,"ScriptKind",(function(){return v})),t.d(n,"ScriptTarget",(function(){return b})),t.d(n,"TokenClass",(function(){return E}));
/*! *****************************************************************************
Copyright (c) Microsoft Corporation. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License"); you may not use
this file except in compliance with the License. You may obtain a copy of the
License at http://www.apache.org/licenses/LICENSE-2.0

THIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED
WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,
MERCHANTABLITY OR NON-INFRINGEMENT.

See the Apache Version 2.0 License for specific language governing permissions
and limitations under the License.
***************************************************************************** */
var i=function(e,n){for(var t=0,r=n.length,a=e.length;t<r;t++,a++)e[a]=n[t];return e},o=function(){return o=Object.assign||function(e){for(var n,t=1,r=arguments.length;t<r;t++)for(var a in n=arguments[t],n)Object.prototype.hasOwnProperty.call(n,a)&&(e[a]=n[a]);return e},o.apply(this,arguments)},s=function(e,n){return Object.defineProperty?Object.defineProperty(e,"raw",{value:n}):e.raw=n,e},c=function(e,n){var t,r,a,i,o={label:0,sent:function(){if(1&a[0])throw a[1];return a[1]},trys:[],ops:[]};return i={next:s(0),throw:s(1),return:s(2)},"function"===typeof Symbol&&(i[Symbol.iterator]=function(){return this}),i;function s(e){return function(n){return c([e,n])}}function c(i){if(t)throw new TypeError("Generator is already executing.");while(o)try{if(t=1,r&&(a=2&i[0]?r["return"]:i[0]?r["throw"]||((a=r["return"])&&a.call(r),0):r.next)&&!(a=a.call(r,i[1])).done)return a;switch(r=0,a&&(i=[2&i[0],a.value]),i[0]){case 0:case 1:a=i;break;case 4:return o.label++,{value:i[1],done:!1};case 5:o.label++,r=i[1],i=[0];continue;case 7:i=o.ops.pop(),o.trys.pop();continue;default:if(a=o.trys,!(a=a.length>0&&a[a.length-1])&&(6===i[0]||2===i[0])){o=0;continue}if(3===i[0]&&(!a||i[1]>a[0]&&i[1]<a[3])){o.label=i[1];break}if(6===i[0]&&o.label<a[1]){o.label=a[1],a=i;break}if(a&&o.label<a[2]){o.label=a[2],o.ops.push(i);break}a[2]&&o.ops.pop(),o.trys.pop();continue}i=n.call(e,o)}catch(s){i=[6,s],r=0}finally{t=a=0}if(5&i[0])throw i[1];return{value:i[0]?i[1]:void 0,done:!0}}},l=function(e,n){var t={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&n.indexOf(r)<0&&(t[r]=e[r]);if(null!=e&&"function"===typeof Object.getOwnPropertySymbols){var a=0;for(r=Object.getOwnPropertySymbols(e);a<r.length;a++)n.indexOf(r[a])<0&&Object.prototype.propertyIsEnumerable.call(e,r[a])&&(t[r[a]]=e[r[a]])}return t},u=function(){var e=function(n,t){return e=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,n){e.__proto__=n}||function(e,n){for(var t in n)Object.prototype.hasOwnProperty.call(n,t)&&(e[t]=n[t])},e(n,t)};return function(n,t){if("function"!==typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function r(){this.constructor=n}e(n,t),n.prototype=null===t?Object.create(t):(r.prototype=t.prototype,new r)}}();(function(e){function n(){var e={};return e.prev=e,{head:e,tail:e,size:0}}function t(e,n){return{key:e,value:n,next:void 0,prev:void 0}}function r(e,n){return e===n||e!==e&&n!==n}function a(e){var n=e.prev;if(!n||n===e)throw new Error("Illegal state");return n}function i(e){while(e){var n=!e.prev;if(e=e.next,!n)return e}}function o(e,n){for(var t=e.tail;t!==e.head;t=a(t))if(r(t.key,n))return t}function s(e,n,r){var a=o(e,n);if(!a){var i=t(n,r);return i.prev=e.tail,e.tail.next=i,e.tail=i,e.size++,i}a.value=r}function c(e,n){for(var t=e.tail;t!==e.head;t=a(t)){if(void 0===t.prev)throw new Error("Illegal state");if(r(t.key,n)){if(t.next)t.next.prev=t.prev;else{if(e.tail!==t)throw new Error("Illegal state");e.tail=t.prev}return t.prev.next=t.next,t.next=t.prev,t.prev=void 0,e.size--,t}}}function l(e){var n=e.tail;while(n!==e.head){var t=a(n);n.next=e.head,n.prev=void 0,n=t}e.head.next=void 0,e.tail=e.head,e.size=0}function u(e,n){var t=e.head;while(t)t=i(t),t&&n(t.value,t.key)}function d(e,n){if(e)for(var t=e.next();!t.done;t=e.next())n(t.value)}function p(e,n){return{current:e.head,selector:n}}function f(e){return e.current=i(e.current),e.current?{value:e.selector(e.current.key,e.current.value),done:!1}:{value:void 0,done:!0}}(function(e){function t(e){var t=function(){function e(e,n){this._data=p(e,n)}return e.prototype.next=function(){return f(this._data)},e}();return function(){function r(t){var r=this;this._mapData=n(),d(e(t),(function(e){var n=e[0],t=e[1];return r.set(n,t)}))}return Object.defineProperty(r.prototype,"size",{get:function(){return this._mapData.size},enumerable:!1,configurable:!0}),r.prototype.get=function(e){var n;return null===(n=o(this._mapData,e))||void 0===n?void 0:n.value},r.prototype.set=function(e,n){return s(this._mapData,e,n),this},r.prototype.has=function(e){return!!o(this._mapData,e)},r.prototype.delete=function(e){return!!c(this._mapData,e)},r.prototype.clear=function(){l(this._mapData)},r.prototype.keys=function(){return new t(this._mapData,(function(e,n){return e}))},r.prototype.values=function(){return new t(this._mapData,(function(e,n){return n}))},r.prototype.entries=function(){return new t(this._mapData,(function(e,n){return[e,n]}))},r.prototype.forEach=function(e){u(this._mapData,e)},r}()}function r(e){var t=function(){function e(e,n){this._data=p(e,n)}return e.prototype.next=function(){return f(this._data)},e}();return function(){function r(t){var r=this;this._mapData=n(),d(e(t),(function(e){return r.add(e)}))}return Object.defineProperty(r.prototype,"size",{get:function(){return this._mapData.size},enumerable:!1,configurable:!0}),r.prototype.add=function(e){return s(this._mapData,e,e),this},r.prototype.has=function(e){return!!o(this._mapData,e)},r.prototype.delete=function(e){return!!c(this._mapData,e)},r.prototype.clear=function(){l(this._mapData)},r.prototype.keys=function(){return new t(this._mapData,(function(e,n){return e}))},r.prototype.values=function(){return new t(this._mapData,(function(e,n){return n}))},r.prototype.entries=function(){return new t(this._mapData,(function(e,n){return[e,n]}))},r.prototype.forEach=function(e){u(this._mapData,e)},r}()}e.createMapShim=t,e.createSetShim=r})(e.ShimCollections||(e.ShimCollections={}))})(d||(d={})),function(e){e.versionMajorMinor="4.3",e.version="4.3.2",function(e){e[e["LessThan"]=-1]="LessThan",e[e["EqualTo"]=0]="EqualTo",e[e["GreaterThan"]=1]="GreaterThan"}(e.Comparison||(e.Comparison={})),function(e){function n(){return"undefined"!==typeof Map&&"entries"in Map.prototype&&1===new Map([[0,0]]).size?Map:void 0}function t(){return"undefined"!==typeof Set&&"entries"in Set.prototype&&1===new Set([0]).size?Set:void 0}e.tryGetNativeMap=n,e.tryGetNativeSet=t}(e.NativeCollections||(e.NativeCollections={}))}(d||(d={})),function(e){function n(n,r,a){var i,o=null!==(i=e.NativeCollections[r]())&&void 0!==i?i:null===e.ShimCollections||void 0===e.ShimCollections?void 0:e.ShimCollections[a](t);if(o)return o;throw new Error("TypeScript requires an environment that provides a compatible native "+n+" implementation.")}function t(n){if(n){if(tn(n))return ye(n);if(n instanceof e.Map)return n.entries();if(n instanceof e.Set)return n.values();throw new Error("Iteration not supported.")}}function r(){return new e.Map}function a(n){var t=new e.Map;for(var r in n)Re.call(n,r)&&t.set(r,n[r]);return t}function o(e){return e?e.length:0}function s(e,n){if(e)for(var t=0;t<e.length;t++){var r=n(e[t],t);if(r)return r}}function c(e,n){if(e)for(var t=e.length-1;t>=0;t--){var r=n(e[t],t);if(r)return r}}function l(e,n){if(void 0!==e)for(var t=0;t<e.length;t++){var r=n(e[t],t);if(void 0!==r)return r}}function u(e,n){while(1){var t=e.next();if(t.done)return;var r=n(t.value);if(void 0!==r)return r}}function d(e,n,t){var r=t;if(e)for(var a=e.next(),i=0;!a.done;a=e.next(),i++)r=n(r,a.value,i);return r}function p(n,t,r){var a=[];e.Debug.assertEqual(n.length,t.length);for(var i=0;i<n.length;i++)a.push(r(n[i],t[i],i));return a}function f(n,t){e.Debug.assertEqual(n.length,t.length);var r=0;return{next:function(){return r===n.length?{value:void 0,done:!0}:(r++,{value:[n[r-1],t[r-1]],done:!1})}}}function m(n,t){e.Debug.assert(n.length===t.length);for(var r=new e.Map,a=0;a<n.length;++a)r.set(n[a],t[a]);return r}function _(e,n){if(e.length<=1)return e;for(var t=[],r=0,a=e.length;r<a;r++)r&&t.push(n),t.push(e[r]);return t}function g(e,n){if(e)for(var t=0;t<e.length;t++)if(!n(e[t],t))return!1;return!0}function y(e,n){for(var t=0;t<e.length;t++){var r=e[t];if(n(r,t))return r}}function h(e,n){for(var t=e.length-1;t>=0;t--){var r=e[t];if(n(r,t))return r}}function v(e,n,t){for(var r=t||0;r<e.length;r++)if(n(e[r],r))return r;return-1}function b(e,n,t){for(var r=void 0===t?e.length-1:t;r>=0;r--)if(n(e[r],r))return r;return-1}function E(n,t){for(var r=0;r<n.length;r++){var a=t(n[r],r);if(a)return a}return e.Debug.fail()}function T(e,n,t){if(void 0===t&&(t=En),e)for(var r=0,a=e;r<a.length;r++){var i=a[r];if(t(i,n))return!0}return!1}function S(e,n,t){return void 0===t&&(t=En),e.length===n.length&&e.every((function(e,r){return t(e,n[r])}))}function x(e,n,t){for(var r=t||0;r<e.length;r++)if(T(n,e.charCodeAt(r)))return r;return-1}function L(e,n){var t=0;if(e)for(var r=0;r<e.length;r++){var a=e[r];n(a,r)&&t++}return t}function D(e,n){if(e){var t=e.length,r=0;while(r<t&&n(e[r]))r++;if(r<t){var a=e.slice(0,r);r++;while(r<t){var i=e[r];n(i)&&a.push(i),r++}return a}}return e}function A(e,n){for(var t=0,r=0;r<e.length;r++)n(e[r],r,e)&&(e[t]=e[r],t++);e.length=t}function C(e){e.length=0}function I(e,n){var t;if(e){t=[];for(var r=0;r<e.length;r++)t.push(n(e[r],r))}return t}function N(e,n){return{next:function(){var t=e.next();return t.done?t:{value:n(t.value),done:!1}}}}function k(e,n){if(e)for(var t=0;t<e.length;t++){var r=e[t],a=n(r,t);if(r!==a){var i=e.slice(0,t);for(i.push(a),t++;t<e.length;t++)i.push(n(e[t],t));return i}}return e}function R(e){for(var n=[],t=0,r=e;t<r.length;t++){var a=r[t];a&&(tn(a)?pe(n,a):n.push(a))}return n}function O(n,t){var r;if(n)for(var a=0;a<n.length;a++){var i=t(n[a],a);i&&(r=tn(i)?pe(r,i):le(r,i))}return r||e.emptyArray}function w(e,n){var t=[];if(e)for(var r=0;r<e.length;r++){var a=n(e[r],r);a&&(tn(a)?pe(t,a):t.push(a))}return t}function P(n,t){var r=n.next();if(r.done)return e.emptyIterator;var a=i(r.value);return{next:function(){while(1){var e=a.next();if(!e.done)return e;var t=n.next();if(t.done)return t;a=i(t.value)}}};function i(n){var r=t(n);return void 0===r?e.emptyIterator:tn(r)?ye(r):r}}function M(e,n){var t;if(e)for(var r=0;r<e.length;r++){var a=e[r],i=n(a,r);(t||a!==i||tn(i))&&(t||(t=e.slice(0,r)),tn(i)?pe(t,i):t.push(i))}return t||e}function F(e,n){for(var t=[],r=0;r<e.length;r++){var a=n(e[r],r);if(void 0===a)return;t.push(a)}return t}function G(e,n){var t=[];if(e)for(var r=0;r<e.length;r++){var a=n(e[r],r);void 0!==a&&t.push(a)}return t}function B(e,n){return{next:function(){while(1){var t=e.next();if(t.done)return t;var r=n(t.value);if(void 0!==r)return{value:r,done:!1}}}}}function U(n,t){if(n){var r=new e.Map;return n.forEach((function(e,n){var a=t(n,e);if(void 0!==a){var i=a[0],o=a[1];void 0!==i&&void 0!==o&&r.set(i,o)}})),r}}function V(n,t){if(n){var r=new e.Set;return n.forEach((function(e){var n=t(e);void 0!==n&&r.add(n)})),r}}function j(e,n,t){if(e.has(n))return e.get(n);var r=t();return e.set(n,r),r}function K(e,n){return!e.has(n)&&(e.add(n),!0)}function H(e){var n=!1;return{next:function(){var t=n;return n=!0,t?{value:void 0,done:!0}:{value:e,done:!1}}}}function W(e,n,t){var r;if(e){r=[];var a=e.length,i=void 0,o=void 0,s=0,c=0;while(s<a){while(c<a){var l=e[c];if(o=n(l,c),0===c)i=o;else if(o!==i)break;c++}if(s<c){var u=t(e.slice(s,c),i,s,c);u&&r.push(u),s=c}i=o,c++}}return r}function z(n,t){if(n){var r=new e.Map;return n.forEach((function(e,n){var a=t(n,e),i=a[0],o=a[1];r.set(i,o)})),r}}function q(e,n){if(e){if(!n)return e.length>0;for(var t=0,r=e;t<r.length;t++){var a=r[t];if(n(a))return!0}}return!1}function J(e,n,t){for(var r,a=0;a<e.length;a++)n(e[a])?r=void 0===r?a:r:void 0!==r&&(t(r,a),r=void 0);void 0!==r&&t(r,e.length)}function X(e,n){return q(n)?q(e)?i(i([],e),n):n:e}function Y(e,n){return n}function Q(e){return e.map(Y)}function Z(e,n,t){var r=Q(e);_e(e,r,t);for(var a=e[r[0]],i=[r[0]],o=1;o<r.length;o++){var s=r[o],c=e[s];n(a,c)||(i.push(s),a=c)}return i.sort(),i.map((function(n){return e[n]}))}function $(e,n){for(var t=[],r=0,a=e;r<a.length;r++){var i=a[r];fe(t,i,n)}return t}function ee(e,n,t){return 0===e.length?[]:1===e.length?e.slice():t?Z(e,n,t):$(e,n)}function ne(n,t){if(0===n.length)return e.emptyArray;for(var r=n[0],a=[r],i=1;i<n.length;i++){var o=n[i];switch(t(o,r)){case!0:case 0:continue;case-1:return e.Debug.fail("Array is unsorted.")}a.push(r=o)}return a}function te(e,n,t){if(0!==e.length){var r=Ie(e,n,fn,t);r<0&&e.splice(~r,0,n)}else e.push(n)}function re(e,n,t){return ne(ge(e,n),t||n||In)}function ae(e,n){if(e.length<2)return!0;for(var t=e[0],r=0,a=e.slice(1);r<a.length;r++){var i=a[r];if(1===n(t,i))return!1;t=i}return!0}function ie(e,n,t){if(void 0===t&&(t=En),!e||!n)return e===n;if(e.length!==n.length)return!1;for(var r=0;r<e.length;r++)if(!t(e[r],n[r],r))return!1;return!0}function oe(e){var n;if(e)for(var t=0;t<e.length;t++){var r=e[t];!n&&r||(n||(n=e.slice(0,t)),r&&n.push(r))}return n||e}function se(n,t,r){if(!t||!n||0===t.length||0===n.length)return t;var a=[];e:for(var i=0,o=0;o<t.length;o++){o>0&&e.Debug.assertGreaterThanOrEqual(r(t[o],t[o-1]),0);n:for(var s=i;i<n.length;i++)switch(i>s&&e.Debug.assertGreaterThanOrEqual(r(n[i],n[i-1]),0),r(t[o],n[i])){case-1:a.push(t[o]);continue e;case 0:continue e;case 1:continue n}}return a}function ce(e,n){for(var t=0,r=0,a=e;r<a.length;r++){var i=a[r];t+=i[n]}return t}function le(e,n){return void 0===n?e:void 0===e?[n]:(e.push(n),e)}function ue(e,n){return void 0===e?n:void 0===n?e:tn(e)?tn(n)?X(e,n):le(e,n):tn(n)?le(n,e):[e,n]}function de(e,n){return n<0?e.length+n:n}function pe(e,n,t,r){if(void 0===n||0===n.length)return e;if(void 0===e)return n.slice(t,r);t=void 0===t?0:de(n,t),r=void 0===r?n.length:de(n,r);for(var a=t;a<r&&a<n.length;a++)void 0!==n[a]&&e.push(n[a]);return e}function fe(e,n,t){return!T(e,n,t)&&(e.push(n),!0)}function me(e,n,t){return e?(fe(e,n,t),e):[n]}function _e(e,n,t){n.sort((function(n,r){return t(e[n],e[r])||Ln(n,r)}))}function ge(e,n){return 0===e.length?e:e.slice().sort(n)}function ye(e){var n=0;return{next:function(){return n===e.length?{value:void 0,done:!0}:(n++,{value:e[n-1],done:!1})}}}function he(e){var n=e.length;return{next:function(){return 0===n?{value:void 0,done:!0}:(n--,{value:e[n],done:!1})}}}function ve(e,n){var t=Q(e);return _e(e,t,n),t.map((function(n){return e[n]}))}function be(e,n,t,r){while(t<r){if(e[t]!==n[t])return!1;t++}return!0}function Ee(e,n){if(e&&(n=de(e,n),n<e.length))return e[n]}function Te(e){return 0===e.length?void 0:e[0]}function Se(n){return e.Debug.assert(0!==n.length),n[0]}function xe(e){return 0===e.length?void 0:e[e.length-1]}function Le(n){return e.Debug.assert(0!==n.length),n[n.length-1]}function De(e){return e&&1===e.length?e[0]:void 0}function Ae(e){return e&&1===e.length?e[0]:e}function Ce(e,n,t){var r=e.slice(0);return r[n]=t,r}function Ie(e,n,t,r,a){return Ne(e,t(n),t,r,a)}function Ne(e,n,t,r,a){if(!q(e))return-1;var i=a||0,o=e.length-1;while(i<=o){var s=i+(o-i>>1),c=t(e[s],s);switch(r(c,n)){case-1:i=s+1;break;case 0:return s;case 1:o=s-1;break}}return~i}function ke(e,n,t,r,a){if(e&&e.length>0){var i=e.length;if(i>0){var o=void 0===r||r<0?0:r,s=void 0===a||o+a>i-1?i-1:o+a,c=void 0;arguments.length<=2?(c=e[o],o++):c=t;while(o<=s)c=n(c,e[o],o),o++;return c}}return t}e.Map=n("Map","tryGetNativeMap","createMapShim"),e.Set=n("Set","tryGetNativeSet","createSetShim"),e.getIterator=t,e.emptyArray=[],e.emptyMap=new e.Map,e.emptySet=new e.Set,e.createMap=r,e.createMapFromTemplate=a,e.length=o,e.forEach=s,e.forEachRight=c,e.firstDefined=l,e.firstDefinedIterator=u,e.reduceLeftIterator=d,e.zipWith=p,e.zipToIterator=f,e.zipToMap=m,e.intersperse=_,e.every=g,e.find=y,e.findLast=h,e.findIndex=v,e.findLastIndex=b,e.findMap=E,e.contains=T,e.arraysEqual=S,e.indexOfAnyCharCode=x,e.countWhere=L,e.filter=D,e.filterMutate=A,e.clear=C,e.map=I,e.mapIterator=N,e.sameMap=k,e.flatten=R,e.flatMap=O,e.flatMapToMutable=w,e.flatMapIterator=P,e.sameFlatMap=M,e.mapAllOrFail=F,e.mapDefined=G,e.mapDefinedIterator=B,e.mapDefinedEntries=U,e.mapDefinedValues=V,e.getOrUpdate=j,e.tryAddToSet=K,e.emptyIterator={next:function(){return{value:void 0,done:!0}}},e.singleIterator=H,e.spanMap=W,e.mapEntries=z,e.some=q,e.getRangesWhere=J,e.concatenate=X,e.indicesOf=Q,e.deduplicate=ee,e.insertSorted=te,e.sortAndDeduplicate=re,e.arrayIsSorted=ae,e.arrayIsEqualTo=ie,e.compact=oe,e.relativeComplement=se,e.sum=ce,e.append=le,e.combine=ue,e.addRange=pe,e.pushIfUnique=fe,e.appendIfUnique=me,e.sort=ge,e.arrayIterator=ye,e.arrayReverseIterator=he,e.stableSort=ve,e.rangeEquals=be,e.elementAt=Ee,e.firstOrUndefined=Te,e.first=Se,e.lastOrUndefined=xe,e.last=Le,e.singleOrUndefined=De,e.singleOrMany=Ae,e.replaceElement=Ce,e.binarySearch=Ie,e.binarySearchKey=Ne,e.reduceLeft=ke;var Re=Object.prototype.hasOwnProperty;function Oe(e,n){return Re.call(e,n)}function we(e,n){return Re.call(e,n)?e[n]:void 0}function Pe(e){var n=[];for(var t in e)Re.call(e,t)&&n.push(t);return n}function Me(e){var n=[];do{for(var t=Object.getOwnPropertyNames(e),r=0,a=t;r<a.length;r++){var i=a[r];fe(n,i)}}while(e=Object.getPrototypeOf(e));return n}function Fe(e){var n=[];for(var t in e)Re.call(e,t)&&n.push(e[t]);return n}e.hasProperty=Oe,e.getProperty=we,e.getOwnKeys=Pe,e.getAllKeys=Me,e.getOwnValues=Fe;var Ge=Object.entries||function(e){for(var n=Pe(e),t=Array(n.length),r=0;r<n.length;r++)t[r]=[n[r],e[n[r]]];return t};function Be(e){return e?Ge(e):[]}function Ue(e,n){for(var t=new Array(e),r=0;r<e;r++)t[r]=n(r);return t}function Ve(e,n){for(var t=[],r=e.next();!r.done;r=e.next())t.push(n?n(r.value):r.value);return t}function je(e){for(var n=[],t=1;t<arguments.length;t++)n[t-1]=arguments[t];for(var r=0,a=n;r<a.length;r++){var i=a[r];if(void 0!==i)for(var o in i)Oe(i,o)&&(e[o]=i[o])}return e}function Ke(e,n,t){if(void 0===t&&(t=En),e===n)return!0;if(!e||!n)return!1;for(var r in e)if(Re.call(e,r)){if(!Re.call(n,r))return!1;if(!t(e[r],n[r]))return!1}for(var r in n)if(Re.call(n,r)&&!Re.call(e,r))return!1;return!0}function He(n,t,r){void 0===r&&(r=fn);for(var a=new e.Map,i=0,o=n;i<o.length;i++){var s=o[i],c=t(s);void 0!==c&&a.set(c,r(s))}return a}function We(e,n,t){void 0===t&&(t=fn);for(var r=[],a=0,i=e;a<i.length;a++){var o=i[a];r[n(o)]=t(o)}return r}function ze(e,n,t){void 0===t&&(t=fn);for(var r=Ze(),a=0,i=e;a<i.length;a++){var o=i[a];r.add(n(o),t(o))}return r}function qe(e,n,t){return void 0===t&&(t=fn),Ve(ze(e,n).values(),t)}function Je(e){var n={};for(var t in e)Re.call(e,t)&&(n[t]=e[t]);return n}function Xe(e,n){var t={};for(var r in n)Re.call(n,r)&&(t[r]=n[r]);for(var r in e)Re.call(e,r)&&(t[r]=e[r]);return t}function Ye(e,n){for(var t in n)Re.call(n,t)&&(e[t]=n[t])}function Qe(e,n){return n?n.bind(e):void 0}function Ze(){var n=new e.Map;return n.add=$e,n.remove=en,n}function $e(e,n){var t=this.get(e);return t?t.push(n):this.set(e,t=[n]),t}function en(e,n){var t=this.get(e);t&&(Xn(t,n),t.length||this.delete(e))}function nn(){return Ze()}function tn(e){return Array.isArray?Array.isArray(e):e instanceof Array}function rn(e){return tn(e)?e:[e]}function an(e){return"string"===typeof e}function on(e){return"number"===typeof e}function sn(e,n){return void 0!==e&&n(e)?e:void 0}function cn(n,t){return void 0!==n&&t(n)?n:e.Debug.fail("Invalid cast. The supplied value "+n+" did not pass the test '"+e.Debug.getFunctionName(t)+"'.")}function ln(e){}function un(){return!1}function dn(){return!0}function pn(){}function fn(e){return e}function mn(e){return e.toLowerCase()}e.getEntries=Be,e.arrayOf=Ue,e.arrayFrom=Ve,e.assign=je,e.equalOwnProperties=Ke,e.arrayToMap=He,e.arrayToNumericMap=We,e.arrayToMultiMap=ze,e.group=qe,e.clone=Je,e.extend=Xe,e.copyProperties=Ye,e.maybeBind=Qe,e.createMultiMap=Ze,e.createUnderscoreEscapedMultiMap=nn,e.isArray=tn,e.toArray=rn,e.isString=an,e.isNumber=on,e.tryCast=sn,e.cast=cn,e.noop=ln,e.returnFalse=un,e.returnTrue=dn,e.returnUndefined=pn,e.identity=fn,e.toLowerCase=mn;var _n=/[^\u0130\u0131\u00DFa-z0-9\\/:\-_\. ]+/g;function gn(e){return _n.test(e)?e.replace(_n,mn):e}function yn(){throw new Error("Not implemented")}function hn(e){var n;return function(){return e&&(n=e(),e=void 0),n}}function vn(n){var t=new e.Map;return function(e){var r=typeof e+":"+e,a=t.get(r);return void 0!==a||t.has(r)||(a=n(e),t.set(r,a)),a}}function bn(e,n,t,r,a){if(a){for(var i=[],o=0;o<arguments.length;o++)i[o]=arguments[o];return function(e){return ke(i,(function(e,n){return n(e)}),e)}}return r?function(a){return r(t(n(e(a))))}:t?function(r){return t(n(e(r)))}:n?function(t){return n(e(t))}:e?function(n){return e(n)}:function(e){return e}}function En(e,n){return e===n}function Tn(e,n){return e===n||void 0!==e&&void 0!==n&&e.toUpperCase()===n.toUpperCase()}function Sn(e,n){return En(e,n)}function xn(e,n){return e===n?0:void 0===e?-1:void 0===n?1:e<n?-1:1}function Ln(e,n){return xn(e,n)}function Dn(e,n){return Ln(null===e||void 0===e?void 0:e.start,null===n||void 0===n?void 0:n.start)||Ln(null===e||void 0===e?void 0:e.length,null===n||void 0===n?void 0:n.length)}function An(e,n,t){return-1===t(e,n)?e:n}function Cn(e,n){return e===n?0:void 0===e?-1:void 0===n?1:(e=e.toUpperCase(),n=n.toUpperCase(),e<n?-1:e>n?1:0)}function In(e,n){return xn(e,n)}function Nn(e){return e?Cn:In}e.toFileNameLowerCase=gn,e.notImplemented=yn,e.memoize=hn,e.memoizeOne=vn,e.compose=bn,function(e){e[e["None"]=0]="None",e[e["Normal"]=1]="Normal",e[e["Aggressive"]=2]="Aggressive",e[e["VeryAggressive"]=3]="VeryAggressive"}(e.AssertionLevel||(e.AssertionLevel={})),e.equateValues=En,e.equateStringsCaseInsensitive=Tn,e.equateStringsCaseSensitive=Sn,e.compareValues=Ln,e.compareTextSpans=Dn,e.min=An,e.compareStringsCaseInsensitive=Cn,e.compareStringsCaseSensitive=In,e.getStringComparer=Nn;var kn,Rn,On=function(){var e,n,t=s();return c;function r(e,n,t){if(e===n)return 0;if(void 0===e)return-1;if(void 0===n)return 1;var r=t(e,n);return r<0?-1:r>0?1:0}function a(e){var n=new Intl.Collator(e,{usage:"sort",sensitivity:"variant"}).compare;return function(e,t){return r(e,t,n)}}function i(e){return void 0!==e?o():function(e,t){return r(e,t,n)};function n(e,n){return e.localeCompare(n)}}function o(){return function(n,t){return r(n,t,e)};function e(e,t){return n(e.toUpperCase(),t.toUpperCase())||n(e,t)}function n(e,n){return e<n?-1:e>n?1:0}}function s(){return"object"===typeof Intl&&"function"===typeof Intl.Collator?a:"function"===typeof String.prototype.localeCompare&&"function"===typeof String.prototype.toLocaleUpperCase&&"a".localeCompare("B")<0?i:o}function c(r){return void 0===r?e||(e=t(r)):"en-US"===r?n||(n=t(r)):t(r)}}();function wn(){return Rn}function Pn(e){Rn!==e&&(Rn=e,kn=void 0)}function Mn(e,n){var t=kn||(kn=On(Rn));return t(e,n)}function Fn(e,n,t,r){return e===n?0:void 0===e?-1:void 0===n?1:r(e[t],n[t])}function Gn(e,n){return Ln(e?1:0,n?1:0)}function Bn(n,t,r){for(var a,i=Math.min(2,Math.floor(.34*n.length)),o=Math.floor(.4*n.length)+1,s=0,c=t;s<c.length;s++){var l=c[s],u=r(l);if(void 0!==u&&Math.abs(u.length-n.length)<=i){if(u===n)continue;if(u.length<3&&u.toLowerCase()!==n.toLowerCase())continue;var d=Un(n,u,o-.1);if(void 0===d)continue;e.Debug.assert(d<o),o=d,a=l}}return a}function Un(e,n,t){for(var r=new Array(n.length+1),a=new Array(n.length+1),i=t+.01,o=0;o<=n.length;o++)r[o]=o;for(o=1;o<=e.length;o++){var s=e.charCodeAt(o-1),c=Math.ceil(o>t?o-t:1),l=Math.floor(n.length>t+o?t+o:n.length);a[0]=o;for(var u=o,d=1;d<c;d++)a[d]=i;for(d=c;d<=l;d++){var p=e[o-1].toLowerCase()===n[d-1].toLowerCase()?r[d-1]+.1:r[d-1]+2,f=s===n.charCodeAt(d-1)?r[d-1]:Math.min(r[d]+1,a[d-1]+1,p);a[d]=f,u=Math.min(u,f)}for(d=l+1;d<=n.length;d++)a[d]=i;if(u>t)return;var m=r;r=a,a=m}var _=r[n.length];return _>t?void 0:_}function Vn(e,n){var t=e.length-n.length;return t>=0&&e.indexOf(n,t)===t}function jn(e,n){return Vn(e,n)?e.slice(0,e.length-n.length):e}function Kn(e,n){return Vn(e,n)?e.slice(0,e.length-n.length):void 0}function Hn(e,n){return-1!==e.indexOf(n)}function Wn(e){var n=/[.-]((min)|(\d+(\.\d+)*))$/;return e.replace(n,"").replace(n,"")}function zn(e,n){for(var t=0;t<e.length;t++)if(e[t]===n)return qn(e,t),!0;return!1}function qn(e,n){for(var t=n;t<e.length-1;t++)e[t]=e[t+1];e.pop()}function Jn(e,n){e[n]=e[e.length-1],e.pop()}function Xn(e,n){return Yn(e,(function(e){return e===n}))}function Yn(e,n){for(var t=0;t<e.length;t++)if(n(e[t]))return Jn(e,t),!0;return!1}function Qn(e){return e?fn:gn}function Zn(e){var n=e.prefix,t=e.suffix;return n+"*"+t}function $n(n,t){return e.Debug.assert(at(n,t)),t.substring(n.prefix.length,t.length-n.suffix.length)}function et(e,n,t){for(var r,a=-1,i=0,o=e;i<o.length;i++){var s=o[i],c=n(s);at(c,t)&&c.prefix.length>a&&(a=c.prefix.length,r=s)}return r}function nt(e,n){return 0===e.lastIndexOf(n,0)}function tt(e,n){return nt(e,n)?e.substr(n.length):e}function rt(e,n,t){return void 0===t&&(t=fn),nt(t(e),t(n))?e.substring(n.length):void 0}function at(e,n){var t=e.prefix,r=e.suffix;return n.length>=t.length+r.length&&nt(n,t)&&Vn(n,r)}function it(e,n){return function(t){return e(t)&&n(t)}}function ot(){for(var e=[],n=0;n<arguments.length;n++)e[n]=arguments[n];return function(){for(var n=[],t=0;t<arguments.length;t++)n[t]=arguments[t];for(var r=0,a=e;r<a.length;r++){var i=a[r];if(i.apply(void 0,n))return!0}return!1}}function st(e){return function(){for(var n=[],t=0;t<arguments.length;t++)n[t]=arguments[t];return!e.apply(void 0,n)}}function ct(e){}function lt(e){return void 0===e?void 0:[e]}function ut(e,n,t,r,a,i){i=i||ln;var o=0,s=0,c=e.length,l=n.length,u=!1;while(o<c&&s<l){var d=e[o],p=n[s],f=t(d,p);-1===f?(r(d),o++,u=!0):1===f?(a(p),s++,u=!0):(i(p,d),o++,s++)}while(o<c)r(e[o++]),u=!0;while(s<l)a(n[s++]),u=!0;return u}function dt(e,n){for(var t=Array(e),r=0;r<e;r++)t[r]=n(r);return t}function pt(e){var n=[];return ft(e,n,void 0,0),n}function ft(e,n,t,r){for(var a=0,i=e[r];a<i.length;a++){var o=i[a],s=void 0;t?(s=t.slice(),s.push(o)):s=[o],r===e.length-1?n.push(s):ft(e,n,s,r+1)}}function mt(e,n,t){return void 0===t&&(t=" "),n<=e.length?e:t.repeat(n-e.length)+e}function _t(e,n,t){return void 0===t&&(t=" "),n<=e.length?e:e+t.repeat(n-e.length)}function gt(e,n){var t=e.length,r=0;while(r<t&&n(e[r]))r++;return e.slice(0,r)}e.getUILocale=wn,e.setUILocale=Pn,e.compareStringsCaseSensitiveUI=Mn,e.compareProperties=Fn,e.compareBooleans=Gn,e.getSpellingSuggestion=Bn,e.endsWith=Vn,e.removeSuffix=jn,e.tryRemoveSuffix=Kn,e.stringContains=Hn,e.removeMinAndVersionNumbers=Wn,e.orderedRemoveItem=zn,e.orderedRemoveItemAt=qn,e.unorderedRemoveItemAt=Jn,e.unorderedRemoveItem=Xn,e.createGetCanonicalFileName=Qn,e.patternText=Zn,e.matchedText=$n,e.findBestPatternMatch=et,e.startsWith=nt,e.removePrefix=tt,e.tryRemovePrefix=rt,e.and=it,e.or=ot,e.not=st,e.assertType=ct,e.singleElementArray=lt,e.enumerateInsertsAndDeletes=ut,e.fill=dt,e.cartesianProduct=pt,e.padLeft=mt,e.padRight=_t,e.takeWhile=gt}(d||(d={})),function(e){var n;(function(e){e[e["Off"]=0]="Off",e[e["Error"]=1]="Error",e[e["Warning"]=2]="Warning",e[e["Info"]=3]="Info",e[e["Verbose"]=4]="Verbose"})(n=e.LogLevel||(e.LogLevel={})),function(t){var r,a=0;function i(){return null!==r&&void 0!==r?r:r=new e.Version(e.version)}function o(e){return t.currentLogLevel<=e}function s(e,n){t.loggingHost&&o(e)&&t.loggingHost.log(e,n)}function c(e){s(n.Info,e)}t.currentLogLevel=n.Warning,t.isDebugging=!1,t.getTypeScriptVersion=i,t.shouldLog=o,t.log=c,function(e){function t(e){s(n.Error,e)}function r(e){s(n.Warning,e)}function a(e){s(n.Info,e)}function i(e){s(n.Verbose,e)}e.error=t,e.warn=r,e.log=a,e.trace=i}(c=t.log||(t.log={}));var l={};function u(){return a}function d(n){var r=a;if(a=n,n>r)for(var i=0,o=e.getOwnKeys(l);i<o.length;i++){var s=o[i],c=l[s];void 0!==c&&t[s]!==c.assertion&&n>=c.level&&(t[s]=c,l[s]=void 0)}}function p(e){return a>=e}function f(n,r){return!!p(n)||(l[r]={level:n,assertion:t[r]},t[r]=e.noop,!1)}function m(e,n){var t=new Error(e?"Debug Failure. "+e:"Debug Failure.");throw Error.captureStackTrace&&Error.captureStackTrace(t,n||m),t}function _(e,n,t){return m((n||"Unexpected node.")+"\r\nNode "+F(e.kind)+" was unexpected.",t||_)}function g(e,n,t,r){e||(n=n?"False expression: "+n:"False expression.",t&&(n+="\r\nVerbose Debug Information: "+("string"===typeof t?t:t())),m(n,r||g))}function y(e,n,t,r,a){if(e!==n){var i=t?r?t+" "+r:t:"";m("Expected "+e+" === "+n+". "+i,a||y)}}function h(e,n,t,r){e>=n&&m("Expected "+e+" < "+n+". "+(t||""),r||h)}function v(e,n,t){e>n&&m("Expected "+e+" <= "+n,t||v)}function b(e,n,t){e<n&&m("Expected "+e+" >= "+n,t||b)}function E(e,n,t){void 0!==e&&null!==e||m(n,t||E)}function T(e,n,t){return E(e,n,t||T),e}function S(e,n,t){for(var r=0,a=e;r<a.length;r++){var i=a[r];E(i,n,t||S)}}function x(e,n,t){return S(e,n,t||x),e}function L(n,t,r){void 0===t&&(t="Illegal value:");var a="object"===typeof n&&e.hasProperty(n,"kind")&&e.hasProperty(n,"pos")&&F?"SyntaxKind: "+F(n.kind):JSON.stringify(n);return m(t+" "+a,r||L)}function D(n,t,r,a){f(1,"assertEachNode")&&g(void 0===t||e.every(n,t),r||"Unexpected node.",(function(){return"Node array did not pass test '"+O(t)+"'."}),a||D)}function A(e,n,t,r){f(1,"assertNode")&&g(void 0!==e&&(void 0===n||n(e)),t||"Unexpected node.",(function(){return"Node "+F(e.kind)+" did not pass test '"+O(n)+"'."}),r||A)}function C(e,n,t,r){f(1,"assertNotNode")&&g(void 0===e||void 0===n||!n(e),t||"Unexpected node.",(function(){return"Node "+F(e.kind)+" should not have passed test '"+O(n)+"'."}),r||C)}function I(e,n,t,r){f(1,"assertOptionalNode")&&g(void 0===n||void 0===e||n(e),t||"Unexpected node.",(function(){return"Node "+F(e.kind)+" did not pass test '"+O(n)+"'."}),r||I)}function N(e,n,t,r){f(1,"assertOptionalToken")&&g(void 0===n||void 0===e||e.kind===n,t||"Unexpected node.",(function(){return"Node "+F(e.kind)+" was not a '"+F(n)+"' token."}),r||N)}function k(e,n,t){f(1,"assertMissingNode")&&g(void 0===e,n||"Unexpected node.",(function(){return"Node "+F(e.kind)+" was unexpected'."}),t||k)}function R(e){}function O(e){if("function"!==typeof e)return"";if(e.hasOwnProperty("name"))return e.name;var n=Function.prototype.toString.call(e),t=/^function\s+([\w\$]+)\s*\(/.exec(n);return t?t[1]:""}function w(n){return"{ name: "+e.unescapeLeadingUnderscores(n.escapedName)+"; flags: "+j(n.flags)+"; declarations: "+e.map(n.declarations,(function(e){return F(e.kind)}))+" }"}function P(e,n,t){void 0===e&&(e=0);var r=M(n);if(0===e)return r.length>0&&0===r[0][0]?r[0][1]:"0";if(t){for(var a="",i=e,o=0,s=r;o<s.length;o++){var c=s[o],l=c[0],u=c[1];if(l>e)break;0!==l&&l&e&&(a=a+(a?"|":"")+u,i&=~l)}if(0===i)return a}else for(var d=0,p=r;d<p.length;d++){var f=p[d];l=f[0],u=f[1];if(l===e)return u}return e.toString()}function M(n){var t=[];for(var r in n){var a=n[r];"number"===typeof a&&t.push([a,r])}return e.stableSort(t,(function(n,t){return e.compareValues(n[0],t[0])}))}function F(n){return P(n,e.SyntaxKind,!1)}function G(n){return P(n,e.NodeFlags,!0)}function B(n){return P(n,e.ModifierFlags,!0)}function U(n){return P(n,e.TransformFlags,!0)}function V(n){return P(n,e.EmitFlags,!0)}function j(n){return P(n,e.SymbolFlags,!0)}function K(n){return P(n,e.TypeFlags,!0)}function H(n){return P(n,e.SignatureFlags,!0)}function W(n){return P(n,e.ObjectFlags,!0)}function z(n){return P(n,e.FlowFlags,!0)}t.getAssertionLevel=u,t.setAssertionLevel=d,t.shouldAssert=p,t.fail=m,t.failBadSyntaxKind=_,t.assert=g,t.assertEqual=y,t.assertLessThan=h,t.assertLessThanOrEqual=v,t.assertGreaterThanOrEqual=b,t.assertIsDefined=E,t.checkDefined=T,t.assertDefined=T,t.assertEachIsDefined=S,t.checkEachDefined=x,t.assertEachDefined=x,t.assertNever=L,t.assertEachNode=D,t.assertNode=A,t.assertNotNode=C,t.assertOptionalNode=I,t.assertOptionalToken=N,t.assertMissingNode=k,t.type=R,t.getFunctionName=O,t.formatSymbol=w,t.formatEnum=P,t.formatSyntaxKind=F,t.formatNodeFlags=G,t.formatModifierFlags=B,t.formatTransformFlags=U,t.formatEmitFlags=V,t.formatSymbolFlags=j,t.formatTypeFlags=K,t.formatSignatureFlags=H,t.formatObjectFlags=W,t.formatFlowFlags=z;var q,J,X,Y=!1;function Q(){if(ae(),!q)throw new Error("Debugging helpers could not be loaded.");return q}function Z(e){return console.log($(e))}function $(e){return Q().formatControlFlowGraph(e)}function ee(n){"__debugFlowFlags"in n||Object.defineProperties(n,{__tsDebuggerDisplay:{value:function(){var e=2&this.flags?"FlowStart":4&this.flags?"FlowBranchLabel":8&this.flags?"FlowLoopLabel":16&this.flags?"FlowAssignment":32&this.flags?"FlowTrueCondition":64&this.flags?"FlowFalseCondition":128&this.flags?"FlowSwitchClause":256&this.flags?"FlowArrayMutation":512&this.flags?"FlowCall":1024&this.flags?"FlowReduceLabel":1&this.flags?"FlowUnreachable":"UnknownFlow",n=-2048&this.flags;return e+(n?" ("+z(n)+")":"")}},__debugFlowFlags:{get:function(){return P(this.flags,e.FlowFlags,!0)}},__debugToString:{value:function(){return $(this)}}})}function ne(e){Y&&("function"===typeof Object.setPrototypeOf?(J||(J=Object.create(Object.prototype),ee(J)),Object.setPrototypeOf(e,J)):ee(e))}function te(e){"__tsDebuggerDisplay"in e||Object.defineProperties(e,{__tsDebuggerDisplay:{value:function(e){return e=String(e).replace(/(?:,[\s\w\d_]+:[^,]+)+\]$/,"]"),"NodeArray "+e}}})}function re(e){Y&&("function"===typeof Object.setPrototypeOf?(X||(X=Object.create(Array.prototype),te(X)),Object.setPrototypeOf(e,X)):te(e))}function ae(){if(!Y){var n,t;Object.defineProperties(e.objectAllocator.getSymbolConstructor().prototype,{__tsDebuggerDisplay:{value:function(){var n=33554432&this.flags?"TransientSymbol":"Symbol",t=-33554433&this.flags;return n+" '"+e.symbolName(this)+"'"+(t?" ("+j(t)+")":"")}},__debugFlags:{get:function(){return j(this.flags)}}}),Object.defineProperties(e.objectAllocator.getTypeConstructor().prototype,{__tsDebuggerDisplay:{value:function(){var n=98304&this.flags?"NullableType":384&this.flags?"LiteralType "+JSON.stringify(this.value):2048&this.flags?"LiteralType "+(this.value.negative?"-":"")+this.value.base10Value+"n":8192&this.flags?"UniqueESSymbolType":32&this.flags?"EnumType":67359327&this.flags?"IntrinsicType "+this.intrinsicName:1048576&this.flags?"UnionType":2097152&this.flags?"IntersectionType":4194304&this.flags?"IndexType":8388608&this.flags?"IndexedAccessType":16777216&this.flags?"ConditionalType":33554432&this.flags?"SubstitutionType":262144&this.flags?"TypeParameter":524288&this.flags?3&this.objectFlags?"InterfaceType":4&this.objectFlags?"TypeReference":8&this.objectFlags?"TupleType":16&this.objectFlags?"AnonymousType":32&this.objectFlags?"MappedType":1024&this.objectFlags?"ReverseMappedType":256&this.objectFlags?"EvolvingArrayType":"ObjectType":"Type",t=524288&this.flags?-1344&this.objectFlags:0;return n+(this.symbol?" '"+e.symbolName(this.symbol)+"'":"")+(t?" ("+W(t)+")":"")}},__debugFlags:{get:function(){return K(this.flags)}},__debugObjectFlags:{get:function(){return 524288&this.flags?W(this.objectFlags):""}},__debugTypeToString:{value:function(){var e=c(),n=null===e||void 0===e?void 0:e.get(this);return void 0===n&&(n=this.checker.typeToString(this),null===e||void 0===e||e.set(this,n)),n}}}),Object.defineProperties(e.objectAllocator.getSignatureConstructor().prototype,{__debugFlags:{get:function(){return H(this.flags)}},__debugSignatureToString:{value:function(){var e;return null===(e=this.checker)||void 0===e?void 0:e.signatureToString(this)}}});for(var r=[e.objectAllocator.getNodeConstructor(),e.objectAllocator.getIdentifierConstructor(),e.objectAllocator.getTokenConstructor(),e.objectAllocator.getSourceFileConstructor()],a=0,i=r;a<i.length;a++){var o=i[a];o.prototype.hasOwnProperty("__debugKind")||Object.defineProperties(o.prototype,{__tsDebuggerDisplay:{value:function(){var n=e.isGeneratedIdentifier(this)?"GeneratedIdentifier":e.isIdentifier(this)?"Identifier '"+e.idText(this)+"'":e.isPrivateIdentifier(this)?"PrivateIdentifier '"+e.idText(this)+"'":e.isStringLiteral(this)?"StringLiteral "+JSON.stringify(this.text.length<10?this.text:this.text.slice(10)+"..."):e.isNumericLiteral(this)?"NumericLiteral "+this.text:e.isBigIntLiteral(this)?"BigIntLiteral "+this.text+"n":e.isTypeParameterDeclaration(this)?"TypeParameterDeclaration":e.isParameter(this)?"ParameterDeclaration":e.isConstructorDeclaration(this)?"ConstructorDeclaration":e.isGetAccessorDeclaration(this)?"GetAccessorDeclaration":e.isSetAccessorDeclaration(this)?"SetAccessorDeclaration":e.isCallSignatureDeclaration(this)?"CallSignatureDeclaration":e.isConstructSignatureDeclaration(this)?"ConstructSignatureDeclaration":e.isIndexSignatureDeclaration(this)?"IndexSignatureDeclaration":e.isTypePredicateNode(this)?"TypePredicateNode":e.isTypeReferenceNode(this)?"TypeReferenceNode":e.isFunctionTypeNode(this)?"FunctionTypeNode":e.isConstructorTypeNode(this)?"ConstructorTypeNode":e.isTypeQueryNode(this)?"TypeQueryNode":e.isTypeLiteralNode(this)?"TypeLiteralNode":e.isArrayTypeNode(this)?"ArrayTypeNode":e.isTupleTypeNode(this)?"TupleTypeNode":e.isOptionalTypeNode(this)?"OptionalTypeNode":e.isRestTypeNode(this)?"RestTypeNode":e.isUnionTypeNode(this)?"UnionTypeNode":e.isIntersectionTypeNode(this)?"IntersectionTypeNode":e.isConditionalTypeNode(this)?"ConditionalTypeNode":e.isInferTypeNode(this)?"InferTypeNode":e.isParenthesizedTypeNode(this)?"ParenthesizedTypeNode":e.isThisTypeNode(this)?"ThisTypeNode":e.isTypeOperatorNode(this)?"TypeOperatorNode":e.isIndexedAccessTypeNode(this)?"IndexedAccessTypeNode":e.isMappedTypeNode(this)?"MappedTypeNode":e.isLiteralTypeNode(this)?"LiteralTypeNode":e.isNamedTupleMember(this)?"NamedTupleMember":e.isImportTypeNode(this)?"ImportTypeNode":F(this.kind);return n+(this.flags?" ("+G(this.flags)+")":"")}},__debugKind:{get:function(){return F(this.kind)}},__debugNodeFlags:{get:function(){return G(this.flags)}},__debugModifierFlags:{get:function(){return B(e.getEffectiveModifierFlagsNoCache(this))}},__debugTransformFlags:{get:function(){return U(this.transformFlags)}},__debugIsParseTreeNode:{get:function(){return e.isParseTreeNode(this)}},__debugEmitFlags:{get:function(){return V(e.getEmitFlags(this))}},__debugGetText:{value:function(n){if(e.nodeIsSynthesized(this))return"";var t=l(),r=null===t||void 0===t?void 0:t.get(this);if(void 0===r){var a=e.getParseTreeNode(this),i=a&&e.getSourceFileOfNode(a);r=i?e.getSourceTextOfNodeFromSourceFile(i,a,n):"",null===t||void 0===t||t.set(this,r)}return r}}})}try{if(e.sys&&e.sys.require){e.getDirectoryPath(e.resolvePath(e.sys.getExecutingFilePath()));var s=void 0;s.error||(s.module.init(e),q=s.module)}}catch(u){}Y=!0}function c(){return void 0===n&&"function"===typeof WeakMap&&(n=new WeakMap),n}function l(){return void 0===t&&"function"===typeof WeakMap&&(t=new WeakMap),t}}function ie(n,t,r,a,i){var o=t?"DeprecationError: ":"DeprecationWarning: ";return o+="'"+n+"' ",o+=a?"has been deprecated since v"+a:"is deprecated",o+=t?" and can no longer be used.":r?" and will no longer be usable after v"+r+".":".",o+=i?" "+e.formatStringFromArgs(i,[n],0):"",o}function oe(e,n,t,r){var a=ie(e,!0,n,t,r);return function(){throw new TypeError(a)}}function se(e,n,t,r){var a=!1;return function(){a||(c.warn(ie(e,!1,n,t,r)),a=!0)}}function ce(n,t){var r,a;void 0===t&&(t={});var o="string"===typeof t.typeScriptVersion?new e.Version(t.typeScriptVersion):null!==(r=t.typeScriptVersion)&&void 0!==r?r:i(),s="string"===typeof t.errorAfter?new e.Version(t.errorAfter):t.errorAfter,c="string"===typeof t.warnAfter?new e.Version(t.warnAfter):t.warnAfter,l="string"===typeof t.since?new e.Version(t.since):null!==(a=t.since)&&void 0!==a?a:c,u=t.error||s&&o.compareTo(s)<=0,d=!c||o.compareTo(c)>=0;return u?oe(n,s,l,t.message):d?se(n,s,l,t.message):e.noop}function le(e,n){return function(){return e(),n.apply(this,arguments)}}function ue(e,n){var t=ce(O(e),n);return le(t,e)}t.printControlFlowGraph=Z,t.formatControlFlowGraph=$,t.attachFlowNodeDebugInfo=ne,t.attachNodeArrayDebugInfo=re,t.enableDebugInfo=ae,t.deprecate=ue}(e.Debug||(e.Debug={}))}(d||(d={})),function(e){var n=/^(0|[1-9]\d*)(?:\.(0|[1-9]\d*)(?:\.(0|[1-9]\d*)(?:\-([a-z0-9-.]+))?(?:\+([a-z0-9-.]+))?)?)?$/i,t=/^(?:0|[1-9]\d*|[a-z-][a-z0-9-]*)(?:\.(?:0|[1-9]\d*|[a-z-][a-z0-9-]*))*$/i,r=/^[a-z0-9-]+(?:\.[a-z0-9-]+)*$/i,a=/^(0|[1-9]\d*)$/,i=function(){function n(n,a,i,s,c){if(void 0===a&&(a=0),void 0===i&&(i=0),void 0===s&&(s=""),void 0===c&&(c=""),"string"===typeof n){var l=e.Debug.checkDefined(o(n),"Invalid version");n=l.major,a=l.minor,i=l.patch,s=l.prerelease,c=l.build}e.Debug.assert(n>=0,"Invalid argument: major"),e.Debug.assert(a>=0,"Invalid argument: minor"),e.Debug.assert(i>=0,"Invalid argument: patch"),e.Debug.assert(!s||t.test(s),"Invalid argument: prerelease"),e.Debug.assert(!c||r.test(c),"Invalid argument: build"),this.major=n,this.minor=a,this.patch=i,this.prerelease=s?s.split("."):e.emptyArray,this.build=c?c.split("."):e.emptyArray}return n.tryParse=function(e){var t=o(e);if(t){var r=t.major,a=t.minor,i=t.patch,s=t.prerelease,c=t.build;return new n(r,a,i,s,c)}},n.prototype.compareTo=function(n){return this===n?0:void 0===n?1:e.compareValues(this.major,n.major)||e.compareValues(this.minor,n.minor)||e.compareValues(this.patch,n.patch)||s(this.prerelease,n.prerelease)},n.prototype.increment=function(t){switch(t){case"major":return new n(this.major+1,0,0);case"minor":return new n(this.major,this.minor+1,0);case"patch":return new n(this.major,this.minor,this.patch+1);default:return e.Debug.assertNever(t)}},n.prototype.toString=function(){var n=this.major+"."+this.minor+"."+this.patch;return e.some(this.prerelease)&&(n+="-"+this.prerelease.join(".")),e.some(this.build)&&(n+="+"+this.build.join(".")),n},n.zero=new n(0,0,0),n}();function o(e){var a=n.exec(e);if(a){var i=a[1],o=a[2],s=void 0===o?"0":o,c=a[3],l=void 0===c?"0":c,u=a[4],d=void 0===u?"":u,p=a[5],f=void 0===p?"":p;if((!d||t.test(d))&&(!f||r.test(f)))return{major:parseInt(i,10),minor:parseInt(s,10),patch:parseInt(l,10),prerelease:d,build:f}}}function s(n,t){if(n===t)return 0;if(0===n.length)return 0===t.length?0:1;if(0===t.length)return-1;for(var r=Math.min(n.length,t.length),i=0;i<r;i++){var o=n[i],s=t[i];if(o!==s){var c=a.test(o),l=a.test(s);if(c||l){if(c!==l)return c?-1:1;var u=e.compareValues(+o,+s);if(u)return u}else{u=e.compareStringsCaseSensitive(o,s);if(u)return u}}}return e.compareValues(n.length,t.length)}e.Version=i;var c=function(){function n(n){this._alternatives=n?e.Debug.checkDefined(m(n),"Invalid range spec."):e.emptyArray}return n.tryParse=function(e){var t=m(e);if(t){var r=new n("");return r._alternatives=t,r}},n.prototype.test=function(e){return"string"===typeof e&&(e=new i(e)),b(e,this._alternatives)},n.prototype.toString=function(){return S(this._alternatives)},n}();e.VersionRange=c;var l=/\s*\|\|\s*/g,u=/\s+/g,d=/^([xX*0]|[1-9]\d*)(?:\.([xX*0]|[1-9]\d*)(?:\.([xX*0]|[1-9]\d*)(?:-([a-z0-9-.]+))?(?:\+([a-z0-9-.]+))?)?)?$/i,p=/^\s*([a-z0-9-+.*]+)\s+-\s+([a-z0-9-+.*]+)\s*$/i,f=/^\s*(~|\^|<|<=|>|>=|=)?\s*([a-z0-9-+.*]+)$/i;function m(e){for(var n=[],t=0,r=e.trim().split(l);t<r.length;t++){var a=r[t];if(a){var i=[],o=p.exec(a);if(o){if(!g(o[1],o[2],i))return}else for(var s=0,c=a.split(u);s<c.length;s++){var d=c[s],m=f.exec(d);if(!m||!y(m[1],m[2],i))return}n.push(i)}}return n}function _(e){var n=d.exec(e);if(n){var t=n[1],r=n[2],a=void 0===r?"*":r,o=n[3],s=void 0===o?"*":o,c=n[4],l=n[5],u=new i(h(t)?0:parseInt(t,10),h(t)||h(a)?0:parseInt(a,10),h(t)||h(a)||h(s)?0:parseInt(s,10),c,l);return{version:u,major:t,minor:a,patch:s}}}function g(e,n,t){var r=_(e);if(!r)return!1;var a=_(n);return!!a&&(h(r.major)||t.push(v(">=",r.version)),h(a.major)||t.push(h(a.minor)?v("<",a.version.increment("major")):h(a.patch)?v("<",a.version.increment("minor")):v("<=",a.version)),!0)}function y(e,n,t){var r=_(n);if(!r)return!1;var a=r.version,o=r.major,s=r.minor,c=r.patch;if(h(o))"<"!==e&&">"!==e||t.push(v("<",i.zero));else switch(e){case"~":t.push(v(">=",a)),t.push(v("<",a.increment(h(s)?"major":"minor")));break;case"^":t.push(v(">=",a)),t.push(v("<",a.increment(a.major>0||h(s)?"major":a.minor>0||h(c)?"minor":"patch")));break;case"<":case">=":t.push(v(e,a));break;case"<=":case">":t.push(h(s)?v("<="===e?"<":">=",a.increment("major")):h(c)?v("<="===e?"<":">=",a.increment("minor")):v(e,a));break;case"=":case void 0:h(s)||h(c)?(t.push(v(">=",a)),t.push(v("<",a.increment(h(s)?"major":"minor")))):t.push(v("=",a));break;default:return!1}return!0}function h(e){return"*"===e||"x"===e||"X"===e}function v(e,n){return{operator:e,operand:n}}function b(e,n){if(0===n.length)return!0;for(var t=0,r=n;t<r.length;t++){var a=r[t];if(E(e,a))return!0}return!1}function E(e,n){for(var t=0,r=n;t<r.length;t++){var a=r[t];if(!T(e,a.operator,a.operand))return!1}return!0}function T(n,t,r){var a=n.compareTo(r);switch(t){case"<":return a<0;case"<=":return a<=0;case">":return a>0;case">=":return a>=0;case"=":return 0===a;default:return e.Debug.assertNever(t)}}function S(n){return e.map(n,x).join(" || ")||"*"}function x(n){return e.map(n,L).join(" ")}function L(e){return""+e.operator+e.operand}}(d||(d={})),function(n){function t(e,n){return"object"===typeof e&&"number"===typeof e.timeOrigin&&"function"===typeof e.mark&&"function"===typeof e.measure&&"function"===typeof e.now&&"function"===typeof n}function r(){if("object"===typeof performance&&"function"===typeof PerformanceObserver&&t(performance,PerformanceObserver))return{shouldWriteNativeEvents:!0,performance:performance,PerformanceObserver:PerformanceObserver}}function i(){if("undefined"!==typeof e&&e.nextTick&&!e.browser&&"object"===typeof a)try{var r,i={},o=i.performance,s=i.PerformanceObserver;if(t(o,s)){r=o;var c=new n.Version(e.versions.node),l=new n.VersionRange("<12.16.3 || 13 <13.13");return l.test(c)&&(r={get timeOrigin(){return o.timeOrigin},now:function(){return o.now()},mark:function(e){return o.mark(e)},measure:function(e,n,t){void 0===n&&(n="nodeStart"),void 0===t&&(t="__performance.measure-fix__",o.mark(t)),o.measure(e,n,t),"__performance.measure-fix__"===t&&o.clearMarks("__performance.measure-fix__")}}),{shouldWriteNativeEvents:!1,performance:r,PerformanceObserver:s}}}catch(u){}}var o=r()||i(),s=null===o||void 0===o?void 0:o.performance;function c(){return o}n.tryGetNativePerformanceHooks=c,n.timestamp=s?function(){return s.now()}:Date.now?Date.now:function(){return+new Date}}(d||(d={})),function(e){(function(n){var t,r;function a(e,t,r,a){return e?i(t,r,a):n.nullTimer}function i(n,t,r){var a=0;return{enter:i,exit:o};function i(){1===++a&&d(t)}function o(){0===--a?(d(r),p(n,t,r)):a<0&&e.Debug.fail("enter/exit count does not match.")}}n.createTimerIf=a,n.createTimer=i,n.nullTimer={enter:e.noop,exit:e.noop};var o=!1,s=e.timestamp(),c=new e.Map,l=new e.Map,u=new e.Map;function d(n){var t;if(o){var a=null!==(t=l.get(n))&&void 0!==t?t:0;l.set(n,a+1),c.set(n,e.timestamp()),null===r||void 0===r||r.mark(n)}}function p(n,t,a){var i,l;if(o){var d=null!==(i=void 0!==a?c.get(a):void 0)&&void 0!==i?i:e.timestamp(),p=null!==(l=void 0!==t?c.get(t):void 0)&&void 0!==l?l:s,f=u.get(n)||0;u.set(n,f+(d-p)),null===r||void 0===r||r.measure(n,t,a)}}function f(e){return l.get(e)||0}function m(e){return u.get(e)||0}function _(e){u.forEach((function(n,t){return e(t,n)}))}function g(){return o}function y(n){var a;return void 0===n&&(n=e.sys),o||(o=!0,t||(t=e.tryGetNativePerformanceHooks()),t&&(s=t.performance.timeOrigin,(t.shouldWriteNativeEvents||(null===(a=null===n||void 0===n?void 0:n.cpuProfilingEnabled)||void 0===a?void 0:a.call(n))||(null===n||void 0===n?void 0:n.debugMode))&&(r=t.performance))),!0}function h(){o&&(c.clear(),l.clear(),u.clear(),r=void 0,o=!1)}n.mark=d,n.measure=p,n.getCount=f,n.getDuration=m,n.forEachMeasure=_,n.isEnabled=g,n.enable=y,n.disable=h})(e.performance||(e.performance={}))}(d||(d={})),function(e){var n,t,r={logEvent:e.noop,logErrEvent:e.noop,logPerfEvent:e.noop,logInfoEvent:e.noop,logStartCommand:e.noop,logStopCommand:e.noop,logStartUpdateProgram:e.noop,logStopUpdateProgram:e.noop,logStartUpdateGraph:e.noop,logStopUpdateGraph:e.noop,logStartResolveModule:e.noop,logStopResolveModule:e.noop,logStartParseSourceFile:e.noop,logStopParseSourceFile:e.noop,logStartReadFile:e.noop,logStopReadFile:e.noop,logStartBindFile:e.noop,logStopBindFile:e.noop,logStartScheduledOperation:e.noop,logStopScheduledOperation:e.noop};try{n=Object({NODE_ENV:"production",BASE_URL:"dist/"}).TS_ETW_MODULE_PATH;t=void 0}catch(a){t=void 0}e.perfLogger=t&&t.logEvent?t:r}(d||(d={})),function(n){var t;(function(t){var r,a,i,s=0,c=0,l=[],u=[];function d(d,p,f){if(n.Debug.assert(!n.tracing,"Tracing already started"),void 0===r)try{r=void 0}catch(h){throw new Error("tracing requires having fs\n(original error: "+(h.message||h)+")")}a=d,l.length=0,void 0===i&&(i=n.combinePaths(p,"legend.json")),r.existsSync(p)||r.mkdirSync(p,{recursive:!0});var m="build"===a?"."+e.pid+"-"+ ++s:"server"===a?"."+e.pid:"",_=n.combinePaths(p,"trace"+m+".json"),g=n.combinePaths(p,"types"+m+".json");u.push({configFilePath:f,tracePath:_,typesPath:g}),c=r.openSync(_,"w"),n.tracing=t;var y={cat:"__metadata",ph:"M",ts:1e3*n.timestamp(),pid:1,tid:1};r.writeSync(c,"[\n"+[o({name:"process_name",args:{name:"tsc"}},y),o({name:"thread_name",args:{name:"Main"}},y),o(o({name:"TracingStartedInBrowser"},y),{cat:"disabled-by-default-devtools.timeline"})].map((function(e){return JSON.stringify(e)})).join(",\n"))}function p(){n.Debug.assert(n.tracing,"Tracing is not in progress"),n.Debug.assert(!!l.length===("server"!==a)),r.writeSync(c,"\n]\n"),r.closeSync(c),n.tracing=void 0,l.length?S(l):u[u.length-1].typesPath=void 0}function f(e){"server"!==a&&l.push(e)}function m(e,n,t){E("I",e,n,t,'"s":"g"')}t.startTracing=d,t.stopTracing=p,t.recordType=f,function(e){e["Parse"]="parse",e["Program"]="program",e["Bind"]="bind",e["Check"]="check",e["CheckTypes"]="checkTypes",e["Emit"]="emit",e["Session"]="session"}(t.Phase||(t.Phase={})),t.instant=m;var _=[];function g(e,t,r,a){void 0===a&&(a=!1),a&&E("B",e,t,r),_.push({phase:e,name:t,args:r,time:1e3*n.timestamp(),separateBeginAndEnd:a})}function y(){n.Debug.assert(_.length>0),b(_.length-1,1e3*n.timestamp()),_.length--}function h(){for(var e=1e3*n.timestamp(),t=_.length-1;t>=0;t--)b(t,e);_.length=0}t.push=g,t.pop=y,t.popAll=h;var v=1e4;function b(e,n){var t=_[e],r=t.phase,a=t.name,i=t.args,o=t.time,s=t.separateBeginAndEnd;s?E("E",r,a,i,void 0,n):v-o%v<=n-o&&E("X",r,a,i,'"dur":'+(n-o),o)}function E(e,t,i,o,s,l){void 0===l&&(l=1e3*n.timestamp()),"server"===a&&"checkTypes"===t||(n.performance.mark("beginTracing"),r.writeSync(c,',\n{"pid":1,"tid":1,"ph":"'+e+'","cat":"'+t+'","ts":'+l+',"name":"'+i+'"'),s&&r.writeSync(c,","+s),o&&r.writeSync(c,',"args":'+JSON.stringify(o)),r.writeSync(c,"}"),n.performance.mark("endTracing"),n.performance.measure("Tracing","beginTracing","endTracing"))}function T(e){var t=n.getSourceFileOfNode(e);return t?{path:t.path,start:r(n.getLineAndCharacterOfPosition(t,e.pos)),end:r(n.getLineAndCharacterOfPosition(t,e.end))}:void 0;function r(e){return{line:e.line+1,character:e.character+1}}}function S(e){var t,a,i,s,c,l,d,p,f,m,_,g,y,h,v,b,E,S,x,L,D,A;n.performance.mark("beginDumpTypes");var C=u[u.length-1].typesPath,I=r.openSync(C,"w"),N=new n.Map;r.writeSync(I,"[");for(var k=e.length,R=0;R<k;R++){var O=e[R],w=O.objectFlags,P=null!==(t=O.aliasSymbol)&&void 0!==t?t:O.symbol,M=void 0;if(16&w|2944&O.flags)try{M=null===(a=O.checker)||void 0===a?void 0:a.typeToString(O)}catch(Z){M=void 0}var F={};if(8388608&O.flags){var G=O;F={indexedAccessObjectType:null===(i=G.objectType)||void 0===i?void 0:i.id,indexedAccessIndexType:null===(s=G.indexType)||void 0===s?void 0:s.id}}var B={};if(4&w){var U=O;B={instantiatedType:null===(c=U.target)||void 0===c?void 0:c.id,typeArguments:null===(l=U.resolvedTypeArguments)||void 0===l?void 0:l.map((function(e){return e.id})),referenceLocation:T(U.node)}}var V={};if(16777216&O.flags){var j=O;V={conditionalCheckType:null===(d=j.checkType)||void 0===d?void 0:d.id,conditionalExtendsType:null===(p=j.extendsType)||void 0===p?void 0:p.id,conditionalTrueType:null!==(m=null===(f=j.resolvedTrueType)||void 0===f?void 0:f.id)&&void 0!==m?m:-1,conditionalFalseType:null!==(g=null===(_=j.resolvedFalseType)||void 0===_?void 0:_.id)&&void 0!==g?g:-1}}var K={};if(33554432&O.flags){var H=O;K={substitutionBaseType:null===(y=H.baseType)||void 0===y?void 0:y.id,substituteType:null===(h=H.substitute)||void 0===h?void 0:h.id}}var W={};if(1024&w){var z=O;W={reverseMappedSourceType:null===(v=z.source)||void 0===v?void 0:v.id,reverseMappedMappedType:null===(b=z.mappedType)||void 0===b?void 0:b.id,reverseMappedConstraintType:null===(E=z.constraintType)||void 0===E?void 0:E.id}}var q={};if(256&w){var J=O;q={evolvingArrayElementType:J.elementType.id,evolvingArrayFinalType:null===(S=J.finalArrayType)||void 0===S?void 0:S.id}}var X=void 0,Y=O.checker.getRecursionIdentity(O);Y&&(X=N.get(Y),X||(X=N.size,N.set(Y,X)));var Q=o(o(o(o(o(o(o({id:O.id,intrinsicName:O.intrinsicName,symbolName:(null===P||void 0===P?void 0:P.escapedName)&&n.unescapeLeadingUnderscores(P.escapedName),recursionId:X,isTuple:!!(8&w)||void 0,unionTypes:1048576&O.flags?null===(x=O.types)||void 0===x?void 0:x.map((function(e){return e.id})):void 0,intersectionTypes:2097152&O.flags?O.types.map((function(e){return e.id})):void 0,aliasTypeArguments:null===(L=O.aliasTypeArguments)||void 0===L?void 0:L.map((function(e){return e.id})),keyofType:4194304&O.flags?null===(D=O.type)||void 0===D?void 0:D.id:void 0},F),B),V),K),W),q),{destructuringPattern:T(O.pattern),firstDeclaration:T(null===(A=null===P||void 0===P?void 0:P.declarations)||void 0===A?void 0:A[0]),flags:n.Debug.formatTypeFlags(O.flags).split("|"),display:M});r.writeSync(I,JSON.stringify(Q)),R<k-1&&r.writeSync(I,",\n")}r.writeSync(I,"]\n"),r.closeSync(I),n.performance.mark("endDumpTypes"),n.performance.measure("Dump types","beginDumpTypes","endDumpTypes")}function x(){i&&r.writeFileSync(i,JSON.stringify(u))}t.dumpLegend=x})(t||(t={})),n.startTracing=t.startTracing,n.dumpTracingLegend=t.dumpLegend}(d||(d={})),function(e){(function(e){e[e["Unknown"]=0]="Unknown",e[e["EndOfFileToken"]=1]="EndOfFileToken",e[e["SingleLineCommentTrivia"]=2]="SingleLineCommentTrivia",e[e["MultiLineCommentTrivia"]=3]="MultiLineCommentTrivia",e[e["NewLineTrivia"]=4]="NewLineTrivia",e[e["WhitespaceTrivia"]=5]="WhitespaceTrivia",e[e["ShebangTrivia"]=6]="ShebangTrivia",e[e["ConflictMarkerTrivia"]=7]="ConflictMarkerTrivia",e[e["NumericLiteral"]=8]="NumericLiteral",e[e["BigIntLiteral"]=9]="BigIntLiteral",e[e["StringLiteral"]=10]="StringLiteral",e[e["JsxText"]=11]="JsxText",e[e["JsxTextAllWhiteSpaces"]=12]="JsxTextAllWhiteSpaces",e[e["RegularExpressionLiteral"]=13]="RegularExpressionLiteral",e[e["NoSubstitutionTemplateLiteral"]=14]="NoSubstitutionTemplateLiteral",e[e["TemplateHead"]=15]="TemplateHead",e[e["TemplateMiddle"]=16]="TemplateMiddle",e[e["TemplateTail"]=17]="TemplateTail",e[e["OpenBraceToken"]=18]="OpenBraceToken",e[e["CloseBraceToken"]=19]="CloseBraceToken",e[e["OpenParenToken"]=20]="OpenParenToken",e[e["CloseParenToken"]=21]="CloseParenToken",e[e["OpenBracketToken"]=22]="OpenBracketToken",e[e["CloseBracketToken"]=23]="CloseBracketToken",e[e["DotToken"]=24]="DotToken",e[e["DotDotDotToken"]=25]="DotDotDotToken",e[e["SemicolonToken"]=26]="SemicolonToken",e[e["CommaToken"]=27]="CommaToken",e[e["QuestionDotToken"]=28]="QuestionDotToken",e[e["LessThanToken"]=29]="LessThanToken",e[e["LessThanSlashToken"]=30]="LessThanSlashToken",e[e["GreaterThanToken"]=31]="GreaterThanToken",e[e["LessThanEqualsToken"]=32]="LessThanEqualsToken",e[e["GreaterThanEqualsToken"]=33]="GreaterThanEqualsToken",e[e["EqualsEqualsToken"]=34]="EqualsEqualsToken",e[e["ExclamationEqualsToken"]=35]="ExclamationEqualsToken",e[e["EqualsEqualsEqualsToken"]=36]="EqualsEqualsEqualsToken",e[e["ExclamationEqualsEqualsToken"]=37]="ExclamationEqualsEqualsToken",e[e["EqualsGreaterThanToken"]=38]="EqualsGreaterThanToken",e[e["PlusToken"]=39]="PlusToken",e[e["MinusToken"]=40]="MinusToken",e[e["AsteriskToken"]=41]="AsteriskToken",e[e["AsteriskAsteriskToken"]=42]="AsteriskAsteriskToken",e[e["SlashToken"]=43]="SlashToken",e[e["PercentToken"]=44]="PercentToken",e[e["PlusPlusToken"]=45]="PlusPlusToken",e[e["MinusMinusToken"]=46]="MinusMinusToken",e[e["LessThanLessThanToken"]=47]="LessThanLessThanToken",e[e["GreaterThanGreaterThanToken"]=48]="GreaterThanGreaterThanToken",e[e["GreaterThanGreaterThanGreaterThanToken"]=49]="GreaterThanGreaterThanGreaterThanToken",e[e["AmpersandToken"]=50]="AmpersandToken",e[e["BarToken"]=51]="BarToken",e[e["CaretToken"]=52]="CaretToken",e[e["ExclamationToken"]=53]="ExclamationToken",e[e["TildeToken"]=54]="TildeToken",e[e["AmpersandAmpersandToken"]=55]="AmpersandAmpersandToken",e[e["BarBarToken"]=56]="BarBarToken",e[e["QuestionToken"]=57]="QuestionToken",e[e["ColonToken"]=58]="ColonToken",e[e["AtToken"]=59]="AtToken",e[e["QuestionQuestionToken"]=60]="QuestionQuestionToken",e[e["BacktickToken"]=61]="BacktickToken",e[e["EqualsToken"]=62]="EqualsToken",e[e["PlusEqualsToken"]=63]="PlusEqualsToken",e[e["MinusEqualsToken"]=64]="MinusEqualsToken",e[e["AsteriskEqualsToken"]=65]="AsteriskEqualsToken",e[e["AsteriskAsteriskEqualsToken"]=66]="AsteriskAsteriskEqualsToken",e[e["SlashEqualsToken"]=67]="SlashEqualsToken",e[e["PercentEqualsToken"]=68]="PercentEqualsToken",e[e["LessThanLessThanEqualsToken"]=69]="LessThanLessThanEqualsToken",e[e["GreaterThanGreaterThanEqualsToken"]=70]="GreaterThanGreaterThanEqualsToken",e[e["GreaterThanGreaterThanGreaterThanEqualsToken"]=71]="GreaterThanGreaterThanGreaterThanEqualsToken",e[e["AmpersandEqualsToken"]=72]="AmpersandEqualsToken",e[e["BarEqualsToken"]=73]="BarEqualsToken",e[e["BarBarEqualsToken"]=74]="BarBarEqualsToken",e[e["AmpersandAmpersandEqualsToken"]=75]="AmpersandAmpersandEqualsToken",e[e["QuestionQuestionEqualsToken"]=76]="QuestionQuestionEqualsToken",e[e["CaretEqualsToken"]=77]="CaretEqualsToken",e[e["Identifier"]=78]="Identifier",e[e["PrivateIdentifier"]=79]="PrivateIdentifier",e[e["BreakKeyword"]=80]="BreakKeyword",e[e["CaseKeyword"]=81]="CaseKeyword",e[e["CatchKeyword"]=82]="CatchKeyword",e[e["ClassKeyword"]=83]="ClassKeyword",e[e["ConstKeyword"]=84]="ConstKeyword",e[e["ContinueKeyword"]=85]="ContinueKeyword",e[e["DebuggerKeyword"]=86]="DebuggerKeyword",e[e["DefaultKeyword"]=87]="DefaultKeyword",e[e["DeleteKeyword"]=88]="DeleteKeyword",e[e["DoKeyword"]=89]="DoKeyword",e[e["ElseKeyword"]=90]="ElseKeyword",e[e["EnumKeyword"]=91]="EnumKeyword",e[e["ExportKeyword"]=92]="ExportKeyword",e[e["ExtendsKeyword"]=93]="ExtendsKeyword",e[e["FalseKeyword"]=94]="FalseKeyword",e[e["FinallyKeyword"]=95]="FinallyKeyword",e[e["ForKeyword"]=96]="ForKeyword",e[e["FunctionKeyword"]=97]="FunctionKeyword",e[e["IfKeyword"]=98]="IfKeyword",e[e["ImportKeyword"]=99]="ImportKeyword",e[e["InKeyword"]=100]="InKeyword",e[e["InstanceOfKeyword"]=101]="InstanceOfKeyword",e[e["NewKeyword"]=102]="NewKeyword",e[e["NullKeyword"]=103]="NullKeyword",e[e["ReturnKeyword"]=104]="ReturnKeyword",e[e["SuperKeyword"]=105]="SuperKeyword",e[e["SwitchKeyword"]=106]="SwitchKeyword",e[e["ThisKeyword"]=107]="ThisKeyword",e[e["ThrowKeyword"]=108]="ThrowKeyword",e[e["TrueKeyword"]=109]="TrueKeyword",e[e["TryKeyword"]=110]="TryKeyword",e[e["TypeOfKeyword"]=111]="TypeOfKeyword",e[e["VarKeyword"]=112]="VarKeyword",e[e["VoidKeyword"]=113]="VoidKeyword",e[e["WhileKeyword"]=114]="WhileKeyword",e[e["WithKeyword"]=115]="WithKeyword",e[e["ImplementsKeyword"]=116]="ImplementsKeyword",e[e["InterfaceKeyword"]=117]="InterfaceKeyword",e[e["LetKeyword"]=118]="LetKeyword",e[e["PackageKeyword"]=119]="PackageKeyword",e[e["PrivateKeyword"]=120]="PrivateKeyword",e[e["ProtectedKeyword"]=121]="ProtectedKeyword",e[e["PublicKeyword"]=122]="PublicKeyword",e[e["StaticKeyword"]=123]="StaticKeyword",e[e["YieldKeyword"]=124]="YieldKeyword",e[e["AbstractKeyword"]=125]="AbstractKeyword",e[e["AsKeyword"]=126]="AsKeyword",e[e["AssertsKeyword"]=127]="AssertsKeyword",e[e["AnyKeyword"]=128]="AnyKeyword",e[e["AsyncKeyword"]=129]="AsyncKeyword",e[e["AwaitKeyword"]=130]="AwaitKeyword",e[e["BooleanKeyword"]=131]="BooleanKeyword",e[e["ConstructorKeyword"]=132]="ConstructorKeyword",e[e["DeclareKeyword"]=133]="DeclareKeyword",e[e["GetKeyword"]=134]="GetKeyword",e[e["InferKeyword"]=135]="InferKeyword",e[e["IntrinsicKeyword"]=136]="IntrinsicKeyword",e[e["IsKeyword"]=137]="IsKeyword",e[e["KeyOfKeyword"]=138]="KeyOfKeyword",e[e["ModuleKeyword"]=139]="ModuleKeyword",e[e["NamespaceKeyword"]=140]="NamespaceKeyword",e[e["NeverKeyword"]=141]="NeverKeyword",e[e["ReadonlyKeyword"]=142]="ReadonlyKeyword",e[e["RequireKeyword"]=143]="RequireKeyword",e[e["NumberKeyword"]=144]="NumberKeyword",e[e["ObjectKeyword"]=145]="ObjectKeyword",e[e["SetKeyword"]=146]="SetKeyword",e[e["StringKeyword"]=147]="StringKeyword",e[e["SymbolKeyword"]=148]="SymbolKeyword",e[e["TypeKeyword"]=149]="TypeKeyword",e[e["UndefinedKeyword"]=150]="UndefinedKeyword",e[e["UniqueKeyword"]=151]="UniqueKeyword",e[e["UnknownKeyword"]=152]="UnknownKeyword",e[e["FromKeyword"]=153]="FromKeyword",e[e["GlobalKeyword"]=154]="GlobalKeyword",e[e["BigIntKeyword"]=155]="BigIntKeyword",e[e["OverrideKeyword"]=156]="OverrideKeyword",e[e["OfKeyword"]=157]="OfKeyword",e[e["QualifiedName"]=158]="QualifiedName",e[e["ComputedPropertyName"]=159]="ComputedPropertyName",e[e["TypeParameter"]=160]="TypeParameter",e[e["Parameter"]=161]="Parameter",e[e["Decorator"]=162]="Decorator",e[e["PropertySignature"]=163]="PropertySignature",e[e["PropertyDeclaration"]=164]="PropertyDeclaration",e[e["MethodSignature"]=165]="MethodSignature",e[e["MethodDeclaration"]=166]="MethodDeclaration",e[e["Constructor"]=167]="Constructor",e[e["GetAccessor"]=168]="GetAccessor",e[e["SetAccessor"]=169]="SetAccessor",e[e["CallSignature"]=170]="CallSignature",e[e["ConstructSignature"]=171]="ConstructSignature",e[e["IndexSignature"]=172]="IndexSignature",e[e["TypePredicate"]=173]="TypePredicate",e[e["TypeReference"]=174]="TypeReference",e[e["FunctionType"]=175]="FunctionType",e[e["ConstructorType"]=176]="ConstructorType",e[e["TypeQuery"]=177]="TypeQuery",e[e["TypeLiteral"]=178]="TypeLiteral",e[e["ArrayType"]=179]="ArrayType",e[e["TupleType"]=180]="TupleType",e[e["OptionalType"]=181]="OptionalType",e[e["RestType"]=182]="RestType",e[e["UnionType"]=183]="UnionType",e[e["IntersectionType"]=184]="IntersectionType",e[e["ConditionalType"]=185]="ConditionalType",e[e["InferType"]=186]="InferType",e[e["ParenthesizedType"]=187]="ParenthesizedType",e[e["ThisType"]=188]="ThisType",e[e["TypeOperator"]=189]="TypeOperator",e[e["IndexedAccessType"]=190]="IndexedAccessType",e[e["MappedType"]=191]="MappedType",e[e["LiteralType"]=192]="LiteralType",e[e["NamedTupleMember"]=193]="NamedTupleMember",e[e["TemplateLiteralType"]=194]="TemplateLiteralType",e[e["TemplateLiteralTypeSpan"]=195]="TemplateLiteralTypeSpan",e[e["ImportType"]=196]="ImportType",e[e["ObjectBindingPattern"]=197]="ObjectBindingPattern",e[e["ArrayBindingPattern"]=198]="ArrayBindingPattern",e[e["BindingElement"]=199]="BindingElement",e[e["ArrayLiteralExpression"]=200]="ArrayLiteralExpression",e[e["ObjectLiteralExpression"]=201]="ObjectLiteralExpression",e[e["PropertyAccessExpression"]=202]="PropertyAccessExpression",e[e["ElementAccessExpression"]=203]="ElementAccessExpression",e[e["CallExpression"]=204]="CallExpression",e[e["NewExpression"]=205]="NewExpression",e[e["TaggedTemplateExpression"]=206]="TaggedTemplateExpression",e[e["TypeAssertionExpression"]=207]="TypeAssertionExpression",e[e["ParenthesizedExpression"]=208]="ParenthesizedExpression",e[e["FunctionExpression"]=209]="FunctionExpression",e[e["ArrowFunction"]=210]="ArrowFunction",e[e["DeleteExpression"]=211]="DeleteExpression",e[e["TypeOfExpression"]=212]="TypeOfExpression",e[e["VoidExpression"]=213]="VoidExpression",e[e["AwaitExpression"]=214]="AwaitExpression",e[e["PrefixUnaryExpression"]=215]="PrefixUnaryExpression",e[e["PostfixUnaryExpression"]=216]="PostfixUnaryExpression",e[e["BinaryExpression"]=217]="BinaryExpression",e[e["ConditionalExpression"]=218]="ConditionalExpression",e[e["TemplateExpression"]=219]="TemplateExpression",e[e["YieldExpression"]=220]="YieldExpression",e[e["SpreadElement"]=221]="SpreadElement",e[e["ClassExpression"]=222]="ClassExpression",e[e["OmittedExpression"]=223]="OmittedExpression",e[e["ExpressionWithTypeArguments"]=224]="ExpressionWithTypeArguments",e[e["AsExpression"]=225]="AsExpression",e[e["NonNullExpression"]=226]="NonNullExpression",e[e["MetaProperty"]=227]="MetaProperty",e[e["SyntheticExpression"]=228]="SyntheticExpression",e[e["TemplateSpan"]=229]="TemplateSpan",e[e["SemicolonClassElement"]=230]="SemicolonClassElement",e[e["Block"]=231]="Block",e[e["EmptyStatement"]=232]="EmptyStatement",e[e["VariableStatement"]=233]="VariableStatement",e[e["ExpressionStatement"]=234]="ExpressionStatement",e[e["IfStatement"]=235]="IfStatement",e[e["DoStatement"]=236]="DoStatement",e[e["WhileStatement"]=237]="WhileStatement",e[e["ForStatement"]=238]="ForStatement",e[e["ForInStatement"]=239]="ForInStatement",e[e["ForOfStatement"]=240]="ForOfStatement",e[e["ContinueStatement"]=241]="ContinueStatement",e[e["BreakStatement"]=242]="BreakStatement",e[e["ReturnStatement"]=243]="ReturnStatement",e[e["WithStatement"]=244]="WithStatement",e[e["SwitchStatement"]=245]="SwitchStatement",e[e["LabeledStatement"]=246]="LabeledStatement",e[e["ThrowStatement"]=247]="ThrowStatement",e[e["TryStatement"]=248]="TryStatement",e[e["DebuggerStatement"]=249]="DebuggerStatement",e[e["VariableDeclaration"]=250]="VariableDeclaration",e[e["VariableDeclarationList"]=251]="VariableDeclarationList",e[e["FunctionDeclaration"]=252]="FunctionDeclaration",e[e["ClassDeclaration"]=253]="ClassDeclaration",e[e["InterfaceDeclaration"]=254]="InterfaceDeclaration",e[e["TypeAliasDeclaration"]=255]="TypeAliasDeclaration",e[e["EnumDeclaration"]=256]="EnumDeclaration",e[e["ModuleDeclaration"]=257]="ModuleDeclaration",e[e["ModuleBlock"]=258]="ModuleBlock",e[e["CaseBlock"]=259]="CaseBlock",e[e["NamespaceExportDeclaration"]=260]="NamespaceExportDeclaration",e[e["ImportEqualsDeclaration"]=261]="ImportEqualsDeclaration",e[e["ImportDeclaration"]=262]="ImportDeclaration",e[e["ImportClause"]=263]="ImportClause",e[e["NamespaceImport"]=264]="NamespaceImport",e[e["NamedImports"]=265]="NamedImports",e[e["ImportSpecifier"]=266]="ImportSpecifier",e[e["ExportAssignment"]=267]="ExportAssignment",e[e["ExportDeclaration"]=268]="ExportDeclaration",e[e["NamedExports"]=269]="NamedExports",e[e["NamespaceExport"]=270]="NamespaceExport",e[e["ExportSpecifier"]=271]="ExportSpecifier",e[e["MissingDeclaration"]=272]="MissingDeclaration",e[e["ExternalModuleReference"]=273]="ExternalModuleReference",e[e["JsxElement"]=274]="JsxElement",e[e["JsxSelfClosingElement"]=275]="JsxSelfClosingElement",e[e["JsxOpeningElement"]=276]="JsxOpeningElement",e[e["JsxClosingElement"]=277]="JsxClosingElement",e[e["JsxFragment"]=278]="JsxFragment",e[e["JsxOpeningFragment"]=279]="JsxOpeningFragment",e[e["JsxClosingFragment"]=280]="JsxClosingFragment",e[e["JsxAttribute"]=281]="JsxAttribute",e[e["JsxAttributes"]=282]="JsxAttributes",e[e["JsxSpreadAttribute"]=283]="JsxSpreadAttribute",e[e["JsxExpression"]=284]="JsxExpression",e[e["CaseClause"]=285]="CaseClause",e[e["DefaultClause"]=286]="DefaultClause",e[e["HeritageClause"]=287]="HeritageClause",e[e["CatchClause"]=288]="CatchClause",e[e["PropertyAssignment"]=289]="PropertyAssignment",e[e["ShorthandPropertyAssignment"]=290]="ShorthandPropertyAssignment",e[e["SpreadAssignment"]=291]="SpreadAssignment",e[e["EnumMember"]=292]="EnumMember",e[e["UnparsedPrologue"]=293]="UnparsedPrologue",e[e["UnparsedPrepend"]=294]="UnparsedPrepend",e[e["UnparsedText"]=295]="UnparsedText",e[e["UnparsedInternalText"]=296]="UnparsedInternalText",e[e["UnparsedSyntheticReference"]=297]="UnparsedSyntheticReference",e[e["SourceFile"]=298]="SourceFile",e[e["Bundle"]=299]="Bundle",e[e["UnparsedSource"]=300]="UnparsedSource",e[e["InputFiles"]=301]="InputFiles",e[e["JSDocTypeExpression"]=302]="JSDocTypeExpression",e[e["JSDocNameReference"]=303]="JSDocNameReference",e[e["JSDocAllType"]=304]="JSDocAllType",e[e["JSDocUnknownType"]=305]="JSDocUnknownType",e[e["JSDocNullableType"]=306]="JSDocNullableType",e[e["JSDocNonNullableType"]=307]="JSDocNonNullableType",e[e["JSDocOptionalType"]=308]="JSDocOptionalType",e[e["JSDocFunctionType"]=309]="JSDocFunctionType",e[e["JSDocVariadicType"]=310]="JSDocVariadicType",e[e["JSDocNamepathType"]=311]="JSDocNamepathType",e[e["JSDocComment"]=312]="JSDocComment",e[e["JSDocText"]=313]="JSDocText",e[e["JSDocTypeLiteral"]=314]="JSDocTypeLiteral",e[e["JSDocSignature"]=315]="JSDocSignature",e[e["JSDocLink"]=316]="JSDocLink",e[e["JSDocTag"]=317]="JSDocTag",e[e["JSDocAugmentsTag"]=318]="JSDocAugmentsTag",e[e["JSDocImplementsTag"]=319]="JSDocImplementsTag",e[e["JSDocAuthorTag"]=320]="JSDocAuthorTag",e[e["JSDocDeprecatedTag"]=321]="JSDocDeprecatedTag",e[e["JSDocClassTag"]=322]="JSDocClassTag",e[e["JSDocPublicTag"]=323]="JSDocPublicTag",e[e["JSDocPrivateTag"]=324]="JSDocPrivateTag",e[e["JSDocProtectedTag"]=325]="JSDocProtectedTag",e[e["JSDocReadonlyTag"]=326]="JSDocReadonlyTag",e[e["JSDocOverrideTag"]=327]="JSDocOverrideTag",e[e["JSDocCallbackTag"]=328]="JSDocCallbackTag",e[e["JSDocEnumTag"]=329]="JSDocEnumTag",e[e["JSDocParameterTag"]=330]="JSDocParameterTag",e[e["JSDocReturnTag"]=331]="JSDocReturnTag",e[e["JSDocThisTag"]=332]="JSDocThisTag",e[e["JSDocTypeTag"]=333]="JSDocTypeTag",e[e["JSDocTemplateTag"]=334]="JSDocTemplateTag",e[e["JSDocTypedefTag"]=335]="JSDocTypedefTag",e[e["JSDocSeeTag"]=336]="JSDocSeeTag",e[e["JSDocPropertyTag"]=337]="JSDocPropertyTag",e[e["SyntaxList"]=338]="SyntaxList",e[e["NotEmittedStatement"]=339]="NotEmittedStatement",e[e["PartiallyEmittedExpression"]=340]="PartiallyEmittedExpression",e[e["CommaListExpression"]=341]="CommaListExpression",e[e["MergeDeclarationMarker"]=342]="MergeDeclarationMarker",e[e["EndOfDeclarationMarker"]=343]="EndOfDeclarationMarker",e[e["SyntheticReferenceExpression"]=344]="SyntheticReferenceExpression",e[e["Count"]=345]="Count",e[e["FirstAssignment"]=62]="FirstAssignment",e[e["LastAssignment"]=77]="LastAssignment",e[e["FirstCompoundAssignment"]=63]="FirstCompoundAssignment",e[e["LastCompoundAssignment"]=77]="LastCompoundAssignment",e[e["FirstReservedWord"]=80]="FirstReservedWord",e[e["LastReservedWord"]=115]="LastReservedWord",e[e["FirstKeyword"]=80]="FirstKeyword",e[e["LastKeyword"]=157]="LastKeyword",e[e["FirstFutureReservedWord"]=116]="FirstFutureReservedWord",e[e["LastFutureReservedWord"]=124]="LastFutureReservedWord",e[e["FirstTypeNode"]=173]="FirstTypeNode",e[e["LastTypeNode"]=196]="LastTypeNode",e[e["FirstPunctuation"]=18]="FirstPunctuation",e[e["LastPunctuation"]=77]="LastPunctuation",e[e["FirstToken"]=0]="FirstToken",e[e["LastToken"]=157]="LastToken",e[e["FirstTriviaToken"]=2]="FirstTriviaToken",e[e["LastTriviaToken"]=7]="LastTriviaToken",e[e["FirstLiteralToken"]=8]="FirstLiteralToken",e[e["LastLiteralToken"]=14]="LastLiteralToken",e[e["FirstTemplateToken"]=14]="FirstTemplateToken",e[e["LastTemplateToken"]=17]="LastTemplateToken",e[e["FirstBinaryOperator"]=29]="FirstBinaryOperator",e[e["LastBinaryOperator"]=77]="LastBinaryOperator",e[e["FirstStatement"]=233]="FirstStatement",e[e["LastStatement"]=249]="LastStatement",e[e["FirstNode"]=158]="FirstNode",e[e["FirstJSDocNode"]=302]="FirstJSDocNode",e[e["LastJSDocNode"]=337]="LastJSDocNode",e[e["FirstJSDocTagNode"]=317]="FirstJSDocTagNode",e[e["LastJSDocTagNode"]=337]="LastJSDocTagNode",e[e["FirstContextualKeyword"]=125]="FirstContextualKeyword",e[e["LastContextualKeyword"]=157]="LastContextualKeyword"})(e.SyntaxKind||(e.SyntaxKind={})),function(e){e[e["None"]=0]="None",e[e["Let"]=1]="Let",e[e["Const"]=2]="Const",e[e["NestedNamespace"]=4]="NestedNamespace",e[e["Synthesized"]=8]="Synthesized",e[e["Namespace"]=16]="Namespace",e[e["OptionalChain"]=32]="OptionalChain",e[e["ExportContext"]=64]="ExportContext",e[e["ContainsThis"]=128]="ContainsThis",e[e["HasImplicitReturn"]=256]="HasImplicitReturn",e[e["HasExplicitReturn"]=512]="HasExplicitReturn",e[e["GlobalAugmentation"]=1024]="GlobalAugmentation",e[e["HasAsyncFunctions"]=2048]="HasAsyncFunctions",e[e["DisallowInContext"]=4096]="DisallowInContext",e[e["YieldContext"]=8192]="YieldContext",e[e["DecoratorContext"]=16384]="DecoratorContext",e[e["AwaitContext"]=32768]="AwaitContext",e[e["ThisNodeHasError"]=65536]="ThisNodeHasError",e[e["JavaScriptFile"]=131072]="JavaScriptFile",e[e["ThisNodeOrAnySubNodesHasError"]=262144]="ThisNodeOrAnySubNodesHasError",e[e["HasAggregatedChildData"]=524288]="HasAggregatedChildData",e[e["PossiblyContainsDynamicImport"]=1048576]="PossiblyContainsDynamicImport",e[e["PossiblyContainsImportMeta"]=2097152]="PossiblyContainsImportMeta",e[e["JSDoc"]=4194304]="JSDoc",e[e["Ambient"]=8388608]="Ambient",e[e["InWithStatement"]=16777216]="InWithStatement",e[e["JsonFile"]=33554432]="JsonFile",e[e["TypeCached"]=67108864]="TypeCached",e[e["Deprecated"]=134217728]="Deprecated",e[e["BlockScoped"]=3]="BlockScoped",e[e["ReachabilityCheckFlags"]=768]="ReachabilityCheckFlags",e[e["ReachabilityAndEmitFlags"]=2816]="ReachabilityAndEmitFlags",e[e["ContextFlags"]=25358336]="ContextFlags",e[e["TypeExcludesFlags"]=40960]="TypeExcludesFlags",e[e["PermanentlySetIncrementalFlags"]=3145728]="PermanentlySetIncrementalFlags"}(e.NodeFlags||(e.NodeFlags={})),function(e){e[e["None"]=0]="None",e[e["Export"]=1]="Export",e[e["Ambient"]=2]="Ambient",e[e["Public"]=4]="Public",e[e["Private"]=8]="Private",e[e["Protected"]=16]="Protected",e[e["Static"]=32]="Static",e[e["Readonly"]=64]="Readonly",e[e["Abstract"]=128]="Abstract",e[e["Async"]=256]="Async",e[e["Default"]=512]="Default",e[e["Const"]=2048]="Const",e[e["HasComputedJSDocModifiers"]=4096]="HasComputedJSDocModifiers",e[e["Deprecated"]=8192]="Deprecated",e[e["Override"]=16384]="Override",e[e["HasComputedFlags"]=536870912]="HasComputedFlags",e[e["AccessibilityModifier"]=28]="AccessibilityModifier",e[e["ParameterPropertyModifier"]=16476]="ParameterPropertyModifier",e[e["NonPublicAccessibilityModifier"]=24]="NonPublicAccessibilityModifier",e[e["TypeScriptModifier"]=18654]="TypeScriptModifier",e[e["ExportDefault"]=513]="ExportDefault",e[e["All"]=27647]="All"}(e.ModifierFlags||(e.ModifierFlags={})),function(e){e[e["None"]=0]="None",e[e["IntrinsicNamedElement"]=1]="IntrinsicNamedElement",e[e["IntrinsicIndexedElement"]=2]="IntrinsicIndexedElement",e[e["IntrinsicElement"]=3]="IntrinsicElement"}(e.JsxFlags||(e.JsxFlags={})),function(e){e[e["Succeeded"]=1]="Succeeded",e[e["Failed"]=2]="Failed",e[e["Reported"]=4]="Reported",e[e["ReportsUnmeasurable"]=8]="ReportsUnmeasurable",e[e["ReportsUnreliable"]=16]="ReportsUnreliable",e[e["ReportsMask"]=24]="ReportsMask"}(e.RelationComparisonResult||(e.RelationComparisonResult={})),function(e){e[e["None"]=0]="None",e[e["Auto"]=1]="Auto",e[e["Loop"]=2]="Loop",e[e["Unique"]=3]="Unique",e[e["Node"]=4]="Node",e[e["KindMask"]=7]="KindMask",e[e["ReservedInNestedScopes"]=8]="ReservedInNestedScopes",e[e["Optimistic"]=16]="Optimistic",e[e["FileLevel"]=32]="FileLevel",e[e["AllowNameSubstitution"]=64]="AllowNameSubstitution"}(e.GeneratedIdentifierFlags||(e.GeneratedIdentifierFlags={})),function(e){e[e["None"]=0]="None",e[e["PrecedingLineBreak"]=1]="PrecedingLineBreak",e[e["PrecedingJSDocComment"]=2]="PrecedingJSDocComment",e[e["Unterminated"]=4]="Unterminated",e[e["ExtendedUnicodeEscape"]=8]="ExtendedUnicodeEscape",e[e["Scientific"]=16]="Scientific",e[e["Octal"]=32]="Octal",e[e["HexSpecifier"]=64]="HexSpecifier",e[e["BinarySpecifier"]=128]="BinarySpecifier",e[e["OctalSpecifier"]=256]="OctalSpecifier",e[e["ContainsSeparator"]=512]="ContainsSeparator",e[e["UnicodeEscape"]=1024]="UnicodeEscape",e[e["ContainsInvalidEscape"]=2048]="ContainsInvalidEscape",e[e["BinaryOrOctalSpecifier"]=384]="BinaryOrOctalSpecifier",e[e["NumericLiteralFlags"]=1008]="NumericLiteralFlags",e[e["TemplateLiteralLikeFlags"]=2048]="TemplateLiteralLikeFlags"}(e.TokenFlags||(e.TokenFlags={})),function(e){e[e["Unreachable"]=1]="Unreachable",e[e["Start"]=2]="Start",e[e["BranchLabel"]=4]="BranchLabel",e[e["LoopLabel"]=8]="LoopLabel",e[e["Assignment"]=16]="Assignment",e[e["TrueCondition"]=32]="TrueCondition",e[e["FalseCondition"]=64]="FalseCondition",e[e["SwitchClause"]=128]="SwitchClause",e[e["ArrayMutation"]=256]="ArrayMutation",e[e["Call"]=512]="Call",e[e["ReduceLabel"]=1024]="ReduceLabel",e[e["Referenced"]=2048]="Referenced",e[e["Shared"]=4096]="Shared",e[e["Label"]=12]="Label",e[e["Condition"]=96]="Condition"}(e.FlowFlags||(e.FlowFlags={})),function(e){e[e["ExpectError"]=0]="ExpectError",e[e["Ignore"]=1]="Ignore"}(e.CommentDirectiveType||(e.CommentDirectiveType={}));var n,t=function(){function e(){}return e}();function r(e,t){void 0===t&&(t=!0);var r=n[e.category];return t?r.toLowerCase():r}e.OperationCanceledException=t,function(e){e[e["RootFile"]=0]="RootFile",e[e["SourceFromProjectReference"]=1]="SourceFromProjectReference",e[e["OutputFromProjectReference"]=2]="OutputFromProjectReference",e[e["Import"]=3]="Import",e[e["ReferenceFile"]=4]="ReferenceFile",e[e["TypeReferenceDirective"]=5]="TypeReferenceDirective",e[e["LibFile"]=6]="LibFile",e[e["LibReferenceDirective"]=7]="LibReferenceDirective",e[e["AutomaticTypeDirectiveFile"]=8]="AutomaticTypeDirectiveFile"}(e.FileIncludeKind||(e.FileIncludeKind={})),function(e){e[e["FilePreprocessingReferencedDiagnostic"]=0]="FilePreprocessingReferencedDiagnostic",e[e["FilePreprocessingFileExplainingDiagnostic"]=1]="FilePreprocessingFileExplainingDiagnostic"}(e.FilePreprocessingDiagnosticsKind||(e.FilePreprocessingDiagnosticsKind={})),function(e){e[e["Not"]=0]="Not",e[e["SafeModules"]=1]="SafeModules",e[e["Completely"]=2]="Completely"}(e.StructureIsReused||(e.StructureIsReused={})),function(e){e[e["Success"]=0]="Success",e[e["DiagnosticsPresent_OutputsSkipped"]=1]="DiagnosticsPresent_OutputsSkipped",e[e["DiagnosticsPresent_OutputsGenerated"]=2]="DiagnosticsPresent_OutputsGenerated",e[e["InvalidProject_OutputsSkipped"]=3]="InvalidProject_OutputsSkipped",e[e["ProjectReferenceCycle_OutputsSkipped"]=4]="ProjectReferenceCycle_OutputsSkipped",e[e["ProjectReferenceCycle_OutputsSkupped"]=4]="ProjectReferenceCycle_OutputsSkupped"}(e.ExitStatus||(e.ExitStatus={})),function(e){e[e["None"]=0]="None",e[e["Literal"]=1]="Literal",e[e["Subtype"]=2]="Subtype"}(e.UnionReduction||(e.UnionReduction={})),function(e){e[e["None"]=0]="None",e[e["Signature"]=1]="Signature",e[e["NoConstraints"]=2]="NoConstraints",e[e["Completions"]=4]="Completions",e[e["SkipBindingPatterns"]=8]="SkipBindingPatterns"}(e.ContextFlags||(e.ContextFlags={})),function(e){e[e["None"]=0]="None",e[e["NoTruncation"]=1]="NoTruncation",e[e["WriteArrayAsGenericType"]=2]="WriteArrayAsGenericType",e[e["GenerateNamesForShadowedTypeParams"]=4]="GenerateNamesForShadowedTypeParams",e[e["UseStructuralFallback"]=8]="UseStructuralFallback",e[e["ForbidIndexedAccessSymbolReferences"]=16]="ForbidIndexedAccessSymbolReferences",e[e["WriteTypeArgumentsOfSignature"]=32]="WriteTypeArgumentsOfSignature",e[e["UseFullyQualifiedType"]=64]="UseFullyQualifiedType",e[e["UseOnlyExternalAliasing"]=128]="UseOnlyExternalAliasing",e[e["SuppressAnyReturnType"]=256]="SuppressAnyReturnType",e[e["WriteTypeParametersInQualifiedName"]=512]="WriteTypeParametersInQualifiedName",e[e["MultilineObjectLiterals"]=1024]="MultilineObjectLiterals",e[e["WriteClassExpressionAsTypeLiteral"]=2048]="WriteClassExpressionAsTypeLiteral",e[e["UseTypeOfFunction"]=4096]="UseTypeOfFunction",e[e["OmitParameterModifiers"]=8192]="OmitParameterModifiers",e[e["UseAliasDefinedOutsideCurrentScope"]=16384]="UseAliasDefinedOutsideCurrentScope",e[e["UseSingleQuotesForStringLiteralType"]=268435456]="UseSingleQuotesForStringLiteralType",e[e["NoTypeReduction"]=536870912]="NoTypeReduction",e[e["NoUndefinedOptionalParameterType"]=1073741824]="NoUndefinedOptionalParameterType",e[e["AllowThisInObjectLiteral"]=32768]="AllowThisInObjectLiteral",e[e["AllowQualifiedNameInPlaceOfIdentifier"]=65536]="AllowQualifiedNameInPlaceOfIdentifier",e[e["AllowQualifedNameInPlaceOfIdentifier"]=65536]="AllowQualifedNameInPlaceOfIdentifier",e[e["AllowAnonymousIdentifier"]=131072]="AllowAnonymousIdentifier",e[e["AllowEmptyUnionOrIntersection"]=262144]="AllowEmptyUnionOrIntersection",e[e["AllowEmptyTuple"]=524288]="AllowEmptyTuple",e[e["AllowUniqueESSymbolType"]=1048576]="AllowUniqueESSymbolType",e[e["AllowEmptyIndexInfoType"]=2097152]="AllowEmptyIndexInfoType",e[e["AllowNodeModulesRelativePaths"]=67108864]="AllowNodeModulesRelativePaths",e[e["DoNotIncludeSymbolChain"]=134217728]="DoNotIncludeSymbolChain",e[e["IgnoreErrors"]=70221824]="IgnoreErrors",e[e["InObjectTypeLiteral"]=4194304]="InObjectTypeLiteral",e[e["InTypeAlias"]=8388608]="InTypeAlias",e[e["InInitialEntityName"]=16777216]="InInitialEntityName"}(e.NodeBuilderFlags||(e.NodeBuilderFlags={})),function(e){e[e["None"]=0]="None",e[e["NoTruncation"]=1]="NoTruncation",e[e["WriteArrayAsGenericType"]=2]="WriteArrayAsGenericType",e[e["UseStructuralFallback"]=8]="UseStructuralFallback",e[e["WriteTypeArgumentsOfSignature"]=32]="WriteTypeArgumentsOfSignature",e[e["UseFullyQualifiedType"]=64]="UseFullyQualifiedType",e[e["SuppressAnyReturnType"]=256]="SuppressAnyReturnType",e[e["MultilineObjectLiterals"]=1024]="MultilineObjectLiterals",e[e["WriteClassExpressionAsTypeLiteral"]=2048]="WriteClassExpressionAsTypeLiteral",e[e["UseTypeOfFunction"]=4096]="UseTypeOfFunction",e[e["OmitParameterModifiers"]=8192]="OmitParameterModifiers",e[e["UseAliasDefinedOutsideCurrentScope"]=16384]="UseAliasDefinedOutsideCurrentScope",e[e["UseSingleQuotesForStringLiteralType"]=268435456]="UseSingleQuotesForStringLiteralType",e[e["NoTypeReduction"]=536870912]="NoTypeReduction",e[e["AllowUniqueESSymbolType"]=1048576]="AllowUniqueESSymbolType",e[e["AddUndefined"]=131072]="AddUndefined",e[e["WriteArrowStyleSignature"]=262144]="WriteArrowStyleSignature",e[e["InArrayType"]=524288]="InArrayType",e[e["InElementType"]=2097152]="InElementType",e[e["InFirstTypeArgument"]=4194304]="InFirstTypeArgument",e[e["InTypeAlias"]=8388608]="InTypeAlias",e[e["WriteOwnNameForAnyLike"]=0]="WriteOwnNameForAnyLike",e[e["NodeBuilderFlagsMask"]=814775659]="NodeBuilderFlagsMask"}(e.TypeFormatFlags||(e.TypeFormatFlags={})),function(e){e[e["None"]=0]="None",e[e["WriteTypeParametersOrArguments"]=1]="WriteTypeParametersOrArguments",e[e["UseOnlyExternalAliasing"]=2]="UseOnlyExternalAliasing",e[e["AllowAnyNodeKind"]=4]="AllowAnyNodeKind",e[e["UseAliasDefinedOutsideCurrentScope"]=8]="UseAliasDefinedOutsideCurrentScope",e[e["DoNotIncludeSymbolChain"]=16]="DoNotIncludeSymbolChain"}(e.SymbolFormatFlags||(e.SymbolFormatFlags={})),function(e){e[e["Accessible"]=0]="Accessible",e[e["NotAccessible"]=1]="NotAccessible",e[e["CannotBeNamed"]=2]="CannotBeNamed"}(e.SymbolAccessibility||(e.SymbolAccessibility={})),function(e){e[e["UnionOrIntersection"]=0]="UnionOrIntersection",e[e["Spread"]=1]="Spread"}(e.SyntheticSymbolKind||(e.SyntheticSymbolKind={})),function(e){e[e["This"]=0]="This",e[e["Identifier"]=1]="Identifier",e[e["AssertsThis"]=2]="AssertsThis",e[e["AssertsIdentifier"]=3]="AssertsIdentifier"}(e.TypePredicateKind||(e.TypePredicateKind={})),function(e){e[e["Unknown"]=0]="Unknown",e[e["TypeWithConstructSignatureAndValue"]=1]="TypeWithConstructSignatureAndValue",e[e["VoidNullableOrNeverType"]=2]="VoidNullableOrNeverType",e[e["NumberLikeType"]=3]="NumberLikeType",e[e["BigIntLikeType"]=4]="BigIntLikeType",e[e["StringLikeType"]=5]="StringLikeType",e[e["BooleanType"]=6]="BooleanType",e[e["ArrayLikeType"]=7]="ArrayLikeType",e[e["ESSymbolType"]=8]="ESSymbolType",e[e["Promise"]=9]="Promise",e[e["TypeWithCallSignature"]=10]="TypeWithCallSignature",e[e["ObjectType"]=11]="ObjectType"}(e.TypeReferenceSerializationKind||(e.TypeReferenceSerializationKind={})),function(e){e[e["None"]=0]="None",e[e["FunctionScopedVariable"]=1]="FunctionScopedVariable",e[e["BlockScopedVariable"]=2]="BlockScopedVariable",e[e["Property"]=4]="Property",e[e["EnumMember"]=8]="EnumMember",e[e["Function"]=16]="Function",e[e["Class"]=32]="Class",e[e["Interface"]=64]="Interface",e[e["ConstEnum"]=128]="ConstEnum",e[e["RegularEnum"]=256]="RegularEnum",e[e["ValueModule"]=512]="ValueModule",e[e["NamespaceModule"]=1024]="NamespaceModule",e[e["TypeLiteral"]=2048]="TypeLiteral",e[e["ObjectLiteral"]=4096]="ObjectLiteral",e[e["Method"]=8192]="Method",e[e["Constructor"]=16384]="Constructor",e[e["GetAccessor"]=32768]="GetAccessor",e[e["SetAccessor"]=65536]="SetAccessor",e[e["Signature"]=131072]="Signature",e[e["TypeParameter"]=262144]="TypeParameter",e[e["TypeAlias"]=524288]="TypeAlias",e[e["ExportValue"]=1048576]="ExportValue",e[e["Alias"]=2097152]="Alias",e[e["Prototype"]=4194304]="Prototype",e[e["ExportStar"]=8388608]="ExportStar",e[e["Optional"]=16777216]="Optional",e[e["Transient"]=33554432]="Transient",e[e["Assignment"]=67108864]="Assignment",e[e["ModuleExports"]=134217728]="ModuleExports",e[e["All"]=67108863]="All",e[e["Enum"]=384]="Enum",e[e["Variable"]=3]="Variable",e[e["Value"]=111551]="Value",e[e["Type"]=788968]="Type",e[e["Namespace"]=1920]="Namespace",e[e["Module"]=1536]="Module",e[e["Accessor"]=98304]="Accessor",e[e["FunctionScopedVariableExcludes"]=111550]="FunctionScopedVariableExcludes",e[e["BlockScopedVariableExcludes"]=111551]="BlockScopedVariableExcludes",e[e["ParameterExcludes"]=111551]="ParameterExcludes",e[e["PropertyExcludes"]=0]="PropertyExcludes",e[e["EnumMemberExcludes"]=900095]="EnumMemberExcludes",e[e["FunctionExcludes"]=110991]="FunctionExcludes",e[e["ClassExcludes"]=899503]="ClassExcludes",e[e["InterfaceExcludes"]=788872]="InterfaceExcludes",e[e["RegularEnumExcludes"]=899327]="RegularEnumExcludes",e[e["ConstEnumExcludes"]=899967]="ConstEnumExcludes",e[e["ValueModuleExcludes"]=110735]="ValueModuleExcludes",e[e["NamespaceModuleExcludes"]=0]="NamespaceModuleExcludes",e[e["MethodExcludes"]=103359]="MethodExcludes",e[e["GetAccessorExcludes"]=46015]="GetAccessorExcludes",e[e["SetAccessorExcludes"]=78783]="SetAccessorExcludes",e[e["TypeParameterExcludes"]=526824]="TypeParameterExcludes",e[e["TypeAliasExcludes"]=788968]="TypeAliasExcludes",e[e["AliasExcludes"]=2097152]="AliasExcludes",e[e["ModuleMember"]=2623475]="ModuleMember",e[e["ExportHasLocal"]=944]="ExportHasLocal",e[e["BlockScoped"]=418]="BlockScoped",e[e["PropertyOrAccessor"]=98308]="PropertyOrAccessor",e[e["ClassMember"]=106500]="ClassMember",e[e["ExportSupportsDefaultModifier"]=112]="ExportSupportsDefaultModifier",e[e["ExportDoesNotSupportDefaultModifier"]=-113]="ExportDoesNotSupportDefaultModifier",e[e["Classifiable"]=2885600]="Classifiable",e[e["LateBindingContainer"]=6256]="LateBindingContainer"}(e.SymbolFlags||(e.SymbolFlags={})),function(e){e[e["Numeric"]=0]="Numeric",e[e["Literal"]=1]="Literal"}(e.EnumKind||(e.EnumKind={})),function(e){e[e["Instantiated"]=1]="Instantiated",e[e["SyntheticProperty"]=2]="SyntheticProperty",e[e["SyntheticMethod"]=4]="SyntheticMethod",e[e["Readonly"]=8]="Readonly",e[e["ReadPartial"]=16]="ReadPartial",e[e["WritePartial"]=32]="WritePartial",e[e["HasNonUniformType"]=64]="HasNonUniformType",e[e["HasLiteralType"]=128]="HasLiteralType",e[e["ContainsPublic"]=256]="ContainsPublic",e[e["ContainsProtected"]=512]="ContainsProtected",e[e["ContainsPrivate"]=1024]="ContainsPrivate",e[e["ContainsStatic"]=2048]="ContainsStatic",e[e["Late"]=4096]="Late",e[e["ReverseMapped"]=8192]="ReverseMapped",e[e["OptionalParameter"]=16384]="OptionalParameter",e[e["RestParameter"]=32768]="RestParameter",e[e["DeferredType"]=65536]="DeferredType",e[e["HasNeverType"]=131072]="HasNeverType",e[e["Mapped"]=262144]="Mapped",e[e["StripOptional"]=524288]="StripOptional",e[e["Synthetic"]=6]="Synthetic",e[e["Discriminant"]=192]="Discriminant",e[e["Partial"]=48]="Partial"}(e.CheckFlags||(e.CheckFlags={})),function(e){e["Call"]="__call",e["Constructor"]="__constructor",e["New"]="__new",e["Index"]="__index",e["ExportStar"]="__export",e["Global"]="__global",e["Missing"]="__missing",e["Type"]="__type",e["Object"]="__object",e["JSXAttributes"]="__jsxAttributes",e["Class"]="__class",e["Function"]="__function",e["Computed"]="__computed",e["Resolving"]="__resolving__",e["ExportEquals"]="export=",e["Default"]="default",e["This"]="this"}(e.InternalSymbolName||(e.InternalSymbolName={})),function(e){e[e["TypeChecked"]=1]="TypeChecked",e[e["LexicalThis"]=2]="LexicalThis",e[e["CaptureThis"]=4]="CaptureThis",e[e["CaptureNewTarget"]=8]="CaptureNewTarget",e[e["SuperInstance"]=256]="SuperInstance",e[e["SuperStatic"]=512]="SuperStatic",e[e["ContextChecked"]=1024]="ContextChecked",e[e["AsyncMethodWithSuper"]=2048]="AsyncMethodWithSuper",e[e["AsyncMethodWithSuperBinding"]=4096]="AsyncMethodWithSuperBinding",e[e["CaptureArguments"]=8192]="CaptureArguments",e[e["EnumValuesComputed"]=16384]="EnumValuesComputed",e[e["LexicalModuleMergesWithClass"]=32768]="LexicalModuleMergesWithClass",e[e["LoopWithCapturedBlockScopedBinding"]=65536]="LoopWithCapturedBlockScopedBinding",e[e["ContainsCapturedBlockScopeBinding"]=131072]="ContainsCapturedBlockScopeBinding",e[e["CapturedBlockScopedBinding"]=262144]="CapturedBlockScopedBinding",e[e["BlockScopedBindingInLoop"]=524288]="BlockScopedBindingInLoop",e[e["ClassWithBodyScopedClassBinding"]=1048576]="ClassWithBodyScopedClassBinding",e[e["BodyScopedClassBinding"]=2097152]="BodyScopedClassBinding",e[e["NeedsLoopOutParameter"]=4194304]="NeedsLoopOutParameter",e[e["AssignmentsMarked"]=8388608]="AssignmentsMarked",e[e["ClassWithConstructorReference"]=16777216]="ClassWithConstructorReference",e[e["ConstructorReferenceInClass"]=33554432]="ConstructorReferenceInClass",e[e["ContainsClassWithPrivateIdentifiers"]=67108864]="ContainsClassWithPrivateIdentifiers"}(e.NodeCheckFlags||(e.NodeCheckFlags={})),function(e){e[e["Any"]=1]="Any",e[e["Unknown"]=2]="Unknown",e[e["String"]=4]="String",e[e["Number"]=8]="Number",e[e["Boolean"]=16]="Boolean",e[e["Enum"]=32]="Enum",e[e["BigInt"]=64]="BigInt",e[e["StringLiteral"]=128]="StringLiteral",e[e["NumberLiteral"]=256]="NumberLiteral",e[e["BooleanLiteral"]=512]="BooleanLiteral",e[e["EnumLiteral"]=1024]="EnumLiteral",e[e["BigIntLiteral"]=2048]="BigIntLiteral",e[e["ESSymbol"]=4096]="ESSymbol",e[e["UniqueESSymbol"]=8192]="UniqueESSymbol",e[e["Void"]=16384]="Void",e[e["Undefined"]=32768]="Undefined",e[e["Null"]=65536]="Null",e[e["Never"]=131072]="Never",e[e["TypeParameter"]=262144]="TypeParameter",e[e["Object"]=524288]="Object",e[e["Union"]=1048576]="Union",e[e["Intersection"]=2097152]="Intersection",e[e["Index"]=4194304]="Index",e[e["IndexedAccess"]=8388608]="IndexedAccess",e[e["Conditional"]=16777216]="Conditional",e[e["Substitution"]=33554432]="Substitution",e[e["NonPrimitive"]=67108864]="NonPrimitive",e[e["TemplateLiteral"]=134217728]="TemplateLiteral",e[e["StringMapping"]=268435456]="StringMapping",e[e["AnyOrUnknown"]=3]="AnyOrUnknown",e[e["Nullable"]=98304]="Nullable",e[e["Literal"]=2944]="Literal",e[e["Unit"]=109440]="Unit",e[e["StringOrNumberLiteral"]=384]="StringOrNumberLiteral",e[e["StringOrNumberLiteralOrUnique"]=8576]="StringOrNumberLiteralOrUnique",e[e["DefinitelyFalsy"]=117632]="DefinitelyFalsy",e[e["PossiblyFalsy"]=117724]="PossiblyFalsy",e[e["Intrinsic"]=67359327]="Intrinsic",e[e["Primitive"]=131068]="Primitive",e[e["StringLike"]=402653316]="StringLike",e[e["NumberLike"]=296]="NumberLike",e[e["BigIntLike"]=2112]="BigIntLike",e[e["BooleanLike"]=528]="BooleanLike",e[e["EnumLike"]=1056]="EnumLike",e[e["ESSymbolLike"]=12288]="ESSymbolLike",e[e["VoidLike"]=49152]="VoidLike",e[e["DisjointDomains"]=469892092]="DisjointDomains",e[e["UnionOrIntersection"]=3145728]="UnionOrIntersection",e[e["StructuredType"]=3670016]="StructuredType",e[e["TypeVariable"]=8650752]="TypeVariable",e[e["InstantiableNonPrimitive"]=58982400]="InstantiableNonPrimitive",e[e["InstantiablePrimitive"]=406847488]="InstantiablePrimitive",e[e["Instantiable"]=465829888]="Instantiable",e[e["StructuredOrInstantiable"]=469499904]="StructuredOrInstantiable",e[e["ObjectFlagsType"]=3899393]="ObjectFlagsType",e[e["Simplifiable"]=25165824]="Simplifiable",e[e["Substructure"]=469237760]="Substructure",e[e["Narrowable"]=536624127]="Narrowable",e[e["NotPrimitiveUnion"]=468598819]="NotPrimitiveUnion",e[e["IncludesMask"]=205258751]="IncludesMask",e[e["IncludesStructuredOrInstantiable"]=262144]="IncludesStructuredOrInstantiable",e[e["IncludesNonWideningType"]=4194304]="IncludesNonWideningType",e[e["IncludesWildcard"]=8388608]="IncludesWildcard",e[e["IncludesEmptyObject"]=16777216]="IncludesEmptyObject"}(e.TypeFlags||(e.TypeFlags={})),function(e){e[e["Class"]=1]="Class",e[e["Interface"]=2]="Interface",e[e["Reference"]=4]="Reference",e[e["Tuple"]=8]="Tuple",e[e["Anonymous"]=16]="Anonymous",e[e["Mapped"]=32]="Mapped",e[e["Instantiated"]=64]="Instantiated",e[e["ObjectLiteral"]=128]="ObjectLiteral",e[e["EvolvingArray"]=256]="EvolvingArray",e[e["ObjectLiteralPatternWithComputedProperties"]=512]="ObjectLiteralPatternWithComputedProperties",e[e["ReverseMapped"]=1024]="ReverseMapped",e[e["JsxAttributes"]=2048]="JsxAttributes",e[e["MarkerType"]=4096]="MarkerType",e[e["JSLiteral"]=8192]="JSLiteral",e[e["FreshLiteral"]=16384]="FreshLiteral",e[e["ArrayLiteral"]=32768]="ArrayLiteral",e[e["PrimitiveUnion"]=65536]="PrimitiveUnion",e[e["ContainsWideningType"]=131072]="ContainsWideningType",e[e["ContainsObjectOrArrayLiteral"]=262144]="ContainsObjectOrArrayLiteral",e[e["NonInferrableType"]=524288]="NonInferrableType",e[e["CouldContainTypeVariablesComputed"]=1048576]="CouldContainTypeVariablesComputed",e[e["CouldContainTypeVariables"]=2097152]="CouldContainTypeVariables",e[e["ClassOrInterface"]=3]="ClassOrInterface",e[e["RequiresWidening"]=393216]="RequiresWidening",e[e["PropagatingFlags"]=917504]="PropagatingFlags",e[e["ObjectTypeKindMask"]=1343]="ObjectTypeKindMask",e[e["ContainsSpread"]=4194304]="ContainsSpread",e[e["ObjectRestType"]=8388608]="ObjectRestType",e[e["IsClassInstanceClone"]=16777216]="IsClassInstanceClone",e[e["IdenticalBaseTypeCalculated"]=33554432]="IdenticalBaseTypeCalculated",e[e["IdenticalBaseTypeExists"]=67108864]="IdenticalBaseTypeExists",e[e["IsGenericObjectTypeComputed"]=4194304]="IsGenericObjectTypeComputed",e[e["IsGenericObjectType"]=8388608]="IsGenericObjectType",e[e["IsGenericIndexTypeComputed"]=16777216]="IsGenericIndexTypeComputed",e[e["IsGenericIndexType"]=33554432]="IsGenericIndexType",e[e["ContainsIntersections"]=67108864]="ContainsIntersections",e[e["IsNeverIntersectionComputed"]=67108864]="IsNeverIntersectionComputed",e[e["IsNeverIntersection"]=134217728]="IsNeverIntersection"}(e.ObjectFlags||(e.ObjectFlags={})),function(e){e[e["Invariant"]=0]="Invariant",e[e["Covariant"]=1]="Covariant",e[e["Contravariant"]=2]="Contravariant",e[e["Bivariant"]=3]="Bivariant",e[e["Independent"]=4]="Independent",e[e["VarianceMask"]=7]="VarianceMask",e[e["Unmeasurable"]=8]="Unmeasurable",e[e["Unreliable"]=16]="Unreliable",e[e["AllowsStructuralFallback"]=24]="AllowsStructuralFallback"}(e.VarianceFlags||(e.VarianceFlags={})),function(e){e[e["Required"]=1]="Required",e[e["Optional"]=2]="Optional",e[e["Rest"]=4]="Rest",e[e["Variadic"]=8]="Variadic",e[e["Fixed"]=3]="Fixed",e[e["Variable"]=12]="Variable",e[e["NonRequired"]=14]="NonRequired",e[e["NonRest"]=11]="NonRest"}(e.ElementFlags||(e.ElementFlags={})),function(e){e[e["Component"]=0]="Component",e[e["Function"]=1]="Function",e[e["Mixed"]=2]="Mixed"}(e.JsxReferenceKind||(e.JsxReferenceKind={})),function(e){e[e["Call"]=0]="Call",e[e["Construct"]=1]="Construct"}(e.SignatureKind||(e.SignatureKind={})),function(e){e[e["None"]=0]="None",e[e["HasRestParameter"]=1]="HasRestParameter",e[e["HasLiteralTypes"]=2]="HasLiteralTypes",e[e["Abstract"]=4]="Abstract",e[e["IsInnerCallChain"]=8]="IsInnerCallChain",e[e["IsOuterCallChain"]=16]="IsOuterCallChain",e[e["IsUntypedSignatureInJSFile"]=32]="IsUntypedSignatureInJSFile",e[e["PropagatingFlags"]=39]="PropagatingFlags",e[e["CallChainFlags"]=24]="CallChainFlags"}(e.SignatureFlags||(e.SignatureFlags={})),function(e){e[e["String"]=0]="String",e[e["Number"]=1]="Number"}(e.IndexKind||(e.IndexKind={})),function(e){e[e["Simple"]=0]="Simple",e[e["Array"]=1]="Array",e[e["Function"]=2]="Function",e[e["Composite"]=3]="Composite",e[e["Merged"]=4]="Merged"}(e.TypeMapKind||(e.TypeMapKind={})),function(e){e[e["NakedTypeVariable"]=1]="NakedTypeVariable",e[e["SpeculativeTuple"]=2]="SpeculativeTuple",e[e["SubstituteSource"]=4]="SubstituteSource",e[e["HomomorphicMappedType"]=8]="HomomorphicMappedType",e[e["PartialHomomorphicMappedType"]=16]="PartialHomomorphicMappedType",e[e["MappedTypeConstraint"]=32]="MappedTypeConstraint",e[e["ContravariantConditional"]=64]="ContravariantConditional",e[e["ReturnType"]=128]="ReturnType",e[e["LiteralKeyof"]=256]="LiteralKeyof",e[e["NoConstraints"]=512]="NoConstraints",e[e["AlwaysStrict"]=1024]="AlwaysStrict",e[e["MaxValue"]=2048]="MaxValue",e[e["PriorityImpliesCombination"]=416]="PriorityImpliesCombination",e[e["Circularity"]=-1]="Circularity"}(e.InferencePriority||(e.InferencePriority={})),function(e){e[e["None"]=0]="None",e[e["NoDefault"]=1]="NoDefault",e[e["AnyDefault"]=2]="AnyDefault",e[e["SkippedGenericFunction"]=4]="SkippedGenericFunction"}(e.InferenceFlags||(e.InferenceFlags={})),function(e){e[e["False"]=0]="False",e[e["Unknown"]=1]="Unknown",e[e["Maybe"]=3]="Maybe",e[e["True"]=-1]="True"}(e.Ternary||(e.Ternary={})),function(e){e[e["None"]=0]="None",e[e["ExportsProperty"]=1]="ExportsProperty",e[e["ModuleExports"]=2]="ModuleExports",e[e["PrototypeProperty"]=3]="PrototypeProperty",e[e["ThisProperty"]=4]="ThisProperty",e[e["Property"]=5]="Property",e[e["Prototype"]=6]="Prototype",e[e["ObjectDefinePropertyValue"]=7]="ObjectDefinePropertyValue",e[e["ObjectDefinePropertyExports"]=8]="ObjectDefinePropertyExports",e[e["ObjectDefinePrototypeProperty"]=9]="ObjectDefinePrototypeProperty"}(e.AssignmentDeclarationKind||(e.AssignmentDeclarationKind={})),function(e){e[e["Warning"]=0]="Warning",e[e["Error"]=1]="Error",e[e["Suggestion"]=2]="Suggestion",e[e["Message"]=3]="Message"}(n=e.DiagnosticCategory||(e.DiagnosticCategory={})),e.diagnosticCategoryName=r,function(e){e[e["Classic"]=1]="Classic",e[e["NodeJs"]=2]="NodeJs"}(e.ModuleResolutionKind||(e.ModuleResolutionKind={})),function(e){e[e["FixedPollingInterval"]=0]="FixedPollingInterval",e[e["PriorityPollingInterval"]=1]="PriorityPollingInterval",e[e["DynamicPriorityPolling"]=2]="DynamicPriorityPolling",e[e["FixedChunkSizePolling"]=3]="FixedChunkSizePolling",e[e["UseFsEvents"]=4]="UseFsEvents",e[e["UseFsEventsOnParentDirectory"]=5]="UseFsEventsOnParentDirectory"}(e.WatchFileKind||(e.WatchFileKind={})),function(e){e[e["UseFsEvents"]=0]="UseFsEvents",e[e["FixedPollingInterval"]=1]="FixedPollingInterval",e[e["DynamicPriorityPolling"]=2]="DynamicPriorityPolling",e[e["FixedChunkSizePolling"]=3]="FixedChunkSizePolling"}(e.WatchDirectoryKind||(e.WatchDirectoryKind={})),function(e){e[e["FixedInterval"]=0]="FixedInterval",e[e["PriorityInterval"]=1]="PriorityInterval",e[e["DynamicPriority"]=2]="DynamicPriority",e[e["FixedChunkSize"]=3]="FixedChunkSize"}(e.PollingWatchKind||(e.PollingWatchKind={})),function(e){e[e["None"]=0]="None",e[e["CommonJS"]=1]="CommonJS",e[e["AMD"]=2]="AMD",e[e["UMD"]=3]="UMD",e[e["System"]=4]="System",e[e["ES2015"]=5]="ES2015",e[e["ES2020"]=6]="ES2020",e[e["ESNext"]=99]="ESNext"}(e.ModuleKind||(e.ModuleKind={})),function(e){e[e["None"]=0]="None",e[e["Preserve"]=1]="Preserve",e[e["React"]=2]="React",e[e["ReactNative"]=3]="ReactNative",e[e["ReactJSX"]=4]="ReactJSX",e[e["ReactJSXDev"]=5]="ReactJSXDev"}(e.JsxEmit||(e.JsxEmit={})),function(e){e[e["Remove"]=0]="Remove",e[e["Preserve"]=1]="Preserve",e[e["Error"]=2]="Error"}(e.ImportsNotUsedAsValues||(e.ImportsNotUsedAsValues={})),function(e){e[e["CarriageReturnLineFeed"]=0]="CarriageReturnLineFeed",e[e["LineFeed"]=1]="LineFeed"}(e.NewLineKind||(e.NewLineKind={})),function(e){e[e["Unknown"]=0]="Unknown",e[e["JS"]=1]="JS",e[e["JSX"]=2]="JSX",e[e["TS"]=3]="TS",e[e["TSX"]=4]="TSX",e[e["External"]=5]="External",e[e["JSON"]=6]="JSON",e[e["Deferred"]=7]="Deferred"}(e.ScriptKind||(e.ScriptKind={})),function(e){e[e["ES3"]=0]="ES3",e[e["ES5"]=1]="ES5",e[e["ES2015"]=2]="ES2015",e[e["ES2016"]=3]="ES2016",e[e["ES2017"]=4]="ES2017",e[e["ES2018"]=5]="ES2018",e[e["ES2019"]=6]="ES2019",e[e["ES2020"]=7]="ES2020",e[e["ES2021"]=8]="ES2021",e[e["ESNext"]=99]="ESNext",e[e["JSON"]=100]="JSON",e[e["Latest"]=99]="Latest"}(e.ScriptTarget||(e.ScriptTarget={})),function(e){e[e["Standard"]=0]="Standard",e[e["JSX"]=1]="JSX"}(e.LanguageVariant||(e.LanguageVariant={})),function(e){e[e["None"]=0]="None",e[e["Recursive"]=1]="Recursive"}(e.WatchDirectoryFlags||(e.WatchDirectoryFlags={})),function(e){e[e["nullCharacter"]=0]="nullCharacter",e[e["maxAsciiCharacter"]=127]="maxAsciiCharacter",e[e["lineFeed"]=10]="lineFeed",e[e["carriageReturn"]=13]="carriageReturn",e[e["lineSeparator"]=8232]="lineSeparator",e[e["paragraphSeparator"]=8233]="paragraphSeparator",e[e["nextLine"]=133]="nextLine",e[e["space"]=32]="space",e[e["nonBreakingSpace"]=160]="nonBreakingSpace",e[e["enQuad"]=8192]="enQuad",e[e["emQuad"]=8193]="emQuad",e[e["enSpace"]=8194]="enSpace",e[e["emSpace"]=8195]="emSpace",e[e["threePerEmSpace"]=8196]="threePerEmSpace",e[e["fourPerEmSpace"]=8197]="fourPerEmSpace",e[e["sixPerEmSpace"]=8198]="sixPerEmSpace",e[e["figureSpace"]=8199]="figureSpace",e[e["punctuationSpace"]=8200]="punctuationSpace",e[e["thinSpace"]=8201]="thinSpace",e[e["hairSpace"]=8202]="hairSpace",e[e["zeroWidthSpace"]=8203]="zeroWidthSpace",e[e["narrowNoBreakSpace"]=8239]="narrowNoBreakSpace",e[e["ideographicSpace"]=12288]="ideographicSpace",e[e["mathematicalSpace"]=8287]="mathematicalSpace",e[e["ogham"]=5760]="ogham",e[e["_"]=95]="_",e[e["$"]=36]="$",e[e["_0"]=48]="_0",e[e["_1"]=49]="_1",e[e["_2"]=50]="_2",e[e["_3"]=51]="_3",e[e["_4"]=52]="_4",e[e["_5"]=53]="_5",e[e["_6"]=54]="_6",e[e["_7"]=55]="_7",e[e["_8"]=56]="_8",e[e["_9"]=57]="_9",e[e["a"]=97]="a",e[e["b"]=98]="b",e[e["c"]=99]="c",e[e["d"]=100]="d",e[e["e"]=101]="e",e[e["f"]=102]="f",e[e["g"]=103]="g",e[e["h"]=104]="h",e[e["i"]=105]="i",e[e["j"]=106]="j",e[e["k"]=107]="k",e[e["l"]=108]="l",e[e["m"]=109]="m",e[e["n"]=110]="n",e[e["o"]=111]="o",e[e["p"]=112]="p",e[e["q"]=113]="q",e[e["r"]=114]="r",e[e["s"]=115]="s",e[e["t"]=116]="t",e[e["u"]=117]="u",e[e["v"]=118]="v",e[e["w"]=119]="w",e[e["x"]=120]="x",e[e["y"]=121]="y",e[e["z"]=122]="z",e[e["A"]=65]="A",e[e["B"]=66]="B",e[e["C"]=67]="C",e[e["D"]=68]="D",e[e["E"]=69]="E",e[e["F"]=70]="F",e[e["G"]=71]="G",e[e["H"]=72]="H",e[e["I"]=73]="I",e[e["J"]=74]="J",e[e["K"]=75]="K",e[e["L"]=76]="L",e[e["M"]=77]="M",e[e["N"]=78]="N",e[e["O"]=79]="O",e[e["P"]=80]="P",e[e["Q"]=81]="Q",e[e["R"]=82]="R",e[e["S"]=83]="S",e[e["T"]=84]="T",e[e["U"]=85]="U",e[e["V"]=86]="V",e[e["W"]=87]="W",e[e["X"]=88]="X",e[e["Y"]=89]="Y",e[e["Z"]=90]="Z",e[e["ampersand"]=38]="ampersand",e[e["asterisk"]=42]="asterisk",e[e["at"]=64]="at",e[e["backslash"]=92]="backslash",e[e["backtick"]=96]="backtick",e[e["bar"]=124]="bar",e[e["caret"]=94]="caret",e[e["closeBrace"]=125]="closeBrace",e[e["closeBracket"]=93]="closeBracket",e[e["closeParen"]=41]="closeParen",e[e["colon"]=58]="colon",e[e["comma"]=44]="comma",e[e["dot"]=46]="dot",e[e["doubleQuote"]=34]="doubleQuote",e[e["equals"]=61]="equals",e[e["exclamation"]=33]="exclamation",e[e["greaterThan"]=62]="greaterThan",e[e["hash"]=35]="hash",e[e["lessThan"]=60]="lessThan",e[e["minus"]=45]="minus",e[e["openBrace"]=123]="openBrace",e[e["openBracket"]=91]="openBracket",e[e["openParen"]=40]="openParen",e[e["percent"]=37]="percent",e[e["plus"]=43]="plus",e[e["question"]=63]="question",e[e["semicolon"]=59]="semicolon",e[e["singleQuote"]=39]="singleQuote",e[e["slash"]=47]="slash",e[e["tilde"]=126]="tilde",e[e["backspace"]=8]="backspace",e[e["formFeed"]=12]="formFeed",e[e["byteOrderMark"]=65279]="byteOrderMark",e[e["tab"]=9]="tab",e[e["verticalTab"]=11]="verticalTab"}(e.CharacterCodes||(e.CharacterCodes={})),function(e){e["Ts"]=".ts",e["Tsx"]=".tsx",e["Dts"]=".d.ts",e["Js"]=".js",e["Jsx"]=".jsx",e["Json"]=".json",e["TsBuildInfo"]=".tsbuildinfo"}(e.Extension||(e.Extension={})),function(e){e[e["None"]=0]="None",e[e["ContainsTypeScript"]=1]="ContainsTypeScript",e[e["ContainsJsx"]=2]="ContainsJsx",e[e["ContainsESNext"]=4]="ContainsESNext",e[e["ContainsES2021"]=8]="ContainsES2021",e[e["ContainsES2020"]=16]="ContainsES2020",e[e["ContainsES2019"]=32]="ContainsES2019",e[e["ContainsES2018"]=64]="ContainsES2018",e[e["ContainsES2017"]=128]="ContainsES2017",e[e["ContainsES2016"]=256]="ContainsES2016",e[e["ContainsES2015"]=512]="ContainsES2015",e[e["ContainsGenerator"]=1024]="ContainsGenerator",e[e["ContainsDestructuringAssignment"]=2048]="ContainsDestructuringAssignment",e[e["ContainsTypeScriptClassSyntax"]=4096]="ContainsTypeScriptClassSyntax",e[e["ContainsLexicalThis"]=8192]="ContainsLexicalThis",e[e["ContainsRestOrSpread"]=16384]="ContainsRestOrSpread",e[e["ContainsObjectRestOrSpread"]=32768]="ContainsObjectRestOrSpread",e[e["ContainsComputedPropertyName"]=65536]="ContainsComputedPropertyName",e[e["ContainsBlockScopedBinding"]=131072]="ContainsBlockScopedBinding",e[e["ContainsBindingPattern"]=262144]="ContainsBindingPattern",e[e["ContainsYield"]=524288]="ContainsYield",e[e["ContainsAwait"]=1048576]="ContainsAwait",e[e["ContainsHoistedDeclarationOrCompletion"]=2097152]="ContainsHoistedDeclarationOrCompletion",e[e["ContainsDynamicImport"]=4194304]="ContainsDynamicImport",e[e["ContainsClassFields"]=8388608]="ContainsClassFields",e[e["ContainsPossibleTopLevelAwait"]=16777216]="ContainsPossibleTopLevelAwait",e[e["HasComputedFlags"]=536870912]="HasComputedFlags",e[e["AssertTypeScript"]=1]="AssertTypeScript",e[e["AssertJsx"]=2]="AssertJsx",e[e["AssertESNext"]=4]="AssertESNext",e[e["AssertES2021"]=8]="AssertES2021",e[e["AssertES2020"]=16]="AssertES2020",e[e["AssertES2019"]=32]="AssertES2019",e[e["AssertES2018"]=64]="AssertES2018",e[e["AssertES2017"]=128]="AssertES2017",e[e["AssertES2016"]=256]="AssertES2016",e[e["AssertES2015"]=512]="AssertES2015",e[e["AssertGenerator"]=1024]="AssertGenerator",e[e["AssertDestructuringAssignment"]=2048]="AssertDestructuringAssignment",e[e["OuterExpressionExcludes"]=536870912]="OuterExpressionExcludes",e[e["PropertyAccessExcludes"]=536870912]="PropertyAccessExcludes",e[e["NodeExcludes"]=536870912]="NodeExcludes",e[e["ArrowFunctionExcludes"]=557748224]="ArrowFunctionExcludes",e[e["FunctionExcludes"]=557756416]="FunctionExcludes",e[e["ConstructorExcludes"]=557752320]="ConstructorExcludes",e[e["MethodOrAccessorExcludes"]=540975104]="MethodOrAccessorExcludes",e[e["PropertyExcludes"]=536879104]="PropertyExcludes",e[e["ClassExcludes"]=536940544]="ClassExcludes",e[e["ModuleExcludes"]=555888640]="ModuleExcludes",e[e["TypeExcludes"]=-2]="TypeExcludes",e[e["ObjectLiteralExcludes"]=536973312]="ObjectLiteralExcludes",e[e["ArrayLiteralOrCallOrNewExcludes"]=536887296]="ArrayLiteralOrCallOrNewExcludes",e[e["VariableDeclarationListExcludes"]=537165824]="VariableDeclarationListExcludes",e[e["ParameterExcludes"]=536870912]="ParameterExcludes",e[e["CatchClauseExcludes"]=536903680]="CatchClauseExcludes",e[e["BindingPatternExcludes"]=536887296]="BindingPatternExcludes",e[e["PropertyNamePropagatingFlags"]=8192]="PropertyNamePropagatingFlags"}(e.TransformFlags||(e.TransformFlags={})),function(e){e[e["None"]=0]="None",e[e["SingleLine"]=1]="SingleLine",e[e["AdviseOnEmitNode"]=2]="AdviseOnEmitNode",e[e["NoSubstitution"]=4]="NoSubstitution",e[e["CapturesThis"]=8]="CapturesThis",e[e["NoLeadingSourceMap"]=16]="NoLeadingSourceMap",e[e["NoTrailingSourceMap"]=32]="NoTrailingSourceMap",e[e["NoSourceMap"]=48]="NoSourceMap",e[e["NoNestedSourceMaps"]=64]="NoNestedSourceMaps",e[e["NoTokenLeadingSourceMaps"]=128]="NoTokenLeadingSourceMaps",e[e["NoTokenTrailingSourceMaps"]=256]="NoTokenTrailingSourceMaps",e[e["NoTokenSourceMaps"]=384]="NoTokenSourceMaps",e[e["NoLeadingComments"]=512]="NoLeadingComments",e[e["NoTrailingComments"]=1024]="NoTrailingComments",e[e["NoComments"]=1536]="NoComments",e[e["NoNestedComments"]=2048]="NoNestedComments",e[e["HelperName"]=4096]="HelperName",e[e["ExportName"]=8192]="ExportName",e[e["LocalName"]=16384]="LocalName",e[e["InternalName"]=32768]="InternalName",e[e["Indented"]=65536]="Indented",e[e["NoIndentation"]=131072]="NoIndentation",e[e["AsyncFunctionBody"]=262144]="AsyncFunctionBody",e[e["ReuseTempVariableScope"]=524288]="ReuseTempVariableScope",e[e["CustomPrologue"]=1048576]="CustomPrologue",e[e["NoHoisting"]=2097152]="NoHoisting",e[e["HasEndOfDeclarationMarker"]=4194304]="HasEndOfDeclarationMarker",e[e["Iterator"]=8388608]="Iterator",e[e["NoAsciiEscaping"]=16777216]="NoAsciiEscaping",e[e["TypeScriptClassWrapper"]=33554432]="TypeScriptClassWrapper",e[e["NeverApplyImportHelper"]=67108864]="NeverApplyImportHelper",e[e["IgnoreSourceNewlines"]=134217728]="IgnoreSourceNewlines"}(e.EmitFlags||(e.EmitFlags={})),function(e){e[e["Extends"]=1]="Extends",e[e["Assign"]=2]="Assign",e[e["Rest"]=4]="Rest",e[e["Decorate"]=8]="Decorate",e[e["Metadata"]=16]="Metadata",e[e["Param"]=32]="Param",e[e["Awaiter"]=64]="Awaiter",e[e["Generator"]=128]="Generator",e[e["Values"]=256]="Values",e[e["Read"]=512]="Read",e[e["SpreadArray"]=1024]="SpreadArray",e[e["Await"]=2048]="Await",e[e["AsyncGenerator"]=4096]="AsyncGenerator",e[e["AsyncDelegator"]=8192]="AsyncDelegator",e[e["AsyncValues"]=16384]="AsyncValues",e[e["ExportStar"]=32768]="ExportStar",e[e["ImportStar"]=65536]="ImportStar",e[e["ImportDefault"]=131072]="ImportDefault",e[e["MakeTemplateObject"]=262144]="MakeTemplateObject",e[e["ClassPrivateFieldGet"]=524288]="ClassPrivateFieldGet",e[e["ClassPrivateFieldSet"]=1048576]="ClassPrivateFieldSet",e[e["CreateBinding"]=2097152]="CreateBinding",e[e["FirstEmitHelper"]=1]="FirstEmitHelper",e[e["LastEmitHelper"]=2097152]="LastEmitHelper",e[e["ForOfIncludes"]=256]="ForOfIncludes",e[e["ForAwaitOfIncludes"]=16384]="ForAwaitOfIncludes",e[e["AsyncGeneratorIncludes"]=6144]="AsyncGeneratorIncludes",e[e["AsyncDelegatorIncludes"]=26624]="AsyncDelegatorIncludes",e[e["SpreadIncludes"]=1536]="SpreadIncludes"}(e.ExternalEmitHelpers||(e.ExternalEmitHelpers={})),function(e){e[e["SourceFile"]=0]="SourceFile",e[e["Expression"]=1]="Expression",e[e["IdentifierName"]=2]="IdentifierName",e[e["MappedTypeParameter"]=3]="MappedTypeParameter",e[e["Unspecified"]=4]="Unspecified",e[e["EmbeddedStatement"]=5]="EmbeddedStatement",e[e["JsxAttributeValue"]=6]="JsxAttributeValue"}(e.EmitHint||(e.EmitHint={})),function(e){e[e["Parentheses"]=1]="Parentheses",e[e["TypeAssertions"]=2]="TypeAssertions",e[e["NonNullAssertions"]=4]="NonNullAssertions",e[e["PartiallyEmittedExpressions"]=8]="PartiallyEmittedExpressions",e[e["Assertions"]=6]="Assertions",e[e["All"]=15]="All"}(e.OuterExpressionKinds||(e.OuterExpressionKinds={})),function(e){e[e["None"]=0]="None",e[e["InParameters"]=1]="InParameters",e[e["VariablesHoistedInParameters"]=2]="VariablesHoistedInParameters"}(e.LexicalEnvironmentFlags||(e.LexicalEnvironmentFlags={})),function(e){e["Prologue"]="prologue",e["EmitHelpers"]="emitHelpers",e["NoDefaultLib"]="no-default-lib",e["Reference"]="reference",e["Type"]="type",e["Lib"]="lib",e["Prepend"]="prepend",e["Text"]="text",e["Internal"]="internal"}(e.BundleFileSectionKind||(e.BundleFileSectionKind={})),function(e){e[e["None"]=0]="None",e[e["SingleLine"]=0]="SingleLine",e[e["MultiLine"]=1]="MultiLine",e[e["PreserveLines"]=2]="PreserveLines",e[e["LinesMask"]=3]="LinesMask",e[e["NotDelimited"]=0]="NotDelimited",e[e["BarDelimited"]=4]="BarDelimited",e[e["AmpersandDelimited"]=8]="AmpersandDelimited",e[e["CommaDelimited"]=16]="CommaDelimited",e[e["AsteriskDelimited"]=32]="AsteriskDelimited",e[e["DelimitersMask"]=60]="DelimitersMask",e[e["AllowTrailingComma"]=64]="AllowTrailingComma",e[e["Indented"]=128]="Indented",e[e["SpaceBetweenBraces"]=256]="SpaceBetweenBraces",e[e["SpaceBetweenSiblings"]=512]="SpaceBetweenSiblings",e[e["Braces"]=1024]="Braces",e[e["Parenthesis"]=2048]="Parenthesis",e[e["AngleBrackets"]=4096]="AngleBrackets",e[e["SquareBrackets"]=8192]="SquareBrackets",e[e["BracketsMask"]=15360]="BracketsMask",e[e["OptionalIfUndefined"]=16384]="OptionalIfUndefined",e[e["OptionalIfEmpty"]=32768]="OptionalIfEmpty",e[e["Optional"]=49152]="Optional",e[e["PreferNewLine"]=65536]="PreferNewLine",e[e["NoTrailingNewLine"]=131072]="NoTrailingNewLine",e[e["NoInterveningComments"]=262144]="NoInterveningComments",e[e["NoSpaceIfEmpty"]=524288]="NoSpaceIfEmpty",e[e["SingleElement"]=1048576]="SingleElement",e[e["SpaceAfterList"]=2097152]="SpaceAfterList",e[e["Modifiers"]=262656]="Modifiers",e[e["HeritageClauses"]=512]="HeritageClauses",e[e["SingleLineTypeLiteralMembers"]=768]="SingleLineTypeLiteralMembers",e[e["MultiLineTypeLiteralMembers"]=32897]="MultiLineTypeLiteralMembers",e[e["SingleLineTupleTypeElements"]=528]="SingleLineTupleTypeElements",e[e["MultiLineTupleTypeElements"]=657]="MultiLineTupleTypeElements",e[e["UnionTypeConstituents"]=516]="UnionTypeConstituents",e[e["IntersectionTypeConstituents"]=520]="IntersectionTypeConstituents",e[e["ObjectBindingPatternElements"]=525136]="ObjectBindingPatternElements",e[e["ArrayBindingPatternElements"]=524880]="ArrayBindingPatternElements",e[e["ObjectLiteralExpressionProperties"]=526226]="ObjectLiteralExpressionProperties",e[e["ArrayLiteralExpressionElements"]=8914]="ArrayLiteralExpressionElements",e[e["CommaListElements"]=528]="CommaListElements",e[e["CallExpressionArguments"]=2576]="CallExpressionArguments",e[e["NewExpressionArguments"]=18960]="NewExpressionArguments",e[e["TemplateExpressionSpans"]=262144]="TemplateExpressionSpans",e[e["SingleLineBlockStatements"]=768]="SingleLineBlockStatements",e[e["MultiLineBlockStatements"]=129]="MultiLineBlockStatements",e[e["VariableDeclarationList"]=528]="VariableDeclarationList",e[e["SingleLineFunctionBodyStatements"]=768]="SingleLineFunctionBodyStatements",e[e["MultiLineFunctionBodyStatements"]=1]="MultiLineFunctionBodyStatements",e[e["ClassHeritageClauses"]=0]="ClassHeritageClauses",e[e["ClassMembers"]=129]="ClassMembers",e[e["InterfaceMembers"]=129]="InterfaceMembers",e[e["EnumMembers"]=145]="EnumMembers",e[e["CaseBlockClauses"]=129]="CaseBlockClauses",e[e["NamedImportsOrExportsElements"]=525136]="NamedImportsOrExportsElements",e[e["JsxElementOrFragmentChildren"]=262144]="JsxElementOrFragmentChildren",e[e["JsxElementAttributes"]=262656]="JsxElementAttributes",e[e["CaseOrDefaultClauseStatements"]=163969]="CaseOrDefaultClauseStatements",e[e["HeritageClauseTypes"]=528]="HeritageClauseTypes",e[e["SourceFileStatements"]=131073]="SourceFileStatements",e[e["Decorators"]=2146305]="Decorators",e[e["TypeArguments"]=53776]="TypeArguments",e[e["TypeParameters"]=53776]="TypeParameters",e[e["Parameters"]=2576]="Parameters",e[e["IndexSignatureParameters"]=8848]="IndexSignatureParameters",e[e["JSDocComment"]=33]="JSDocComment"}(e.ListFormat||(e.ListFormat={})),function(e){e[e["None"]=0]="None",e[e["TripleSlashXML"]=1]="TripleSlashXML",e[e["SingleLine"]=2]="SingleLine",e[e["MultiLine"]=4]="MultiLine",e[e["All"]=7]="All",e[e["Default"]=7]="Default"}(e.PragmaKindFlags||(e.PragmaKindFlags={})),e.commentPragmas={reference:{args:[{name:"types",optional:!0,captureSpan:!0},{name:"lib",optional:!0,captureSpan:!0},{name:"path",optional:!0,captureSpan:!0},{name:"no-default-lib",optional:!0}],kind:1},"amd-dependency":{args:[{name:"path"},{name:"name",optional:!0}],kind:1},"amd-module":{args:[{name:"name"}],kind:1},"ts-check":{kind:2},"ts-nocheck":{kind:2},jsx:{args:[{name:"factory"}],kind:4},jsxfrag:{args:[{name:"factory"}],kind:4},jsximportsource:{args:[{name:"factory"}],kind:4},jsxruntime:{args:[{name:"factory"}],kind:4}}}(d||(d={})),function(e){e.directorySeparator="/",e.altDirectorySeparator="\\";var n="://",t=/\\/g;function r(e){return 47===e||92===e}function a(e){return y(e)<0}function o(e){return y(e)>0}function s(e){var n=y(e);return n>0&&n===e.length}function c(e){return 0!==y(e)}function l(e){return/^\.\.?($|[\\/])/.test(e)}function u(e){return!c(e)&&!l(e)}function d(n){return e.stringContains(b(n),".")}function p(n,t){return n.length>t.length&&e.endsWith(n,t)}function f(e,n){for(var t=0,r=n;t<r.length;t++){var a=r[t];if(p(e,a))return!0}return!1}function m(e){return e.length>0&&r(e.charCodeAt(e.length-1))}function _(e){return e>=97&&e<=122||e>=65&&e<=90}function g(e,n){var t=e.charCodeAt(n);if(58===t)return n+1;if(37===t&&51===e.charCodeAt(n+1)){var r=e.charCodeAt(n+2);if(97===r||65===r)return n+3}return-1}function y(t){if(!t)return 0;var r=t.charCodeAt(0);if(47===r||92===r){if(t.charCodeAt(1)!==r)return 1;var a=t.indexOf(47===r?e.directorySeparator:e.altDirectorySeparator,2);return a<0?t.length:a+1}if(_(r)&&58===t.charCodeAt(1)){var i=t.charCodeAt(2);if(47===i||92===i)return 3;if(2===t.length)return 2}var o=t.indexOf(n);if(-1!==o){var s=o+n.length,c=t.indexOf(e.directorySeparator,s);if(-1!==c){var l=t.slice(0,o),u=t.slice(s,c);if("file"===l&&(""===u||"localhost"===u)&&_(t.charCodeAt(c+1))){var d=g(t,c+2);if(-1!==d){if(47===t.charCodeAt(d))return~(d+1);if(d===t.length)return~d}}return~(c+1)}return~t.length}return 0}function h(e){var n=y(e);return n<0?~n:n}function v(n){n=A(n);var t=h(n);return t===n.length?n:(n=G(n),n.slice(0,Math.max(t,n.lastIndexOf(e.directorySeparator))))}function b(n,t,r){n=A(n);var a=h(n);if(a===n.length)return"";n=G(n);var i=n.slice(Math.max(h(n),n.lastIndexOf(e.directorySeparator)+1)),o=void 0!==t&&void 0!==r?S(i,t,r):void 0;return o?i.slice(0,i.length-o.length):i}function E(n,t,r){if(e.startsWith(t,".")||(t="."+t),n.length>=t.length&&46===n.charCodeAt(n.length-t.length)){var a=n.slice(n.length-t.length);if(r(a,t))return a}}function T(e,n,t){if("string"===typeof n)return E(e,n,t)||"";for(var r=0,a=n;r<a.length;r++){var i=a[r],o=E(e,i,t);if(o)return o}return""}function S(n,t,r){if(t)return T(G(n),t,r?e.equateStringsCaseInsensitive:e.equateStringsCaseSensitive);var a=b(n),i=a.lastIndexOf(".");return i>=0?a.substring(i):""}function x(n,t){var r=n.substring(0,t),a=n.substring(t).split(e.directorySeparator);return a.length&&!e.lastOrUndefined(a)&&a.pop(),i([r],a)}function L(e,n){return void 0===n&&(n=""),e=I(n,e),x(e,h(e))}function D(n){if(0===n.length)return"";var t=n[0]&&B(n[0]);return t+n.slice(1).join(e.directorySeparator)}function A(n){return n.replace(t,e.directorySeparator)}function C(n){if(!e.some(n))return[];for(var t=[n[0]],r=1;r<n.length;r++){var a=n[r];if(a&&"."!==a){if(".."===a)if(t.length>1){if(".."!==t[t.length-1]){t.pop();continue}}else if(t[0])continue;t.push(a)}}return t}function I(e){for(var n=[],t=1;t<arguments.length;t++)n[t-1]=arguments[t];e&&(e=A(e));for(var r=0,a=n;r<a.length;r++){var i=a[r];i&&(i=A(i),e=e&&0===h(i)?B(e)+i:i)}return e}function N(n){for(var t=[],r=1;r<arguments.length;r++)t[r-1]=arguments[r];return O(e.some(t)?I.apply(void 0,i([n],t)):A(n))}function k(e,n){return C(L(e,n))}function R(e,n){return D(k(e,n))}function O(e){e=A(e);var n=D(C(L(e)));return n&&m(e)?B(n):n}function w(n){return 0===n.length?"":n.slice(1).join(e.directorySeparator)}function P(e,n){return w(k(e,n))}function M(e,n,t){var r=o(e)?O(e):R(e,n);return t(r)}function F(n){n=A(n);var t=C(L(n)),r=t[0],a=t.slice(1);if(a.length){var i=r+a.join(e.directorySeparator);return{path:m(n)?B(i):i,parts:a}}return{path:r,parts:a}}function G(e){return m(e)?e.substr(0,e.length-1):e}function B(n){return m(n)?n:n+e.directorySeparator}function U(e){return c(e)||l(e)?e:"./"+e}function V(n,t,r,a){var i=void 0!==r&&void 0!==a?S(n,r,a):S(n);return i?n.slice(0,n.length-i.length)+(e.startsWith(t,".")?t:"."+t):n}e.isAnyDirectorySeparator=r,e.isUrl=a,e.isRootedDiskPath=o,e.isDiskPathRoot=s,e.pathIsAbsolute=c,e.pathIsRelative=l,e.pathIsBareSpecifier=u,e.hasExtension=d,e.fileExtensionIs=p,e.fileExtensionIsOneOf=f,e.hasTrailingDirectorySeparator=m,e.getRootLength=h,e.getDirectoryPath=v,e.getBaseFileName=b,e.getAnyExtensionFromPath=S,e.getPathComponents=L,e.getPathFromPathComponents=D,e.normalizeSlashes=A,e.reducePathComponents=C,e.combinePaths=I,e.resolvePath=N,e.getNormalizedPathComponents=k,e.getNormalizedAbsolutePath=R,e.normalizePath=O,e.getNormalizedAbsolutePathWithoutRoot=P,e.toPath=M,e.normalizePathAndParts=F,e.removeTrailingDirectorySeparator=G,e.ensureTrailingDirectorySeparator=B,e.ensurePathIsNonModuleName=U,e.changeAnyExtension=V;var j=/(^|\/)\.{0,2}($|\/)/;function K(n,t,r){if(n===t)return 0;if(void 0===n)return-1;if(void 0===t)return 1;var a=n.substring(0,h(n)),i=t.substring(0,h(t)),o=e.compareStringsCaseInsensitive(a,i);if(0!==o)return o;var s=n.substring(a.length),c=t.substring(i.length);if(!j.test(s)&&!j.test(c))return r(s,c);for(var l=C(L(n)),u=C(L(t)),d=Math.min(l.length,u.length),p=1;p<d;p++){var f=r(l[p],u[p]);if(0!==f)return f}return e.compareValues(l.length,u.length)}function H(n,t){return K(n,t,e.compareStringsCaseSensitive)}function W(n,t){return K(n,t,e.compareStringsCaseInsensitive)}function z(n,t,r,a){return"string"===typeof r?(n=I(r,n),t=I(r,t)):"boolean"===typeof r&&(a=r),K(n,t,e.getStringComparer(a))}function q(n,t,r,a){if("string"===typeof r?(n=I(r,n),t=I(r,t)):"boolean"===typeof r&&(a=r),void 0===n||void 0===t)return!1;if(n===t)return!0;var i=C(L(n)),o=C(L(t));if(o.length<i.length)return!1;for(var s=a?e.equateStringsCaseInsensitive:e.equateStringsCaseSensitive,c=0;c<i.length;c++){var l=0===c?e.equateStringsCaseInsensitive:s;if(!l(i[c],o[c]))return!1}return!0}function J(n,t,r){var a=r(n),i=r(t);return e.startsWith(a,i+"/")||e.startsWith(a,i+"\\")}function X(n,t,r,a){var o,s=C(L(n)),c=C(L(t));for(o=0;o<s.length&&o<c.length;o++){var l=a(s[o]),u=a(c[o]),d=0===o?e.equateStringsCaseInsensitive:r;if(!d(l,u))break}if(0===o)return c;for(var p=c.slice(o),f=[];o<s.length;o++)f.push("..");return i(i([""],f),p)}function Y(n,t,r){e.Debug.assert(h(n)>0===h(t)>0,"Paths must either both be absolute or both be relative");var a="function"===typeof r?r:e.identity,i="boolean"===typeof r&&r,o=X(n,t,i?e.equateStringsCaseInsensitive:e.equateStringsCaseSensitive,a);return D(o)}function Q(e,n,t){return o(e)?$(n,e,n,t,!1):e}function Z(e,n,t){return U(Y(v(e),n,t))}function $(n,t,r,a,i){var s=X(N(r,n),N(r,t),e.equateStringsCaseSensitive,a),c=s[0];if(i&&o(c)){var l=c.charAt(0)===e.directorySeparator?"file://":"file:///";s[0]=l+c}return D(s)}function ee(e,n){while(1){var t=n(e);if(void 0!==t)return t;var r=v(e);if(r===e)return;e=r}}function ne(n){return e.endsWith(n,"/node_modules")}e.comparePathsCaseSensitive=H,e.comparePathsCaseInsensitive=W,e.comparePaths=z,e.containsPath=q,e.startsWithDirectory=J,e.getPathComponentsRelativeTo=X,e.getRelativePathFromDirectory=Y,e.convertToRelativePath=Q,e.getRelativePathFromFile=Z,e.getRelativePathToDirectoryOrUrl=$,e.forEachAncestorDirectory=ee,e.isNodeModulesDirectory=ne}(d||(d={})),function(n){function t(e){for(var n=5381,t=0;t<e.length;t++)n=(n<<5)+n+e.charCodeAt(t);return n.toString()}function r(){Error.stackTraceLimit<100&&(Error.stackTraceLimit=100)}var a,i;function s(e,t){return e.getModifiedTime(t)||n.missingFileModifiedTime}function c(e){var n;return n={},n[i.Low]=e.Low,n[i.Medium]=e.Medium,n[i.High]=e.High,n}n.generateDjb2Hash=t,n.setStackTraceLimit=r,function(e){e[e["Created"]=0]="Created",e[e["Changed"]=1]="Changed",e[e["Deleted"]=2]="Deleted"}(a=n.FileWatcherEventKind||(n.FileWatcherEventKind={})),function(e){e[e["High"]=2e3]="High",e[e["Medium"]=500]="Medium",e[e["Low"]=250]="Low"}(i=n.PollingInterval||(n.PollingInterval={})),n.missingFileModifiedTime=new Date(0),n.getModifiedTime=s;var l={Low:32,Medium:64,High:256},u=c(l);function d(e){if(e.getEnvironmentVariable){var t=s("TSC_WATCH_POLLINGINTERVAL",i);u=d("TSC_WATCH_POLLINGCHUNKSIZE",l)||u,n.unchangedPollThresholds=d("TSC_WATCH_UNCHANGEDPOLLTHRESHOLDS",l)||n.unchangedPollThresholds}function r(n,t){return e.getEnvironmentVariable(n+"_"+t.toUpperCase())}function a(e){var n;return t("Low"),t("Medium"),t("High"),n;function t(t){var a=r(e,t);a&&((n||(n={}))[t]=Number(a))}}function s(e,n){var t=a(e);return!!t&&(r("Low"),r("Medium"),r("High"),!0);function r(e){n[e]=t[e]||n[e]}}function d(e,n){var r=a(e);return(t||r)&&c(r?o(o({},n),r):n)}}function p(e,n,t,r,a){for(var i=t,o=n.length;r&&o;u(),o--){var c=n[t];if(c)if(c.isClosed)n[t]=void 0;else{r--;var l=y(c,s(e,c.fileName));c.isClosed?n[t]=void 0:(null===a||void 0===a||a(c,t,l),n[t]&&(i<t&&(n[i]=c,n[t]=void 0),i++))}}return t;function u(){t++,t===n.length&&(i<t&&(n.length=i),t=0,i=0)}}function f(e){var t=[],r=[],a=d(i.Low),o=d(i.Medium),c=d(i.High);return l;function l(r,a,i){var o={fileName:r,callback:a,unchangedPolls:0,mtime:s(e,r)};return t.push(o),y(o,i),{close:function(){o.isClosed=!0,n.unorderedRemoveItem(t,o)}}}function d(e){var n=[];return n.pollingInterval=e,n.pollIndex=0,n.pollScheduled=!1,n}function f(e){e.pollIndex=_(e,e.pollingInterval,e.pollIndex,u[e.pollingInterval]),e.length?b(e.pollingInterval):(n.Debug.assert(0===e.pollIndex),e.pollScheduled=!1)}function m(e){_(r,i.Low,0,r.length),f(e),!e.pollScheduled&&r.length&&b(i.Low)}function _(t,a,o,s){return p(e,t,o,s,c);function c(e,o,s){s?(e.unchangedPolls=0,t!==r&&(t[o]=void 0,h(e))):e.unchangedPolls!==n.unchangedPollThresholds[a]?e.unchangedPolls++:t===r?(e.unchangedPolls=1,t[o]=void 0,y(e,i.Low)):a!==i.High&&(e.unchangedPolls++,t[o]=void 0,y(e,a===i.Low?i.Medium:i.High))}}function g(e){switch(e){case i.Low:return a;case i.Medium:return o;case i.High:return c}}function y(e,n){g(n).push(e),v(n)}function h(e){r.push(e),v(i.Low)}function v(e){g(e).pollScheduled||b(e)}function b(n){g(n).pollScheduled=e.setTimeout(n===i.Low?m:f,n,g(n))}}function m(e,t){var r=n.createMultiMap(),o=new n.Map,s=n.createGetCanonicalFileName(t);return c;function c(e,t,a,i){var c=s(e);r.add(c,t);var u=n.getDirectoryPath(c)||".",d=o.get(u)||l(n.getDirectoryPath(e)||".",u,i);return d.referenceCount++,{close:function(){1===d.referenceCount?(d.close(),o.delete(u)):d.referenceCount--,r.remove(c,t)}}}function l(t,c,l){var u=e(t,1,(function(e,i){if(n.isString(i)){var o=n.getNormalizedAbsolutePath(i,t),c=o&&r.get(s(o));if(c)for(var l=0,u=c;l<u.length;l++){var d=u[l];d(o,a.Changed)}}}),!1,i.Medium,l);return u.referenceCount=0,o.set(c,u),u}}function _(e){var t,r=[],a=0;return o;function o(t,a){var i={fileName:t,callback:a,mtime:s(e,t)};return r.push(i),l(),{close:function(){i.isClosed=!0,n.unorderedRemoveItem(r,i)}}}function c(){t=void 0,a=p(e,r,a,u[i.Low]),l()}function l(){r.length&&!t&&(t=e.setTimeout(c,i.High))}}function g(e,t){var r=new n.Map,a=n.createMultiMap(),i=n.createGetCanonicalFileName(t);return function(t,o,s,c){var l=i(t),u=r.get(l);return u?u.refCount++:r.set(l,{watcher:e(t,(function(e,t){return n.forEach(a.get(l),(function(n){return n(e,t)}))}),s,c),refCount:1}),a.add(l,o),{close:function(){var e=n.Debug.checkDefined(r.get(l));a.remove(l,o),e.refCount--,e.refCount||(r.delete(l),n.closeFileWatcherOf(e))}}}}function y(e,n){var t=e.mtime.getTime(),r=n.getTime();return t!==r&&(e.mtime=n,e.callback(e.fileName,h(t,r)),!0)}function h(e,n){return 0===e?a.Created:0===n?a.Deleted:a.Changed}function v(e){n.sysLog=e}function b(e){var t,r=e.watchDirectory,a=e.useCaseSensitiveFileNames,i=e.getCurrentDirectory,o=e.getAccessibleSortedChildDirectories,s=e.directoryExists,c=e.realpath,l=e.setTimeout,u=e.clearTimeout,d=new n.Map,p=n.createMultiMap(),f=new n.Map,m=n.getStringComparer(!a),_=n.createGetCanonicalFileName(a);return function(e,n,t,a){return t?g(e,a,n):r(e,n,t,a)};function g(e,t,a){var i=_(e),o=d.get(i);o?o.refCount++:(o={watcher:r(e,(function(n){x(n,t)||((null===t||void 0===t?void 0:t.synchronousWatchDirectory)?(y(i,n),T(e,i,t)):h(e,i,n,t))}),!1,t),refCount:1,childWatches:n.emptyArray},d.set(i,o),T(e,i,t));var s=a&&{dirName:e,callback:a};return s&&p.add(i,s),{dirName:e,close:function(){var e=n.Debug.checkDefined(d.get(i));s&&p.remove(i,s),e.refCount--,e.refCount||(d.delete(i),n.closeFileWatcherOf(e),e.childWatches.forEach(n.closeFileWatcher))}}}function y(e,t,r){var a,i;n.isString(t)?a=t:i=t,p.forEach((function(t,o){var s;if((!i||!0!==i.get(o))&&(o===e||n.startsWith(e,o)&&e[o.length]===n.directorySeparator))if(i)if(r){var c=i.get(o);c?(s=c).push.apply(s,r):i.set(o,r.slice())}else i.set(o,!0);else t.forEach((function(e){var n=e.callback;return n(a)}))}))}function h(e,n,t,r){var a=d.get(n);a&&s(e)?v(e,n,t,r):(y(n,t),E(a))}function v(e,n,r,a){var i=f.get(n);i?i.fileNames.push(r):f.set(n,{dirName:e,options:a,fileNames:[r]}),t&&(u(t),t=void 0),t=l(b,1e3)}function b(){t=void 0,n.sysLog("sysLog:: onTimerToUpdateChildWatches:: "+f.size);var e=n.timestamp(),r=new n.Map;while(!t&&f.size){var a=f.entries().next();n.Debug.assert(!a.done);var i=a.value,o=i[0],s=i[1],c=s.dirName,l=s.options,u=s.fileNames;f.delete(o);var d=T(c,o,l);y(o,r,d?void 0:u)}n.sysLog("sysLog:: invokingWatchers:: Elapsed:: "+(n.timestamp()-e)+"ms:: "+f.size),p.forEach((function(e,t){var a=r.get(t);a&&e.forEach((function(e){var t=e.callback,r=e.dirName;n.isArray(a)?a.forEach(t):t(r)}))}));var m=n.timestamp()-e;n.sysLog("sysLog:: Elapsed:: "+m+"ms:: onTimerToUpdateChildWatches:: "+f.size+" "+t)}function E(e){if(e){var t=e.childWatches;e.childWatches=n.emptyArray;for(var r=0,a=t;r<a.length;r++){var i=a[r];i.close(),E(d.get(_(i.dirName)))}}}function T(e,t,r){var a,i=d.get(t);if(!i)return!1;var l=n.enumerateInsertsAndDeletes(s(e)?n.mapDefined(o(e),(function(t){var a=n.getNormalizedAbsolutePath(t,e);return x(a,r)||0!==m(a,n.normalizePath(c(a)))?void 0:a})):n.emptyArray,i.childWatches,(function(e,n){return m(e,n.dirName)}),u,n.closeFileWatcher,p);return i.childWatches=a||n.emptyArray,l;function u(e){var n=g(e,r);p(n)}function p(e){(a||(a=[])).push(e)}}function x(e,t){return n.some(n.ignoredPaths,(function(n){return L(e,n)}))||S(e,t,a,i)}function L(e,t){return!!n.stringContains(e,t)||!a&&n.stringContains(_(e),t)}}function E(e){return function(n,t){return e(t===a.Changed?"change":"rename","")}}function T(e,n,t){return function(r){n(e,"rename"===r?t(e)?a.Created:a.Deleted:a.Changed)}}function S(e,t,r,a){return((null===t||void 0===t?void 0:t.excludeDirectories)||(null===t||void 0===t?void 0:t.excludeFiles))&&(n.matchesExclude(e,null===t||void 0===t?void 0:t.excludeFiles,r,a())||n.matchesExclude(e,null===t||void 0===t?void 0:t.excludeDirectories,r,a()))}function x(e,t,r,a,i){return function(o,s){if("rename"===o){var c=s?n.normalizePath(n.combinePaths(e,s)):e;s&&S(c,r,a,i)||t(c)}}}function L(e){var t,r,a,o,s=e.pollingWatchFile,c=e.getModifiedTime,l=e.setTimeout,u=e.clearTimeout,d=e.fsWatch,p=e.fileExists,g=e.useCaseSensitiveFileNames,y=e.getCurrentDirectory,h=e.fsSupportsRecursiveFsWatch,v=e.directoryExists,E=e.getAccessibleSortedChildDirectories,S=e.realpath,L=e.tscWatchFile,D=e.useNonPollingWatchers,A=e.tscWatchDirectory,C=e.defaultWatchFileKind;return{watchFile:I,watchDirectory:w};function I(e,t,r,o){o=R(o,D);var c=n.Debug.checkDefined(o.watchFile);switch(c){case n.WatchFileKind.FixedPollingInterval:return s(e,t,i.Low,void 0);case n.WatchFileKind.PriorityPollingInterval:return s(e,t,r,void 0);case n.WatchFileKind.DynamicPriorityPolling:return N()(e,t,r,void 0);case n.WatchFileKind.FixedChunkSizePolling:return k()(e,t,void 0,void 0);case n.WatchFileKind.UseFsEvents:return d(e,0,T(e,t,p),!1,r,n.getFallbackOptions(o));case n.WatchFileKind.UseFsEventsOnParentDirectory:return a||(a=m(d,g)),a(e,t,r,n.getFallbackOptions(o));default:n.Debug.assertNever(c)}}function N(){return t||(t=f({getModifiedTime:c,setTimeout:l}))}function k(){return r||(r=_({getModifiedTime:c,setTimeout:l}))}function R(e,t){if(e&&void 0!==e.watchFile)return e;switch(L){case"PriorityPollingInterval":return{watchFile:n.WatchFileKind.PriorityPollingInterval};case"DynamicPriorityPolling":return{watchFile:n.WatchFileKind.DynamicPriorityPolling};case"UseFsEvents":return O(n.WatchFileKind.UseFsEvents,n.PollingWatchKind.PriorityInterval,e);case"UseFsEventsWithFallbackDynamicPolling":return O(n.WatchFileKind.UseFsEvents,n.PollingWatchKind.DynamicPriority,e);case"UseFsEventsOnParentDirectory":t=!0;default:return t?O(n.WatchFileKind.UseFsEventsOnParentDirectory,n.PollingWatchKind.PriorityInterval,e):{watchFile:(null===C||void 0===C?void 0:C())||n.WatchFileKind.FixedPollingInterval}}}function O(e,n,t){var r=null===t||void 0===t?void 0:t.fallbackPolling;return{watchFile:e,fallbackPolling:void 0===r?n:r}}function w(e,t,r,a){return h?d(e,1,x(e,t,a,g,y),r,i.Medium,n.getFallbackOptions(a)):(o||(o=b({useCaseSensitiveFileNames:g,getCurrentDirectory:y,directoryExists:v,getAccessibleSortedChildDirectories:E,watchDirectory:P,realpath:S,setTimeout:l,clearTimeout:u})),o(e,t,r,a))}function P(e,t,r,a){n.Debug.assert(!r);var o=M(a),c=n.Debug.checkDefined(o.watchDirectory);switch(c){case n.WatchDirectoryKind.FixedPollingInterval:return s(e,(function(){return t(e)}),i.Medium,void 0);case n.WatchDirectoryKind.DynamicPriorityPolling:return N()(e,(function(){return t(e)}),i.Medium,void 0);case n.WatchDirectoryKind.FixedChunkSizePolling:return k()(e,(function(){return t(e)}),void 0,void 0);case n.WatchDirectoryKind.UseFsEvents:return d(e,1,x(e,t,a,g,y),r,i.Medium,n.getFallbackOptions(o));default:n.Debug.assertNever(c)}}function M(e){if(e&&void 0!==e.watchDirectory)return e;switch(A){case"RecursiveDirectoryUsingFsWatchFile":return{watchDirectory:n.WatchDirectoryKind.FixedPollingInterval};case"RecursiveDirectoryUsingDynamicPriorityPolling":return{watchDirectory:n.WatchDirectoryKind.DynamicPriorityPolling};default:var t=null===e||void 0===e?void 0:e.fallbackPolling;return{watchDirectory:n.WatchDirectoryKind.UseFsEvents,fallbackPolling:void 0!==t?t:void 0}}}}function D(e){var t=e.writeFile;e.writeFile=function(r,a,i){return n.writeFileEnsuringDirectories(r,a,!!i,(function(n,r,a){return t.call(e,n,r,a)}),(function(n){return e.createDirectory(n)}),(function(n){return e.directoryExists(n)}))}}function A(){if("undefined"!==typeof e){var n=e.version;if(n){var t=n.indexOf(".");if(-1!==t)return parseInt(n.substring(1,t))}}}n.unchangedPollThresholds=c(l),n.setCustomPollingValues=d,n.createDynamicPriorityPollingWatchFile=f,n.createSingleFileWatcherPerName=g,n.onWatchedFileStat=y,n.getFileWatcherEventKind=h,n.ignoredPaths=["/node_modules/.","/.git","/.#"],n.sysLog=n.noop,n.setSysLog=v,n.createDirectoryWatcherSupportingRecursive=b,function(e){e[e["File"]=0]="File",e[e["Directory"]=1]="Directory"}(n.FileSystemEntryKind||(n.FileSystemEntryKind={})),n.createFileWatcherCallback=E,n.createSystemWatchFunctions=L,n.patchWriteFileEnsuringDirectory=D,n.getNodeMajorVersion=A,n.sys=void 0,n.sys&&n.sys.getEnvironmentVariable&&(d(n.sys),n.Debug.setAssertionLevel(/^development$/i.test(n.sys.getEnvironmentVariable("NODE_ENV"))?1:0)),n.sys&&n.sys.debugMode&&(n.Debug.isDebugging=!0)}(d||(d={})),function(e){function n(e,n,t,r,a,i,o){return{code:e,category:n,key:t,message:r,reportsUnnecessary:a,elidedInCompatabilityPyramid:i,reportsDeprecated:o}}e.Diagnostics={Unterminated_string_literal:n(1002,e.DiagnosticCategory.Error,"Unterminated_string_literal_1002","Unterminated string literal."),Identifier_expected:n(1003,e.DiagnosticCategory.Error,"Identifier_expected_1003","Identifier expected."),_0_expected:n(1005,e.DiagnosticCategory.Error,"_0_expected_1005","'{0}' expected."),A_file_cannot_have_a_reference_to_itself:n(1006,e.DiagnosticCategory.Error,"A_file_cannot_have_a_reference_to_itself_1006","A file cannot have a reference to itself."),The_parser_expected_to_find_a_to_match_the_token_here:n(1007,e.DiagnosticCategory.Error,"The_parser_expected_to_find_a_to_match_the_token_here_1007","The parser expected to find a '}' to match the '{' token here."),Trailing_comma_not_allowed:n(1009,e.DiagnosticCategory.Error,"Trailing_comma_not_allowed_1009","Trailing comma not allowed."),Asterisk_Slash_expected:n(1010,e.DiagnosticCategory.Error,"Asterisk_Slash_expected_1010","'*/' expected."),An_element_access_expression_should_take_an_argument:n(1011,e.DiagnosticCategory.Error,"An_element_access_expression_should_take_an_argument_1011","An element access expression should take an argument."),Unexpected_token:n(1012,e.DiagnosticCategory.Error,"Unexpected_token_1012","Unexpected token."),A_rest_parameter_or_binding_pattern_may_not_have_a_trailing_comma:n(1013,e.DiagnosticCategory.Error,"A_rest_parameter_or_binding_pattern_may_not_have_a_trailing_comma_1013","A rest parameter or binding pattern may not have a trailing comma."),A_rest_parameter_must_be_last_in_a_parameter_list:n(1014,e.DiagnosticCategory.Error,"A_rest_parameter_must_be_last_in_a_parameter_list_1014","A rest parameter must be last in a parameter list."),Parameter_cannot_have_question_mark_and_initializer:n(1015,e.DiagnosticCategory.Error,"Parameter_cannot_have_question_mark_and_initializer_1015","Parameter cannot have question mark and initializer."),A_required_parameter_cannot_follow_an_optional_parameter:n(1016,e.DiagnosticCategory.Error,"A_required_parameter_cannot_follow_an_optional_parameter_1016","A required parameter cannot follow an optional parameter."),An_index_signature_cannot_have_a_rest_parameter:n(1017,e.DiagnosticCategory.Error,"An_index_signature_cannot_have_a_rest_parameter_1017","An index signature cannot have a rest parameter."),An_index_signature_parameter_cannot_have_an_accessibility_modifier:n(1018,e.DiagnosticCategory.Error,"An_index_signature_parameter_cannot_have_an_accessibility_modifier_1018","An index signature parameter cannot have an accessibility modifier."),An_index_signature_parameter_cannot_have_a_question_mark:n(1019,e.DiagnosticCategory.Error,"An_index_signature_parameter_cannot_have_a_question_mark_1019","An index signature parameter cannot have a question mark."),An_index_signature_parameter_cannot_have_an_initializer:n(1020,e.DiagnosticCategory.Error,"An_index_signature_parameter_cannot_have_an_initializer_1020","An index signature parameter cannot have an initializer."),An_index_signature_must_have_a_type_annotation:n(1021,e.DiagnosticCategory.Error,"An_index_signature_must_have_a_type_annotation_1021","An index signature must have a type annotation."),An_index_signature_parameter_must_have_a_type_annotation:n(1022,e.DiagnosticCategory.Error,"An_index_signature_parameter_must_have_a_type_annotation_1022","An index signature parameter must have a type annotation."),An_index_signature_parameter_type_must_be_either_string_or_number:n(1023,e.DiagnosticCategory.Error,"An_index_signature_parameter_type_must_be_either_string_or_number_1023","An index signature parameter type must be either 'string' or 'number'."),readonly_modifier_can_only_appear_on_a_property_declaration_or_index_signature:n(1024,e.DiagnosticCategory.Error,"readonly_modifier_can_only_appear_on_a_property_declaration_or_index_signature_1024","'readonly' modifier can only appear on a property declaration or index signature."),An_index_signature_cannot_have_a_trailing_comma:n(1025,e.DiagnosticCategory.Error,"An_index_signature_cannot_have_a_trailing_comma_1025","An index signature cannot have a trailing comma."),Accessibility_modifier_already_seen:n(1028,e.DiagnosticCategory.Error,"Accessibility_modifier_already_seen_1028","Accessibility modifier already seen."),_0_modifier_must_precede_1_modifier:n(1029,e.DiagnosticCategory.Error,"_0_modifier_must_precede_1_modifier_1029","'{0}' modifier must precede '{1}' modifier."),_0_modifier_already_seen:n(1030,e.DiagnosticCategory.Error,"_0_modifier_already_seen_1030","'{0}' modifier already seen."),_0_modifier_cannot_appear_on_class_elements_of_this_kind:n(1031,e.DiagnosticCategory.Error,"_0_modifier_cannot_appear_on_class_elements_of_this_kind_1031","'{0}' modifier cannot appear on class elements of this kind."),super_must_be_followed_by_an_argument_list_or_member_access:n(1034,e.DiagnosticCategory.Error,"super_must_be_followed_by_an_argument_list_or_member_access_1034","'super' must be followed by an argument list or member access."),Only_ambient_modules_can_use_quoted_names:n(1035,e.DiagnosticCategory.Error,"Only_ambient_modules_can_use_quoted_names_1035","Only ambient modules can use quoted names."),Statements_are_not_allowed_in_ambient_contexts:n(1036,e.DiagnosticCategory.Error,"Statements_are_not_allowed_in_ambient_contexts_1036","Statements are not allowed in ambient contexts."),A_declare_modifier_cannot_be_used_in_an_already_ambient_context:n(1038,e.DiagnosticCategory.Error,"A_declare_modifier_cannot_be_used_in_an_already_ambient_context_1038","A 'declare' modifier cannot be used in an already ambient context."),Initializers_are_not_allowed_in_ambient_contexts:n(1039,e.DiagnosticCategory.Error,"Initializers_are_not_allowed_in_ambient_contexts_1039","Initializers are not allowed in ambient contexts."),_0_modifier_cannot_be_used_in_an_ambient_context:n(1040,e.DiagnosticCategory.Error,"_0_modifier_cannot_be_used_in_an_ambient_context_1040","'{0}' modifier cannot be used in an ambient context."),_0_modifier_cannot_be_used_with_a_class_declaration:n(1041,e.DiagnosticCategory.Error,"_0_modifier_cannot_be_used_with_a_class_declaration_1041","'{0}' modifier cannot be used with a class declaration."),_0_modifier_cannot_be_used_here:n(1042,e.DiagnosticCategory.Error,"_0_modifier_cannot_be_used_here_1042","'{0}' modifier cannot be used here."),_0_modifier_cannot_appear_on_a_data_property:n(1043,e.DiagnosticCategory.Error,"_0_modifier_cannot_appear_on_a_data_property_1043","'{0}' modifier cannot appear on a data property."),_0_modifier_cannot_appear_on_a_module_or_namespace_element:n(1044,e.DiagnosticCategory.Error,"_0_modifier_cannot_appear_on_a_module_or_namespace_element_1044","'{0}' modifier cannot appear on a module or namespace element."),A_0_modifier_cannot_be_used_with_an_interface_declaration:n(1045,e.DiagnosticCategory.Error,"A_0_modifier_cannot_be_used_with_an_interface_declaration_1045","A '{0}' modifier cannot be used with an interface declaration."),Top_level_declarations_in_d_ts_files_must_start_with_either_a_declare_or_export_modifier:n(1046,e.DiagnosticCategory.Error,"Top_level_declarations_in_d_ts_files_must_start_with_either_a_declare_or_export_modifier_1046","Top-level declarations in .d.ts files must start with either a 'declare' or 'export' modifier."),A_rest_parameter_cannot_be_optional:n(1047,e.DiagnosticCategory.Error,"A_rest_parameter_cannot_be_optional_1047","A rest parameter cannot be optional."),A_rest_parameter_cannot_have_an_initializer:n(1048,e.DiagnosticCategory.Error,"A_rest_parameter_cannot_have_an_initializer_1048","A rest parameter cannot have an initializer."),A_set_accessor_must_have_exactly_one_parameter:n(1049,e.DiagnosticCategory.Error,"A_set_accessor_must_have_exactly_one_parameter_1049","A 'set' accessor must have exactly one parameter."),A_set_accessor_cannot_have_an_optional_parameter:n(1051,e.DiagnosticCategory.Error,"A_set_accessor_cannot_have_an_optional_parameter_1051","A 'set' accessor cannot have an optional parameter."),A_set_accessor_parameter_cannot_have_an_initializer:n(1052,e.DiagnosticCategory.Error,"A_set_accessor_parameter_cannot_have_an_initializer_1052","A 'set' accessor parameter cannot have an initializer."),A_set_accessor_cannot_have_rest_parameter:n(1053,e.DiagnosticCategory.Error,"A_set_accessor_cannot_have_rest_parameter_1053","A 'set' accessor cannot have rest parameter."),A_get_accessor_cannot_have_parameters:n(1054,e.DiagnosticCategory.Error,"A_get_accessor_cannot_have_parameters_1054","A 'get' accessor cannot have parameters."),Type_0_is_not_a_valid_async_function_return_type_in_ES5_SlashES3_because_it_does_not_refer_to_a_Promise_compatible_constructor_value:n(1055,e.DiagnosticCategory.Error,"Type_0_is_not_a_valid_async_function_return_type_in_ES5_SlashES3_because_it_does_not_refer_to_a_Prom_1055","Type '{0}' is not a valid async function return type in ES5/ES3 because it does not refer to a Promise-compatible constructor value."),Accessors_are_only_available_when_targeting_ECMAScript_5_and_higher:n(1056,e.DiagnosticCategory.Error,"Accessors_are_only_available_when_targeting_ECMAScript_5_and_higher_1056","Accessors are only available when targeting ECMAScript 5 and higher."),An_async_function_or_method_must_have_a_valid_awaitable_return_type:n(1057,e.DiagnosticCategory.Error,"An_async_function_or_method_must_have_a_valid_awaitable_return_type_1057","An async function or method must have a valid awaitable return type."),The_return_type_of_an_async_function_must_either_be_a_valid_promise_or_must_not_contain_a_callable_then_member:n(1058,e.DiagnosticCategory.Error,"The_return_type_of_an_async_function_must_either_be_a_valid_promise_or_must_not_contain_a_callable_t_1058","The return type of an async function must either be a valid promise or must not contain a callable 'then' member."),A_promise_must_have_a_then_method:n(1059,e.DiagnosticCategory.Error,"A_promise_must_have_a_then_method_1059","A promise must have a 'then' method."),The_first_parameter_of_the_then_method_of_a_promise_must_be_a_callback:n(1060,e.DiagnosticCategory.Error,"The_first_parameter_of_the_then_method_of_a_promise_must_be_a_callback_1060","The first parameter of the 'then' method of a promise must be a callback."),Enum_member_must_have_initializer:n(1061,e.DiagnosticCategory.Error,"Enum_member_must_have_initializer_1061","Enum member must have initializer."),Type_is_referenced_directly_or_indirectly_in_the_fulfillment_callback_of_its_own_then_method:n(1062,e.DiagnosticCategory.Error,"Type_is_referenced_directly_or_indirectly_in_the_fulfillment_callback_of_its_own_then_method_1062","Type is referenced directly or indirectly in the fulfillment callback of its own 'then' method."),An_export_assignment_cannot_be_used_in_a_namespace:n(1063,e.DiagnosticCategory.Error,"An_export_assignment_cannot_be_used_in_a_namespace_1063","An export assignment cannot be used in a namespace."),The_return_type_of_an_async_function_or_method_must_be_the_global_Promise_T_type_Did_you_mean_to_write_Promise_0:n(1064,e.DiagnosticCategory.Error,"The_return_type_of_an_async_function_or_method_must_be_the_global_Promise_T_type_Did_you_mean_to_wri_1064","The return type of an async function or method must be the global Promise<T> type. Did you mean to write 'Promise<{0}>'?"),In_ambient_enum_declarations_member_initializer_must_be_constant_expression:n(1066,e.DiagnosticCategory.Error,"In_ambient_enum_declarations_member_initializer_must_be_constant_expression_1066","In ambient enum declarations member initializer must be constant expression."),Unexpected_token_A_constructor_method_accessor_or_property_was_expected:n(1068,e.DiagnosticCategory.Error,"Unexpected_token_A_constructor_method_accessor_or_property_was_expected_1068","Unexpected token. A constructor, method, accessor, or property was expected."),Unexpected_token_A_type_parameter_name_was_expected_without_curly_braces:n(1069,e.DiagnosticCategory.Error,"Unexpected_token_A_type_parameter_name_was_expected_without_curly_braces_1069","Unexpected token. A type parameter name was expected without curly braces."),_0_modifier_cannot_appear_on_a_type_member:n(1070,e.DiagnosticCategory.Error,"_0_modifier_cannot_appear_on_a_type_member_1070","'{0}' modifier cannot appear on a type member."),_0_modifier_cannot_appear_on_an_index_signature:n(1071,e.DiagnosticCategory.Error,"_0_modifier_cannot_appear_on_an_index_signature_1071","'{0}' modifier cannot appear on an index signature."),A_0_modifier_cannot_be_used_with_an_import_declaration:n(1079,e.DiagnosticCategory.Error,"A_0_modifier_cannot_be_used_with_an_import_declaration_1079","A '{0}' modifier cannot be used with an import declaration."),Invalid_reference_directive_syntax:n(1084,e.DiagnosticCategory.Error,"Invalid_reference_directive_syntax_1084","Invalid 'reference' directive syntax."),Octal_literals_are_not_available_when_targeting_ECMAScript_5_and_higher_Use_the_syntax_0:n(1085,e.DiagnosticCategory.Error,"Octal_literals_are_not_available_when_targeting_ECMAScript_5_and_higher_Use_the_syntax_0_1085","Octal literals are not available when targeting ECMAScript 5 and higher. Use the syntax '{0}'."),_0_modifier_cannot_appear_on_a_constructor_declaration:n(1089,e.DiagnosticCategory.Error,"_0_modifier_cannot_appear_on_a_constructor_declaration_1089","'{0}' modifier cannot appear on a constructor declaration."),_0_modifier_cannot_appear_on_a_parameter:n(1090,e.DiagnosticCategory.Error,"_0_modifier_cannot_appear_on_a_parameter_1090","'{0}' modifier cannot appear on a parameter."),Only_a_single_variable_declaration_is_allowed_in_a_for_in_statement:n(1091,e.DiagnosticCategory.Error,"Only_a_single_variable_declaration_is_allowed_in_a_for_in_statement_1091","Only a single variable declaration is allowed in a 'for...in' statement."),Type_parameters_cannot_appear_on_a_constructor_declaration:n(1092,e.DiagnosticCategory.Error,"Type_parameters_cannot_appear_on_a_constructor_declaration_1092","Type parameters cannot appear on a constructor declaration."),Type_annotation_cannot_appear_on_a_constructor_declaration:n(1093,e.DiagnosticCategory.Error,"Type_annotation_cannot_appear_on_a_constructor_declaration_1093","Type annotation cannot appear on a constructor declaration."),An_accessor_cannot_have_type_parameters:n(1094,e.DiagnosticCategory.Error,"An_accessor_cannot_have_type_parameters_1094","An accessor cannot have type parameters."),A_set_accessor_cannot_have_a_return_type_annotation:n(1095,e.DiagnosticCategory.Error,"A_set_accessor_cannot_have_a_return_type_annotation_1095","A 'set' accessor cannot have a return type annotation."),An_index_signature_must_have_exactly_one_parameter:n(1096,e.DiagnosticCategory.Error,"An_index_signature_must_have_exactly_one_parameter_1096","An index signature must have exactly one parameter."),_0_list_cannot_be_empty:n(1097,e.DiagnosticCategory.Error,"_0_list_cannot_be_empty_1097","'{0}' list cannot be empty."),Type_parameter_list_cannot_be_empty:n(1098,e.DiagnosticCategory.Error,"Type_parameter_list_cannot_be_empty_1098","Type parameter list cannot be empty."),Type_argument_list_cannot_be_empty:n(1099,e.DiagnosticCategory.Error,"Type_argument_list_cannot_be_empty_1099","Type argument list cannot be empty."),Invalid_use_of_0_in_strict_mode:n(1100,e.DiagnosticCategory.Error,"Invalid_use_of_0_in_strict_mode_1100","Invalid use of '{0}' in strict mode."),with_statements_are_not_allowed_in_strict_mode:n(1101,e.DiagnosticCategory.Error,"with_statements_are_not_allowed_in_strict_mode_1101","'with' statements are not allowed in strict mode."),delete_cannot_be_called_on_an_identifier_in_strict_mode:n(1102,e.DiagnosticCategory.Error,"delete_cannot_be_called_on_an_identifier_in_strict_mode_1102","'delete' cannot be called on an identifier in strict mode."),for_await_loops_are_only_allowed_within_async_functions_and_at_the_top_levels_of_modules:n(1103,e.DiagnosticCategory.Error,"for_await_loops_are_only_allowed_within_async_functions_and_at_the_top_levels_of_modules_1103","'for await' loops are only allowed within async functions and at the top levels of modules."),A_continue_statement_can_only_be_used_within_an_enclosing_iteration_statement:n(1104,e.DiagnosticCategory.Error,"A_continue_statement_can_only_be_used_within_an_enclosing_iteration_statement_1104","A 'continue' statement can only be used within an enclosing iteration statement."),A_break_statement_can_only_be_used_within_an_enclosing_iteration_or_switch_statement:n(1105,e.DiagnosticCategory.Error,"A_break_statement_can_only_be_used_within_an_enclosing_iteration_or_switch_statement_1105","A 'break' statement can only be used within an enclosing iteration or switch statement."),Jump_target_cannot_cross_function_boundary:n(1107,e.DiagnosticCategory.Error,"Jump_target_cannot_cross_function_boundary_1107","Jump target cannot cross function boundary."),A_return_statement_can_only_be_used_within_a_function_body:n(1108,e.DiagnosticCategory.Error,"A_return_statement_can_only_be_used_within_a_function_body_1108","A 'return' statement can only be used within a function body."),Expression_expected:n(1109,e.DiagnosticCategory.Error,"Expression_expected_1109","Expression expected."),Type_expected:n(1110,e.DiagnosticCategory.Error,"Type_expected_1110","Type expected."),A_default_clause_cannot_appear_more_than_once_in_a_switch_statement:n(1113,e.DiagnosticCategory.Error,"A_default_clause_cannot_appear_more_than_once_in_a_switch_statement_1113","A 'default' clause cannot appear more than once in a 'switch' statement."),Duplicate_label_0:n(1114,e.DiagnosticCategory.Error,"Duplicate_label_0_1114","Duplicate label '{0}'."),A_continue_statement_can_only_jump_to_a_label_of_an_enclosing_iteration_statement:n(1115,e.DiagnosticCategory.Error,"A_continue_statement_can_only_jump_to_a_label_of_an_enclosing_iteration_statement_1115","A 'continue' statement can only jump to a label of an enclosing iteration statement."),A_break_statement_can_only_jump_to_a_label_of_an_enclosing_statement:n(1116,e.DiagnosticCategory.Error,"A_break_statement_can_only_jump_to_a_label_of_an_enclosing_statement_1116","A 'break' statement can only jump to a label of an enclosing statement."),An_object_literal_cannot_have_multiple_properties_with_the_same_name_in_strict_mode:n(1117,e.DiagnosticCategory.Error,"An_object_literal_cannot_have_multiple_properties_with_the_same_name_in_strict_mode_1117","An object literal cannot have multiple properties with the same name in strict mode."),An_object_literal_cannot_have_multiple_get_Slashset_accessors_with_the_same_name:n(1118,e.DiagnosticCategory.Error,"An_object_literal_cannot_have_multiple_get_Slashset_accessors_with_the_same_name_1118","An object literal cannot have multiple get/set accessors with the same name."),An_object_literal_cannot_have_property_and_accessor_with_the_same_name:n(1119,e.DiagnosticCategory.Error,"An_object_literal_cannot_have_property_and_accessor_with_the_same_name_1119","An object literal cannot have property and accessor with the same name."),An_export_assignment_cannot_have_modifiers:n(1120,e.DiagnosticCategory.Error,"An_export_assignment_cannot_have_modifiers_1120","An export assignment cannot have modifiers."),Octal_literals_are_not_allowed_in_strict_mode:n(1121,e.DiagnosticCategory.Error,"Octal_literals_are_not_allowed_in_strict_mode_1121","Octal literals are not allowed in strict mode."),Variable_declaration_list_cannot_be_empty:n(1123,e.DiagnosticCategory.Error,"Variable_declaration_list_cannot_be_empty_1123","Variable declaration list cannot be empty."),Digit_expected:n(1124,e.DiagnosticCategory.Error,"Digit_expected_1124","Digit expected."),Hexadecimal_digit_expected:n(1125,e.DiagnosticCategory.Error,"Hexadecimal_digit_expected_1125","Hexadecimal digit expected."),Unexpected_end_of_text:n(1126,e.DiagnosticCategory.Error,"Unexpected_end_of_text_1126","Unexpected end of text."),Invalid_character:n(1127,e.DiagnosticCategory.Error,"Invalid_character_1127","Invalid character."),Declaration_or_statement_expected:n(1128,e.DiagnosticCategory.Error,"Declaration_or_statement_expected_1128","Declaration or statement expected."),Statement_expected:n(1129,e.DiagnosticCategory.Error,"Statement_expected_1129","Statement expected."),case_or_default_expected:n(1130,e.DiagnosticCategory.Error,"case_or_default_expected_1130","'case' or 'default' expected."),Property_or_signature_expected:n(1131,e.DiagnosticCategory.Error,"Property_or_signature_expected_1131","Property or signature expected."),Enum_member_expected:n(1132,e.DiagnosticCategory.Error,"Enum_member_expected_1132","Enum member expected."),Variable_declaration_expected:n(1134,e.DiagnosticCategory.Error,"Variable_declaration_expected_1134","Variable declaration expected."),Argument_expression_expected:n(1135,e.DiagnosticCategory.Error,"Argument_expression_expected_1135","Argument expression expected."),Property_assignment_expected:n(1136,e.DiagnosticCategory.Error,"Property_assignment_expected_1136","Property assignment expected."),Expression_or_comma_expected:n(1137,e.DiagnosticCategory.Error,"Expression_or_comma_expected_1137","Expression or comma expected."),Parameter_declaration_expected:n(1138,e.DiagnosticCategory.Error,"Parameter_declaration_expected_1138","Parameter declaration expected."),Type_parameter_declaration_expected:n(1139,e.DiagnosticCategory.Error,"Type_parameter_declaration_expected_1139","Type parameter declaration expected."),Type_argument_expected:n(1140,e.DiagnosticCategory.Error,"Type_argument_expected_1140","Type argument expected."),String_literal_expected:n(1141,e.DiagnosticCategory.Error,"String_literal_expected_1141","String literal expected."),Line_break_not_permitted_here:n(1142,e.DiagnosticCategory.Error,"Line_break_not_permitted_here_1142","Line break not permitted here."),or_expected:n(1144,e.DiagnosticCategory.Error,"or_expected_1144","'{' or ';' expected."),Declaration_expected:n(1146,e.DiagnosticCategory.Error,"Declaration_expected_1146","Declaration expected."),Import_declarations_in_a_namespace_cannot_reference_a_module:n(1147,e.DiagnosticCategory.Error,"Import_declarations_in_a_namespace_cannot_reference_a_module_1147","Import declarations in a namespace cannot reference a module."),Cannot_use_imports_exports_or_module_augmentations_when_module_is_none:n(1148,e.DiagnosticCategory.Error,"Cannot_use_imports_exports_or_module_augmentations_when_module_is_none_1148","Cannot use imports, exports, or module augmentations when '--module' is 'none'."),File_name_0_differs_from_already_included_file_name_1_only_in_casing:n(1149,e.DiagnosticCategory.Error,"File_name_0_differs_from_already_included_file_name_1_only_in_casing_1149","File name '{0}' differs from already included file name '{1}' only in casing."),const_declarations_must_be_initialized:n(1155,e.DiagnosticCategory.Error,"const_declarations_must_be_initialized_1155","'const' declarations must be initialized."),const_declarations_can_only_be_declared_inside_a_block:n(1156,e.DiagnosticCategory.Error,"const_declarations_can_only_be_declared_inside_a_block_1156","'const' declarations can only be declared inside a block."),let_declarations_can_only_be_declared_inside_a_block:n(1157,e.DiagnosticCategory.Error,"let_declarations_can_only_be_declared_inside_a_block_1157","'let' declarations can only be declared inside a block."),Unterminated_template_literal:n(1160,e.DiagnosticCategory.Error,"Unterminated_template_literal_1160","Unterminated template literal."),Unterminated_regular_expression_literal:n(1161,e.DiagnosticCategory.Error,"Unterminated_regular_expression_literal_1161","Unterminated regular expression literal."),An_object_member_cannot_be_declared_optional:n(1162,e.DiagnosticCategory.Error,"An_object_member_cannot_be_declared_optional_1162","An object member cannot be declared optional."),A_yield_expression_is_only_allowed_in_a_generator_body:n(1163,e.DiagnosticCategory.Error,"A_yield_expression_is_only_allowed_in_a_generator_body_1163","A 'yield' expression is only allowed in a generator body."),Computed_property_names_are_not_allowed_in_enums:n(1164,e.DiagnosticCategory.Error,"Computed_property_names_are_not_allowed_in_enums_1164","Computed property names are not allowed in enums."),A_computed_property_name_in_an_ambient_context_must_refer_to_an_expression_whose_type_is_a_literal_type_or_a_unique_symbol_type:n(1165,e.DiagnosticCategory.Error,"A_computed_property_name_in_an_ambient_context_must_refer_to_an_expression_whose_type_is_a_literal_t_1165","A computed property name in an ambient context must refer to an expression whose type is a literal type or a 'unique symbol' type."),A_computed_property_name_in_a_class_property_declaration_must_have_a_simple_literal_type_or_a_unique_symbol_type:n(1166,e.DiagnosticCategory.Error,"A_computed_property_name_in_a_class_property_declaration_must_have_a_simple_literal_type_or_a_unique_1166","A computed property name in a class property declaration must have a simple literal type or a 'unique symbol' type."),A_computed_property_name_in_a_method_overload_must_refer_to_an_expression_whose_type_is_a_literal_type_or_a_unique_symbol_type:n(1168,e.DiagnosticCategory.Error,"A_computed_property_name_in_a_method_overload_must_refer_to_an_expression_whose_type_is_a_literal_ty_1168","A computed property name in a method overload must refer to an expression whose type is a literal type or a 'unique symbol' type."),A_computed_property_name_in_an_interface_must_refer_to_an_expression_whose_type_is_a_literal_type_or_a_unique_symbol_type:n(1169,e.DiagnosticCategory.Error,"A_computed_property_name_in_an_interface_must_refer_to_an_expression_whose_type_is_a_literal_type_or_1169","A computed property name in an interface must refer to an expression whose type is a literal type or a 'unique symbol' type."),A_computed_property_name_in_a_type_literal_must_refer_to_an_expression_whose_type_is_a_literal_type_or_a_unique_symbol_type:n(1170,e.DiagnosticCategory.Error,"A_computed_property_name_in_a_type_literal_must_refer_to_an_expression_whose_type_is_a_literal_type__1170","A computed property name in a type literal must refer to an expression whose type is a literal type or a 'unique symbol' type."),A_comma_expression_is_not_allowed_in_a_computed_property_name:n(1171,e.DiagnosticCategory.Error,"A_comma_expression_is_not_allowed_in_a_computed_property_name_1171","A comma expression is not allowed in a computed property name."),extends_clause_already_seen:n(1172,e.DiagnosticCategory.Error,"extends_clause_already_seen_1172","'extends' clause already seen."),extends_clause_must_precede_implements_clause:n(1173,e.DiagnosticCategory.Error,"extends_clause_must_precede_implements_clause_1173","'extends' clause must precede 'implements' clause."),Classes_can_only_extend_a_single_class:n(1174,e.DiagnosticCategory.Error,"Classes_can_only_extend_a_single_class_1174","Classes can only extend a single class."),implements_clause_already_seen:n(1175,e.DiagnosticCategory.Error,"implements_clause_already_seen_1175","'implements' clause already seen."),Interface_declaration_cannot_have_implements_clause:n(1176,e.DiagnosticCategory.Error,"Interface_declaration_cannot_have_implements_clause_1176","Interface declaration cannot have 'implements' clause."),Binary_digit_expected:n(1177,e.DiagnosticCategory.Error,"Binary_digit_expected_1177","Binary digit expected."),Octal_digit_expected:n(1178,e.DiagnosticCategory.Error,"Octal_digit_expected_1178","Octal digit expected."),Unexpected_token_expected:n(1179,e.DiagnosticCategory.Error,"Unexpected_token_expected_1179","Unexpected token. '{' expected."),Property_destructuring_pattern_expected:n(1180,e.DiagnosticCategory.Error,"Property_destructuring_pattern_expected_1180","Property destructuring pattern expected."),Array_element_destructuring_pattern_expected:n(1181,e.DiagnosticCategory.Error,"Array_element_destructuring_pattern_expected_1181","Array element destructuring pattern expected."),A_destructuring_declaration_must_have_an_initializer:n(1182,e.DiagnosticCategory.Error,"A_destructuring_declaration_must_have_an_initializer_1182","A destructuring declaration must have an initializer."),An_implementation_cannot_be_declared_in_ambient_contexts:n(1183,e.DiagnosticCategory.Error,"An_implementation_cannot_be_declared_in_ambient_contexts_1183","An implementation cannot be declared in ambient contexts."),Modifiers_cannot_appear_here:n(1184,e.DiagnosticCategory.Error,"Modifiers_cannot_appear_here_1184","Modifiers cannot appear here."),Merge_conflict_marker_encountered:n(1185,e.DiagnosticCategory.Error,"Merge_conflict_marker_encountered_1185","Merge conflict marker encountered."),A_rest_element_cannot_have_an_initializer:n(1186,e.DiagnosticCategory.Error,"A_rest_element_cannot_have_an_initializer_1186","A rest element cannot have an initializer."),A_parameter_property_may_not_be_declared_using_a_binding_pattern:n(1187,e.DiagnosticCategory.Error,"A_parameter_property_may_not_be_declared_using_a_binding_pattern_1187","A parameter property may not be declared using a binding pattern."),Only_a_single_variable_declaration_is_allowed_in_a_for_of_statement:n(1188,e.DiagnosticCategory.Error,"Only_a_single_variable_declaration_is_allowed_in_a_for_of_statement_1188","Only a single variable declaration is allowed in a 'for...of' statement."),The_variable_declaration_of_a_for_in_statement_cannot_have_an_initializer:n(1189,e.DiagnosticCategory.Error,"The_variable_declaration_of_a_for_in_statement_cannot_have_an_initializer_1189","The variable declaration of a 'for...in' statement cannot have an initializer."),The_variable_declaration_of_a_for_of_statement_cannot_have_an_initializer:n(1190,e.DiagnosticCategory.Error,"The_variable_declaration_of_a_for_of_statement_cannot_have_an_initializer_1190","The variable declaration of a 'for...of' statement cannot have an initializer."),An_import_declaration_cannot_have_modifiers:n(1191,e.DiagnosticCategory.Error,"An_import_declaration_cannot_have_modifiers_1191","An import declaration cannot have modifiers."),Module_0_has_no_default_export:n(1192,e.DiagnosticCategory.Error,"Module_0_has_no_default_export_1192","Module '{0}' has no default export."),An_export_declaration_cannot_have_modifiers:n(1193,e.DiagnosticCategory.Error,"An_export_declaration_cannot_have_modifiers_1193","An export declaration cannot have modifiers."),Export_declarations_are_not_permitted_in_a_namespace:n(1194,e.DiagnosticCategory.Error,"Export_declarations_are_not_permitted_in_a_namespace_1194","Export declarations are not permitted in a namespace."),export_Asterisk_does_not_re_export_a_default:n(1195,e.DiagnosticCategory.Error,"export_Asterisk_does_not_re_export_a_default_1195","'export *' does not re-export a default."),Catch_clause_variable_type_annotation_must_be_any_or_unknown_if_specified:n(1196,e.DiagnosticCategory.Error,"Catch_clause_variable_type_annotation_must_be_any_or_unknown_if_specified_1196","Catch clause variable type annotation must be 'any' or 'unknown' if specified."),Catch_clause_variable_cannot_have_an_initializer:n(1197,e.DiagnosticCategory.Error,"Catch_clause_variable_cannot_have_an_initializer_1197","Catch clause variable cannot have an initializer."),An_extended_Unicode_escape_value_must_be_between_0x0_and_0x10FFFF_inclusive:n(1198,e.DiagnosticCategory.Error,"An_extended_Unicode_escape_value_must_be_between_0x0_and_0x10FFFF_inclusive_1198","An extended Unicode escape value must be between 0x0 and 0x10FFFF inclusive."),Unterminated_Unicode_escape_sequence:n(1199,e.DiagnosticCategory.Error,"Unterminated_Unicode_escape_sequence_1199","Unterminated Unicode escape sequence."),Line_terminator_not_permitted_before_arrow:n(1200,e.DiagnosticCategory.Error,"Line_terminator_not_permitted_before_arrow_1200","Line terminator not permitted before arrow."),Import_assignment_cannot_be_used_when_targeting_ECMAScript_modules_Consider_using_import_Asterisk_as_ns_from_mod_import_a_from_mod_import_d_from_mod_or_another_module_format_instead:n(1202,e.DiagnosticCategory.Error,"Import_assignment_cannot_be_used_when_targeting_ECMAScript_modules_Consider_using_import_Asterisk_as_1202","Import assignment cannot be used when targeting ECMAScript modules. Consider using 'import * as ns from \"mod\"', 'import {a} from \"mod\"', 'import d from \"mod\"', or another module format instead."),Export_assignment_cannot_be_used_when_targeting_ECMAScript_modules_Consider_using_export_default_or_another_module_format_instead:n(1203,e.DiagnosticCategory.Error,"Export_assignment_cannot_be_used_when_targeting_ECMAScript_modules_Consider_using_export_default_or__1203","Export assignment cannot be used when targeting ECMAScript modules. Consider using 'export default' or another module format instead."),Re_exporting_a_type_when_the_isolatedModules_flag_is_provided_requires_using_export_type:n(1205,e.DiagnosticCategory.Error,"Re_exporting_a_type_when_the_isolatedModules_flag_is_provided_requires_using_export_type_1205","Re-exporting a type when the '--isolatedModules' flag is provided requires using 'export type'."),Decorators_are_not_valid_here:n(1206,e.DiagnosticCategory.Error,"Decorators_are_not_valid_here_1206","Decorators are not valid here."),Decorators_cannot_be_applied_to_multiple_get_Slashset_accessors_of_the_same_name:n(1207,e.DiagnosticCategory.Error,"Decorators_cannot_be_applied_to_multiple_get_Slashset_accessors_of_the_same_name_1207","Decorators cannot be applied to multiple get/set accessors of the same name."),_0_cannot_be_compiled_under_isolatedModules_because_it_is_considered_a_global_script_file_Add_an_import_export_or_an_empty_export_statement_to_make_it_a_module:n(1208,e.DiagnosticCategory.Error,"_0_cannot_be_compiled_under_isolatedModules_because_it_is_considered_a_global_script_file_Add_an_imp_1208","'{0}' cannot be compiled under '--isolatedModules' because it is considered a global script file. Add an import, export, or an empty 'export {}' statement to make it a module."),Invalid_use_of_0_Class_definitions_are_automatically_in_strict_mode:n(1210,e.DiagnosticCategory.Error,"Invalid_use_of_0_Class_definitions_are_automatically_in_strict_mode_1210","Invalid use of '{0}'. Class definitions are automatically in strict mode."),A_class_declaration_without_the_default_modifier_must_have_a_name:n(1211,e.DiagnosticCategory.Error,"A_class_declaration_without_the_default_modifier_must_have_a_name_1211","A class declaration without the 'default' modifier must have a name."),Identifier_expected_0_is_a_reserved_word_in_strict_mode:n(1212,e.DiagnosticCategory.Error,"Identifier_expected_0_is_a_reserved_word_in_strict_mode_1212","Identifier expected. '{0}' is a reserved word in strict mode."),Identifier_expected_0_is_a_reserved_word_in_strict_mode_Class_definitions_are_automatically_in_strict_mode:n(1213,e.DiagnosticCategory.Error,"Identifier_expected_0_is_a_reserved_word_in_strict_mode_Class_definitions_are_automatically_in_stric_1213","Identifier expected. '{0}' is a reserved word in strict mode. Class definitions are automatically in strict mode."),Identifier_expected_0_is_a_reserved_word_in_strict_mode_Modules_are_automatically_in_strict_mode:n(1214,e.DiagnosticCategory.Error,"Identifier_expected_0_is_a_reserved_word_in_strict_mode_Modules_are_automatically_in_strict_mode_1214","Identifier expected. '{0}' is a reserved word in strict mode. Modules are automatically in strict mode."),Invalid_use_of_0_Modules_are_automatically_in_strict_mode:n(1215,e.DiagnosticCategory.Error,"Invalid_use_of_0_Modules_are_automatically_in_strict_mode_1215","Invalid use of '{0}'. Modules are automatically in strict mode."),Identifier_expected_esModule_is_reserved_as_an_exported_marker_when_transforming_ECMAScript_modules:n(1216,e.DiagnosticCategory.Error,"Identifier_expected_esModule_is_reserved_as_an_exported_marker_when_transforming_ECMAScript_modules_1216","Identifier expected. '__esModule' is reserved as an exported marker when transforming ECMAScript modules."),Export_assignment_is_not_supported_when_module_flag_is_system:n(1218,e.DiagnosticCategory.Error,"Export_assignment_is_not_supported_when_module_flag_is_system_1218","Export assignment is not supported when '--module' flag is 'system'."),Experimental_support_for_decorators_is_a_feature_that_is_subject_to_change_in_a_future_release_Set_the_experimentalDecorators_option_in_your_tsconfig_or_jsconfig_to_remove_this_warning:n(1219,e.DiagnosticCategory.Error,"Experimental_support_for_decorators_is_a_feature_that_is_subject_to_change_in_a_future_release_Set_t_1219","Experimental support for decorators is a feature that is subject to change in a future release. Set the 'experimentalDecorators' option in your 'tsconfig' or 'jsconfig' to remove this warning."),Generators_are_only_available_when_targeting_ECMAScript_2015_or_higher:n(1220,e.DiagnosticCategory.Error,"Generators_are_only_available_when_targeting_ECMAScript_2015_or_higher_1220","Generators are only available when targeting ECMAScript 2015 or higher."),Generators_are_not_allowed_in_an_ambient_context:n(1221,e.DiagnosticCategory.Error,"Generators_are_not_allowed_in_an_ambient_context_1221","Generators are not allowed in an ambient context."),An_overload_signature_cannot_be_declared_as_a_generator:n(1222,e.DiagnosticCategory.Error,"An_overload_signature_cannot_be_declared_as_a_generator_1222","An overload signature cannot be declared as a generator."),_0_tag_already_specified:n(1223,e.DiagnosticCategory.Error,"_0_tag_already_specified_1223","'{0}' tag already specified."),Signature_0_must_be_a_type_predicate:n(1224,e.DiagnosticCategory.Error,"Signature_0_must_be_a_type_predicate_1224","Signature '{0}' must be a type predicate."),Cannot_find_parameter_0:n(1225,e.DiagnosticCategory.Error,"Cannot_find_parameter_0_1225","Cannot find parameter '{0}'."),Type_predicate_0_is_not_assignable_to_1:n(1226,e.DiagnosticCategory.Error,"Type_predicate_0_is_not_assignable_to_1_1226","Type predicate '{0}' is not assignable to '{1}'."),Parameter_0_is_not_in_the_same_position_as_parameter_1:n(1227,e.DiagnosticCategory.Error,"Parameter_0_is_not_in_the_same_position_as_parameter_1_1227","Parameter '{0}' is not in the same position as parameter '{1}'."),A_type_predicate_is_only_allowed_in_return_type_position_for_functions_and_methods:n(1228,e.DiagnosticCategory.Error,"A_type_predicate_is_only_allowed_in_return_type_position_for_functions_and_methods_1228","A type predicate is only allowed in return type position for functions and methods."),A_type_predicate_cannot_reference_a_rest_parameter:n(1229,e.DiagnosticCategory.Error,"A_type_predicate_cannot_reference_a_rest_parameter_1229","A type predicate cannot reference a rest parameter."),A_type_predicate_cannot_reference_element_0_in_a_binding_pattern:n(1230,e.DiagnosticCategory.Error,"A_type_predicate_cannot_reference_element_0_in_a_binding_pattern_1230","A type predicate cannot reference element '{0}' in a binding pattern."),An_export_assignment_must_be_at_the_top_level_of_a_file_or_module_declaration:n(1231,e.DiagnosticCategory.Error,"An_export_assignment_must_be_at_the_top_level_of_a_file_or_module_declaration_1231","An export assignment must be at the top level of a file or module declaration."),An_import_declaration_can_only_be_used_in_a_namespace_or_module:n(1232,e.DiagnosticCategory.Error,"An_import_declaration_can_only_be_used_in_a_namespace_or_module_1232","An import declaration can only be used in a namespace or module."),An_export_declaration_can_only_be_used_in_a_module:n(1233,e.DiagnosticCategory.Error,"An_export_declaration_can_only_be_used_in_a_module_1233","An export declaration can only be used in a module."),An_ambient_module_declaration_is_only_allowed_at_the_top_level_in_a_file:n(1234,e.DiagnosticCategory.Error,"An_ambient_module_declaration_is_only_allowed_at_the_top_level_in_a_file_1234","An ambient module declaration is only allowed at the top level in a file."),A_namespace_declaration_is_only_allowed_in_a_namespace_or_module:n(1235,e.DiagnosticCategory.Error,"A_namespace_declaration_is_only_allowed_in_a_namespace_or_module_1235","A namespace declaration is only allowed in a namespace or module."),The_return_type_of_a_property_decorator_function_must_be_either_void_or_any:n(1236,e.DiagnosticCategory.Error,"The_return_type_of_a_property_decorator_function_must_be_either_void_or_any_1236","The return type of a property decorator function must be either 'void' or 'any'."),The_return_type_of_a_parameter_decorator_function_must_be_either_void_or_any:n(1237,e.DiagnosticCategory.Error,"The_return_type_of_a_parameter_decorator_function_must_be_either_void_or_any_1237","The return type of a parameter decorator function must be either 'void' or 'any'."),Unable_to_resolve_signature_of_class_decorator_when_called_as_an_expression:n(1238,e.DiagnosticCategory.Error,"Unable_to_resolve_signature_of_class_decorator_when_called_as_an_expression_1238","Unable to resolve signature of class decorator when called as an expression."),Unable_to_resolve_signature_of_parameter_decorator_when_called_as_an_expression:n(1239,e.DiagnosticCategory.Error,"Unable_to_resolve_signature_of_parameter_decorator_when_called_as_an_expression_1239","Unable to resolve signature of parameter decorator when called as an expression."),Unable_to_resolve_signature_of_property_decorator_when_called_as_an_expression:n(1240,e.DiagnosticCategory.Error,"Unable_to_resolve_signature_of_property_decorator_when_called_as_an_expression_1240","Unable to resolve signature of property decorator when called as an expression."),Unable_to_resolve_signature_of_method_decorator_when_called_as_an_expression:n(1241,e.DiagnosticCategory.Error,"Unable_to_resolve_signature_of_method_decorator_when_called_as_an_expression_1241","Unable to resolve signature of method decorator when called as an expression."),abstract_modifier_can_only_appear_on_a_class_method_or_property_declaration:n(1242,e.DiagnosticCategory.Error,"abstract_modifier_can_only_appear_on_a_class_method_or_property_declaration_1242","'abstract' modifier can only appear on a class, method, or property declaration."),_0_modifier_cannot_be_used_with_1_modifier:n(1243,e.DiagnosticCategory.Error,"_0_modifier_cannot_be_used_with_1_modifier_1243","'{0}' modifier cannot be used with '{1}' modifier."),Abstract_methods_can_only_appear_within_an_abstract_class:n(1244,e.DiagnosticCategory.Error,"Abstract_methods_can_only_appear_within_an_abstract_class_1244","Abstract methods can only appear within an abstract class."),Method_0_cannot_have_an_implementation_because_it_is_marked_abstract:n(1245,e.DiagnosticCategory.Error,"Method_0_cannot_have_an_implementation_because_it_is_marked_abstract_1245","Method '{0}' cannot have an implementation because it is marked abstract."),An_interface_property_cannot_have_an_initializer:n(1246,e.DiagnosticCategory.Error,"An_interface_property_cannot_have_an_initializer_1246","An interface property cannot have an initializer."),A_type_literal_property_cannot_have_an_initializer:n(1247,e.DiagnosticCategory.Error,"A_type_literal_property_cannot_have_an_initializer_1247","A type literal property cannot have an initializer."),A_class_member_cannot_have_the_0_keyword:n(1248,e.DiagnosticCategory.Error,"A_class_member_cannot_have_the_0_keyword_1248","A class member cannot have the '{0}' keyword."),A_decorator_can_only_decorate_a_method_implementation_not_an_overload:n(1249,e.DiagnosticCategory.Error,"A_decorator_can_only_decorate_a_method_implementation_not_an_overload_1249","A decorator can only decorate a method implementation, not an overload."),Function_declarations_are_not_allowed_inside_blocks_in_strict_mode_when_targeting_ES3_or_ES5:n(1250,e.DiagnosticCategory.Error,"Function_declarations_are_not_allowed_inside_blocks_in_strict_mode_when_targeting_ES3_or_ES5_1250","Function declarations are not allowed inside blocks in strict mode when targeting 'ES3' or 'ES5'."),Function_declarations_are_not_allowed_inside_blocks_in_strict_mode_when_targeting_ES3_or_ES5_Class_definitions_are_automatically_in_strict_mode:n(1251,e.DiagnosticCategory.Error,"Function_declarations_are_not_allowed_inside_blocks_in_strict_mode_when_targeting_ES3_or_ES5_Class_d_1251","Function declarations are not allowed inside blocks in strict mode when targeting 'ES3' or 'ES5'. Class definitions are automatically in strict mode."),Function_declarations_are_not_allowed_inside_blocks_in_strict_mode_when_targeting_ES3_or_ES5_Modules_are_automatically_in_strict_mode:n(1252,e.DiagnosticCategory.Error,"Function_declarations_are_not_allowed_inside_blocks_in_strict_mode_when_targeting_ES3_or_ES5_Modules_1252","Function declarations are not allowed inside blocks in strict mode when targeting 'ES3' or 'ES5'. Modules are automatically in strict mode."),_0_tag_cannot_be_used_independently_as_a_top_level_JSDoc_tag:n(1253,e.DiagnosticCategory.Error,"_0_tag_cannot_be_used_independently_as_a_top_level_JSDoc_tag_1253","'{0}' tag cannot be used independently as a top level JSDoc tag."),A_const_initializer_in_an_ambient_context_must_be_a_string_or_numeric_literal_or_literal_enum_reference:n(1254,e.DiagnosticCategory.Error,"A_const_initializer_in_an_ambient_context_must_be_a_string_or_numeric_literal_or_literal_enum_refere_1254","A 'const' initializer in an ambient context must be a string or numeric literal or literal enum reference."),A_definite_assignment_assertion_is_not_permitted_in_this_context:n(1255,e.DiagnosticCategory.Error,"A_definite_assignment_assertion_is_not_permitted_in_this_context_1255","A definite assignment assertion '!' is not permitted in this context."),A_required_element_cannot_follow_an_optional_element:n(1257,e.DiagnosticCategory.Error,"A_required_element_cannot_follow_an_optional_element_1257","A required element cannot follow an optional element."),A_default_export_must_be_at_the_top_level_of_a_file_or_module_declaration:n(1258,e.DiagnosticCategory.Error,"A_default_export_must_be_at_the_top_level_of_a_file_or_module_declaration_1258","A default export must be at the top level of a file or module declaration."),Module_0_can_only_be_default_imported_using_the_1_flag:n(1259,e.DiagnosticCategory.Error,"Module_0_can_only_be_default_imported_using_the_1_flag_1259","Module '{0}' can only be default-imported using the '{1}' flag"),Keywords_cannot_contain_escape_characters:n(1260,e.DiagnosticCategory.Error,"Keywords_cannot_contain_escape_characters_1260","Keywords cannot contain escape characters."),Already_included_file_name_0_differs_from_file_name_1_only_in_casing:n(1261,e.DiagnosticCategory.Error,"Already_included_file_name_0_differs_from_file_name_1_only_in_casing_1261","Already included file name '{0}' differs from file name '{1}' only in casing."),Identifier_expected_0_is_a_reserved_word_at_the_top_level_of_a_module:n(1262,e.DiagnosticCategory.Error,"Identifier_expected_0_is_a_reserved_word_at_the_top_level_of_a_module_1262","Identifier expected. '{0}' is a reserved word at the top-level of a module."),Declarations_with_initializers_cannot_also_have_definite_assignment_assertions:n(1263,e.DiagnosticCategory.Error,"Declarations_with_initializers_cannot_also_have_definite_assignment_assertions_1263","Declarations with initializers cannot also have definite assignment assertions."),Declarations_with_definite_assignment_assertions_must_also_have_type_annotations:n(1264,e.DiagnosticCategory.Error,"Declarations_with_definite_assignment_assertions_must_also_have_type_annotations_1264","Declarations with definite assignment assertions must also have type annotations."),A_rest_element_cannot_follow_another_rest_element:n(1265,e.DiagnosticCategory.Error,"A_rest_element_cannot_follow_another_rest_element_1265","A rest element cannot follow another rest element."),An_optional_element_cannot_follow_a_rest_element:n(1266,e.DiagnosticCategory.Error,"An_optional_element_cannot_follow_a_rest_element_1266","An optional element cannot follow a rest element."),with_statements_are_not_allowed_in_an_async_function_block:n(1300,e.DiagnosticCategory.Error,"with_statements_are_not_allowed_in_an_async_function_block_1300","'with' statements are not allowed in an async function block."),await_expressions_are_only_allowed_within_async_functions_and_at_the_top_levels_of_modules:n(1308,e.DiagnosticCategory.Error,"await_expressions_are_only_allowed_within_async_functions_and_at_the_top_levels_of_modules_1308","'await' expressions are only allowed within async functions and at the top levels of modules."),Did_you_mean_to_use_a_Colon_An_can_only_follow_a_property_name_when_the_containing_object_literal_is_part_of_a_destructuring_pattern:n(1312,e.DiagnosticCategory.Error,"Did_you_mean_to_use_a_Colon_An_can_only_follow_a_property_name_when_the_containing_object_literal_is_1312","Did you mean to use a ':'? An '=' can only follow a property name when the containing object literal is part of a destructuring pattern."),The_body_of_an_if_statement_cannot_be_the_empty_statement:n(1313,e.DiagnosticCategory.Error,"The_body_of_an_if_statement_cannot_be_the_empty_statement_1313","The body of an 'if' statement cannot be the empty statement."),Global_module_exports_may_only_appear_in_module_files:n(1314,e.DiagnosticCategory.Error,"Global_module_exports_may_only_appear_in_module_files_1314","Global module exports may only appear in module files."),Global_module_exports_may_only_appear_in_declaration_files:n(1315,e.DiagnosticCategory.Error,"Global_module_exports_may_only_appear_in_declaration_files_1315","Global module exports may only appear in declaration files."),Global_module_exports_may_only_appear_at_top_level:n(1316,e.DiagnosticCategory.Error,"Global_module_exports_may_only_appear_at_top_level_1316","Global module exports may only appear at top level."),A_parameter_property_cannot_be_declared_using_a_rest_parameter:n(1317,e.DiagnosticCategory.Error,"A_parameter_property_cannot_be_declared_using_a_rest_parameter_1317","A parameter property cannot be declared using a rest parameter."),An_abstract_accessor_cannot_have_an_implementation:n(1318,e.DiagnosticCategory.Error,"An_abstract_accessor_cannot_have_an_implementation_1318","An abstract accessor cannot have an implementation."),A_default_export_can_only_be_used_in_an_ECMAScript_style_module:n(1319,e.DiagnosticCategory.Error,"A_default_export_can_only_be_used_in_an_ECMAScript_style_module_1319","A default export can only be used in an ECMAScript-style module."),Type_of_await_operand_must_either_be_a_valid_promise_or_must_not_contain_a_callable_then_member:n(1320,e.DiagnosticCategory.Error,"Type_of_await_operand_must_either_be_a_valid_promise_or_must_not_contain_a_callable_then_member_1320","Type of 'await' operand must either be a valid promise or must not contain a callable 'then' member."),Type_of_yield_operand_in_an_async_generator_must_either_be_a_valid_promise_or_must_not_contain_a_callable_then_member:n(1321,e.DiagnosticCategory.Error,"Type_of_yield_operand_in_an_async_generator_must_either_be_a_valid_promise_or_must_not_contain_a_cal_1321","Type of 'yield' operand in an async generator must either be a valid promise or must not contain a callable 'then' member."),Type_of_iterated_elements_of_a_yield_Asterisk_operand_must_either_be_a_valid_promise_or_must_not_contain_a_callable_then_member:n(1322,e.DiagnosticCategory.Error,"Type_of_iterated_elements_of_a_yield_Asterisk_operand_must_either_be_a_valid_promise_or_must_not_con_1322","Type of iterated elements of a 'yield*' operand must either be a valid promise or must not contain a callable 'then' member."),Dynamic_imports_are_only_supported_when_the_module_flag_is_set_to_es2020_esnext_commonjs_amd_system_or_umd:n(1323,e.DiagnosticCategory.Error,"Dynamic_imports_are_only_supported_when_the_module_flag_is_set_to_es2020_esnext_commonjs_amd_system__1323","Dynamic imports are only supported when the '--module' flag is set to 'es2020', 'esnext', 'commonjs', 'amd', 'system', or 'umd'."),Dynamic_import_must_have_one_specifier_as_an_argument:n(1324,e.DiagnosticCategory.Error,"Dynamic_import_must_have_one_specifier_as_an_argument_1324","Dynamic import must have one specifier as an argument."),Specifier_of_dynamic_import_cannot_be_spread_element:n(1325,e.DiagnosticCategory.Error,"Specifier_of_dynamic_import_cannot_be_spread_element_1325","Specifier of dynamic import cannot be spread element."),Dynamic_import_cannot_have_type_arguments:n(1326,e.DiagnosticCategory.Error,"Dynamic_import_cannot_have_type_arguments_1326","Dynamic import cannot have type arguments."),String_literal_with_double_quotes_expected:n(1327,e.DiagnosticCategory.Error,"String_literal_with_double_quotes_expected_1327","String literal with double quotes expected."),Property_value_can_only_be_string_literal_numeric_literal_true_false_null_object_literal_or_array_literal:n(1328,e.DiagnosticCategory.Error,"Property_value_can_only_be_string_literal_numeric_literal_true_false_null_object_literal_or_array_li_1328","Property value can only be string literal, numeric literal, 'true', 'false', 'null', object literal or array literal."),_0_accepts_too_few_arguments_to_be_used_as_a_decorator_here_Did_you_mean_to_call_it_first_and_write_0:n(1329,e.DiagnosticCategory.Error,"_0_accepts_too_few_arguments_to_be_used_as_a_decorator_here_Did_you_mean_to_call_it_first_and_write__1329","'{0}' accepts too few arguments to be used as a decorator here. Did you mean to call it first and write '@{0}()'?"),A_property_of_an_interface_or_type_literal_whose_type_is_a_unique_symbol_type_must_be_readonly:n(1330,e.DiagnosticCategory.Error,"A_property_of_an_interface_or_type_literal_whose_type_is_a_unique_symbol_type_must_be_readonly_1330","A property of an interface or type literal whose type is a 'unique symbol' type must be 'readonly'."),A_property_of_a_class_whose_type_is_a_unique_symbol_type_must_be_both_static_and_readonly:n(1331,e.DiagnosticCategory.Error,"A_property_of_a_class_whose_type_is_a_unique_symbol_type_must_be_both_static_and_readonly_1331","A property of a class whose type is a 'unique symbol' type must be both 'static' and 'readonly'."),A_variable_whose_type_is_a_unique_symbol_type_must_be_const:n(1332,e.DiagnosticCategory.Error,"A_variable_whose_type_is_a_unique_symbol_type_must_be_const_1332","A variable whose type is a 'unique symbol' type must be 'const'."),unique_symbol_types_may_not_be_used_on_a_variable_declaration_with_a_binding_name:n(1333,e.DiagnosticCategory.Error,"unique_symbol_types_may_not_be_used_on_a_variable_declaration_with_a_binding_name_1333","'unique symbol' types may not be used on a variable declaration with a binding name."),unique_symbol_types_are_only_allowed_on_variables_in_a_variable_statement:n(1334,e.DiagnosticCategory.Error,"unique_symbol_types_are_only_allowed_on_variables_in_a_variable_statement_1334","'unique symbol' types are only allowed on variables in a variable statement."),unique_symbol_types_are_not_allowed_here:n(1335,e.DiagnosticCategory.Error,"unique_symbol_types_are_not_allowed_here_1335","'unique symbol' types are not allowed here."),An_index_signature_parameter_type_cannot_be_a_type_alias_Consider_writing_0_Colon_1_Colon_2_instead:n(1336,e.DiagnosticCategory.Error,"An_index_signature_parameter_type_cannot_be_a_type_alias_Consider_writing_0_Colon_1_Colon_2_instead_1336","An index signature parameter type cannot be a type alias. Consider writing '[{0}: {1}]: {2}' instead."),An_index_signature_parameter_type_cannot_be_a_union_type_Consider_using_a_mapped_object_type_instead:n(1337,e.DiagnosticCategory.Error,"An_index_signature_parameter_type_cannot_be_a_union_type_Consider_using_a_mapped_object_type_instead_1337","An index signature parameter type cannot be a union type. Consider using a mapped object type instead."),infer_declarations_are_only_permitted_in_the_extends_clause_of_a_conditional_type:n(1338,e.DiagnosticCategory.Error,"infer_declarations_are_only_permitted_in_the_extends_clause_of_a_conditional_type_1338","'infer' declarations are only permitted in the 'extends' clause of a conditional type."),Module_0_does_not_refer_to_a_value_but_is_used_as_a_value_here:n(1339,e.DiagnosticCategory.Error,"Module_0_does_not_refer_to_a_value_but_is_used_as_a_value_here_1339","Module '{0}' does not refer to a value, but is used as a value here."),Module_0_does_not_refer_to_a_type_but_is_used_as_a_type_here_Did_you_mean_typeof_import_0:n(1340,e.DiagnosticCategory.Error,"Module_0_does_not_refer_to_a_type_but_is_used_as_a_type_here_Did_you_mean_typeof_import_0_1340","Module '{0}' does not refer to a type, but is used as a type here. Did you mean 'typeof import('{0}')'?"),Type_arguments_cannot_be_used_here:n(1342,e.DiagnosticCategory.Error,"Type_arguments_cannot_be_used_here_1342","Type arguments cannot be used here."),The_import_meta_meta_property_is_only_allowed_when_the_module_option_is_es2020_esnext_or_system:n(1343,e.DiagnosticCategory.Error,"The_import_meta_meta_property_is_only_allowed_when_the_module_option_is_es2020_esnext_or_system_1343","The 'import.meta' meta-property is only allowed when the '--module' option is 'es2020', 'esnext', or 'system'."),A_label_is_not_allowed_here:n(1344,e.DiagnosticCategory.Error,"A_label_is_not_allowed_here_1344","'A label is not allowed here."),An_expression_of_type_void_cannot_be_tested_for_truthiness:n(1345,e.DiagnosticCategory.Error,"An_expression_of_type_void_cannot_be_tested_for_truthiness_1345","An expression of type 'void' cannot be tested for truthiness."),This_parameter_is_not_allowed_with_use_strict_directive:n(1346,e.DiagnosticCategory.Error,"This_parameter_is_not_allowed_with_use_strict_directive_1346","This parameter is not allowed with 'use strict' directive."),use_strict_directive_cannot_be_used_with_non_simple_parameter_list:n(1347,e.DiagnosticCategory.Error,"use_strict_directive_cannot_be_used_with_non_simple_parameter_list_1347","'use strict' directive cannot be used with non-simple parameter list."),Non_simple_parameter_declared_here:n(1348,e.DiagnosticCategory.Error,"Non_simple_parameter_declared_here_1348","Non-simple parameter declared here."),use_strict_directive_used_here:n(1349,e.DiagnosticCategory.Error,"use_strict_directive_used_here_1349","'use strict' directive used here."),Print_the_final_configuration_instead_of_building:n(1350,e.DiagnosticCategory.Message,"Print_the_final_configuration_instead_of_building_1350","Print the final configuration instead of building."),An_identifier_or_keyword_cannot_immediately_follow_a_numeric_literal:n(1351,e.DiagnosticCategory.Error,"An_identifier_or_keyword_cannot_immediately_follow_a_numeric_literal_1351","An identifier or keyword cannot immediately follow a numeric literal."),A_bigint_literal_cannot_use_exponential_notation:n(1352,e.DiagnosticCategory.Error,"A_bigint_literal_cannot_use_exponential_notation_1352","A bigint literal cannot use exponential notation."),A_bigint_literal_must_be_an_integer:n(1353,e.DiagnosticCategory.Error,"A_bigint_literal_must_be_an_integer_1353","A bigint literal must be an integer."),readonly_type_modifier_is_only_permitted_on_array_and_tuple_literal_types:n(1354,e.DiagnosticCategory.Error,"readonly_type_modifier_is_only_permitted_on_array_and_tuple_literal_types_1354","'readonly' type modifier is only permitted on array and tuple literal types."),A_const_assertions_can_only_be_applied_to_references_to_enum_members_or_string_number_boolean_array_or_object_literals:n(1355,e.DiagnosticCategory.Error,"A_const_assertions_can_only_be_applied_to_references_to_enum_members_or_string_number_boolean_array__1355","A 'const' assertions can only be applied to references to enum members, or string, number, boolean, array, or object literals."),Did_you_mean_to_mark_this_function_as_async:n(1356,e.DiagnosticCategory.Error,"Did_you_mean_to_mark_this_function_as_async_1356","Did you mean to mark this function as 'async'?"),An_enum_member_name_must_be_followed_by_a_or:n(1357,e.DiagnosticCategory.Error,"An_enum_member_name_must_be_followed_by_a_or_1357","An enum member name must be followed by a ',', '=', or '}'."),Tagged_template_expressions_are_not_permitted_in_an_optional_chain:n(1358,e.DiagnosticCategory.Error,"Tagged_template_expressions_are_not_permitted_in_an_optional_chain_1358","Tagged template expressions are not permitted in an optional chain."),Identifier_expected_0_is_a_reserved_word_that_cannot_be_used_here:n(1359,e.DiagnosticCategory.Error,"Identifier_expected_0_is_a_reserved_word_that_cannot_be_used_here_1359","Identifier expected. '{0}' is a reserved word that cannot be used here."),Did_you_mean_to_parenthesize_this_function_type:n(1360,e.DiagnosticCategory.Error,"Did_you_mean_to_parenthesize_this_function_type_1360","Did you mean to parenthesize this function type?"),_0_cannot_be_used_as_a_value_because_it_was_imported_using_import_type:n(1361,e.DiagnosticCategory.Error,"_0_cannot_be_used_as_a_value_because_it_was_imported_using_import_type_1361","'{0}' cannot be used as a value because it was imported using 'import type'."),_0_cannot_be_used_as_a_value_because_it_was_exported_using_export_type:n(1362,e.DiagnosticCategory.Error,"_0_cannot_be_used_as_a_value_because_it_was_exported_using_export_type_1362","'{0}' cannot be used as a value because it was exported using 'export type'."),A_type_only_import_can_specify_a_default_import_or_named_bindings_but_not_both:n(1363,e.DiagnosticCategory.Error,"A_type_only_import_can_specify_a_default_import_or_named_bindings_but_not_both_1363","A type-only import can specify a default import or named bindings, but not both."),Convert_to_type_only_export:n(1364,e.DiagnosticCategory.Message,"Convert_to_type_only_export_1364","Convert to type-only export"),Convert_all_re_exported_types_to_type_only_exports:n(1365,e.DiagnosticCategory.Message,"Convert_all_re_exported_types_to_type_only_exports_1365","Convert all re-exported types to type-only exports"),Split_into_two_separate_import_declarations:n(1366,e.DiagnosticCategory.Message,"Split_into_two_separate_import_declarations_1366","Split into two separate import declarations"),Split_all_invalid_type_only_imports:n(1367,e.DiagnosticCategory.Message,"Split_all_invalid_type_only_imports_1367","Split all invalid type-only imports"),Specify_emit_Slashchecking_behavior_for_imports_that_are_only_used_for_types:n(1368,e.DiagnosticCategory.Message,"Specify_emit_Slashchecking_behavior_for_imports_that_are_only_used_for_types_1368","Specify emit/checking behavior for imports that are only used for types"),Did_you_mean_0:n(1369,e.DiagnosticCategory.Message,"Did_you_mean_0_1369","Did you mean '{0}'?"),This_import_is_never_used_as_a_value_and_must_use_import_type_because_importsNotUsedAsValues_is_set_to_error:n(1371,e.DiagnosticCategory.Error,"This_import_is_never_used_as_a_value_and_must_use_import_type_because_importsNotUsedAsValues_is_set__1371","This import is never used as a value and must use 'import type' because 'importsNotUsedAsValues' is set to 'error'."),Convert_to_type_only_import:n(1373,e.DiagnosticCategory.Message,"Convert_to_type_only_import_1373","Convert to type-only import"),Convert_all_imports_not_used_as_a_value_to_type_only_imports:n(1374,e.DiagnosticCategory.Message,"Convert_all_imports_not_used_as_a_value_to_type_only_imports_1374","Convert all imports not used as a value to type-only imports"),await_expressions_are_only_allowed_at_the_top_level_of_a_file_when_that_file_is_a_module_but_this_file_has_no_imports_or_exports_Consider_adding_an_empty_export_to_make_this_file_a_module:n(1375,e.DiagnosticCategory.Error,"await_expressions_are_only_allowed_at_the_top_level_of_a_file_when_that_file_is_a_module_but_this_fi_1375","'await' expressions are only allowed at the top level of a file when that file is a module, but this file has no imports or exports. Consider adding an empty 'export {}' to make this file a module."),_0_was_imported_here:n(1376,e.DiagnosticCategory.Message,"_0_was_imported_here_1376","'{0}' was imported here."),_0_was_exported_here:n(1377,e.DiagnosticCategory.Message,"_0_was_exported_here_1377","'{0}' was exported here."),Top_level_await_expressions_are_only_allowed_when_the_module_option_is_set_to_esnext_or_system_and_the_target_option_is_set_to_es2017_or_higher:n(1378,e.DiagnosticCategory.Error,"Top_level_await_expressions_are_only_allowed_when_the_module_option_is_set_to_esnext_or_system_and_t_1378","Top-level 'await' expressions are only allowed when the 'module' option is set to 'esnext' or 'system', and the 'target' option is set to 'es2017' or higher."),An_import_alias_cannot_reference_a_declaration_that_was_exported_using_export_type:n(1379,e.DiagnosticCategory.Error,"An_import_alias_cannot_reference_a_declaration_that_was_exported_using_export_type_1379","An import alias cannot reference a declaration that was exported using 'export type'."),An_import_alias_cannot_reference_a_declaration_that_was_imported_using_import_type:n(1380,e.DiagnosticCategory.Error,"An_import_alias_cannot_reference_a_declaration_that_was_imported_using_import_type_1380","An import alias cannot reference a declaration that was imported using 'import type'."),Unexpected_token_Did_you_mean_or_rbrace:n(1381,e.DiagnosticCategory.Error,"Unexpected_token_Did_you_mean_or_rbrace_1381","Unexpected token. Did you mean `{'}'}` or `&rbrace;`?"),Unexpected_token_Did_you_mean_or_gt:n(1382,e.DiagnosticCategory.Error,"Unexpected_token_Did_you_mean_or_gt_1382","Unexpected token. Did you mean `{'>'}` or `&gt;`?"),Only_named_exports_may_use_export_type:n(1383,e.DiagnosticCategory.Error,"Only_named_exports_may_use_export_type_1383","Only named exports may use 'export type'."),A_new_expression_with_type_arguments_must_always_be_followed_by_a_parenthesized_argument_list:n(1384,e.DiagnosticCategory.Error,"A_new_expression_with_type_arguments_must_always_be_followed_by_a_parenthesized_argument_list_1384","A 'new' expression with type arguments must always be followed by a parenthesized argument list."),Function_type_notation_must_be_parenthesized_when_used_in_a_union_type:n(1385,e.DiagnosticCategory.Error,"Function_type_notation_must_be_parenthesized_when_used_in_a_union_type_1385","Function type notation must be parenthesized when used in a union type."),Constructor_type_notation_must_be_parenthesized_when_used_in_a_union_type:n(1386,e.DiagnosticCategory.Error,"Constructor_type_notation_must_be_parenthesized_when_used_in_a_union_type_1386","Constructor type notation must be parenthesized when used in a union type."),Function_type_notation_must_be_parenthesized_when_used_in_an_intersection_type:n(1387,e.DiagnosticCategory.Error,"Function_type_notation_must_be_parenthesized_when_used_in_an_intersection_type_1387","Function type notation must be parenthesized when used in an intersection type."),Constructor_type_notation_must_be_parenthesized_when_used_in_an_intersection_type:n(1388,e.DiagnosticCategory.Error,"Constructor_type_notation_must_be_parenthesized_when_used_in_an_intersection_type_1388","Constructor type notation must be parenthesized when used in an intersection type."),_0_is_not_allowed_as_a_variable_declaration_name:n(1389,e.DiagnosticCategory.Error,"_0_is_not_allowed_as_a_variable_declaration_name_1389","'{0}' is not allowed as a variable declaration name."),Provides_a_root_package_name_when_using_outFile_with_declarations:n(1390,e.DiagnosticCategory.Message,"Provides_a_root_package_name_when_using_outFile_with_declarations_1390","Provides a root package name when using outFile with declarations."),The_bundledPackageName_option_must_be_provided_when_using_outFile_and_node_module_resolution_with_declaration_emit:n(1391,e.DiagnosticCategory.Error,"The_bundledPackageName_option_must_be_provided_when_using_outFile_and_node_module_resolution_with_de_1391","The 'bundledPackageName' option must be provided when using outFile and node module resolution with declaration emit."),An_import_alias_cannot_use_import_type:n(1392,e.DiagnosticCategory.Error,"An_import_alias_cannot_use_import_type_1392","An import alias cannot use 'import type'"),Imported_via_0_from_file_1:n(1393,e.DiagnosticCategory.Message,"Imported_via_0_from_file_1_1393","Imported via {0} from file '{1}'"),Imported_via_0_from_file_1_with_packageId_2:n(1394,e.DiagnosticCategory.Message,"Imported_via_0_from_file_1_with_packageId_2_1394","Imported via {0} from file '{1}' with packageId '{2}'"),Imported_via_0_from_file_1_to_import_importHelpers_as_specified_in_compilerOptions:n(1395,e.DiagnosticCategory.Message,"Imported_via_0_from_file_1_to_import_importHelpers_as_specified_in_compilerOptions_1395","Imported via {0} from file '{1}' to import 'importHelpers' as specified in compilerOptions"),Imported_via_0_from_file_1_with_packageId_2_to_import_importHelpers_as_specified_in_compilerOptions:n(1396,e.DiagnosticCategory.Message,"Imported_via_0_from_file_1_with_packageId_2_to_import_importHelpers_as_specified_in_compilerOptions_1396","Imported via {0} from file '{1}' with packageId '{2}' to import 'importHelpers' as specified in compilerOptions"),Imported_via_0_from_file_1_to_import_jsx_and_jsxs_factory_functions:n(1397,e.DiagnosticCategory.Message,"Imported_via_0_from_file_1_to_import_jsx_and_jsxs_factory_functions_1397","Imported via {0} from file '{1}' to import 'jsx' and 'jsxs' factory functions"),Imported_via_0_from_file_1_with_packageId_2_to_import_jsx_and_jsxs_factory_functions:n(1398,e.DiagnosticCategory.Message,"Imported_via_0_from_file_1_with_packageId_2_to_import_jsx_and_jsxs_factory_functions_1398","Imported via {0} from file '{1}' with packageId '{2}' to import 'jsx' and 'jsxs' factory functions"),File_is_included_via_import_here:n(1399,e.DiagnosticCategory.Message,"File_is_included_via_import_here_1399","File is included via import here."),Referenced_via_0_from_file_1:n(1400,e.DiagnosticCategory.Message,"Referenced_via_0_from_file_1_1400","Referenced via '{0}' from file '{1}'"),File_is_included_via_reference_here:n(1401,e.DiagnosticCategory.Message,"File_is_included_via_reference_here_1401","File is included via reference here."),Type_library_referenced_via_0_from_file_1:n(1402,e.DiagnosticCategory.Message,"Type_library_referenced_via_0_from_file_1_1402","Type library referenced via '{0}' from file '{1}'"),Type_library_referenced_via_0_from_file_1_with_packageId_2:n(1403,e.DiagnosticCategory.Message,"Type_library_referenced_via_0_from_file_1_with_packageId_2_1403","Type library referenced via '{0}' from file '{1}' with packageId '{2}'"),File_is_included_via_type_library_reference_here:n(1404,e.DiagnosticCategory.Message,"File_is_included_via_type_library_reference_here_1404","File is included via type library reference here."),Library_referenced_via_0_from_file_1:n(1405,e.DiagnosticCategory.Message,"Library_referenced_via_0_from_file_1_1405","Library referenced via '{0}' from file '{1}'"),File_is_included_via_library_reference_here:n(1406,e.DiagnosticCategory.Message,"File_is_included_via_library_reference_here_1406","File is included via library reference here."),Matched_by_include_pattern_0_in_1:n(1407,e.DiagnosticCategory.Message,"Matched_by_include_pattern_0_in_1_1407","Matched by include pattern '{0}' in '{1}'"),File_is_matched_by_include_pattern_specified_here:n(1408,e.DiagnosticCategory.Message,"File_is_matched_by_include_pattern_specified_here_1408","File is matched by include pattern specified here."),Part_of_files_list_in_tsconfig_json:n(1409,e.DiagnosticCategory.Message,"Part_of_files_list_in_tsconfig_json_1409","Part of 'files' list in tsconfig.json"),File_is_matched_by_files_list_specified_here:n(1410,e.DiagnosticCategory.Message,"File_is_matched_by_files_list_specified_here_1410","File is matched by 'files' list specified here."),Output_from_referenced_project_0_included_because_1_specified:n(1411,e.DiagnosticCategory.Message,"Output_from_referenced_project_0_included_because_1_specified_1411","Output from referenced project '{0}' included because '{1}' specified"),Output_from_referenced_project_0_included_because_module_is_specified_as_none:n(1412,e.DiagnosticCategory.Message,"Output_from_referenced_project_0_included_because_module_is_specified_as_none_1412","Output from referenced project '{0}' included because '--module' is specified as 'none'"),File_is_output_from_referenced_project_specified_here:n(1413,e.DiagnosticCategory.Message,"File_is_output_from_referenced_project_specified_here_1413","File is output from referenced project specified here."),Source_from_referenced_project_0_included_because_1_specified:n(1414,e.DiagnosticCategory.Message,"Source_from_referenced_project_0_included_because_1_specified_1414","Source from referenced project '{0}' included because '{1}' specified"),Source_from_referenced_project_0_included_because_module_is_specified_as_none:n(1415,e.DiagnosticCategory.Message,"Source_from_referenced_project_0_included_because_module_is_specified_as_none_1415","Source from referenced project '{0}' included because '--module' is specified as 'none'"),File_is_source_from_referenced_project_specified_here:n(1416,e.DiagnosticCategory.Message,"File_is_source_from_referenced_project_specified_here_1416","File is source from referenced project specified here."),Entry_point_of_type_library_0_specified_in_compilerOptions:n(1417,e.DiagnosticCategory.Message,"Entry_point_of_type_library_0_specified_in_compilerOptions_1417","Entry point of type library '{0}' specified in compilerOptions"),Entry_point_of_type_library_0_specified_in_compilerOptions_with_packageId_1:n(1418,e.DiagnosticCategory.Message,"Entry_point_of_type_library_0_specified_in_compilerOptions_with_packageId_1_1418","Entry point of type library '{0}' specified in compilerOptions with packageId '{1}'"),File_is_entry_point_of_type_library_specified_here:n(1419,e.DiagnosticCategory.Message,"File_is_entry_point_of_type_library_specified_here_1419","File is entry point of type library specified here."),Entry_point_for_implicit_type_library_0:n(1420,e.DiagnosticCategory.Message,"Entry_point_for_implicit_type_library_0_1420","Entry point for implicit type library '{0}'"),Entry_point_for_implicit_type_library_0_with_packageId_1:n(1421,e.DiagnosticCategory.Message,"Entry_point_for_implicit_type_library_0_with_packageId_1_1421","Entry point for implicit type library '{0}' with packageId '{1}'"),Library_0_specified_in_compilerOptions:n(1422,e.DiagnosticCategory.Message,"Library_0_specified_in_compilerOptions_1422","Library '{0}' specified in compilerOptions"),File_is_library_specified_here:n(1423,e.DiagnosticCategory.Message,"File_is_library_specified_here_1423","File is library specified here."),Default_library:n(1424,e.DiagnosticCategory.Message,"Default_library_1424","Default library"),Default_library_for_target_0:n(1425,e.DiagnosticCategory.Message,"Default_library_for_target_0_1425","Default library for target '{0}'"),File_is_default_library_for_target_specified_here:n(1426,e.DiagnosticCategory.Message,"File_is_default_library_for_target_specified_here_1426","File is default library for target specified here."),Root_file_specified_for_compilation:n(1427,e.DiagnosticCategory.Message,"Root_file_specified_for_compilation_1427","Root file specified for compilation"),File_is_output_of_project_reference_source_0:n(1428,e.DiagnosticCategory.Message,"File_is_output_of_project_reference_source_0_1428","File is output of project reference source '{0}'"),File_redirects_to_file_0:n(1429,e.DiagnosticCategory.Message,"File_redirects_to_file_0_1429","File redirects to file '{0}'"),The_file_is_in_the_program_because_Colon:n(1430,e.DiagnosticCategory.Message,"The_file_is_in_the_program_because_Colon_1430","The file is in the program because:"),for_await_loops_are_only_allowed_at_the_top_level_of_a_file_when_that_file_is_a_module_but_this_file_has_no_imports_or_exports_Consider_adding_an_empty_export_to_make_this_file_a_module:n(1431,e.DiagnosticCategory.Error,"for_await_loops_are_only_allowed_at_the_top_level_of_a_file_when_that_file_is_a_module_but_this_file_1431","'for await' loops are only allowed at the top level of a file when that file is a module, but this file has no imports or exports. Consider adding an empty 'export {}' to make this file a module."),Top_level_for_await_loops_are_only_allowed_when_the_module_option_is_set_to_esnext_or_system_and_the_target_option_is_set_to_es2017_or_higher:n(1432,e.DiagnosticCategory.Error,"Top_level_for_await_loops_are_only_allowed_when_the_module_option_is_set_to_esnext_or_system_and_the_1432","Top-level 'for await' loops are only allowed when the 'module' option is set to 'esnext' or 'system', and the 'target' option is set to 'es2017' or higher."),Decorators_may_not_be_applied_to_this_parameters:n(1433,e.DiagnosticCategory.Error,"Decorators_may_not_be_applied_to_this_parameters_1433","Decorators may not be applied to 'this' parameters."),The_types_of_0_are_incompatible_between_these_types:n(2200,e.DiagnosticCategory.Error,"The_types_of_0_are_incompatible_between_these_types_2200","The types of '{0}' are incompatible between these types."),The_types_returned_by_0_are_incompatible_between_these_types:n(2201,e.DiagnosticCategory.Error,"The_types_returned_by_0_are_incompatible_between_these_types_2201","The types returned by '{0}' are incompatible between these types."),Call_signature_return_types_0_and_1_are_incompatible:n(2202,e.DiagnosticCategory.Error,"Call_signature_return_types_0_and_1_are_incompatible_2202","Call signature return types '{0}' and '{1}' are incompatible.",void 0,!0),Construct_signature_return_types_0_and_1_are_incompatible:n(2203,e.DiagnosticCategory.Error,"Construct_signature_return_types_0_and_1_are_incompatible_2203","Construct signature return types '{0}' and '{1}' are incompatible.",void 0,!0),Call_signatures_with_no_arguments_have_incompatible_return_types_0_and_1:n(2204,e.DiagnosticCategory.Error,"Call_signatures_with_no_arguments_have_incompatible_return_types_0_and_1_2204","Call signatures with no arguments have incompatible return types '{0}' and '{1}'.",void 0,!0),Construct_signatures_with_no_arguments_have_incompatible_return_types_0_and_1:n(2205,e.DiagnosticCategory.Error,"Construct_signatures_with_no_arguments_have_incompatible_return_types_0_and_1_2205","Construct signatures with no arguments have incompatible return types '{0}' and '{1}'.",void 0,!0),Duplicate_identifier_0:n(2300,e.DiagnosticCategory.Error,"Duplicate_identifier_0_2300","Duplicate identifier '{0}'."),Initializer_of_instance_member_variable_0_cannot_reference_identifier_1_declared_in_the_constructor:n(2301,e.DiagnosticCategory.Error,"Initializer_of_instance_member_variable_0_cannot_reference_identifier_1_declared_in_the_constructor_2301","Initializer of instance member variable '{0}' cannot reference identifier '{1}' declared in the constructor."),Static_members_cannot_reference_class_type_parameters:n(2302,e.DiagnosticCategory.Error,"Static_members_cannot_reference_class_type_parameters_2302","Static members cannot reference class type parameters."),Circular_definition_of_import_alias_0:n(2303,e.DiagnosticCategory.Error,"Circular_definition_of_import_alias_0_2303","Circular definition of import alias '{0}'."),Cannot_find_name_0:n(2304,e.DiagnosticCategory.Error,"Cannot_find_name_0_2304","Cannot find name '{0}'."),Module_0_has_no_exported_member_1:n(2305,e.DiagnosticCategory.Error,"Module_0_has_no_exported_member_1_2305","Module '{0}' has no exported member '{1}'."),File_0_is_not_a_module:n(2306,e.DiagnosticCategory.Error,"File_0_is_not_a_module_2306","File '{0}' is not a module."),Cannot_find_module_0_or_its_corresponding_type_declarations:n(2307,e.DiagnosticCategory.Error,"Cannot_find_module_0_or_its_corresponding_type_declarations_2307","Cannot find module '{0}' or its corresponding type declarations."),Module_0_has_already_exported_a_member_named_1_Consider_explicitly_re_exporting_to_resolve_the_ambiguity:n(2308,e.DiagnosticCategory.Error,"Module_0_has_already_exported_a_member_named_1_Consider_explicitly_re_exporting_to_resolve_the_ambig_2308","Module {0} has already exported a member named '{1}'. Consider explicitly re-exporting to resolve the ambiguity."),An_export_assignment_cannot_be_used_in_a_module_with_other_exported_elements:n(2309,e.DiagnosticCategory.Error,"An_export_assignment_cannot_be_used_in_a_module_with_other_exported_elements_2309","An export assignment cannot be used in a module with other exported elements."),Type_0_recursively_references_itself_as_a_base_type:n(2310,e.DiagnosticCategory.Error,"Type_0_recursively_references_itself_as_a_base_type_2310","Type '{0}' recursively references itself as a base type."),A_class_may_only_extend_another_class:n(2311,e.DiagnosticCategory.Error,"A_class_may_only_extend_another_class_2311","A class may only extend another class."),An_interface_can_only_extend_an_object_type_or_intersection_of_object_types_with_statically_known_members:n(2312,e.DiagnosticCategory.Error,"An_interface_can_only_extend_an_object_type_or_intersection_of_object_types_with_statically_known_me_2312","An interface can only extend an object type or intersection of object types with statically known members."),Type_parameter_0_has_a_circular_constraint:n(2313,e.DiagnosticCategory.Error,"Type_parameter_0_has_a_circular_constraint_2313","Type parameter '{0}' has a circular constraint."),Generic_type_0_requires_1_type_argument_s:n(2314,e.DiagnosticCategory.Error,"Generic_type_0_requires_1_type_argument_s_2314","Generic type '{0}' requires {1} type argument(s)."),Type_0_is_not_generic:n(2315,e.DiagnosticCategory.Error,"Type_0_is_not_generic_2315","Type '{0}' is not generic."),Global_type_0_must_be_a_class_or_interface_type:n(2316,e.DiagnosticCategory.Error,"Global_type_0_must_be_a_class_or_interface_type_2316","Global type '{0}' must be a class or interface type."),Global_type_0_must_have_1_type_parameter_s:n(2317,e.DiagnosticCategory.Error,"Global_type_0_must_have_1_type_parameter_s_2317","Global type '{0}' must have {1} type parameter(s)."),Cannot_find_global_type_0:n(2318,e.DiagnosticCategory.Error,"Cannot_find_global_type_0_2318","Cannot find global type '{0}'."),Named_property_0_of_types_1_and_2_are_not_identical:n(2319,e.DiagnosticCategory.Error,"Named_property_0_of_types_1_and_2_are_not_identical_2319","Named property '{0}' of types '{1}' and '{2}' are not identical."),Interface_0_cannot_simultaneously_extend_types_1_and_2:n(2320,e.DiagnosticCategory.Error,"Interface_0_cannot_simultaneously_extend_types_1_and_2_2320","Interface '{0}' cannot simultaneously extend types '{1}' and '{2}'."),Excessive_stack_depth_comparing_types_0_and_1:n(2321,e.DiagnosticCategory.Error,"Excessive_stack_depth_comparing_types_0_and_1_2321","Excessive stack depth comparing types '{0}' and '{1}'."),Type_0_is_not_assignable_to_type_1:n(2322,e.DiagnosticCategory.Error,"Type_0_is_not_assignable_to_type_1_2322","Type '{0}' is not assignable to type '{1}'."),Cannot_redeclare_exported_variable_0:n(2323,e.DiagnosticCategory.Error,"Cannot_redeclare_exported_variable_0_2323","Cannot redeclare exported variable '{0}'."),Property_0_is_missing_in_type_1:n(2324,e.DiagnosticCategory.Error,"Property_0_is_missing_in_type_1_2324","Property '{0}' is missing in type '{1}'."),Property_0_is_private_in_type_1_but_not_in_type_2:n(2325,e.DiagnosticCategory.Error,"Property_0_is_private_in_type_1_but_not_in_type_2_2325","Property '{0}' is private in type '{1}' but not in type '{2}'."),Types_of_property_0_are_incompatible:n(2326,e.DiagnosticCategory.Error,"Types_of_property_0_are_incompatible_2326","Types of property '{0}' are incompatible."),Property_0_is_optional_in_type_1_but_required_in_type_2:n(2327,e.DiagnosticCategory.Error,"Property_0_is_optional_in_type_1_but_required_in_type_2_2327","Property '{0}' is optional in type '{1}' but required in type '{2}'."),Types_of_parameters_0_and_1_are_incompatible:n(2328,e.DiagnosticCategory.Error,"Types_of_parameters_0_and_1_are_incompatible_2328","Types of parameters '{0}' and '{1}' are incompatible."),Index_signature_is_missing_in_type_0:n(2329,e.DiagnosticCategory.Error,"Index_signature_is_missing_in_type_0_2329","Index signature is missing in type '{0}'."),Index_signatures_are_incompatible:n(2330,e.DiagnosticCategory.Error,"Index_signatures_are_incompatible_2330","Index signatures are incompatible."),this_cannot_be_referenced_in_a_module_or_namespace_body:n(2331,e.DiagnosticCategory.Error,"this_cannot_be_referenced_in_a_module_or_namespace_body_2331","'this' cannot be referenced in a module or namespace body."),this_cannot_be_referenced_in_current_location:n(2332,e.DiagnosticCategory.Error,"this_cannot_be_referenced_in_current_location_2332","'this' cannot be referenced in current location."),this_cannot_be_referenced_in_constructor_arguments:n(2333,e.DiagnosticCategory.Error,"this_cannot_be_referenced_in_constructor_arguments_2333","'this' cannot be referenced in constructor arguments."),this_cannot_be_referenced_in_a_static_property_initializer:n(2334,e.DiagnosticCategory.Error,"this_cannot_be_referenced_in_a_static_property_initializer_2334","'this' cannot be referenced in a static property initializer."),super_can_only_be_referenced_in_a_derived_class:n(2335,e.DiagnosticCategory.Error,"super_can_only_be_referenced_in_a_derived_class_2335","'super' can only be referenced in a derived class."),super_cannot_be_referenced_in_constructor_arguments:n(2336,e.DiagnosticCategory.Error,"super_cannot_be_referenced_in_constructor_arguments_2336","'super' cannot be referenced in constructor arguments."),Super_calls_are_not_permitted_outside_constructors_or_in_nested_functions_inside_constructors:n(2337,e.DiagnosticCategory.Error,"Super_calls_are_not_permitted_outside_constructors_or_in_nested_functions_inside_constructors_2337","Super calls are not permitted outside constructors or in nested functions inside constructors."),super_property_access_is_permitted_only_in_a_constructor_member_function_or_member_accessor_of_a_derived_class:n(2338,e.DiagnosticCategory.Error,"super_property_access_is_permitted_only_in_a_constructor_member_function_or_member_accessor_of_a_der_2338","'super' property access is permitted only in a constructor, member function, or member accessor of a derived class."),Property_0_does_not_exist_on_type_1:n(2339,e.DiagnosticCategory.Error,"Property_0_does_not_exist_on_type_1_2339","Property '{0}' does not exist on type '{1}'."),Only_public_and_protected_methods_of_the_base_class_are_accessible_via_the_super_keyword:n(2340,e.DiagnosticCategory.Error,"Only_public_and_protected_methods_of_the_base_class_are_accessible_via_the_super_keyword_2340","Only public and protected methods of the base class are accessible via the 'super' keyword."),Property_0_is_private_and_only_accessible_within_class_1:n(2341,e.DiagnosticCategory.Error,"Property_0_is_private_and_only_accessible_within_class_1_2341","Property '{0}' is private and only accessible within class '{1}'."),An_index_expression_argument_must_be_of_type_string_number_symbol_or_any:n(2342,e.DiagnosticCategory.Error,"An_index_expression_argument_must_be_of_type_string_number_symbol_or_any_2342","An index expression argument must be of type 'string', 'number', 'symbol', or 'any'."),This_syntax_requires_an_imported_helper_named_1_which_does_not_exist_in_0_Consider_upgrading_your_version_of_0:n(2343,e.DiagnosticCategory.Error,"This_syntax_requires_an_imported_helper_named_1_which_does_not_exist_in_0_Consider_upgrading_your_ve_2343","This syntax requires an imported helper named '{1}' which does not exist in '{0}'. Consider upgrading your version of '{0}'."),Type_0_does_not_satisfy_the_constraint_1:n(2344,e.DiagnosticCategory.Error,"Type_0_does_not_satisfy_the_constraint_1_2344","Type '{0}' does not satisfy the constraint '{1}'."),Argument_of_type_0_is_not_assignable_to_parameter_of_type_1:n(2345,e.DiagnosticCategory.Error,"Argument_of_type_0_is_not_assignable_to_parameter_of_type_1_2345","Argument of type '{0}' is not assignable to parameter of type '{1}'."),Call_target_does_not_contain_any_signatures:n(2346,e.DiagnosticCategory.Error,"Call_target_does_not_contain_any_signatures_2346","Call target does not contain any signatures."),Untyped_function_calls_may_not_accept_type_arguments:n(2347,e.DiagnosticCategory.Error,"Untyped_function_calls_may_not_accept_type_arguments_2347","Untyped function calls may not accept type arguments."),Value_of_type_0_is_not_callable_Did_you_mean_to_include_new:n(2348,e.DiagnosticCategory.Error,"Value_of_type_0_is_not_callable_Did_you_mean_to_include_new_2348","Value of type '{0}' is not callable. Did you mean to include 'new'?"),This_expression_is_not_callable:n(2349,e.DiagnosticCategory.Error,"This_expression_is_not_callable_2349","This expression is not callable."),Only_a_void_function_can_be_called_with_the_new_keyword:n(2350,e.DiagnosticCategory.Error,"Only_a_void_function_can_be_called_with_the_new_keyword_2350","Only a void function can be called with the 'new' keyword."),This_expression_is_not_constructable:n(2351,e.DiagnosticCategory.Error,"This_expression_is_not_constructable_2351","This expression is not constructable."),Conversion_of_type_0_to_type_1_may_be_a_mistake_because_neither_type_sufficiently_overlaps_with_the_other_If_this_was_intentional_convert_the_expression_to_unknown_first:n(2352,e.DiagnosticCategory.Error,"Conversion_of_type_0_to_type_1_may_be_a_mistake_because_neither_type_sufficiently_overlaps_with_the__2352","Conversion of type '{0}' to type '{1}' may be a mistake because neither type sufficiently overlaps with the other. If this was intentional, convert the expression to 'unknown' first."),Object_literal_may_only_specify_known_properties_and_0_does_not_exist_in_type_1:n(2353,e.DiagnosticCategory.Error,"Object_literal_may_only_specify_known_properties_and_0_does_not_exist_in_type_1_2353","Object literal may only specify known properties, and '{0}' does not exist in type '{1}'."),This_syntax_requires_an_imported_helper_but_module_0_cannot_be_found:n(2354,e.DiagnosticCategory.Error,"This_syntax_requires_an_imported_helper_but_module_0_cannot_be_found_2354","This syntax requires an imported helper but module '{0}' cannot be found."),A_function_whose_declared_type_is_neither_void_nor_any_must_return_a_value:n(2355,e.DiagnosticCategory.Error,"A_function_whose_declared_type_is_neither_void_nor_any_must_return_a_value_2355","A function whose declared type is neither 'void' nor 'any' must return a value."),An_arithmetic_operand_must_be_of_type_any_number_bigint_or_an_enum_type:n(2356,e.DiagnosticCategory.Error,"An_arithmetic_operand_must_be_of_type_any_number_bigint_or_an_enum_type_2356","An arithmetic operand must be of type 'any', 'number', 'bigint' or an enum type."),The_operand_of_an_increment_or_decrement_operator_must_be_a_variable_or_a_property_access:n(2357,e.DiagnosticCategory.Error,"The_operand_of_an_increment_or_decrement_operator_must_be_a_variable_or_a_property_access_2357","The operand of an increment or decrement operator must be a variable or a property access."),The_left_hand_side_of_an_instanceof_expression_must_be_of_type_any_an_object_type_or_a_type_parameter:n(2358,e.DiagnosticCategory.Error,"The_left_hand_side_of_an_instanceof_expression_must_be_of_type_any_an_object_type_or_a_type_paramete_2358","The left-hand side of an 'instanceof' expression must be of type 'any', an object type or a type parameter."),The_right_hand_side_of_an_instanceof_expression_must_be_of_type_any_or_of_a_type_assignable_to_the_Function_interface_type:n(2359,e.DiagnosticCategory.Error,"The_right_hand_side_of_an_instanceof_expression_must_be_of_type_any_or_of_a_type_assignable_to_the_F_2359","The right-hand side of an 'instanceof' expression must be of type 'any' or of a type assignable to the 'Function' interface type."),The_left_hand_side_of_an_in_expression_must_be_of_type_any_string_number_or_symbol:n(2360,e.DiagnosticCategory.Error,"The_left_hand_side_of_an_in_expression_must_be_of_type_any_string_number_or_symbol_2360","The left-hand side of an 'in' expression must be of type 'any', 'string', 'number', or 'symbol'."),The_right_hand_side_of_an_in_expression_must_not_be_a_primitive:n(2361,e.DiagnosticCategory.Error,"The_right_hand_side_of_an_in_expression_must_not_be_a_primitive_2361","The right-hand side of an 'in' expression must not be a primitive."),The_left_hand_side_of_an_arithmetic_operation_must_be_of_type_any_number_bigint_or_an_enum_type:n(2362,e.DiagnosticCategory.Error,"The_left_hand_side_of_an_arithmetic_operation_must_be_of_type_any_number_bigint_or_an_enum_type_2362","The left-hand side of an arithmetic operation must be of type 'any', 'number', 'bigint' or an enum type."),The_right_hand_side_of_an_arithmetic_operation_must_be_of_type_any_number_bigint_or_an_enum_type:n(2363,e.DiagnosticCategory.Error,"The_right_hand_side_of_an_arithmetic_operation_must_be_of_type_any_number_bigint_or_an_enum_type_2363","The right-hand side of an arithmetic operation must be of type 'any', 'number', 'bigint' or an enum type."),The_left_hand_side_of_an_assignment_expression_must_be_a_variable_or_a_property_access:n(2364,e.DiagnosticCategory.Error,"The_left_hand_side_of_an_assignment_expression_must_be_a_variable_or_a_property_access_2364","The left-hand side of an assignment expression must be a variable or a property access."),Operator_0_cannot_be_applied_to_types_1_and_2:n(2365,e.DiagnosticCategory.Error,"Operator_0_cannot_be_applied_to_types_1_and_2_2365","Operator '{0}' cannot be applied to types '{1}' and '{2}'."),Function_lacks_ending_return_statement_and_return_type_does_not_include_undefined:n(2366,e.DiagnosticCategory.Error,"Function_lacks_ending_return_statement_and_return_type_does_not_include_undefined_2366","Function lacks ending return statement and return type does not include 'undefined'."),This_condition_will_always_return_0_since_the_types_1_and_2_have_no_overlap:n(2367,e.DiagnosticCategory.Error,"This_condition_will_always_return_0_since_the_types_1_and_2_have_no_overlap_2367","This condition will always return '{0}' since the types '{1}' and '{2}' have no overlap."),Type_parameter_name_cannot_be_0:n(2368,e.DiagnosticCategory.Error,"Type_parameter_name_cannot_be_0_2368","Type parameter name cannot be '{0}'."),A_parameter_property_is_only_allowed_in_a_constructor_implementation:n(2369,e.DiagnosticCategory.Error,"A_parameter_property_is_only_allowed_in_a_constructor_implementation_2369","A parameter property is only allowed in a constructor implementation."),A_rest_parameter_must_be_of_an_array_type:n(2370,e.DiagnosticCategory.Error,"A_rest_parameter_must_be_of_an_array_type_2370","A rest parameter must be of an array type."),A_parameter_initializer_is_only_allowed_in_a_function_or_constructor_implementation:n(2371,e.DiagnosticCategory.Error,"A_parameter_initializer_is_only_allowed_in_a_function_or_constructor_implementation_2371","A parameter initializer is only allowed in a function or constructor implementation."),Parameter_0_cannot_reference_itself:n(2372,e.DiagnosticCategory.Error,"Parameter_0_cannot_reference_itself_2372","Parameter '{0}' cannot reference itself."),Parameter_0_cannot_reference_identifier_1_declared_after_it:n(2373,e.DiagnosticCategory.Error,"Parameter_0_cannot_reference_identifier_1_declared_after_it_2373","Parameter '{0}' cannot reference identifier '{1}' declared after it."),Duplicate_string_index_signature:n(2374,e.DiagnosticCategory.Error,"Duplicate_string_index_signature_2374","Duplicate string index signature."),Duplicate_number_index_signature:n(2375,e.DiagnosticCategory.Error,"Duplicate_number_index_signature_2375","Duplicate number index signature."),A_super_call_must_be_the_first_statement_in_the_constructor_when_a_class_contains_initialized_properties_parameter_properties_or_private_identifiers:n(2376,e.DiagnosticCategory.Error,"A_super_call_must_be_the_first_statement_in_the_constructor_when_a_class_contains_initialized_proper_2376","A 'super' call must be the first statement in the constructor when a class contains initialized properties, parameter properties, or private identifiers."),Constructors_for_derived_classes_must_contain_a_super_call:n(2377,e.DiagnosticCategory.Error,"Constructors_for_derived_classes_must_contain_a_super_call_2377","Constructors for derived classes must contain a 'super' call."),A_get_accessor_must_return_a_value:n(2378,e.DiagnosticCategory.Error,"A_get_accessor_must_return_a_value_2378","A 'get' accessor must return a value."),The_return_type_of_a_get_accessor_must_be_assignable_to_its_set_accessor_type:n(2380,e.DiagnosticCategory.Error,"The_return_type_of_a_get_accessor_must_be_assignable_to_its_set_accessor_type_2380","The return type of a 'get' accessor must be assignable to its 'set' accessor type"),A_signature_with_an_implementation_cannot_use_a_string_literal_type:n(2381,e.DiagnosticCategory.Error,"A_signature_with_an_implementation_cannot_use_a_string_literal_type_2381","A signature with an implementation cannot use a string literal type."),Specialized_overload_signature_is_not_assignable_to_any_non_specialized_signature:n(2382,e.DiagnosticCategory.Error,"Specialized_overload_signature_is_not_assignable_to_any_non_specialized_signature_2382","Specialized overload signature is not assignable to any non-specialized signature."),Overload_signatures_must_all_be_exported_or_non_exported:n(2383,e.DiagnosticCategory.Error,"Overload_signatures_must_all_be_exported_or_non_exported_2383","Overload signatures must all be exported or non-exported."),Overload_signatures_must_all_be_ambient_or_non_ambient:n(2384,e.DiagnosticCategory.Error,"Overload_signatures_must_all_be_ambient_or_non_ambient_2384","Overload signatures must all be ambient or non-ambient."),Overload_signatures_must_all_be_public_private_or_protected:n(2385,e.DiagnosticCategory.Error,"Overload_signatures_must_all_be_public_private_or_protected_2385","Overload signatures must all be public, private or protected."),Overload_signatures_must_all_be_optional_or_required:n(2386,e.DiagnosticCategory.Error,"Overload_signatures_must_all_be_optional_or_required_2386","Overload signatures must all be optional or required."),Function_overload_must_be_static:n(2387,e.DiagnosticCategory.Error,"Function_overload_must_be_static_2387","Function overload must be static."),Function_overload_must_not_be_static:n(2388,e.DiagnosticCategory.Error,"Function_overload_must_not_be_static_2388","Function overload must not be static."),Function_implementation_name_must_be_0:n(2389,e.DiagnosticCategory.Error,"Function_implementation_name_must_be_0_2389","Function implementation name must be '{0}'."),Constructor_implementation_is_missing:n(2390,e.DiagnosticCategory.Error,"Constructor_implementation_is_missing_2390","Constructor implementation is missing."),Function_implementation_is_missing_or_not_immediately_following_the_declaration:n(2391,e.DiagnosticCategory.Error,"Function_implementation_is_missing_or_not_immediately_following_the_declaration_2391","Function implementation is missing or not immediately following the declaration."),Multiple_constructor_implementations_are_not_allowed:n(2392,e.DiagnosticCategory.Error,"Multiple_constructor_implementations_are_not_allowed_2392","Multiple constructor implementations are not allowed."),Duplicate_function_implementation:n(2393,e.DiagnosticCategory.Error,"Duplicate_function_implementation_2393","Duplicate function implementation."),This_overload_signature_is_not_compatible_with_its_implementation_signature:n(2394,e.DiagnosticCategory.Error,"This_overload_signature_is_not_compatible_with_its_implementation_signature_2394","This overload signature is not compatible with its implementation signature."),Individual_declarations_in_merged_declaration_0_must_be_all_exported_or_all_local:n(2395,e.DiagnosticCategory.Error,"Individual_declarations_in_merged_declaration_0_must_be_all_exported_or_all_local_2395","Individual declarations in merged declaration '{0}' must be all exported or all local."),Duplicate_identifier_arguments_Compiler_uses_arguments_to_initialize_rest_parameters:n(2396,e.DiagnosticCategory.Error,"Duplicate_identifier_arguments_Compiler_uses_arguments_to_initialize_rest_parameters_2396","Duplicate identifier 'arguments'. Compiler uses 'arguments' to initialize rest parameters."),Declaration_name_conflicts_with_built_in_global_identifier_0:n(2397,e.DiagnosticCategory.Error,"Declaration_name_conflicts_with_built_in_global_identifier_0_2397","Declaration name conflicts with built-in global identifier '{0}'."),constructor_cannot_be_used_as_a_parameter_property_name:n(2398,e.DiagnosticCategory.Error,"constructor_cannot_be_used_as_a_parameter_property_name_2398","'constructor' cannot be used as a parameter property name."),Duplicate_identifier_this_Compiler_uses_variable_declaration_this_to_capture_this_reference:n(2399,e.DiagnosticCategory.Error,"Duplicate_identifier_this_Compiler_uses_variable_declaration_this_to_capture_this_reference_2399","Duplicate identifier '_this'. Compiler uses variable declaration '_this' to capture 'this' reference."),Expression_resolves_to_variable_declaration_this_that_compiler_uses_to_capture_this_reference:n(2400,e.DiagnosticCategory.Error,"Expression_resolves_to_variable_declaration_this_that_compiler_uses_to_capture_this_reference_2400","Expression resolves to variable declaration '_this' that compiler uses to capture 'this' reference."),Duplicate_identifier_super_Compiler_uses_super_to_capture_base_class_reference:n(2401,e.DiagnosticCategory.Error,"Duplicate_identifier_super_Compiler_uses_super_to_capture_base_class_reference_2401","Duplicate identifier '_super'. Compiler uses '_super' to capture base class reference."),Expression_resolves_to_super_that_compiler_uses_to_capture_base_class_reference:n(2402,e.DiagnosticCategory.Error,"Expression_resolves_to_super_that_compiler_uses_to_capture_base_class_reference_2402","Expression resolves to '_super' that compiler uses to capture base class reference."),Subsequent_variable_declarations_must_have_the_same_type_Variable_0_must_be_of_type_1_but_here_has_type_2:n(2403,e.DiagnosticCategory.Error,"Subsequent_variable_declarations_must_have_the_same_type_Variable_0_must_be_of_type_1_but_here_has_t_2403","Subsequent variable declarations must have the same type.  Variable '{0}' must be of type '{1}', but here has type '{2}'."),The_left_hand_side_of_a_for_in_statement_cannot_use_a_type_annotation:n(2404,e.DiagnosticCategory.Error,"The_left_hand_side_of_a_for_in_statement_cannot_use_a_type_annotation_2404","The left-hand side of a 'for...in' statement cannot use a type annotation."),The_left_hand_side_of_a_for_in_statement_must_be_of_type_string_or_any:n(2405,e.DiagnosticCategory.Error,"The_left_hand_side_of_a_for_in_statement_must_be_of_type_string_or_any_2405","The left-hand side of a 'for...in' statement must be of type 'string' or 'any'."),The_left_hand_side_of_a_for_in_statement_must_be_a_variable_or_a_property_access:n(2406,e.DiagnosticCategory.Error,"The_left_hand_side_of_a_for_in_statement_must_be_a_variable_or_a_property_access_2406","The left-hand side of a 'for...in' statement must be a variable or a property access."),The_right_hand_side_of_a_for_in_statement_must_be_of_type_any_an_object_type_or_a_type_parameter_but_here_has_type_0:n(2407,e.DiagnosticCategory.Error,"The_right_hand_side_of_a_for_in_statement_must_be_of_type_any_an_object_type_or_a_type_parameter_but_2407","The right-hand side of a 'for...in' statement must be of type 'any', an object type or a type parameter, but here has type '{0}'."),Setters_cannot_return_a_value:n(2408,e.DiagnosticCategory.Error,"Setters_cannot_return_a_value_2408","Setters cannot return a value."),Return_type_of_constructor_signature_must_be_assignable_to_the_instance_type_of_the_class:n(2409,e.DiagnosticCategory.Error,"Return_type_of_constructor_signature_must_be_assignable_to_the_instance_type_of_the_class_2409","Return type of constructor signature must be assignable to the instance type of the class."),The_with_statement_is_not_supported_All_symbols_in_a_with_block_will_have_type_any:n(2410,e.DiagnosticCategory.Error,"The_with_statement_is_not_supported_All_symbols_in_a_with_block_will_have_type_any_2410","The 'with' statement is not supported. All symbols in a 'with' block will have type 'any'."),Property_0_of_type_1_is_not_assignable_to_string_index_type_2:n(2411,e.DiagnosticCategory.Error,"Property_0_of_type_1_is_not_assignable_to_string_index_type_2_2411","Property '{0}' of type '{1}' is not assignable to string index type '{2}'."),Property_0_of_type_1_is_not_assignable_to_numeric_index_type_2:n(2412,e.DiagnosticCategory.Error,"Property_0_of_type_1_is_not_assignable_to_numeric_index_type_2_2412","Property '{0}' of type '{1}' is not assignable to numeric index type '{2}'."),Numeric_index_type_0_is_not_assignable_to_string_index_type_1:n(2413,e.DiagnosticCategory.Error,"Numeric_index_type_0_is_not_assignable_to_string_index_type_1_2413","Numeric index type '{0}' is not assignable to string index type '{1}'."),Class_name_cannot_be_0:n(2414,e.DiagnosticCategory.Error,"Class_name_cannot_be_0_2414","Class name cannot be '{0}'."),Class_0_incorrectly_extends_base_class_1:n(2415,e.DiagnosticCategory.Error,"Class_0_incorrectly_extends_base_class_1_2415","Class '{0}' incorrectly extends base class '{1}'."),Property_0_in_type_1_is_not_assignable_to_the_same_property_in_base_type_2:n(2416,e.DiagnosticCategory.Error,"Property_0_in_type_1_is_not_assignable_to_the_same_property_in_base_type_2_2416","Property '{0}' in type '{1}' is not assignable to the same property in base type '{2}'."),Class_static_side_0_incorrectly_extends_base_class_static_side_1:n(2417,e.DiagnosticCategory.Error,"Class_static_side_0_incorrectly_extends_base_class_static_side_1_2417","Class static side '{0}' incorrectly extends base class static side '{1}'."),Type_of_computed_property_s_value_is_0_which_is_not_assignable_to_type_1:n(2418,e.DiagnosticCategory.Error,"Type_of_computed_property_s_value_is_0_which_is_not_assignable_to_type_1_2418","Type of computed property's value is '{0}', which is not assignable to type '{1}'."),Types_of_construct_signatures_are_incompatible:n(2419,e.DiagnosticCategory.Error,"Types_of_construct_signatures_are_incompatible_2419","Types of construct signatures are incompatible."),Class_0_incorrectly_implements_interface_1:n(2420,e.DiagnosticCategory.Error,"Class_0_incorrectly_implements_interface_1_2420","Class '{0}' incorrectly implements interface '{1}'."),A_class_can_only_implement_an_object_type_or_intersection_of_object_types_with_statically_known_members:n(2422,e.DiagnosticCategory.Error,"A_class_can_only_implement_an_object_type_or_intersection_of_object_types_with_statically_known_memb_2422","A class can only implement an object type or intersection of object types with statically known members."),Class_0_defines_instance_member_function_1_but_extended_class_2_defines_it_as_instance_member_accessor:n(2423,e.DiagnosticCategory.Error,"Class_0_defines_instance_member_function_1_but_extended_class_2_defines_it_as_instance_member_access_2423","Class '{0}' defines instance member function '{1}', but extended class '{2}' defines it as instance member accessor."),Class_0_defines_instance_member_property_1_but_extended_class_2_defines_it_as_instance_member_function:n(2425,e.DiagnosticCategory.Error,"Class_0_defines_instance_member_property_1_but_extended_class_2_defines_it_as_instance_member_functi_2425","Class '{0}' defines instance member property '{1}', but extended class '{2}' defines it as instance member function."),Class_0_defines_instance_member_accessor_1_but_extended_class_2_defines_it_as_instance_member_function:n(2426,e.DiagnosticCategory.Error,"Class_0_defines_instance_member_accessor_1_but_extended_class_2_defines_it_as_instance_member_functi_2426","Class '{0}' defines instance member accessor '{1}', but extended class '{2}' defines it as instance member function."),Interface_name_cannot_be_0:n(2427,e.DiagnosticCategory.Error,"Interface_name_cannot_be_0_2427","Interface name cannot be '{0}'."),All_declarations_of_0_must_have_identical_type_parameters:n(2428,e.DiagnosticCategory.Error,"All_declarations_of_0_must_have_identical_type_parameters_2428","All declarations of '{0}' must have identical type parameters."),Interface_0_incorrectly_extends_interface_1:n(2430,e.DiagnosticCategory.Error,"Interface_0_incorrectly_extends_interface_1_2430","Interface '{0}' incorrectly extends interface '{1}'."),Enum_name_cannot_be_0:n(2431,e.DiagnosticCategory.Error,"Enum_name_cannot_be_0_2431","Enum name cannot be '{0}'."),In_an_enum_with_multiple_declarations_only_one_declaration_can_omit_an_initializer_for_its_first_enum_element:n(2432,e.DiagnosticCategory.Error,"In_an_enum_with_multiple_declarations_only_one_declaration_can_omit_an_initializer_for_its_first_enu_2432","In an enum with multiple declarations, only one declaration can omit an initializer for its first enum element."),A_namespace_declaration_cannot_be_in_a_different_file_from_a_class_or_function_with_which_it_is_merged:n(2433,e.DiagnosticCategory.Error,"A_namespace_declaration_cannot_be_in_a_different_file_from_a_class_or_function_with_which_it_is_merg_2433","A namespace declaration cannot be in a different file from a class or function with which it is merged."),A_namespace_declaration_cannot_be_located_prior_to_a_class_or_function_with_which_it_is_merged:n(2434,e.DiagnosticCategory.Error,"A_namespace_declaration_cannot_be_located_prior_to_a_class_or_function_with_which_it_is_merged_2434","A namespace declaration cannot be located prior to a class or function with which it is merged."),Ambient_modules_cannot_be_nested_in_other_modules_or_namespaces:n(2435,e.DiagnosticCategory.Error,"Ambient_modules_cannot_be_nested_in_other_modules_or_namespaces_2435","Ambient modules cannot be nested in other modules or namespaces."),Ambient_module_declaration_cannot_specify_relative_module_name:n(2436,e.DiagnosticCategory.Error,"Ambient_module_declaration_cannot_specify_relative_module_name_2436","Ambient module declaration cannot specify relative module name."),Module_0_is_hidden_by_a_local_declaration_with_the_same_name:n(2437,e.DiagnosticCategory.Error,"Module_0_is_hidden_by_a_local_declaration_with_the_same_name_2437","Module '{0}' is hidden by a local declaration with the same name."),Import_name_cannot_be_0:n(2438,e.DiagnosticCategory.Error,"Import_name_cannot_be_0_2438","Import name cannot be '{0}'."),Import_or_export_declaration_in_an_ambient_module_declaration_cannot_reference_module_through_relative_module_name:n(2439,e.DiagnosticCategory.Error,"Import_or_export_declaration_in_an_ambient_module_declaration_cannot_reference_module_through_relati_2439","Import or export declaration in an ambient module declaration cannot reference module through relative module name."),Import_declaration_conflicts_with_local_declaration_of_0:n(2440,e.DiagnosticCategory.Error,"Import_declaration_conflicts_with_local_declaration_of_0_2440","Import declaration conflicts with local declaration of '{0}'."),Duplicate_identifier_0_Compiler_reserves_name_1_in_top_level_scope_of_a_module:n(2441,e.DiagnosticCategory.Error,"Duplicate_identifier_0_Compiler_reserves_name_1_in_top_level_scope_of_a_module_2441","Duplicate identifier '{0}'. Compiler reserves name '{1}' in top level scope of a module."),Types_have_separate_declarations_of_a_private_property_0:n(2442,e.DiagnosticCategory.Error,"Types_have_separate_declarations_of_a_private_property_0_2442","Types have separate declarations of a private property '{0}'."),Property_0_is_protected_but_type_1_is_not_a_class_derived_from_2:n(2443,e.DiagnosticCategory.Error,"Property_0_is_protected_but_type_1_is_not_a_class_derived_from_2_2443","Property '{0}' is protected but type '{1}' is not a class derived from '{2}'."),Property_0_is_protected_in_type_1_but_public_in_type_2:n(2444,e.DiagnosticCategory.Error,"Property_0_is_protected_in_type_1_but_public_in_type_2_2444","Property '{0}' is protected in type '{1}' but public in type '{2}'."),Property_0_is_protected_and_only_accessible_within_class_1_and_its_subclasses:n(2445,e.DiagnosticCategory.Error,"Property_0_is_protected_and_only_accessible_within_class_1_and_its_subclasses_2445","Property '{0}' is protected and only accessible within class '{1}' and its subclasses."),Property_0_is_protected_and_only_accessible_through_an_instance_of_class_1_This_is_an_instance_of_class_2:n(2446,e.DiagnosticCategory.Error,"Property_0_is_protected_and_only_accessible_through_an_instance_of_class_1_This_is_an_instance_of_cl_2446","Property '{0}' is protected and only accessible through an instance of class '{1}'. This is an instance of class '{2}'."),The_0_operator_is_not_allowed_for_boolean_types_Consider_using_1_instead:n(2447,e.DiagnosticCategory.Error,"The_0_operator_is_not_allowed_for_boolean_types_Consider_using_1_instead_2447","The '{0}' operator is not allowed for boolean types. Consider using '{1}' instead."),Block_scoped_variable_0_used_before_its_declaration:n(2448,e.DiagnosticCategory.Error,"Block_scoped_variable_0_used_before_its_declaration_2448","Block-scoped variable '{0}' used before its declaration."),Class_0_used_before_its_declaration:n(2449,e.DiagnosticCategory.Error,"Class_0_used_before_its_declaration_2449","Class '{0}' used before its declaration."),Enum_0_used_before_its_declaration:n(2450,e.DiagnosticCategory.Error,"Enum_0_used_before_its_declaration_2450","Enum '{0}' used before its declaration."),Cannot_redeclare_block_scoped_variable_0:n(2451,e.DiagnosticCategory.Error,"Cannot_redeclare_block_scoped_variable_0_2451","Cannot redeclare block-scoped variable '{0}'."),An_enum_member_cannot_have_a_numeric_name:n(2452,e.DiagnosticCategory.Error,"An_enum_member_cannot_have_a_numeric_name_2452","An enum member cannot have a numeric name."),The_type_argument_for_type_parameter_0_cannot_be_inferred_from_the_usage_Consider_specifying_the_type_arguments_explicitly:n(2453,e.DiagnosticCategory.Error,"The_type_argument_for_type_parameter_0_cannot_be_inferred_from_the_usage_Consider_specifying_the_typ_2453","The type argument for type parameter '{0}' cannot be inferred from the usage. Consider specifying the type arguments explicitly."),Variable_0_is_used_before_being_assigned:n(2454,e.DiagnosticCategory.Error,"Variable_0_is_used_before_being_assigned_2454","Variable '{0}' is used before being assigned."),Type_argument_candidate_1_is_not_a_valid_type_argument_because_it_is_not_a_supertype_of_candidate_0:n(2455,e.DiagnosticCategory.Error,"Type_argument_candidate_1_is_not_a_valid_type_argument_because_it_is_not_a_supertype_of_candidate_0_2455","Type argument candidate '{1}' is not a valid type argument because it is not a supertype of candidate '{0}'."),Type_alias_0_circularly_references_itself:n(2456,e.DiagnosticCategory.Error,"Type_alias_0_circularly_references_itself_2456","Type alias '{0}' circularly references itself."),Type_alias_name_cannot_be_0:n(2457,e.DiagnosticCategory.Error,"Type_alias_name_cannot_be_0_2457","Type alias name cannot be '{0}'."),An_AMD_module_cannot_have_multiple_name_assignments:n(2458,e.DiagnosticCategory.Error,"An_AMD_module_cannot_have_multiple_name_assignments_2458","An AMD module cannot have multiple name assignments."),Module_0_declares_1_locally_but_it_is_not_exported:n(2459,e.DiagnosticCategory.Error,"Module_0_declares_1_locally_but_it_is_not_exported_2459","Module '{0}' declares '{1}' locally, but it is not exported."),Module_0_declares_1_locally_but_it_is_exported_as_2:n(2460,e.DiagnosticCategory.Error,"Module_0_declares_1_locally_but_it_is_exported_as_2_2460","Module '{0}' declares '{1}' locally, but it is exported as '{2}'."),Type_0_is_not_an_array_type:n(2461,e.DiagnosticCategory.Error,"Type_0_is_not_an_array_type_2461","Type '{0}' is not an array type."),A_rest_element_must_be_last_in_a_destructuring_pattern:n(2462,e.DiagnosticCategory.Error,"A_rest_element_must_be_last_in_a_destructuring_pattern_2462","A rest element must be last in a destructuring pattern."),A_binding_pattern_parameter_cannot_be_optional_in_an_implementation_signature:n(2463,e.DiagnosticCategory.Error,"A_binding_pattern_parameter_cannot_be_optional_in_an_implementation_signature_2463","A binding pattern parameter cannot be optional in an implementation signature."),A_computed_property_name_must_be_of_type_string_number_symbol_or_any:n(2464,e.DiagnosticCategory.Error,"A_computed_property_name_must_be_of_type_string_number_symbol_or_any_2464","A computed property name must be of type 'string', 'number', 'symbol', or 'any'."),this_cannot_be_referenced_in_a_computed_property_name:n(2465,e.DiagnosticCategory.Error,"this_cannot_be_referenced_in_a_computed_property_name_2465","'this' cannot be referenced in a computed property name."),super_cannot_be_referenced_in_a_computed_property_name:n(2466,e.DiagnosticCategory.Error,"super_cannot_be_referenced_in_a_computed_property_name_2466","'super' cannot be referenced in a computed property name."),A_computed_property_name_cannot_reference_a_type_parameter_from_its_containing_type:n(2467,e.DiagnosticCategory.Error,"A_computed_property_name_cannot_reference_a_type_parameter_from_its_containing_type_2467","A computed property name cannot reference a type parameter from its containing type."),Cannot_find_global_value_0:n(2468,e.DiagnosticCategory.Error,"Cannot_find_global_value_0_2468","Cannot find global value '{0}'."),The_0_operator_cannot_be_applied_to_type_symbol:n(2469,e.DiagnosticCategory.Error,"The_0_operator_cannot_be_applied_to_type_symbol_2469","The '{0}' operator cannot be applied to type 'symbol'."),Symbol_reference_does_not_refer_to_the_global_Symbol_constructor_object:n(2470,e.DiagnosticCategory.Error,"Symbol_reference_does_not_refer_to_the_global_Symbol_constructor_object_2470","'Symbol' reference does not refer to the global Symbol constructor object."),A_computed_property_name_of_the_form_0_must_be_of_type_symbol:n(2471,e.DiagnosticCategory.Error,"A_computed_property_name_of_the_form_0_must_be_of_type_symbol_2471","A computed property name of the form '{0}' must be of type 'symbol'."),Spread_operator_in_new_expressions_is_only_available_when_targeting_ECMAScript_5_and_higher:n(2472,e.DiagnosticCategory.Error,"Spread_operator_in_new_expressions_is_only_available_when_targeting_ECMAScript_5_and_higher_2472","Spread operator in 'new' expressions is only available when targeting ECMAScript 5 and higher."),Enum_declarations_must_all_be_const_or_non_const:n(2473,e.DiagnosticCategory.Error,"Enum_declarations_must_all_be_const_or_non_const_2473","Enum declarations must all be const or non-const."),const_enum_member_initializers_can_only_contain_literal_values_and_other_computed_enum_values:n(2474,e.DiagnosticCategory.Error,"const_enum_member_initializers_can_only_contain_literal_values_and_other_computed_enum_values_2474","const enum member initializers can only contain literal values and other computed enum values."),const_enums_can_only_be_used_in_property_or_index_access_expressions_or_the_right_hand_side_of_an_import_declaration_or_export_assignment_or_type_query:n(2475,e.DiagnosticCategory.Error,"const_enums_can_only_be_used_in_property_or_index_access_expressions_or_the_right_hand_side_of_an_im_2475","'const' enums can only be used in property or index access expressions or the right hand side of an import declaration or export assignment or type query."),A_const_enum_member_can_only_be_accessed_using_a_string_literal:n(2476,e.DiagnosticCategory.Error,"A_const_enum_member_can_only_be_accessed_using_a_string_literal_2476","A const enum member can only be accessed using a string literal."),const_enum_member_initializer_was_evaluated_to_a_non_finite_value:n(2477,e.DiagnosticCategory.Error,"const_enum_member_initializer_was_evaluated_to_a_non_finite_value_2477","'const' enum member initializer was evaluated to a non-finite value."),const_enum_member_initializer_was_evaluated_to_disallowed_value_NaN:n(2478,e.DiagnosticCategory.Error,"const_enum_member_initializer_was_evaluated_to_disallowed_value_NaN_2478","'const' enum member initializer was evaluated to disallowed value 'NaN'."),Property_0_does_not_exist_on_const_enum_1:n(2479,e.DiagnosticCategory.Error,"Property_0_does_not_exist_on_const_enum_1_2479","Property '{0}' does not exist on 'const' enum '{1}'."),let_is_not_allowed_to_be_used_as_a_name_in_let_or_const_declarations:n(2480,e.DiagnosticCategory.Error,"let_is_not_allowed_to_be_used_as_a_name_in_let_or_const_declarations_2480","'let' is not allowed to be used as a name in 'let' or 'const' declarations."),Cannot_initialize_outer_scoped_variable_0_in_the_same_scope_as_block_scoped_declaration_1:n(2481,e.DiagnosticCategory.Error,"Cannot_initialize_outer_scoped_variable_0_in_the_same_scope_as_block_scoped_declaration_1_2481","Cannot initialize outer scoped variable '{0}' in the same scope as block scoped declaration '{1}'."),The_left_hand_side_of_a_for_of_statement_cannot_use_a_type_annotation:n(2483,e.DiagnosticCategory.Error,"The_left_hand_side_of_a_for_of_statement_cannot_use_a_type_annotation_2483","The left-hand side of a 'for...of' statement cannot use a type annotation."),Export_declaration_conflicts_with_exported_declaration_of_0:n(2484,e.DiagnosticCategory.Error,"Export_declaration_conflicts_with_exported_declaration_of_0_2484","Export declaration conflicts with exported declaration of '{0}'."),The_left_hand_side_of_a_for_of_statement_must_be_a_variable_or_a_property_access:n(2487,e.DiagnosticCategory.Error,"The_left_hand_side_of_a_for_of_statement_must_be_a_variable_or_a_property_access_2487","The left-hand side of a 'for...of' statement must be a variable or a property access."),Type_0_must_have_a_Symbol_iterator_method_that_returns_an_iterator:n(2488,e.DiagnosticCategory.Error,"Type_0_must_have_a_Symbol_iterator_method_that_returns_an_iterator_2488","Type '{0}' must have a '[Symbol.iterator]()' method that returns an iterator."),An_iterator_must_have_a_next_method:n(2489,e.DiagnosticCategory.Error,"An_iterator_must_have_a_next_method_2489","An iterator must have a 'next()' method."),The_type_returned_by_the_0_method_of_an_iterator_must_have_a_value_property:n(2490,e.DiagnosticCategory.Error,"The_type_returned_by_the_0_method_of_an_iterator_must_have_a_value_property_2490","The type returned by the '{0}()' method of an iterator must have a 'value' property."),The_left_hand_side_of_a_for_in_statement_cannot_be_a_destructuring_pattern:n(2491,e.DiagnosticCategory.Error,"The_left_hand_side_of_a_for_in_statement_cannot_be_a_destructuring_pattern_2491","The left-hand side of a 'for...in' statement cannot be a destructuring pattern."),Cannot_redeclare_identifier_0_in_catch_clause:n(2492,e.DiagnosticCategory.Error,"Cannot_redeclare_identifier_0_in_catch_clause_2492","Cannot redeclare identifier '{0}' in catch clause."),Tuple_type_0_of_length_1_has_no_element_at_index_2:n(2493,e.DiagnosticCategory.Error,"Tuple_type_0_of_length_1_has_no_element_at_index_2_2493","Tuple type '{0}' of length '{1}' has no element at index '{2}'."),Using_a_string_in_a_for_of_statement_is_only_supported_in_ECMAScript_5_and_higher:n(2494,e.DiagnosticCategory.Error,"Using_a_string_in_a_for_of_statement_is_only_supported_in_ECMAScript_5_and_higher_2494","Using a string in a 'for...of' statement is only supported in ECMAScript 5 and higher."),Type_0_is_not_an_array_type_or_a_string_type:n(2495,e.DiagnosticCategory.Error,"Type_0_is_not_an_array_type_or_a_string_type_2495","Type '{0}' is not an array type or a string type."),The_arguments_object_cannot_be_referenced_in_an_arrow_function_in_ES3_and_ES5_Consider_using_a_standard_function_expression:n(2496,e.DiagnosticCategory.Error,"The_arguments_object_cannot_be_referenced_in_an_arrow_function_in_ES3_and_ES5_Consider_using_a_stand_2496","The 'arguments' object cannot be referenced in an arrow function in ES3 and ES5. Consider using a standard function expression."),This_module_can_only_be_referenced_with_ECMAScript_imports_Slashexports_by_turning_on_the_0_flag_and_referencing_its_default_export:n(2497,e.DiagnosticCategory.Error,"This_module_can_only_be_referenced_with_ECMAScript_imports_Slashexports_by_turning_on_the_0_flag_and_2497","This module can only be referenced with ECMAScript imports/exports by turning on the '{0}' flag and referencing its default export."),Module_0_uses_export_and_cannot_be_used_with_export_Asterisk:n(2498,e.DiagnosticCategory.Error,"Module_0_uses_export_and_cannot_be_used_with_export_Asterisk_2498","Module '{0}' uses 'export =' and cannot be used with 'export *'."),An_interface_can_only_extend_an_identifier_Slashqualified_name_with_optional_type_arguments:n(2499,e.DiagnosticCategory.Error,"An_interface_can_only_extend_an_identifier_Slashqualified_name_with_optional_type_arguments_2499","An interface can only extend an identifier/qualified-name with optional type arguments."),A_class_can_only_implement_an_identifier_Slashqualified_name_with_optional_type_arguments:n(2500,e.DiagnosticCategory.Error,"A_class_can_only_implement_an_identifier_Slashqualified_name_with_optional_type_arguments_2500","A class can only implement an identifier/qualified-name with optional type arguments."),A_rest_element_cannot_contain_a_binding_pattern:n(2501,e.DiagnosticCategory.Error,"A_rest_element_cannot_contain_a_binding_pattern_2501","A rest element cannot contain a binding pattern."),_0_is_referenced_directly_or_indirectly_in_its_own_type_annotation:n(2502,e.DiagnosticCategory.Error,"_0_is_referenced_directly_or_indirectly_in_its_own_type_annotation_2502","'{0}' is referenced directly or indirectly in its own type annotation."),Cannot_find_namespace_0:n(2503,e.DiagnosticCategory.Error,"Cannot_find_namespace_0_2503","Cannot find namespace '{0}'."),Type_0_must_have_a_Symbol_asyncIterator_method_that_returns_an_async_iterator:n(2504,e.DiagnosticCategory.Error,"Type_0_must_have_a_Symbol_asyncIterator_method_that_returns_an_async_iterator_2504","Type '{0}' must have a '[Symbol.asyncIterator]()' method that returns an async iterator."),A_generator_cannot_have_a_void_type_annotation:n(2505,e.DiagnosticCategory.Error,"A_generator_cannot_have_a_void_type_annotation_2505","A generator cannot have a 'void' type annotation."),_0_is_referenced_directly_or_indirectly_in_its_own_base_expression:n(2506,e.DiagnosticCategory.Error,"_0_is_referenced_directly_or_indirectly_in_its_own_base_expression_2506","'{0}' is referenced directly or indirectly in its own base expression."),Type_0_is_not_a_constructor_function_type:n(2507,e.DiagnosticCategory.Error,"Type_0_is_not_a_constructor_function_type_2507","Type '{0}' is not a constructor function type."),No_base_constructor_has_the_specified_number_of_type_arguments:n(2508,e.DiagnosticCategory.Error,"No_base_constructor_has_the_specified_number_of_type_arguments_2508","No base constructor has the specified number of type arguments."),Base_constructor_return_type_0_is_not_an_object_type_or_intersection_of_object_types_with_statically_known_members:n(2509,e.DiagnosticCategory.Error,"Base_constructor_return_type_0_is_not_an_object_type_or_intersection_of_object_types_with_statically_2509","Base constructor return type '{0}' is not an object type or intersection of object types with statically known members."),Base_constructors_must_all_have_the_same_return_type:n(2510,e.DiagnosticCategory.Error,"Base_constructors_must_all_have_the_same_return_type_2510","Base constructors must all have the same return type."),Cannot_create_an_instance_of_an_abstract_class:n(2511,e.DiagnosticCategory.Error,"Cannot_create_an_instance_of_an_abstract_class_2511","Cannot create an instance of an abstract class."),Overload_signatures_must_all_be_abstract_or_non_abstract:n(2512,e.DiagnosticCategory.Error,"Overload_signatures_must_all_be_abstract_or_non_abstract_2512","Overload signatures must all be abstract or non-abstract."),Abstract_method_0_in_class_1_cannot_be_accessed_via_super_expression:n(2513,e.DiagnosticCategory.Error,"Abstract_method_0_in_class_1_cannot_be_accessed_via_super_expression_2513","Abstract method '{0}' in class '{1}' cannot be accessed via super expression."),Classes_containing_abstract_methods_must_be_marked_abstract:n(2514,e.DiagnosticCategory.Error,"Classes_containing_abstract_methods_must_be_marked_abstract_2514","Classes containing abstract methods must be marked abstract."),Non_abstract_class_0_does_not_implement_inherited_abstract_member_1_from_class_2:n(2515,e.DiagnosticCategory.Error,"Non_abstract_class_0_does_not_implement_inherited_abstract_member_1_from_class_2_2515","Non-abstract class '{0}' does not implement inherited abstract member '{1}' from class '{2}'."),All_declarations_of_an_abstract_method_must_be_consecutive:n(2516,e.DiagnosticCategory.Error,"All_declarations_of_an_abstract_method_must_be_consecutive_2516","All declarations of an abstract method must be consecutive."),Cannot_assign_an_abstract_constructor_type_to_a_non_abstract_constructor_type:n(2517,e.DiagnosticCategory.Error,"Cannot_assign_an_abstract_constructor_type_to_a_non_abstract_constructor_type_2517","Cannot assign an abstract constructor type to a non-abstract constructor type."),A_this_based_type_guard_is_not_compatible_with_a_parameter_based_type_guard:n(2518,e.DiagnosticCategory.Error,"A_this_based_type_guard_is_not_compatible_with_a_parameter_based_type_guard_2518","A 'this'-based type guard is not compatible with a parameter-based type guard."),An_async_iterator_must_have_a_next_method:n(2519,e.DiagnosticCategory.Error,"An_async_iterator_must_have_a_next_method_2519","An async iterator must have a 'next()' method."),Duplicate_identifier_0_Compiler_uses_declaration_1_to_support_async_functions:n(2520,e.DiagnosticCategory.Error,"Duplicate_identifier_0_Compiler_uses_declaration_1_to_support_async_functions_2520","Duplicate identifier '{0}'. Compiler uses declaration '{1}' to support async functions."),Expression_resolves_to_variable_declaration_0_that_compiler_uses_to_support_async_functions:n(2521,e.DiagnosticCategory.Error,"Expression_resolves_to_variable_declaration_0_that_compiler_uses_to_support_async_functions_2521","Expression resolves to variable declaration '{0}' that compiler uses to support async functions."),The_arguments_object_cannot_be_referenced_in_an_async_function_or_method_in_ES3_and_ES5_Consider_using_a_standard_function_or_method:n(2522,e.DiagnosticCategory.Error,"The_arguments_object_cannot_be_referenced_in_an_async_function_or_method_in_ES3_and_ES5_Consider_usi_2522","The 'arguments' object cannot be referenced in an async function or method in ES3 and ES5. Consider using a standard function or method."),yield_expressions_cannot_be_used_in_a_parameter_initializer:n(2523,e.DiagnosticCategory.Error,"yield_expressions_cannot_be_used_in_a_parameter_initializer_2523","'yield' expressions cannot be used in a parameter initializer."),await_expressions_cannot_be_used_in_a_parameter_initializer:n(2524,e.DiagnosticCategory.Error,"await_expressions_cannot_be_used_in_a_parameter_initializer_2524","'await' expressions cannot be used in a parameter initializer."),Initializer_provides_no_value_for_this_binding_element_and_the_binding_element_has_no_default_value:n(2525,e.DiagnosticCategory.Error,"Initializer_provides_no_value_for_this_binding_element_and_the_binding_element_has_no_default_value_2525","Initializer provides no value for this binding element and the binding element has no default value."),A_this_type_is_available_only_in_a_non_static_member_of_a_class_or_interface:n(2526,e.DiagnosticCategory.Error,"A_this_type_is_available_only_in_a_non_static_member_of_a_class_or_interface_2526","A 'this' type is available only in a non-static member of a class or interface."),The_inferred_type_of_0_references_an_inaccessible_1_type_A_type_annotation_is_necessary:n(2527,e.DiagnosticCategory.Error,"The_inferred_type_of_0_references_an_inaccessible_1_type_A_type_annotation_is_necessary_2527","The inferred type of '{0}' references an inaccessible '{1}' type. A type annotation is necessary."),A_module_cannot_have_multiple_default_exports:n(2528,e.DiagnosticCategory.Error,"A_module_cannot_have_multiple_default_exports_2528","A module cannot have multiple default exports."),Duplicate_identifier_0_Compiler_reserves_name_1_in_top_level_scope_of_a_module_containing_async_functions:n(2529,e.DiagnosticCategory.Error,"Duplicate_identifier_0_Compiler_reserves_name_1_in_top_level_scope_of_a_module_containing_async_func_2529","Duplicate identifier '{0}'. Compiler reserves name '{1}' in top level scope of a module containing async functions."),Property_0_is_incompatible_with_index_signature:n(2530,e.DiagnosticCategory.Error,"Property_0_is_incompatible_with_index_signature_2530","Property '{0}' is incompatible with index signature."),Object_is_possibly_null:n(2531,e.DiagnosticCategory.Error,"Object_is_possibly_null_2531","Object is possibly 'null'."),Object_is_possibly_undefined:n(2532,e.DiagnosticCategory.Error,"Object_is_possibly_undefined_2532","Object is possibly 'undefined'."),Object_is_possibly_null_or_undefined:n(2533,e.DiagnosticCategory.Error,"Object_is_possibly_null_or_undefined_2533","Object is possibly 'null' or 'undefined'."),A_function_returning_never_cannot_have_a_reachable_end_point:n(2534,e.DiagnosticCategory.Error,"A_function_returning_never_cannot_have_a_reachable_end_point_2534","A function returning 'never' cannot have a reachable end point."),Enum_type_0_has_members_with_initializers_that_are_not_literals:n(2535,e.DiagnosticCategory.Error,"Enum_type_0_has_members_with_initializers_that_are_not_literals_2535","Enum type '{0}' has members with initializers that are not literals."),Type_0_cannot_be_used_to_index_type_1:n(2536,e.DiagnosticCategory.Error,"Type_0_cannot_be_used_to_index_type_1_2536","Type '{0}' cannot be used to index type '{1}'."),Type_0_has_no_matching_index_signature_for_type_1:n(2537,e.DiagnosticCategory.Error,"Type_0_has_no_matching_index_signature_for_type_1_2537","Type '{0}' has no matching index signature for type '{1}'."),Type_0_cannot_be_used_as_an_index_type:n(2538,e.DiagnosticCategory.Error,"Type_0_cannot_be_used_as_an_index_type_2538","Type '{0}' cannot be used as an index type."),Cannot_assign_to_0_because_it_is_not_a_variable:n(2539,e.DiagnosticCategory.Error,"Cannot_assign_to_0_because_it_is_not_a_variable_2539","Cannot assign to '{0}' because it is not a variable."),Cannot_assign_to_0_because_it_is_a_read_only_property:n(2540,e.DiagnosticCategory.Error,"Cannot_assign_to_0_because_it_is_a_read_only_property_2540","Cannot assign to '{0}' because it is a read-only property."),The_target_of_an_assignment_must_be_a_variable_or_a_property_access:n(2541,e.DiagnosticCategory.Error,"The_target_of_an_assignment_must_be_a_variable_or_a_property_access_2541","The target of an assignment must be a variable or a property access."),Index_signature_in_type_0_only_permits_reading:n(2542,e.DiagnosticCategory.Error,"Index_signature_in_type_0_only_permits_reading_2542","Index signature in type '{0}' only permits reading."),Duplicate_identifier_newTarget_Compiler_uses_variable_declaration_newTarget_to_capture_new_target_meta_property_reference:n(2543,e.DiagnosticCategory.Error,"Duplicate_identifier_newTarget_Compiler_uses_variable_declaration_newTarget_to_capture_new_target_me_2543","Duplicate identifier '_newTarget'. Compiler uses variable declaration '_newTarget' to capture 'new.target' meta-property reference."),Expression_resolves_to_variable_declaration_newTarget_that_compiler_uses_to_capture_new_target_meta_property_reference:n(2544,e.DiagnosticCategory.Error,"Expression_resolves_to_variable_declaration_newTarget_that_compiler_uses_to_capture_new_target_meta__2544","Expression resolves to variable declaration '_newTarget' that compiler uses to capture 'new.target' meta-property reference."),A_mixin_class_must_have_a_constructor_with_a_single_rest_parameter_of_type_any:n(2545,e.DiagnosticCategory.Error,"A_mixin_class_must_have_a_constructor_with_a_single_rest_parameter_of_type_any_2545","A mixin class must have a constructor with a single rest parameter of type 'any[]'."),The_type_returned_by_the_0_method_of_an_async_iterator_must_be_a_promise_for_a_type_with_a_value_property:n(2547,e.DiagnosticCategory.Error,"The_type_returned_by_the_0_method_of_an_async_iterator_must_be_a_promise_for_a_type_with_a_value_pro_2547","The type returned by the '{0}()' method of an async iterator must be a promise for a type with a 'value' property."),Type_0_is_not_an_array_type_or_does_not_have_a_Symbol_iterator_method_that_returns_an_iterator:n(2548,e.DiagnosticCategory.Error,"Type_0_is_not_an_array_type_or_does_not_have_a_Symbol_iterator_method_that_returns_an_iterator_2548","Type '{0}' is not an array type or does not have a '[Symbol.iterator]()' method that returns an iterator."),Type_0_is_not_an_array_type_or_a_string_type_or_does_not_have_a_Symbol_iterator_method_that_returns_an_iterator:n(2549,e.DiagnosticCategory.Error,"Type_0_is_not_an_array_type_or_a_string_type_or_does_not_have_a_Symbol_iterator_method_that_returns__2549","Type '{0}' is not an array type or a string type or does not have a '[Symbol.iterator]()' method that returns an iterator."),Property_0_does_not_exist_on_type_1_Do_you_need_to_change_your_target_library_Try_changing_the_lib_compiler_option_to_2_or_later:n(2550,e.DiagnosticCategory.Error,"Property_0_does_not_exist_on_type_1_Do_you_need_to_change_your_target_library_Try_changing_the_lib_c_2550","Property '{0}' does not exist on type '{1}'. Do you need to change your target library? Try changing the 'lib' compiler option to '{2}' or later."),Property_0_does_not_exist_on_type_1_Did_you_mean_2:n(2551,e.DiagnosticCategory.Error,"Property_0_does_not_exist_on_type_1_Did_you_mean_2_2551","Property '{0}' does not exist on type '{1}'. Did you mean '{2}'?"),Cannot_find_name_0_Did_you_mean_1:n(2552,e.DiagnosticCategory.Error,"Cannot_find_name_0_Did_you_mean_1_2552","Cannot find name '{0}'. Did you mean '{1}'?"),Computed_values_are_not_permitted_in_an_enum_with_string_valued_members:n(2553,e.DiagnosticCategory.Error,"Computed_values_are_not_permitted_in_an_enum_with_string_valued_members_2553","Computed values are not permitted in an enum with string valued members."),Expected_0_arguments_but_got_1:n(2554,e.DiagnosticCategory.Error,"Expected_0_arguments_but_got_1_2554","Expected {0} arguments, but got {1}."),Expected_at_least_0_arguments_but_got_1:n(2555,e.DiagnosticCategory.Error,"Expected_at_least_0_arguments_but_got_1_2555","Expected at least {0} arguments, but got {1}."),A_spread_argument_must_either_have_a_tuple_type_or_be_passed_to_a_rest_parameter:n(2556,e.DiagnosticCategory.Error,"A_spread_argument_must_either_have_a_tuple_type_or_be_passed_to_a_rest_parameter_2556","A spread argument must either have a tuple type or be passed to a rest parameter."),Expected_0_type_arguments_but_got_1:n(2558,e.DiagnosticCategory.Error,"Expected_0_type_arguments_but_got_1_2558","Expected {0} type arguments, but got {1}."),Type_0_has_no_properties_in_common_with_type_1:n(2559,e.DiagnosticCategory.Error,"Type_0_has_no_properties_in_common_with_type_1_2559","Type '{0}' has no properties in common with type '{1}'."),Value_of_type_0_has_no_properties_in_common_with_type_1_Did_you_mean_to_call_it:n(2560,e.DiagnosticCategory.Error,"Value_of_type_0_has_no_properties_in_common_with_type_1_Did_you_mean_to_call_it_2560","Value of type '{0}' has no properties in common with type '{1}'. Did you mean to call it?"),Object_literal_may_only_specify_known_properties_but_0_does_not_exist_in_type_1_Did_you_mean_to_write_2:n(2561,e.DiagnosticCategory.Error,"Object_literal_may_only_specify_known_properties_but_0_does_not_exist_in_type_1_Did_you_mean_to_writ_2561","Object literal may only specify known properties, but '{0}' does not exist in type '{1}'. Did you mean to write '{2}'?"),Base_class_expressions_cannot_reference_class_type_parameters:n(2562,e.DiagnosticCategory.Error,"Base_class_expressions_cannot_reference_class_type_parameters_2562","Base class expressions cannot reference class type parameters."),The_containing_function_or_module_body_is_too_large_for_control_flow_analysis:n(2563,e.DiagnosticCategory.Error,"The_containing_function_or_module_body_is_too_large_for_control_flow_analysis_2563","The containing function or module body is too large for control flow analysis."),Property_0_has_no_initializer_and_is_not_definitely_assigned_in_the_constructor:n(2564,e.DiagnosticCategory.Error,"Property_0_has_no_initializer_and_is_not_definitely_assigned_in_the_constructor_2564","Property '{0}' has no initializer and is not definitely assigned in the constructor."),Property_0_is_used_before_being_assigned:n(2565,e.DiagnosticCategory.Error,"Property_0_is_used_before_being_assigned_2565","Property '{0}' is used before being assigned."),A_rest_element_cannot_have_a_property_name:n(2566,e.DiagnosticCategory.Error,"A_rest_element_cannot_have_a_property_name_2566","A rest element cannot have a property name."),Enum_declarations_can_only_merge_with_namespace_or_other_enum_declarations:n(2567,e.DiagnosticCategory.Error,"Enum_declarations_can_only_merge_with_namespace_or_other_enum_declarations_2567","Enum declarations can only merge with namespace or other enum declarations."),Type_0_is_not_an_array_type_or_a_string_type_Use_compiler_option_downlevelIteration_to_allow_iterating_of_iterators:n(2569,e.DiagnosticCategory.Error,"Type_0_is_not_an_array_type_or_a_string_type_Use_compiler_option_downlevelIteration_to_allow_iterati_2569","Type '{0}' is not an array type or a string type. Use compiler option '--downlevelIteration' to allow iterating of iterators."),Object_is_of_type_unknown:n(2571,e.DiagnosticCategory.Error,"Object_is_of_type_unknown_2571","Object is of type 'unknown'."),Rest_signatures_are_incompatible:n(2572,e.DiagnosticCategory.Error,"Rest_signatures_are_incompatible_2572","Rest signatures are incompatible."),Property_0_is_incompatible_with_rest_element_type:n(2573,e.DiagnosticCategory.Error,"Property_0_is_incompatible_with_rest_element_type_2573","Property '{0}' is incompatible with rest element type."),A_rest_element_type_must_be_an_array_type:n(2574,e.DiagnosticCategory.Error,"A_rest_element_type_must_be_an_array_type_2574","A rest element type must be an array type."),No_overload_expects_0_arguments_but_overloads_do_exist_that_expect_either_1_or_2_arguments:n(2575,e.DiagnosticCategory.Error,"No_overload_expects_0_arguments_but_overloads_do_exist_that_expect_either_1_or_2_arguments_2575","No overload expects {0} arguments, but overloads do exist that expect either {1} or {2} arguments."),Property_0_does_not_exist_on_type_1_Did_you_mean_to_access_the_static_member_2_instead:n(2576,e.DiagnosticCategory.Error,"Property_0_does_not_exist_on_type_1_Did_you_mean_to_access_the_static_member_2_instead_2576","Property '{0}' does not exist on type '{1}'. Did you mean to access the static member '{2}' instead?"),Return_type_annotation_circularly_references_itself:n(2577,e.DiagnosticCategory.Error,"Return_type_annotation_circularly_references_itself_2577","Return type annotation circularly references itself."),Unused_ts_expect_error_directive:n(2578,e.DiagnosticCategory.Error,"Unused_ts_expect_error_directive_2578","Unused '@ts-expect-error' directive."),Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_node_Try_npm_i_save_dev_types_Slashnode:n(2580,e.DiagnosticCategory.Error,"Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_node_Try_npm_i_save_dev_types_Slashno_2580","Cannot find name '{0}'. Do you need to install type definitions for node? Try `npm i --save-dev @types/node`."),Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_jQuery_Try_npm_i_save_dev_types_Slashjquery:n(2581,e.DiagnosticCategory.Error,"Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_jQuery_Try_npm_i_save_dev_types_Slash_2581","Cannot find name '{0}'. Do you need to install type definitions for jQuery? Try `npm i --save-dev @types/jquery`."),Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_a_test_runner_Try_npm_i_save_dev_types_Slashjest_or_npm_i_save_dev_types_Slashmocha:n(2582,e.DiagnosticCategory.Error,"Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_a_test_runner_Try_npm_i_save_dev_type_2582","Cannot find name '{0}'. Do you need to install type definitions for a test runner? Try `npm i --save-dev @types/jest` or `npm i --save-dev @types/mocha`."),Cannot_find_name_0_Do_you_need_to_change_your_target_library_Try_changing_the_lib_compiler_option_to_1_or_later:n(2583,e.DiagnosticCategory.Error,"Cannot_find_name_0_Do_you_need_to_change_your_target_library_Try_changing_the_lib_compiler_option_to_2583","Cannot find name '{0}'. Do you need to change your target library? Try changing the 'lib' compiler option to '{1}' or later."),Cannot_find_name_0_Do_you_need_to_change_your_target_library_Try_changing_the_lib_compiler_option_to_include_dom:n(2584,e.DiagnosticCategory.Error,"Cannot_find_name_0_Do_you_need_to_change_your_target_library_Try_changing_the_lib_compiler_option_to_2584","Cannot find name '{0}'. Do you need to change your target library? Try changing the 'lib' compiler option to include 'dom'."),_0_only_refers_to_a_type_but_is_being_used_as_a_value_here_Do_you_need_to_change_your_target_library_Try_changing_the_lib_compiler_option_to_es2015_or_later:n(2585,e.DiagnosticCategory.Error,"_0_only_refers_to_a_type_but_is_being_used_as_a_value_here_Do_you_need_to_change_your_target_library_2585","'{0}' only refers to a type, but is being used as a value here. Do you need to change your target library? Try changing the 'lib' compiler option to es2015 or later."),Enum_type_0_circularly_references_itself:n(2586,e.DiagnosticCategory.Error,"Enum_type_0_circularly_references_itself_2586","Enum type '{0}' circularly references itself."),JSDoc_type_0_circularly_references_itself:n(2587,e.DiagnosticCategory.Error,"JSDoc_type_0_circularly_references_itself_2587","JSDoc type '{0}' circularly references itself."),Cannot_assign_to_0_because_it_is_a_constant:n(2588,e.DiagnosticCategory.Error,"Cannot_assign_to_0_because_it_is_a_constant_2588","Cannot assign to '{0}' because it is a constant."),Type_instantiation_is_excessively_deep_and_possibly_infinite:n(2589,e.DiagnosticCategory.Error,"Type_instantiation_is_excessively_deep_and_possibly_infinite_2589","Type instantiation is excessively deep and possibly infinite."),Expression_produces_a_union_type_that_is_too_complex_to_represent:n(2590,e.DiagnosticCategory.Error,"Expression_produces_a_union_type_that_is_too_complex_to_represent_2590","Expression produces a union type that is too complex to represent."),Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_node_Try_npm_i_save_dev_types_Slashnode_and_then_add_node_to_the_types_field_in_your_tsconfig:n(2591,e.DiagnosticCategory.Error,"Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_node_Try_npm_i_save_dev_types_Slashno_2591","Cannot find name '{0}'. Do you need to install type definitions for node? Try `npm i --save-dev @types/node` and then add 'node' to the types field in your tsconfig."),Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_jQuery_Try_npm_i_save_dev_types_Slashjquery_and_then_add_jquery_to_the_types_field_in_your_tsconfig:n(2592,e.DiagnosticCategory.Error,"Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_jQuery_Try_npm_i_save_dev_types_Slash_2592","Cannot find name '{0}'. Do you need to install type definitions for jQuery? Try `npm i --save-dev @types/jquery` and then add 'jquery' to the types field in your tsconfig."),Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_a_test_runner_Try_npm_i_save_dev_types_Slashjest_or_npm_i_save_dev_types_Slashmocha_and_then_add_jest_or_mocha_to_the_types_field_in_your_tsconfig:n(2593,e.DiagnosticCategory.Error,"Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_a_test_runner_Try_npm_i_save_dev_type_2593","Cannot find name '{0}'. Do you need to install type definitions for a test runner? Try `npm i --save-dev @types/jest` or `npm i --save-dev @types/mocha` and then add 'jest' or 'mocha' to the types field in your tsconfig."),This_module_is_declared_with_using_export_and_can_only_be_used_with_a_default_import_when_using_the_0_flag:n(2594,e.DiagnosticCategory.Error,"This_module_is_declared_with_using_export_and_can_only_be_used_with_a_default_import_when_using_the__2594","This module is declared with using 'export =', and can only be used with a default import when using the '{0}' flag."),_0_can_only_be_imported_by_using_a_default_import:n(2595,e.DiagnosticCategory.Error,"_0_can_only_be_imported_by_using_a_default_import_2595","'{0}' can only be imported by using a default import."),_0_can_only_be_imported_by_turning_on_the_esModuleInterop_flag_and_using_a_default_import:n(2596,e.DiagnosticCategory.Error,"_0_can_only_be_imported_by_turning_on_the_esModuleInterop_flag_and_using_a_default_import_2596","'{0}' can only be imported by turning on the 'esModuleInterop' flag and using a default import."),_0_can_only_be_imported_by_using_a_require_call_or_by_using_a_default_import:n(2597,e.DiagnosticCategory.Error,"_0_can_only_be_imported_by_using_a_require_call_or_by_using_a_default_import_2597","'{0}' can only be imported by using a 'require' call or by using a default import."),_0_can_only_be_imported_by_using_a_require_call_or_by_turning_on_the_esModuleInterop_flag_and_using_a_default_import:n(2598,e.DiagnosticCategory.Error,"_0_can_only_be_imported_by_using_a_require_call_or_by_turning_on_the_esModuleInterop_flag_and_using__2598","'{0}' can only be imported by using a 'require' call or by turning on the 'esModuleInterop' flag and using a default import."),JSX_element_attributes_type_0_may_not_be_a_union_type:n(2600,e.DiagnosticCategory.Error,"JSX_element_attributes_type_0_may_not_be_a_union_type_2600","JSX element attributes type '{0}' may not be a union type."),The_return_type_of_a_JSX_element_constructor_must_return_an_object_type:n(2601,e.DiagnosticCategory.Error,"The_return_type_of_a_JSX_element_constructor_must_return_an_object_type_2601","The return type of a JSX element constructor must return an object type."),JSX_element_implicitly_has_type_any_because_the_global_type_JSX_Element_does_not_exist:n(2602,e.DiagnosticCategory.Error,"JSX_element_implicitly_has_type_any_because_the_global_type_JSX_Element_does_not_exist_2602","JSX element implicitly has type 'any' because the global type 'JSX.Element' does not exist."),Property_0_in_type_1_is_not_assignable_to_type_2:n(2603,e.DiagnosticCategory.Error,"Property_0_in_type_1_is_not_assignable_to_type_2_2603","Property '{0}' in type '{1}' is not assignable to type '{2}'."),JSX_element_type_0_does_not_have_any_construct_or_call_signatures:n(2604,e.DiagnosticCategory.Error,"JSX_element_type_0_does_not_have_any_construct_or_call_signatures_2604","JSX element type '{0}' does not have any construct or call signatures."),JSX_element_type_0_is_not_a_constructor_function_for_JSX_elements:n(2605,e.DiagnosticCategory.Error,"JSX_element_type_0_is_not_a_constructor_function_for_JSX_elements_2605","JSX element type '{0}' is not a constructor function for JSX elements."),Property_0_of_JSX_spread_attribute_is_not_assignable_to_target_property:n(2606,e.DiagnosticCategory.Error,"Property_0_of_JSX_spread_attribute_is_not_assignable_to_target_property_2606","Property '{0}' of JSX spread attribute is not assignable to target property."),JSX_element_class_does_not_support_attributes_because_it_does_not_have_a_0_property:n(2607,e.DiagnosticCategory.Error,"JSX_element_class_does_not_support_attributes_because_it_does_not_have_a_0_property_2607","JSX element class does not support attributes because it does not have a '{0}' property."),The_global_type_JSX_0_may_not_have_more_than_one_property:n(2608,e.DiagnosticCategory.Error,"The_global_type_JSX_0_may_not_have_more_than_one_property_2608","The global type 'JSX.{0}' may not have more than one property."),JSX_spread_child_must_be_an_array_type:n(2609,e.DiagnosticCategory.Error,"JSX_spread_child_must_be_an_array_type_2609","JSX spread child must be an array type."),_0_is_defined_as_an_accessor_in_class_1_but_is_overridden_here_in_2_as_an_instance_property:n(2610,e.DiagnosticCategory.Error,"_0_is_defined_as_an_accessor_in_class_1_but_is_overridden_here_in_2_as_an_instance_property_2610","'{0}' is defined as an accessor in class '{1}', but is overridden here in '{2}' as an instance property."),_0_is_defined_as_a_property_in_class_1_but_is_overridden_here_in_2_as_an_accessor:n(2611,e.DiagnosticCategory.Error,"_0_is_defined_as_a_property_in_class_1_but_is_overridden_here_in_2_as_an_accessor_2611","'{0}' is defined as a property in class '{1}', but is overridden here in '{2}' as an accessor."),Property_0_will_overwrite_the_base_property_in_1_If_this_is_intentional_add_an_initializer_Otherwise_add_a_declare_modifier_or_remove_the_redundant_declaration:n(2612,e.DiagnosticCategory.Error,"Property_0_will_overwrite_the_base_property_in_1_If_this_is_intentional_add_an_initializer_Otherwise_2612","Property '{0}' will overwrite the base property in '{1}'. If this is intentional, add an initializer. Otherwise, add a 'declare' modifier or remove the redundant declaration."),Module_0_has_no_default_export_Did_you_mean_to_use_import_1_from_0_instead:n(2613,e.DiagnosticCategory.Error,"Module_0_has_no_default_export_Did_you_mean_to_use_import_1_from_0_instead_2613","Module '{0}' has no default export. Did you mean to use 'import { {1} } from {0}' instead?"),Module_0_has_no_exported_member_1_Did_you_mean_to_use_import_1_from_0_instead:n(2614,e.DiagnosticCategory.Error,"Module_0_has_no_exported_member_1_Did_you_mean_to_use_import_1_from_0_instead_2614","Module '{0}' has no exported member '{1}'. Did you mean to use 'import {1} from {0}' instead?"),Type_of_property_0_circularly_references_itself_in_mapped_type_1:n(2615,e.DiagnosticCategory.Error,"Type_of_property_0_circularly_references_itself_in_mapped_type_1_2615","Type of property '{0}' circularly references itself in mapped type '{1}'."),_0_can_only_be_imported_by_using_import_1_require_2_or_a_default_import:n(2616,e.DiagnosticCategory.Error,"_0_can_only_be_imported_by_using_import_1_require_2_or_a_default_import_2616","'{0}' can only be imported by using 'import {1} = require({2})' or a default import."),_0_can_only_be_imported_by_using_import_1_require_2_or_by_turning_on_the_esModuleInterop_flag_and_using_a_default_import:n(2617,e.DiagnosticCategory.Error,"_0_can_only_be_imported_by_using_import_1_require_2_or_by_turning_on_the_esModuleInterop_flag_and_us_2617","'{0}' can only be imported by using 'import {1} = require({2})' or by turning on the 'esModuleInterop' flag and using a default import."),Source_has_0_element_s_but_target_requires_1:n(2618,e.DiagnosticCategory.Error,"Source_has_0_element_s_but_target_requires_1_2618","Source has {0} element(s) but target requires {1}."),Source_has_0_element_s_but_target_allows_only_1:n(2619,e.DiagnosticCategory.Error,"Source_has_0_element_s_but_target_allows_only_1_2619","Source has {0} element(s) but target allows only {1}."),Target_requires_0_element_s_but_source_may_have_fewer:n(2620,e.DiagnosticCategory.Error,"Target_requires_0_element_s_but_source_may_have_fewer_2620","Target requires {0} element(s) but source may have fewer."),Target_allows_only_0_element_s_but_source_may_have_more:n(2621,e.DiagnosticCategory.Error,"Target_allows_only_0_element_s_but_source_may_have_more_2621","Target allows only {0} element(s) but source may have more."),Source_provides_no_match_for_required_element_at_position_0_in_target:n(2623,e.DiagnosticCategory.Error,"Source_provides_no_match_for_required_element_at_position_0_in_target_2623","Source provides no match for required element at position {0} in target."),Source_provides_no_match_for_variadic_element_at_position_0_in_target:n(2624,e.DiagnosticCategory.Error,"Source_provides_no_match_for_variadic_element_at_position_0_in_target_2624","Source provides no match for variadic element at position {0} in target."),Variadic_element_at_position_0_in_source_does_not_match_element_at_position_1_in_target:n(2625,e.DiagnosticCategory.Error,"Variadic_element_at_position_0_in_source_does_not_match_element_at_position_1_in_target_2625","Variadic element at position {0} in source does not match element at position {1} in target."),Type_at_position_0_in_source_is_not_compatible_with_type_at_position_1_in_target:n(2626,e.DiagnosticCategory.Error,"Type_at_position_0_in_source_is_not_compatible_with_type_at_position_1_in_target_2626","Type at position {0} in source is not compatible with type at position {1} in target."),Type_at_positions_0_through_1_in_source_is_not_compatible_with_type_at_position_2_in_target:n(2627,e.DiagnosticCategory.Error,"Type_at_positions_0_through_1_in_source_is_not_compatible_with_type_at_position_2_in_target_2627","Type at positions {0} through {1} in source is not compatible with type at position {2} in target."),Cannot_assign_to_0_because_it_is_an_enum:n(2628,e.DiagnosticCategory.Error,"Cannot_assign_to_0_because_it_is_an_enum_2628","Cannot assign to '{0}' because it is an enum."),Cannot_assign_to_0_because_it_is_a_class:n(2629,e.DiagnosticCategory.Error,"Cannot_assign_to_0_because_it_is_a_class_2629","Cannot assign to '{0}' because it is a class."),Cannot_assign_to_0_because_it_is_a_function:n(2630,e.DiagnosticCategory.Error,"Cannot_assign_to_0_because_it_is_a_function_2630","Cannot assign to '{0}' because it is a function."),Cannot_assign_to_0_because_it_is_a_namespace:n(2631,e.DiagnosticCategory.Error,"Cannot_assign_to_0_because_it_is_a_namespace_2631","Cannot assign to '{0}' because it is a namespace."),Cannot_assign_to_0_because_it_is_an_import:n(2632,e.DiagnosticCategory.Error,"Cannot_assign_to_0_because_it_is_an_import_2632","Cannot assign to '{0}' because it is an import."),JSX_property_access_expressions_cannot_include_JSX_namespace_names:n(2633,e.DiagnosticCategory.Error,"JSX_property_access_expressions_cannot_include_JSX_namespace_names_2633","JSX property access expressions cannot include JSX namespace names"),Cannot_augment_module_0_with_value_exports_because_it_resolves_to_a_non_module_entity:n(2649,e.DiagnosticCategory.Error,"Cannot_augment_module_0_with_value_exports_because_it_resolves_to_a_non_module_entity_2649","Cannot augment module '{0}' with value exports because it resolves to a non-module entity."),A_member_initializer_in_a_enum_declaration_cannot_reference_members_declared_after_it_including_members_defined_in_other_enums:n(2651,e.DiagnosticCategory.Error,"A_member_initializer_in_a_enum_declaration_cannot_reference_members_declared_after_it_including_memb_2651","A member initializer in a enum declaration cannot reference members declared after it, including members defined in other enums."),Merged_declaration_0_cannot_include_a_default_export_declaration_Consider_adding_a_separate_export_default_0_declaration_instead:n(2652,e.DiagnosticCategory.Error,"Merged_declaration_0_cannot_include_a_default_export_declaration_Consider_adding_a_separate_export_d_2652","Merged declaration '{0}' cannot include a default export declaration. Consider adding a separate 'export default {0}' declaration instead."),Non_abstract_class_expression_does_not_implement_inherited_abstract_member_0_from_class_1:n(2653,e.DiagnosticCategory.Error,"Non_abstract_class_expression_does_not_implement_inherited_abstract_member_0_from_class_1_2653","Non-abstract class expression does not implement inherited abstract member '{0}' from class '{1}'."),Exported_external_package_typings_file_cannot_contain_tripleslash_references_Please_contact_the_package_author_to_update_the_package_definition:n(2654,e.DiagnosticCategory.Error,"Exported_external_package_typings_file_cannot_contain_tripleslash_references_Please_contact_the_pack_2654","Exported external package typings file cannot contain tripleslash references. Please contact the package author to update the package definition."),Exported_external_package_typings_file_0_is_not_a_module_Please_contact_the_package_author_to_update_the_package_definition:n(2656,e.DiagnosticCategory.Error,"Exported_external_package_typings_file_0_is_not_a_module_Please_contact_the_package_author_to_update_2656","Exported external package typings file '{0}' is not a module. Please contact the package author to update the package definition."),JSX_expressions_must_have_one_parent_element:n(2657,e.DiagnosticCategory.Error,"JSX_expressions_must_have_one_parent_element_2657","JSX expressions must have one parent element."),Type_0_provides_no_match_for_the_signature_1:n(2658,e.DiagnosticCategory.Error,"Type_0_provides_no_match_for_the_signature_1_2658","Type '{0}' provides no match for the signature '{1}'."),super_is_only_allowed_in_members_of_object_literal_expressions_when_option_target_is_ES2015_or_higher:n(2659,e.DiagnosticCategory.Error,"super_is_only_allowed_in_members_of_object_literal_expressions_when_option_target_is_ES2015_or_highe_2659","'super' is only allowed in members of object literal expressions when option 'target' is 'ES2015' or higher."),super_can_only_be_referenced_in_members_of_derived_classes_or_object_literal_expressions:n(2660,e.DiagnosticCategory.Error,"super_can_only_be_referenced_in_members_of_derived_classes_or_object_literal_expressions_2660","'super' can only be referenced in members of derived classes or object literal expressions."),Cannot_export_0_Only_local_declarations_can_be_exported_from_a_module:n(2661,e.DiagnosticCategory.Error,"Cannot_export_0_Only_local_declarations_can_be_exported_from_a_module_2661","Cannot export '{0}'. Only local declarations can be exported from a module."),Cannot_find_name_0_Did_you_mean_the_static_member_1_0:n(2662,e.DiagnosticCategory.Error,"Cannot_find_name_0_Did_you_mean_the_static_member_1_0_2662","Cannot find name '{0}'. Did you mean the static member '{1}.{0}'?"),Cannot_find_name_0_Did_you_mean_the_instance_member_this_0:n(2663,e.DiagnosticCategory.Error,"Cannot_find_name_0_Did_you_mean_the_instance_member_this_0_2663","Cannot find name '{0}'. Did you mean the instance member 'this.{0}'?"),Invalid_module_name_in_augmentation_module_0_cannot_be_found:n(2664,e.DiagnosticCategory.Error,"Invalid_module_name_in_augmentation_module_0_cannot_be_found_2664","Invalid module name in augmentation, module '{0}' cannot be found."),Invalid_module_name_in_augmentation_Module_0_resolves_to_an_untyped_module_at_1_which_cannot_be_augmented:n(2665,e.DiagnosticCategory.Error,"Invalid_module_name_in_augmentation_Module_0_resolves_to_an_untyped_module_at_1_which_cannot_be_augm_2665","Invalid module name in augmentation. Module '{0}' resolves to an untyped module at '{1}', which cannot be augmented."),Exports_and_export_assignments_are_not_permitted_in_module_augmentations:n(2666,e.DiagnosticCategory.Error,"Exports_and_export_assignments_are_not_permitted_in_module_augmentations_2666","Exports and export assignments are not permitted in module augmentations."),Imports_are_not_permitted_in_module_augmentations_Consider_moving_them_to_the_enclosing_external_module:n(2667,e.DiagnosticCategory.Error,"Imports_are_not_permitted_in_module_augmentations_Consider_moving_them_to_the_enclosing_external_mod_2667","Imports are not permitted in module augmentations. Consider moving them to the enclosing external module."),export_modifier_cannot_be_applied_to_ambient_modules_and_module_augmentations_since_they_are_always_visible:n(2668,e.DiagnosticCategory.Error,"export_modifier_cannot_be_applied_to_ambient_modules_and_module_augmentations_since_they_are_always__2668","'export' modifier cannot be applied to ambient modules and module augmentations since they are always visible."),Augmentations_for_the_global_scope_can_only_be_directly_nested_in_external_modules_or_ambient_module_declarations:n(2669,e.DiagnosticCategory.Error,"Augmentations_for_the_global_scope_can_only_be_directly_nested_in_external_modules_or_ambient_module_2669","Augmentations for the global scope can only be directly nested in external modules or ambient module declarations."),Augmentations_for_the_global_scope_should_have_declare_modifier_unless_they_appear_in_already_ambient_context:n(2670,e.DiagnosticCategory.Error,"Augmentations_for_the_global_scope_should_have_declare_modifier_unless_they_appear_in_already_ambien_2670","Augmentations for the global scope should have 'declare' modifier unless they appear in already ambient context."),Cannot_augment_module_0_because_it_resolves_to_a_non_module_entity:n(2671,e.DiagnosticCategory.Error,"Cannot_augment_module_0_because_it_resolves_to_a_non_module_entity_2671","Cannot augment module '{0}' because it resolves to a non-module entity."),Cannot_assign_a_0_constructor_type_to_a_1_constructor_type:n(2672,e.DiagnosticCategory.Error,"Cannot_assign_a_0_constructor_type_to_a_1_constructor_type_2672","Cannot assign a '{0}' constructor type to a '{1}' constructor type."),Constructor_of_class_0_is_private_and_only_accessible_within_the_class_declaration:n(2673,e.DiagnosticCategory.Error,"Constructor_of_class_0_is_private_and_only_accessible_within_the_class_declaration_2673","Constructor of class '{0}' is private and only accessible within the class declaration."),Constructor_of_class_0_is_protected_and_only_accessible_within_the_class_declaration:n(2674,e.DiagnosticCategory.Error,"Constructor_of_class_0_is_protected_and_only_accessible_within_the_class_declaration_2674","Constructor of class '{0}' is protected and only accessible within the class declaration."),Cannot_extend_a_class_0_Class_constructor_is_marked_as_private:n(2675,e.DiagnosticCategory.Error,"Cannot_extend_a_class_0_Class_constructor_is_marked_as_private_2675","Cannot extend a class '{0}'. Class constructor is marked as private."),Accessors_must_both_be_abstract_or_non_abstract:n(2676,e.DiagnosticCategory.Error,"Accessors_must_both_be_abstract_or_non_abstract_2676","Accessors must both be abstract or non-abstract."),A_type_predicate_s_type_must_be_assignable_to_its_parameter_s_type:n(2677,e.DiagnosticCategory.Error,"A_type_predicate_s_type_must_be_assignable_to_its_parameter_s_type_2677","A type predicate's type must be assignable to its parameter's type."),Type_0_is_not_comparable_to_type_1:n(2678,e.DiagnosticCategory.Error,"Type_0_is_not_comparable_to_type_1_2678","Type '{0}' is not comparable to type '{1}'."),A_function_that_is_called_with_the_new_keyword_cannot_have_a_this_type_that_is_void:n(2679,e.DiagnosticCategory.Error,"A_function_that_is_called_with_the_new_keyword_cannot_have_a_this_type_that_is_void_2679","A function that is called with the 'new' keyword cannot have a 'this' type that is 'void'."),A_0_parameter_must_be_the_first_parameter:n(2680,e.DiagnosticCategory.Error,"A_0_parameter_must_be_the_first_parameter_2680","A '{0}' parameter must be the first parameter."),A_constructor_cannot_have_a_this_parameter:n(2681,e.DiagnosticCategory.Error,"A_constructor_cannot_have_a_this_parameter_2681","A constructor cannot have a 'this' parameter."),get_and_set_accessor_must_have_the_same_this_type:n(2682,e.DiagnosticCategory.Error,"get_and_set_accessor_must_have_the_same_this_type_2682","'get' and 'set' accessor must have the same 'this' type."),this_implicitly_has_type_any_because_it_does_not_have_a_type_annotation:n(2683,e.DiagnosticCategory.Error,"this_implicitly_has_type_any_because_it_does_not_have_a_type_annotation_2683","'this' implicitly has type 'any' because it does not have a type annotation."),The_this_context_of_type_0_is_not_assignable_to_method_s_this_of_type_1:n(2684,e.DiagnosticCategory.Error,"The_this_context_of_type_0_is_not_assignable_to_method_s_this_of_type_1_2684","The 'this' context of type '{0}' is not assignable to method's 'this' of type '{1}'."),The_this_types_of_each_signature_are_incompatible:n(2685,e.DiagnosticCategory.Error,"The_this_types_of_each_signature_are_incompatible_2685","The 'this' types of each signature are incompatible."),_0_refers_to_a_UMD_global_but_the_current_file_is_a_module_Consider_adding_an_import_instead:n(2686,e.DiagnosticCategory.Error,"_0_refers_to_a_UMD_global_but_the_current_file_is_a_module_Consider_adding_an_import_instead_2686","'{0}' refers to a UMD global, but the current file is a module. Consider adding an import instead."),All_declarations_of_0_must_have_identical_modifiers:n(2687,e.DiagnosticCategory.Error,"All_declarations_of_0_must_have_identical_modifiers_2687","All declarations of '{0}' must have identical modifiers."),Cannot_find_type_definition_file_for_0:n(2688,e.DiagnosticCategory.Error,"Cannot_find_type_definition_file_for_0_2688","Cannot find type definition file for '{0}'."),Cannot_extend_an_interface_0_Did_you_mean_implements:n(2689,e.DiagnosticCategory.Error,"Cannot_extend_an_interface_0_Did_you_mean_implements_2689","Cannot extend an interface '{0}'. Did you mean 'implements'?"),_0_only_refers_to_a_type_but_is_being_used_as_a_value_here_Did_you_mean_to_use_1_in_0:n(2690,e.DiagnosticCategory.Error,"_0_only_refers_to_a_type_but_is_being_used_as_a_value_here_Did_you_mean_to_use_1_in_0_2690","'{0}' only refers to a type, but is being used as a value here. Did you mean to use '{1} in {0}'?"),An_import_path_cannot_end_with_a_0_extension_Consider_importing_1_instead:n(2691,e.DiagnosticCategory.Error,"An_import_path_cannot_end_with_a_0_extension_Consider_importing_1_instead_2691","An import path cannot end with a '{0}' extension. Consider importing '{1}' instead."),_0_is_a_primitive_but_1_is_a_wrapper_object_Prefer_using_0_when_possible:n(2692,e.DiagnosticCategory.Error,"_0_is_a_primitive_but_1_is_a_wrapper_object_Prefer_using_0_when_possible_2692","'{0}' is a primitive, but '{1}' is a wrapper object. Prefer using '{0}' when possible."),_0_only_refers_to_a_type_but_is_being_used_as_a_value_here:n(2693,e.DiagnosticCategory.Error,"_0_only_refers_to_a_type_but_is_being_used_as_a_value_here_2693","'{0}' only refers to a type, but is being used as a value here."),Namespace_0_has_no_exported_member_1:n(2694,e.DiagnosticCategory.Error,"Namespace_0_has_no_exported_member_1_2694","Namespace '{0}' has no exported member '{1}'."),Left_side_of_comma_operator_is_unused_and_has_no_side_effects:n(2695,e.DiagnosticCategory.Error,"Left_side_of_comma_operator_is_unused_and_has_no_side_effects_2695","Left side of comma operator is unused and has no side effects.",!0),The_Object_type_is_assignable_to_very_few_other_types_Did_you_mean_to_use_the_any_type_instead:n(2696,e.DiagnosticCategory.Error,"The_Object_type_is_assignable_to_very_few_other_types_Did_you_mean_to_use_the_any_type_instead_2696","The 'Object' type is assignable to very few other types. Did you mean to use the 'any' type instead?"),An_async_function_or_method_must_return_a_Promise_Make_sure_you_have_a_declaration_for_Promise_or_include_ES2015_in_your_lib_option:n(2697,e.DiagnosticCategory.Error,"An_async_function_or_method_must_return_a_Promise_Make_sure_you_have_a_declaration_for_Promise_or_in_2697","An async function or method must return a 'Promise'. Make sure you have a declaration for 'Promise' or include 'ES2015' in your '--lib' option."),Spread_types_may_only_be_created_from_object_types:n(2698,e.DiagnosticCategory.Error,"Spread_types_may_only_be_created_from_object_types_2698","Spread types may only be created from object types."),Static_property_0_conflicts_with_built_in_property_Function_0_of_constructor_function_1:n(2699,e.DiagnosticCategory.Error,"Static_property_0_conflicts_with_built_in_property_Function_0_of_constructor_function_1_2699","Static property '{0}' conflicts with built-in property 'Function.{0}' of constructor function '{1}'."),Rest_types_may_only_be_created_from_object_types:n(2700,e.DiagnosticCategory.Error,"Rest_types_may_only_be_created_from_object_types_2700","Rest types may only be created from object types."),The_target_of_an_object_rest_assignment_must_be_a_variable_or_a_property_access:n(2701,e.DiagnosticCategory.Error,"The_target_of_an_object_rest_assignment_must_be_a_variable_or_a_property_access_2701","The target of an object rest assignment must be a variable or a property access."),_0_only_refers_to_a_type_but_is_being_used_as_a_namespace_here:n(2702,e.DiagnosticCategory.Error,"_0_only_refers_to_a_type_but_is_being_used_as_a_namespace_here_2702","'{0}' only refers to a type, but is being used as a namespace here."),The_operand_of_a_delete_operator_must_be_a_property_reference:n(2703,e.DiagnosticCategory.Error,"The_operand_of_a_delete_operator_must_be_a_property_reference_2703","The operand of a 'delete' operator must be a property reference."),The_operand_of_a_delete_operator_cannot_be_a_read_only_property:n(2704,e.DiagnosticCategory.Error,"The_operand_of_a_delete_operator_cannot_be_a_read_only_property_2704","The operand of a 'delete' operator cannot be a read-only property."),An_async_function_or_method_in_ES5_SlashES3_requires_the_Promise_constructor_Make_sure_you_have_a_declaration_for_the_Promise_constructor_or_include_ES2015_in_your_lib_option:n(2705,e.DiagnosticCategory.Error,"An_async_function_or_method_in_ES5_SlashES3_requires_the_Promise_constructor_Make_sure_you_have_a_de_2705","An async function or method in ES5/ES3 requires the 'Promise' constructor.  Make sure you have a declaration for the 'Promise' constructor or include 'ES2015' in your '--lib' option."),Required_type_parameters_may_not_follow_optional_type_parameters:n(2706,e.DiagnosticCategory.Error,"Required_type_parameters_may_not_follow_optional_type_parameters_2706","Required type parameters may not follow optional type parameters."),Generic_type_0_requires_between_1_and_2_type_arguments:n(2707,e.DiagnosticCategory.Error,"Generic_type_0_requires_between_1_and_2_type_arguments_2707","Generic type '{0}' requires between {1} and {2} type arguments."),Cannot_use_namespace_0_as_a_value:n(2708,e.DiagnosticCategory.Error,"Cannot_use_namespace_0_as_a_value_2708","Cannot use namespace '{0}' as a value."),Cannot_use_namespace_0_as_a_type:n(2709,e.DiagnosticCategory.Error,"Cannot_use_namespace_0_as_a_type_2709","Cannot use namespace '{0}' as a type."),_0_are_specified_twice_The_attribute_named_0_will_be_overwritten:n(2710,e.DiagnosticCategory.Error,"_0_are_specified_twice_The_attribute_named_0_will_be_overwritten_2710","'{0}' are specified twice. The attribute named '{0}' will be overwritten."),A_dynamic_import_call_returns_a_Promise_Make_sure_you_have_a_declaration_for_Promise_or_include_ES2015_in_your_lib_option:n(2711,e.DiagnosticCategory.Error,"A_dynamic_import_call_returns_a_Promise_Make_sure_you_have_a_declaration_for_Promise_or_include_ES20_2711","A dynamic import call returns a 'Promise'. Make sure you have a declaration for 'Promise' or include 'ES2015' in your '--lib' option."),A_dynamic_import_call_in_ES5_SlashES3_requires_the_Promise_constructor_Make_sure_you_have_a_declaration_for_the_Promise_constructor_or_include_ES2015_in_your_lib_option:n(2712,e.DiagnosticCategory.Error,"A_dynamic_import_call_in_ES5_SlashES3_requires_the_Promise_constructor_Make_sure_you_have_a_declarat_2712","A dynamic import call in ES5/ES3 requires the 'Promise' constructor.  Make sure you have a declaration for the 'Promise' constructor or include 'ES2015' in your '--lib' option."),Cannot_access_0_1_because_0_is_a_type_but_not_a_namespace_Did_you_mean_to_retrieve_the_type_of_the_property_1_in_0_with_0_1:n(2713,e.DiagnosticCategory.Error,"Cannot_access_0_1_because_0_is_a_type_but_not_a_namespace_Did_you_mean_to_retrieve_the_type_of_the_p_2713","Cannot access '{0}.{1}' because '{0}' is a type, but not a namespace. Did you mean to retrieve the type of the property '{1}' in '{0}' with '{0}[\"{1}\"]'?"),The_expression_of_an_export_assignment_must_be_an_identifier_or_qualified_name_in_an_ambient_context:n(2714,e.DiagnosticCategory.Error,"The_expression_of_an_export_assignment_must_be_an_identifier_or_qualified_name_in_an_ambient_context_2714","The expression of an export assignment must be an identifier or qualified name in an ambient context."),Abstract_property_0_in_class_1_cannot_be_accessed_in_the_constructor:n(2715,e.DiagnosticCategory.Error,"Abstract_property_0_in_class_1_cannot_be_accessed_in_the_constructor_2715","Abstract property '{0}' in class '{1}' cannot be accessed in the constructor."),Type_parameter_0_has_a_circular_default:n(2716,e.DiagnosticCategory.Error,"Type_parameter_0_has_a_circular_default_2716","Type parameter '{0}' has a circular default."),Subsequent_property_declarations_must_have_the_same_type_Property_0_must_be_of_type_1_but_here_has_type_2:n(2717,e.DiagnosticCategory.Error,"Subsequent_property_declarations_must_have_the_same_type_Property_0_must_be_of_type_1_but_here_has_t_2717","Subsequent property declarations must have the same type.  Property '{0}' must be of type '{1}', but here has type '{2}'."),Duplicate_property_0:n(2718,e.DiagnosticCategory.Error,"Duplicate_property_0_2718","Duplicate property '{0}'."),Type_0_is_not_assignable_to_type_1_Two_different_types_with_this_name_exist_but_they_are_unrelated:n(2719,e.DiagnosticCategory.Error,"Type_0_is_not_assignable_to_type_1_Two_different_types_with_this_name_exist_but_they_are_unrelated_2719","Type '{0}' is not assignable to type '{1}'. Two different types with this name exist, but they are unrelated."),Class_0_incorrectly_implements_class_1_Did_you_mean_to_extend_1_and_inherit_its_members_as_a_subclass:n(2720,e.DiagnosticCategory.Error,"Class_0_incorrectly_implements_class_1_Did_you_mean_to_extend_1_and_inherit_its_members_as_a_subclas_2720","Class '{0}' incorrectly implements class '{1}'. Did you mean to extend '{1}' and inherit its members as a subclass?"),Cannot_invoke_an_object_which_is_possibly_null:n(2721,e.DiagnosticCategory.Error,"Cannot_invoke_an_object_which_is_possibly_null_2721","Cannot invoke an object which is possibly 'null'."),Cannot_invoke_an_object_which_is_possibly_undefined:n(2722,e.DiagnosticCategory.Error,"Cannot_invoke_an_object_which_is_possibly_undefined_2722","Cannot invoke an object which is possibly 'undefined'."),Cannot_invoke_an_object_which_is_possibly_null_or_undefined:n(2723,e.DiagnosticCategory.Error,"Cannot_invoke_an_object_which_is_possibly_null_or_undefined_2723","Cannot invoke an object which is possibly 'null' or 'undefined'."),_0_has_no_exported_member_named_1_Did_you_mean_2:n(2724,e.DiagnosticCategory.Error,"_0_has_no_exported_member_named_1_Did_you_mean_2_2724","'{0}' has no exported member named '{1}'. Did you mean '{2}'?"),Class_name_cannot_be_Object_when_targeting_ES5_with_module_0:n(2725,e.DiagnosticCategory.Error,"Class_name_cannot_be_Object_when_targeting_ES5_with_module_0_2725","Class name cannot be 'Object' when targeting ES5 with module {0}."),Cannot_find_lib_definition_for_0:n(2726,e.DiagnosticCategory.Error,"Cannot_find_lib_definition_for_0_2726","Cannot find lib definition for '{0}'."),Cannot_find_lib_definition_for_0_Did_you_mean_1:n(2727,e.DiagnosticCategory.Error,"Cannot_find_lib_definition_for_0_Did_you_mean_1_2727","Cannot find lib definition for '{0}'. Did you mean '{1}'?"),_0_is_declared_here:n(2728,e.DiagnosticCategory.Message,"_0_is_declared_here_2728","'{0}' is declared here."),Property_0_is_used_before_its_initialization:n(2729,e.DiagnosticCategory.Error,"Property_0_is_used_before_its_initialization_2729","Property '{0}' is used before its initialization."),An_arrow_function_cannot_have_a_this_parameter:n(2730,e.DiagnosticCategory.Error,"An_arrow_function_cannot_have_a_this_parameter_2730","An arrow function cannot have a 'this' parameter."),Implicit_conversion_of_a_symbol_to_a_string_will_fail_at_runtime_Consider_wrapping_this_expression_in_String:n(2731,e.DiagnosticCategory.Error,"Implicit_conversion_of_a_symbol_to_a_string_will_fail_at_runtime_Consider_wrapping_this_expression_i_2731","Implicit conversion of a 'symbol' to a 'string' will fail at runtime. Consider wrapping this expression in 'String(...)'."),Cannot_find_module_0_Consider_using_resolveJsonModule_to_import_module_with_json_extension:n(2732,e.DiagnosticCategory.Error,"Cannot_find_module_0_Consider_using_resolveJsonModule_to_import_module_with_json_extension_2732","Cannot find module '{0}'. Consider using '--resolveJsonModule' to import module with '.json' extension."),Property_0_was_also_declared_here:n(2733,e.DiagnosticCategory.Error,"Property_0_was_also_declared_here_2733","Property '{0}' was also declared here."),Are_you_missing_a_semicolon:n(2734,e.DiagnosticCategory.Error,"Are_you_missing_a_semicolon_2734","Are you missing a semicolon?"),Did_you_mean_for_0_to_be_constrained_to_type_new_args_Colon_any_1:n(2735,e.DiagnosticCategory.Error,"Did_you_mean_for_0_to_be_constrained_to_type_new_args_Colon_any_1_2735","Did you mean for '{0}' to be constrained to type 'new (...args: any[]) => {1}'?"),Operator_0_cannot_be_applied_to_type_1:n(2736,e.DiagnosticCategory.Error,"Operator_0_cannot_be_applied_to_type_1_2736","Operator '{0}' cannot be applied to type '{1}'."),BigInt_literals_are_not_available_when_targeting_lower_than_ES2020:n(2737,e.DiagnosticCategory.Error,"BigInt_literals_are_not_available_when_targeting_lower_than_ES2020_2737","BigInt literals are not available when targeting lower than ES2020."),An_outer_value_of_this_is_shadowed_by_this_container:n(2738,e.DiagnosticCategory.Message,"An_outer_value_of_this_is_shadowed_by_this_container_2738","An outer value of 'this' is shadowed by this container."),Type_0_is_missing_the_following_properties_from_type_1_Colon_2:n(2739,e.DiagnosticCategory.Error,"Type_0_is_missing_the_following_properties_from_type_1_Colon_2_2739","Type '{0}' is missing the following properties from type '{1}': {2}"),Type_0_is_missing_the_following_properties_from_type_1_Colon_2_and_3_more:n(2740,e.DiagnosticCategory.Error,"Type_0_is_missing_the_following_properties_from_type_1_Colon_2_and_3_more_2740","Type '{0}' is missing the following properties from type '{1}': {2}, and {3} more."),Property_0_is_missing_in_type_1_but_required_in_type_2:n(2741,e.DiagnosticCategory.Error,"Property_0_is_missing_in_type_1_but_required_in_type_2_2741","Property '{0}' is missing in type '{1}' but required in type '{2}'."),The_inferred_type_of_0_cannot_be_named_without_a_reference_to_1_This_is_likely_not_portable_A_type_annotation_is_necessary:n(2742,e.DiagnosticCategory.Error,"The_inferred_type_of_0_cannot_be_named_without_a_reference_to_1_This_is_likely_not_portable_A_type_a_2742","The inferred type of '{0}' cannot be named without a reference to '{1}'. This is likely not portable. A type annotation is necessary."),No_overload_expects_0_type_arguments_but_overloads_do_exist_that_expect_either_1_or_2_type_arguments:n(2743,e.DiagnosticCategory.Error,"No_overload_expects_0_type_arguments_but_overloads_do_exist_that_expect_either_1_or_2_type_arguments_2743","No overload expects {0} type arguments, but overloads do exist that expect either {1} or {2} type arguments."),Type_parameter_defaults_can_only_reference_previously_declared_type_parameters:n(2744,e.DiagnosticCategory.Error,"Type_parameter_defaults_can_only_reference_previously_declared_type_parameters_2744","Type parameter defaults can only reference previously declared type parameters."),This_JSX_tag_s_0_prop_expects_type_1_which_requires_multiple_children_but_only_a_single_child_was_provided:n(2745,e.DiagnosticCategory.Error,"This_JSX_tag_s_0_prop_expects_type_1_which_requires_multiple_children_but_only_a_single_child_was_pr_2745","This JSX tag's '{0}' prop expects type '{1}' which requires multiple children, but only a single child was provided."),This_JSX_tag_s_0_prop_expects_a_single_child_of_type_1_but_multiple_children_were_provided:n(2746,e.DiagnosticCategory.Error,"This_JSX_tag_s_0_prop_expects_a_single_child_of_type_1_but_multiple_children_were_provided_2746","This JSX tag's '{0}' prop expects a single child of type '{1}', but multiple children were provided."),_0_components_don_t_accept_text_as_child_elements_Text_in_JSX_has_the_type_string_but_the_expected_type_of_1_is_2:n(2747,e.DiagnosticCategory.Error,"_0_components_don_t_accept_text_as_child_elements_Text_in_JSX_has_the_type_string_but_the_expected_t_2747","'{0}' components don't accept text as child elements. Text in JSX has the type 'string', but the expected type of '{1}' is '{2}'."),Cannot_access_ambient_const_enums_when_the_isolatedModules_flag_is_provided:n(2748,e.DiagnosticCategory.Error,"Cannot_access_ambient_const_enums_when_the_isolatedModules_flag_is_provided_2748","Cannot access ambient const enums when the '--isolatedModules' flag is provided."),_0_refers_to_a_value_but_is_being_used_as_a_type_here_Did_you_mean_typeof_0:n(2749,e.DiagnosticCategory.Error,"_0_refers_to_a_value_but_is_being_used_as_a_type_here_Did_you_mean_typeof_0_2749","'{0}' refers to a value, but is being used as a type here. Did you mean 'typeof {0}'?"),The_implementation_signature_is_declared_here:n(2750,e.DiagnosticCategory.Error,"The_implementation_signature_is_declared_here_2750","The implementation signature is declared here."),Circularity_originates_in_type_at_this_location:n(2751,e.DiagnosticCategory.Error,"Circularity_originates_in_type_at_this_location_2751","Circularity originates in type at this location."),The_first_export_default_is_here:n(2752,e.DiagnosticCategory.Error,"The_first_export_default_is_here_2752","The first export default is here."),Another_export_default_is_here:n(2753,e.DiagnosticCategory.Error,"Another_export_default_is_here_2753","Another export default is here."),super_may_not_use_type_arguments:n(2754,e.DiagnosticCategory.Error,"super_may_not_use_type_arguments_2754","'super' may not use type arguments."),No_constituent_of_type_0_is_callable:n(2755,e.DiagnosticCategory.Error,"No_constituent_of_type_0_is_callable_2755","No constituent of type '{0}' is callable."),Not_all_constituents_of_type_0_are_callable:n(2756,e.DiagnosticCategory.Error,"Not_all_constituents_of_type_0_are_callable_2756","Not all constituents of type '{0}' are callable."),Type_0_has_no_call_signatures:n(2757,e.DiagnosticCategory.Error,"Type_0_has_no_call_signatures_2757","Type '{0}' has no call signatures."),Each_member_of_the_union_type_0_has_signatures_but_none_of_those_signatures_are_compatible_with_each_other:n(2758,e.DiagnosticCategory.Error,"Each_member_of_the_union_type_0_has_signatures_but_none_of_those_signatures_are_compatible_with_each_2758","Each member of the union type '{0}' has signatures, but none of those signatures are compatible with each other."),No_constituent_of_type_0_is_constructable:n(2759,e.DiagnosticCategory.Error,"No_constituent_of_type_0_is_constructable_2759","No constituent of type '{0}' is constructable."),Not_all_constituents_of_type_0_are_constructable:n(2760,e.DiagnosticCategory.Error,"Not_all_constituents_of_type_0_are_constructable_2760","Not all constituents of type '{0}' are constructable."),Type_0_has_no_construct_signatures:n(2761,e.DiagnosticCategory.Error,"Type_0_has_no_construct_signatures_2761","Type '{0}' has no construct signatures."),Each_member_of_the_union_type_0_has_construct_signatures_but_none_of_those_signatures_are_compatible_with_each_other:n(2762,e.DiagnosticCategory.Error,"Each_member_of_the_union_type_0_has_construct_signatures_but_none_of_those_signatures_are_compatible_2762","Each member of the union type '{0}' has construct signatures, but none of those signatures are compatible with each other."),Cannot_iterate_value_because_the_next_method_of_its_iterator_expects_type_1_but_for_of_will_always_send_0:n(2763,e.DiagnosticCategory.Error,"Cannot_iterate_value_because_the_next_method_of_its_iterator_expects_type_1_but_for_of_will_always_s_2763","Cannot iterate value because the 'next' method of its iterator expects type '{1}', but for-of will always send '{0}'."),Cannot_iterate_value_because_the_next_method_of_its_iterator_expects_type_1_but_array_spread_will_always_send_0:n(2764,e.DiagnosticCategory.Error,"Cannot_iterate_value_because_the_next_method_of_its_iterator_expects_type_1_but_array_spread_will_al_2764","Cannot iterate value because the 'next' method of its iterator expects type '{1}', but array spread will always send '{0}'."),Cannot_iterate_value_because_the_next_method_of_its_iterator_expects_type_1_but_array_destructuring_will_always_send_0:n(2765,e.DiagnosticCategory.Error,"Cannot_iterate_value_because_the_next_method_of_its_iterator_expects_type_1_but_array_destructuring__2765","Cannot iterate value because the 'next' method of its iterator expects type '{1}', but array destructuring will always send '{0}'."),Cannot_delegate_iteration_to_value_because_the_next_method_of_its_iterator_expects_type_1_but_the_containing_generator_will_always_send_0:n(2766,e.DiagnosticCategory.Error,"Cannot_delegate_iteration_to_value_because_the_next_method_of_its_iterator_expects_type_1_but_the_co_2766","Cannot delegate iteration to value because the 'next' method of its iterator expects type '{1}', but the containing generator will always send '{0}'."),The_0_property_of_an_iterator_must_be_a_method:n(2767,e.DiagnosticCategory.Error,"The_0_property_of_an_iterator_must_be_a_method_2767","The '{0}' property of an iterator must be a method."),The_0_property_of_an_async_iterator_must_be_a_method:n(2768,e.DiagnosticCategory.Error,"The_0_property_of_an_async_iterator_must_be_a_method_2768","The '{0}' property of an async iterator must be a method."),No_overload_matches_this_call:n(2769,e.DiagnosticCategory.Error,"No_overload_matches_this_call_2769","No overload matches this call."),The_last_overload_gave_the_following_error:n(2770,e.DiagnosticCategory.Error,"The_last_overload_gave_the_following_error_2770","The last overload gave the following error."),The_last_overload_is_declared_here:n(2771,e.DiagnosticCategory.Error,"The_last_overload_is_declared_here_2771","The last overload is declared here."),Overload_0_of_1_2_gave_the_following_error:n(2772,e.DiagnosticCategory.Error,"Overload_0_of_1_2_gave_the_following_error_2772","Overload {0} of {1}, '{2}', gave the following error."),Did_you_forget_to_use_await:n(2773,e.DiagnosticCategory.Error,"Did_you_forget_to_use_await_2773","Did you forget to use 'await'?"),This_condition_will_always_return_true_since_this_function_is_always_defined_Did_you_mean_to_call_it_instead:n(2774,e.DiagnosticCategory.Error,"This_condition_will_always_return_true_since_this_function_is_always_defined_Did_you_mean_to_call_it_2774","This condition will always return true since this function is always defined. Did you mean to call it instead?"),Assertions_require_every_name_in_the_call_target_to_be_declared_with_an_explicit_type_annotation:n(2775,e.DiagnosticCategory.Error,"Assertions_require_every_name_in_the_call_target_to_be_declared_with_an_explicit_type_annotation_2775","Assertions require every name in the call target to be declared with an explicit type annotation."),Assertions_require_the_call_target_to_be_an_identifier_or_qualified_name:n(2776,e.DiagnosticCategory.Error,"Assertions_require_the_call_target_to_be_an_identifier_or_qualified_name_2776","Assertions require the call target to be an identifier or qualified name."),The_operand_of_an_increment_or_decrement_operator_may_not_be_an_optional_property_access:n(2777,e.DiagnosticCategory.Error,"The_operand_of_an_increment_or_decrement_operator_may_not_be_an_optional_property_access_2777","The operand of an increment or decrement operator may not be an optional property access."),The_target_of_an_object_rest_assignment_may_not_be_an_optional_property_access:n(2778,e.DiagnosticCategory.Error,"The_target_of_an_object_rest_assignment_may_not_be_an_optional_property_access_2778","The target of an object rest assignment may not be an optional property access."),The_left_hand_side_of_an_assignment_expression_may_not_be_an_optional_property_access:n(2779,e.DiagnosticCategory.Error,"The_left_hand_side_of_an_assignment_expression_may_not_be_an_optional_property_access_2779","The left-hand side of an assignment expression may not be an optional property access."),The_left_hand_side_of_a_for_in_statement_may_not_be_an_optional_property_access:n(2780,e.DiagnosticCategory.Error,"The_left_hand_side_of_a_for_in_statement_may_not_be_an_optional_property_access_2780","The left-hand side of a 'for...in' statement may not be an optional property access."),The_left_hand_side_of_a_for_of_statement_may_not_be_an_optional_property_access:n(2781,e.DiagnosticCategory.Error,"The_left_hand_side_of_a_for_of_statement_may_not_be_an_optional_property_access_2781","The left-hand side of a 'for...of' statement may not be an optional property access."),_0_needs_an_explicit_type_annotation:n(2782,e.DiagnosticCategory.Message,"_0_needs_an_explicit_type_annotation_2782","'{0}' needs an explicit type annotation."),_0_is_specified_more_than_once_so_this_usage_will_be_overwritten:n(2783,e.DiagnosticCategory.Error,"_0_is_specified_more_than_once_so_this_usage_will_be_overwritten_2783","'{0}' is specified more than once, so this usage will be overwritten."),get_and_set_accessors_cannot_declare_this_parameters:n(2784,e.DiagnosticCategory.Error,"get_and_set_accessors_cannot_declare_this_parameters_2784","'get' and 'set' accessors cannot declare 'this' parameters."),This_spread_always_overwrites_this_property:n(2785,e.DiagnosticCategory.Error,"This_spread_always_overwrites_this_property_2785","This spread always overwrites this property."),_0_cannot_be_used_as_a_JSX_component:n(2786,e.DiagnosticCategory.Error,"_0_cannot_be_used_as_a_JSX_component_2786","'{0}' cannot be used as a JSX component."),Its_return_type_0_is_not_a_valid_JSX_element:n(2787,e.DiagnosticCategory.Error,"Its_return_type_0_is_not_a_valid_JSX_element_2787","Its return type '{0}' is not a valid JSX element."),Its_instance_type_0_is_not_a_valid_JSX_element:n(2788,e.DiagnosticCategory.Error,"Its_instance_type_0_is_not_a_valid_JSX_element_2788","Its instance type '{0}' is not a valid JSX element."),Its_element_type_0_is_not_a_valid_JSX_element:n(2789,e.DiagnosticCategory.Error,"Its_element_type_0_is_not_a_valid_JSX_element_2789","Its element type '{0}' is not a valid JSX element."),The_operand_of_a_delete_operator_must_be_optional:n(2790,e.DiagnosticCategory.Error,"The_operand_of_a_delete_operator_must_be_optional_2790","The operand of a 'delete' operator must be optional."),Exponentiation_cannot_be_performed_on_bigint_values_unless_the_target_option_is_set_to_es2016_or_later:n(2791,e.DiagnosticCategory.Error,"Exponentiation_cannot_be_performed_on_bigint_values_unless_the_target_option_is_set_to_es2016_or_lat_2791","Exponentiation cannot be performed on 'bigint' values unless the 'target' option is set to 'es2016' or later."),Cannot_find_module_0_Did_you_mean_to_set_the_moduleResolution_option_to_node_or_to_add_aliases_to_the_paths_option:n(2792,e.DiagnosticCategory.Error,"Cannot_find_module_0_Did_you_mean_to_set_the_moduleResolution_option_to_node_or_to_add_aliases_to_th_2792","Cannot find module '{0}'. Did you mean to set the 'moduleResolution' option to 'node', or to add aliases to the 'paths' option?"),The_call_would_have_succeeded_against_this_implementation_but_implementation_signatures_of_overloads_are_not_externally_visible:n(2793,e.DiagnosticCategory.Error,"The_call_would_have_succeeded_against_this_implementation_but_implementation_signatures_of_overloads_2793","The call would have succeeded against this implementation, but implementation signatures of overloads are not externally visible."),Expected_0_arguments_but_got_1_Did_you_forget_to_include_void_in_your_type_argument_to_Promise:n(2794,e.DiagnosticCategory.Error,"Expected_0_arguments_but_got_1_Did_you_forget_to_include_void_in_your_type_argument_to_Promise_2794","Expected {0} arguments, but got {1}. Did you forget to include 'void' in your type argument to 'Promise'?"),The_intrinsic_keyword_can_only_be_used_to_declare_compiler_provided_intrinsic_types:n(2795,e.DiagnosticCategory.Error,"The_intrinsic_keyword_can_only_be_used_to_declare_compiler_provided_intrinsic_types_2795","The 'intrinsic' keyword can only be used to declare compiler provided intrinsic types."),It_is_likely_that_you_are_missing_a_comma_to_separate_these_two_template_expressions_They_form_a_tagged_template_expression_which_cannot_be_invoked:n(2796,e.DiagnosticCategory.Error,"It_is_likely_that_you_are_missing_a_comma_to_separate_these_two_template_expressions_They_form_a_tag_2796","It is likely that you are missing a comma to separate these two template expressions. They form a tagged template expression which cannot be invoked."),A_mixin_class_that_extends_from_a_type_variable_containing_an_abstract_construct_signature_must_also_be_declared_abstract:n(2797,e.DiagnosticCategory.Error,"A_mixin_class_that_extends_from_a_type_variable_containing_an_abstract_construct_signature_must_also_2797","A mixin class that extends from a type variable containing an abstract construct signature must also be declared 'abstract'."),The_declaration_was_marked_as_deprecated_here:n(2798,e.DiagnosticCategory.Error,"The_declaration_was_marked_as_deprecated_here_2798","The declaration was marked as deprecated here."),Type_produces_a_tuple_type_that_is_too_large_to_represent:n(2799,e.DiagnosticCategory.Error,"Type_produces_a_tuple_type_that_is_too_large_to_represent_2799","Type produces a tuple type that is too large to represent."),Expression_produces_a_tuple_type_that_is_too_large_to_represent:n(2800,e.DiagnosticCategory.Error,"Expression_produces_a_tuple_type_that_is_too_large_to_represent_2800","Expression produces a tuple type that is too large to represent."),This_condition_will_always_return_true_since_this_0_is_always_defined:n(2801,e.DiagnosticCategory.Error,"This_condition_will_always_return_true_since_this_0_is_always_defined_2801","This condition will always return true since this '{0}' is always defined."),Type_0_can_only_be_iterated_through_when_using_the_downlevelIteration_flag_or_with_a_target_of_es2015_or_higher:n(2802,e.DiagnosticCategory.Error,"Type_0_can_only_be_iterated_through_when_using_the_downlevelIteration_flag_or_with_a_target_of_es201_2802","Type '{0}' can only be iterated through when using the '--downlevelIteration' flag or with a '--target' of 'es2015' or higher."),Cannot_assign_to_private_method_0_Private_methods_are_not_writable:n(2803,e.DiagnosticCategory.Error,"Cannot_assign_to_private_method_0_Private_methods_are_not_writable_2803","Cannot assign to private method '{0}'. Private methods are not writable."),Duplicate_identifier_0_Static_and_instance_elements_cannot_share_the_same_private_name:n(2804,e.DiagnosticCategory.Error,"Duplicate_identifier_0_Static_and_instance_elements_cannot_share_the_same_private_name_2804","Duplicate identifier '{0}'. Static and instance elements cannot share the same private name."),Static_fields_with_private_names_can_t_have_initializers_when_the_useDefineForClassFields_flag_is_not_specified_with_a_target_of_esnext_Consider_adding_the_useDefineForClassFields_flag:n(2805,e.DiagnosticCategory.Error,"Static_fields_with_private_names_can_t_have_initializers_when_the_useDefineForClassFields_flag_is_no_2805","Static fields with private names can't have initializers when the '--useDefineForClassFields' flag is not specified with a '--target' of 'esnext'. Consider adding the '--useDefineForClassFields' flag."),Private_accessor_was_defined_without_a_getter:n(2806,e.DiagnosticCategory.Error,"Private_accessor_was_defined_without_a_getter_2806","Private accessor was defined without a getter."),This_syntax_requires_an_imported_helper_named_1_with_2_parameters_which_is_not_compatible_with_the_one_in_0_Consider_upgrading_your_version_of_0:n(2807,e.DiagnosticCategory.Error,"This_syntax_requires_an_imported_helper_named_1_with_2_parameters_which_is_not_compatible_with_the_o_2807","This syntax requires an imported helper named '{1}' with {2} parameters, which is not compatible with the one in '{0}'. Consider upgrading your version of '{0}'."),A_get_accessor_must_be_at_least_as_accessible_as_the_setter:n(2808,e.DiagnosticCategory.Error,"A_get_accessor_must_be_at_least_as_accessible_as_the_setter_2808","A get accessor must be at least as accessible as the setter"),Declaration_or_statement_expected_This_follows_a_block_of_statements_so_if_you_intended_to_write_a_destructuring_assignment_you_might_need_to_wrap_the_the_whole_assignment_in_parentheses:n(2809,e.DiagnosticCategory.Error,"Declaration_or_statement_expected_This_follows_a_block_of_statements_so_if_you_intended_to_write_a_d_2809","Declaration or statement expected. This '=' follows a block of statements, so if you intended to write a destructuring assignment, you might need to wrap the the whole assignment in parentheses."),Property_0_may_not_be_used_in_a_static_property_s_initializer_in_the_same_class_when_target_is_esnext_and_useDefineForClassFields_is_false:n(2810,e.DiagnosticCategory.Error,"Property_0_may_not_be_used_in_a_static_property_s_initializer_in_the_same_class_when_target_is_esnex_2810","Property '{0}' may not be used in a static property's initializer in the same class when 'target' is 'esnext' and 'useDefineForClassFields' is 'false'."),Initializer_for_property_0:n(2811,e.DiagnosticCategory.Error,"Initializer_for_property_0_2811","Initializer for property '{0}'"),Property_0_does_not_exist_on_type_1_Try_changing_the_lib_compiler_option_to_include_dom:n(2812,e.DiagnosticCategory.Error,"Property_0_does_not_exist_on_type_1_Try_changing_the_lib_compiler_option_to_include_dom_2812","Property '{0}' does not exist on type '{1}'. Try changing the 'lib' compiler option to include 'dom'."),Import_declaration_0_is_using_private_name_1:n(4e3,e.DiagnosticCategory.Error,"Import_declaration_0_is_using_private_name_1_4000","Import declaration '{0}' is using private name '{1}'."),Type_parameter_0_of_exported_class_has_or_is_using_private_name_1:n(4002,e.DiagnosticCategory.Error,"Type_parameter_0_of_exported_class_has_or_is_using_private_name_1_4002","Type parameter '{0}' of exported class has or is using private name '{1}'."),Type_parameter_0_of_exported_interface_has_or_is_using_private_name_1:n(4004,e.DiagnosticCategory.Error,"Type_parameter_0_of_exported_interface_has_or_is_using_private_name_1_4004","Type parameter '{0}' of exported interface has or is using private name '{1}'."),Type_parameter_0_of_constructor_signature_from_exported_interface_has_or_is_using_private_name_1:n(4006,e.DiagnosticCategory.Error,"Type_parameter_0_of_constructor_signature_from_exported_interface_has_or_is_using_private_name_1_4006","Type parameter '{0}' of constructor signature from exported interface has or is using private name '{1}'."),Type_parameter_0_of_call_signature_from_exported_interface_has_or_is_using_private_name_1:n(4008,e.DiagnosticCategory.Error,"Type_parameter_0_of_call_signature_from_exported_interface_has_or_is_using_private_name_1_4008","Type parameter '{0}' of call signature from exported interface has or is using private name '{1}'."),Type_parameter_0_of_public_static_method_from_exported_class_has_or_is_using_private_name_1:n(4010,e.DiagnosticCategory.Error,"Type_parameter_0_of_public_static_method_from_exported_class_has_or_is_using_private_name_1_4010","Type parameter '{0}' of public static method from exported class has or is using private name '{1}'."),Type_parameter_0_of_public_method_from_exported_class_has_or_is_using_private_name_1:n(4012,e.DiagnosticCategory.Error,"Type_parameter_0_of_public_method_from_exported_class_has_or_is_using_private_name_1_4012","Type parameter '{0}' of public method from exported class has or is using private name '{1}'."),Type_parameter_0_of_method_from_exported_interface_has_or_is_using_private_name_1:n(4014,e.DiagnosticCategory.Error,"Type_parameter_0_of_method_from_exported_interface_has_or_is_using_private_name_1_4014","Type parameter '{0}' of method from exported interface has or is using private name '{1}'."),Type_parameter_0_of_exported_function_has_or_is_using_private_name_1:n(4016,e.DiagnosticCategory.Error,"Type_parameter_0_of_exported_function_has_or_is_using_private_name_1_4016","Type parameter '{0}' of exported function has or is using private name '{1}'."),Implements_clause_of_exported_class_0_has_or_is_using_private_name_1:n(4019,e.DiagnosticCategory.Error,"Implements_clause_of_exported_class_0_has_or_is_using_private_name_1_4019","Implements clause of exported class '{0}' has or is using private name '{1}'."),extends_clause_of_exported_class_0_has_or_is_using_private_name_1:n(4020,e.DiagnosticCategory.Error,"extends_clause_of_exported_class_0_has_or_is_using_private_name_1_4020","'extends' clause of exported class '{0}' has or is using private name '{1}'."),extends_clause_of_exported_class_has_or_is_using_private_name_0:n(4021,e.DiagnosticCategory.Error,"extends_clause_of_exported_class_has_or_is_using_private_name_0_4021","'extends' clause of exported class has or is using private name '{0}'."),extends_clause_of_exported_interface_0_has_or_is_using_private_name_1:n(4022,e.DiagnosticCategory.Error,"extends_clause_of_exported_interface_0_has_or_is_using_private_name_1_4022","'extends' clause of exported interface '{0}' has or is using private name '{1}'."),Exported_variable_0_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named:n(4023,e.DiagnosticCategory.Error,"Exported_variable_0_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named_4023","Exported variable '{0}' has or is using name '{1}' from external module {2} but cannot be named."),Exported_variable_0_has_or_is_using_name_1_from_private_module_2:n(4024,e.DiagnosticCategory.Error,"Exported_variable_0_has_or_is_using_name_1_from_private_module_2_4024","Exported variable '{0}' has or is using name '{1}' from private module '{2}'."),Exported_variable_0_has_or_is_using_private_name_1:n(4025,e.DiagnosticCategory.Error,"Exported_variable_0_has_or_is_using_private_name_1_4025","Exported variable '{0}' has or is using private name '{1}'."),Public_static_property_0_of_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named:n(4026,e.DiagnosticCategory.Error,"Public_static_property_0_of_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot__4026","Public static property '{0}' of exported class has or is using name '{1}' from external module {2} but cannot be named."),Public_static_property_0_of_exported_class_has_or_is_using_name_1_from_private_module_2:n(4027,e.DiagnosticCategory.Error,"Public_static_property_0_of_exported_class_has_or_is_using_name_1_from_private_module_2_4027","Public static property '{0}' of exported class has or is using name '{1}' from private module '{2}'."),Public_static_property_0_of_exported_class_has_or_is_using_private_name_1:n(4028,e.DiagnosticCategory.Error,"Public_static_property_0_of_exported_class_has_or_is_using_private_name_1_4028","Public static property '{0}' of exported class has or is using private name '{1}'."),Public_property_0_of_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named:n(4029,e.DiagnosticCategory.Error,"Public_property_0_of_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_name_4029","Public property '{0}' of exported class has or is using name '{1}' from external module {2} but cannot be named."),Public_property_0_of_exported_class_has_or_is_using_name_1_from_private_module_2:n(4030,e.DiagnosticCategory.Error,"Public_property_0_of_exported_class_has_or_is_using_name_1_from_private_module_2_4030","Public property '{0}' of exported class has or is using name '{1}' from private module '{2}'."),Public_property_0_of_exported_class_has_or_is_using_private_name_1:n(4031,e.DiagnosticCategory.Error,"Public_property_0_of_exported_class_has_or_is_using_private_name_1_4031","Public property '{0}' of exported class has or is using private name '{1}'."),Property_0_of_exported_interface_has_or_is_using_name_1_from_private_module_2:n(4032,e.DiagnosticCategory.Error,"Property_0_of_exported_interface_has_or_is_using_name_1_from_private_module_2_4032","Property '{0}' of exported interface has or is using name '{1}' from private module '{2}'."),Property_0_of_exported_interface_has_or_is_using_private_name_1:n(4033,e.DiagnosticCategory.Error,"Property_0_of_exported_interface_has_or_is_using_private_name_1_4033","Property '{0}' of exported interface has or is using private name '{1}'."),Parameter_type_of_public_static_setter_0_from_exported_class_has_or_is_using_name_1_from_private_module_2:n(4034,e.DiagnosticCategory.Error,"Parameter_type_of_public_static_setter_0_from_exported_class_has_or_is_using_name_1_from_private_mod_4034","Parameter type of public static setter '{0}' from exported class has or is using name '{1}' from private module '{2}'."),Parameter_type_of_public_static_setter_0_from_exported_class_has_or_is_using_private_name_1:n(4035,e.DiagnosticCategory.Error,"Parameter_type_of_public_static_setter_0_from_exported_class_has_or_is_using_private_name_1_4035","Parameter type of public static setter '{0}' from exported class has or is using private name '{1}'."),Parameter_type_of_public_setter_0_from_exported_class_has_or_is_using_name_1_from_private_module_2:n(4036,e.DiagnosticCategory.Error,"Parameter_type_of_public_setter_0_from_exported_class_has_or_is_using_name_1_from_private_module_2_4036","Parameter type of public setter '{0}' from exported class has or is using name '{1}' from private module '{2}'."),Parameter_type_of_public_setter_0_from_exported_class_has_or_is_using_private_name_1:n(4037,e.DiagnosticCategory.Error,"Parameter_type_of_public_setter_0_from_exported_class_has_or_is_using_private_name_1_4037","Parameter type of public setter '{0}' from exported class has or is using private name '{1}'."),Return_type_of_public_static_getter_0_from_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named:n(4038,e.DiagnosticCategory.Error,"Return_type_of_public_static_getter_0_from_exported_class_has_or_is_using_name_1_from_external_modul_4038","Return type of public static getter '{0}' from exported class has or is using name '{1}' from external module {2} but cannot be named."),Return_type_of_public_static_getter_0_from_exported_class_has_or_is_using_name_1_from_private_module_2:n(4039,e.DiagnosticCategory.Error,"Return_type_of_public_static_getter_0_from_exported_class_has_or_is_using_name_1_from_private_module_4039","Return type of public static getter '{0}' from exported class has or is using name '{1}' from private module '{2}'."),Return_type_of_public_static_getter_0_from_exported_class_has_or_is_using_private_name_1:n(4040,e.DiagnosticCategory.Error,"Return_type_of_public_static_getter_0_from_exported_class_has_or_is_using_private_name_1_4040","Return type of public static getter '{0}' from exported class has or is using private name '{1}'."),Return_type_of_public_getter_0_from_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named:n(4041,e.DiagnosticCategory.Error,"Return_type_of_public_getter_0_from_exported_class_has_or_is_using_name_1_from_external_module_2_but_4041","Return type of public getter '{0}' from exported class has or is using name '{1}' from external module {2} but cannot be named."),Return_type_of_public_getter_0_from_exported_class_has_or_is_using_name_1_from_private_module_2:n(4042,e.DiagnosticCategory.Error,"Return_type_of_public_getter_0_from_exported_class_has_or_is_using_name_1_from_private_module_2_4042","Return type of public getter '{0}' from exported class has or is using name '{1}' from private module '{2}'."),Return_type_of_public_getter_0_from_exported_class_has_or_is_using_private_name_1:n(4043,e.DiagnosticCategory.Error,"Return_type_of_public_getter_0_from_exported_class_has_or_is_using_private_name_1_4043","Return type of public getter '{0}' from exported class has or is using private name '{1}'."),Return_type_of_constructor_signature_from_exported_interface_has_or_is_using_name_0_from_private_module_1:n(4044,e.DiagnosticCategory.Error,"Return_type_of_constructor_signature_from_exported_interface_has_or_is_using_name_0_from_private_mod_4044","Return type of constructor signature from exported interface has or is using name '{0}' from private module '{1}'."),Return_type_of_constructor_signature_from_exported_interface_has_or_is_using_private_name_0:n(4045,e.DiagnosticCategory.Error,"Return_type_of_constructor_signature_from_exported_interface_has_or_is_using_private_name_0_4045","Return type of constructor signature from exported interface has or is using private name '{0}'."),Return_type_of_call_signature_from_exported_interface_has_or_is_using_name_0_from_private_module_1:n(4046,e.DiagnosticCategory.Error,"Return_type_of_call_signature_from_exported_interface_has_or_is_using_name_0_from_private_module_1_4046","Return type of call signature from exported interface has or is using name '{0}' from private module '{1}'."),Return_type_of_call_signature_from_exported_interface_has_or_is_using_private_name_0:n(4047,e.DiagnosticCategory.Error,"Return_type_of_call_signature_from_exported_interface_has_or_is_using_private_name_0_4047","Return type of call signature from exported interface has or is using private name '{0}'."),Return_type_of_index_signature_from_exported_interface_has_or_is_using_name_0_from_private_module_1:n(4048,e.DiagnosticCategory.Error,"Return_type_of_index_signature_from_exported_interface_has_or_is_using_name_0_from_private_module_1_4048","Return type of index signature from exported interface has or is using name '{0}' from private module '{1}'."),Return_type_of_index_signature_from_exported_interface_has_or_is_using_private_name_0:n(4049,e.DiagnosticCategory.Error,"Return_type_of_index_signature_from_exported_interface_has_or_is_using_private_name_0_4049","Return type of index signature from exported interface has or is using private name '{0}'."),Return_type_of_public_static_method_from_exported_class_has_or_is_using_name_0_from_external_module_1_but_cannot_be_named:n(4050,e.DiagnosticCategory.Error,"Return_type_of_public_static_method_from_exported_class_has_or_is_using_name_0_from_external_module__4050","Return type of public static method from exported class has or is using name '{0}' from external module {1} but cannot be named."),Return_type_of_public_static_method_from_exported_class_has_or_is_using_name_0_from_private_module_1:n(4051,e.DiagnosticCategory.Error,"Return_type_of_public_static_method_from_exported_class_has_or_is_using_name_0_from_private_module_1_4051","Return type of public static method from exported class has or is using name '{0}' from private module '{1}'."),Return_type_of_public_static_method_from_exported_class_has_or_is_using_private_name_0:n(4052,e.DiagnosticCategory.Error,"Return_type_of_public_static_method_from_exported_class_has_or_is_using_private_name_0_4052","Return type of public static method from exported class has or is using private name '{0}'."),Return_type_of_public_method_from_exported_class_has_or_is_using_name_0_from_external_module_1_but_cannot_be_named:n(4053,e.DiagnosticCategory.Error,"Return_type_of_public_method_from_exported_class_has_or_is_using_name_0_from_external_module_1_but_c_4053","Return type of public method from exported class has or is using name '{0}' from external module {1} but cannot be named."),Return_type_of_public_method_from_exported_class_has_or_is_using_name_0_from_private_module_1:n(4054,e.DiagnosticCategory.Error,"Return_type_of_public_method_from_exported_class_has_or_is_using_name_0_from_private_module_1_4054","Return type of public method from exported class has or is using name '{0}' from private module '{1}'."),Return_type_of_public_method_from_exported_class_has_or_is_using_private_name_0:n(4055,e.DiagnosticCategory.Error,"Return_type_of_public_method_from_exported_class_has_or_is_using_private_name_0_4055","Return type of public method from exported class has or is using private name '{0}'."),Return_type_of_method_from_exported_interface_has_or_is_using_name_0_from_private_module_1:n(4056,e.DiagnosticCategory.Error,"Return_type_of_method_from_exported_interface_has_or_is_using_name_0_from_private_module_1_4056","Return type of method from exported interface has or is using name '{0}' from private module '{1}'."),Return_type_of_method_from_exported_interface_has_or_is_using_private_name_0:n(4057,e.DiagnosticCategory.Error,"Return_type_of_method_from_exported_interface_has_or_is_using_private_name_0_4057","Return type of method from exported interface has or is using private name '{0}'."),Return_type_of_exported_function_has_or_is_using_name_0_from_external_module_1_but_cannot_be_named:n(4058,e.DiagnosticCategory.Error,"Return_type_of_exported_function_has_or_is_using_name_0_from_external_module_1_but_cannot_be_named_4058","Return type of exported function has or is using name '{0}' from external module {1} but cannot be named."),Return_type_of_exported_function_has_or_is_using_name_0_from_private_module_1:n(4059,e.DiagnosticCategory.Error,"Return_type_of_exported_function_has_or_is_using_name_0_from_private_module_1_4059","Return type of exported function has or is using name '{0}' from private module '{1}'."),Return_type_of_exported_function_has_or_is_using_private_name_0:n(4060,e.DiagnosticCategory.Error,"Return_type_of_exported_function_has_or_is_using_private_name_0_4060","Return type of exported function has or is using private name '{0}'."),Parameter_0_of_constructor_from_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named:n(4061,e.DiagnosticCategory.Error,"Parameter_0_of_constructor_from_exported_class_has_or_is_using_name_1_from_external_module_2_but_can_4061","Parameter '{0}' of constructor from exported class has or is using name '{1}' from external module {2} but cannot be named."),Parameter_0_of_constructor_from_exported_class_has_or_is_using_name_1_from_private_module_2:n(4062,e.DiagnosticCategory.Error,"Parameter_0_of_constructor_from_exported_class_has_or_is_using_name_1_from_private_module_2_4062","Parameter '{0}' of constructor from exported class has or is using name '{1}' from private module '{2}'."),Parameter_0_of_constructor_from_exported_class_has_or_is_using_private_name_1:n(4063,e.DiagnosticCategory.Error,"Parameter_0_of_constructor_from_exported_class_has_or_is_using_private_name_1_4063","Parameter '{0}' of constructor from exported class has or is using private name '{1}'."),Parameter_0_of_constructor_signature_from_exported_interface_has_or_is_using_name_1_from_private_module_2:n(4064,e.DiagnosticCategory.Error,"Parameter_0_of_constructor_signature_from_exported_interface_has_or_is_using_name_1_from_private_mod_4064","Parameter '{0}' of constructor signature from exported interface has or is using name '{1}' from private module '{2}'."),Parameter_0_of_constructor_signature_from_exported_interface_has_or_is_using_private_name_1:n(4065,e.DiagnosticCategory.Error,"Parameter_0_of_constructor_signature_from_exported_interface_has_or_is_using_private_name_1_4065","Parameter '{0}' of constructor signature from exported interface has or is using private name '{1}'."),Parameter_0_of_call_signature_from_exported_interface_has_or_is_using_name_1_from_private_module_2:n(4066,e.DiagnosticCategory.Error,"Parameter_0_of_call_signature_from_exported_interface_has_or_is_using_name_1_from_private_module_2_4066","Parameter '{0}' of call signature from exported interface has or is using name '{1}' from private module '{2}'."),Parameter_0_of_call_signature_from_exported_interface_has_or_is_using_private_name_1:n(4067,e.DiagnosticCategory.Error,"Parameter_0_of_call_signature_from_exported_interface_has_or_is_using_private_name_1_4067","Parameter '{0}' of call signature from exported interface has or is using private name '{1}'."),Parameter_0_of_public_static_method_from_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named:n(4068,e.DiagnosticCategory.Error,"Parameter_0_of_public_static_method_from_exported_class_has_or_is_using_name_1_from_external_module__4068","Parameter '{0}' of public static method from exported class has or is using name '{1}' from external module {2} but cannot be named."),Parameter_0_of_public_static_method_from_exported_class_has_or_is_using_name_1_from_private_module_2:n(4069,e.DiagnosticCategory.Error,"Parameter_0_of_public_static_method_from_exported_class_has_or_is_using_name_1_from_private_module_2_4069","Parameter '{0}' of public static method from exported class has or is using name '{1}' from private module '{2}'."),Parameter_0_of_public_static_method_from_exported_class_has_or_is_using_private_name_1:n(4070,e.DiagnosticCategory.Error,"Parameter_0_of_public_static_method_from_exported_class_has_or_is_using_private_name_1_4070","Parameter '{0}' of public static method from exported class has or is using private name '{1}'."),Parameter_0_of_public_method_from_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named:n(4071,e.DiagnosticCategory.Error,"Parameter_0_of_public_method_from_exported_class_has_or_is_using_name_1_from_external_module_2_but_c_4071","Parameter '{0}' of public method from exported class has or is using name '{1}' from external module {2} but cannot be named."),Parameter_0_of_public_method_from_exported_class_has_or_is_using_name_1_from_private_module_2:n(4072,e.DiagnosticCategory.Error,"Parameter_0_of_public_method_from_exported_class_has_or_is_using_name_1_from_private_module_2_4072","Parameter '{0}' of public method from exported class has or is using name '{1}' from private module '{2}'."),Parameter_0_of_public_method_from_exported_class_has_or_is_using_private_name_1:n(4073,e.DiagnosticCategory.Error,"Parameter_0_of_public_method_from_exported_class_has_or_is_using_private_name_1_4073","Parameter '{0}' of public method from exported class has or is using private name '{1}'."),Parameter_0_of_method_from_exported_interface_has_or_is_using_name_1_from_private_module_2:n(4074,e.DiagnosticCategory.Error,"Parameter_0_of_method_from_exported_interface_has_or_is_using_name_1_from_private_module_2_4074","Parameter '{0}' of method from exported interface has or is using name '{1}' from private module '{2}'."),Parameter_0_of_method_from_exported_interface_has_or_is_using_private_name_1:n(4075,e.DiagnosticCategory.Error,"Parameter_0_of_method_from_exported_interface_has_or_is_using_private_name_1_4075","Parameter '{0}' of method from exported interface has or is using private name '{1}'."),Parameter_0_of_exported_function_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named:n(4076,e.DiagnosticCategory.Error,"Parameter_0_of_exported_function_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named_4076","Parameter '{0}' of exported function has or is using name '{1}' from external module {2} but cannot be named."),Parameter_0_of_exported_function_has_or_is_using_name_1_from_private_module_2:n(4077,e.DiagnosticCategory.Error,"Parameter_0_of_exported_function_has_or_is_using_name_1_from_private_module_2_4077","Parameter '{0}' of exported function has or is using name '{1}' from private module '{2}'."),Parameter_0_of_exported_function_has_or_is_using_private_name_1:n(4078,e.DiagnosticCategory.Error,"Parameter_0_of_exported_function_has_or_is_using_private_name_1_4078","Parameter '{0}' of exported function has or is using private name '{1}'."),Exported_type_alias_0_has_or_is_using_private_name_1:n(4081,e.DiagnosticCategory.Error,"Exported_type_alias_0_has_or_is_using_private_name_1_4081","Exported type alias '{0}' has or is using private name '{1}'."),Default_export_of_the_module_has_or_is_using_private_name_0:n(4082,e.DiagnosticCategory.Error,"Default_export_of_the_module_has_or_is_using_private_name_0_4082","Default export of the module has or is using private name '{0}'."),Type_parameter_0_of_exported_type_alias_has_or_is_using_private_name_1:n(4083,e.DiagnosticCategory.Error,"Type_parameter_0_of_exported_type_alias_has_or_is_using_private_name_1_4083","Type parameter '{0}' of exported type alias has or is using private name '{1}'."),Exported_type_alias_0_has_or_is_using_private_name_1_from_module_2:n(4084,e.DiagnosticCategory.Error,"Exported_type_alias_0_has_or_is_using_private_name_1_from_module_2_4084","Exported type alias '{0}' has or is using private name '{1}' from module {2}."),Conflicting_definitions_for_0_found_at_1_and_2_Consider_installing_a_specific_version_of_this_library_to_resolve_the_conflict:n(4090,e.DiagnosticCategory.Error,"Conflicting_definitions_for_0_found_at_1_and_2_Consider_installing_a_specific_version_of_this_librar_4090","Conflicting definitions for '{0}' found at '{1}' and '{2}'. Consider installing a specific version of this library to resolve the conflict."),Parameter_0_of_index_signature_from_exported_interface_has_or_is_using_name_1_from_private_module_2:n(4091,e.DiagnosticCategory.Error,"Parameter_0_of_index_signature_from_exported_interface_has_or_is_using_name_1_from_private_module_2_4091","Parameter '{0}' of index signature from exported interface has or is using name '{1}' from private module '{2}'."),Parameter_0_of_index_signature_from_exported_interface_has_or_is_using_private_name_1:n(4092,e.DiagnosticCategory.Error,"Parameter_0_of_index_signature_from_exported_interface_has_or_is_using_private_name_1_4092","Parameter '{0}' of index signature from exported interface has or is using private name '{1}'."),Property_0_of_exported_class_expression_may_not_be_private_or_protected:n(4094,e.DiagnosticCategory.Error,"Property_0_of_exported_class_expression_may_not_be_private_or_protected_4094","Property '{0}' of exported class expression may not be private or protected."),Public_static_method_0_of_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named:n(4095,e.DiagnosticCategory.Error,"Public_static_method_0_of_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_4095","Public static method '{0}' of exported class has or is using name '{1}' from external module {2} but cannot be named."),Public_static_method_0_of_exported_class_has_or_is_using_name_1_from_private_module_2:n(4096,e.DiagnosticCategory.Error,"Public_static_method_0_of_exported_class_has_or_is_using_name_1_from_private_module_2_4096","Public static method '{0}' of exported class has or is using name '{1}' from private module '{2}'."),Public_static_method_0_of_exported_class_has_or_is_using_private_name_1:n(4097,e.DiagnosticCategory.Error,"Public_static_method_0_of_exported_class_has_or_is_using_private_name_1_4097","Public static method '{0}' of exported class has or is using private name '{1}'."),Public_method_0_of_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named:n(4098,e.DiagnosticCategory.Error,"Public_method_0_of_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named_4098","Public method '{0}' of exported class has or is using name '{1}' from external module {2} but cannot be named."),Public_method_0_of_exported_class_has_or_is_using_name_1_from_private_module_2:n(4099,e.DiagnosticCategory.Error,"Public_method_0_of_exported_class_has_or_is_using_name_1_from_private_module_2_4099","Public method '{0}' of exported class has or is using name '{1}' from private module '{2}'."),Public_method_0_of_exported_class_has_or_is_using_private_name_1:n(4100,e.DiagnosticCategory.Error,"Public_method_0_of_exported_class_has_or_is_using_private_name_1_4100","Public method '{0}' of exported class has or is using private name '{1}'."),Method_0_of_exported_interface_has_or_is_using_name_1_from_private_module_2:n(4101,e.DiagnosticCategory.Error,"Method_0_of_exported_interface_has_or_is_using_name_1_from_private_module_2_4101","Method '{0}' of exported interface has or is using name '{1}' from private module '{2}'."),Method_0_of_exported_interface_has_or_is_using_private_name_1:n(4102,e.DiagnosticCategory.Error,"Method_0_of_exported_interface_has_or_is_using_private_name_1_4102","Method '{0}' of exported interface has or is using private name '{1}'."),Type_parameter_0_of_exported_mapped_object_type_is_using_private_name_1:n(4103,e.DiagnosticCategory.Error,"Type_parameter_0_of_exported_mapped_object_type_is_using_private_name_1_4103","Type parameter '{0}' of exported mapped object type is using private name '{1}'."),The_type_0_is_readonly_and_cannot_be_assigned_to_the_mutable_type_1:n(4104,e.DiagnosticCategory.Error,"The_type_0_is_readonly_and_cannot_be_assigned_to_the_mutable_type_1_4104","The type '{0}' is 'readonly' and cannot be assigned to the mutable type '{1}'."),Private_or_protected_member_0_cannot_be_accessed_on_a_type_parameter:n(4105,e.DiagnosticCategory.Error,"Private_or_protected_member_0_cannot_be_accessed_on_a_type_parameter_4105","Private or protected member '{0}' cannot be accessed on a type parameter."),Parameter_0_of_accessor_has_or_is_using_private_name_1:n(4106,e.DiagnosticCategory.Error,"Parameter_0_of_accessor_has_or_is_using_private_name_1_4106","Parameter '{0}' of accessor has or is using private name '{1}'."),Parameter_0_of_accessor_has_or_is_using_name_1_from_private_module_2:n(4107,e.DiagnosticCategory.Error,"Parameter_0_of_accessor_has_or_is_using_name_1_from_private_module_2_4107","Parameter '{0}' of accessor has or is using name '{1}' from private module '{2}'."),Parameter_0_of_accessor_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named:n(4108,e.DiagnosticCategory.Error,"Parameter_0_of_accessor_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named_4108","Parameter '{0}' of accessor has or is using name '{1}' from external module '{2}' but cannot be named."),Type_arguments_for_0_circularly_reference_themselves:n(4109,e.DiagnosticCategory.Error,"Type_arguments_for_0_circularly_reference_themselves_4109","Type arguments for '{0}' circularly reference themselves."),Tuple_type_arguments_circularly_reference_themselves:n(4110,e.DiagnosticCategory.Error,"Tuple_type_arguments_circularly_reference_themselves_4110","Tuple type arguments circularly reference themselves."),Property_0_comes_from_an_index_signature_so_it_must_be_accessed_with_0:n(4111,e.DiagnosticCategory.Error,"Property_0_comes_from_an_index_signature_so_it_must_be_accessed_with_0_4111","Property '{0}' comes from an index signature, so it must be accessed with ['{0}']."),This_member_cannot_have_an_override_modifier_because_its_containing_class_0_does_not_extend_another_class:n(4112,e.DiagnosticCategory.Error,"This_member_cannot_have_an_override_modifier_because_its_containing_class_0_does_not_extend_another__4112","This member cannot have an 'override' modifier because its containing class '{0}' does not extend another class."),This_member_cannot_have_an_override_modifier_because_it_is_not_declared_in_the_base_class_0:n(4113,e.DiagnosticCategory.Error,"This_member_cannot_have_an_override_modifier_because_it_is_not_declared_in_the_base_class_0_4113","This member cannot have an 'override' modifier because it is not declared in the base class '{0}'."),This_member_must_have_an_override_modifier_because_it_overrides_a_member_in_the_base_class_0:n(4114,e.DiagnosticCategory.Error,"This_member_must_have_an_override_modifier_because_it_overrides_a_member_in_the_base_class_0_4114","This member must have an 'override' modifier because it overrides a member in the base class '{0}'."),This_parameter_property_must_have_an_override_modifier_because_it_overrides_a_member_in_base_class_0:n(4115,e.DiagnosticCategory.Error,"This_parameter_property_must_have_an_override_modifier_because_it_overrides_a_member_in_base_class_0_4115","This parameter property must have an 'override' modifier because it overrides a member in base class '{0}'."),This_member_must_have_an_override_modifier_because_it_overrides_an_abstract_method_that_is_declared_in_the_base_class_0:n(4116,e.DiagnosticCategory.Error,"This_member_must_have_an_override_modifier_because_it_overrides_an_abstract_method_that_is_declared__4116","This member must have an 'override' modifier because it overrides an abstract method that is declared in the base class '{0}'."),The_current_host_does_not_support_the_0_option:n(5001,e.DiagnosticCategory.Error,"The_current_host_does_not_support_the_0_option_5001","The current host does not support the '{0}' option."),Cannot_find_the_common_subdirectory_path_for_the_input_files:n(5009,e.DiagnosticCategory.Error,"Cannot_find_the_common_subdirectory_path_for_the_input_files_5009","Cannot find the common subdirectory path for the input files."),File_specification_cannot_end_in_a_recursive_directory_wildcard_Asterisk_Asterisk_Colon_0:n(5010,e.DiagnosticCategory.Error,"File_specification_cannot_end_in_a_recursive_directory_wildcard_Asterisk_Asterisk_Colon_0_5010","File specification cannot end in a recursive directory wildcard ('**'): '{0}'."),Cannot_read_file_0_Colon_1:n(5012,e.DiagnosticCategory.Error,"Cannot_read_file_0_Colon_1_5012","Cannot read file '{0}': {1}."),Failed_to_parse_file_0_Colon_1:n(5014,e.DiagnosticCategory.Error,"Failed_to_parse_file_0_Colon_1_5014","Failed to parse file '{0}': {1}."),Unknown_compiler_option_0:n(5023,e.DiagnosticCategory.Error,"Unknown_compiler_option_0_5023","Unknown compiler option '{0}'."),Compiler_option_0_requires_a_value_of_type_1:n(5024,e.DiagnosticCategory.Error,"Compiler_option_0_requires_a_value_of_type_1_5024","Compiler option '{0}' requires a value of type {1}."),Unknown_compiler_option_0_Did_you_mean_1:n(5025,e.DiagnosticCategory.Error,"Unknown_compiler_option_0_Did_you_mean_1_5025","Unknown compiler option '{0}'. Did you mean '{1}'?"),Could_not_write_file_0_Colon_1:n(5033,e.DiagnosticCategory.Error,"Could_not_write_file_0_Colon_1_5033","Could not write file '{0}': {1}."),Option_project_cannot_be_mixed_with_source_files_on_a_command_line:n(5042,e.DiagnosticCategory.Error,"Option_project_cannot_be_mixed_with_source_files_on_a_command_line_5042","Option 'project' cannot be mixed with source files on a command line."),Option_isolatedModules_can_only_be_used_when_either_option_module_is_provided_or_option_target_is_ES2015_or_higher:n(5047,e.DiagnosticCategory.Error,"Option_isolatedModules_can_only_be_used_when_either_option_module_is_provided_or_option_target_is_ES_5047","Option 'isolatedModules' can only be used when either option '--module' is provided or option 'target' is 'ES2015' or higher."),Option_0_cannot_be_specified_when_option_target_is_ES3:n(5048,e.DiagnosticCategory.Error,"Option_0_cannot_be_specified_when_option_target_is_ES3_5048","Option '{0}' cannot be specified when option 'target' is 'ES3'."),Option_0_can_only_be_used_when_either_option_inlineSourceMap_or_option_sourceMap_is_provided:n(5051,e.DiagnosticCategory.Error,"Option_0_can_only_be_used_when_either_option_inlineSourceMap_or_option_sourceMap_is_provided_5051","Option '{0} can only be used when either option '--inlineSourceMap' or option '--sourceMap' is provided."),Option_0_cannot_be_specified_without_specifying_option_1:n(5052,e.DiagnosticCategory.Error,"Option_0_cannot_be_specified_without_specifying_option_1_5052","Option '{0}' cannot be specified without specifying option '{1}'."),Option_0_cannot_be_specified_with_option_1:n(5053,e.DiagnosticCategory.Error,"Option_0_cannot_be_specified_with_option_1_5053","Option '{0}' cannot be specified with option '{1}'."),A_tsconfig_json_file_is_already_defined_at_Colon_0:n(5054,e.DiagnosticCategory.Error,"A_tsconfig_json_file_is_already_defined_at_Colon_0_5054","A 'tsconfig.json' file is already defined at: '{0}'."),Cannot_write_file_0_because_it_would_overwrite_input_file:n(5055,e.DiagnosticCategory.Error,"Cannot_write_file_0_because_it_would_overwrite_input_file_5055","Cannot write file '{0}' because it would overwrite input file."),Cannot_write_file_0_because_it_would_be_overwritten_by_multiple_input_files:n(5056,e.DiagnosticCategory.Error,"Cannot_write_file_0_because_it_would_be_overwritten_by_multiple_input_files_5056","Cannot write file '{0}' because it would be overwritten by multiple input files."),Cannot_find_a_tsconfig_json_file_at_the_specified_directory_Colon_0:n(5057,e.DiagnosticCategory.Error,"Cannot_find_a_tsconfig_json_file_at_the_specified_directory_Colon_0_5057","Cannot find a tsconfig.json file at the specified directory: '{0}'."),The_specified_path_does_not_exist_Colon_0:n(5058,e.DiagnosticCategory.Error,"The_specified_path_does_not_exist_Colon_0_5058","The specified path does not exist: '{0}'."),Invalid_value_for_reactNamespace_0_is_not_a_valid_identifier:n(5059,e.DiagnosticCategory.Error,"Invalid_value_for_reactNamespace_0_is_not_a_valid_identifier_5059","Invalid value for '--reactNamespace'. '{0}' is not a valid identifier."),Pattern_0_can_have_at_most_one_Asterisk_character:n(5061,e.DiagnosticCategory.Error,"Pattern_0_can_have_at_most_one_Asterisk_character_5061","Pattern '{0}' can have at most one '*' character."),Substitution_0_in_pattern_1_can_have_at_most_one_Asterisk_character:n(5062,e.DiagnosticCategory.Error,"Substitution_0_in_pattern_1_can_have_at_most_one_Asterisk_character_5062","Substitution '{0}' in pattern '{1}' can have at most one '*' character."),Substitutions_for_pattern_0_should_be_an_array:n(5063,e.DiagnosticCategory.Error,"Substitutions_for_pattern_0_should_be_an_array_5063","Substitutions for pattern '{0}' should be an array."),Substitution_0_for_pattern_1_has_incorrect_type_expected_string_got_2:n(5064,e.DiagnosticCategory.Error,"Substitution_0_for_pattern_1_has_incorrect_type_expected_string_got_2_5064","Substitution '{0}' for pattern '{1}' has incorrect type, expected 'string', got '{2}'."),File_specification_cannot_contain_a_parent_directory_that_appears_after_a_recursive_directory_wildcard_Asterisk_Asterisk_Colon_0:n(5065,e.DiagnosticCategory.Error,"File_specification_cannot_contain_a_parent_directory_that_appears_after_a_recursive_directory_wildca_5065","File specification cannot contain a parent directory ('..') that appears after a recursive directory wildcard ('**'): '{0}'."),Substitutions_for_pattern_0_shouldn_t_be_an_empty_array:n(5066,e.DiagnosticCategory.Error,"Substitutions_for_pattern_0_shouldn_t_be_an_empty_array_5066","Substitutions for pattern '{0}' shouldn't be an empty array."),Invalid_value_for_jsxFactory_0_is_not_a_valid_identifier_or_qualified_name:n(5067,e.DiagnosticCategory.Error,"Invalid_value_for_jsxFactory_0_is_not_a_valid_identifier_or_qualified_name_5067","Invalid value for 'jsxFactory'. '{0}' is not a valid identifier or qualified-name."),Adding_a_tsconfig_json_file_will_help_organize_projects_that_contain_both_TypeScript_and_JavaScript_files_Learn_more_at_https_Colon_Slash_Slashaka_ms_Slashtsconfig:n(5068,e.DiagnosticCategory.Error,"Adding_a_tsconfig_json_file_will_help_organize_projects_that_contain_both_TypeScript_and_JavaScript__5068","Adding a tsconfig.json file will help organize projects that contain both TypeScript and JavaScript files. Learn more at https://aka.ms/tsconfig."),Option_0_cannot_be_specified_without_specifying_option_1_or_option_2:n(5069,e.DiagnosticCategory.Error,"Option_0_cannot_be_specified_without_specifying_option_1_or_option_2_5069","Option '{0}' cannot be specified without specifying option '{1}' or option '{2}'."),Option_resolveJsonModule_cannot_be_specified_without_node_module_resolution_strategy:n(5070,e.DiagnosticCategory.Error,"Option_resolveJsonModule_cannot_be_specified_without_node_module_resolution_strategy_5070","Option '--resolveJsonModule' cannot be specified without 'node' module resolution strategy."),Option_resolveJsonModule_can_only_be_specified_when_module_code_generation_is_commonjs_amd_es2015_or_esNext:n(5071,e.DiagnosticCategory.Error,"Option_resolveJsonModule_can_only_be_specified_when_module_code_generation_is_commonjs_amd_es2015_or_5071","Option '--resolveJsonModule' can only be specified when module code generation is 'commonjs', 'amd', 'es2015' or 'esNext'."),Unknown_build_option_0:n(5072,e.DiagnosticCategory.Error,"Unknown_build_option_0_5072","Unknown build option '{0}'."),Build_option_0_requires_a_value_of_type_1:n(5073,e.DiagnosticCategory.Error,"Build_option_0_requires_a_value_of_type_1_5073","Build option '{0}' requires a value of type {1}."),Option_incremental_can_only_be_specified_using_tsconfig_emitting_to_single_file_or_when_option_tsBuildInfoFile_is_specified:n(5074,e.DiagnosticCategory.Error,"Option_incremental_can_only_be_specified_using_tsconfig_emitting_to_single_file_or_when_option_tsBui_5074","Option '--incremental' can only be specified using tsconfig, emitting to single file or when option '--tsBuildInfoFile' is specified."),_0_is_assignable_to_the_constraint_of_type_1_but_1_could_be_instantiated_with_a_different_subtype_of_constraint_2:n(5075,e.DiagnosticCategory.Error,"_0_is_assignable_to_the_constraint_of_type_1_but_1_could_be_instantiated_with_a_different_subtype_of_5075","'{0}' is assignable to the constraint of type '{1}', but '{1}' could be instantiated with a different subtype of constraint '{2}'."),_0_and_1_operations_cannot_be_mixed_without_parentheses:n(5076,e.DiagnosticCategory.Error,"_0_and_1_operations_cannot_be_mixed_without_parentheses_5076","'{0}' and '{1}' operations cannot be mixed without parentheses."),Unknown_build_option_0_Did_you_mean_1:n(5077,e.DiagnosticCategory.Error,"Unknown_build_option_0_Did_you_mean_1_5077","Unknown build option '{0}'. Did you mean '{1}'?"),Unknown_watch_option_0:n(5078,e.DiagnosticCategory.Error,"Unknown_watch_option_0_5078","Unknown watch option '{0}'."),Unknown_watch_option_0_Did_you_mean_1:n(5079,e.DiagnosticCategory.Error,"Unknown_watch_option_0_Did_you_mean_1_5079","Unknown watch option '{0}'. Did you mean '{1}'?"),Watch_option_0_requires_a_value_of_type_1:n(5080,e.DiagnosticCategory.Error,"Watch_option_0_requires_a_value_of_type_1_5080","Watch option '{0}' requires a value of type {1}."),Cannot_find_a_tsconfig_json_file_at_the_current_directory_Colon_0:n(5081,e.DiagnosticCategory.Error,"Cannot_find_a_tsconfig_json_file_at_the_current_directory_Colon_0_5081","Cannot find a tsconfig.json file at the current directory: {0}."),_0_could_be_instantiated_with_an_arbitrary_type_which_could_be_unrelated_to_1:n(5082,e.DiagnosticCategory.Error,"_0_could_be_instantiated_with_an_arbitrary_type_which_could_be_unrelated_to_1_5082","'{0}' could be instantiated with an arbitrary type which could be unrelated to '{1}'."),Cannot_read_file_0:n(5083,e.DiagnosticCategory.Error,"Cannot_read_file_0_5083","Cannot read file '{0}'."),Tuple_members_must_all_have_names_or_all_not_have_names:n(5084,e.DiagnosticCategory.Error,"Tuple_members_must_all_have_names_or_all_not_have_names_5084","Tuple members must all have names or all not have names."),A_tuple_member_cannot_be_both_optional_and_rest:n(5085,e.DiagnosticCategory.Error,"A_tuple_member_cannot_be_both_optional_and_rest_5085","A tuple member cannot be both optional and rest."),A_labeled_tuple_element_is_declared_as_optional_with_a_question_mark_after_the_name_and_before_the_colon_rather_than_after_the_type:n(5086,e.DiagnosticCategory.Error,"A_labeled_tuple_element_is_declared_as_optional_with_a_question_mark_after_the_name_and_before_the_c_5086","A labeled tuple element is declared as optional with a question mark after the name and before the colon, rather than after the type."),A_labeled_tuple_element_is_declared_as_rest_with_a_before_the_name_rather_than_before_the_type:n(5087,e.DiagnosticCategory.Error,"A_labeled_tuple_element_is_declared_as_rest_with_a_before_the_name_rather_than_before_the_type_5087","A labeled tuple element is declared as rest with a '...' before the name, rather than before the type."),The_inferred_type_of_0_references_a_type_with_a_cyclic_structure_which_cannot_be_trivially_serialized_A_type_annotation_is_necessary:n(5088,e.DiagnosticCategory.Error,"The_inferred_type_of_0_references_a_type_with_a_cyclic_structure_which_cannot_be_trivially_serialize_5088","The inferred type of '{0}' references a type with a cyclic structure which cannot be trivially serialized. A type annotation is necessary."),Option_0_cannot_be_specified_when_option_jsx_is_1:n(5089,e.DiagnosticCategory.Error,"Option_0_cannot_be_specified_when_option_jsx_is_1_5089","Option '{0}' cannot be specified when option 'jsx' is '{1}'."),Non_relative_paths_are_not_allowed_when_baseUrl_is_not_set_Did_you_forget_a_leading_Slash:n(5090,e.DiagnosticCategory.Error,"Non_relative_paths_are_not_allowed_when_baseUrl_is_not_set_Did_you_forget_a_leading_Slash_5090","Non-relative paths are not allowed when 'baseUrl' is not set. Did you forget a leading './'?"),Option_preserveConstEnums_cannot_be_disabled_when_isolatedModules_is_enabled:n(5091,e.DiagnosticCategory.Error,"Option_preserveConstEnums_cannot_be_disabled_when_isolatedModules_is_enabled_5091","Option 'preserveConstEnums' cannot be disabled when 'isolatedModules' is enabled."),The_root_value_of_a_0_file_must_be_an_object:n(5092,e.DiagnosticCategory.Error,"The_root_value_of_a_0_file_must_be_an_object_5092","The root value of a '{0}' file must be an object."),Compiler_option_0_may_only_be_used_with_build:n(5093,e.DiagnosticCategory.Error,"Compiler_option_0_may_only_be_used_with_build_5093","Compiler option '--{0}' may only be used with '--build'."),Compiler_option_0_may_not_be_used_with_build:n(5094,e.DiagnosticCategory.Error,"Compiler_option_0_may_not_be_used_with_build_5094","Compiler option '--{0}' may not be used with '--build'."),Generates_a_sourcemap_for_each_corresponding_d_ts_file:n(6e3,e.DiagnosticCategory.Message,"Generates_a_sourcemap_for_each_corresponding_d_ts_file_6000","Generates a sourcemap for each corresponding '.d.ts' file."),Concatenate_and_emit_output_to_single_file:n(6001,e.DiagnosticCategory.Message,"Concatenate_and_emit_output_to_single_file_6001","Concatenate and emit output to single file."),Generates_corresponding_d_ts_file:n(6002,e.DiagnosticCategory.Message,"Generates_corresponding_d_ts_file_6002","Generates corresponding '.d.ts' file."),Specify_the_location_where_debugger_should_locate_map_files_instead_of_generated_locations:n(6003,e.DiagnosticCategory.Message,"Specify_the_location_where_debugger_should_locate_map_files_instead_of_generated_locations_6003","Specify the location where debugger should locate map files instead of generated locations."),Specify_the_location_where_debugger_should_locate_TypeScript_files_instead_of_source_locations:n(6004,e.DiagnosticCategory.Message,"Specify_the_location_where_debugger_should_locate_TypeScript_files_instead_of_source_locations_6004","Specify the location where debugger should locate TypeScript files instead of source locations."),Watch_input_files:n(6005,e.DiagnosticCategory.Message,"Watch_input_files_6005","Watch input files."),Redirect_output_structure_to_the_directory:n(6006,e.DiagnosticCategory.Message,"Redirect_output_structure_to_the_directory_6006","Redirect output structure to the directory."),Do_not_erase_const_enum_declarations_in_generated_code:n(6007,e.DiagnosticCategory.Message,"Do_not_erase_const_enum_declarations_in_generated_code_6007","Do not erase const enum declarations in generated code."),Do_not_emit_outputs_if_any_errors_were_reported:n(6008,e.DiagnosticCategory.Message,"Do_not_emit_outputs_if_any_errors_were_reported_6008","Do not emit outputs if any errors were reported."),Do_not_emit_comments_to_output:n(6009,e.DiagnosticCategory.Message,"Do_not_emit_comments_to_output_6009","Do not emit comments to output."),Do_not_emit_outputs:n(6010,e.DiagnosticCategory.Message,"Do_not_emit_outputs_6010","Do not emit outputs."),Allow_default_imports_from_modules_with_no_default_export_This_does_not_affect_code_emit_just_typechecking:n(6011,e.DiagnosticCategory.Message,"Allow_default_imports_from_modules_with_no_default_export_This_does_not_affect_code_emit_just_typech_6011","Allow default imports from modules with no default export. This does not affect code emit, just typechecking."),Skip_type_checking_of_declaration_files:n(6012,e.DiagnosticCategory.Message,"Skip_type_checking_of_declaration_files_6012","Skip type checking of declaration files."),Do_not_resolve_the_real_path_of_symlinks:n(6013,e.DiagnosticCategory.Message,"Do_not_resolve_the_real_path_of_symlinks_6013","Do not resolve the real path of symlinks."),Only_emit_d_ts_declaration_files:n(6014,e.DiagnosticCategory.Message,"Only_emit_d_ts_declaration_files_6014","Only emit '.d.ts' declaration files."),Specify_ECMAScript_target_version_Colon_ES3_default_ES5_ES2015_ES2016_ES2017_ES2018_ES2019_ES2020_ES2021_or_ESNEXT:n(6015,e.DiagnosticCategory.Message,"Specify_ECMAScript_target_version_Colon_ES3_default_ES5_ES2015_ES2016_ES2017_ES2018_ES2019_ES2020_ES_6015","Specify ECMAScript target version: 'ES3' (default), 'ES5', 'ES2015', 'ES2016', 'ES2017', 'ES2018', 'ES2019', 'ES2020', 'ES2021', or 'ESNEXT'."),Specify_module_code_generation_Colon_none_commonjs_amd_system_umd_es2015_es2020_or_ESNext:n(6016,e.DiagnosticCategory.Message,"Specify_module_code_generation_Colon_none_commonjs_amd_system_umd_es2015_es2020_or_ESNext_6016","Specify module code generation: 'none', 'commonjs', 'amd', 'system', 'umd', 'es2015', 'es2020', or 'ESNext'."),Print_this_message:n(6017,e.DiagnosticCategory.Message,"Print_this_message_6017","Print this message."),Print_the_compiler_s_version:n(6019,e.DiagnosticCategory.Message,"Print_the_compiler_s_version_6019","Print the compiler's version."),Compile_the_project_given_the_path_to_its_configuration_file_or_to_a_folder_with_a_tsconfig_json:n(6020,e.DiagnosticCategory.Message,"Compile_the_project_given_the_path_to_its_configuration_file_or_to_a_folder_with_a_tsconfig_json_6020","Compile the project given the path to its configuration file, or to a folder with a 'tsconfig.json'."),Syntax_Colon_0:n(6023,e.DiagnosticCategory.Message,"Syntax_Colon_0_6023","Syntax: {0}"),options:n(6024,e.DiagnosticCategory.Message,"options_6024","options"),file:n(6025,e.DiagnosticCategory.Message,"file_6025","file"),Examples_Colon_0:n(6026,e.DiagnosticCategory.Message,"Examples_Colon_0_6026","Examples: {0}"),Options_Colon:n(6027,e.DiagnosticCategory.Message,"Options_Colon_6027","Options:"),Version_0:n(6029,e.DiagnosticCategory.Message,"Version_0_6029","Version {0}"),Insert_command_line_options_and_files_from_a_file:n(6030,e.DiagnosticCategory.Message,"Insert_command_line_options_and_files_from_a_file_6030","Insert command line options and files from a file."),Starting_compilation_in_watch_mode:n(6031,e.DiagnosticCategory.Message,"Starting_compilation_in_watch_mode_6031","Starting compilation in watch mode..."),File_change_detected_Starting_incremental_compilation:n(6032,e.DiagnosticCategory.Message,"File_change_detected_Starting_incremental_compilation_6032","File change detected. Starting incremental compilation..."),KIND:n(6034,e.DiagnosticCategory.Message,"KIND_6034","KIND"),FILE:n(6035,e.DiagnosticCategory.Message,"FILE_6035","FILE"),VERSION:n(6036,e.DiagnosticCategory.Message,"VERSION_6036","VERSION"),LOCATION:n(6037,e.DiagnosticCategory.Message,"LOCATION_6037","LOCATION"),DIRECTORY:n(6038,e.DiagnosticCategory.Message,"DIRECTORY_6038","DIRECTORY"),STRATEGY:n(6039,e.DiagnosticCategory.Message,"STRATEGY_6039","STRATEGY"),FILE_OR_DIRECTORY:n(6040,e.DiagnosticCategory.Message,"FILE_OR_DIRECTORY_6040","FILE OR DIRECTORY"),Generates_corresponding_map_file:n(6043,e.DiagnosticCategory.Message,"Generates_corresponding_map_file_6043","Generates corresponding '.map' file."),Compiler_option_0_expects_an_argument:n(6044,e.DiagnosticCategory.Error,"Compiler_option_0_expects_an_argument_6044","Compiler option '{0}' expects an argument."),Unterminated_quoted_string_in_response_file_0:n(6045,e.DiagnosticCategory.Error,"Unterminated_quoted_string_in_response_file_0_6045","Unterminated quoted string in response file '{0}'."),Argument_for_0_option_must_be_Colon_1:n(6046,e.DiagnosticCategory.Error,"Argument_for_0_option_must_be_Colon_1_6046","Argument for '{0}' option must be: {1}."),Locale_must_be_of_the_form_language_or_language_territory_For_example_0_or_1:n(6048,e.DiagnosticCategory.Error,"Locale_must_be_of_the_form_language_or_language_territory_For_example_0_or_1_6048","Locale must be of the form <language> or <language>-<territory>. For example '{0}' or '{1}'."),Unsupported_locale_0:n(6049,e.DiagnosticCategory.Error,"Unsupported_locale_0_6049","Unsupported locale '{0}'."),Unable_to_open_file_0:n(6050,e.DiagnosticCategory.Error,"Unable_to_open_file_0_6050","Unable to open file '{0}'."),Corrupted_locale_file_0:n(6051,e.DiagnosticCategory.Error,"Corrupted_locale_file_0_6051","Corrupted locale file {0}."),Raise_error_on_expressions_and_declarations_with_an_implied_any_type:n(6052,e.DiagnosticCategory.Message,"Raise_error_on_expressions_and_declarations_with_an_implied_any_type_6052","Raise error on expressions and declarations with an implied 'any' type."),File_0_not_found:n(6053,e.DiagnosticCategory.Error,"File_0_not_found_6053","File '{0}' not found."),File_0_has_an_unsupported_extension_The_only_supported_extensions_are_1:n(6054,e.DiagnosticCategory.Error,"File_0_has_an_unsupported_extension_The_only_supported_extensions_are_1_6054","File '{0}' has an unsupported extension. The only supported extensions are {1}."),Suppress_noImplicitAny_errors_for_indexing_objects_lacking_index_signatures:n(6055,e.DiagnosticCategory.Message,"Suppress_noImplicitAny_errors_for_indexing_objects_lacking_index_signatures_6055","Suppress noImplicitAny errors for indexing objects lacking index signatures."),Do_not_emit_declarations_for_code_that_has_an_internal_annotation:n(6056,e.DiagnosticCategory.Message,"Do_not_emit_declarations_for_code_that_has_an_internal_annotation_6056","Do not emit declarations for code that has an '@internal' annotation."),Specify_the_root_directory_of_input_files_Use_to_control_the_output_directory_structure_with_outDir:n(6058,e.DiagnosticCategory.Message,"Specify_the_root_directory_of_input_files_Use_to_control_the_output_directory_structure_with_outDir_6058","Specify the root directory of input files. Use to control the output directory structure with --outDir."),File_0_is_not_under_rootDir_1_rootDir_is_expected_to_contain_all_source_files:n(6059,e.DiagnosticCategory.Error,"File_0_is_not_under_rootDir_1_rootDir_is_expected_to_contain_all_source_files_6059","File '{0}' is not under 'rootDir' '{1}'. 'rootDir' is expected to contain all source files."),Specify_the_end_of_line_sequence_to_be_used_when_emitting_files_Colon_CRLF_dos_or_LF_unix:n(6060,e.DiagnosticCategory.Message,"Specify_the_end_of_line_sequence_to_be_used_when_emitting_files_Colon_CRLF_dos_or_LF_unix_6060","Specify the end of line sequence to be used when emitting files: 'CRLF' (dos) or 'LF' (unix)."),NEWLINE:n(6061,e.DiagnosticCategory.Message,"NEWLINE_6061","NEWLINE"),Option_0_can_only_be_specified_in_tsconfig_json_file_or_set_to_null_on_command_line:n(6064,e.DiagnosticCategory.Error,"Option_0_can_only_be_specified_in_tsconfig_json_file_or_set_to_null_on_command_line_6064","Option '{0}' can only be specified in 'tsconfig.json' file or set to 'null' on command line."),Enables_experimental_support_for_ES7_decorators:n(6065,e.DiagnosticCategory.Message,"Enables_experimental_support_for_ES7_decorators_6065","Enables experimental support for ES7 decorators."),Enables_experimental_support_for_emitting_type_metadata_for_decorators:n(6066,e.DiagnosticCategory.Message,"Enables_experimental_support_for_emitting_type_metadata_for_decorators_6066","Enables experimental support for emitting type metadata for decorators."),Enables_experimental_support_for_ES7_async_functions:n(6068,e.DiagnosticCategory.Message,"Enables_experimental_support_for_ES7_async_functions_6068","Enables experimental support for ES7 async functions."),Specify_module_resolution_strategy_Colon_node_Node_js_or_classic_TypeScript_pre_1_6:n(6069,e.DiagnosticCategory.Message,"Specify_module_resolution_strategy_Colon_node_Node_js_or_classic_TypeScript_pre_1_6_6069","Specify module resolution strategy: 'node' (Node.js) or 'classic' (TypeScript pre-1.6)."),Initializes_a_TypeScript_project_and_creates_a_tsconfig_json_file:n(6070,e.DiagnosticCategory.Message,"Initializes_a_TypeScript_project_and_creates_a_tsconfig_json_file_6070","Initializes a TypeScript project and creates a tsconfig.json file."),Successfully_created_a_tsconfig_json_file:n(6071,e.DiagnosticCategory.Message,"Successfully_created_a_tsconfig_json_file_6071","Successfully created a tsconfig.json file."),Suppress_excess_property_checks_for_object_literals:n(6072,e.DiagnosticCategory.Message,"Suppress_excess_property_checks_for_object_literals_6072","Suppress excess property checks for object literals."),Stylize_errors_and_messages_using_color_and_context_experimental:n(6073,e.DiagnosticCategory.Message,"Stylize_errors_and_messages_using_color_and_context_experimental_6073","Stylize errors and messages using color and context (experimental)."),Do_not_report_errors_on_unused_labels:n(6074,e.DiagnosticCategory.Message,"Do_not_report_errors_on_unused_labels_6074","Do not report errors on unused labels."),Report_error_when_not_all_code_paths_in_function_return_a_value:n(6075,e.DiagnosticCategory.Message,"Report_error_when_not_all_code_paths_in_function_return_a_value_6075","Report error when not all code paths in function return a value."),Report_errors_for_fallthrough_cases_in_switch_statement:n(6076,e.DiagnosticCategory.Message,"Report_errors_for_fallthrough_cases_in_switch_statement_6076","Report errors for fallthrough cases in switch statement."),Do_not_report_errors_on_unreachable_code:n(6077,e.DiagnosticCategory.Message,"Do_not_report_errors_on_unreachable_code_6077","Do not report errors on unreachable code."),Disallow_inconsistently_cased_references_to_the_same_file:n(6078,e.DiagnosticCategory.Message,"Disallow_inconsistently_cased_references_to_the_same_file_6078","Disallow inconsistently-cased references to the same file."),Specify_library_files_to_be_included_in_the_compilation:n(6079,e.DiagnosticCategory.Message,"Specify_library_files_to_be_included_in_the_compilation_6079","Specify library files to be included in the compilation."),Specify_JSX_code_generation_Colon_preserve_react_native_react_react_jsx_or_react_jsxdev:n(6080,e.DiagnosticCategory.Message,"Specify_JSX_code_generation_Colon_preserve_react_native_react_react_jsx_or_react_jsxdev_6080","Specify JSX code generation: 'preserve', 'react-native', 'react', 'react-jsx' or 'react-jsxdev'."),File_0_has_an_unsupported_extension_so_skipping_it:n(6081,e.DiagnosticCategory.Message,"File_0_has_an_unsupported_extension_so_skipping_it_6081","File '{0}' has an unsupported extension, so skipping it."),Only_amd_and_system_modules_are_supported_alongside_0:n(6082,e.DiagnosticCategory.Error,"Only_amd_and_system_modules_are_supported_alongside_0_6082","Only 'amd' and 'system' modules are supported alongside --{0}."),Base_directory_to_resolve_non_absolute_module_names:n(6083,e.DiagnosticCategory.Message,"Base_directory_to_resolve_non_absolute_module_names_6083","Base directory to resolve non-absolute module names."),Deprecated_Use_jsxFactory_instead_Specify_the_object_invoked_for_createElement_when_targeting_react_JSX_emit:n(6084,e.DiagnosticCategory.Message,"Deprecated_Use_jsxFactory_instead_Specify_the_object_invoked_for_createElement_when_targeting_react__6084","[Deprecated] Use '--jsxFactory' instead. Specify the object invoked for createElement when targeting 'react' JSX emit"),Enable_tracing_of_the_name_resolution_process:n(6085,e.DiagnosticCategory.Message,"Enable_tracing_of_the_name_resolution_process_6085","Enable tracing of the name resolution process."),Resolving_module_0_from_1:n(6086,e.DiagnosticCategory.Message,"Resolving_module_0_from_1_6086","======== Resolving module '{0}' from '{1}'. ========"),Explicitly_specified_module_resolution_kind_Colon_0:n(6087,e.DiagnosticCategory.Message,"Explicitly_specified_module_resolution_kind_Colon_0_6087","Explicitly specified module resolution kind: '{0}'."),Module_resolution_kind_is_not_specified_using_0:n(6088,e.DiagnosticCategory.Message,"Module_resolution_kind_is_not_specified_using_0_6088","Module resolution kind is not specified, using '{0}'."),Module_name_0_was_successfully_resolved_to_1:n(6089,e.DiagnosticCategory.Message,"Module_name_0_was_successfully_resolved_to_1_6089","======== Module name '{0}' was successfully resolved to '{1}'. ========"),Module_name_0_was_not_resolved:n(6090,e.DiagnosticCategory.Message,"Module_name_0_was_not_resolved_6090","======== Module name '{0}' was not resolved. ========"),paths_option_is_specified_looking_for_a_pattern_to_match_module_name_0:n(6091,e.DiagnosticCategory.Message,"paths_option_is_specified_looking_for_a_pattern_to_match_module_name_0_6091","'paths' option is specified, looking for a pattern to match module name '{0}'."),Module_name_0_matched_pattern_1:n(6092,e.DiagnosticCategory.Message,"Module_name_0_matched_pattern_1_6092","Module name '{0}', matched pattern '{1}'."),Trying_substitution_0_candidate_module_location_Colon_1:n(6093,e.DiagnosticCategory.Message,"Trying_substitution_0_candidate_module_location_Colon_1_6093","Trying substitution '{0}', candidate module location: '{1}'."),Resolving_module_name_0_relative_to_base_url_1_2:n(6094,e.DiagnosticCategory.Message,"Resolving_module_name_0_relative_to_base_url_1_2_6094","Resolving module name '{0}' relative to base url '{1}' - '{2}'."),Loading_module_as_file_Slash_folder_candidate_module_location_0_target_file_type_1:n(6095,e.DiagnosticCategory.Message,"Loading_module_as_file_Slash_folder_candidate_module_location_0_target_file_type_1_6095","Loading module as file / folder, candidate module location '{0}', target file type '{1}'."),File_0_does_not_exist:n(6096,e.DiagnosticCategory.Message,"File_0_does_not_exist_6096","File '{0}' does not exist."),File_0_exist_use_it_as_a_name_resolution_result:n(6097,e.DiagnosticCategory.Message,"File_0_exist_use_it_as_a_name_resolution_result_6097","File '{0}' exist - use it as a name resolution result."),Loading_module_0_from_node_modules_folder_target_file_type_1:n(6098,e.DiagnosticCategory.Message,"Loading_module_0_from_node_modules_folder_target_file_type_1_6098","Loading module '{0}' from 'node_modules' folder, target file type '{1}'."),Found_package_json_at_0:n(6099,e.DiagnosticCategory.Message,"Found_package_json_at_0_6099","Found 'package.json' at '{0}'."),package_json_does_not_have_a_0_field:n(6100,e.DiagnosticCategory.Message,"package_json_does_not_have_a_0_field_6100","'package.json' does not have a '{0}' field."),package_json_has_0_field_1_that_references_2:n(6101,e.DiagnosticCategory.Message,"package_json_has_0_field_1_that_references_2_6101","'package.json' has '{0}' field '{1}' that references '{2}'."),Allow_javascript_files_to_be_compiled:n(6102,e.DiagnosticCategory.Message,"Allow_javascript_files_to_be_compiled_6102","Allow javascript files to be compiled."),Option_0_should_have_array_of_strings_as_a_value:n(6103,e.DiagnosticCategory.Error,"Option_0_should_have_array_of_strings_as_a_value_6103","Option '{0}' should have array of strings as a value."),Checking_if_0_is_the_longest_matching_prefix_for_1_2:n(6104,e.DiagnosticCategory.Message,"Checking_if_0_is_the_longest_matching_prefix_for_1_2_6104","Checking if '{0}' is the longest matching prefix for '{1}' - '{2}'."),Expected_type_of_0_field_in_package_json_to_be_1_got_2:n(6105,e.DiagnosticCategory.Message,"Expected_type_of_0_field_in_package_json_to_be_1_got_2_6105","Expected type of '{0}' field in 'package.json' to be '{1}', got '{2}'."),baseUrl_option_is_set_to_0_using_this_value_to_resolve_non_relative_module_name_1:n(6106,e.DiagnosticCategory.Message,"baseUrl_option_is_set_to_0_using_this_value_to_resolve_non_relative_module_name_1_6106","'baseUrl' option is set to '{0}', using this value to resolve non-relative module name '{1}'."),rootDirs_option_is_set_using_it_to_resolve_relative_module_name_0:n(6107,e.DiagnosticCategory.Message,"rootDirs_option_is_set_using_it_to_resolve_relative_module_name_0_6107","'rootDirs' option is set, using it to resolve relative module name '{0}'."),Longest_matching_prefix_for_0_is_1:n(6108,e.DiagnosticCategory.Message,"Longest_matching_prefix_for_0_is_1_6108","Longest matching prefix for '{0}' is '{1}'."),Loading_0_from_the_root_dir_1_candidate_location_2:n(6109,e.DiagnosticCategory.Message,"Loading_0_from_the_root_dir_1_candidate_location_2_6109","Loading '{0}' from the root dir '{1}', candidate location '{2}'."),Trying_other_entries_in_rootDirs:n(6110,e.DiagnosticCategory.Message,"Trying_other_entries_in_rootDirs_6110","Trying other entries in 'rootDirs'."),Module_resolution_using_rootDirs_has_failed:n(6111,e.DiagnosticCategory.Message,"Module_resolution_using_rootDirs_has_failed_6111","Module resolution using 'rootDirs' has failed."),Do_not_emit_use_strict_directives_in_module_output:n(6112,e.DiagnosticCategory.Message,"Do_not_emit_use_strict_directives_in_module_output_6112","Do not emit 'use strict' directives in module output."),Enable_strict_null_checks:n(6113,e.DiagnosticCategory.Message,"Enable_strict_null_checks_6113","Enable strict null checks."),Unknown_option_excludes_Did_you_mean_exclude:n(6114,e.DiagnosticCategory.Error,"Unknown_option_excludes_Did_you_mean_exclude_6114","Unknown option 'excludes'. Did you mean 'exclude'?"),Raise_error_on_this_expressions_with_an_implied_any_type:n(6115,e.DiagnosticCategory.Message,"Raise_error_on_this_expressions_with_an_implied_any_type_6115","Raise error on 'this' expressions with an implied 'any' type."),Resolving_type_reference_directive_0_containing_file_1_root_directory_2:n(6116,e.DiagnosticCategory.Message,"Resolving_type_reference_directive_0_containing_file_1_root_directory_2_6116","======== Resolving type reference directive '{0}', containing file '{1}', root directory '{2}'. ========"),Resolving_using_primary_search_paths:n(6117,e.DiagnosticCategory.Message,"Resolving_using_primary_search_paths_6117","Resolving using primary search paths..."),Resolving_from_node_modules_folder:n(6118,e.DiagnosticCategory.Message,"Resolving_from_node_modules_folder_6118","Resolving from node_modules folder..."),Type_reference_directive_0_was_successfully_resolved_to_1_primary_Colon_2:n(6119,e.DiagnosticCategory.Message,"Type_reference_directive_0_was_successfully_resolved_to_1_primary_Colon_2_6119","======== Type reference directive '{0}' was successfully resolved to '{1}', primary: {2}. ========"),Type_reference_directive_0_was_not_resolved:n(6120,e.DiagnosticCategory.Message,"Type_reference_directive_0_was_not_resolved_6120","======== Type reference directive '{0}' was not resolved. ========"),Resolving_with_primary_search_path_0:n(6121,e.DiagnosticCategory.Message,"Resolving_with_primary_search_path_0_6121","Resolving with primary search path '{0}'."),Root_directory_cannot_be_determined_skipping_primary_search_paths:n(6122,e.DiagnosticCategory.Message,"Root_directory_cannot_be_determined_skipping_primary_search_paths_6122","Root directory cannot be determined, skipping primary search paths."),Resolving_type_reference_directive_0_containing_file_1_root_directory_not_set:n(6123,e.DiagnosticCategory.Message,"Resolving_type_reference_directive_0_containing_file_1_root_directory_not_set_6123","======== Resolving type reference directive '{0}', containing file '{1}', root directory not set. ========"),Type_declaration_files_to_be_included_in_compilation:n(6124,e.DiagnosticCategory.Message,"Type_declaration_files_to_be_included_in_compilation_6124","Type declaration files to be included in compilation."),Looking_up_in_node_modules_folder_initial_location_0:n(6125,e.DiagnosticCategory.Message,"Looking_up_in_node_modules_folder_initial_location_0_6125","Looking up in 'node_modules' folder, initial location '{0}'."),Containing_file_is_not_specified_and_root_directory_cannot_be_determined_skipping_lookup_in_node_modules_folder:n(6126,e.DiagnosticCategory.Message,"Containing_file_is_not_specified_and_root_directory_cannot_be_determined_skipping_lookup_in_node_mod_6126","Containing file is not specified and root directory cannot be determined, skipping lookup in 'node_modules' folder."),Resolving_type_reference_directive_0_containing_file_not_set_root_directory_1:n(6127,e.DiagnosticCategory.Message,"Resolving_type_reference_directive_0_containing_file_not_set_root_directory_1_6127","======== Resolving type reference directive '{0}', containing file not set, root directory '{1}'. ========"),Resolving_type_reference_directive_0_containing_file_not_set_root_directory_not_set:n(6128,e.DiagnosticCategory.Message,"Resolving_type_reference_directive_0_containing_file_not_set_root_directory_not_set_6128","======== Resolving type reference directive '{0}', containing file not set, root directory not set. ========"),Resolving_real_path_for_0_result_1:n(6130,e.DiagnosticCategory.Message,"Resolving_real_path_for_0_result_1_6130","Resolving real path for '{0}', result '{1}'."),Cannot_compile_modules_using_option_0_unless_the_module_flag_is_amd_or_system:n(6131,e.DiagnosticCategory.Error,"Cannot_compile_modules_using_option_0_unless_the_module_flag_is_amd_or_system_6131","Cannot compile modules using option '{0}' unless the '--module' flag is 'amd' or 'system'."),File_name_0_has_a_1_extension_stripping_it:n(6132,e.DiagnosticCategory.Message,"File_name_0_has_a_1_extension_stripping_it_6132","File name '{0}' has a '{1}' extension - stripping it."),_0_is_declared_but_its_value_is_never_read:n(6133,e.DiagnosticCategory.Error,"_0_is_declared_but_its_value_is_never_read_6133","'{0}' is declared but its value is never read.",!0),Report_errors_on_unused_locals:n(6134,e.DiagnosticCategory.Message,"Report_errors_on_unused_locals_6134","Report errors on unused locals."),Report_errors_on_unused_parameters:n(6135,e.DiagnosticCategory.Message,"Report_errors_on_unused_parameters_6135","Report errors on unused parameters."),The_maximum_dependency_depth_to_search_under_node_modules_and_load_JavaScript_files:n(6136,e.DiagnosticCategory.Message,"The_maximum_dependency_depth_to_search_under_node_modules_and_load_JavaScript_files_6136","The maximum dependency depth to search under node_modules and load JavaScript files."),Cannot_import_type_declaration_files_Consider_importing_0_instead_of_1:n(6137,e.DiagnosticCategory.Error,"Cannot_import_type_declaration_files_Consider_importing_0_instead_of_1_6137","Cannot import type declaration files. Consider importing '{0}' instead of '{1}'."),Property_0_is_declared_but_its_value_is_never_read:n(6138,e.DiagnosticCategory.Error,"Property_0_is_declared_but_its_value_is_never_read_6138","Property '{0}' is declared but its value is never read.",!0),Import_emit_helpers_from_tslib:n(6139,e.DiagnosticCategory.Message,"Import_emit_helpers_from_tslib_6139","Import emit helpers from 'tslib'."),Auto_discovery_for_typings_is_enabled_in_project_0_Running_extra_resolution_pass_for_module_1_using_cache_location_2:n(6140,e.DiagnosticCategory.Error,"Auto_discovery_for_typings_is_enabled_in_project_0_Running_extra_resolution_pass_for_module_1_using__6140","Auto discovery for typings is enabled in project '{0}'. Running extra resolution pass for module '{1}' using cache location '{2}'."),Parse_in_strict_mode_and_emit_use_strict_for_each_source_file:n(6141,e.DiagnosticCategory.Message,"Parse_in_strict_mode_and_emit_use_strict_for_each_source_file_6141",'Parse in strict mode and emit "use strict" for each source file.'),Module_0_was_resolved_to_1_but_jsx_is_not_set:n(6142,e.DiagnosticCategory.Error,"Module_0_was_resolved_to_1_but_jsx_is_not_set_6142","Module '{0}' was resolved to '{1}', but '--jsx' is not set."),Module_0_was_resolved_as_locally_declared_ambient_module_in_file_1:n(6144,e.DiagnosticCategory.Message,"Module_0_was_resolved_as_locally_declared_ambient_module_in_file_1_6144","Module '{0}' was resolved as locally declared ambient module in file '{1}'."),Module_0_was_resolved_as_ambient_module_declared_in_1_since_this_file_was_not_modified:n(6145,e.DiagnosticCategory.Message,"Module_0_was_resolved_as_ambient_module_declared_in_1_since_this_file_was_not_modified_6145","Module '{0}' was resolved as ambient module declared in '{1}' since this file was not modified."),Specify_the_JSX_factory_function_to_use_when_targeting_react_JSX_emit_e_g_React_createElement_or_h:n(6146,e.DiagnosticCategory.Message,"Specify_the_JSX_factory_function_to_use_when_targeting_react_JSX_emit_e_g_React_createElement_or_h_6146","Specify the JSX factory function to use when targeting 'react' JSX emit, e.g. 'React.createElement' or 'h'."),Resolution_for_module_0_was_found_in_cache_from_location_1:n(6147,e.DiagnosticCategory.Message,"Resolution_for_module_0_was_found_in_cache_from_location_1_6147","Resolution for module '{0}' was found in cache from location '{1}'."),Directory_0_does_not_exist_skipping_all_lookups_in_it:n(6148,e.DiagnosticCategory.Message,"Directory_0_does_not_exist_skipping_all_lookups_in_it_6148","Directory '{0}' does not exist, skipping all lookups in it."),Show_diagnostic_information:n(6149,e.DiagnosticCategory.Message,"Show_diagnostic_information_6149","Show diagnostic information."),Show_verbose_diagnostic_information:n(6150,e.DiagnosticCategory.Message,"Show_verbose_diagnostic_information_6150","Show verbose diagnostic information."),Emit_a_single_file_with_source_maps_instead_of_having_a_separate_file:n(6151,e.DiagnosticCategory.Message,"Emit_a_single_file_with_source_maps_instead_of_having_a_separate_file_6151","Emit a single file with source maps instead of having a separate file."),Emit_the_source_alongside_the_sourcemaps_within_a_single_file_requires_inlineSourceMap_or_sourceMap_to_be_set:n(6152,e.DiagnosticCategory.Message,"Emit_the_source_alongside_the_sourcemaps_within_a_single_file_requires_inlineSourceMap_or_sourceMap__6152","Emit the source alongside the sourcemaps within a single file; requires '--inlineSourceMap' or '--sourceMap' to be set."),Transpile_each_file_as_a_separate_module_similar_to_ts_transpileModule:n(6153,e.DiagnosticCategory.Message,"Transpile_each_file_as_a_separate_module_similar_to_ts_transpileModule_6153","Transpile each file as a separate module (similar to 'ts.transpileModule')."),Print_names_of_generated_files_part_of_the_compilation:n(6154,e.DiagnosticCategory.Message,"Print_names_of_generated_files_part_of_the_compilation_6154","Print names of generated files part of the compilation."),Print_names_of_files_part_of_the_compilation:n(6155,e.DiagnosticCategory.Message,"Print_names_of_files_part_of_the_compilation_6155","Print names of files part of the compilation."),The_locale_used_when_displaying_messages_to_the_user_e_g_en_us:n(6156,e.DiagnosticCategory.Message,"The_locale_used_when_displaying_messages_to_the_user_e_g_en_us_6156","The locale used when displaying messages to the user (e.g. 'en-us')"),Do_not_generate_custom_helper_functions_like_extends_in_compiled_output:n(6157,e.DiagnosticCategory.Message,"Do_not_generate_custom_helper_functions_like_extends_in_compiled_output_6157","Do not generate custom helper functions like '__extends' in compiled output."),Do_not_include_the_default_library_file_lib_d_ts:n(6158,e.DiagnosticCategory.Message,"Do_not_include_the_default_library_file_lib_d_ts_6158","Do not include the default library file (lib.d.ts)."),Do_not_add_triple_slash_references_or_imported_modules_to_the_list_of_compiled_files:n(6159,e.DiagnosticCategory.Message,"Do_not_add_triple_slash_references_or_imported_modules_to_the_list_of_compiled_files_6159","Do not add triple-slash references or imported modules to the list of compiled files."),Deprecated_Use_skipLibCheck_instead_Skip_type_checking_of_default_library_declaration_files:n(6160,e.DiagnosticCategory.Message,"Deprecated_Use_skipLibCheck_instead_Skip_type_checking_of_default_library_declaration_files_6160","[Deprecated] Use '--skipLibCheck' instead. Skip type checking of default library declaration files."),List_of_folders_to_include_type_definitions_from:n(6161,e.DiagnosticCategory.Message,"List_of_folders_to_include_type_definitions_from_6161","List of folders to include type definitions from."),Disable_size_limitations_on_JavaScript_projects:n(6162,e.DiagnosticCategory.Message,"Disable_size_limitations_on_JavaScript_projects_6162","Disable size limitations on JavaScript projects."),The_character_set_of_the_input_files:n(6163,e.DiagnosticCategory.Message,"The_character_set_of_the_input_files_6163","The character set of the input files."),Emit_a_UTF_8_Byte_Order_Mark_BOM_in_the_beginning_of_output_files:n(6164,e.DiagnosticCategory.Message,"Emit_a_UTF_8_Byte_Order_Mark_BOM_in_the_beginning_of_output_files_6164","Emit a UTF-8 Byte Order Mark (BOM) in the beginning of output files."),Do_not_truncate_error_messages:n(6165,e.DiagnosticCategory.Message,"Do_not_truncate_error_messages_6165","Do not truncate error messages."),Output_directory_for_generated_declaration_files:n(6166,e.DiagnosticCategory.Message,"Output_directory_for_generated_declaration_files_6166","Output directory for generated declaration files."),A_series_of_entries_which_re_map_imports_to_lookup_locations_relative_to_the_baseUrl:n(6167,e.DiagnosticCategory.Message,"A_series_of_entries_which_re_map_imports_to_lookup_locations_relative_to_the_baseUrl_6167","A series of entries which re-map imports to lookup locations relative to the 'baseUrl'."),List_of_root_folders_whose_combined_content_represents_the_structure_of_the_project_at_runtime:n(6168,e.DiagnosticCategory.Message,"List_of_root_folders_whose_combined_content_represents_the_structure_of_the_project_at_runtime_6168","List of root folders whose combined content represents the structure of the project at runtime."),Show_all_compiler_options:n(6169,e.DiagnosticCategory.Message,"Show_all_compiler_options_6169","Show all compiler options."),Deprecated_Use_outFile_instead_Concatenate_and_emit_output_to_single_file:n(6170,e.DiagnosticCategory.Message,"Deprecated_Use_outFile_instead_Concatenate_and_emit_output_to_single_file_6170","[Deprecated] Use '--outFile' instead. Concatenate and emit output to single file"),Command_line_Options:n(6171,e.DiagnosticCategory.Message,"Command_line_Options_6171","Command-line Options"),Basic_Options:n(6172,e.DiagnosticCategory.Message,"Basic_Options_6172","Basic Options"),Strict_Type_Checking_Options:n(6173,e.DiagnosticCategory.Message,"Strict_Type_Checking_Options_6173","Strict Type-Checking Options"),Module_Resolution_Options:n(6174,e.DiagnosticCategory.Message,"Module_Resolution_Options_6174","Module Resolution Options"),Source_Map_Options:n(6175,e.DiagnosticCategory.Message,"Source_Map_Options_6175","Source Map Options"),Additional_Checks:n(6176,e.DiagnosticCategory.Message,"Additional_Checks_6176","Additional Checks"),Experimental_Options:n(6177,e.DiagnosticCategory.Message,"Experimental_Options_6177","Experimental Options"),Advanced_Options:n(6178,e.DiagnosticCategory.Message,"Advanced_Options_6178","Advanced Options"),Provide_full_support_for_iterables_in_for_of_spread_and_destructuring_when_targeting_ES5_or_ES3:n(6179,e.DiagnosticCategory.Message,"Provide_full_support_for_iterables_in_for_of_spread_and_destructuring_when_targeting_ES5_or_ES3_6179","Provide full support for iterables in 'for-of', spread, and destructuring when targeting 'ES5' or 'ES3'."),Enable_all_strict_type_checking_options:n(6180,e.DiagnosticCategory.Message,"Enable_all_strict_type_checking_options_6180","Enable all strict type-checking options."),List_of_language_service_plugins:n(6181,e.DiagnosticCategory.Message,"List_of_language_service_plugins_6181","List of language service plugins."),Scoped_package_detected_looking_in_0:n(6182,e.DiagnosticCategory.Message,"Scoped_package_detected_looking_in_0_6182","Scoped package detected, looking in '{0}'"),Reusing_resolution_of_module_0_to_file_1_from_old_program:n(6183,e.DiagnosticCategory.Message,"Reusing_resolution_of_module_0_to_file_1_from_old_program_6183","Reusing resolution of module '{0}' to file '{1}' from old program."),Reusing_module_resolutions_originating_in_0_since_resolutions_are_unchanged_from_old_program:n(6184,e.DiagnosticCategory.Message,"Reusing_module_resolutions_originating_in_0_since_resolutions_are_unchanged_from_old_program_6184","Reusing module resolutions originating in '{0}' since resolutions are unchanged from old program."),Disable_strict_checking_of_generic_signatures_in_function_types:n(6185,e.DiagnosticCategory.Message,"Disable_strict_checking_of_generic_signatures_in_function_types_6185","Disable strict checking of generic signatures in function types."),Enable_strict_checking_of_function_types:n(6186,e.DiagnosticCategory.Message,"Enable_strict_checking_of_function_types_6186","Enable strict checking of function types."),Enable_strict_checking_of_property_initialization_in_classes:n(6187,e.DiagnosticCategory.Message,"Enable_strict_checking_of_property_initialization_in_classes_6187","Enable strict checking of property initialization in classes."),Numeric_separators_are_not_allowed_here:n(6188,e.DiagnosticCategory.Error,"Numeric_separators_are_not_allowed_here_6188","Numeric separators are not allowed here."),Multiple_consecutive_numeric_separators_are_not_permitted:n(6189,e.DiagnosticCategory.Error,"Multiple_consecutive_numeric_separators_are_not_permitted_6189","Multiple consecutive numeric separators are not permitted."),Whether_to_keep_outdated_console_output_in_watch_mode_instead_of_clearing_the_screen:n(6191,e.DiagnosticCategory.Message,"Whether_to_keep_outdated_console_output_in_watch_mode_instead_of_clearing_the_screen_6191","Whether to keep outdated console output in watch mode instead of clearing the screen."),All_imports_in_import_declaration_are_unused:n(6192,e.DiagnosticCategory.Error,"All_imports_in_import_declaration_are_unused_6192","All imports in import declaration are unused.",!0),Found_1_error_Watching_for_file_changes:n(6193,e.DiagnosticCategory.Message,"Found_1_error_Watching_for_file_changes_6193","Found 1 error. Watching for file changes."),Found_0_errors_Watching_for_file_changes:n(6194,e.DiagnosticCategory.Message,"Found_0_errors_Watching_for_file_changes_6194","Found {0} errors. Watching for file changes."),Resolve_keyof_to_string_valued_property_names_only_no_numbers_or_symbols:n(6195,e.DiagnosticCategory.Message,"Resolve_keyof_to_string_valued_property_names_only_no_numbers_or_symbols_6195","Resolve 'keyof' to string valued property names only (no numbers or symbols)."),_0_is_declared_but_never_used:n(6196,e.DiagnosticCategory.Error,"_0_is_declared_but_never_used_6196","'{0}' is declared but never used.",!0),Include_modules_imported_with_json_extension:n(6197,e.DiagnosticCategory.Message,"Include_modules_imported_with_json_extension_6197","Include modules imported with '.json' extension"),All_destructured_elements_are_unused:n(6198,e.DiagnosticCategory.Error,"All_destructured_elements_are_unused_6198","All destructured elements are unused.",!0),All_variables_are_unused:n(6199,e.DiagnosticCategory.Error,"All_variables_are_unused_6199","All variables are unused.",!0),Definitions_of_the_following_identifiers_conflict_with_those_in_another_file_Colon_0:n(6200,e.DiagnosticCategory.Error,"Definitions_of_the_following_identifiers_conflict_with_those_in_another_file_Colon_0_6200","Definitions of the following identifiers conflict with those in another file: {0}"),Conflicts_are_in_this_file:n(6201,e.DiagnosticCategory.Message,"Conflicts_are_in_this_file_6201","Conflicts are in this file."),Project_references_may_not_form_a_circular_graph_Cycle_detected_Colon_0:n(6202,e.DiagnosticCategory.Error,"Project_references_may_not_form_a_circular_graph_Cycle_detected_Colon_0_6202","Project references may not form a circular graph. Cycle detected: {0}"),_0_was_also_declared_here:n(6203,e.DiagnosticCategory.Message,"_0_was_also_declared_here_6203","'{0}' was also declared here."),and_here:n(6204,e.DiagnosticCategory.Message,"and_here_6204","and here."),All_type_parameters_are_unused:n(6205,e.DiagnosticCategory.Error,"All_type_parameters_are_unused_6205","All type parameters are unused."),package_json_has_a_typesVersions_field_with_version_specific_path_mappings:n(6206,e.DiagnosticCategory.Message,"package_json_has_a_typesVersions_field_with_version_specific_path_mappings_6206","'package.json' has a 'typesVersions' field with version-specific path mappings."),package_json_does_not_have_a_typesVersions_entry_that_matches_version_0:n(6207,e.DiagnosticCategory.Message,"package_json_does_not_have_a_typesVersions_entry_that_matches_version_0_6207","'package.json' does not have a 'typesVersions' entry that matches version '{0}'."),package_json_has_a_typesVersions_entry_0_that_matches_compiler_version_1_looking_for_a_pattern_to_match_module_name_2:n(6208,e.DiagnosticCategory.Message,"package_json_has_a_typesVersions_entry_0_that_matches_compiler_version_1_looking_for_a_pattern_to_ma_6208","'package.json' has a 'typesVersions' entry '{0}' that matches compiler version '{1}', looking for a pattern to match module name '{2}'."),package_json_has_a_typesVersions_entry_0_that_is_not_a_valid_semver_range:n(6209,e.DiagnosticCategory.Message,"package_json_has_a_typesVersions_entry_0_that_is_not_a_valid_semver_range_6209","'package.json' has a 'typesVersions' entry '{0}' that is not a valid semver range."),An_argument_for_0_was_not_provided:n(6210,e.DiagnosticCategory.Message,"An_argument_for_0_was_not_provided_6210","An argument for '{0}' was not provided."),An_argument_matching_this_binding_pattern_was_not_provided:n(6211,e.DiagnosticCategory.Message,"An_argument_matching_this_binding_pattern_was_not_provided_6211","An argument matching this binding pattern was not provided."),Did_you_mean_to_call_this_expression:n(6212,e.DiagnosticCategory.Message,"Did_you_mean_to_call_this_expression_6212","Did you mean to call this expression?"),Did_you_mean_to_use_new_with_this_expression:n(6213,e.DiagnosticCategory.Message,"Did_you_mean_to_use_new_with_this_expression_6213","Did you mean to use 'new' with this expression?"),Enable_strict_bind_call_and_apply_methods_on_functions:n(6214,e.DiagnosticCategory.Message,"Enable_strict_bind_call_and_apply_methods_on_functions_6214","Enable strict 'bind', 'call', and 'apply' methods on functions."),Using_compiler_options_of_project_reference_redirect_0:n(6215,e.DiagnosticCategory.Message,"Using_compiler_options_of_project_reference_redirect_0_6215","Using compiler options of project reference redirect '{0}'."),Found_1_error:n(6216,e.DiagnosticCategory.Message,"Found_1_error_6216","Found 1 error."),Found_0_errors:n(6217,e.DiagnosticCategory.Message,"Found_0_errors_6217","Found {0} errors."),Module_name_0_was_successfully_resolved_to_1_with_Package_ID_2:n(6218,e.DiagnosticCategory.Message,"Module_name_0_was_successfully_resolved_to_1_with_Package_ID_2_6218","======== Module name '{0}' was successfully resolved to '{1}' with Package ID '{2}'. ========"),Type_reference_directive_0_was_successfully_resolved_to_1_with_Package_ID_2_primary_Colon_3:n(6219,e.DiagnosticCategory.Message,"Type_reference_directive_0_was_successfully_resolved_to_1_with_Package_ID_2_primary_Colon_3_6219","======== Type reference directive '{0}' was successfully resolved to '{1}' with Package ID '{2}', primary: {3}. ========"),package_json_had_a_falsy_0_field:n(6220,e.DiagnosticCategory.Message,"package_json_had_a_falsy_0_field_6220","'package.json' had a falsy '{0}' field."),Disable_use_of_source_files_instead_of_declaration_files_from_referenced_projects:n(6221,e.DiagnosticCategory.Message,"Disable_use_of_source_files_instead_of_declaration_files_from_referenced_projects_6221","Disable use of source files instead of declaration files from referenced projects."),Emit_class_fields_with_Define_instead_of_Set:n(6222,e.DiagnosticCategory.Message,"Emit_class_fields_with_Define_instead_of_Set_6222","Emit class fields with Define instead of Set."),Generates_a_CPU_profile:n(6223,e.DiagnosticCategory.Message,"Generates_a_CPU_profile_6223","Generates a CPU profile."),Disable_solution_searching_for_this_project:n(6224,e.DiagnosticCategory.Message,"Disable_solution_searching_for_this_project_6224","Disable solution searching for this project."),Specify_strategy_for_watching_file_Colon_FixedPollingInterval_default_PriorityPollingInterval_DynamicPriorityPolling_FixedChunkSizePolling_UseFsEvents_UseFsEventsOnParentDirectory:n(6225,e.DiagnosticCategory.Message,"Specify_strategy_for_watching_file_Colon_FixedPollingInterval_default_PriorityPollingInterval_Dynami_6225","Specify strategy for watching file: 'FixedPollingInterval' (default), 'PriorityPollingInterval', 'DynamicPriorityPolling', 'FixedChunkSizePolling', 'UseFsEvents', 'UseFsEventsOnParentDirectory'."),Specify_strategy_for_watching_directory_on_platforms_that_don_t_support_recursive_watching_natively_Colon_UseFsEvents_default_FixedPollingInterval_DynamicPriorityPolling_FixedChunkSizePolling:n(6226,e.DiagnosticCategory.Message,"Specify_strategy_for_watching_directory_on_platforms_that_don_t_support_recursive_watching_natively__6226","Specify strategy for watching directory on platforms that don't support recursive watching natively: 'UseFsEvents' (default), 'FixedPollingInterval', 'DynamicPriorityPolling', 'FixedChunkSizePolling'."),Specify_strategy_for_creating_a_polling_watch_when_it_fails_to_create_using_file_system_events_Colon_FixedInterval_default_PriorityInterval_DynamicPriority_FixedChunkSize:n(6227,e.DiagnosticCategory.Message,"Specify_strategy_for_creating_a_polling_watch_when_it_fails_to_create_using_file_system_events_Colon_6227","Specify strategy for creating a polling watch when it fails to create using file system events: 'FixedInterval' (default), 'PriorityInterval', 'DynamicPriority', 'FixedChunkSize'."),Synchronously_call_callbacks_and_update_the_state_of_directory_watchers_on_platforms_that_don_t_support_recursive_watching_natively:n(6228,e.DiagnosticCategory.Message,"Synchronously_call_callbacks_and_update_the_state_of_directory_watchers_on_platforms_that_don_t_supp_6228","Synchronously call callbacks and update the state of directory watchers on platforms that don't support recursive watching natively."),Tag_0_expects_at_least_1_arguments_but_the_JSX_factory_2_provides_at_most_3:n(6229,e.DiagnosticCategory.Error,"Tag_0_expects_at_least_1_arguments_but_the_JSX_factory_2_provides_at_most_3_6229","Tag '{0}' expects at least '{1}' arguments, but the JSX factory '{2}' provides at most '{3}'."),Option_0_can_only_be_specified_in_tsconfig_json_file_or_set_to_false_or_null_on_command_line:n(6230,e.DiagnosticCategory.Error,"Option_0_can_only_be_specified_in_tsconfig_json_file_or_set_to_false_or_null_on_command_line_6230","Option '{0}' can only be specified in 'tsconfig.json' file or set to 'false' or 'null' on command line."),Could_not_resolve_the_path_0_with_the_extensions_Colon_1:n(6231,e.DiagnosticCategory.Error,"Could_not_resolve_the_path_0_with_the_extensions_Colon_1_6231","Could not resolve the path '{0}' with the extensions: {1}."),Declaration_augments_declaration_in_another_file_This_cannot_be_serialized:n(6232,e.DiagnosticCategory.Error,"Declaration_augments_declaration_in_another_file_This_cannot_be_serialized_6232","Declaration augments declaration in another file. This cannot be serialized."),This_is_the_declaration_being_augmented_Consider_moving_the_augmenting_declaration_into_the_same_file:n(6233,e.DiagnosticCategory.Error,"This_is_the_declaration_being_augmented_Consider_moving_the_augmenting_declaration_into_the_same_fil_6233","This is the declaration being augmented. Consider moving the augmenting declaration into the same file."),This_expression_is_not_callable_because_it_is_a_get_accessor_Did_you_mean_to_use_it_without:n(6234,e.DiagnosticCategory.Error,"This_expression_is_not_callable_because_it_is_a_get_accessor_Did_you_mean_to_use_it_without_6234","This expression is not callable because it is a 'get' accessor. Did you mean to use it without '()'?"),Disable_loading_referenced_projects:n(6235,e.DiagnosticCategory.Message,"Disable_loading_referenced_projects_6235","Disable loading referenced projects."),Arguments_for_the_rest_parameter_0_were_not_provided:n(6236,e.DiagnosticCategory.Error,"Arguments_for_the_rest_parameter_0_were_not_provided_6236","Arguments for the rest parameter '{0}' were not provided."),Generates_an_event_trace_and_a_list_of_types:n(6237,e.DiagnosticCategory.Message,"Generates_an_event_trace_and_a_list_of_types_6237","Generates an event trace and a list of types."),Specify_the_module_specifier_to_be_used_to_import_the_jsx_and_jsxs_factory_functions_from_eg_react:n(6238,e.DiagnosticCategory.Error,"Specify_the_module_specifier_to_be_used_to_import_the_jsx_and_jsxs_factory_functions_from_eg_react_6238","Specify the module specifier to be used to import the 'jsx' and 'jsxs' factory functions from. eg, react"),File_0_exists_according_to_earlier_cached_lookups:n(6239,e.DiagnosticCategory.Message,"File_0_exists_according_to_earlier_cached_lookups_6239","File '{0}' exists according to earlier cached lookups."),File_0_does_not_exist_according_to_earlier_cached_lookups:n(6240,e.DiagnosticCategory.Message,"File_0_does_not_exist_according_to_earlier_cached_lookups_6240","File '{0}' does not exist according to earlier cached lookups."),Resolution_for_type_reference_directive_0_was_found_in_cache_from_location_1:n(6241,e.DiagnosticCategory.Message,"Resolution_for_type_reference_directive_0_was_found_in_cache_from_location_1_6241","Resolution for type reference directive '{0}' was found in cache from location '{1}'."),Resolving_type_reference_directive_0_containing_file_1:n(6242,e.DiagnosticCategory.Message,"Resolving_type_reference_directive_0_containing_file_1_6242","======== Resolving type reference directive '{0}', containing file '{1}'. ========"),Projects_to_reference:n(6300,e.DiagnosticCategory.Message,"Projects_to_reference_6300","Projects to reference"),Enable_project_compilation:n(6302,e.DiagnosticCategory.Message,"Enable_project_compilation_6302","Enable project compilation"),Composite_projects_may_not_disable_declaration_emit:n(6304,e.DiagnosticCategory.Error,"Composite_projects_may_not_disable_declaration_emit_6304","Composite projects may not disable declaration emit."),Output_file_0_has_not_been_built_from_source_file_1:n(6305,e.DiagnosticCategory.Error,"Output_file_0_has_not_been_built_from_source_file_1_6305","Output file '{0}' has not been built from source file '{1}'."),Referenced_project_0_must_have_setting_composite_Colon_true:n(6306,e.DiagnosticCategory.Error,"Referenced_project_0_must_have_setting_composite_Colon_true_6306","Referenced project '{0}' must have setting \"composite\": true."),File_0_is_not_listed_within_the_file_list_of_project_1_Projects_must_list_all_files_or_use_an_include_pattern:n(6307,e.DiagnosticCategory.Error,"File_0_is_not_listed_within_the_file_list_of_project_1_Projects_must_list_all_files_or_use_an_includ_6307","File '{0}' is not listed within the file list of project '{1}'. Projects must list all files or use an 'include' pattern."),Cannot_prepend_project_0_because_it_does_not_have_outFile_set:n(6308,e.DiagnosticCategory.Error,"Cannot_prepend_project_0_because_it_does_not_have_outFile_set_6308","Cannot prepend project '{0}' because it does not have 'outFile' set"),Output_file_0_from_project_1_does_not_exist:n(6309,e.DiagnosticCategory.Error,"Output_file_0_from_project_1_does_not_exist_6309","Output file '{0}' from project '{1}' does not exist"),Referenced_project_0_may_not_disable_emit:n(6310,e.DiagnosticCategory.Error,"Referenced_project_0_may_not_disable_emit_6310","Referenced project '{0}' may not disable emit."),Project_0_is_out_of_date_because_oldest_output_1_is_older_than_newest_input_2:n(6350,e.DiagnosticCategory.Message,"Project_0_is_out_of_date_because_oldest_output_1_is_older_than_newest_input_2_6350","Project '{0}' is out of date because oldest output '{1}' is older than newest input '{2}'"),Project_0_is_up_to_date_because_newest_input_1_is_older_than_oldest_output_2:n(6351,e.DiagnosticCategory.Message,"Project_0_is_up_to_date_because_newest_input_1_is_older_than_oldest_output_2_6351","Project '{0}' is up to date because newest input '{1}' is older than oldest output '{2}'"),Project_0_is_out_of_date_because_output_file_1_does_not_exist:n(6352,e.DiagnosticCategory.Message,"Project_0_is_out_of_date_because_output_file_1_does_not_exist_6352","Project '{0}' is out of date because output file '{1}' does not exist"),Project_0_is_out_of_date_because_its_dependency_1_is_out_of_date:n(6353,e.DiagnosticCategory.Message,"Project_0_is_out_of_date_because_its_dependency_1_is_out_of_date_6353","Project '{0}' is out of date because its dependency '{1}' is out of date"),Project_0_is_up_to_date_with_d_ts_files_from_its_dependencies:n(6354,e.DiagnosticCategory.Message,"Project_0_is_up_to_date_with_d_ts_files_from_its_dependencies_6354","Project '{0}' is up to date with .d.ts files from its dependencies"),Projects_in_this_build_Colon_0:n(6355,e.DiagnosticCategory.Message,"Projects_in_this_build_Colon_0_6355","Projects in this build: {0}"),A_non_dry_build_would_delete_the_following_files_Colon_0:n(6356,e.DiagnosticCategory.Message,"A_non_dry_build_would_delete_the_following_files_Colon_0_6356","A non-dry build would delete the following files: {0}"),A_non_dry_build_would_build_project_0:n(6357,e.DiagnosticCategory.Message,"A_non_dry_build_would_build_project_0_6357","A non-dry build would build project '{0}'"),Building_project_0:n(6358,e.DiagnosticCategory.Message,"Building_project_0_6358","Building project '{0}'..."),Updating_output_timestamps_of_project_0:n(6359,e.DiagnosticCategory.Message,"Updating_output_timestamps_of_project_0_6359","Updating output timestamps of project '{0}'..."),delete_this_Project_0_is_up_to_date_because_it_was_previously_built:n(6360,e.DiagnosticCategory.Message,"delete_this_Project_0_is_up_to_date_because_it_was_previously_built_6360","delete this - Project '{0}' is up to date because it was previously built"),Project_0_is_up_to_date:n(6361,e.DiagnosticCategory.Message,"Project_0_is_up_to_date_6361","Project '{0}' is up to date"),Skipping_build_of_project_0_because_its_dependency_1_has_errors:n(6362,e.DiagnosticCategory.Message,"Skipping_build_of_project_0_because_its_dependency_1_has_errors_6362","Skipping build of project '{0}' because its dependency '{1}' has errors"),Project_0_can_t_be_built_because_its_dependency_1_has_errors:n(6363,e.DiagnosticCategory.Message,"Project_0_can_t_be_built_because_its_dependency_1_has_errors_6363","Project '{0}' can't be built because its dependency '{1}' has errors"),Build_one_or_more_projects_and_their_dependencies_if_out_of_date:n(6364,e.DiagnosticCategory.Message,"Build_one_or_more_projects_and_their_dependencies_if_out_of_date_6364","Build one or more projects and their dependencies, if out of date"),Delete_the_outputs_of_all_projects:n(6365,e.DiagnosticCategory.Message,"Delete_the_outputs_of_all_projects_6365","Delete the outputs of all projects"),Enable_verbose_logging:n(6366,e.DiagnosticCategory.Message,"Enable_verbose_logging_6366","Enable verbose logging"),Show_what_would_be_built_or_deleted_if_specified_with_clean:n(6367,e.DiagnosticCategory.Message,"Show_what_would_be_built_or_deleted_if_specified_with_clean_6367","Show what would be built (or deleted, if specified with '--clean')"),Build_all_projects_including_those_that_appear_to_be_up_to_date:n(6368,e.DiagnosticCategory.Message,"Build_all_projects_including_those_that_appear_to_be_up_to_date_6368","Build all projects, including those that appear to be up to date"),Option_build_must_be_the_first_command_line_argument:n(6369,e.DiagnosticCategory.Error,"Option_build_must_be_the_first_command_line_argument_6369","Option '--build' must be the first command line argument."),Options_0_and_1_cannot_be_combined:n(6370,e.DiagnosticCategory.Error,"Options_0_and_1_cannot_be_combined_6370","Options '{0}' and '{1}' cannot be combined."),Updating_unchanged_output_timestamps_of_project_0:n(6371,e.DiagnosticCategory.Message,"Updating_unchanged_output_timestamps_of_project_0_6371","Updating unchanged output timestamps of project '{0}'..."),Project_0_is_out_of_date_because_output_of_its_dependency_1_has_changed:n(6372,e.DiagnosticCategory.Message,"Project_0_is_out_of_date_because_output_of_its_dependency_1_has_changed_6372","Project '{0}' is out of date because output of its dependency '{1}' has changed"),Updating_output_of_project_0:n(6373,e.DiagnosticCategory.Message,"Updating_output_of_project_0_6373","Updating output of project '{0}'..."),A_non_dry_build_would_update_timestamps_for_output_of_project_0:n(6374,e.DiagnosticCategory.Message,"A_non_dry_build_would_update_timestamps_for_output_of_project_0_6374","A non-dry build would update timestamps for output of project '{0}'"),A_non_dry_build_would_update_output_of_project_0:n(6375,e.DiagnosticCategory.Message,"A_non_dry_build_would_update_output_of_project_0_6375","A non-dry build would update output of project '{0}'"),Cannot_update_output_of_project_0_because_there_was_error_reading_file_1:n(6376,e.DiagnosticCategory.Message,"Cannot_update_output_of_project_0_because_there_was_error_reading_file_1_6376","Cannot update output of project '{0}' because there was error reading file '{1}'"),Cannot_write_file_0_because_it_will_overwrite_tsbuildinfo_file_generated_by_referenced_project_1:n(6377,e.DiagnosticCategory.Error,"Cannot_write_file_0_because_it_will_overwrite_tsbuildinfo_file_generated_by_referenced_project_1_6377","Cannot write file '{0}' because it will overwrite '.tsbuildinfo' file generated by referenced project '{1}'"),Enable_incremental_compilation:n(6378,e.DiagnosticCategory.Message,"Enable_incremental_compilation_6378","Enable incremental compilation"),Composite_projects_may_not_disable_incremental_compilation:n(6379,e.DiagnosticCategory.Error,"Composite_projects_may_not_disable_incremental_compilation_6379","Composite projects may not disable incremental compilation."),Specify_file_to_store_incremental_compilation_information:n(6380,e.DiagnosticCategory.Message,"Specify_file_to_store_incremental_compilation_information_6380","Specify file to store incremental compilation information"),Project_0_is_out_of_date_because_output_for_it_was_generated_with_version_1_that_differs_with_current_version_2:n(6381,e.DiagnosticCategory.Message,"Project_0_is_out_of_date_because_output_for_it_was_generated_with_version_1_that_differs_with_curren_6381","Project '{0}' is out of date because output for it was generated with version '{1}' that differs with current version '{2}'"),Skipping_build_of_project_0_because_its_dependency_1_was_not_built:n(6382,e.DiagnosticCategory.Message,"Skipping_build_of_project_0_because_its_dependency_1_was_not_built_6382","Skipping build of project '{0}' because its dependency '{1}' was not built"),Project_0_can_t_be_built_because_its_dependency_1_was_not_built:n(6383,e.DiagnosticCategory.Message,"Project_0_can_t_be_built_because_its_dependency_1_was_not_built_6383","Project '{0}' can't be built because its dependency '{1}' was not built"),Have_recompiles_in_incremental_and_watch_assume_that_changes_within_a_file_will_only_affect_files_directly_depending_on_it:n(6384,e.DiagnosticCategory.Message,"Have_recompiles_in_incremental_and_watch_assume_that_changes_within_a_file_will_only_affect_files_di_6384","Have recompiles in '--incremental' and '--watch' assume that changes within a file will only affect files directly depending on it."),_0_is_deprecated:n(6385,e.DiagnosticCategory.Suggestion,"_0_is_deprecated_6385","'{0}' is deprecated.",void 0,void 0,!0),Performance_timings_for_diagnostics_or_extendedDiagnostics_are_not_available_in_this_session_A_native_implementation_of_the_Web_Performance_API_could_not_be_found:n(6386,e.DiagnosticCategory.Message,"Performance_timings_for_diagnostics_or_extendedDiagnostics_are_not_available_in_this_session_A_nativ_6386","Performance timings for '--diagnostics' or '--extendedDiagnostics' are not available in this session. A native implementation of the Web Performance API could not be found."),The_signature_0_of_1_is_deprecated:n(6387,e.DiagnosticCategory.Suggestion,"The_signature_0_of_1_is_deprecated_6387","The signature '{0}' of '{1}' is deprecated.",void 0,void 0,!0),Project_0_is_being_forcibly_rebuilt:n(6388,e.DiagnosticCategory.Message,"Project_0_is_being_forcibly_rebuilt_6388","Project '{0}' is being forcibly rebuilt"),The_expected_type_comes_from_property_0_which_is_declared_here_on_type_1:n(6500,e.DiagnosticCategory.Message,"The_expected_type_comes_from_property_0_which_is_declared_here_on_type_1_6500","The expected type comes from property '{0}' which is declared here on type '{1}'"),The_expected_type_comes_from_this_index_signature:n(6501,e.DiagnosticCategory.Message,"The_expected_type_comes_from_this_index_signature_6501","The expected type comes from this index signature."),The_expected_type_comes_from_the_return_type_of_this_signature:n(6502,e.DiagnosticCategory.Message,"The_expected_type_comes_from_the_return_type_of_this_signature_6502","The expected type comes from the return type of this signature."),Print_names_of_files_that_are_part_of_the_compilation_and_then_stop_processing:n(6503,e.DiagnosticCategory.Message,"Print_names_of_files_that_are_part_of_the_compilation_and_then_stop_processing_6503","Print names of files that are part of the compilation and then stop processing."),File_0_is_a_JavaScript_file_Did_you_mean_to_enable_the_allowJs_option:n(6504,e.DiagnosticCategory.Error,"File_0_is_a_JavaScript_file_Did_you_mean_to_enable_the_allowJs_option_6504","File '{0}' is a JavaScript file. Did you mean to enable the 'allowJs' option?"),Print_names_of_files_and_the_reason_they_are_part_of_the_compilation:n(6505,e.DiagnosticCategory.Message,"Print_names_of_files_and_the_reason_they_are_part_of_the_compilation_6505","Print names of files and the reason they are part of the compilation."),Include_undefined_in_index_signature_results:n(6800,e.DiagnosticCategory.Message,"Include_undefined_in_index_signature_results_6800","Include 'undefined' in index signature results"),Ensure_overriding_members_in_derived_classes_are_marked_with_an_override_modifier:n(6801,e.DiagnosticCategory.Message,"Ensure_overriding_members_in_derived_classes_are_marked_with_an_override_modifier_6801","Ensure overriding members in derived classes are marked with an 'override' modifier."),Require_undeclared_properties_from_index_signatures_to_use_element_accesses:n(6802,e.DiagnosticCategory.Message,"Require_undeclared_properties_from_index_signatures_to_use_element_accesses_6802","Require undeclared properties from index signatures to use element accesses."),Variable_0_implicitly_has_an_1_type:n(7005,e.DiagnosticCategory.Error,"Variable_0_implicitly_has_an_1_type_7005","Variable '{0}' implicitly has an '{1}' type."),Parameter_0_implicitly_has_an_1_type:n(7006,e.DiagnosticCategory.Error,"Parameter_0_implicitly_has_an_1_type_7006","Parameter '{0}' implicitly has an '{1}' type."),Member_0_implicitly_has_an_1_type:n(7008,e.DiagnosticCategory.Error,"Member_0_implicitly_has_an_1_type_7008","Member '{0}' implicitly has an '{1}' type."),new_expression_whose_target_lacks_a_construct_signature_implicitly_has_an_any_type:n(7009,e.DiagnosticCategory.Error,"new_expression_whose_target_lacks_a_construct_signature_implicitly_has_an_any_type_7009","'new' expression, whose target lacks a construct signature, implicitly has an 'any' type."),_0_which_lacks_return_type_annotation_implicitly_has_an_1_return_type:n(7010,e.DiagnosticCategory.Error,"_0_which_lacks_return_type_annotation_implicitly_has_an_1_return_type_7010","'{0}', which lacks return-type annotation, implicitly has an '{1}' return type."),Function_expression_which_lacks_return_type_annotation_implicitly_has_an_0_return_type:n(7011,e.DiagnosticCategory.Error,"Function_expression_which_lacks_return_type_annotation_implicitly_has_an_0_return_type_7011","Function expression, which lacks return-type annotation, implicitly has an '{0}' return type."),Construct_signature_which_lacks_return_type_annotation_implicitly_has_an_any_return_type:n(7013,e.DiagnosticCategory.Error,"Construct_signature_which_lacks_return_type_annotation_implicitly_has_an_any_return_type_7013","Construct signature, which lacks return-type annotation, implicitly has an 'any' return type."),Function_type_which_lacks_return_type_annotation_implicitly_has_an_0_return_type:n(7014,e.DiagnosticCategory.Error,"Function_type_which_lacks_return_type_annotation_implicitly_has_an_0_return_type_7014","Function type, which lacks return-type annotation, implicitly has an '{0}' return type."),Element_implicitly_has_an_any_type_because_index_expression_is_not_of_type_number:n(7015,e.DiagnosticCategory.Error,"Element_implicitly_has_an_any_type_because_index_expression_is_not_of_type_number_7015","Element implicitly has an 'any' type because index expression is not of type 'number'."),Could_not_find_a_declaration_file_for_module_0_1_implicitly_has_an_any_type:n(7016,e.DiagnosticCategory.Error,"Could_not_find_a_declaration_file_for_module_0_1_implicitly_has_an_any_type_7016","Could not find a declaration file for module '{0}'. '{1}' implicitly has an 'any' type."),Element_implicitly_has_an_any_type_because_type_0_has_no_index_signature:n(7017,e.DiagnosticCategory.Error,"Element_implicitly_has_an_any_type_because_type_0_has_no_index_signature_7017","Element implicitly has an 'any' type because type '{0}' has no index signature."),Object_literal_s_property_0_implicitly_has_an_1_type:n(7018,e.DiagnosticCategory.Error,"Object_literal_s_property_0_implicitly_has_an_1_type_7018","Object literal's property '{0}' implicitly has an '{1}' type."),Rest_parameter_0_implicitly_has_an_any_type:n(7019,e.DiagnosticCategory.Error,"Rest_parameter_0_implicitly_has_an_any_type_7019","Rest parameter '{0}' implicitly has an 'any[]' type."),Call_signature_which_lacks_return_type_annotation_implicitly_has_an_any_return_type:n(7020,e.DiagnosticCategory.Error,"Call_signature_which_lacks_return_type_annotation_implicitly_has_an_any_return_type_7020","Call signature, which lacks return-type annotation, implicitly has an 'any' return type."),_0_implicitly_has_type_any_because_it_does_not_have_a_type_annotation_and_is_referenced_directly_or_indirectly_in_its_own_initializer:n(7022,e.DiagnosticCategory.Error,"_0_implicitly_has_type_any_because_it_does_not_have_a_type_annotation_and_is_referenced_directly_or__7022","'{0}' implicitly has type 'any' because it does not have a type annotation and is referenced directly or indirectly in its own initializer."),_0_implicitly_has_return_type_any_because_it_does_not_have_a_return_type_annotation_and_is_referenced_directly_or_indirectly_in_one_of_its_return_expressions:n(7023,e.DiagnosticCategory.Error,"_0_implicitly_has_return_type_any_because_it_does_not_have_a_return_type_annotation_and_is_reference_7023","'{0}' implicitly has return type 'any' because it does not have a return type annotation and is referenced directly or indirectly in one of its return expressions."),Function_implicitly_has_return_type_any_because_it_does_not_have_a_return_type_annotation_and_is_referenced_directly_or_indirectly_in_one_of_its_return_expressions:n(7024,e.DiagnosticCategory.Error,"Function_implicitly_has_return_type_any_because_it_does_not_have_a_return_type_annotation_and_is_ref_7024","Function implicitly has return type 'any' because it does not have a return type annotation and is referenced directly or indirectly in one of its return expressions."),Generator_implicitly_has_yield_type_0_because_it_does_not_yield_any_values_Consider_supplying_a_return_type_annotation:n(7025,e.DiagnosticCategory.Error,"Generator_implicitly_has_yield_type_0_because_it_does_not_yield_any_values_Consider_supplying_a_retu_7025","Generator implicitly has yield type '{0}' because it does not yield any values. Consider supplying a return type annotation."),JSX_element_implicitly_has_type_any_because_no_interface_JSX_0_exists:n(7026,e.DiagnosticCategory.Error,"JSX_element_implicitly_has_type_any_because_no_interface_JSX_0_exists_7026","JSX element implicitly has type 'any' because no interface 'JSX.{0}' exists."),Unreachable_code_detected:n(7027,e.DiagnosticCategory.Error,"Unreachable_code_detected_7027","Unreachable code detected.",!0),Unused_label:n(7028,e.DiagnosticCategory.Error,"Unused_label_7028","Unused label.",!0),Fallthrough_case_in_switch:n(7029,e.DiagnosticCategory.Error,"Fallthrough_case_in_switch_7029","Fallthrough case in switch."),Not_all_code_paths_return_a_value:n(7030,e.DiagnosticCategory.Error,"Not_all_code_paths_return_a_value_7030","Not all code paths return a value."),Binding_element_0_implicitly_has_an_1_type:n(7031,e.DiagnosticCategory.Error,"Binding_element_0_implicitly_has_an_1_type_7031","Binding element '{0}' implicitly has an '{1}' type."),Property_0_implicitly_has_type_any_because_its_set_accessor_lacks_a_parameter_type_annotation:n(7032,e.DiagnosticCategory.Error,"Property_0_implicitly_has_type_any_because_its_set_accessor_lacks_a_parameter_type_annotation_7032","Property '{0}' implicitly has type 'any', because its set accessor lacks a parameter type annotation."),Property_0_implicitly_has_type_any_because_its_get_accessor_lacks_a_return_type_annotation:n(7033,e.DiagnosticCategory.Error,"Property_0_implicitly_has_type_any_because_its_get_accessor_lacks_a_return_type_annotation_7033","Property '{0}' implicitly has type 'any', because its get accessor lacks a return type annotation."),Variable_0_implicitly_has_type_1_in_some_locations_where_its_type_cannot_be_determined:n(7034,e.DiagnosticCategory.Error,"Variable_0_implicitly_has_type_1_in_some_locations_where_its_type_cannot_be_determined_7034","Variable '{0}' implicitly has type '{1}' in some locations where its type cannot be determined."),Try_npm_i_save_dev_types_Slash_1_if_it_exists_or_add_a_new_declaration_d_ts_file_containing_declare_module_0:n(7035,e.DiagnosticCategory.Error,"Try_npm_i_save_dev_types_Slash_1_if_it_exists_or_add_a_new_declaration_d_ts_file_containing_declare__7035","Try `npm i --save-dev @types/{1}` if it exists or add a new declaration (.d.ts) file containing `declare module '{0}';`"),Dynamic_import_s_specifier_must_be_of_type_string_but_here_has_type_0:n(7036,e.DiagnosticCategory.Error,"Dynamic_import_s_specifier_must_be_of_type_string_but_here_has_type_0_7036","Dynamic import's specifier must be of type 'string', but here has type '{0}'."),Enables_emit_interoperability_between_CommonJS_and_ES_Modules_via_creation_of_namespace_objects_for_all_imports_Implies_allowSyntheticDefaultImports:n(7037,e.DiagnosticCategory.Message,"Enables_emit_interoperability_between_CommonJS_and_ES_Modules_via_creation_of_namespace_objects_for__7037","Enables emit interoperability between CommonJS and ES Modules via creation of namespace objects for all imports. Implies 'allowSyntheticDefaultImports'."),Type_originates_at_this_import_A_namespace_style_import_cannot_be_called_or_constructed_and_will_cause_a_failure_at_runtime_Consider_using_a_default_import_or_import_require_here_instead:n(7038,e.DiagnosticCategory.Message,"Type_originates_at_this_import_A_namespace_style_import_cannot_be_called_or_constructed_and_will_cau_7038","Type originates at this import. A namespace-style import cannot be called or constructed, and will cause a failure at runtime. Consider using a default import or import require here instead."),Mapped_object_type_implicitly_has_an_any_template_type:n(7039,e.DiagnosticCategory.Error,"Mapped_object_type_implicitly_has_an_any_template_type_7039","Mapped object type implicitly has an 'any' template type."),If_the_0_package_actually_exposes_this_module_consider_sending_a_pull_request_to_amend_https_Colon_Slash_Slashgithub_com_SlashDefinitelyTyped_SlashDefinitelyTyped_Slashtree_Slashmaster_Slashtypes_Slash_1:n(7040,e.DiagnosticCategory.Error,"If_the_0_package_actually_exposes_this_module_consider_sending_a_pull_request_to_amend_https_Colon_S_7040","If the '{0}' package actually exposes this module, consider sending a pull request to amend 'https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/{1}'"),The_containing_arrow_function_captures_the_global_value_of_this:n(7041,e.DiagnosticCategory.Error,"The_containing_arrow_function_captures_the_global_value_of_this_7041","The containing arrow function captures the global value of 'this'."),Module_0_was_resolved_to_1_but_resolveJsonModule_is_not_used:n(7042,e.DiagnosticCategory.Error,"Module_0_was_resolved_to_1_but_resolveJsonModule_is_not_used_7042","Module '{0}' was resolved to '{1}', but '--resolveJsonModule' is not used."),Variable_0_implicitly_has_an_1_type_but_a_better_type_may_be_inferred_from_usage:n(7043,e.DiagnosticCategory.Suggestion,"Variable_0_implicitly_has_an_1_type_but_a_better_type_may_be_inferred_from_usage_7043","Variable '{0}' implicitly has an '{1}' type, but a better type may be inferred from usage."),Parameter_0_implicitly_has_an_1_type_but_a_better_type_may_be_inferred_from_usage:n(7044,e.DiagnosticCategory.Suggestion,"Parameter_0_implicitly_has_an_1_type_but_a_better_type_may_be_inferred_from_usage_7044","Parameter '{0}' implicitly has an '{1}' type, but a better type may be inferred from usage."),Member_0_implicitly_has_an_1_type_but_a_better_type_may_be_inferred_from_usage:n(7045,e.DiagnosticCategory.Suggestion,"Member_0_implicitly_has_an_1_type_but_a_better_type_may_be_inferred_from_usage_7045","Member '{0}' implicitly has an '{1}' type, but a better type may be inferred from usage."),Variable_0_implicitly_has_type_1_in_some_locations_but_a_better_type_may_be_inferred_from_usage:n(7046,e.DiagnosticCategory.Suggestion,"Variable_0_implicitly_has_type_1_in_some_locations_but_a_better_type_may_be_inferred_from_usage_7046","Variable '{0}' implicitly has type '{1}' in some locations, but a better type may be inferred from usage."),Rest_parameter_0_implicitly_has_an_any_type_but_a_better_type_may_be_inferred_from_usage:n(7047,e.DiagnosticCategory.Suggestion,"Rest_parameter_0_implicitly_has_an_any_type_but_a_better_type_may_be_inferred_from_usage_7047","Rest parameter '{0}' implicitly has an 'any[]' type, but a better type may be inferred from usage."),Property_0_implicitly_has_type_any_but_a_better_type_for_its_get_accessor_may_be_inferred_from_usage:n(7048,e.DiagnosticCategory.Suggestion,"Property_0_implicitly_has_type_any_but_a_better_type_for_its_get_accessor_may_be_inferred_from_usage_7048","Property '{0}' implicitly has type 'any', but a better type for its get accessor may be inferred from usage."),Property_0_implicitly_has_type_any_but_a_better_type_for_its_set_accessor_may_be_inferred_from_usage:n(7049,e.DiagnosticCategory.Suggestion,"Property_0_implicitly_has_type_any_but_a_better_type_for_its_set_accessor_may_be_inferred_from_usage_7049","Property '{0}' implicitly has type 'any', but a better type for its set accessor may be inferred from usage."),_0_implicitly_has_an_1_return_type_but_a_better_type_may_be_inferred_from_usage:n(7050,e.DiagnosticCategory.Suggestion,"_0_implicitly_has_an_1_return_type_but_a_better_type_may_be_inferred_from_usage_7050","'{0}' implicitly has an '{1}' return type, but a better type may be inferred from usage."),Parameter_has_a_name_but_no_type_Did_you_mean_0_Colon_1:n(7051,e.DiagnosticCategory.Error,"Parameter_has_a_name_but_no_type_Did_you_mean_0_Colon_1_7051","Parameter has a name but no type. Did you mean '{0}: {1}'?"),Element_implicitly_has_an_any_type_because_type_0_has_no_index_signature_Did_you_mean_to_call_1:n(7052,e.DiagnosticCategory.Error,"Element_implicitly_has_an_any_type_because_type_0_has_no_index_signature_Did_you_mean_to_call_1_7052","Element implicitly has an 'any' type because type '{0}' has no index signature. Did you mean to call '{1}'?"),Element_implicitly_has_an_any_type_because_expression_of_type_0_can_t_be_used_to_index_type_1:n(7053,e.DiagnosticCategory.Error,"Element_implicitly_has_an_any_type_because_expression_of_type_0_can_t_be_used_to_index_type_1_7053","Element implicitly has an 'any' type because expression of type '{0}' can't be used to index type '{1}'."),No_index_signature_with_a_parameter_of_type_0_was_found_on_type_1:n(7054,e.DiagnosticCategory.Error,"No_index_signature_with_a_parameter_of_type_0_was_found_on_type_1_7054","No index signature with a parameter of type '{0}' was found on type '{1}'."),_0_which_lacks_return_type_annotation_implicitly_has_an_1_yield_type:n(7055,e.DiagnosticCategory.Error,"_0_which_lacks_return_type_annotation_implicitly_has_an_1_yield_type_7055","'{0}', which lacks return-type annotation, implicitly has an '{1}' yield type."),The_inferred_type_of_this_node_exceeds_the_maximum_length_the_compiler_will_serialize_An_explicit_type_annotation_is_needed:n(7056,e.DiagnosticCategory.Error,"The_inferred_type_of_this_node_exceeds_the_maximum_length_the_compiler_will_serialize_An_explicit_ty_7056","The inferred type of this node exceeds the maximum length the compiler will serialize. An explicit type annotation is needed."),yield_expression_implicitly_results_in_an_any_type_because_its_containing_generator_lacks_a_return_type_annotation:n(7057,e.DiagnosticCategory.Error,"yield_expression_implicitly_results_in_an_any_type_because_its_containing_generator_lacks_a_return_t_7057","'yield' expression implicitly results in an 'any' type because its containing generator lacks a return-type annotation."),You_cannot_rename_this_element:n(8e3,e.DiagnosticCategory.Error,"You_cannot_rename_this_element_8000","You cannot rename this element."),You_cannot_rename_elements_that_are_defined_in_the_standard_TypeScript_library:n(8001,e.DiagnosticCategory.Error,"You_cannot_rename_elements_that_are_defined_in_the_standard_TypeScript_library_8001","You cannot rename elements that are defined in the standard TypeScript library."),import_can_only_be_used_in_TypeScript_files:n(8002,e.DiagnosticCategory.Error,"import_can_only_be_used_in_TypeScript_files_8002","'import ... =' can only be used in TypeScript files."),export_can_only_be_used_in_TypeScript_files:n(8003,e.DiagnosticCategory.Error,"export_can_only_be_used_in_TypeScript_files_8003","'export =' can only be used in TypeScript files."),Type_parameter_declarations_can_only_be_used_in_TypeScript_files:n(8004,e.DiagnosticCategory.Error,"Type_parameter_declarations_can_only_be_used_in_TypeScript_files_8004","Type parameter declarations can only be used in TypeScript files."),implements_clauses_can_only_be_used_in_TypeScript_files:n(8005,e.DiagnosticCategory.Error,"implements_clauses_can_only_be_used_in_TypeScript_files_8005","'implements' clauses can only be used in TypeScript files."),_0_declarations_can_only_be_used_in_TypeScript_files:n(8006,e.DiagnosticCategory.Error,"_0_declarations_can_only_be_used_in_TypeScript_files_8006","'{0}' declarations can only be used in TypeScript files."),Type_aliases_can_only_be_used_in_TypeScript_files:n(8008,e.DiagnosticCategory.Error,"Type_aliases_can_only_be_used_in_TypeScript_files_8008","Type aliases can only be used in TypeScript files."),The_0_modifier_can_only_be_used_in_TypeScript_files:n(8009,e.DiagnosticCategory.Error,"The_0_modifier_can_only_be_used_in_TypeScript_files_8009","The '{0}' modifier can only be used in TypeScript files."),Type_annotations_can_only_be_used_in_TypeScript_files:n(8010,e.DiagnosticCategory.Error,"Type_annotations_can_only_be_used_in_TypeScript_files_8010","Type annotations can only be used in TypeScript files."),Type_arguments_can_only_be_used_in_TypeScript_files:n(8011,e.DiagnosticCategory.Error,"Type_arguments_can_only_be_used_in_TypeScript_files_8011","Type arguments can only be used in TypeScript files."),Parameter_modifiers_can_only_be_used_in_TypeScript_files:n(8012,e.DiagnosticCategory.Error,"Parameter_modifiers_can_only_be_used_in_TypeScript_files_8012","Parameter modifiers can only be used in TypeScript files."),Non_null_assertions_can_only_be_used_in_TypeScript_files:n(8013,e.DiagnosticCategory.Error,"Non_null_assertions_can_only_be_used_in_TypeScript_files_8013","Non-null assertions can only be used in TypeScript files."),Type_assertion_expressions_can_only_be_used_in_TypeScript_files:n(8016,e.DiagnosticCategory.Error,"Type_assertion_expressions_can_only_be_used_in_TypeScript_files_8016","Type assertion expressions can only be used in TypeScript files."),Octal_literal_types_must_use_ES2015_syntax_Use_the_syntax_0:n(8017,e.DiagnosticCategory.Error,"Octal_literal_types_must_use_ES2015_syntax_Use_the_syntax_0_8017","Octal literal types must use ES2015 syntax. Use the syntax '{0}'."),Octal_literals_are_not_allowed_in_enums_members_initializer_Use_the_syntax_0:n(8018,e.DiagnosticCategory.Error,"Octal_literals_are_not_allowed_in_enums_members_initializer_Use_the_syntax_0_8018","Octal literals are not allowed in enums members initializer. Use the syntax '{0}'."),Report_errors_in_js_files:n(8019,e.DiagnosticCategory.Message,"Report_errors_in_js_files_8019","Report errors in .js files."),JSDoc_types_can_only_be_used_inside_documentation_comments:n(8020,e.DiagnosticCategory.Error,"JSDoc_types_can_only_be_used_inside_documentation_comments_8020","JSDoc types can only be used inside documentation comments."),JSDoc_typedef_tag_should_either_have_a_type_annotation_or_be_followed_by_property_or_member_tags:n(8021,e.DiagnosticCategory.Error,"JSDoc_typedef_tag_should_either_have_a_type_annotation_or_be_followed_by_property_or_member_tags_8021","JSDoc '@typedef' tag should either have a type annotation or be followed by '@property' or '@member' tags."),JSDoc_0_is_not_attached_to_a_class:n(8022,e.DiagnosticCategory.Error,"JSDoc_0_is_not_attached_to_a_class_8022","JSDoc '@{0}' is not attached to a class."),JSDoc_0_1_does_not_match_the_extends_2_clause:n(8023,e.DiagnosticCategory.Error,"JSDoc_0_1_does_not_match_the_extends_2_clause_8023","JSDoc '@{0} {1}' does not match the 'extends {2}' clause."),JSDoc_param_tag_has_name_0_but_there_is_no_parameter_with_that_name:n(8024,e.DiagnosticCategory.Error,"JSDoc_param_tag_has_name_0_but_there_is_no_parameter_with_that_name_8024","JSDoc '@param' tag has name '{0}', but there is no parameter with that name."),Class_declarations_cannot_have_more_than_one_augments_or_extends_tag:n(8025,e.DiagnosticCategory.Error,"Class_declarations_cannot_have_more_than_one_augments_or_extends_tag_8025","Class declarations cannot have more than one '@augments' or '@extends' tag."),Expected_0_type_arguments_provide_these_with_an_extends_tag:n(8026,e.DiagnosticCategory.Error,"Expected_0_type_arguments_provide_these_with_an_extends_tag_8026","Expected {0} type arguments; provide these with an '@extends' tag."),Expected_0_1_type_arguments_provide_these_with_an_extends_tag:n(8027,e.DiagnosticCategory.Error,"Expected_0_1_type_arguments_provide_these_with_an_extends_tag_8027","Expected {0}-{1} type arguments; provide these with an '@extends' tag."),JSDoc_may_only_appear_in_the_last_parameter_of_a_signature:n(8028,e.DiagnosticCategory.Error,"JSDoc_may_only_appear_in_the_last_parameter_of_a_signature_8028","JSDoc '...' may only appear in the last parameter of a signature."),JSDoc_param_tag_has_name_0_but_there_is_no_parameter_with_that_name_It_would_match_arguments_if_it_had_an_array_type:n(8029,e.DiagnosticCategory.Error,"JSDoc_param_tag_has_name_0_but_there_is_no_parameter_with_that_name_It_would_match_arguments_if_it_h_8029","JSDoc '@param' tag has name '{0}', but there is no parameter with that name. It would match 'arguments' if it had an array type."),The_type_of_a_function_declaration_must_match_the_function_s_signature:n(8030,e.DiagnosticCategory.Error,"The_type_of_a_function_declaration_must_match_the_function_s_signature_8030","The type of a function declaration must match the function's signature."),You_cannot_rename_a_module_via_a_global_import:n(8031,e.DiagnosticCategory.Error,"You_cannot_rename_a_module_via_a_global_import_8031","You cannot rename a module via a global import."),Qualified_name_0_is_not_allowed_without_a_leading_param_object_1:n(8032,e.DiagnosticCategory.Error,"Qualified_name_0_is_not_allowed_without_a_leading_param_object_1_8032","Qualified name '{0}' is not allowed without a leading '@param {object} {1}'."),A_JSDoc_typedef_comment_may_not_contain_multiple_type_tags:n(8033,e.DiagnosticCategory.Error,"A_JSDoc_typedef_comment_may_not_contain_multiple_type_tags_8033","A JSDoc '@typedef' comment may not contain multiple '@type' tags."),The_tag_was_first_specified_here:n(8034,e.DiagnosticCategory.Error,"The_tag_was_first_specified_here_8034","The tag was first specified here."),Only_identifiers_Slashqualified_names_with_optional_type_arguments_are_currently_supported_in_a_class_extends_clause:n(9002,e.DiagnosticCategory.Error,"Only_identifiers_Slashqualified_names_with_optional_type_arguments_are_currently_supported_in_a_clas_9002","Only identifiers/qualified-names with optional type arguments are currently supported in a class 'extends' clause."),class_expressions_are_not_currently_supported:n(9003,e.DiagnosticCategory.Error,"class_expressions_are_not_currently_supported_9003","'class' expressions are not currently supported."),Language_service_is_disabled:n(9004,e.DiagnosticCategory.Error,"Language_service_is_disabled_9004","Language service is disabled."),Declaration_emit_for_this_file_requires_using_private_name_0_An_explicit_type_annotation_may_unblock_declaration_emit:n(9005,e.DiagnosticCategory.Error,"Declaration_emit_for_this_file_requires_using_private_name_0_An_explicit_type_annotation_may_unblock_9005","Declaration emit for this file requires using private name '{0}'. An explicit type annotation may unblock declaration emit."),Declaration_emit_for_this_file_requires_using_private_name_0_from_module_1_An_explicit_type_annotation_may_unblock_declaration_emit:n(9006,e.DiagnosticCategory.Error,"Declaration_emit_for_this_file_requires_using_private_name_0_from_module_1_An_explicit_type_annotati_9006","Declaration emit for this file requires using private name '{0}' from module '{1}'. An explicit type annotation may unblock declaration emit."),JSX_attributes_must_only_be_assigned_a_non_empty_expression:n(17e3,e.DiagnosticCategory.Error,"JSX_attributes_must_only_be_assigned_a_non_empty_expression_17000","JSX attributes must only be assigned a non-empty 'expression'."),JSX_elements_cannot_have_multiple_attributes_with_the_same_name:n(17001,e.DiagnosticCategory.Error,"JSX_elements_cannot_have_multiple_attributes_with_the_same_name_17001","JSX elements cannot have multiple attributes with the same name."),Expected_corresponding_JSX_closing_tag_for_0:n(17002,e.DiagnosticCategory.Error,"Expected_corresponding_JSX_closing_tag_for_0_17002","Expected corresponding JSX closing tag for '{0}'."),JSX_attribute_expected:n(17003,e.DiagnosticCategory.Error,"JSX_attribute_expected_17003","JSX attribute expected."),Cannot_use_JSX_unless_the_jsx_flag_is_provided:n(17004,e.DiagnosticCategory.Error,"Cannot_use_JSX_unless_the_jsx_flag_is_provided_17004","Cannot use JSX unless the '--jsx' flag is provided."),A_constructor_cannot_contain_a_super_call_when_its_class_extends_null:n(17005,e.DiagnosticCategory.Error,"A_constructor_cannot_contain_a_super_call_when_its_class_extends_null_17005","A constructor cannot contain a 'super' call when its class extends 'null'."),An_unary_expression_with_the_0_operator_is_not_allowed_in_the_left_hand_side_of_an_exponentiation_expression_Consider_enclosing_the_expression_in_parentheses:n(17006,e.DiagnosticCategory.Error,"An_unary_expression_with_the_0_operator_is_not_allowed_in_the_left_hand_side_of_an_exponentiation_ex_17006","An unary expression with the '{0}' operator is not allowed in the left-hand side of an exponentiation expression. Consider enclosing the expression in parentheses."),A_type_assertion_expression_is_not_allowed_in_the_left_hand_side_of_an_exponentiation_expression_Consider_enclosing_the_expression_in_parentheses:n(17007,e.DiagnosticCategory.Error,"A_type_assertion_expression_is_not_allowed_in_the_left_hand_side_of_an_exponentiation_expression_Con_17007","A type assertion expression is not allowed in the left-hand side of an exponentiation expression. Consider enclosing the expression in parentheses."),JSX_element_0_has_no_corresponding_closing_tag:n(17008,e.DiagnosticCategory.Error,"JSX_element_0_has_no_corresponding_closing_tag_17008","JSX element '{0}' has no corresponding closing tag."),super_must_be_called_before_accessing_this_in_the_constructor_of_a_derived_class:n(17009,e.DiagnosticCategory.Error,"super_must_be_called_before_accessing_this_in_the_constructor_of_a_derived_class_17009","'super' must be called before accessing 'this' in the constructor of a derived class."),Unknown_type_acquisition_option_0:n(17010,e.DiagnosticCategory.Error,"Unknown_type_acquisition_option_0_17010","Unknown type acquisition option '{0}'."),super_must_be_called_before_accessing_a_property_of_super_in_the_constructor_of_a_derived_class:n(17011,e.DiagnosticCategory.Error,"super_must_be_called_before_accessing_a_property_of_super_in_the_constructor_of_a_derived_class_17011","'super' must be called before accessing a property of 'super' in the constructor of a derived class."),_0_is_not_a_valid_meta_property_for_keyword_1_Did_you_mean_2:n(17012,e.DiagnosticCategory.Error,"_0_is_not_a_valid_meta_property_for_keyword_1_Did_you_mean_2_17012","'{0}' is not a valid meta-property for keyword '{1}'. Did you mean '{2}'?"),Meta_property_0_is_only_allowed_in_the_body_of_a_function_declaration_function_expression_or_constructor:n(17013,e.DiagnosticCategory.Error,"Meta_property_0_is_only_allowed_in_the_body_of_a_function_declaration_function_expression_or_constru_17013","Meta-property '{0}' is only allowed in the body of a function declaration, function expression, or constructor."),JSX_fragment_has_no_corresponding_closing_tag:n(17014,e.DiagnosticCategory.Error,"JSX_fragment_has_no_corresponding_closing_tag_17014","JSX fragment has no corresponding closing tag."),Expected_corresponding_closing_tag_for_JSX_fragment:n(17015,e.DiagnosticCategory.Error,"Expected_corresponding_closing_tag_for_JSX_fragment_17015","Expected corresponding closing tag for JSX fragment."),The_jsxFragmentFactory_compiler_option_must_be_provided_to_use_JSX_fragments_with_the_jsxFactory_compiler_option:n(17016,e.DiagnosticCategory.Error,"The_jsxFragmentFactory_compiler_option_must_be_provided_to_use_JSX_fragments_with_the_jsxFactory_com_17016","The 'jsxFragmentFactory' compiler option must be provided to use JSX fragments with the 'jsxFactory' compiler option."),An_jsxFrag_pragma_is_required_when_using_an_jsx_pragma_with_JSX_fragments:n(17017,e.DiagnosticCategory.Error,"An_jsxFrag_pragma_is_required_when_using_an_jsx_pragma_with_JSX_fragments_17017","An @jsxFrag pragma is required when using an @jsx pragma with JSX fragments."),Unknown_type_acquisition_option_0_Did_you_mean_1:n(17018,e.DiagnosticCategory.Error,"Unknown_type_acquisition_option_0_Did_you_mean_1_17018","Unknown type acquisition option '{0}'. Did you mean '{1}'?"),Circularity_detected_while_resolving_configuration_Colon_0:n(18e3,e.DiagnosticCategory.Error,"Circularity_detected_while_resolving_configuration_Colon_0_18000","Circularity detected while resolving configuration: {0}"),A_path_in_an_extends_option_must_be_relative_or_rooted_but_0_is_not:n(18001,e.DiagnosticCategory.Error,"A_path_in_an_extends_option_must_be_relative_or_rooted_but_0_is_not_18001","A path in an 'extends' option must be relative or rooted, but '{0}' is not."),The_files_list_in_config_file_0_is_empty:n(18002,e.DiagnosticCategory.Error,"The_files_list_in_config_file_0_is_empty_18002","The 'files' list in config file '{0}' is empty."),No_inputs_were_found_in_config_file_0_Specified_include_paths_were_1_and_exclude_paths_were_2:n(18003,e.DiagnosticCategory.Error,"No_inputs_were_found_in_config_file_0_Specified_include_paths_were_1_and_exclude_paths_were_2_18003","No inputs were found in config file '{0}'. Specified 'include' paths were '{1}' and 'exclude' paths were '{2}'."),File_is_a_CommonJS_module_it_may_be_converted_to_an_ES6_module:n(80001,e.DiagnosticCategory.Suggestion,"File_is_a_CommonJS_module_it_may_be_converted_to_an_ES6_module_80001","File is a CommonJS module; it may be converted to an ES6 module."),This_constructor_function_may_be_converted_to_a_class_declaration:n(80002,e.DiagnosticCategory.Suggestion,"This_constructor_function_may_be_converted_to_a_class_declaration_80002","This constructor function may be converted to a class declaration."),Import_may_be_converted_to_a_default_import:n(80003,e.DiagnosticCategory.Suggestion,"Import_may_be_converted_to_a_default_import_80003","Import may be converted to a default import."),JSDoc_types_may_be_moved_to_TypeScript_types:n(80004,e.DiagnosticCategory.Suggestion,"JSDoc_types_may_be_moved_to_TypeScript_types_80004","JSDoc types may be moved to TypeScript types."),require_call_may_be_converted_to_an_import:n(80005,e.DiagnosticCategory.Suggestion,"require_call_may_be_converted_to_an_import_80005","'require' call may be converted to an import."),This_may_be_converted_to_an_async_function:n(80006,e.DiagnosticCategory.Suggestion,"This_may_be_converted_to_an_async_function_80006","This may be converted to an async function."),await_has_no_effect_on_the_type_of_this_expression:n(80007,e.DiagnosticCategory.Suggestion,"await_has_no_effect_on_the_type_of_this_expression_80007","'await' has no effect on the type of this expression."),Numeric_literals_with_absolute_values_equal_to_2_53_or_greater_are_too_large_to_be_represented_accurately_as_integers:n(80008,e.DiagnosticCategory.Suggestion,"Numeric_literals_with_absolute_values_equal_to_2_53_or_greater_are_too_large_to_be_represented_accur_80008","Numeric literals with absolute values equal to 2^53 or greater are too large to be represented accurately as integers."),Add_missing_super_call:n(90001,e.DiagnosticCategory.Message,"Add_missing_super_call_90001","Add missing 'super()' call"),Make_super_call_the_first_statement_in_the_constructor:n(90002,e.DiagnosticCategory.Message,"Make_super_call_the_first_statement_in_the_constructor_90002","Make 'super()' call the first statement in the constructor"),Change_extends_to_implements:n(90003,e.DiagnosticCategory.Message,"Change_extends_to_implements_90003","Change 'extends' to 'implements'"),Remove_unused_declaration_for_Colon_0:n(90004,e.DiagnosticCategory.Message,"Remove_unused_declaration_for_Colon_0_90004","Remove unused declaration for: '{0}'"),Remove_import_from_0:n(90005,e.DiagnosticCategory.Message,"Remove_import_from_0_90005","Remove import from '{0}'"),Implement_interface_0:n(90006,e.DiagnosticCategory.Message,"Implement_interface_0_90006","Implement interface '{0}'"),Implement_inherited_abstract_class:n(90007,e.DiagnosticCategory.Message,"Implement_inherited_abstract_class_90007","Implement inherited abstract class"),Add_0_to_unresolved_variable:n(90008,e.DiagnosticCategory.Message,"Add_0_to_unresolved_variable_90008","Add '{0}.' to unresolved variable"),Remove_variable_statement:n(90010,e.DiagnosticCategory.Message,"Remove_variable_statement_90010","Remove variable statement"),Remove_template_tag:n(90011,e.DiagnosticCategory.Message,"Remove_template_tag_90011","Remove template tag"),Remove_type_parameters:n(90012,e.DiagnosticCategory.Message,"Remove_type_parameters_90012","Remove type parameters"),Import_0_from_module_1:n(90013,e.DiagnosticCategory.Message,"Import_0_from_module_1_90013","Import '{0}' from module \"{1}\""),Change_0_to_1:n(90014,e.DiagnosticCategory.Message,"Change_0_to_1_90014","Change '{0}' to '{1}'"),Add_0_to_existing_import_declaration_from_1:n(90015,e.DiagnosticCategory.Message,"Add_0_to_existing_import_declaration_from_1_90015","Add '{0}' to existing import declaration from \"{1}\""),Declare_property_0:n(90016,e.DiagnosticCategory.Message,"Declare_property_0_90016","Declare property '{0}'"),Add_index_signature_for_property_0:n(90017,e.DiagnosticCategory.Message,"Add_index_signature_for_property_0_90017","Add index signature for property '{0}'"),Disable_checking_for_this_file:n(90018,e.DiagnosticCategory.Message,"Disable_checking_for_this_file_90018","Disable checking for this file"),Ignore_this_error_message:n(90019,e.DiagnosticCategory.Message,"Ignore_this_error_message_90019","Ignore this error message"),Initialize_property_0_in_the_constructor:n(90020,e.DiagnosticCategory.Message,"Initialize_property_0_in_the_constructor_90020","Initialize property '{0}' in the constructor"),Initialize_static_property_0:n(90021,e.DiagnosticCategory.Message,"Initialize_static_property_0_90021","Initialize static property '{0}'"),Change_spelling_to_0:n(90022,e.DiagnosticCategory.Message,"Change_spelling_to_0_90022","Change spelling to '{0}'"),Declare_method_0:n(90023,e.DiagnosticCategory.Message,"Declare_method_0_90023","Declare method '{0}'"),Declare_static_method_0:n(90024,e.DiagnosticCategory.Message,"Declare_static_method_0_90024","Declare static method '{0}'"),Prefix_0_with_an_underscore:n(90025,e.DiagnosticCategory.Message,"Prefix_0_with_an_underscore_90025","Prefix '{0}' with an underscore"),Rewrite_as_the_indexed_access_type_0:n(90026,e.DiagnosticCategory.Message,"Rewrite_as_the_indexed_access_type_0_90026","Rewrite as the indexed access type '{0}'"),Declare_static_property_0:n(90027,e.DiagnosticCategory.Message,"Declare_static_property_0_90027","Declare static property '{0}'"),Call_decorator_expression:n(90028,e.DiagnosticCategory.Message,"Call_decorator_expression_90028","Call decorator expression"),Add_async_modifier_to_containing_function:n(90029,e.DiagnosticCategory.Message,"Add_async_modifier_to_containing_function_90029","Add async modifier to containing function"),Replace_infer_0_with_unknown:n(90030,e.DiagnosticCategory.Message,"Replace_infer_0_with_unknown_90030","Replace 'infer {0}' with 'unknown'"),Replace_all_unused_infer_with_unknown:n(90031,e.DiagnosticCategory.Message,"Replace_all_unused_infer_with_unknown_90031","Replace all unused 'infer' with 'unknown'"),Import_default_0_from_module_1:n(90032,e.DiagnosticCategory.Message,"Import_default_0_from_module_1_90032","Import default '{0}' from module \"{1}\""),Add_default_import_0_to_existing_import_declaration_from_1:n(90033,e.DiagnosticCategory.Message,"Add_default_import_0_to_existing_import_declaration_from_1_90033","Add default import '{0}' to existing import declaration from \"{1}\""),Add_parameter_name:n(90034,e.DiagnosticCategory.Message,"Add_parameter_name_90034","Add parameter name"),Declare_private_property_0:n(90035,e.DiagnosticCategory.Message,"Declare_private_property_0_90035","Declare private property '{0}'"),Replace_0_with_Promise_1:n(90036,e.DiagnosticCategory.Message,"Replace_0_with_Promise_1_90036","Replace '{0}' with 'Promise<{1}>'"),Fix_all_incorrect_return_type_of_an_async_functions:n(90037,e.DiagnosticCategory.Message,"Fix_all_incorrect_return_type_of_an_async_functions_90037","Fix all incorrect return type of an async functions"),Declare_private_method_0:n(90038,e.DiagnosticCategory.Message,"Declare_private_method_0_90038","Declare private method '{0}'"),Remove_unused_destructuring_declaration:n(90039,e.DiagnosticCategory.Message,"Remove_unused_destructuring_declaration_90039","Remove unused destructuring declaration"),Remove_unused_declarations_for_Colon_0:n(90041,e.DiagnosticCategory.Message,"Remove_unused_declarations_for_Colon_0_90041","Remove unused declarations for: '{0}'"),Declare_a_private_field_named_0:n(90053,e.DiagnosticCategory.Message,"Declare_a_private_field_named_0_90053","Declare a private field named '{0}'."),Convert_function_to_an_ES2015_class:n(95001,e.DiagnosticCategory.Message,"Convert_function_to_an_ES2015_class_95001","Convert function to an ES2015 class"),Convert_function_0_to_class:n(95002,e.DiagnosticCategory.Message,"Convert_function_0_to_class_95002","Convert function '{0}' to class"),Convert_0_to_1_in_0:n(95003,e.DiagnosticCategory.Message,"Convert_0_to_1_in_0_95003","Convert '{0}' to '{1} in {0}'"),Extract_to_0_in_1:n(95004,e.DiagnosticCategory.Message,"Extract_to_0_in_1_95004","Extract to {0} in {1}"),Extract_function:n(95005,e.DiagnosticCategory.Message,"Extract_function_95005","Extract function"),Extract_constant:n(95006,e.DiagnosticCategory.Message,"Extract_constant_95006","Extract constant"),Extract_to_0_in_enclosing_scope:n(95007,e.DiagnosticCategory.Message,"Extract_to_0_in_enclosing_scope_95007","Extract to {0} in enclosing scope"),Extract_to_0_in_1_scope:n(95008,e.DiagnosticCategory.Message,"Extract_to_0_in_1_scope_95008","Extract to {0} in {1} scope"),Annotate_with_type_from_JSDoc:n(95009,e.DiagnosticCategory.Message,"Annotate_with_type_from_JSDoc_95009","Annotate with type from JSDoc"),Annotate_with_types_from_JSDoc:n(95010,e.DiagnosticCategory.Message,"Annotate_with_types_from_JSDoc_95010","Annotate with types from JSDoc"),Infer_type_of_0_from_usage:n(95011,e.DiagnosticCategory.Message,"Infer_type_of_0_from_usage_95011","Infer type of '{0}' from usage"),Infer_parameter_types_from_usage:n(95012,e.DiagnosticCategory.Message,"Infer_parameter_types_from_usage_95012","Infer parameter types from usage"),Convert_to_default_import:n(95013,e.DiagnosticCategory.Message,"Convert_to_default_import_95013","Convert to default import"),Install_0:n(95014,e.DiagnosticCategory.Message,"Install_0_95014","Install '{0}'"),Replace_import_with_0:n(95015,e.DiagnosticCategory.Message,"Replace_import_with_0_95015","Replace import with '{0}'."),Use_synthetic_default_member:n(95016,e.DiagnosticCategory.Message,"Use_synthetic_default_member_95016","Use synthetic 'default' member."),Convert_to_ES6_module:n(95017,e.DiagnosticCategory.Message,"Convert_to_ES6_module_95017","Convert to ES6 module"),Add_undefined_type_to_property_0:n(95018,e.DiagnosticCategory.Message,"Add_undefined_type_to_property_0_95018","Add 'undefined' type to property '{0}'"),Add_initializer_to_property_0:n(95019,e.DiagnosticCategory.Message,"Add_initializer_to_property_0_95019","Add initializer to property '{0}'"),Add_definite_assignment_assertion_to_property_0:n(95020,e.DiagnosticCategory.Message,"Add_definite_assignment_assertion_to_property_0_95020","Add definite assignment assertion to property '{0}'"),Convert_all_type_literals_to_mapped_type:n(95021,e.DiagnosticCategory.Message,"Convert_all_type_literals_to_mapped_type_95021","Convert all type literals to mapped type"),Add_all_missing_members:n(95022,e.DiagnosticCategory.Message,"Add_all_missing_members_95022","Add all missing members"),Infer_all_types_from_usage:n(95023,e.DiagnosticCategory.Message,"Infer_all_types_from_usage_95023","Infer all types from usage"),Delete_all_unused_declarations:n(95024,e.DiagnosticCategory.Message,"Delete_all_unused_declarations_95024","Delete all unused declarations"),Prefix_all_unused_declarations_with_where_possible:n(95025,e.DiagnosticCategory.Message,"Prefix_all_unused_declarations_with_where_possible_95025","Prefix all unused declarations with '_' where possible"),Fix_all_detected_spelling_errors:n(95026,e.DiagnosticCategory.Message,"Fix_all_detected_spelling_errors_95026","Fix all detected spelling errors"),Add_initializers_to_all_uninitialized_properties:n(95027,e.DiagnosticCategory.Message,"Add_initializers_to_all_uninitialized_properties_95027","Add initializers to all uninitialized properties"),Add_definite_assignment_assertions_to_all_uninitialized_properties:n(95028,e.DiagnosticCategory.Message,"Add_definite_assignment_assertions_to_all_uninitialized_properties_95028","Add definite assignment assertions to all uninitialized properties"),Add_undefined_type_to_all_uninitialized_properties:n(95029,e.DiagnosticCategory.Message,"Add_undefined_type_to_all_uninitialized_properties_95029","Add undefined type to all uninitialized properties"),Change_all_jsdoc_style_types_to_TypeScript:n(95030,e.DiagnosticCategory.Message,"Change_all_jsdoc_style_types_to_TypeScript_95030","Change all jsdoc-style types to TypeScript"),Change_all_jsdoc_style_types_to_TypeScript_and_add_undefined_to_nullable_types:n(95031,e.DiagnosticCategory.Message,"Change_all_jsdoc_style_types_to_TypeScript_and_add_undefined_to_nullable_types_95031","Change all jsdoc-style types to TypeScript (and add '| undefined' to nullable types)"),Implement_all_unimplemented_interfaces:n(95032,e.DiagnosticCategory.Message,"Implement_all_unimplemented_interfaces_95032","Implement all unimplemented interfaces"),Install_all_missing_types_packages:n(95033,e.DiagnosticCategory.Message,"Install_all_missing_types_packages_95033","Install all missing types packages"),Rewrite_all_as_indexed_access_types:n(95034,e.DiagnosticCategory.Message,"Rewrite_all_as_indexed_access_types_95034","Rewrite all as indexed access types"),Convert_all_to_default_imports:n(95035,e.DiagnosticCategory.Message,"Convert_all_to_default_imports_95035","Convert all to default imports"),Make_all_super_calls_the_first_statement_in_their_constructor:n(95036,e.DiagnosticCategory.Message,"Make_all_super_calls_the_first_statement_in_their_constructor_95036","Make all 'super()' calls the first statement in their constructor"),Add_qualifier_to_all_unresolved_variables_matching_a_member_name:n(95037,e.DiagnosticCategory.Message,"Add_qualifier_to_all_unresolved_variables_matching_a_member_name_95037","Add qualifier to all unresolved variables matching a member name"),Change_all_extended_interfaces_to_implements:n(95038,e.DiagnosticCategory.Message,"Change_all_extended_interfaces_to_implements_95038","Change all extended interfaces to 'implements'"),Add_all_missing_super_calls:n(95039,e.DiagnosticCategory.Message,"Add_all_missing_super_calls_95039","Add all missing super calls"),Implement_all_inherited_abstract_classes:n(95040,e.DiagnosticCategory.Message,"Implement_all_inherited_abstract_classes_95040","Implement all inherited abstract classes"),Add_all_missing_async_modifiers:n(95041,e.DiagnosticCategory.Message,"Add_all_missing_async_modifiers_95041","Add all missing 'async' modifiers"),Add_ts_ignore_to_all_error_messages:n(95042,e.DiagnosticCategory.Message,"Add_ts_ignore_to_all_error_messages_95042","Add '@ts-ignore' to all error messages"),Annotate_everything_with_types_from_JSDoc:n(95043,e.DiagnosticCategory.Message,"Annotate_everything_with_types_from_JSDoc_95043","Annotate everything with types from JSDoc"),Add_to_all_uncalled_decorators:n(95044,e.DiagnosticCategory.Message,"Add_to_all_uncalled_decorators_95044","Add '()' to all uncalled decorators"),Convert_all_constructor_functions_to_classes:n(95045,e.DiagnosticCategory.Message,"Convert_all_constructor_functions_to_classes_95045","Convert all constructor functions to classes"),Generate_get_and_set_accessors:n(95046,e.DiagnosticCategory.Message,"Generate_get_and_set_accessors_95046","Generate 'get' and 'set' accessors"),Convert_require_to_import:n(95047,e.DiagnosticCategory.Message,"Convert_require_to_import_95047","Convert 'require' to 'import'"),Convert_all_require_to_import:n(95048,e.DiagnosticCategory.Message,"Convert_all_require_to_import_95048","Convert all 'require' to 'import'"),Move_to_a_new_file:n(95049,e.DiagnosticCategory.Message,"Move_to_a_new_file_95049","Move to a new file"),Remove_unreachable_code:n(95050,e.DiagnosticCategory.Message,"Remove_unreachable_code_95050","Remove unreachable code"),Remove_all_unreachable_code:n(95051,e.DiagnosticCategory.Message,"Remove_all_unreachable_code_95051","Remove all unreachable code"),Add_missing_typeof:n(95052,e.DiagnosticCategory.Message,"Add_missing_typeof_95052","Add missing 'typeof'"),Remove_unused_label:n(95053,e.DiagnosticCategory.Message,"Remove_unused_label_95053","Remove unused label"),Remove_all_unused_labels:n(95054,e.DiagnosticCategory.Message,"Remove_all_unused_labels_95054","Remove all unused labels"),Convert_0_to_mapped_object_type:n(95055,e.DiagnosticCategory.Message,"Convert_0_to_mapped_object_type_95055","Convert '{0}' to mapped object type"),Convert_namespace_import_to_named_imports:n(95056,e.DiagnosticCategory.Message,"Convert_namespace_import_to_named_imports_95056","Convert namespace import to named imports"),Convert_named_imports_to_namespace_import:n(95057,e.DiagnosticCategory.Message,"Convert_named_imports_to_namespace_import_95057","Convert named imports to namespace import"),Add_or_remove_braces_in_an_arrow_function:n(95058,e.DiagnosticCategory.Message,"Add_or_remove_braces_in_an_arrow_function_95058","Add or remove braces in an arrow function"),Add_braces_to_arrow_function:n(95059,e.DiagnosticCategory.Message,"Add_braces_to_arrow_function_95059","Add braces to arrow function"),Remove_braces_from_arrow_function:n(95060,e.DiagnosticCategory.Message,"Remove_braces_from_arrow_function_95060","Remove braces from arrow function"),Convert_default_export_to_named_export:n(95061,e.DiagnosticCategory.Message,"Convert_default_export_to_named_export_95061","Convert default export to named export"),Convert_named_export_to_default_export:n(95062,e.DiagnosticCategory.Message,"Convert_named_export_to_default_export_95062","Convert named export to default export"),Add_missing_enum_member_0:n(95063,e.DiagnosticCategory.Message,"Add_missing_enum_member_0_95063","Add missing enum member '{0}'"),Add_all_missing_imports:n(95064,e.DiagnosticCategory.Message,"Add_all_missing_imports_95064","Add all missing imports"),Convert_to_async_function:n(95065,e.DiagnosticCategory.Message,"Convert_to_async_function_95065","Convert to async function"),Convert_all_to_async_functions:n(95066,e.DiagnosticCategory.Message,"Convert_all_to_async_functions_95066","Convert all to async functions"),Add_missing_call_parentheses:n(95067,e.DiagnosticCategory.Message,"Add_missing_call_parentheses_95067","Add missing call parentheses"),Add_all_missing_call_parentheses:n(95068,e.DiagnosticCategory.Message,"Add_all_missing_call_parentheses_95068","Add all missing call parentheses"),Add_unknown_conversion_for_non_overlapping_types:n(95069,e.DiagnosticCategory.Message,"Add_unknown_conversion_for_non_overlapping_types_95069","Add 'unknown' conversion for non-overlapping types"),Add_unknown_to_all_conversions_of_non_overlapping_types:n(95070,e.DiagnosticCategory.Message,"Add_unknown_to_all_conversions_of_non_overlapping_types_95070","Add 'unknown' to all conversions of non-overlapping types"),Add_missing_new_operator_to_call:n(95071,e.DiagnosticCategory.Message,"Add_missing_new_operator_to_call_95071","Add missing 'new' operator to call"),Add_missing_new_operator_to_all_calls:n(95072,e.DiagnosticCategory.Message,"Add_missing_new_operator_to_all_calls_95072","Add missing 'new' operator to all calls"),Add_names_to_all_parameters_without_names:n(95073,e.DiagnosticCategory.Message,"Add_names_to_all_parameters_without_names_95073","Add names to all parameters without names"),Enable_the_experimentalDecorators_option_in_your_configuration_file:n(95074,e.DiagnosticCategory.Message,"Enable_the_experimentalDecorators_option_in_your_configuration_file_95074","Enable the 'experimentalDecorators' option in your configuration file"),Convert_parameters_to_destructured_object:n(95075,e.DiagnosticCategory.Message,"Convert_parameters_to_destructured_object_95075","Convert parameters to destructured object"),Allow_accessing_UMD_globals_from_modules:n(95076,e.DiagnosticCategory.Message,"Allow_accessing_UMD_globals_from_modules_95076","Allow accessing UMD globals from modules."),Extract_type:n(95077,e.DiagnosticCategory.Message,"Extract_type_95077","Extract type"),Extract_to_type_alias:n(95078,e.DiagnosticCategory.Message,"Extract_to_type_alias_95078","Extract to type alias"),Extract_to_typedef:n(95079,e.DiagnosticCategory.Message,"Extract_to_typedef_95079","Extract to typedef"),Infer_this_type_of_0_from_usage:n(95080,e.DiagnosticCategory.Message,"Infer_this_type_of_0_from_usage_95080","Infer 'this' type of '{0}' from usage"),Add_const_to_unresolved_variable:n(95081,e.DiagnosticCategory.Message,"Add_const_to_unresolved_variable_95081","Add 'const' to unresolved variable"),Add_const_to_all_unresolved_variables:n(95082,e.DiagnosticCategory.Message,"Add_const_to_all_unresolved_variables_95082","Add 'const' to all unresolved variables"),Add_await:n(95083,e.DiagnosticCategory.Message,"Add_await_95083","Add 'await'"),Add_await_to_initializer_for_0:n(95084,e.DiagnosticCategory.Message,"Add_await_to_initializer_for_0_95084","Add 'await' to initializer for '{0}'"),Fix_all_expressions_possibly_missing_await:n(95085,e.DiagnosticCategory.Message,"Fix_all_expressions_possibly_missing_await_95085","Fix all expressions possibly missing 'await'"),Remove_unnecessary_await:n(95086,e.DiagnosticCategory.Message,"Remove_unnecessary_await_95086","Remove unnecessary 'await'"),Remove_all_unnecessary_uses_of_await:n(95087,e.DiagnosticCategory.Message,"Remove_all_unnecessary_uses_of_await_95087","Remove all unnecessary uses of 'await'"),Enable_the_jsx_flag_in_your_configuration_file:n(95088,e.DiagnosticCategory.Message,"Enable_the_jsx_flag_in_your_configuration_file_95088","Enable the '--jsx' flag in your configuration file"),Add_await_to_initializers:n(95089,e.DiagnosticCategory.Message,"Add_await_to_initializers_95089","Add 'await' to initializers"),Extract_to_interface:n(95090,e.DiagnosticCategory.Message,"Extract_to_interface_95090","Extract to interface"),Convert_to_a_bigint_numeric_literal:n(95091,e.DiagnosticCategory.Message,"Convert_to_a_bigint_numeric_literal_95091","Convert to a bigint numeric literal"),Convert_all_to_bigint_numeric_literals:n(95092,e.DiagnosticCategory.Message,"Convert_all_to_bigint_numeric_literals_95092","Convert all to bigint numeric literals"),Convert_const_to_let:n(95093,e.DiagnosticCategory.Message,"Convert_const_to_let_95093","Convert 'const' to 'let'"),Prefix_with_declare:n(95094,e.DiagnosticCategory.Message,"Prefix_with_declare_95094","Prefix with 'declare'"),Prefix_all_incorrect_property_declarations_with_declare:n(95095,e.DiagnosticCategory.Message,"Prefix_all_incorrect_property_declarations_with_declare_95095","Prefix all incorrect property declarations with 'declare'"),Convert_to_template_string:n(95096,e.DiagnosticCategory.Message,"Convert_to_template_string_95096","Convert to template string"),Add_export_to_make_this_file_into_a_module:n(95097,e.DiagnosticCategory.Message,"Add_export_to_make_this_file_into_a_module_95097","Add 'export {}' to make this file into a module"),Set_the_target_option_in_your_configuration_file_to_0:n(95098,e.DiagnosticCategory.Message,"Set_the_target_option_in_your_configuration_file_to_0_95098","Set the 'target' option in your configuration file to '{0}'"),Set_the_module_option_in_your_configuration_file_to_0:n(95099,e.DiagnosticCategory.Message,"Set_the_module_option_in_your_configuration_file_to_0_95099","Set the 'module' option in your configuration file to '{0}'"),Convert_invalid_character_to_its_html_entity_code:n(95100,e.DiagnosticCategory.Message,"Convert_invalid_character_to_its_html_entity_code_95100","Convert invalid character to its html entity code"),Convert_all_invalid_characters_to_HTML_entity_code:n(95101,e.DiagnosticCategory.Message,"Convert_all_invalid_characters_to_HTML_entity_code_95101","Convert all invalid characters to HTML entity code"),Add_class_tag:n(95102,e.DiagnosticCategory.Message,"Add_class_tag_95102","Add '@class' tag"),Add_this_tag:n(95103,e.DiagnosticCategory.Message,"Add_this_tag_95103","Add '@this' tag"),Add_this_parameter:n(95104,e.DiagnosticCategory.Message,"Add_this_parameter_95104","Add 'this' parameter."),Convert_function_expression_0_to_arrow_function:n(95105,e.DiagnosticCategory.Message,"Convert_function_expression_0_to_arrow_function_95105","Convert function expression '{0}' to arrow function"),Convert_function_declaration_0_to_arrow_function:n(95106,e.DiagnosticCategory.Message,"Convert_function_declaration_0_to_arrow_function_95106","Convert function declaration '{0}' to arrow function"),Fix_all_implicit_this_errors:n(95107,e.DiagnosticCategory.Message,"Fix_all_implicit_this_errors_95107","Fix all implicit-'this' errors"),Wrap_invalid_character_in_an_expression_container:n(95108,e.DiagnosticCategory.Message,"Wrap_invalid_character_in_an_expression_container_95108","Wrap invalid character in an expression container"),Wrap_all_invalid_characters_in_an_expression_container:n(95109,e.DiagnosticCategory.Message,"Wrap_all_invalid_characters_in_an_expression_container_95109","Wrap all invalid characters in an expression container"),Visit_https_Colon_Slash_Slashaka_ms_Slashtsconfig_json_to_read_more_about_this_file:n(95110,e.DiagnosticCategory.Message,"Visit_https_Colon_Slash_Slashaka_ms_Slashtsconfig_json_to_read_more_about_this_file_95110","Visit https://aka.ms/tsconfig.json to read more about this file"),Add_a_return_statement:n(95111,e.DiagnosticCategory.Message,"Add_a_return_statement_95111","Add a return statement"),Remove_braces_from_arrow_function_body:n(95112,e.DiagnosticCategory.Message,"Remove_braces_from_arrow_function_body_95112","Remove braces from arrow function body"),Wrap_the_following_body_with_parentheses_which_should_be_an_object_literal:n(95113,e.DiagnosticCategory.Message,"Wrap_the_following_body_with_parentheses_which_should_be_an_object_literal_95113","Wrap the following body with parentheses which should be an object literal"),Add_all_missing_return_statement:n(95114,e.DiagnosticCategory.Message,"Add_all_missing_return_statement_95114","Add all missing return statement"),Remove_braces_from_all_arrow_function_bodies_with_relevant_issues:n(95115,e.DiagnosticCategory.Message,"Remove_braces_from_all_arrow_function_bodies_with_relevant_issues_95115","Remove braces from all arrow function bodies with relevant issues"),Wrap_all_object_literal_with_parentheses:n(95116,e.DiagnosticCategory.Message,"Wrap_all_object_literal_with_parentheses_95116","Wrap all object literal with parentheses"),Move_labeled_tuple_element_modifiers_to_labels:n(95117,e.DiagnosticCategory.Message,"Move_labeled_tuple_element_modifiers_to_labels_95117","Move labeled tuple element modifiers to labels"),Convert_overload_list_to_single_signature:n(95118,e.DiagnosticCategory.Message,"Convert_overload_list_to_single_signature_95118","Convert overload list to single signature"),Generate_get_and_set_accessors_for_all_overriding_properties:n(95119,e.DiagnosticCategory.Message,"Generate_get_and_set_accessors_for_all_overriding_properties_95119","Generate 'get' and 'set' accessors for all overriding properties"),Wrap_in_JSX_fragment:n(95120,e.DiagnosticCategory.Message,"Wrap_in_JSX_fragment_95120","Wrap in JSX fragment"),Wrap_all_unparented_JSX_in_JSX_fragment:n(95121,e.DiagnosticCategory.Message,"Wrap_all_unparented_JSX_in_JSX_fragment_95121","Wrap all unparented JSX in JSX fragment"),Convert_arrow_function_or_function_expression:n(95122,e.DiagnosticCategory.Message,"Convert_arrow_function_or_function_expression_95122","Convert arrow function or function expression"),Convert_to_anonymous_function:n(95123,e.DiagnosticCategory.Message,"Convert_to_anonymous_function_95123","Convert to anonymous function"),Convert_to_named_function:n(95124,e.DiagnosticCategory.Message,"Convert_to_named_function_95124","Convert to named function"),Convert_to_arrow_function:n(95125,e.DiagnosticCategory.Message,"Convert_to_arrow_function_95125","Convert to arrow function"),Remove_parentheses:n(95126,e.DiagnosticCategory.Message,"Remove_parentheses_95126","Remove parentheses"),Could_not_find_a_containing_arrow_function:n(95127,e.DiagnosticCategory.Message,"Could_not_find_a_containing_arrow_function_95127","Could not find a containing arrow function"),Containing_function_is_not_an_arrow_function:n(95128,e.DiagnosticCategory.Message,"Containing_function_is_not_an_arrow_function_95128","Containing function is not an arrow function"),Could_not_find_export_statement:n(95129,e.DiagnosticCategory.Message,"Could_not_find_export_statement_95129","Could not find export statement"),This_file_already_has_a_default_export:n(95130,e.DiagnosticCategory.Message,"This_file_already_has_a_default_export_95130","This file already has a default export"),Could_not_find_import_clause:n(95131,e.DiagnosticCategory.Message,"Could_not_find_import_clause_95131","Could not find import clause"),Could_not_find_namespace_import_or_named_imports:n(95132,e.DiagnosticCategory.Message,"Could_not_find_namespace_import_or_named_imports_95132","Could not find namespace import or named imports"),Selection_is_not_a_valid_type_node:n(95133,e.DiagnosticCategory.Message,"Selection_is_not_a_valid_type_node_95133","Selection is not a valid type node"),No_type_could_be_extracted_from_this_type_node:n(95134,e.DiagnosticCategory.Message,"No_type_could_be_extracted_from_this_type_node_95134","No type could be extracted from this type node"),Could_not_find_property_for_which_to_generate_accessor:n(95135,e.DiagnosticCategory.Message,"Could_not_find_property_for_which_to_generate_accessor_95135","Could not find property for which to generate accessor"),Name_is_not_valid:n(95136,e.DiagnosticCategory.Message,"Name_is_not_valid_95136","Name is not valid"),Can_only_convert_property_with_modifier:n(95137,e.DiagnosticCategory.Message,"Can_only_convert_property_with_modifier_95137","Can only convert property with modifier"),Switch_each_misused_0_to_1:n(95138,e.DiagnosticCategory.Message,"Switch_each_misused_0_to_1_95138","Switch each misused '{0}' to '{1}'"),Convert_to_optional_chain_expression:n(95139,e.DiagnosticCategory.Message,"Convert_to_optional_chain_expression_95139","Convert to optional chain expression"),Could_not_find_convertible_access_expression:n(95140,e.DiagnosticCategory.Message,"Could_not_find_convertible_access_expression_95140","Could not find convertible access expression"),Could_not_find_matching_access_expressions:n(95141,e.DiagnosticCategory.Message,"Could_not_find_matching_access_expressions_95141","Could not find matching access expressions"),Can_only_convert_logical_AND_access_chains:n(95142,e.DiagnosticCategory.Message,"Can_only_convert_logical_AND_access_chains_95142","Can only convert logical AND access chains"),Add_void_to_Promise_resolved_without_a_value:n(95143,e.DiagnosticCategory.Message,"Add_void_to_Promise_resolved_without_a_value_95143","Add 'void' to Promise resolved without a value"),Add_void_to_all_Promises_resolved_without_a_value:n(95144,e.DiagnosticCategory.Message,"Add_void_to_all_Promises_resolved_without_a_value_95144","Add 'void' to all Promises resolved without a value"),Use_element_access_for_0:n(95145,e.DiagnosticCategory.Message,"Use_element_access_for_0_95145","Use element access for '{0}'"),Use_element_access_for_all_undeclared_properties:n(95146,e.DiagnosticCategory.Message,"Use_element_access_for_all_undeclared_properties_95146","Use element access for all undeclared properties."),Delete_all_unused_imports:n(95147,e.DiagnosticCategory.Message,"Delete_all_unused_imports_95147","Delete all unused imports"),Infer_function_return_type:n(95148,e.DiagnosticCategory.Message,"Infer_function_return_type_95148","Infer function return type"),Return_type_must_be_inferred_from_a_function:n(95149,e.DiagnosticCategory.Message,"Return_type_must_be_inferred_from_a_function_95149","Return type must be inferred from a function"),Could_not_determine_function_return_type:n(95150,e.DiagnosticCategory.Message,"Could_not_determine_function_return_type_95150","Could not determine function return type"),Could_not_convert_to_arrow_function:n(95151,e.DiagnosticCategory.Message,"Could_not_convert_to_arrow_function_95151","Could not convert to arrow function"),Could_not_convert_to_named_function:n(95152,e.DiagnosticCategory.Message,"Could_not_convert_to_named_function_95152","Could not convert to named function"),Could_not_convert_to_anonymous_function:n(95153,e.DiagnosticCategory.Message,"Could_not_convert_to_anonymous_function_95153","Could not convert to anonymous function"),Can_only_convert_string_concatenation:n(95154,e.DiagnosticCategory.Message,"Can_only_convert_string_concatenation_95154","Can only convert string concatenation"),Selection_is_not_a_valid_statement_or_statements:n(95155,e.DiagnosticCategory.Message,"Selection_is_not_a_valid_statement_or_statements_95155","Selection is not a valid statement or statements"),Add_missing_function_declaration_0:n(95156,e.DiagnosticCategory.Message,"Add_missing_function_declaration_0_95156","Add missing function declaration '{0}'"),Add_all_missing_function_declarations:n(95157,e.DiagnosticCategory.Message,"Add_all_missing_function_declarations_95157","Add all missing function declarations"),Method_not_implemented:n(95158,e.DiagnosticCategory.Message,"Method_not_implemented_95158","Method not implemented."),Function_not_implemented:n(95159,e.DiagnosticCategory.Message,"Function_not_implemented_95159","Function not implemented."),Add_override_modifier:n(95160,e.DiagnosticCategory.Message,"Add_override_modifier_95160","Add 'override' modifier"),Remove_override_modifier:n(95161,e.DiagnosticCategory.Message,"Remove_override_modifier_95161","Remove 'override' modifier"),Add_all_missing_override_modifiers:n(95162,e.DiagnosticCategory.Message,"Add_all_missing_override_modifiers_95162","Add all missing 'override' modifiers"),Remove_all_unnecessary_override_modifiers:n(95163,e.DiagnosticCategory.Message,"Remove_all_unnecessary_override_modifiers_95163","Remove all unnecessary 'override' modifiers"),No_value_exists_in_scope_for_the_shorthand_property_0_Either_declare_one_or_provide_an_initializer:n(18004,e.DiagnosticCategory.Error,"No_value_exists_in_scope_for_the_shorthand_property_0_Either_declare_one_or_provide_an_initializer_18004","No value exists in scope for the shorthand property '{0}'. Either declare one or provide an initializer."),Classes_may_not_have_a_field_named_constructor:n(18006,e.DiagnosticCategory.Error,"Classes_may_not_have_a_field_named_constructor_18006","Classes may not have a field named 'constructor'."),JSX_expressions_may_not_use_the_comma_operator_Did_you_mean_to_write_an_array:n(18007,e.DiagnosticCategory.Error,"JSX_expressions_may_not_use_the_comma_operator_Did_you_mean_to_write_an_array_18007","JSX expressions may not use the comma operator. Did you mean to write an array?"),Private_identifiers_cannot_be_used_as_parameters:n(18009,e.DiagnosticCategory.Error,"Private_identifiers_cannot_be_used_as_parameters_18009","Private identifiers cannot be used as parameters."),An_accessibility_modifier_cannot_be_used_with_a_private_identifier:n(18010,e.DiagnosticCategory.Error,"An_accessibility_modifier_cannot_be_used_with_a_private_identifier_18010","An accessibility modifier cannot be used with a private identifier."),The_operand_of_a_delete_operator_cannot_be_a_private_identifier:n(18011,e.DiagnosticCategory.Error,"The_operand_of_a_delete_operator_cannot_be_a_private_identifier_18011","The operand of a 'delete' operator cannot be a private identifier."),constructor_is_a_reserved_word:n(18012,e.DiagnosticCategory.Error,"constructor_is_a_reserved_word_18012","'#constructor' is a reserved word."),Property_0_is_not_accessible_outside_class_1_because_it_has_a_private_identifier:n(18013,e.DiagnosticCategory.Error,"Property_0_is_not_accessible_outside_class_1_because_it_has_a_private_identifier_18013","Property '{0}' is not accessible outside class '{1}' because it has a private identifier."),The_property_0_cannot_be_accessed_on_type_1_within_this_class_because_it_is_shadowed_by_another_private_identifier_with_the_same_spelling:n(18014,e.DiagnosticCategory.Error,"The_property_0_cannot_be_accessed_on_type_1_within_this_class_because_it_is_shadowed_by_another_priv_18014","The property '{0}' cannot be accessed on type '{1}' within this class because it is shadowed by another private identifier with the same spelling."),Property_0_in_type_1_refers_to_a_different_member_that_cannot_be_accessed_from_within_type_2:n(18015,e.DiagnosticCategory.Error,"Property_0_in_type_1_refers_to_a_different_member_that_cannot_be_accessed_from_within_type_2_18015","Property '{0}' in type '{1}' refers to a different member that cannot be accessed from within type '{2}'."),Private_identifiers_are_not_allowed_outside_class_bodies:n(18016,e.DiagnosticCategory.Error,"Private_identifiers_are_not_allowed_outside_class_bodies_18016","Private identifiers are not allowed outside class bodies."),The_shadowing_declaration_of_0_is_defined_here:n(18017,e.DiagnosticCategory.Error,"The_shadowing_declaration_of_0_is_defined_here_18017","The shadowing declaration of '{0}' is defined here"),The_declaration_of_0_that_you_probably_intended_to_use_is_defined_here:n(18018,e.DiagnosticCategory.Error,"The_declaration_of_0_that_you_probably_intended_to_use_is_defined_here_18018","The declaration of '{0}' that you probably intended to use is defined here"),_0_modifier_cannot_be_used_with_a_private_identifier:n(18019,e.DiagnosticCategory.Error,"_0_modifier_cannot_be_used_with_a_private_identifier_18019","'{0}' modifier cannot be used with a private identifier."),An_enum_member_cannot_be_named_with_a_private_identifier:n(18024,e.DiagnosticCategory.Error,"An_enum_member_cannot_be_named_with_a_private_identifier_18024","An enum member cannot be named with a private identifier."),can_only_be_used_at_the_start_of_a_file:n(18026,e.DiagnosticCategory.Error,"can_only_be_used_at_the_start_of_a_file_18026","'#!' can only be used at the start of a file."),Compiler_reserves_name_0_when_emitting_private_identifier_downlevel:n(18027,e.DiagnosticCategory.Error,"Compiler_reserves_name_0_when_emitting_private_identifier_downlevel_18027","Compiler reserves name '{0}' when emitting private identifier downlevel."),Private_identifiers_are_only_available_when_targeting_ECMAScript_2015_and_higher:n(18028,e.DiagnosticCategory.Error,"Private_identifiers_are_only_available_when_targeting_ECMAScript_2015_and_higher_18028","Private identifiers are only available when targeting ECMAScript 2015 and higher."),Private_identifiers_are_not_allowed_in_variable_declarations:n(18029,e.DiagnosticCategory.Error,"Private_identifiers_are_not_allowed_in_variable_declarations_18029","Private identifiers are not allowed in variable declarations."),An_optional_chain_cannot_contain_private_identifiers:n(18030,e.DiagnosticCategory.Error,"An_optional_chain_cannot_contain_private_identifiers_18030","An optional chain cannot contain private identifiers."),The_intersection_0_was_reduced_to_never_because_property_1_has_conflicting_types_in_some_constituents:n(18031,e.DiagnosticCategory.Error,"The_intersection_0_was_reduced_to_never_because_property_1_has_conflicting_types_in_some_constituent_18031","The intersection '{0}' was reduced to 'never' because property '{1}' has conflicting types in some constituents."),The_intersection_0_was_reduced_to_never_because_property_1_exists_in_multiple_constituents_and_is_private_in_some:n(18032,e.DiagnosticCategory.Error,"The_intersection_0_was_reduced_to_never_because_property_1_exists_in_multiple_constituents_and_is_pr_18032","The intersection '{0}' was reduced to 'never' because property '{1}' exists in multiple constituents and is private in some."),Only_numeric_enums_can_have_computed_members_but_this_expression_has_type_0_If_you_do_not_need_exhaustiveness_checks_consider_using_an_object_literal_instead:n(18033,e.DiagnosticCategory.Error,"Only_numeric_enums_can_have_computed_members_but_this_expression_has_type_0_If_you_do_not_need_exhau_18033","Only numeric enums can have computed members, but this expression has type '{0}'. If you do not need exhaustiveness checks, consider using an object literal instead."),Specify_the_JSX_fragment_factory_function_to_use_when_targeting_react_JSX_emit_with_jsxFactory_compiler_option_is_specified_e_g_Fragment:n(18034,e.DiagnosticCategory.Message,"Specify_the_JSX_fragment_factory_function_to_use_when_targeting_react_JSX_emit_with_jsxFactory_compi_18034","Specify the JSX fragment factory function to use when targeting 'react' JSX emit with 'jsxFactory' compiler option is specified, e.g. 'Fragment'."),Invalid_value_for_jsxFragmentFactory_0_is_not_a_valid_identifier_or_qualified_name:n(18035,e.DiagnosticCategory.Error,"Invalid_value_for_jsxFragmentFactory_0_is_not_a_valid_identifier_or_qualified_name_18035","Invalid value for 'jsxFragmentFactory'. '{0}' is not a valid identifier or qualified-name."),Class_decorators_can_t_be_used_with_static_private_identifier_Consider_removing_the_experimental_decorator:n(18036,e.DiagnosticCategory.Error,"Class_decorators_can_t_be_used_with_static_private_identifier_Consider_removing_the_experimental_dec_18036","Class decorators can't be used with static private identifier. Consider removing the experimental decorator.")}}(d||(d={})),function(e){var n;function t(e){return e>=78}function r(e){return 31===e||t(e)}e.tokenIsIdentifierOrKeyword=t,e.tokenIsIdentifierOrKeywordOrGreaterThan=r;var a=(n={abstract:125,any:128,as:126,asserts:127,bigint:155,boolean:131,break:80,case:81,catch:82,class:83,continue:85,const:84},n["constructor"]=132,n.debugger=86,n.declare=133,n.default=87,n.delete=88,n.do=89,n.else=90,n.enum=91,n.export=92,n.extends=93,n.false=94,n.finally=95,n.for=96,n.from=153,n.function=97,n.get=134,n.if=98,n.implements=116,n.import=99,n.in=100,n.infer=135,n.instanceof=101,n.interface=117,n.intrinsic=136,n.is=137,n.keyof=138,n.let=118,n.module=139,n.namespace=140,n.never=141,n.new=102,n.null=103,n.number=144,n.object=145,n.package=119,n.private=120,n.protected=121,n.public=122,n.override=156,n.readonly=142,n.require=143,n.global=154,n.return=104,n.set=146,n.static=123,n.string=147,n.super=105,n.switch=106,n.symbol=148,n.this=107,n.throw=108,n.true=109,n.try=110,n.type=149,n.typeof=111,n.undefined=150,n.unique=151,n.unknown=152,n.var=112,n.void=113,n.while=114,n.with=115,n.yield=124,n.async=129,n.await=130,n.of=157,n),i=new e.Map(e.getEntries(a)),s=new e.Map(e.getEntries(o(o({},a),{"{":18,"}":19,"(":20,")":21,"[":22,"]":23,".":24,"...":25,";":26,",":27,"<":29,">":31,"<=":32,">=":33,"==":34,"!=":35,"===":36,"!==":37,"=>":38,"+":39,"-":40,"**":42,"*":41,"/":43,"%":44,"++":45,"--":46,"<<":47,"</":30,">>":48,">>>":49,"&":50,"|":51,"^":52,"!":53,"~":54,"&&":55,"||":56,"?":57,"??":60,"?.":28,":":58,"=":62,"+=":63,"-=":64,"*=":65,"**=":66,"/=":67,"%=":68,"<<=":69,">>=":70,">>>=":71,"&=":72,"|=":73,"^=":77,"||=":74,"&&=":75,"??=":76,"@":59,"`":61}))),c=[170,170,181,181,186,186,192,214,216,246,248,543,546,563,592,685,688,696,699,705,720,721,736,740,750,750,890,890,902,902,904,906,908,908,910,929,931,974,976,983,986,1011,1024,1153,1164,1220,1223,1224,1227,1228,1232,1269,1272,1273,1329,1366,1369,1369,1377,1415,1488,1514,1520,1522,1569,1594,1600,1610,1649,1747,1749,1749,1765,1766,1786,1788,1808,1808,1810,1836,1920,1957,2309,2361,2365,2365,2384,2384,2392,2401,2437,2444,2447,2448,2451,2472,2474,2480,2482,2482,2486,2489,2524,2525,2527,2529,2544,2545,2565,2570,2575,2576,2579,2600,2602,2608,2610,2611,2613,2614,2616,2617,2649,2652,2654,2654,2674,2676,2693,2699,2701,2701,2703,2705,2707,2728,2730,2736,2738,2739,2741,2745,2749,2749,2768,2768,2784,2784,2821,2828,2831,2832,2835,2856,2858,2864,2866,2867,2870,2873,2877,2877,2908,2909,2911,2913,2949,2954,2958,2960,2962,2965,2969,2970,2972,2972,2974,2975,2979,2980,2984,2986,2990,2997,2999,3001,3077,3084,3086,3088,3090,3112,3114,3123,3125,3129,3168,3169,3205,3212,3214,3216,3218,3240,3242,3251,3253,3257,3294,3294,3296,3297,3333,3340,3342,3344,3346,3368,3370,3385,3424,3425,3461,3478,3482,3505,3507,3515,3517,3517,3520,3526,3585,3632,3634,3635,3648,3654,3713,3714,3716,3716,3719,3720,3722,3722,3725,3725,3732,3735,3737,3743,3745,3747,3749,3749,3751,3751,3754,3755,3757,3760,3762,3763,3773,3773,3776,3780,3782,3782,3804,3805,3840,3840,3904,3911,3913,3946,3976,3979,4096,4129,4131,4135,4137,4138,4176,4181,4256,4293,4304,4342,4352,4441,4447,4514,4520,4601,4608,4614,4616,4678,4680,4680,4682,4685,4688,4694,4696,4696,4698,4701,4704,4742,4744,4744,4746,4749,4752,4782,4784,4784,4786,4789,4792,4798,4800,4800,4802,4805,4808,4814,4816,4822,4824,4846,4848,4878,4880,4880,4882,4885,4888,4894,4896,4934,4936,4954,5024,5108,5121,5740,5743,5750,5761,5786,5792,5866,6016,6067,6176,6263,6272,6312,7680,7835,7840,7929,7936,7957,7960,7965,7968,8005,8008,8013,8016,8023,8025,8025,8027,8027,8029,8029,8031,8061,8064,8116,8118,8124,8126,8126,8130,8132,8134,8140,8144,8147,8150,8155,8160,8172,8178,8180,8182,8188,8319,8319,8450,8450,8455,8455,8458,8467,8469,8469,8473,8477,8484,8484,8486,8486,8488,8488,8490,8493,8495,8497,8499,8505,8544,8579,12293,12295,12321,12329,12337,12341,12344,12346,12353,12436,12445,12446,12449,12538,12540,12542,12549,12588,12593,12686,12704,12727,13312,19893,19968,40869,40960,42124,44032,55203,63744,64045,64256,64262,64275,64279,64285,64285,64287,64296,64298,64310,64312,64316,64318,64318,64320,64321,64323,64324,64326,64433,64467,64829,64848,64911,64914,64967,65008,65019,65136,65138,65140,65140,65142,65276,65313,65338,65345,65370,65382,65470,65474,65479,65482,65487,65490,65495,65498,65500],l=[170,170,181,181,186,186,192,214,216,246,248,543,546,563,592,685,688,696,699,705,720,721,736,740,750,750,768,846,864,866,890,890,902,902,904,906,908,908,910,929,931,974,976,983,986,1011,1024,1153,1155,1158,1164,1220,1223,1224,1227,1228,1232,1269,1272,1273,1329,1366,1369,1369,1377,1415,1425,1441,1443,1465,1467,1469,1471,1471,1473,1474,1476,1476,1488,1514,1520,1522,1569,1594,1600,1621,1632,1641,1648,1747,1749,1756,1759,1768,1770,1773,1776,1788,1808,1836,1840,1866,1920,1968,2305,2307,2309,2361,2364,2381,2384,2388,2392,2403,2406,2415,2433,2435,2437,2444,2447,2448,2451,2472,2474,2480,2482,2482,2486,2489,2492,2492,2494,2500,2503,2504,2507,2509,2519,2519,2524,2525,2527,2531,2534,2545,2562,2562,2565,2570,2575,2576,2579,2600,2602,2608,2610,2611,2613,2614,2616,2617,2620,2620,2622,2626,2631,2632,2635,2637,2649,2652,2654,2654,2662,2676,2689,2691,2693,2699,2701,2701,2703,2705,2707,2728,2730,2736,2738,2739,2741,2745,2748,2757,2759,2761,2763,2765,2768,2768,2784,2784,2790,2799,2817,2819,2821,2828,2831,2832,2835,2856,2858,2864,2866,2867,2870,2873,2876,2883,2887,2888,2891,2893,2902,2903,2908,2909,2911,2913,2918,2927,2946,2947,2949,2954,2958,2960,2962,2965,2969,2970,2972,2972,2974,2975,2979,2980,2984,2986,2990,2997,2999,3001,3006,3010,3014,3016,3018,3021,3031,3031,3047,3055,3073,3075,3077,3084,3086,3088,3090,3112,3114,3123,3125,3129,3134,3140,3142,3144,3146,3149,3157,3158,3168,3169,3174,3183,3202,3203,3205,3212,3214,3216,3218,3240,3242,3251,3253,3257,3262,3268,3270,3272,3274,3277,3285,3286,3294,3294,3296,3297,3302,3311,3330,3331,3333,3340,3342,3344,3346,3368,3370,3385,3390,3395,3398,3400,3402,3405,3415,3415,3424,3425,3430,3439,3458,3459,3461,3478,3482,3505,3507,3515,3517,3517,3520,3526,3530,3530,3535,3540,3542,3542,3544,3551,3570,3571,3585,3642,3648,3662,3664,3673,3713,3714,3716,3716,3719,3720,3722,3722,3725,3725,3732,3735,3737,3743,3745,3747,3749,3749,3751,3751,3754,3755,3757,3769,3771,3773,3776,3780,3782,3782,3784,3789,3792,3801,3804,3805,3840,3840,3864,3865,3872,3881,3893,3893,3895,3895,3897,3897,3902,3911,3913,3946,3953,3972,3974,3979,3984,3991,3993,4028,4038,4038,4096,4129,4131,4135,4137,4138,4140,4146,4150,4153,4160,4169,4176,4185,4256,4293,4304,4342,4352,4441,4447,4514,4520,4601,4608,4614,4616,4678,4680,4680,4682,4685,4688,4694,4696,4696,4698,4701,4704,4742,4744,4744,4746,4749,4752,4782,4784,4784,4786,4789,4792,4798,4800,4800,4802,4805,4808,4814,4816,4822,4824,4846,4848,4878,4880,4880,4882,4885,4888,4894,4896,4934,4936,4954,4969,4977,5024,5108,5121,5740,5743,5750,5761,5786,5792,5866,6016,6099,6112,6121,6160,6169,6176,6263,6272,6313,7680,7835,7840,7929,7936,7957,7960,7965,7968,8005,8008,8013,8016,8023,8025,8025,8027,8027,8029,8029,8031,8061,8064,8116,8118,8124,8126,8126,8130,8132,8134,8140,8144,8147,8150,8155,8160,8172,8178,8180,8182,8188,8255,8256,8319,8319,8400,8412,8417,8417,8450,8450,8455,8455,8458,8467,8469,8469,8473,8477,8484,8484,8486,8486,8488,8488,8490,8493,8495,8497,8499,8505,8544,8579,12293,12295,12321,12335,12337,12341,12344,12346,12353,12436,12441,12442,12445,12446,12449,12542,12549,12588,12593,12686,12704,12727,13312,19893,19968,40869,40960,42124,44032,55203,63744,64045,64256,64262,64275,64279,64285,64296,64298,64310,64312,64316,64318,64318,64320,64321,64323,64324,64326,64433,64467,64829,64848,64911,64914,64967,65008,65019,65056,65059,65075,65076,65101,65103,65136,65138,65140,65140,65142,65276,65296,65305,65313,65338,65343,65343,65345,65370,65381,65470,65474,65479,65482,65487,65490,65495,65498,65500],u=[170,170,181,181,186,186,192,214,216,246,248,705,710,721,736,740,748,748,750,750,880,884,886,887,890,893,902,902,904,906,908,908,910,929,931,1013,1015,1153,1162,1319,1329,1366,1369,1369,1377,1415,1488,1514,1520,1522,1568,1610,1646,1647,1649,1747,1749,1749,1765,1766,1774,1775,1786,1788,1791,1791,1808,1808,1810,1839,1869,1957,1969,1969,1994,2026,2036,2037,2042,2042,2048,2069,2074,2074,2084,2084,2088,2088,2112,2136,2208,2208,2210,2220,2308,2361,2365,2365,2384,2384,2392,2401,2417,2423,2425,2431,2437,2444,2447,2448,2451,2472,2474,2480,2482,2482,2486,2489,2493,2493,2510,2510,2524,2525,2527,2529,2544,2545,2565,2570,2575,2576,2579,2600,2602,2608,2610,2611,2613,2614,2616,2617,2649,2652,2654,2654,2674,2676,2693,2701,2703,2705,2707,2728,2730,2736,2738,2739,2741,2745,2749,2749,2768,2768,2784,2785,2821,2828,2831,2832,2835,2856,2858,2864,2866,2867,2869,2873,2877,2877,2908,2909,2911,2913,2929,2929,2947,2947,2949,2954,2958,2960,2962,2965,2969,2970,2972,2972,2974,2975,2979,2980,2984,2986,2990,3001,3024,3024,3077,3084,3086,3088,3090,3112,3114,3123,3125,3129,3133,3133,3160,3161,3168,3169,3205,3212,3214,3216,3218,3240,3242,3251,3253,3257,3261,3261,3294,3294,3296,3297,3313,3314,3333,3340,3342,3344,3346,3386,3389,3389,3406,3406,3424,3425,3450,3455,3461,3478,3482,3505,3507,3515,3517,3517,3520,3526,3585,3632,3634,3635,3648,3654,3713,3714,3716,3716,3719,3720,3722,3722,3725,3725,3732,3735,3737,3743,3745,3747,3749,3749,3751,3751,3754,3755,3757,3760,3762,3763,3773,3773,3776,3780,3782,3782,3804,3807,3840,3840,3904,3911,3913,3948,3976,3980,4096,4138,4159,4159,4176,4181,4186,4189,4193,4193,4197,4198,4206,4208,4213,4225,4238,4238,4256,4293,4295,4295,4301,4301,4304,4346,4348,4680,4682,4685,4688,4694,4696,4696,4698,4701,4704,4744,4746,4749,4752,4784,4786,4789,4792,4798,4800,4800,4802,4805,4808,4822,4824,4880,4882,4885,4888,4954,4992,5007,5024,5108,5121,5740,5743,5759,5761,5786,5792,5866,5870,5872,5888,5900,5902,5905,5920,5937,5952,5969,5984,5996,5998,6e3,6016,6067,6103,6103,6108,6108,6176,6263,6272,6312,6314,6314,6320,6389,6400,6428,6480,6509,6512,6516,6528,6571,6593,6599,6656,6678,6688,6740,6823,6823,6917,6963,6981,6987,7043,7072,7086,7087,7098,7141,7168,7203,7245,7247,7258,7293,7401,7404,7406,7409,7413,7414,7424,7615,7680,7957,7960,7965,7968,8005,8008,8013,8016,8023,8025,8025,8027,8027,8029,8029,8031,8061,8064,8116,8118,8124,8126,8126,8130,8132,8134,8140,8144,8147,8150,8155,8160,8172,8178,8180,8182,8188,8305,8305,8319,8319,8336,8348,8450,8450,8455,8455,8458,8467,8469,8469,8473,8477,8484,8484,8486,8486,8488,8488,8490,8493,8495,8505,8508,8511,8517,8521,8526,8526,8544,8584,11264,11310,11312,11358,11360,11492,11499,11502,11506,11507,11520,11557,11559,11559,11565,11565,11568,11623,11631,11631,11648,11670,11680,11686,11688,11694,11696,11702,11704,11710,11712,11718,11720,11726,11728,11734,11736,11742,11823,11823,12293,12295,12321,12329,12337,12341,12344,12348,12353,12438,12445,12447,12449,12538,12540,12543,12549,12589,12593,12686,12704,12730,12784,12799,13312,19893,19968,40908,40960,42124,42192,42237,42240,42508,42512,42527,42538,42539,42560,42606,42623,42647,42656,42735,42775,42783,42786,42888,42891,42894,42896,42899,42912,42922,43e3,43009,43011,43013,43015,43018,43020,43042,43072,43123,43138,43187,43250,43255,43259,43259,43274,43301,43312,43334,43360,43388,43396,43442,43471,43471,43520,43560,43584,43586,43588,43595,43616,43638,43642,43642,43648,43695,43697,43697,43701,43702,43705,43709,43712,43712,43714,43714,43739,43741,43744,43754,43762,43764,43777,43782,43785,43790,43793,43798,43808,43814,43816,43822,43968,44002,44032,55203,55216,55238,55243,55291,63744,64109,64112,64217,64256,64262,64275,64279,64285,64285,64287,64296,64298,64310,64312,64316,64318,64318,64320,64321,64323,64324,64326,64433,64467,64829,64848,64911,64914,64967,65008,65019,65136,65140,65142,65276,65313,65338,65345,65370,65382,65470,65474,65479,65482,65487,65490,65495,65498,65500],d=[170,170,181,181,186,186,192,214,216,246,248,705,710,721,736,740,748,748,750,750,768,884,886,887,890,893,902,902,904,906,908,908,910,929,931,1013,1015,1153,1155,1159,1162,1319,1329,1366,1369,1369,1377,1415,1425,1469,1471,1471,1473,1474,1476,1477,1479,1479,1488,1514,1520,1522,1552,1562,1568,1641,1646,1747,1749,1756,1759,1768,1770,1788,1791,1791,1808,1866,1869,1969,1984,2037,2042,2042,2048,2093,2112,2139,2208,2208,2210,2220,2276,2302,2304,2403,2406,2415,2417,2423,2425,2431,2433,2435,2437,2444,2447,2448,2451,2472,2474,2480,2482,2482,2486,2489,2492,2500,2503,2504,2507,2510,2519,2519,2524,2525,2527,2531,2534,2545,2561,2563,2565,2570,2575,2576,2579,2600,2602,2608,2610,2611,2613,2614,2616,2617,2620,2620,2622,2626,2631,2632,2635,2637,2641,2641,2649,2652,2654,2654,2662,2677,2689,2691,2693,2701,2703,2705,2707,2728,2730,2736,2738,2739,2741,2745,2748,2757,2759,2761,2763,2765,2768,2768,2784,2787,2790,2799,2817,2819,2821,2828,2831,2832,2835,2856,2858,2864,2866,2867,2869,2873,2876,2884,2887,2888,2891,2893,2902,2903,2908,2909,2911,2915,2918,2927,2929,2929,2946,2947,2949,2954,2958,2960,2962,2965,2969,2970,2972,2972,2974,2975,2979,2980,2984,2986,2990,3001,3006,3010,3014,3016,3018,3021,3024,3024,3031,3031,3046,3055,3073,3075,3077,3084,3086,3088,3090,3112,3114,3123,3125,3129,3133,3140,3142,3144,3146,3149,3157,3158,3160,3161,3168,3171,3174,3183,3202,3203,3205,3212,3214,3216,3218,3240,3242,3251,3253,3257,3260,3268,3270,3272,3274,3277,3285,3286,3294,3294,3296,3299,3302,3311,3313,3314,3330,3331,3333,3340,3342,3344,3346,3386,3389,3396,3398,3400,3402,3406,3415,3415,3424,3427,3430,3439,3450,3455,3458,3459,3461,3478,3482,3505,3507,3515,3517,3517,3520,3526,3530,3530,3535,3540,3542,3542,3544,3551,3570,3571,3585,3642,3648,3662,3664,3673,3713,3714,3716,3716,3719,3720,3722,3722,3725,3725,3732,3735,3737,3743,3745,3747,3749,3749,3751,3751,3754,3755,3757,3769,3771,3773,3776,3780,3782,3782,3784,3789,3792,3801,3804,3807,3840,3840,3864,3865,3872,3881,3893,3893,3895,3895,3897,3897,3902,3911,3913,3948,3953,3972,3974,3991,3993,4028,4038,4038,4096,4169,4176,4253,4256,4293,4295,4295,4301,4301,4304,4346,4348,4680,4682,4685,4688,4694,4696,4696,4698,4701,4704,4744,4746,4749,4752,4784,4786,4789,4792,4798,4800,4800,4802,4805,4808,4822,4824,4880,4882,4885,4888,4954,4957,4959,4992,5007,5024,5108,5121,5740,5743,5759,5761,5786,5792,5866,5870,5872,5888,5900,5902,5908,5920,5940,5952,5971,5984,5996,5998,6e3,6002,6003,6016,6099,6103,6103,6108,6109,6112,6121,6155,6157,6160,6169,6176,6263,6272,6314,6320,6389,6400,6428,6432,6443,6448,6459,6470,6509,6512,6516,6528,6571,6576,6601,6608,6617,6656,6683,6688,6750,6752,6780,6783,6793,6800,6809,6823,6823,6912,6987,6992,7001,7019,7027,7040,7155,7168,7223,7232,7241,7245,7293,7376,7378,7380,7414,7424,7654,7676,7957,7960,7965,7968,8005,8008,8013,8016,8023,8025,8025,8027,8027,8029,8029,8031,8061,8064,8116,8118,8124,8126,8126,8130,8132,8134,8140,8144,8147,8150,8155,8160,8172,8178,8180,8182,8188,8204,8205,8255,8256,8276,8276,8305,8305,8319,8319,8336,8348,8400,8412,8417,8417,8421,8432,8450,8450,8455,8455,8458,8467,8469,8469,8473,8477,8484,8484,8486,8486,8488,8488,8490,8493,8495,8505,8508,8511,8517,8521,8526,8526,8544,8584,11264,11310,11312,11358,11360,11492,11499,11507,11520,11557,11559,11559,11565,11565,11568,11623,11631,11631,11647,11670,11680,11686,11688,11694,11696,11702,11704,11710,11712,11718,11720,11726,11728,11734,11736,11742,11744,11775,11823,11823,12293,12295,12321,12335,12337,12341,12344,12348,12353,12438,12441,12442,12445,12447,12449,12538,12540,12543,12549,12589,12593,12686,12704,12730,12784,12799,13312,19893,19968,40908,40960,42124,42192,42237,42240,42508,42512,42539,42560,42607,42612,42621,42623,42647,42655,42737,42775,42783,42786,42888,42891,42894,42896,42899,42912,42922,43e3,43047,43072,43123,43136,43204,43216,43225,43232,43255,43259,43259,43264,43309,43312,43347,43360,43388,43392,43456,43471,43481,43520,43574,43584,43597,43600,43609,43616,43638,43642,43643,43648,43714,43739,43741,43744,43759,43762,43766,43777,43782,43785,43790,43793,43798,43808,43814,43816,43822,43968,44010,44012,44013,44016,44025,44032,55203,55216,55238,55243,55291,63744,64109,64112,64217,64256,64262,64275,64279,64285,64296,64298,64310,64312,64316,64318,64318,64320,64321,64323,64324,64326,64433,64467,64829,64848,64911,64914,64967,65008,65019,65024,65039,65056,65062,65075,65076,65101,65103,65136,65140,65142,65276,65296,65305,65313,65338,65343,65343,65345,65370,65382,65470,65474,65479,65482,65487,65490,65495,65498,65500],p=[65,90,97,122,170,170,181,181,186,186,192,214,216,246,248,705,710,721,736,740,748,748,750,750,880,884,886,887,890,893,895,895,902,902,904,906,908,908,910,929,931,1013,1015,1153,1162,1327,1329,1366,1369,1369,1376,1416,1488,1514,1519,1522,1568,1610,1646,1647,1649,1747,1749,1749,1765,1766,1774,1775,1786,1788,1791,1791,1808,1808,1810,1839,1869,1957,1969,1969,1994,2026,2036,2037,2042,2042,2048,2069,2074,2074,2084,2084,2088,2088,2112,2136,2144,2154,2208,2228,2230,2237,2308,2361,2365,2365,2384,2384,2392,2401,2417,2432,2437,2444,2447,2448,2451,2472,2474,2480,2482,2482,2486,2489,2493,2493,2510,2510,2524,2525,2527,2529,2544,2545,2556,2556,2565,2570,2575,2576,2579,2600,2602,2608,2610,2611,2613,2614,2616,2617,2649,2652,2654,2654,2674,2676,2693,2701,2703,2705,2707,2728,2730,2736,2738,2739,2741,2745,2749,2749,2768,2768,2784,2785,2809,2809,2821,2828,2831,2832,2835,2856,2858,2864,2866,2867,2869,2873,2877,2877,2908,2909,2911,2913,2929,2929,2947,2947,2949,2954,2958,2960,2962,2965,2969,2970,2972,2972,2974,2975,2979,2980,2984,2986,2990,3001,3024,3024,3077,3084,3086,3088,3090,3112,3114,3129,3133,3133,3160,3162,3168,3169,3200,3200,3205,3212,3214,3216,3218,3240,3242,3251,3253,3257,3261,3261,3294,3294,3296,3297,3313,3314,3333,3340,3342,3344,3346,3386,3389,3389,3406,3406,3412,3414,3423,3425,3450,3455,3461,3478,3482,3505,3507,3515,3517,3517,3520,3526,3585,3632,3634,3635,3648,3654,3713,3714,3716,3716,3718,3722,3724,3747,3749,3749,3751,3760,3762,3763,3773,3773,3776,3780,3782,3782,3804,3807,3840,3840,3904,3911,3913,3948,3976,3980,4096,4138,4159,4159,4176,4181,4186,4189,4193,4193,4197,4198,4206,4208,4213,4225,4238,4238,4256,4293,4295,4295,4301,4301,4304,4346,4348,4680,4682,4685,4688,4694,4696,4696,4698,4701,4704,4744,4746,4749,4752,4784,4786,4789,4792,4798,4800,4800,4802,4805,4808,4822,4824,4880,4882,4885,4888,4954,4992,5007,5024,5109,5112,5117,5121,5740,5743,5759,5761,5786,5792,5866,5870,5880,5888,5900,5902,5905,5920,5937,5952,5969,5984,5996,5998,6e3,6016,6067,6103,6103,6108,6108,6176,6264,6272,6312,6314,6314,6320,6389,6400,6430,6480,6509,6512,6516,6528,6571,6576,6601,6656,6678,6688,6740,6823,6823,6917,6963,6981,6987,7043,7072,7086,7087,7098,7141,7168,7203,7245,7247,7258,7293,7296,7304,7312,7354,7357,7359,7401,7404,7406,7411,7413,7414,7418,7418,7424,7615,7680,7957,7960,7965,7968,8005,8008,8013,8016,8023,8025,8025,8027,8027,8029,8029,8031,8061,8064,8116,8118,8124,8126,8126,8130,8132,8134,8140,8144,8147,8150,8155,8160,8172,8178,8180,8182,8188,8305,8305,8319,8319,8336,8348,8450,8450,8455,8455,8458,8467,8469,8469,8472,8477,8484,8484,8486,8486,8488,8488,8490,8505,8508,8511,8517,8521,8526,8526,8544,8584,11264,11310,11312,11358,11360,11492,11499,11502,11506,11507,11520,11557,11559,11559,11565,11565,11568,11623,11631,11631,11648,11670,11680,11686,11688,11694,11696,11702,11704,11710,11712,11718,11720,11726,11728,11734,11736,11742,12293,12295,12321,12329,12337,12341,12344,12348,12353,12438,12443,12447,12449,12538,12540,12543,12549,12591,12593,12686,12704,12730,12784,12799,13312,19893,19968,40943,40960,42124,42192,42237,42240,42508,42512,42527,42538,42539,42560,42606,42623,42653,42656,42735,42775,42783,42786,42888,42891,42943,42946,42950,42999,43009,43011,43013,43015,43018,43020,43042,43072,43123,43138,43187,43250,43255,43259,43259,43261,43262,43274,43301,43312,43334,43360,43388,43396,43442,43471,43471,43488,43492,43494,43503,43514,43518,43520,43560,43584,43586,43588,43595,43616,43638,43642,43642,43646,43695,43697,43697,43701,43702,43705,43709,43712,43712,43714,43714,43739,43741,43744,43754,43762,43764,43777,43782,43785,43790,43793,43798,43808,43814,43816,43822,43824,43866,43868,43879,43888,44002,44032,55203,55216,55238,55243,55291,63744,64109,64112,64217,64256,64262,64275,64279,64285,64285,64287,64296,64298,64310,64312,64316,64318,64318,64320,64321,64323,64324,64326,64433,64467,64829,64848,64911,64914,64967,65008,65019,65136,65140,65142,65276,65313,65338,65345,65370,65382,65470,65474,65479,65482,65487,65490,65495,65498,65500,65536,65547,65549,65574,65576,65594,65596,65597,65599,65613,65616,65629,65664,65786,65856,65908,66176,66204,66208,66256,66304,66335,66349,66378,66384,66421,66432,66461,66464,66499,66504,66511,66513,66517,66560,66717,66736,66771,66776,66811,66816,66855,66864,66915,67072,67382,67392,67413,67424,67431,67584,67589,67592,67592,67594,67637,67639,67640,67644,67644,67647,67669,67680,67702,67712,67742,67808,67826,67828,67829,67840,67861,67872,67897,67968,68023,68030,68031,68096,68096,68112,68115,68117,68119,68121,68149,68192,68220,68224,68252,68288,68295,68297,68324,68352,68405,68416,68437,68448,68466,68480,68497,68608,68680,68736,68786,68800,68850,68864,68899,69376,69404,69415,69415,69424,69445,69600,69622,69635,69687,69763,69807,69840,69864,69891,69926,69956,69956,69968,70002,70006,70006,70019,70066,70081,70084,70106,70106,70108,70108,70144,70161,70163,70187,70272,70278,70280,70280,70282,70285,70287,70301,70303,70312,70320,70366,70405,70412,70415,70416,70419,70440,70442,70448,70450,70451,70453,70457,70461,70461,70480,70480,70493,70497,70656,70708,70727,70730,70751,70751,70784,70831,70852,70853,70855,70855,71040,71086,71128,71131,71168,71215,71236,71236,71296,71338,71352,71352,71424,71450,71680,71723,71840,71903,71935,71935,72096,72103,72106,72144,72161,72161,72163,72163,72192,72192,72203,72242,72250,72250,72272,72272,72284,72329,72349,72349,72384,72440,72704,72712,72714,72750,72768,72768,72818,72847,72960,72966,72968,72969,72971,73008,73030,73030,73056,73061,73063,73064,73066,73097,73112,73112,73440,73458,73728,74649,74752,74862,74880,75075,77824,78894,82944,83526,92160,92728,92736,92766,92880,92909,92928,92975,92992,92995,93027,93047,93053,93071,93760,93823,93952,94026,94032,94032,94099,94111,94176,94177,94179,94179,94208,100343,100352,101106,110592,110878,110928,110930,110948,110951,110960,111355,113664,113770,113776,113788,113792,113800,113808,113817,119808,119892,119894,119964,119966,119967,119970,119970,119973,119974,119977,119980,119982,119993,119995,119995,119997,120003,120005,120069,120071,120074,120077,120084,120086,120092,120094,120121,120123,120126,120128,120132,120134,120134,120138,120144,120146,120485,120488,120512,120514,120538,120540,120570,120572,120596,120598,120628,120630,120654,120656,120686,120688,120712,120714,120744,120746,120770,120772,120779,123136,123180,123191,123197,123214,123214,123584,123627,124928,125124,125184,125251,125259,125259,126464,126467,126469,126495,126497,126498,126500,126500,126503,126503,126505,126514,126516,126519,126521,126521,126523,126523,126530,126530,126535,126535,126537,126537,126539,126539,126541,126543,126545,126546,126548,126548,126551,126551,126553,126553,126555,126555,126557,126557,126559,126559,126561,126562,126564,126564,126567,126570,126572,126578,126580,126583,126585,126588,126590,126590,126592,126601,126603,126619,126625,126627,126629,126633,126635,126651,131072,173782,173824,177972,177984,178205,178208,183969,183984,191456,194560,195101],f=[48,57,65,90,95,95,97,122,170,170,181,181,183,183,186,186,192,214,216,246,248,705,710,721,736,740,748,748,750,750,768,884,886,887,890,893,895,895,902,906,908,908,910,929,931,1013,1015,1153,1155,1159,1162,1327,1329,1366,1369,1369,1376,1416,1425,1469,1471,1471,1473,1474,1476,1477,1479,1479,1488,1514,1519,1522,1552,1562,1568,1641,1646,1747,1749,1756,1759,1768,1770,1788,1791,1791,1808,1866,1869,1969,1984,2037,2042,2042,2045,2045,2048,2093,2112,2139,2144,2154,2208,2228,2230,2237,2259,2273,2275,2403,2406,2415,2417,2435,2437,2444,2447,2448,2451,2472,2474,2480,2482,2482,2486,2489,2492,2500,2503,2504,2507,2510,2519,2519,2524,2525,2527,2531,2534,2545,2556,2556,2558,2558,2561,2563,2565,2570,2575,2576,2579,2600,2602,2608,2610,2611,2613,2614,2616,2617,2620,2620,2622,2626,2631,2632,2635,2637,2641,2641,2649,2652,2654,2654,2662,2677,2689,2691,2693,2701,2703,2705,2707,2728,2730,2736,2738,2739,2741,2745,2748,2757,2759,2761,2763,2765,2768,2768,2784,2787,2790,2799,2809,2815,2817,2819,2821,2828,2831,2832,2835,2856,2858,2864,2866,2867,2869,2873,2876,2884,2887,2888,2891,2893,2902,2903,2908,2909,2911,2915,2918,2927,2929,2929,2946,2947,2949,2954,2958,2960,2962,2965,2969,2970,2972,2972,2974,2975,2979,2980,2984,2986,2990,3001,3006,3010,3014,3016,3018,3021,3024,3024,3031,3031,3046,3055,3072,3084,3086,3088,3090,3112,3114,3129,3133,3140,3142,3144,3146,3149,3157,3158,3160,3162,3168,3171,3174,3183,3200,3203,3205,3212,3214,3216,3218,3240,3242,3251,3253,3257,3260,3268,3270,3272,3274,3277,3285,3286,3294,3294,3296,3299,3302,3311,3313,3314,3328,3331,3333,3340,3342,3344,3346,3396,3398,3400,3402,3406,3412,3415,3423,3427,3430,3439,3450,3455,3458,3459,3461,3478,3482,3505,3507,3515,3517,3517,3520,3526,3530,3530,3535,3540,3542,3542,3544,3551,3558,3567,3570,3571,3585,3642,3648,3662,3664,3673,3713,3714,3716,3716,3718,3722,3724,3747,3749,3749,3751,3773,3776,3780,3782,3782,3784,3789,3792,3801,3804,3807,3840,3840,3864,3865,3872,3881,3893,3893,3895,3895,3897,3897,3902,3911,3913,3948,3953,3972,3974,3991,3993,4028,4038,4038,4096,4169,4176,4253,4256,4293,4295,4295,4301,4301,4304,4346,4348,4680,4682,4685,4688,4694,4696,4696,4698,4701,4704,4744,4746,4749,4752,4784,4786,4789,4792,4798,4800,4800,4802,4805,4808,4822,4824,4880,4882,4885,4888,4954,4957,4959,4969,4977,4992,5007,5024,5109,5112,5117,5121,5740,5743,5759,5761,5786,5792,5866,5870,5880,5888,5900,5902,5908,5920,5940,5952,5971,5984,5996,5998,6e3,6002,6003,6016,6099,6103,6103,6108,6109,6112,6121,6155,6157,6160,6169,6176,6264,6272,6314,6320,6389,6400,6430,6432,6443,6448,6459,6470,6509,6512,6516,6528,6571,6576,6601,6608,6618,6656,6683,6688,6750,6752,6780,6783,6793,6800,6809,6823,6823,6832,6845,6912,6987,6992,7001,7019,7027,7040,7155,7168,7223,7232,7241,7245,7293,7296,7304,7312,7354,7357,7359,7376,7378,7380,7418,7424,7673,7675,7957,7960,7965,7968,8005,8008,8013,8016,8023,8025,8025,8027,8027,8029,8029,8031,8061,8064,8116,8118,8124,8126,8126,8130,8132,8134,8140,8144,8147,8150,8155,8160,8172,8178,8180,8182,8188,8255,8256,8276,8276,8305,8305,8319,8319,8336,8348,8400,8412,8417,8417,8421,8432,8450,8450,8455,8455,8458,8467,8469,8469,8472,8477,8484,8484,8486,8486,8488,8488,8490,8505,8508,8511,8517,8521,8526,8526,8544,8584,11264,11310,11312,11358,11360,11492,11499,11507,11520,11557,11559,11559,11565,11565,11568,11623,11631,11631,11647,11670,11680,11686,11688,11694,11696,11702,11704,11710,11712,11718,11720,11726,11728,11734,11736,11742,11744,11775,12293,12295,12321,12335,12337,12341,12344,12348,12353,12438,12441,12447,12449,12538,12540,12543,12549,12591,12593,12686,12704,12730,12784,12799,13312,19893,19968,40943,40960,42124,42192,42237,42240,42508,42512,42539,42560,42607,42612,42621,42623,42737,42775,42783,42786,42888,42891,42943,42946,42950,42999,43047,43072,43123,43136,43205,43216,43225,43232,43255,43259,43259,43261,43309,43312,43347,43360,43388,43392,43456,43471,43481,43488,43518,43520,43574,43584,43597,43600,43609,43616,43638,43642,43714,43739,43741,43744,43759,43762,43766,43777,43782,43785,43790,43793,43798,43808,43814,43816,43822,43824,43866,43868,43879,43888,44010,44012,44013,44016,44025,44032,55203,55216,55238,55243,55291,63744,64109,64112,64217,64256,64262,64275,64279,64285,64296,64298,64310,64312,64316,64318,64318,64320,64321,64323,64324,64326,64433,64467,64829,64848,64911,64914,64967,65008,65019,65024,65039,65056,65071,65075,65076,65101,65103,65136,65140,65142,65276,65296,65305,65313,65338,65343,65343,65345,65370,65382,65470,65474,65479,65482,65487,65490,65495,65498,65500,65536,65547,65549,65574,65576,65594,65596,65597,65599,65613,65616,65629,65664,65786,65856,65908,66045,66045,66176,66204,66208,66256,66272,66272,66304,66335,66349,66378,66384,66426,66432,66461,66464,66499,66504,66511,66513,66517,66560,66717,66720,66729,66736,66771,66776,66811,66816,66855,66864,66915,67072,67382,67392,67413,67424,67431,67584,67589,67592,67592,67594,67637,67639,67640,67644,67644,67647,67669,67680,67702,67712,67742,67808,67826,67828,67829,67840,67861,67872,67897,67968,68023,68030,68031,68096,68099,68101,68102,68108,68115,68117,68119,68121,68149,68152,68154,68159,68159,68192,68220,68224,68252,68288,68295,68297,68326,68352,68405,68416,68437,68448,68466,68480,68497,68608,68680,68736,68786,68800,68850,68864,68903,68912,68921,69376,69404,69415,69415,69424,69456,69600,69622,69632,69702,69734,69743,69759,69818,69840,69864,69872,69881,69888,69940,69942,69951,69956,69958,69968,70003,70006,70006,70016,70084,70089,70092,70096,70106,70108,70108,70144,70161,70163,70199,70206,70206,70272,70278,70280,70280,70282,70285,70287,70301,70303,70312,70320,70378,70384,70393,70400,70403,70405,70412,70415,70416,70419,70440,70442,70448,70450,70451,70453,70457,70459,70468,70471,70472,70475,70477,70480,70480,70487,70487,70493,70499,70502,70508,70512,70516,70656,70730,70736,70745,70750,70751,70784,70853,70855,70855,70864,70873,71040,71093,71096,71104,71128,71133,71168,71232,71236,71236,71248,71257,71296,71352,71360,71369,71424,71450,71453,71467,71472,71481,71680,71738,71840,71913,71935,71935,72096,72103,72106,72151,72154,72161,72163,72164,72192,72254,72263,72263,72272,72345,72349,72349,72384,72440,72704,72712,72714,72758,72760,72768,72784,72793,72818,72847,72850,72871,72873,72886,72960,72966,72968,72969,72971,73014,73018,73018,73020,73021,73023,73031,73040,73049,73056,73061,73063,73064,73066,73102,73104,73105,73107,73112,73120,73129,73440,73462,73728,74649,74752,74862,74880,75075,77824,78894,82944,83526,92160,92728,92736,92766,92768,92777,92880,92909,92912,92916,92928,92982,92992,92995,93008,93017,93027,93047,93053,93071,93760,93823,93952,94026,94031,94087,94095,94111,94176,94177,94179,94179,94208,100343,100352,101106,110592,110878,110928,110930,110948,110951,110960,111355,113664,113770,113776,113788,113792,113800,113808,113817,113821,113822,119141,119145,119149,119154,119163,119170,119173,119179,119210,119213,119362,119364,119808,119892,119894,119964,119966,119967,119970,119970,119973,119974,119977,119980,119982,119993,119995,119995,119997,120003,120005,120069,120071,120074,120077,120084,120086,120092,120094,120121,120123,120126,120128,120132,120134,120134,120138,120144,120146,120485,120488,120512,120514,120538,120540,120570,120572,120596,120598,120628,120630,120654,120656,120686,120688,120712,120714,120744,120746,120770,120772,120779,120782,120831,121344,121398,121403,121452,121461,121461,121476,121476,121499,121503,121505,121519,122880,122886,122888,122904,122907,122913,122915,122916,122918,122922,123136,123180,123184,123197,123200,123209,123214,123214,123584,123641,124928,125124,125136,125142,125184,125259,125264,125273,126464,126467,126469,126495,126497,126498,126500,126500,126503,126503,126505,126514,126516,126519,126521,126521,126523,126523,126530,126530,126535,126535,126537,126537,126539,126539,126541,126543,126545,126546,126548,126548,126551,126551,126553,126553,126555,126555,126557,126557,126559,126559,126561,126562,126564,126564,126567,126570,126572,126578,126580,126583,126585,126588,126590,126590,126592,126601,126603,126619,126625,126627,126629,126633,126635,126651,131072,173782,173824,177972,177984,178205,178208,183969,183984,191456,194560,195101,917760,917999],m=/^\s*\/\/\/?\s*@(ts-expect-error|ts-ignore)/,_=/^\s*(?:\/|\*)*\s*@(ts-expect-error|ts-ignore)/;function g(e,n){if(e<n[0])return!1;var t,r=0,a=n.length;while(r+1<a){if(t=r+(a-r)/2,t-=t%2,n[t]<=e&&e<=n[t+1])return!0;e<n[t]?a=t:r=t+2}return!1}function y(e,n){return g(e,n>=2?p:1===n?u:c)}function h(e,n){return g(e,n>=2?f:1===n?d:l)}function v(e){var n=[];return e.forEach((function(e,t){n[e]=t})),n}e.isUnicodeIdentifierStart=y;var b=v(s);function E(e){return b[e]}function T(e){return s.get(e)}function S(e){var n=new Array,t=0,r=0;while(t<e.length){var a=e.charCodeAt(t);switch(t++,a){case 13:10===e.charCodeAt(t)&&t++;case 10:n.push(r),r=t;break;default:a>127&&O(a)&&(n.push(r),r=t);break}}return n.push(r),n}function x(e,n,t,r){return e.getPositionOfLineAndCharacter?e.getPositionOfLineAndCharacter(n,t,r):L(D(e),n,t,e.text,r)}function L(n,t,r,a,i){(t<0||t>=n.length)&&(i?t=t<0?0:t>=n.length?n.length-1:t:e.Debug.fail("Bad line number. Line: "+t+", lineStarts.length: "+n.length+" , line map is correct? "+(void 0!==a?e.arraysEqual(n,S(a)):"unknown")));var o=n[t]+r;return i?o>n[t+1]?n[t+1]:"string"===typeof a&&o>a.length?a.length:o:(t<n.length-1?e.Debug.assert(o<n[t+1]):void 0!==a&&e.Debug.assert(o<=a.length),o)}function D(e){return e.lineMap||(e.lineMap=S(e.text))}function A(e,n){var t=C(e,n);return{line:t,character:n-e[t]}}function C(n,t,r){var a=e.binarySearch(n,t,e.identity,e.compareValues,r);return a<0&&(a=~a-1,e.Debug.assert(-1!==a,"position cannot precede the beginning of the file")),a}function I(e,n,t){if(n===t)return 0;var r=D(e),a=Math.min(n,t),i=a===t,o=i?n:t,s=C(r,a),c=C(r,o,s);return i?s-c:c-s}function N(e,n){return A(D(e),n)}function k(e){return R(e)||O(e)}function R(e){return 32===e||9===e||11===e||12===e||160===e||133===e||5760===e||e>=8192&&e<=8203||8239===e||8287===e||12288===e||65279===e}function O(e){return 10===e||13===e||8232===e||8233===e}function w(e){return e>=48&&e<=57}function P(e){return w(e)||e>=65&&e<=70||e>=97&&e<=102}function M(e){return e<=1114111}function F(e){return e>=48&&e<=55}function G(e,n){var t=e.charCodeAt(n);switch(t){case 13:case 10:case 9:case 11:case 12:case 32:case 47:case 60:case 124:case 61:case 62:return!0;case 35:return 0===n;default:return t>127}}function B(n,t,r,a,i){if(e.positionIsSynthesized(t))return t;var o=!1;while(1){var s=n.charCodeAt(t);switch(s){case 13:10===n.charCodeAt(t+1)&&t++;case 10:if(t++,r)return t;o=!!i;continue;case 9:case 11:case 12:case 32:t++;continue;case 47:if(a)break;if(47===n.charCodeAt(t+1)){t+=2;while(t<n.length){if(O(n.charCodeAt(t)))break;t++}o=!1;continue}if(42===n.charCodeAt(t+1)){t+=2;while(t<n.length){if(42===n.charCodeAt(t)&&47===n.charCodeAt(t+1)){t+=2;break}t++}o=!1;continue}break;case 60:case 124:case 61:case 62:if(V(n,t)){t=j(n,t),o=!1;continue}break;case 35:if(0===t&&H(n,t)){t=W(n,t),o=!1;continue}break;case 42:if(o){t++,o=!1;continue}break;default:if(s>127&&k(s)){t++;continue}break}return t}}e.tokenToString=E,e.stringToToken=T,e.computeLineStarts=S,e.getPositionOfLineAndCharacter=x,e.computePositionOfLineAndCharacter=L,e.getLineStarts=D,e.computeLineAndCharacterOfPosition=A,e.computeLineOfPosition=C,e.getLinesBetweenPositions=I,e.getLineAndCharacterOfPosition=N,e.isWhiteSpaceLike=k,e.isWhiteSpaceSingleLine=R,e.isLineBreak=O,e.isOctalDigit=F,e.couldStartTrivia=G,e.skipTrivia=B;var U="<<<<<<<".length;function V(n,t){if(e.Debug.assert(t>=0),0===t||O(n.charCodeAt(t-1))){var r=n.charCodeAt(t);if(t+U<n.length){for(var a=0;a<U;a++)if(n.charCodeAt(t+a)!==r)return!1;return 61===r||32===n.charCodeAt(t+U)}}return!1}function j(n,t,r){r&&r(e.Diagnostics.Merge_conflict_marker_encountered,t,U);var a=n.charCodeAt(t),i=n.length;if(60===a||62===a)while(t<i&&!O(n.charCodeAt(t)))t++;else{e.Debug.assert(124===a||61===a);while(t<i){var o=n.charCodeAt(t);if((61===o||62===o)&&o!==a&&V(n,t))break;t++}}return t}var K=/^#!.*/;function H(n,t){return e.Debug.assert(0===t),K.test(n)}function W(e,n){var t=K.exec(e)[0];return n+=t.length,n}function z(e,n,t,r,a,i,o){var s,c,l,u,d=!1,p=r,f=o;if(0===t){p=!0;var m=ee(n);m&&(t=m.length)}e:while(t>=0&&t<n.length){var _=n.charCodeAt(t);switch(_){case 13:10===n.charCodeAt(t+1)&&t++;case 10:if(t++,r)break e;p=!0,d&&(u=!0);continue;case 9:case 11:case 12:case 32:t++;continue;case 47:var g=n.charCodeAt(t+1),y=!1;if(47===g||42===g){var h=47===g?2:3,v=t;if(t+=2,47===g)while(t<n.length){if(O(n.charCodeAt(t))){y=!0;break}t++}else while(t<n.length){if(42===n.charCodeAt(t)&&47===n.charCodeAt(t+1)){t+=2;break}t++}if(p){if(d&&(f=a(s,c,l,u,i,f),!e&&f))return f;s=v,c=t,l=h,u=y,d=!0}continue}break e;default:if(_>127&&k(_)){d&&O(_)&&(u=!0),t++;continue}break e}}return d&&(f=a(s,c,l,u,i,f)),f}function q(e,n,t,r){return z(!1,e,n,!1,t,r)}function J(e,n,t,r){return z(!1,e,n,!0,t,r)}function X(e,n,t,r,a){return z(!0,e,n,!1,t,r,a)}function Y(e,n,t,r,a){return z(!0,e,n,!0,t,r,a)}function Q(e,n,t,r,a,i){return i||(i=[]),i.push({kind:t,pos:e,end:n,hasTrailingNewLine:r}),i}function Z(e,n){return X(e,n,Q,void 0,void 0)}function $(e,n){return Y(e,n,Q,void 0,void 0)}function ee(e){var n=K.exec(e);if(n)return n[0]}function ne(e,n){return e>=65&&e<=90||e>=97&&e<=122||36===e||95===e||e>127&&y(e,n)}function te(e,n,t){return e>=65&&e<=90||e>=97&&e<=122||e>=48&&e<=57||36===e||95===e||1===t&&(45===e||58===e)||e>127&&h(e,n)}function re(e,n,t){var r=ie(e,0);if(!ne(r,n))return!1;for(var a=oe(r);a<e.length;a+=oe(r))if(!te(r=ie(e,a),n,t))return!1;return!0}function ae(n,r,a,o,s,c,l){void 0===a&&(a=0);var u,d,p,f,g,y,h,v,b=o,E=0;Ce(b,c,l);var T={getStartPos:function(){return p},getTextPos:function(){return u},getToken:function(){return g},getTokenPos:function(){return f},getTokenText:function(){return b.substring(f,u)},getTokenValue:function(){return y},hasUnicodeEscape:function(){return 0!==(1024&h)},hasExtendedUnicodeEscape:function(){return 0!==(8&h)},hasPrecedingLineBreak:function(){return 0!==(1&h)},hasPrecedingJSDocComment:function(){return 0!==(2&h)},isIdentifier:function(){return 78===g||g>115},isReservedWord:function(){return g>=80&&g<=115},isUnterminated:function(){return 0!==(4&h)},getCommentDirectives:function(){return v},getNumericLiteralFlags:function(){return 1008&h},getTokenFlags:function(){return h},reScanGreaterToken:ae,reScanAsteriskEqualsToken:se,reScanSlashToken:ce,reScanTemplateToken:pe,reScanTemplateHeadOrNoSubstitutionTemplate:fe,scanJsxIdentifier:he,scanJsxAttributeValue:ve,reScanJsxAttributeValue:be,reScanJsxToken:me,reScanLessThanToken:_e,reScanQuestionToken:ge,reScanInvalidIdentifier:ee,scanJsxToken:ye,scanJsDocToken:Ee,scan:$,getText:De,clearCommentDirectives:Ae,setText:Ce,setScriptTarget:Ne,setLanguageVariant:ke,setOnError:Ie,setTextPos:Re,setInJSDocType:Oe,tryScan:Le,lookAhead:xe,scanRange:Se};return e.Debug.isDebugging&&Object.defineProperty(T,"__debugShowCurrentPositionInText",{get:function(){var e=T.getText();return e.slice(0,T.getStartPos())+"║"+e.slice(T.getStartPos())}}),T;function S(e,n,t){if(void 0===n&&(n=u),s){var r=u;u=n,s(e,t||0),u=r}}function x(){var n=u,t=!1,r=!1,a="";while(1){var i=b.charCodeAt(u);if(95!==i){if(!w(i))break;t=!0,r=!1,u++}else h|=512,t?(t=!1,r=!0,a+=b.substring(n,u)):S(r?e.Diagnostics.Multiple_consecutive_numeric_separators_are_not_permitted:e.Diagnostics.Numeric_separators_are_not_allowed_here,u,1),u++,n=u}return 95===b.charCodeAt(u-1)&&S(e.Diagnostics.Numeric_separators_are_not_allowed_here,u-1,1),a+b.substring(n,u)}function L(){var n,t,r=u,a=x();46===b.charCodeAt(u)&&(u++,n=x());var i,o=u;if(69===b.charCodeAt(u)||101===b.charCodeAt(u)){u++,h|=16,43!==b.charCodeAt(u)&&45!==b.charCodeAt(u)||u++;var s=u,c=x();c?(t=b.substring(o,s)+c,o=u):S(e.Diagnostics.Digit_expected)}if(512&h?(i=a,n&&(i+="."+n),t&&(i+=t)):i=b.substring(r,o),void 0!==n||16&h)return D(r,void 0===n&&!!(16&h)),{type:8,value:""+ +i};y=i;var l=Z();return D(r),{type:l,value:y}}function D(t,r){if(ne(ie(b,u),n)){var a=u,i=X().length;1===i&&"n"===b[a]?S(r?e.Diagnostics.A_bigint_literal_cannot_use_exponential_notation:e.Diagnostics.A_bigint_literal_must_be_an_integer,t,a-t+1):(S(e.Diagnostics.An_identifier_or_keyword_cannot_immediately_follow_a_numeric_literal,a,i),u=a)}}function A(){var e=u;while(F(b.charCodeAt(u)))u++;return+b.substring(e,u)}function C(e,n){var t=N(e,!1,n);return t?parseInt(t,16):-1}function I(e,n){return N(e,!0,n)}function N(n,t,r){var a=[],i=!1,o=!1;while(a.length<n||t){var s=b.charCodeAt(u);if(r&&95===s)h|=512,i?(i=!1,o=!0):S(o?e.Diagnostics.Multiple_consecutive_numeric_separators_are_not_permitted:e.Diagnostics.Numeric_separators_are_not_allowed_here,u,1),u++;else{if(i=r,s>=65&&s<=70)s+=32;else if(!(s>=48&&s<=57||s>=97&&s<=102))break;a.push(s),u++,o=!1}}return a.length<n&&(a=[]),95===b.charCodeAt(u-1)&&S(e.Diagnostics.Numeric_separators_are_not_allowed_here,u-1,1),String.fromCharCode.apply(String,a)}function G(n){void 0===n&&(n=!1);var t=b.charCodeAt(u);u++;var r="",a=u;while(1){if(u>=d){r+=b.substring(a,u),h|=4,S(e.Diagnostics.Unterminated_string_literal);break}var i=b.charCodeAt(u);if(i===t){r+=b.substring(a,u),u++;break}if(92!==i||n){if(O(i)&&!n){r+=b.substring(a,u),h|=4,S(e.Diagnostics.Unterminated_string_literal);break}u++}else r+=b.substring(a,u),r+=U(),a=u}return r}function B(n){var t=96===b.charCodeAt(u);u++;var r,a=u,i="";while(1){if(u>=d){i+=b.substring(a,u),h|=4,S(e.Diagnostics.Unterminated_template_literal),r=t?14:17;break}var o=b.charCodeAt(u);if(96===o){i+=b.substring(a,u),u++,r=t?14:17;break}if(36===o&&u+1<d&&123===b.charCodeAt(u+1)){i+=b.substring(a,u),u+=2,r=t?15:16;break}92!==o?13!==o?u++:(i+=b.substring(a,u),u++,u<d&&10===b.charCodeAt(u)&&u++,i+="\n",a=u):(i+=b.substring(a,u),i+=U(n),a=u)}return e.Debug.assert(void 0!==r),y=i,r}function U(n){var t=u;if(u++,u>=d)return S(e.Diagnostics.Unexpected_end_of_text),"";var r=b.charCodeAt(u);switch(u++,r){case 48:return n&&u<d&&w(b.charCodeAt(u))?(u++,h|=2048,b.substring(t,u)):"\0";case 98:return"\b";case 116:return"\t";case 110:return"\n";case 118:return"\v";case 102:return"\f";case 114:return"\r";case 39:return"'";case 34:return'"';case 117:if(n)for(var a=u;a<u+4;a++)if(a<d&&!P(b.charCodeAt(a))&&123!==b.charCodeAt(a))return u=a,h|=2048,b.substring(t,u);if(u<d&&123===b.charCodeAt(u)){if(u++,n&&!P(b.charCodeAt(u)))return h|=2048,b.substring(t,u);if(n){var i=u,o=I(1,!1),s=o?parseInt(o,16):-1;if(!M(s)||125!==b.charCodeAt(u))return h|=2048,b.substring(t,u);u=i}return h|=8,z()}return h|=1024,K(4);case 120:if(n){if(!P(b.charCodeAt(u)))return h|=2048,b.substring(t,u);if(!P(b.charCodeAt(u+1)))return u++,h|=2048,b.substring(t,u)}return K(2);case 13:u<d&&10===b.charCodeAt(u)&&u++;case 10:case 8232:case 8233:return"";default:return String.fromCharCode(r)}}function K(n){var t=C(n,!1);return t>=0?String.fromCharCode(t):(S(e.Diagnostics.Hexadecimal_digit_expected),"")}function z(){var n=I(1,!1),t=n?parseInt(n,16):-1,r=!1;return t<0?(S(e.Diagnostics.Hexadecimal_digit_expected),r=!0):t>1114111&&(S(e.Diagnostics.An_extended_Unicode_escape_value_must_be_between_0x0_and_0x10FFFF_inclusive),r=!0),u>=d?(S(e.Diagnostics.Unexpected_end_of_text),r=!0):125===b.charCodeAt(u)?u++:(S(e.Diagnostics.Unterminated_Unicode_escape_sequence),r=!0),r?"":le(t)}function q(){if(u+5<d&&117===b.charCodeAt(u+1)){var e=u;u+=2;var n=C(4,!1);return u=e,n}return-1}function J(){if(n>=2&&117===ie(b,u+1)&&123===ie(b,u+2)){var e=u;u+=3;var t=I(1,!1),r=t?parseInt(t,16):-1;return u=e,r}return-1}function X(){var e="",t=u;while(u<d){var r=ie(b,u);if(te(r,n))u+=oe(r);else{if(92!==r)break;if(r=J(),r>=0&&te(r,n)){u+=3,h|=8,e+=z(),t=u;continue}if(r=q(),!(r>=0&&te(r,n)))break;h|=1024,e+=b.substring(t,u),e+=le(r),u+=6,t=u}}return e+=b.substring(t,u),e}function Y(){var e=y.length;if(e>=2&&e<=12){var n=y.charCodeAt(0);if(n>=97&&n<=122){var t=i.get(y);if(void 0!==t)return g=t}}return g=78}function Q(n){var t="",r=!1,a=!1;while(1){var i=b.charCodeAt(u);if(95!==i){if(r=!0,!w(i)||i-48>=n)break;t+=b[u],u++,a=!1}else h|=512,r?(r=!1,a=!0):S(a?e.Diagnostics.Multiple_consecutive_numeric_separators_are_not_permitted:e.Diagnostics.Numeric_separators_are_not_allowed_here,u,1),u++}return 95===b.charCodeAt(u-1)&&S(e.Diagnostics.Numeric_separators_are_not_allowed_here,u-1,1),t}function Z(){if(110===b.charCodeAt(u))return y+="n",384&h&&(y=e.parsePseudoBigInt(y)+"n"),u++,9;var n=128&h?parseInt(y.slice(2),2):256&h?parseInt(y.slice(2),8):+y;return y=""+n,8}function $(){var t;p=u,h=0;var i=!1;while(1){if(f=u,u>=d)return g=1;var o=ie(b,u);if(35===o&&0===u&&H(b,u)){if(u=W(b,u),r)continue;return g=6}switch(o){case 10:case 13:if(h|=1,r){u++;continue}return 13===o&&u+1<d&&10===b.charCodeAt(u+1)?u+=2:u++,g=4;case 9:case 11:case 12:case 32:case 160:case 5760:case 8192:case 8193:case 8194:case 8195:case 8196:case 8197:case 8198:case 8199:case 8200:case 8201:case 8202:case 8203:case 8239:case 8287:case 12288:case 65279:if(r){u++;continue}while(u<d&&R(b.charCodeAt(u)))u++;return g=5;case 33:return 61===b.charCodeAt(u+1)?61===b.charCodeAt(u+2)?(u+=3,g=37):(u+=2,g=35):(u++,g=53);case 34:case 39:return y=G(),g=10;case 96:return g=B(!1);case 37:return 61===b.charCodeAt(u+1)?(u+=2,g=68):(u++,g=44);case 38:return 38===b.charCodeAt(u+1)?61===b.charCodeAt(u+2)?(u+=3,g=75):(u+=2,g=55):61===b.charCodeAt(u+1)?(u+=2,g=72):(u++,g=50);case 40:return u++,g=20;case 41:return u++,g=21;case 42:if(61===b.charCodeAt(u+1))return u+=2,g=65;if(42===b.charCodeAt(u+1))return 61===b.charCodeAt(u+2)?(u+=3,g=66):(u+=2,g=42);if(u++,E&&!i&&1&h){i=!0;continue}return g=41;case 43:return 43===b.charCodeAt(u+1)?(u+=2,g=45):61===b.charCodeAt(u+1)?(u+=2,g=63):(u++,g=39);case 44:return u++,g=27;case 45:return 45===b.charCodeAt(u+1)?(u+=2,g=46):61===b.charCodeAt(u+1)?(u+=2,g=64):(u++,g=40);case 46:return w(b.charCodeAt(u+1))?(y=L().value,g=8):46===b.charCodeAt(u+1)&&46===b.charCodeAt(u+2)?(u+=3,g=25):(u++,g=24);case 47:if(47===b.charCodeAt(u+1)){u+=2;while(u<d){if(O(b.charCodeAt(u)))break;u++}if(v=ue(v,b.slice(f,u),m,f),r)continue;return g=2}if(42===b.charCodeAt(u+1)){u+=2,42===b.charCodeAt(u)&&47!==b.charCodeAt(u+1)&&(h|=2);var s=!1,c=f;while(u<d){var l=b.charCodeAt(u);if(42===l&&47===b.charCodeAt(u+1)){u+=2,s=!0;break}u++,O(l)&&(c=u,h|=1)}if(v=ue(v,b.slice(c,u),_,c),s||S(e.Diagnostics.Asterisk_Slash_expected),r)continue;return s||(h|=4),g=3}return 61===b.charCodeAt(u+1)?(u+=2,g=67):(u++,g=43);case 48:if(u+2<d&&(88===b.charCodeAt(u+1)||120===b.charCodeAt(u+1)))return u+=2,y=I(1,!0),y||(S(e.Diagnostics.Hexadecimal_digit_expected),y="0"),y="0x"+y,h|=64,g=Z();if(u+2<d&&(66===b.charCodeAt(u+1)||98===b.charCodeAt(u+1)))return u+=2,y=Q(2),y||(S(e.Diagnostics.Binary_digit_expected),y="0"),y="0b"+y,h|=128,g=Z();if(u+2<d&&(79===b.charCodeAt(u+1)||111===b.charCodeAt(u+1)))return u+=2,y=Q(8),y||(S(e.Diagnostics.Octal_digit_expected),y="0"),y="0o"+y,h|=256,g=Z();if(u+1<d&&F(b.charCodeAt(u+1)))return y=""+A(),h|=32,g=8;case 49:case 50:case 51:case 52:case 53:case 54:case 55:case 56:case 57:return t=L(),g=t.type,y=t.value,g;case 58:return u++,g=58;case 59:return u++,g=26;case 60:if(V(b,u)){if(u=j(b,u,S),r)continue;return g=7}return 60===b.charCodeAt(u+1)?61===b.charCodeAt(u+2)?(u+=3,g=69):(u+=2,g=47):61===b.charCodeAt(u+1)?(u+=2,g=32):1===a&&47===b.charCodeAt(u+1)&&42!==b.charCodeAt(u+2)?(u+=2,g=30):(u++,g=29);case 61:if(V(b,u)){if(u=j(b,u,S),r)continue;return g=7}return 61===b.charCodeAt(u+1)?61===b.charCodeAt(u+2)?(u+=3,g=36):(u+=2,g=34):62===b.charCodeAt(u+1)?(u+=2,g=38):(u++,g=62);case 62:if(V(b,u)){if(u=j(b,u,S),r)continue;return g=7}return u++,g=31;case 63:return 46!==b.charCodeAt(u+1)||w(b.charCodeAt(u+2))?63===b.charCodeAt(u+1)?61===b.charCodeAt(u+2)?(u+=3,g=76):(u+=2,g=60):(u++,g=57):(u+=2,g=28);case 91:return u++,g=22;case 93:return u++,g=23;case 94:return 61===b.charCodeAt(u+1)?(u+=2,g=77):(u++,g=52);case 123:return u++,g=18;case 124:if(V(b,u)){if(u=j(b,u,S),r)continue;return g=7}return 124===b.charCodeAt(u+1)?61===b.charCodeAt(u+2)?(u+=3,g=74):(u+=2,g=56):61===b.charCodeAt(u+1)?(u+=2,g=73):(u++,g=51);case 125:return u++,g=19;case 126:return u++,g=54;case 64:return u++,g=59;case 92:var T=J();if(T>=0&&ne(T,n))return u+=3,h|=8,y=z()+X(),g=Y();var x=q();return x>=0&&ne(x,n)?(u+=6,h|=1024,y=String.fromCharCode(x)+X(),g=Y()):(S(e.Diagnostics.Invalid_character),u++,g=0);case 35:if(0!==u&&"!"===b[u+1])return S(e.Diagnostics.can_only_be_used_at_the_start_of_a_file),u++,g=0;if(u++,ne(o=b.charCodeAt(u),n)){u++;while(u<d&&te(o=b.charCodeAt(u),n))u++;y=b.substring(f,u),92===o&&(y+=X())}else y="#",S(e.Diagnostics.Invalid_character);return g=79;default:var D=re(o,n);if(D)return g=D;if(R(o)){u+=oe(o);continue}if(O(o)){h|=1,u+=oe(o);continue}return S(e.Diagnostics.Invalid_character),u+=oe(o),g=0}}}function ee(){e.Debug.assert(0===g,"'reScanInvalidIdentifier' should only be called when the current token is 'SyntaxKind.Unknown'."),u=f=p,h=0;var n=ie(b,u),t=re(n,99);return t?g=t:(u+=oe(n),g)}function re(e,n){var t=e;if(ne(t,n)){u+=oe(t);while(u<d&&te(t=ie(b,u),n))u+=oe(t);return y=b.substring(f,u),92===t&&(y+=X()),Y()}}function ae(){if(31===g){if(62===b.charCodeAt(u))return 62===b.charCodeAt(u+1)?61===b.charCodeAt(u+2)?(u+=3,g=71):(u+=2,g=49):61===b.charCodeAt(u+1)?(u+=2,g=70):(u++,g=48);if(61===b.charCodeAt(u))return u++,g=33}return g}function se(){return e.Debug.assert(65===g,"'reScanAsteriskEqualsToken' should only be called on a '*='"),u=f+1,g=62}function ce(){if(43===g||67===g){var t=f+1,r=!1,a=!1;while(1){if(t>=d){h|=4,S(e.Diagnostics.Unterminated_regular_expression_literal);break}var i=b.charCodeAt(t);if(O(i)){h|=4,S(e.Diagnostics.Unterminated_regular_expression_literal);break}if(r)r=!1;else{if(47===i&&!a){t++;break}91===i?a=!0:92===i?r=!0:93===i&&(a=!1)}t++}while(t<d&&te(b.charCodeAt(t),n))t++;u=t,y=b.substring(f,u),g=13}return g}function ue(n,t,r,a){var i=de(t,r);return void 0===i?n:e.append(n,{range:{pos:a,end:u},type:i})}function de(e,n){var t=n.exec(e);if(t)switch(t[1]){case"ts-expect-error":return 0;case"ts-ignore":return 1}}function pe(n){return e.Debug.assert(19===g,"'reScanTemplateToken' should only be called on a '}'"),u=f,g=B(n)}function fe(){return u=f,g=B(!0)}function me(e){return void 0===e&&(e=!0),u=f=p,g=ye(e)}function _e(){return 47===g?(u=f+1,g=29):g}function ge(){return e.Debug.assert(60===g,"'reScanQuestionToken' should only be called on a '??'"),u=f+1,g=57}function ye(n){if(void 0===n&&(n=!0),p=f=u,u>=d)return g=1;var t=b.charCodeAt(u);if(60===t)return 47===b.charCodeAt(u+1)?(u+=2,g=30):(u++,g=29);if(123===t)return u++,g=18;var r=0;while(u<d){if(t=b.charCodeAt(u),123===t)break;if(60===t){if(V(b,u))return u=j(b,u,S),g=7;break}if(62===t&&S(e.Diagnostics.Unexpected_token_Did_you_mean_or_gt,u,1),125===t&&S(e.Diagnostics.Unexpected_token_Did_you_mean_or_rbrace,u,1),O(t)&&0===r)r=-1;else{if(!n&&O(t)&&r>0)break;k(t)||(r=u)}u++}return y=b.substring(p,u),-1===r?12:11}function he(){if(t(g)){var e=!1;while(u<d){var n=b.charCodeAt(u);if(45!==n)if(58!==n||e){var r=u;if(y+=X(),u===r)break}else y+=":",u++,e=!0,g=78;else y+="-",u++}":"===y.slice(-1)&&(y=y.slice(0,-1),u--)}return g}function ve(){switch(p=u,b.charCodeAt(u)){case 34:case 39:return y=G(!0),g=10;default:return $()}}function be(){return u=f=p,ve()}function Ee(){if(p=f=u,h=0,u>=d)return g=1;var e=ie(b,u);switch(u+=oe(e),e){case 9:case 11:case 12:case 32:while(u<d&&R(b.charCodeAt(u)))u++;return g=5;case 64:return g=59;case 13:10===b.charCodeAt(u)&&u++;case 10:return h|=1,g=4;case 42:return g=41;case 123:return g=18;case 125:return g=19;case 91:return g=22;case 93:return g=23;case 60:return g=29;case 62:return g=31;case 61:return g=62;case 44:return g=27;case 46:return g=24;case 96:return g=61;case 92:u--;var t=J();if(t>=0&&ne(t,n))return u+=3,h|=8,y=z()+X(),g=Y();var r=q();return r>=0&&ne(r,n)?(u+=6,h|=1024,y=String.fromCharCode(r)+X(),g=Y()):(u++,g=0)}if(ne(e,n)){var a=e;while(u<d&&te(a=ie(b,u),n)||45===b.charCodeAt(u))u+=oe(a);return y=b.substring(f,u),92===a&&(y+=X()),g=Y()}return g=0}function Te(e,n){var t=u,r=p,a=f,i=g,o=y,s=h,c=e();return c&&!n||(u=t,p=r,f=a,g=i,y=o,h=s),c}function Se(e,n,t){var r=d,a=u,i=p,o=f,s=g,c=y,l=h,m=v;Ce(b,e,n);var _=t();return d=r,u=a,p=i,f=o,g=s,y=c,h=l,v=m,_}function xe(e){return Te(e,!0)}function Le(e){return Te(e,!1)}function De(){return b}function Ae(){v=void 0}function Ce(e,n,t){b=e||"",d=void 0===t?b.length:n+t,Re(n||0)}function Ie(e){s=e}function Ne(e){n=e}function ke(e){a=e}function Re(n){e.Debug.assert(n>=0),u=n,p=n,f=n,g=0,y=void 0,h=0}function Oe(e){E+=e?1:-1}}e.isShebangTrivia=H,e.scanShebangTrivia=W,e.forEachLeadingCommentRange=q,e.forEachTrailingCommentRange=J,e.reduceEachLeadingCommentRange=X,e.reduceEachTrailingCommentRange=Y,e.getLeadingCommentRanges=Z,e.getTrailingCommentRanges=$,e.getShebang=ee,e.isIdentifierStart=ne,e.isIdentifierPart=te,e.isIdentifierText=re,e.createScanner=ae;var ie=String.prototype.codePointAt?function(e,n){return e.codePointAt(n)}:function(e,n){var t=e.length;if(!(n<0||n>=t)){var r=e.charCodeAt(n);if(r>=55296&&r<=56319&&t>n+1){var a=e.charCodeAt(n+1);if(a>=56320&&a<=57343)return 1024*(r-55296)+a-56320+65536}return r}};function oe(e){return e>=65536?2:1}function se(n){if(e.Debug.assert(0<=n&&n<=1114111),n<=65535)return String.fromCharCode(n);var t=Math.floor((n-65536)/1024)+55296,r=(n-65536)%1024+56320;return String.fromCharCode(t,r)}var ce=String.fromCodePoint?function(e){return String.fromCodePoint(e)}:se;function le(e){return ce(e)}e.utf16EncodeAsString=le}(d||(d={})),function(e){function n(n){return e.pathIsRelative(n)||e.isRootedDiskPath(n)}function t(n){return e.sortAndDeduplicate(n,e.compareDiagnostics)}function r(e){switch(e.target){case 99:return"lib.esnext.full.d.ts";case 8:return"lib.es2021.full.d.ts";case 7:return"lib.es2020.full.d.ts";case 6:return"lib.es2019.full.d.ts";case 5:return"lib.es2018.full.d.ts";case 4:return"lib.es2017.full.d.ts";case 3:return"lib.es2016.full.d.ts";case 2:return"lib.es6.d.ts";default:return"lib.d.ts"}}function a(e){return e.start+e.length}function i(e){return 0===e.length}function o(e,n){return n>=e.start&&n<a(e)}function s(e,n){return n>=e.pos&&n<=e.end}function c(e,n){return n.start>=e.start&&a(n)<=a(e)}function l(e,n){return void 0!==u(e,n)}function u(e,n){var t=_(e,n);return t&&0===t.length?void 0:t}function d(e,n){return f(e.start,e.length,n.start,n.length)}function p(e,n,t){return f(e.start,e.length,n,t)}function f(e,n,t,r){var a=e+n,i=t+r;return t<=a&&i>=e}function m(e,n){return n<=a(e)&&n>=e.start}function _(e,n){var t=Math.max(e.start,n.start),r=Math.min(a(e),a(n));return t<=r?y(t,r):void 0}function g(e,n){if(e<0)throw new Error("start < 0");if(n<0)throw new Error("length < 0");return{start:e,length:n}}function y(e,n){return g(e,n-e)}function h(e){return g(e.span.start,e.newLength)}function v(e){return i(e.span)&&0===e.newLength}function b(e,n){if(n<0)throw new Error("newLength < 0");return{span:e,newLength:n}}function E(n){if(0===n.length)return e.unchangedTextChangeRange;if(1===n.length)return n[0];for(var t=n[0],r=t.span.start,i=a(t.span),o=r+t.newLength,s=1;s<n.length;s++){var c=n[s],l=r,u=i,d=o,p=c.span.start,f=a(c.span),m=p+c.newLength;r=Math.min(l,p),i=Math.max(u,u+(f-d)),o=Math.max(m,m+(d-f))}return b(y(r,i),o-r)}function T(e){if(e&&160===e.kind)for(var n=e;n;n=n.parent)if(vn(n)||Ln(n)||254===n.kind)return n}function S(n,t){return e.hasSyntacticModifier(n,16476)&&167===t.kind}function x(n){return!!On(n)&&e.every(n.elements,L)}function L(n){return!!e.isOmittedExpression(n)||x(n.name)}function D(n){var t=n.parent;while(e.isBindingElement(t.parent))t=t.parent.parent;return t.parent}function A(n,t){e.isBindingElement(n)&&(n=D(n));var r=t(n);return 250===n.kind&&(n=n.parent),n&&251===n.kind&&(r|=t(n),n=n.parent),n&&233===n.kind&&(r|=t(n)),r}function C(n){return A(n,e.getEffectiveModifierFlags)}function I(n){return A(n,e.getEffectiveModifierFlagsAlwaysIncludeJSDoc)}function N(e){return A(e,(function(e){return e.flags}))}function k(n,t,r){var a=n.toLowerCase(),i=/^([a-z]+)([_\-]([a-z]+))?$/.exec(a);if(i){var o=i[1],s=i[3];e.contains(e.supportedLocaleDirectories,a)&&!c(o,s,r)&&c(o,void 0,r),e.setUILocale(n)}else r&&r.push(e.createCompilerDiagnostic(e.Diagnostics.Locale_must_be_of_the_form_language_or_language_territory_For_example_0_or_1,"en","ja-jp"));function c(n,r,a){var i=e.normalizePath(t.getExecutingFilePath()),o=e.getDirectoryPath(i),s=e.combinePaths(o,n);if(r&&(s=s+"-"+r),s=t.resolvePath(e.combinePaths(s,"diagnosticMessages.generated.json")),!t.fileExists(s))return!1;var c="";try{c=t.readFile(s)}catch(l){return a&&a.push(e.createCompilerDiagnostic(e.Diagnostics.Unable_to_open_file_0,s)),!1}try{e.setLocalizedDiagnosticMessages(JSON.parse(c))}catch(u){return a&&a.push(e.createCompilerDiagnostic(e.Diagnostics.Corrupted_locale_file_0,s)),!1}return!0}}function R(e,n){if(e)while(void 0!==e.original)e=e.original;return!n||n(e)?e:void 0}function O(e,n){while(e){var t=n(e);if("quit"===t)return;if(t)return e;e=e.parent}}function w(e){return 0===(8&e.flags)}function P(e,n){if(void 0===e||w(e))return e;e=e.original;while(e){if(w(e))return!n||n(e)?e:void 0;e=e.original}}function M(e){return e.length>=2&&95===e.charCodeAt(0)&&95===e.charCodeAt(1)?"_"+e:e}function F(e){var n=e;return n.length>=3&&95===n.charCodeAt(0)&&95===n.charCodeAt(1)&&95===n.charCodeAt(2)?n.substr(1):n}function G(e){return F(e.escapedText)}function B(e){return e.valueDeclaration&&un(e.valueDeclaration)?G(e.valueDeclaration.name):F(e.escapedName)}function U(n){var t=n.parent.parent;if(t){if(yt(t))return V(t);switch(t.kind){case 233:if(t.declarationList&&t.declarationList.declarations[0])return V(t.declarationList.declarations[0]);break;case 234:var r=t.expression;switch(217===r.kind&&62===r.operatorToken.kind&&(r=r.left),r.kind){case 202:return r.name;case 203:var a=r.argumentExpression;if(e.isIdentifier(a))return a}break;case 208:return V(t.expression);case 246:if(yt(t.statement)||Yn(t.statement))return V(t.statement);break}}}function V(n){var t=z(n);return t&&e.isIdentifier(t)?t:void 0}function j(n,t){return!(!H(n)||!e.isIdentifier(n.name)||G(n.name)!==G(t))||!(!e.isVariableStatement(n)||!e.some(n.declarationList.declarations,(function(e){return j(e,t)})))}function K(e){return e.name||U(e)}function H(e){return!!e.name}function W(n){switch(n.kind){case 78:return n;case 337:case 330:var t=n.name;if(158===t.kind)return t.right;break;case 204:case 217:var r=n;switch(e.getAssignmentDeclarationKind(r)){case 1:case 4:case 5:case 3:return e.getElementOrPropertyAccessArgumentExpressionOrName(r.left);case 7:case 8:case 9:return r.arguments[1];default:return}case 335:return K(n);case 329:return U(n);case 267:var a=n.expression;return e.isIdentifier(a)?a:void 0;case 203:var i=n;if(e.isBindableStaticElementAccessExpression(i))return i.argumentExpression}return n.name}function z(n){if(void 0!==n)return W(n)||(e.isFunctionExpression(n)||e.isArrowFunction(n)||e.isClassExpression(n)?q(n):void 0)}function q(n){if(n.parent){if(e.isPropertyAssignment(n.parent)||e.isBindingElement(n.parent))return n.parent.name;if(e.isBinaryExpression(n.parent)&&n===n.parent.right){if(e.isIdentifier(n.parent.left))return n.parent.left;if(e.isAccessExpression(n.parent.left))return e.getElementOrPropertyAccessArgumentExpressionOrName(n.parent.left)}else if(e.isVariableDeclaration(n.parent)&&e.isIdentifier(n.parent.name))return n.parent.name}}function J(n,t){if(n.name){if(e.isIdentifier(n.name)){var r=n.name.escapedText;return Te(n.parent,t).filter((function(n){return e.isJSDocParameterTag(n)&&e.isIdentifier(n.name)&&n.name.escapedText===r}))}var a=n.parent.parameters.indexOf(n);e.Debug.assert(a>-1,"Parameters should always be in their parents' parameter list");var i=Te(n.parent,t).filter(e.isJSDocParameterTag);if(a<i.length)return[i[a]]}return e.emptyArray}function X(e){return J(e,!1)}function Y(e){return J(e,!0)}function Q(n,t){var r=n.name.escapedText;return Te(n.parent,t).filter((function(n){return e.isJSDocTemplateTag(n)&&n.typeParameters.some((function(e){return e.name.escapedText===r}))}))}function Z(e){return Q(e,!1)}function $(e){return Q(e,!0)}function ee(n){return!!Le(n,e.isJSDocParameterTag)}function ne(n){return Le(n,e.isJSDocAugmentsTag)}function te(n){return De(n,e.isJSDocImplementsTag)}function re(n){return Le(n,e.isJSDocClassTag)}function ae(n){return Le(n,e.isJSDocPublicTag)}function ie(n){return Le(n,e.isJSDocPublicTag,!0)}function oe(n){return Le(n,e.isJSDocPrivateTag)}function se(n){return Le(n,e.isJSDocPrivateTag,!0)}function ce(n){return Le(n,e.isJSDocProtectedTag)}function le(n){return Le(n,e.isJSDocProtectedTag,!0)}function ue(n){return Le(n,e.isJSDocReadonlyTag)}function de(n){return Le(n,e.isJSDocReadonlyTag,!0)}function pe(n){return Le(n,e.isJSDocOverrideTag,!0)}function fe(n){return Le(n,e.isJSDocDeprecatedTag)}function me(n){return Le(n,e.isJSDocDeprecatedTag,!0)}function _e(n){return Le(n,e.isJSDocEnumTag)}function ge(n){return Le(n,e.isJSDocThisTag)}function ye(n){return Le(n,e.isJSDocReturnTag)}function he(n){return Le(n,e.isJSDocTemplateTag)}function ve(n){var t=Le(n,e.isJSDocTypeTag);if(t&&t.typeExpression&&t.typeExpression.type)return t}function be(n){var t=Le(n,e.isJSDocTypeTag);return!t&&e.isParameter(n)&&(t=e.find(X(n),(function(e){return!!e.typeExpression}))),t&&t.typeExpression&&t.typeExpression.type}function Ee(n){var t=ye(n);if(t&&t.typeExpression)return t.typeExpression.type;var r=ve(n);if(r&&r.typeExpression){var a=r.typeExpression.type;if(e.isTypeLiteralNode(a)){var i=e.find(a.members,e.isCallSignatureDeclaration);return i&&i.type}if(e.isFunctionTypeNode(a)||e.isJSDocFunctionType(a))return a.type}}function Te(n,t){var r=n.jsDocCache;if(void 0===r||t){var a=e.getJSDocCommentsAndTags(n,t);e.Debug.assert(a.length<2||a[0]!==a[1]),r=e.flatMap(a,(function(n){return e.isJSDoc(n)?n.tags:n})),t||(n.jsDocCache=r)}return r}function Se(e){return Te(e,!1)}function xe(e){return Te(e,!0)}function Le(n,t,r){return e.find(Te(n,r),t)}function De(e,n){return Se(e).filter(n)}function Ae(e,n){return Se(e).filter((function(e){return e.kind===n}))}function Ce(n){return"string"===typeof n?n:null===n||void 0===n?void 0:n.map((function(n){return 313===n.kind?n.text:"{@link "+(n.name?e.entityNameToString(n.name)+" ":"")+n.text+"}"})).join("")}function Ie(n){if(e.isJSDocSignature(n))return e.emptyArray;if(e.isJSDocTypeAlias(n))return e.Debug.assert(312===n.parent.kind),e.flatMap(n.parent.tags,(function(n){return e.isJSDocTemplateTag(n)?n.typeParameters:void 0}));if(n.typeParameters)return n.typeParameters;if(e.isInJSFile(n)){var t=e.getJSDocTypeParameterDeclarations(n);if(t.length)return t;var r=be(n);if(r&&e.isFunctionTypeNode(r)&&r.typeParameters)return r.typeParameters}return e.emptyArray}function Ne(n){return n.constraint?n.constraint:e.isJSDocTemplateTag(n.parent)&&n===n.parent.typeParameters[0]?n.parent.constraint:void 0}function ke(e){return 78===e.kind||79===e.kind}function Re(e){return 169===e.kind||168===e.kind}function Oe(n){return e.isPropertyAccessExpression(n)&&!!(32&n.flags)}function we(n){return e.isElementAccessExpression(n)&&!!(32&n.flags)}function Pe(n){return e.isCallExpression(n)&&!!(32&n.flags)}function Me(e){var n=e.kind;return!!(32&e.flags)&&(202===n||203===n||204===n||226===n)}function Fe(n){return Me(n)&&!e.isNonNullExpression(n)&&!!n.questionDotToken}function Ge(e){return Fe(e.parent)&&e.parent.expression===e}function Be(e){return!Me(e.parent)||Fe(e.parent)||e!==e.parent.expression}function Ue(e){return 217===e.kind&&60===e.operatorToken.kind}function Ve(n){return e.isTypeReferenceNode(n)&&e.isIdentifier(n.typeName)&&"const"===n.typeName.escapedText&&!n.typeArguments}function je(n){return e.skipOuterExpressions(n,8)}function Ke(n){return e.isNonNullExpression(n)&&!!(32&n.flags)}function He(e){return 242===e.kind||241===e.kind}function We(e){return 270===e.kind||269===e.kind}function ze(e){switch(e.kind){case 295:case 296:return!0;default:return!1}}function qe(e){return ze(e)||293===e.kind||297===e.kind}function Je(e){return 337===e.kind||330===e.kind}function Xe(e){return Ye(e.kind)}function Ye(e){return e>=158}function Qe(e){return e>=0&&e<=157}function Ze(e){return Qe(e.kind)}function $e(e){return e.hasOwnProperty("pos")&&e.hasOwnProperty("end")}function en(e){return 8<=e&&e<=14}function nn(e){return en(e.kind)}function tn(e){return 14<=e&&e<=17}function rn(e){return tn(e.kind)}function an(e){var n=e.kind;return 16===n||17===n}function on(n){return e.isImportSpecifier(n)||e.isExportSpecifier(n)}function sn(e){switch(e.kind){case 266:case 271:return e.parent.parent.isTypeOnly;case 264:return e.parent.isTypeOnly;case 263:case 261:return e.isTypeOnly;default:return!1}}function cn(e){return 10===e.kind||tn(e.kind)}function ln(n){return e.isIdentifier(n)&&(7&n.autoGenerateFlags)>0}function un(n){return(e.isPropertyDeclaration(n)||An(n))&&e.isPrivateIdentifier(n.name)}function dn(n){return e.isPropertyAccessExpression(n)&&e.isPrivateIdentifier(n.name)}function pn(e){switch(e){case 125:case 129:case 84:case 133:case 87:case 92:case 122:case 120:case 121:case 142:case 123:case 156:return!0}return!1}function fn(n){return!!(16476&e.modifierToFlag(n))}function mn(e){return fn(e)||123===e||156===e}function _n(e){return pn(e.kind)}function gn(e){var n=e.kind;return 158===n||78===n}function yn(e){var n=e.kind;return 78===n||79===n||10===n||8===n||159===n}function hn(e){var n=e.kind;return 78===n||197===n||198===n}function vn(e){return!!e&&Tn(e.kind)}function bn(e){return e&&En(e.kind)}function En(e){switch(e){case 252:case 166:case 167:case 168:case 169:case 209:case 210:return!0;default:return!1}}function Tn(e){switch(e){case 165:case 170:case 315:case 171:case 172:case 175:case 309:case 176:return!0;default:return En(e)}}function Sn(n){return e.isSourceFile(n)||e.isModuleBlock(n)||e.isBlock(n)&&vn(n.parent)}function xn(e){var n=e.kind;return 167===n||164===n||166===n||168===n||169===n||172===n||230===n}function Ln(e){return e&&(253===e.kind||222===e.kind)}function Dn(e){return e&&(168===e.kind||169===e.kind)}function An(e){switch(e.kind){case 166:case 168:case 169:return!0;default:return!1}}function Cn(e){var n=e.kind;return 171===n||170===n||163===n||165===n||172===n}function In(e){return Cn(e)||xn(e)}function Nn(e){var n=e.kind;return 289===n||290===n||291===n||166===n||168===n||169===n}function kn(n){return e.isTypeNodeKind(n.kind)}function Rn(e){switch(e.kind){case 175:case 176:return!0}return!1}function On(e){if(e){var n=e.kind;return 198===n||197===n}return!1}function wn(e){var n=e.kind;return 200===n||201===n}function Pn(e){var n=e.kind;return 199===n||223===n}function Mn(e){switch(e.kind){case 250:case 161:case 199:return!0}return!1}function Fn(e){return Gn(e)||Bn(e)}function Gn(e){switch(e.kind){case 197:case 201:return!0}return!1}function Bn(e){switch(e.kind){case 198:case 200:return!0}return!1}function Un(e){var n=e.kind;return 202===n||158===n||196===n}function Vn(e){var n=e.kind;return 202===n||158===n}function jn(e){switch(e.kind){case 276:case 275:case 204:case 205:case 206:case 162:return!0;default:return!1}}function Kn(e){return 204===e.kind||205===e.kind}function Hn(e){var n=e.kind;return 219===n||14===n}function Wn(e){return zn(je(e).kind)}function zn(e){switch(e){case 202:case 203:case 205:case 204:case 274:case 275:case 278:case 206:case 200:case 208:case 201:case 222:case 209:case 78:case 13:case 8:case 9:case 10:case 14:case 219:case 94:case 103:case 107:case 109:case 105:case 226:case 227:case 99:return!0;default:return!1}}function qn(e){return Jn(je(e).kind)}function Jn(e){switch(e){case 215:case 216:case 211:case 212:case 213:case 214:case 207:return!0;default:return zn(e)}}function Xn(e){switch(e.kind){case 216:return!0;case 215:return 45===e.operator||46===e.operator;default:return!1}}function Yn(e){return Qn(je(e).kind)}function Qn(e){switch(e){case 218:case 220:case 210:case 217:case 221:case 225:case 223:case 341:case 340:return!0;default:return Jn(e)}}function Zn(e){var n=e.kind;return 207===n||225===n}function $n(n){return e.isNotEmittedStatement(n)||e.isPartiallyEmittedExpression(n)}function et(e,n){switch(e.kind){case 238:case 239:case 240:case 236:case 237:return!0;case 246:return n&&et(e.statement,n)}return!1}function nt(n){return e.isExportAssignment(n)||e.isExportDeclaration(n)}function tt(n){return e.some(n,nt)}function rt(n){return!e.isAnyImportOrReExport(n)&&!e.isExportAssignment(n)&&!e.hasSyntacticModifier(n,1)&&!e.isAmbientModule(n)}function at(n){return e.isAnyImportOrReExport(n)||e.isExportAssignment(n)||e.hasSyntacticModifier(n,1)}function it(e){return 239===e.kind||240===e.kind}function ot(n){return e.isBlock(n)||Yn(n)}function st(n){return e.isBlock(n)}function ct(n){return e.isVariableDeclarationList(n)||Yn(n)}function lt(e){var n=e.kind;return 258===n||257===n||78===n}function ut(e){var n=e.kind;return 258===n||257===n}function dt(e){var n=e.kind;return 78===n||257===n}function pt(e){var n=e.kind;return 265===n||264===n}function ft(e){return 257===e.kind||256===e.kind}function mt(e){return 210===e||199===e||253===e||222===e||167===e||256===e||292===e||271===e||252===e||209===e||168===e||263===e||261===e||266===e||254===e||281===e||166===e||165===e||257===e||260===e||264===e||270===e||161===e||289===e||164===e||163===e||169===e||290===e||255===e||160===e||250===e||335===e||328===e||337===e}function _t(e){return 252===e||272===e||253===e||254===e||255===e||256===e||257===e||262===e||261===e||268===e||267===e||260===e}function gt(e){return 242===e||241===e||249===e||236===e||234===e||232===e||239===e||240===e||238===e||235===e||246===e||243===e||245===e||247===e||248===e||233===e||237===e||244===e||339===e||343===e||342===e}function yt(n){return 160===n.kind?n.parent&&334!==n.parent.kind||e.isInJSFile(n):mt(n.kind)}function ht(e){return _t(e.kind)}function vt(e){return gt(e.kind)}function bt(e){var n=e.kind;return gt(n)||_t(n)||Et(e)}function Et(n){return 231===n.kind&&((void 0===n.parent||248!==n.parent.kind&&288!==n.parent.kind)&&!e.isFunctionBlock(n))}function Tt(e){var n=e.kind;return gt(n)||_t(n)||231===n}function St(e){var n=e.kind;return 273===n||158===n||78===n}function xt(e){var n=e.kind;return 107===n||78===n||202===n}function Lt(e){var n=e.kind;return 274===n||284===n||275===n||11===n||278===n}function Dt(e){var n=e.kind;return 281===n||283===n}function At(e){var n=e.kind;return 10===n||284===n}function Ct(e){var n=e.kind;return 276===n||275===n}function It(e){var n=e.kind;return 285===n||286===n}function Nt(e){return e.kind>=302&&e.kind<=337}function kt(n){return 312===n.kind||311===n.kind||313===n.kind||316===n.kind||Rt(n)||e.isJSDocTypeLiteral(n)||e.isJSDocSignature(n)}function Rt(e){return e.kind>=317&&e.kind<=337}function Ot(e){return 169===e.kind}function wt(e){return 168===e.kind}function Pt(e){var n=e.jsDoc;return!!n&&n.length>0}function Mt(e){return!!e.type}function Ft(e){return!!e.initializer}function Gt(e){switch(e.kind){case 250:case 161:case 199:case 163:case 164:case 289:case 292:return!0;default:return!1}}function Bt(e){return 281===e.kind||283===e.kind||Nn(e)}function Ut(e){return 174===e.kind||224===e.kind}e.isExternalModuleNameRelative=n,e.sortAndDeduplicateDiagnostics=t,e.getDefaultLibFileName=r,e.textSpanEnd=a,e.textSpanIsEmpty=i,e.textSpanContainsPosition=o,e.textRangeContainsPositionInclusive=s,e.textSpanContainsTextSpan=c,e.textSpanOverlapsWith=l,e.textSpanOverlap=u,e.textSpanIntersectsWithTextSpan=d,e.textSpanIntersectsWith=p,e.decodedTextSpanIntersectsWith=f,e.textSpanIntersectsWithPosition=m,e.textSpanIntersection=_,e.createTextSpan=g,e.createTextSpanFromBounds=y,e.textChangeRangeNewSpan=h,e.textChangeRangeIsUnchanged=v,e.createTextChangeRange=b,e.unchangedTextChangeRange=b(g(0,0),0),e.collapseTextChangeRangesAcrossMultipleVersions=E,e.getTypeParameterOwner=T,e.isParameterPropertyDeclaration=S,e.isEmptyBindingPattern=x,e.isEmptyBindingElement=L,e.walkUpBindingElementsAndPatterns=D,e.getCombinedModifierFlags=C,e.getCombinedNodeFlagsAlwaysIncludeJSDoc=I,e.getCombinedNodeFlags=N,e.supportedLocaleDirectories=["cs","de","es","fr","it","ja","ko","pl","pt-br","ru","tr","zh-cn","zh-tw"],e.validateLocaleAndSetLanguage=k,e.getOriginalNode=R,e.findAncestor=O,e.isParseTreeNode=w,e.getParseTreeNode=P,e.escapeLeadingUnderscores=M,e.unescapeLeadingUnderscores=F,e.idText=G,e.symbolName=B,e.nodeHasName=j,e.getNameOfJSDocTypedef=K,e.isNamedDeclaration=H,e.getNonAssignedNameOfDeclaration=W,e.getNameOfDeclaration=z,e.getAssignedName=q,e.getJSDocParameterTags=X,e.getJSDocParameterTagsNoCache=Y,e.getJSDocTypeParameterTags=Z,e.getJSDocTypeParameterTagsNoCache=$,e.hasJSDocParameterTags=ee,e.getJSDocAugmentsTag=ne,e.getJSDocImplementsTags=te,e.getJSDocClassTag=re,e.getJSDocPublicTag=ae,e.getJSDocPublicTagNoCache=ie,e.getJSDocPrivateTag=oe,e.getJSDocPrivateTagNoCache=se,e.getJSDocProtectedTag=ce,e.getJSDocProtectedTagNoCache=le,e.getJSDocReadonlyTag=ue,e.getJSDocReadonlyTagNoCache=de,e.getJSDocOverrideTagNoCache=pe,e.getJSDocDeprecatedTag=fe,e.getJSDocDeprecatedTagNoCache=me,e.getJSDocEnumTag=_e,e.getJSDocThisTag=ge,e.getJSDocReturnTag=ye,e.getJSDocTemplateTag=he,e.getJSDocTypeTag=ve,e.getJSDocType=be,e.getJSDocReturnType=Ee,e.getJSDocTags=Se,e.getJSDocTagsNoCache=xe,e.getAllJSDocTags=De,e.getAllJSDocTagsOfKind=Ae,e.getTextOfJSDocComment=Ce,e.getEffectiveTypeParameterDeclarations=Ie,e.getEffectiveConstraintOfTypeParameter=Ne,e.isMemberName=ke,e.isGetOrSetAccessorDeclaration=Re,e.isPropertyAccessChain=Oe,e.isElementAccessChain=we,e.isCallChain=Pe,e.isOptionalChain=Me,e.isOptionalChainRoot=Fe,e.isExpressionOfOptionalChainRoot=Ge,e.isOutermostOptionalChain=Be,e.isNullishCoalesce=Ue,e.isConstTypeReference=Ve,e.skipPartiallyEmittedExpressions=je,e.isNonNullChain=Ke,e.isBreakOrContinueStatement=He,e.isNamedExportBindings=We,e.isUnparsedTextLike=ze,e.isUnparsedNode=qe,e.isJSDocPropertyLikeTag=Je,e.isNode=Xe,e.isNodeKind=Ye,e.isTokenKind=Qe,e.isToken=Ze,e.isNodeArray=$e,e.isLiteralKind=en,e.isLiteralExpression=nn,e.isTemplateLiteralKind=tn,e.isTemplateLiteralToken=rn,e.isTemplateMiddleOrTemplateTail=an,e.isImportOrExportSpecifier=on,e.isTypeOnlyImportOrExportDeclaration=sn,e.isStringTextContainingNode=cn,e.isGeneratedIdentifier=ln,e.isPrivateIdentifierClassElementDeclaration=un,e.isPrivateIdentifierPropertyAccessExpression=dn,e.isModifierKind=pn,e.isParameterPropertyModifier=fn,e.isClassMemberModifier=mn,e.isModifier=_n,e.isEntityName=gn,e.isPropertyName=yn,e.isBindingName=hn,e.isFunctionLike=vn,e.isFunctionLikeDeclaration=bn,e.isFunctionLikeKind=Tn,e.isFunctionOrModuleBlock=Sn,e.isClassElement=xn,e.isClassLike=Ln,e.isAccessor=Dn,e.isMethodOrAccessor=An,e.isTypeElement=Cn,e.isClassOrTypeElement=In,e.isObjectLiteralElementLike=Nn,e.isTypeNode=kn,e.isFunctionOrConstructorTypeNode=Rn,e.isBindingPattern=On,e.isAssignmentPattern=wn,e.isArrayBindingElement=Pn,e.isDeclarationBindingElement=Mn,e.isBindingOrAssignmentPattern=Fn,e.isObjectBindingOrAssignmentPattern=Gn,e.isArrayBindingOrAssignmentPattern=Bn,e.isPropertyAccessOrQualifiedNameOrImportTypeNode=Un,e.isPropertyAccessOrQualifiedName=Vn,e.isCallLikeExpression=jn,e.isCallOrNewExpression=Kn,e.isTemplateLiteral=Hn,e.isLeftHandSideExpression=Wn,e.isUnaryExpression=qn,e.isUnaryExpressionWithWrite=Xn,e.isExpression=Yn,e.isAssertionExpression=Zn,e.isNotEmittedOrPartiallyEmittedNode=$n,e.isIterationStatement=et,e.isScopeMarker=nt,e.hasScopeMarker=tt,e.needsScopeMarker=rt,e.isExternalModuleIndicator=at,e.isForInOrOfStatement=it,e.isConciseBody=ot,e.isFunctionBody=st,e.isForInitializer=ct,e.isModuleBody=lt,e.isNamespaceBody=ut,e.isJSDocNamespaceBody=dt,e.isNamedImportBindings=pt,e.isModuleOrEnumDeclaration=ft,e.isDeclaration=yt,e.isDeclarationStatement=ht,e.isStatementButNotDeclaration=vt,e.isStatement=bt,e.isStatementOrBlock=Tt,e.isModuleReference=St,e.isJsxTagNameExpression=xt,e.isJsxChild=Lt,e.isJsxAttributeLike=Dt,e.isStringLiteralOrJsxExpression=At,e.isJsxOpeningLikeElement=Ct,e.isCaseOrDefaultClause=It,e.isJSDocNode=Nt,e.isJSDocCommentContainingNode=kt,e.isJSDocTag=Rt,e.isSetAccessor=Ot,e.isGetAccessor=wt,e.hasJSDocNodes=Pt,e.hasType=Mt,e.hasInitializer=Ft,e.hasOnlyExpressionInitializer=Gt,e.isObjectLiteralElement=Bt,e.isTypeReferenceType=Ut;var Vt=1073741823;function jt(n){for(var t=Vt,r=0,a=n;r<a.length;r++){var i=a[r];if(i.length){for(var o=0;o<i.length&&o<t;o++)if(!e.isWhiteSpaceLike(i.charCodeAt(o)))break;if(o<t&&(t=o),0===t)return 0}}return t===Vt?void 0:t}function Kt(e){return 10===e.kind||14===e.kind}e.guessIndentation=jt,e.isStringLiteralLike=Kt}(d||(d={})),function(e){function n(e,n){var t=e.declarations;if(t)for(var r=0,a=t;r<a.length;r++){var i=a[r];if(i.kind===n)return i}}function t(){return new e.Map}function r(e){return!!e&&!!e.size}function a(n){var t=new e.Map;if(n)for(var r=0,a=n;r<a.length;r++){var i=a[r];t.set(i.escapedName,i)}return t}function s(e){return 0!==(33554432&e.flags)}e.resolvingEmptyArray=[],e.externalHelpersModuleNameText="tslib",e.defaultMaximumTruncationLength=160,e.noTruncationMaximumTruncationLength=1e6,e.getDeclarationOfKind=n,e.createUnderscoreEscapedMap=t,e.hasEntries=r,e.createSymbolTable=a,e.isTransientSymbol=s;var c=l();function l(){var n="",t=function(e){return n+=e};return{getText:function(){return n},write:t,rawWrite:t,writeKeyword:t,writeOperator:t,writePunctuation:t,writeSpace:t,writeStringLiteral:t,writeLiteral:t,writeParameter:t,writeProperty:t,writeSymbol:function(e,n){return t(e)},writeTrailingSemicolon:t,writeComment:t,getTextPos:function(){return n.length},getLine:function(){return 0},getColumn:function(){return 0},getIndent:function(){return 0},isAtStartOfLine:function(){return!1},hasTrailingComment:function(){return!1},hasTrailingWhitespace:function(){return!!n.length&&e.isWhiteSpaceLike(n.charCodeAt(n.length-1))},writeLine:function(){return n+=" "},increaseIndent:e.noop,decreaseIndent:e.noop,clear:function(){return n=""},trackSymbol:e.noop,reportInaccessibleThisError:e.noop,reportInaccessibleUniqueSymbolError:e.noop,reportPrivateInBaseOfClassExpression:e.noop}}function u(e,n){return e.configFilePath!==n.configFilePath||d(e,n)}function d(n,t){return e.moduleResolutionOptionDeclarations.some((function(e){return!eu(jc(n,e),jc(t,e))}))}function p(n,t){while(1){var r=t(n);if("quit"===r)return;if(void 0!==r)return r;if(e.isSourceFile(n))return;n=n.parent}}function f(e,n){for(var t=e.entries(),r=t.next();!r.done;r=t.next()){var a=r.value,i=a[0],o=a[1],s=n(o,i);if(s)return s}}function m(e,n){for(var t=e.keys(),r=t.next();!r.done;r=t.next()){var a=n(r.value);if(a)return a}}function _(e,n){e.forEach((function(e,t){n.set(t,e)}))}function g(e){var n=c.getText();try{return e(c),c.getText()}finally{c.clear(),c.writeKeyword(n)}}function y(e){return e.end-e.pos}function h(e,n){return e&&e.resolvedModules&&e.resolvedModules.get(n)}function v(n,t,r){n.resolvedModules||(n.resolvedModules=new e.Map),n.resolvedModules.set(t,r)}function b(n,t,r){n.resolvedTypeReferenceDirectiveNames||(n.resolvedTypeReferenceDirectiveNames=new e.Map),n.resolvedTypeReferenceDirectiveNames.set(t,r)}function E(e,n){return e.path===n.path&&!e.prepend===!n.prepend&&!e.circular===!n.circular}function T(e,n){return e.isExternalLibraryImport===n.isExternalLibraryImport&&e.extension===n.extension&&e.resolvedFileName===n.resolvedFileName&&e.originalPath===n.originalPath&&S(e.packageId,n.packageId)}function S(e,n){return e===n||!!e&&!!n&&e.name===n.name&&e.subModuleName===n.subModuleName&&e.version===n.version}function x(e){var n=e.name,t=e.subModuleName,r=e.version,a=t?n+"/"+t:n;return a+"@"+r}function L(e,n){return e.resolvedFileName===n.resolvedFileName&&e.primary===n.primary&&e.originalPath===n.originalPath}function D(n,t,r,a){e.Debug.assert(n.length===t.length);for(var i=0;i<n.length;i++){var o=t[i],s=r&&r.get(n[i]),c=s?!o||!a(s,o):o;if(c)return!0}return!1}function A(e){return C(e),0!==(262144&e.flags)}function C(n){if(!(524288&n.flags)){var t=0!==(65536&n.flags)||e.forEachChild(n,A);t&&(n.flags|=262144),n.flags|=524288}}function I(e){while(e&&298!==e.kind)e=e.parent;return e}function N(e){switch(e.kind){case 231:case 259:case 238:case 239:case 240:return!0}return!1}function k(n,t){return e.Debug.assert(n>=0),e.getLineStarts(t)[n]}function R(n){var t=I(n),r=e.getLineAndCharacterOfPosition(t,n.pos);return t.fileName+"("+(r.line+1)+","+(r.character+1)+")"}function O(n,t){e.Debug.assert(n>=0);var r=e.getLineStarts(t),a=n,i=t.text;if(a+1===r.length)return i.length-1;var o=r[a],s=r[a+1]-1;e.Debug.assert(e.isLineBreak(i.charCodeAt(s)));while(o<=s&&e.isLineBreak(i.charCodeAt(s)))s--;return s}function w(e,n,t){return!(t&&t(n))&&!e.identifiers.has(n)}function P(e){return void 0===e||e.pos===e.end&&e.pos>=0&&1!==e.kind}function M(e){return!P(e)}function F(e,n,t){if(void 0===n||0===n.length)return e;for(var r=0;r<e.length;++r)if(!t(e[r]))break;return e.splice.apply(e,i([r,0],n)),e}function G(e,n,t){if(void 0===n)return e;for(var r=0;r<e.length;++r)if(!t(e[r]))break;return e.splice(r,0,n),e}function B(e){return rn(e)||!!(1048576&te(e))}function U(e,n){return F(e,n,rn)}function V(e,n){return F(e,n,B)}function j(e,n){return G(e,n,rn)}function K(e,n){return G(e,n,B)}function H(n,t,r){if(47===n.charCodeAt(t+1)&&t+2<r&&47===n.charCodeAt(t+2)){var a=n.substring(t,r);return!!(a.match(e.fullTripleSlashReferencePathRegEx)||a.match(e.fullTripleSlashAMDReferencePathRegEx)||a.match(dn)||a.match(pn))}return!1}function W(e,n){return 42===e.charCodeAt(n+1)&&33===e.charCodeAt(n+2)}function z(n,t){var r=new e.Map(t.map((function(t){return[""+e.getLineAndCharacterOfPosition(n,t.range.end).line,t]}))),a=new e.Map;return{getUnusedExpectations:i,markUsed:o};function i(){return e.arrayFrom(r.entries()).filter((function(e){var n=e[0],t=e[1];return 0===t.type&&!a.get(n)})).map((function(e){e[0];var n=e[1];return n}))}function o(e){return!!r.has(""+e)&&(a.set(""+e,!0),!0)}}function q(n,t,r){return P(n)?n.pos:e.isJSDocNode(n)||11===n.kind?e.skipTrivia((t||I(n)).text,n.pos,!1,!0):r&&e.hasJSDocNodes(n)?q(n.jsDoc[0],t):338===n.kind&&n._children.length>0?q(n._children[0],t,r):e.skipTrivia((t||I(n)).text,n.pos,!1,!1,mt(n))}function J(n,t){return P(n)||!n.decorators?q(n,t):e.skipTrivia((t||I(n)).text,n.decorators.end)}function X(e,n,t){return void 0===t&&(t=!1),Z(e.text,n,t)}function Y(n){return!!e.findAncestor(n,e.isJSDocTypeExpression)}function Q(n){return!!(e.isExportDeclaration(n)&&n.exportClause&&e.isNamespaceExport(n.exportClause)&&"default"===n.exportClause.name.escapedText)}function Z(n,t,r){if(void 0===r&&(r=!1),P(t))return"";var a=n.substring(r?t.pos:e.skipTrivia(n,t.pos),t.end);return Y(t)&&(a=a.replace(/(^|\r?\n|\r)\s*\*\s*/g,"$1")),a}function $(e,n){return void 0===n&&(n=!1),X(I(e),e,n)}function ee(e){return e.pos}function ne(n,t){return e.binarySearch(n,t,ee,e.compareValues)}function te(e){var n=e.emitNode;return n&&n.flags||0}function re(){return{es2015:{Array:["find","findIndex","fill","copyWithin","entries","keys","values"],RegExp:["flags","sticky","unicode"],Reflect:["apply","construct","defineProperty","deleteProperty","get"," getOwnPropertyDescriptor","getPrototypeOf","has","isExtensible","ownKeys","preventExtensions","set","setPrototypeOf"],ArrayConstructor:["from","of"],ObjectConstructor:["assign","getOwnPropertySymbols","keys","is","setPrototypeOf"],NumberConstructor:["isFinite","isInteger","isNaN","isSafeInteger","parseFloat","parseInt"],Math:["clz32","imul","sign","log10","log2","log1p","expm1","cosh","sinh","tanh","acosh","asinh","atanh","hypot","trunc","fround","cbrt"],Map:["entries","keys","values"],Set:["entries","keys","values"],Promise:e.emptyArray,PromiseConstructor:["all","race","reject","resolve"],Symbol:["for","keyFor"],WeakMap:["entries","keys","values"],WeakSet:["entries","keys","values"],Iterator:e.emptyArray,AsyncIterator:e.emptyArray,String:["codePointAt","includes","endsWith","normalize","repeat","startsWith","anchor","big","blink","bold","fixed","fontcolor","fontsize","italics","link","small","strike","sub","sup"],StringConstructor:["fromCodePoint","raw"]},es2016:{Array:["includes"]},es2017:{Atomics:e.emptyArray,SharedArrayBuffer:e.emptyArray,String:["padStart","padEnd"],ObjectConstructor:["values","entries","getOwnPropertyDescriptors"],DateTimeFormat:["formatToParts"]},es2018:{Promise:["finally"],RegExpMatchArray:["groups"],RegExpExecArray:["groups"],RegExp:["dotAll"],Intl:["PluralRules"],AsyncIterable:e.emptyArray,AsyncIterableIterator:e.emptyArray,AsyncGenerator:e.emptyArray,AsyncGeneratorFunction:e.emptyArray},es2019:{Array:["flat","flatMap"],ObjectConstructor:["fromEntries"],String:["trimStart","trimEnd","trimLeft","trimRight"],Symbol:["description"]},es2020:{BigInt:e.emptyArray,BigInt64Array:e.emptyArray,BigUint64Array:e.emptyArray,PromiseConstructor:["allSettled"],SymbolConstructor:["matchAll"],String:["matchAll"],DataView:["setBigInt64","setBigUint64","getBigInt64","getBigUint64"],RelativeTimeFormat:["format","formatToParts","resolvedOptions"]},es2021:{PromiseConstructor:["any"],String:["replaceAll"]},esnext:{NumberFormat:["formatToParts"]}}}function ae(n,t,r){if(ie(n,r))return X(t,n);switch(n.kind){case 10:var a=2&r?ei:1&r||16777216&te(n)?za:Ja;return n.singleQuote?"'"+a(n.text,39)+"'":'"'+a(n.text,34)+'"';case 14:case 15:case 16:case 17:a=1&r||16777216&te(n)?za:Ja;var i=n.rawText||Ga(a(n.text,96));switch(n.kind){case 14:return"`"+i+"`";case 15:return"`"+i+"${";case 16:return"}"+i+"${";case 17:return"}"+i+"`"}break;case 8:case 9:return n.text;case 13:return 4&r&&n.isUnterminated?n.text+(92===n.text.charCodeAt(n.text.length-1)?" /":"/"):n.text}return e.Debug.fail("Literal kind '"+n.kind+"' not accounted for.")}function ie(n,t){return!(Aa(n)||!n.parent||4&t&&n.isUnterminated)&&(e.isNumericLiteral(n)&&512&n.numericLiteralFlags?!!(8&t):!e.isBigIntLiteral(n))}function oe(n){return e.isString(n)?'"'+Ja(n)+'"':""+n}function se(n){return e.getBaseFileName(n).replace(/^(\d)/,"_$1").replace(/\W/g,"_")}function ce(n){return 0!==(3&e.getCombinedNodeFlags(n))||le(n)}function le(e){var n=La(e);return 250===n.kind&&288===n.parent.kind}function ue(n){return e.isModuleDeclaration(n)&&(10===n.name.kind||ye(n))}function de(n){return e.isModuleDeclaration(n)&&10===n.name.kind}function pe(n){return e.isModuleDeclaration(n)&&e.isStringLiteral(n.name)}function fe(n){return e.isModuleDeclaration(n)||e.isIdentifier(n)}function me(e){return _e(e.valueDeclaration)}function _e(e){return!!e&&257===e.kind&&!e.body}function ge(n){return 298===n.kind||257===n.kind||e.isFunctionLike(n)}function ye(e){return!!(1024&e.flags)}function he(e){return ue(e)&&ve(e)}function ve(n){switch(n.parent.kind){case 298:return e.isExternalModule(n.parent);case 258:return ue(n.parent.parent)&&e.isSourceFile(n.parent.parent.parent)&&!e.isExternalModule(n.parent.parent.parent)}return!1}function be(n){var t;return null===(t=n.declarations)||void 0===t?void 0:t.find((function(n){return!he(n)&&!(e.isModuleDeclaration(n)&&ye(n))}))}function Ee(n,t){return e.isExternalModule(n)||t.isolatedModules||Ac(t)===e.ModuleKind.CommonJS&&!!n.commonJsModuleIndicator}function Te(n,t){switch(n.scriptKind){case 1:case 3:case 2:case 4:break;default:return!1}return!n.isDeclarationFile&&(!!Fc(t,"alwaysStrict")||(!!e.startsWithUseStrict(n.statements)||!(!e.isExternalModule(n)&&!t.isolatedModules)&&(Ac(t)>=e.ModuleKind.ES2015||!t.noImplicitUseStrict)))}function Se(n,t){switch(n.kind){case 298:case 259:case 288:case 257:case 238:case 239:case 240:case 167:case 166:case 168:case 169:case 252:case 209:case 210:return!0;case 231:return!e.isFunctionLike(t)}return!1}function xe(n){switch(n.kind){case 328:case 335:case 315:return!0;default:return e.assertType(n),Le(n)}}function Le(n){switch(n.kind){case 170:case 171:case 165:case 172:case 175:case 176:case 309:case 253:case 222:case 254:case 255:case 334:case 252:case 166:case 167:case 168:case 169:case 209:case 210:return!0;default:return e.assertType(n),!1}}function De(e){switch(e.kind){case 262:case 261:return!0;default:return!1}}function Ae(e){switch(e.kind){case 262:case 261:case 233:case 253:case 252:case 257:case 255:case 254:case 256:return!0;default:return!1}}function Ce(n){return Ie(n)||e.isModuleDeclaration(n)||e.isImportTypeNode(n)||en(n)}function Ie(n){return De(n)||e.isExportDeclaration(n)}function Ne(n){return e.findAncestor(n.parent,(function(e){return Se(e,e.parent)}))}function ke(e){return e&&0!==y(e)?$(e):"(Missing)"}function Re(e){return e.declaration?ke(e.declaration.parameters[0].name):void 0}function Oe(e){return 159===e.kind&&!da(e.expression)}function we(n){switch(n.kind){case 78:case 79:return n.escapedText;case 10:case 8:case 14:return e.escapeLeadingUnderscores(n.text);case 159:return da(n.expression)?e.escapeLeadingUnderscores(n.expression.text):e.Debug.fail("Text of property name cannot be read from non-literal-valued ComputedPropertyNames");default:return e.Debug.assertNever(n)}}function Pe(n){switch(n.kind){case 107:return"this";case 79:case 78:return 0===y(n)?e.idText(n):$(n);case 158:return Pe(n.left)+"."+Pe(n.right);case 202:return e.isIdentifier(n.name)||e.isPrivateIdentifier(n.name)?Pe(n.expression)+"."+Pe(n.name):e.Debug.assertNever(n.name);default:return e.Debug.assertNever(n)}}function Me(e,n,t,r,a,i){var o=I(e);return Ge(o,e,n,t,r,a,i)}function Fe(n,t,r,a,i,o,s){var c=e.skipTrivia(n.text,t.pos);return mc(n,c,t.end-c,r,a,i,o,s)}function Ge(e,n,t,r,a,i,o){var s=ze(e,n);return mc(e,s.start,s.length,t,r,a,i,o)}function Be(e,n,t){var r=I(e),a=ze(r,e);return Ve(r,a.start,a.length,n,t)}function Ue(n,t,r){e.Debug.assertGreaterThanOrEqual(t,0),e.Debug.assertGreaterThanOrEqual(r,0),n&&(e.Debug.assertLessThanOrEqual(t,n.text.length),e.Debug.assertLessThanOrEqual(t+r,n.text.length))}function Ve(e,n,t,r,a){return Ue(e,n,t),{file:e,start:n,length:t,code:r.code,category:r.category,messageText:r.next?r:r.messageText,relatedInformation:a}}function je(e,n,t){return{file:e,start:0,length:0,code:n.code,category:n.category,messageText:n.next?n:n.messageText,relatedInformation:t}}function Ke(e,n,t){return{file:e,start:n.pos,length:n.end-n.pos,code:t.code,category:t.category,messageText:t.message}}function He(n,t){var r=e.createScanner(n.languageVersion,!0,n.languageVariant,n.text,void 0,t);r.scan();var a=r.getTokenPos();return e.createTextSpanFromBounds(a,r.getTextPos())}function We(n,t){var r=e.skipTrivia(n.text,t.pos);if(t.body&&231===t.body.kind){var a=e.getLineAndCharacterOfPosition(n,t.body.pos).line,i=e.getLineAndCharacterOfPosition(n,t.body.end).line;if(a<i)return e.createTextSpan(r,O(a,n)-r+1)}return e.createTextSpanFromBounds(r,t.end)}function ze(n,t){var r=t;switch(t.kind){case 298:var a=e.skipTrivia(n.text,0,!1);return a===n.text.length?e.createTextSpan(0,0):He(n,a);case 250:case 199:case 253:case 222:case 254:case 257:case 256:case 292:case 252:case 209:case 166:case 168:case 169:case 255:case 164:case 163:r=t.name;break;case 210:return We(n,t);case 285:case 286:var i=e.skipTrivia(n.text,t.pos),o=t.statements.length>0?t.statements[0].pos:t.end;return e.createTextSpanFromBounds(i,o)}if(void 0===r)return He(n,t.pos);e.Debug.assert(!e.isJSDoc(r));var s=P(r),c=s||e.isJsxText(t)?r.pos:e.skipTrivia(n.text,r.pos);return s?(e.Debug.assert(c===r.pos,"This failure could trigger https://github.com/Microsoft/TypeScript/issues/20809"),e.Debug.assert(c===r.end,"This failure could trigger https://github.com/Microsoft/TypeScript/issues/20809")):(e.Debug.assert(c>=r.pos,"This failure could trigger https://github.com/Microsoft/TypeScript/issues/20809"),e.Debug.assert(c<=r.end,"This failure could trigger https://github.com/Microsoft/TypeScript/issues/20809")),e.createTextSpanFromBounds(c,r.end)}function qe(e){return void 0!==(e.externalModuleIndicator||e.commonJsModuleIndicator)}function Je(e){return 6===e.scriptKind}function Xe(n){return!!(2048&e.getCombinedModifierFlags(n))}function Ye(n){return!(!(64&e.getCombinedModifierFlags(n))||e.isParameterPropertyDeclaration(n,n.parent))}function Qe(n){return!!(2&e.getCombinedNodeFlags(n))}function Ze(n){return!!(1&e.getCombinedNodeFlags(n))}function $e(e){return 204===e.kind&&105===e.expression.kind}function en(e){return 204===e.kind&&99===e.expression.kind}function nn(n){return e.isMetaProperty(n)&&99===n.keywordToken&&"meta"===n.name.escapedText}function tn(n){return e.isImportTypeNode(n)&&e.isLiteralTypeNode(n.argument)&&e.isStringLiteral(n.argument.literal)}function rn(e){return 234===e.kind&&10===e.expression.kind}function an(e){return!!(1048576&te(e))}function on(n){return an(n)&&e.isFunctionDeclaration(n)}function sn(n){return e.isIdentifier(n.name)&&!n.initializer}function cn(n){return an(n)&&e.isVariableStatement(n)&&e.every(n.declarationList.declarations,sn)}function ln(n,t){return 11!==n.kind?e.getLeadingCommentRanges(t.text,n.pos):void 0}function un(n,t){var r=161===n.kind||160===n.kind||209===n.kind||210===n.kind||208===n.kind||250===n.kind?e.concatenate(e.getTrailingCommentRanges(t,n.pos),e.getLeadingCommentRanges(t,n.pos)):e.getLeadingCommentRanges(t,n.pos);return e.filter(r,(function(e){return 42===t.charCodeAt(e.pos+1)&&42===t.charCodeAt(e.pos+2)&&47!==t.charCodeAt(e.pos+3)}))}e.changesAffectModuleResolution=u,e.optionsHaveModuleResolutionChanges=d,e.forEachAncestor=p,e.forEachEntry=f,e.forEachKey=m,e.copyEntries=_,e.usingSingleLineStringWriter=g,e.getFullWidth=y,e.getResolvedModule=h,e.setResolvedModule=v,e.setResolvedTypeReferenceDirective=b,e.projectReferenceIsEqualTo=E,e.moduleResolutionIsEqualTo=T,e.packageIdToString=x,e.typeDirectiveIsEqualTo=L,e.hasChangesInResolutions=D,e.containsParseError=A,e.getSourceFileOfNode=I,e.isStatementWithLocals=N,e.getStartPositionOfLine=k,e.nodePosToString=R,e.getEndLinePosition=O,e.isFileLevelUniqueName=w,e.nodeIsMissing=P,e.nodeIsPresent=M,e.insertStatementsAfterStandardPrologue=U,e.insertStatementsAfterCustomPrologue=V,e.insertStatementAfterStandardPrologue=j,e.insertStatementAfterCustomPrologue=K,e.isRecognizedTripleSlashComment=H,e.isPinnedComment=W,e.createCommentDirectivesMap=z,e.getTokenPosOfNode=q,e.getNonDecoratorTokenPosOfNode=J,e.getSourceTextOfNodeFromSourceFile=X,e.isExportNamespaceAsDefaultDeclaration=Q,e.getTextOfNodeFromSourceText=Z,e.getTextOfNode=$,e.indexOfNode=ne,e.getEmitFlags=te,e.getScriptTargetFeatures=re,function(e){e[e["None"]=0]="None",e[e["NeverAsciiEscape"]=1]="NeverAsciiEscape",e[e["JsxAttributeEscape"]=2]="JsxAttributeEscape",e[e["TerminateUnterminatedLiterals"]=4]="TerminateUnterminatedLiterals",e[e["AllowNumericSeparator"]=8]="AllowNumericSeparator"}(e.GetLiteralTextFlags||(e.GetLiteralTextFlags={})),e.getLiteralText=ae,e.getTextOfConstantValue=oe,e.makeIdentifierFromModuleName=se,e.isBlockOrCatchScoped=ce,e.isCatchClauseVariableDeclarationOrBindingElement=le,e.isAmbientModule=ue,e.isModuleWithStringLiteralName=de,e.isNonGlobalAmbientModule=pe,e.isEffectiveModuleDeclaration=fe,e.isShorthandAmbientModuleSymbol=me,e.isBlockScopedContainerTopLevel=ge,e.isGlobalScopeAugmentation=ye,e.isExternalModuleAugmentation=he,e.isModuleAugmentationExternal=ve,e.getNonAugmentationDeclaration=be,e.isEffectiveExternalModule=Ee,e.isEffectiveStrictModeSourceFile=Te,e.isBlockScope=Se,e.isDeclarationWithTypeParameters=xe,e.isDeclarationWithTypeParameterChildren=Le,e.isAnyImportSyntax=De,e.isLateVisibilityPaintedStatement=Ae,e.hasPossibleExternalModuleReference=Ce,e.isAnyImportOrReExport=Ie,e.getEnclosingBlockScopeContainer=Ne,e.declarationNameToString=ke,e.getNameFromIndexInfo=Re,e.isComputedNonLiteralName=Oe,e.getTextOfPropertyName=we,e.entityNameToString=Pe,e.createDiagnosticForNode=Me,e.createDiagnosticForNodeArray=Fe,e.createDiagnosticForNodeInSourceFile=Ge,e.createDiagnosticForNodeFromMessageChain=Be,e.createFileDiagnosticFromMessageChain=Ve,e.createDiagnosticForFileFromMessageChain=je,e.createDiagnosticForRange=Ke,e.getSpanOfTokenAtPosition=He,e.getErrorSpanForNode=ze,e.isExternalOrCommonJsModule=qe,e.isJsonSourceFile=Je,e.isEnumConst=Xe,e.isDeclarationReadonly=Ye,e.isVarConst=Qe,e.isLet=Ze,e.isSuperCall=$e,e.isImportCall=en,e.isImportMeta=nn,e.isLiteralImportTypeNode=tn,e.isPrologueDirective=rn,e.isCustomPrologue=an,e.isHoistedFunction=on,e.isHoistedVariableStatement=cn,e.getLeadingCommentRangesOfNode=ln,e.getJSDocCommentRanges=un,e.fullTripleSlashReferencePathRegEx=/^(\/\/\/\s*<reference\s+path\s*=\s*)('|")(.+?)\2.*?\/>/;var dn=/^(\/\/\/\s*<reference\s+types\s*=\s*)('|")(.+?)\2.*?\/>/;e.fullTripleSlashAMDReferencePathRegEx=/^(\/\/\/\s*<amd-dependency\s+path\s*=\s*)('|")(.+?)\2.*?\/>/;var pn=/^(\/\/\/\s*<reference\s+no-default-lib\s*=\s*)('|")(.+?)\2\s*\/>/;function fn(n){if(173<=n.kind&&n.kind<=196)return!0;switch(n.kind){case 128:case 152:case 144:case 155:case 147:case 131:case 148:case 145:case 150:case 141:return!0;case 113:return 213!==n.parent.kind;case 224:return!Co(n);case 160:return 191===n.parent.kind||186===n.parent.kind;case 78:(158===n.parent.kind&&n.parent.right===n||202===n.parent.kind&&n.parent.name===n)&&(n=n.parent),e.Debug.assert(78===n.kind||158===n.kind||202===n.kind,"'node' was expected to be a qualified name, identifier or property access in 'isPartOfTypeNode'.");case 158:case 202:case 107:var t=n.parent;if(177===t.kind)return!1;if(196===t.kind)return!t.isTypeOf;if(173<=t.kind&&t.kind<=196)return!0;switch(t.kind){case 224:return!Co(t);case 160:return n===t.constraint;case 334:return n===t.constraint;case 164:case 163:case 161:case 250:return n===t.type;case 252:case 209:case 210:case 167:case 166:case 165:case 168:case 169:return n===t.type;case 170:case 171:case 172:return n===t.type;case 207:return n===t.type;case 204:case 205:return e.contains(t.typeArguments,n);case 206:return!1}}return!1}function mn(e,n){while(e){if(e.kind===n)return!0;e=e.parent}return!1}function _n(n,t){return r(n);function r(n){switch(n.kind){case 243:return t(n);case 259:case 231:case 235:case 236:case 237:case 238:case 239:case 240:case 244:case 245:case 285:case 286:case 246:case 248:case 288:return e.forEachChild(n,r)}}}function gn(n,t){return r(n);function r(n){switch(n.kind){case 220:t(n);var a=n.expression;return void(a&&r(a));case 256:case 254:case 257:case 255:return;default:if(e.isFunctionLike(n)){if(n.name&&159===n.name.kind)return void r(n.name.expression)}else fn(n)||e.forEachChild(n,r)}}}function yn(n){return n&&179===n.kind?n.elementType:n&&174===n.kind?e.singleOrUndefined(n.typeArguments):void 0}function hn(e){switch(e.kind){case 254:case 253:case 222:case 178:return e.members;case 201:return e.properties}}function vn(e){if(e)switch(e.kind){case 199:case 292:case 161:case 289:case 164:case 163:case 290:case 250:return!0}return!1}function bn(n){return vn(n)||e.isAccessor(n)}function En(e){return 251===e.parent.kind&&233===e.parent.parent.kind}function Tn(n){return e.isVariableDeclaration(n)?Qe(n)&&e.isIdentifier(n.name)&&En(n):e.isPropertyDeclaration(n)?io(n)&&no(n):e.isPropertySignature(n)&&io(n)}function Sn(e){switch(e.kind){case 166:case 165:case 167:case 168:case 169:case 252:case 209:return!0}return!1}function xn(e,n){while(1){if(n&&n(e),246!==e.statement.kind)return e.statement;e=e.statement}}function Ln(n){return n&&231===n.kind&&e.isFunctionLike(n.parent)}function Dn(e){return e&&166===e.kind&&201===e.parent.kind}function An(e){return 166===e.kind&&(201===e.parent.kind||222===e.parent.kind)}function Cn(e){return e&&1===e.kind}function In(e){return e&&0===e.kind}function Nn(e,n,t){return e.properties.filter((function(e){if(289===e.kind){var r=we(e.name);return n===r||!!t&&t===r}return!1}))}function kn(n,t,r){return e.firstDefined(Nn(n,t),(function(n){return e.isArrayLiteralExpression(n.initializer)?e.find(n.initializer.elements,(function(n){return e.isStringLiteral(n)&&n.text===r})):void 0}))}function Rn(n){if(n&&n.statements.length){var t=n.statements[0].expression;return e.tryCast(t,e.isObjectLiteralExpression)}}function On(n,t,r){return e.firstDefined(wn(n,t),(function(n){return e.isArrayLiteralExpression(n.initializer)?e.find(n.initializer.elements,(function(n){return e.isStringLiteral(n)&&n.text===r})):void 0}))}function wn(n,t){var r=Rn(n);return r?Nn(r,t):e.emptyArray}function Pn(n){return e.findAncestor(n.parent,e.isFunctionLike)}function Mn(n){return e.findAncestor(n.parent,e.isFunctionLikeDeclaration)}function Fn(n){return e.findAncestor(n.parent,e.isClassLike)}function Gn(n,t){e.Debug.assert(298!==n.kind);while(1){if(n=n.parent,!n)return e.Debug.fail();switch(n.kind){case 159:if(e.isClassLike(n.parent.parent))return n;n=n.parent;break;case 162:161===n.parent.kind&&e.isClassElement(n.parent.parent)?n=n.parent.parent:e.isClassElement(n.parent)&&(n=n.parent);break;case 210:if(!t)continue;case 252:case 209:case 257:case 164:case 163:case 166:case 165:case 167:case 168:case 169:case 170:case 171:case 172:case 256:case 298:return n}}}function Bn(n){e.isIdentifier(n)&&(e.isClassDeclaration(n.parent)||e.isFunctionDeclaration(n.parent))&&n.parent.name===n&&(n=n.parent);var t=Gn(n,!0);return e.isSourceFile(t)}function Un(e){var n=Gn(e,!1);if(n)switch(n.kind){case 167:case 252:case 209:return n}}function Vn(n,t){while(1){if(n=n.parent,!n)return n;switch(n.kind){case 159:n=n.parent;break;case 252:case 209:case 210:if(!t)continue;case 164:case 163:case 166:case 165:case 167:case 168:case 169:return n;case 162:161===n.parent.kind&&e.isClassElement(n.parent.parent)?n=n.parent.parent:e.isClassElement(n.parent)&&(n=n.parent);break}}}function jn(e){if(209===e.kind||210===e.kind){var n=e,t=e.parent;while(208===t.kind)n=t,t=t.parent;if(204===t.kind&&t.expression===n)return t}}function Kn(e){return 105===e.kind||Hn(e)}function Hn(e){var n=e.kind;return(202===n||203===n)&&105===e.expression.kind}function Wn(e){var n=e.kind;return(202===n||203===n)&&107===e.expression.kind}function zn(n){var t;return!!n&&e.isVariableDeclaration(n)&&107===(null===(t=n.initializer)||void 0===t?void 0:t.kind)}function qn(n){return!!n&&(e.isShorthandPropertyAssignment(n)||e.isPropertyAssignment(n))&&e.isBinaryExpression(n.parent.parent)&&62===n.parent.parent.operatorToken.kind&&107===n.parent.parent.right.kind}function Jn(e){switch(e.kind){case 174:return e.typeName;case 224:return Io(e.expression)?e.expression:void 0;case 78:case 158:return e}}function Xn(e){switch(e.kind){case 206:return e.tag;case 276:case 275:return e.tagName;default:return e.expression}}function Yn(n,t,r){if(e.isNamedDeclaration(n)&&e.isPrivateIdentifier(n.name))return!1;switch(n.kind){case 253:return!0;case 164:return 253===t.kind;case 168:case 169:case 166:return void 0!==n.body&&253===t.kind;case 161:return void 0!==t.body&&(167===t.kind||166===t.kind||169===t.kind)&&253===r.kind}return!1}function Qn(e,n,t){return void 0!==e.decorators&&Yn(e,n,t)}function Zn(e,n,t){return Qn(e,n,t)||$n(e,n)}function $n(n,t){switch(n.kind){case 253:return e.some(n.members,(function(e){return Zn(e,n,t)}));case 166:case 169:return e.some(n.parameters,(function(e){return Qn(e,n,t)}));default:return!1}}function et(e){var n=e.parent;return(276===n.kind||275===n.kind||277===n.kind)&&n.tagName===e}function nt(e){switch(e.kind){case 105:case 103:case 109:case 94:case 13:case 200:case 201:case 202:case 203:case 204:case 205:case 206:case 225:case 207:case 226:case 208:case 209:case 222:case 210:case 213:case 211:case 212:case 215:case 216:case 217:case 218:case 221:case 219:case 223:case 274:case 275:case 278:case 220:case 214:case 227:return!0;case 158:while(158===e.parent.kind)e=e.parent;return 177===e.parent.kind||et(e);case 78:if(177===e.parent.kind||et(e))return!0;case 8:case 9:case 10:case 14:case 107:return tt(e);default:return!1}}function tt(e){var n=e.parent;switch(n.kind){case 250:case 161:case 164:case 163:case 292:case 289:case 199:return n.initializer===e;case 234:case 235:case 236:case 237:case 243:case 244:case 245:case 285:case 247:return n.expression===e;case 238:var t=n;return t.initializer===e&&251!==t.initializer.kind||t.condition===e||t.incrementor===e;case 239:case 240:var r=n;return r.initializer===e&&251!==r.initializer.kind||r.expression===e;case 207:case 225:return e===n.expression;case 229:return e===n.expression;case 159:return e===n.expression;case 162:case 284:case 283:case 291:return!0;case 224:return n.expression===e&&Co(n);case 290:return n.objectAssignmentInitializer===e;default:return nt(n)}}function rt(e){while(158===e.kind||78===e.kind)e=e.parent;return 177===e.kind}function at(n){return e.isNamespaceExport(n)&&!!n.parent.moduleSpecifier}function it(e){return 261===e.kind&&273===e.moduleReference.kind}function ot(n){return e.Debug.assert(it(n)),n.moduleReference.expression}function st(e){return yt(e)&&Qs(e.initializer).arguments[0]}function ct(e){return 261===e.kind&&273!==e.moduleReference.kind}function lt(e){return dt(e)}function ut(e){return!dt(e)}function dt(e){return!!e&&!!(131072&e.flags)}function pt(e){return!!e&&!!(33554432&e.flags)}function ft(e){return!Je(e)}function mt(e){return!!e&&!!(4194304&e.flags)}function _t(n){return e.isTypeReferenceNode(n)&&e.isIdentifier(n.typeName)&&"Object"===n.typeName.escapedText&&n.typeArguments&&2===n.typeArguments.length&&(147===n.typeArguments[0].kind||144===n.typeArguments[0].kind)}function gt(n,t){if(204!==n.kind)return!1;var r=n,a=r.expression,i=r.arguments;if(78!==a.kind||"require"!==a.escapedText)return!1;if(1!==i.length)return!1;var o=i[0];return!t||e.isStringLiteralLike(o)}function yt(n){return 199===n.kind&&(n=n.parent.parent),e.isVariableDeclaration(n)&&!!n.initializer&&gt(Qs(n.initializer),!0)}function ht(n){return e.isVariableStatement(n)&&n.declarationList.declarations.length>0&&e.every(n.declarationList.declarations,(function(e){return yt(e)}))}function vt(e){return 39===e||34===e}function bt(e,n){return 34===X(n,e).charCodeAt(0)}function Et(n){return e.isBinaryExpression(n)||qs(n)||e.isIdentifier(n)||e.isCallExpression(n)}function Tt(n){return dt(n)&&n.initializer&&e.isBinaryExpression(n.initializer)&&(56===n.initializer.operatorToken.kind||60===n.initializer.operatorToken.kind)&&n.name&&Io(n.name)&&Nt(n.name,n.initializer.left)?n.initializer.right:n.initializer}function St(e){var n=Tt(e);return n&&Dt(n,wo(e.name))}function xt(n,t){return e.forEach(n.properties,(function(n){return e.isPropertyAssignment(n)&&e.isIdentifier(n.name)&&"value"===n.name.escapedText&&n.initializer&&Dt(n.initializer,t)}))}function Lt(n){if(n&&n.parent&&e.isBinaryExpression(n.parent)&&62===n.parent.operatorToken.kind){var t=wo(n.parent.left);return Dt(n.parent.right,t)||At(n.parent.left,n.parent.right,t)}if(n&&e.isCallExpression(n)&&Mt(n)){var r=xt(n.arguments[2],"prototype"===n.arguments[1].text);if(r)return r}}function Dt(n,t){if(e.isCallExpression(n)){var r=wr(n.expression);return 209===r.kind||210===r.kind?n:void 0}return 209===n.kind||222===n.kind||210===n.kind||e.isObjectLiteralExpression(n)&&(0===n.properties.length||t)?n:void 0}function At(n,t,r){var a=e.isBinaryExpression(t)&&(56===t.operatorToken.kind||60===t.operatorToken.kind)&&Dt(t.right,r);if(a&&Nt(n,t.left))return a}function Ct(n){var t=e.isVariableDeclaration(n.parent)?n.parent.name:e.isBinaryExpression(n.parent)&&62===n.parent.operatorToken.kind?n.parent.left:void 0;return t&&Dt(n.right,wo(t))&&Io(t)&&Nt(t,n.left)}function It(n){if(e.isBinaryExpression(n.parent)){var t=56!==n.parent.operatorToken.kind&&60!==n.parent.operatorToken.kind||!e.isBinaryExpression(n.parent.parent)?n.parent:n.parent.parent;if(62===t.operatorToken.kind&&e.isIdentifier(t.left))return t.left}else if(e.isVariableDeclaration(n.parent))return n.parent.name}function Nt(n,t){if(ga(n)&&ga(t))return ya(n)===ya(t);if(e.isIdentifier(n)&&Ft(t)&&(107===t.expression.kind||e.isIdentifier(t.expression)&&("window"===t.expression.escapedText||"self"===t.expression.escapedText||"global"===t.expression.escapedText))){var r=jt(t);return e.isPrivateIdentifier(r)&&e.Debug.fail("Unexpected PrivateIdentifier in name expression with literal-like access."),Nt(n,r)}return!(!Ft(n)||!Ft(t))&&(zt(n)===zt(t)&&Nt(n.expression,t.expression))}function kt(e){while(Lo(e,!0))e=e.right;return e}function Rt(n){return e.isIdentifier(n)&&"exports"===n.escapedText}function Ot(n){return e.isIdentifier(n)&&"module"===n.escapedText}function wt(n){return(e.isPropertyAccessExpression(n)||Gt(n))&&Ot(n.expression)&&"exports"===zt(n)}function Pt(e){var n=Kt(e);return 5===n||dt(e)?n:0}function Mt(n){return 3===e.length(n.arguments)&&e.isPropertyAccessExpression(n.expression)&&e.isIdentifier(n.expression.expression)&&"Object"===e.idText(n.expression.expression)&&"defineProperty"===e.idText(n.expression.name)&&da(n.arguments[1])&&Vt(n.arguments[0],!0)}function Ft(n){return e.isPropertyAccessExpression(n)||Gt(n)}function Gt(n){return e.isElementAccessExpression(n)&&da(n.argumentExpression)}function Bt(n,t){return e.isPropertyAccessExpression(n)&&(!t&&107===n.expression.kind||e.isIdentifier(n.name)&&Vt(n.expression,!0))||Ut(n,t)}function Ut(e,n){return Gt(e)&&(!n&&107===e.expression.kind||Io(e.expression)||Bt(e.expression,!0))}function Vt(e,n){return Io(e)||Bt(e,n)}function jt(n){return e.isPropertyAccessExpression(n)?n.name:n.argumentExpression}function Kt(n){if(e.isCallExpression(n)){if(!Mt(n))return 0;var t=n.arguments[0];return Rt(t)||wt(t)?8:Bt(t)&&"prototype"===zt(t)?9:7}return 62!==n.operatorToken.kind||!qs(n.left)||Ht(kt(n))?0:Vt(n.left.expression,!0)&&"prototype"===zt(n.left)&&e.isObjectLiteralExpression(Jt(n))?6:qt(n.left)}function Ht(n){return e.isVoidExpression(n)&&e.isNumericLiteral(n.expression)&&"0"===n.expression.text}function Wt(n){if(e.isPropertyAccessExpression(n))return n.name;var t=wr(n.argumentExpression);return e.isNumericLiteral(t)||e.isStringLiteralLike(t)?t:n}function zt(n){var t=Wt(n);if(t){if(e.isIdentifier(t))return t.escapedText;if(e.isStringLiteralLike(t)||e.isNumericLiteral(t))return e.escapeLeadingUnderscores(t.text)}}function qt(n){if(107===n.expression.kind)return 4;if(wt(n))return 2;if(Vt(n.expression,!0)){if(wo(n.expression))return 3;var t=n;while(!e.isIdentifier(t.expression))t=t.expression;var r=t.expression;if(("exports"===r.escapedText||"module"===r.escapedText&&"exports"===zt(t))&&Bt(n))return 1;if(Vt(n,!0)||e.isElementAccessExpression(n)&&ma(n))return 5}return 0}function Jt(n){while(e.isBinaryExpression(n.right))n=n.right;return n.right}function Xt(n){return e.isBinaryExpression(n)&&3===Pt(n)}function Yt(n){return dt(n)&&n.parent&&234===n.parent.kind&&(!e.isElementAccessExpression(n)||Gt(n))&&!!e.getJSDocTypeTag(n.parent)}function Qt(e,n){var t=e.valueDeclaration;(!t||(!(8388608&n.flags)||8388608&t.flags)&&Et(t)&&!Et(n)||t.kind!==n.kind&&fe(t))&&(e.valueDeclaration=n)}function Zt(n){if(!n||!n.valueDeclaration)return!1;var t=n.valueDeclaration;return 252===t.kind||e.isVariableDeclaration(t)&&t.initializer&&e.isFunctionLike(t.initializer)}function $t(n){var t,r,a;switch(n.kind){case 250:return n.initializer.arguments[0].text;case 262:return null===(t=e.tryCast(n.moduleSpecifier,e.isStringLiteralLike))||void 0===t?void 0:t.text;case 261:return null===(a=e.tryCast(null===(r=e.tryCast(n.moduleReference,e.isExternalModuleReference))||void 0===r?void 0:r.expression,e.isStringLiteralLike))||void 0===a?void 0:a.text;default:e.Debug.assertNever(n)}}function er(n){return nr(n)||e.Debug.failBadSyntaxKind(n.parent)}function nr(n){switch(n.parent.kind){case 262:case 268:return n.parent;case 273:return n.parent.parent;case 204:return en(n.parent)||gt(n.parent,!1)?n.parent:void 0;case 192:return e.Debug.assert(e.isStringLiteral(n)),e.tryCast(n.parent.parent,e.isImportTypeNode);default:return}}function tr(n){switch(n.kind){case 262:case 268:return n.moduleSpecifier;case 261:return 273===n.moduleReference.kind?n.moduleReference.expression:void 0;case 196:return tn(n)?n.argument.literal:void 0;case 204:return n.arguments[0];case 257:return 10===n.name.kind?n.name:void 0;default:return e.Debug.assertNever(n)}}function rr(n){switch(n.kind){case 262:return n.importClause&&e.tryCast(n.importClause.namedBindings,e.isNamespaceImport);case 261:return n;case 268:return n.exportClause&&e.tryCast(n.exportClause,e.isNamespaceExport);default:return e.Debug.assertNever(n)}}function ar(e){return 262===e.kind&&!!e.importClause&&!!e.importClause.name}function ir(n,t){if(n.name){var r=t(n);if(r)return r}if(n.namedBindings){r=e.isNamespaceImport(n.namedBindings)?t(n.namedBindings):e.forEach(n.namedBindings.elements,t);if(r)return r}}function or(e){if(e)switch(e.kind){case 161:case 166:case 165:case 290:case 289:case 164:case 163:return void 0!==e.questionToken}return!1}function sr(n){var t=e.isJSDocFunctionType(n)?e.firstOrUndefined(n.parameters):void 0,r=e.tryCast(t&&t.name,e.isIdentifier);return!!r&&"new"===r.escapedText}function cr(e){return 335===e.kind||328===e.kind||329===e.kind}function lr(n){return cr(n)||e.isTypeAliasDeclaration(n)}function ur(n){return e.isExpressionStatement(n)&&e.isBinaryExpression(n.expression)&&62===n.expression.operatorToken.kind?kt(n.expression):void 0}function dr(n){return e.isExpressionStatement(n)&&e.isBinaryExpression(n.expression)&&0!==Pt(n.expression)&&e.isBinaryExpression(n.expression.right)&&(56===n.expression.right.operatorToken.kind||60===n.expression.right.operatorToken.kind)?n.expression.right.right:void 0}function pr(e){switch(e.kind){case 233:var n=fr(e);return n&&n.initializer;case 164:return e.initializer;case 289:return e.initializer}}function fr(n){return e.isVariableStatement(n)?e.firstOrUndefined(n.declarationList.declarations):void 0}function mr(n){return e.isModuleDeclaration(n)&&n.body&&257===n.body.kind?n.body:void 0}function _r(n,t){var r;vn(n)&&e.hasInitializer(n)&&e.hasJSDocNodes(n.initializer)&&(r=e.append(r,e.last(n.initializer.jsDoc)));var a=n;while(a&&a.parent){if(e.hasJSDocNodes(a)&&(r=e.append(r,e.last(a.jsDoc))),161===a.kind){r=e.addRange(r,(t?e.getJSDocParameterTagsNoCache:e.getJSDocParameterTags)(a));break}if(160===a.kind){r=e.addRange(r,(t?e.getJSDocTypeParameterTagsNoCache:e.getJSDocTypeParameterTags)(a));break}a=gr(a)}return r||e.emptyArray}function gr(n){var t=n.parent;return 289===t.kind||267===t.kind||164===t.kind||234===t.kind&&202===n.kind||243===t.kind||mr(t)||e.isBinaryExpression(n)&&62===n.operatorToken.kind?t:t.parent&&(fr(t.parent)===n||e.isBinaryExpression(t)&&62===t.operatorToken.kind)?t.parent:t.parent&&t.parent.parent&&(fr(t.parent.parent)||pr(t.parent.parent)===n||dr(t.parent.parent))?t.parent.parent:void 0}function yr(n){if(n.symbol)return n.symbol;if(e.isIdentifier(n.name)){var t=n.name.escapedText,r=hr(n);if(r){var a=e.find(r.parameters,(function(e){return 78===e.name.kind&&e.name.escapedText===t}));return a&&a.symbol}}}function hr(n){var t=vr(n);return t&&e.isFunctionLike(t)?t:void 0}function vr(e){var n=br(e);if(n)return dr(n)||ur(n)||pr(n)||fr(n)||mr(n)||n}function br(n){var t=Er(n);if(t){var r=t.parent;return r&&r.jsDoc&&t===e.lastOrUndefined(r.jsDoc)?r:void 0}}function Er(n){return e.findAncestor(n.parent,e.isJSDoc)}function Tr(n){var t=n.name.escapedText,r=n.parent.parent.parent.typeParameters;return r&&e.find(r,(function(e){return e.name.escapedText===t}))}function Sr(n){var t=e.lastOrUndefined(n.parameters);return!!t&&xr(t)}function xr(n){var t=e.isJSDocParameterTag(n)?n.typeExpression&&n.typeExpression.type:n.type;return void 0!==n.dotDotDotToken||!!t&&310===t.kind}function Lr(e){return!!e.typeArguments}function Dr(e){var n=e.parent;while(1){switch(n.kind){case 217:var t=n.operatorToken.kind;return To(t)&&n.left===e?62===t||bo(t)?1:2:0;case 215:case 216:var r=n.operator;return 45===r||46===r?2:0;case 239:case 240:return n.initializer===e?1:0;case 208:case 200:case 221:case 226:e=n;break;case 291:e=n.parent;break;case 290:if(n.name!==e)return 0;e=n.parent;break;case 289:if(n.name===e)return 0;e=n.parent;break;default:return 0}n=e.parent}}function Ar(e){return 0!==Dr(e)}function Cr(e){switch(e.kind){case 231:case 233:case 244:case 235:case 245:case 259:case 285:case 286:case 246:case 238:case 239:case 240:case 236:case 237:case 248:case 288:return!0}return!1}function Ir(n){return e.isFunctionExpression(n)||e.isArrowFunction(n)||e.isMethodOrAccessor(n)||e.isFunctionDeclaration(n)||e.isConstructorDeclaration(n)}function Nr(e,n){while(e&&e.kind===n)e=e.parent;return e}function kr(e){return Nr(e,187)}function Rr(e){return Nr(e,208)}function Or(e){var n;while(e&&187===e.kind)n=e,e=e.parent;return[n,e]}function wr(n){return e.skipOuterExpressions(n,1)}function Pr(e){while(208===e.kind)e=e.parent;return e}function Mr(e){return(202===e.kind||203===e.kind)&&(e=Rr(e.parent),e&&211===e.kind)}function Fr(e,n){while(e){if(e===n)return!0;e=e.parent}return!1}function Gr(n){return!e.isSourceFile(n)&&!e.isBindingPattern(n)&&e.isDeclaration(n.parent)&&n.parent.name===n}function Br(n){var t=n.parent;switch(n.kind){case 10:case 14:case 8:if(e.isComputedPropertyName(t))return t.parent;case 78:if(e.isDeclaration(t))return t.name===n?t:void 0;if(e.isQualifiedName(t)){var r=t.parent;return e.isJSDocParameterTag(r)&&r.name===t?r:void 0}var a=t.parent;return e.isBinaryExpression(a)&&0!==Pt(a)&&(a.left.symbol||a.symbol)&&e.getNameOfDeclaration(a)===n?a:void 0;case 79:return e.isDeclaration(t)&&t.name===n?t:void 0;default:return}}function Ur(n){return da(n)&&159===n.parent.kind&&e.isDeclaration(n.parent.parent)}function Vr(e){var n=e.parent;switch(n.kind){case 164:case 163:case 166:case 165:case 168:case 169:case 292:case 289:case 202:return n.name===e;case 158:return n.right===e;case 199:case 266:return n.propertyName===e;case 271:case 281:return!0}return!1}function jr(n){return 261===n.kind||260===n.kind||263===n.kind&&!!n.name||264===n.kind||270===n.kind||266===n.kind||271===n.kind||267===n.kind&&Wr(n)||e.isBinaryExpression(n)&&2===Pt(n)&&Wr(n)||e.isPropertyAccessExpression(n)&&e.isBinaryExpression(n.parent)&&n.parent.left===n&&62===n.parent.operatorToken.kind&&Hr(n.parent.right)||290===n.kind||289===n.kind&&Hr(n.initializer)}function Kr(e){switch(e.parent.kind){case 263:case 266:case 264:case 271:case 267:case 261:return e.parent;case 158:do{e=e.parent}while(158===e.parent.kind);return Kr(e)}}function Hr(n){return Io(n)||e.isClassExpression(n)}function Wr(e){var n=zr(e);return Hr(n)}function zr(n){return e.isExportAssignment(n)?n.expression:n.right}function qr(e){return 290===e.kind?e.name:289===e.kind?e.initializer:e.parent.right}function Jr(n){var t=Xr(n);if(t&&dt(n)){var r=e.getJSDocAugmentsTag(n);if(r)return r.class}return t}function Xr(e){var n=$r(e.heritageClauses,93);return n&&n.types.length>0?n.types[0]:void 0}function Yr(n){if(dt(n))return e.getJSDocImplementsTags(n).map((function(e){return e.class}));var t=$r(n.heritageClauses,116);return null===t||void 0===t?void 0:t.types}function Qr(n){return e.isInterfaceDeclaration(n)?Zr(n)||e.emptyArray:e.isClassLike(n)&&e.concatenate(e.singleElementArray(Jr(n)),Yr(n))||e.emptyArray}function Zr(e){var n=$r(e.heritageClauses,93);return n?n.types:void 0}function $r(e,n){if(e)for(var t=0,r=e;t<r.length;t++){var a=r[t];if(a.token===n)return a}}function ea(e,n){while(e){if(e.kind===n)return e;e=e.parent}}function na(e){return 80<=e&&e<=157}function ta(e){return 125<=e&&e<=157}function ra(e){return na(e)&&!ta(e)}function aa(e){return 116<=e&&e<=124}function ia(n){var t=e.stringToToken(n);return void 0!==t&&ra(t)}function oa(n){var t=e.stringToToken(n);return void 0!==t&&na(t)}function sa(e){var n=e.originalKeywordKind;return!!n&&!ta(n)}function ca(e){return 2<=e&&e<=7}function la(e){if(!e)return 4;var n=0;switch(e.kind){case 252:case 209:case 166:e.asteriskToken&&(n|=1);case 210:eo(e,256)&&(n|=2);break}return e.body||(n|=4),n}function ua(e){switch(e.kind){case 252:case 209:case 210:case 166:return void 0!==e.body&&void 0===e.asteriskToken&&eo(e,256)}return!1}function da(n){return e.isStringLiteralLike(n)||e.isNumericLiteral(n)}function pa(n){return e.isPrefixUnaryExpression(n)&&(39===n.operator||40===n.operator)&&e.isNumericLiteral(n.operand)}function fa(n){var t=e.getNameOfDeclaration(n);return!!t&&ma(t)}function ma(n){if(159!==n.kind&&203!==n.kind)return!1;var t=e.isElementAccessExpression(n)?wr(n.argumentExpression):n.expression;return!da(t)&&!pa(t)}function _a(n){switch(n.kind){case 78:case 79:return n.escapedText;case 10:case 8:return e.escapeLeadingUnderscores(n.text);case 159:var t=n.expression;return da(t)?e.escapeLeadingUnderscores(t.text):pa(t)?40===t.operator?e.tokenToString(t.operator)+t.operand.text:t.operand.text:void 0;default:return e.Debug.assertNever(n)}}function ga(e){switch(e.kind){case 78:case 10:case 14:case 8:return!0;default:return!1}}function ya(n){return e.isMemberName(n)?e.idText(n):n.text}function ha(n){return e.isMemberName(n)?n.escapedText:e.escapeLeadingUnderscores(n.text)}function va(n){return"__@"+e.getSymbolId(n)+"@"+n.escapedName}function ba(n,t){return"__#"+e.getSymbolId(n)+"@"+t}function Ea(n){return e.startsWith(n.escapedName,"__@")}function Ta(e){return 78===e.kind&&"Symbol"===e.escapedText}function Sa(e){return"push"===e.escapedText||"unshift"===e.escapedText}function xa(e){var n=La(e);return 161===n.kind}function La(e){while(199===e.kind)e=e.parent.parent;return e}function Da(e){var n=e.kind;return 167===n||209===n||252===n||210===n||166===n||168===n||169===n||257===n||298===n}function Aa(e){return Ul(e.pos)||Ul(e.end)}function Ca(n){return e.getParseTreeNode(n,e.isSourceFile)||n}function Ia(e){var n=Ra(e),t=205===e.kind&&void 0!==e.arguments;return Na(e.kind,n,t)}function Na(e,n,t){switch(e){case 205:return t?0:1;case 215:case 212:case 213:case 211:case 214:case 218:case 220:return 1;case 217:switch(n){case 42:case 62:case 63:case 64:case 66:case 65:case 67:case 68:case 69:case 70:case 71:case 72:case 77:case 73:case 74:case 75:case 76:return 1}}return 0}function ka(e){var n=Ra(e),t=205===e.kind&&void 0!==e.arguments;return Oa(e.kind,n,t)}function Ra(e){return 217===e.kind?e.operatorToken.kind:215===e.kind||216===e.kind?e.operator:e.kind}function Oa(e,n,t){switch(e){case 341:return 0;case 221:return 1;case 220:return 2;case 218:return 4;case 217:switch(n){case 27:return 0;case 62:case 63:case 64:case 66:case 65:case 67:case 68:case 69:case 70:case 71:case 72:case 77:case 73:case 74:case 75:case 76:return 3;default:return wa(n)}case 207:case 226:case 215:case 212:case 213:case 211:case 214:return 16;case 216:return 17;case 204:return 18;case 205:return t?19:18;case 206:case 202:case 203:case 227:return 19;case 225:return 11;case 107:case 105:case 78:case 103:case 109:case 94:case 8:case 9:case 10:case 200:case 201:case 209:case 210:case 222:case 13:case 14:case 219:case 208:case 223:case 274:case 275:case 278:return 20;default:return-1}}function wa(e){switch(e){case 60:return 4;case 56:return 5;case 55:return 6;case 51:return 7;case 52:return 8;case 50:return 9;case 34:case 35:case 36:case 37:return 10;case 29:case 31:case 32:case 33:case 101:case 100:case 126:return 11;case 47:case 48:case 49:return 12;case 39:case 40:return 13;case 41:case 43:case 44:return 14;case 42:return 15}return-1}function Pa(n){return e.filter(n,(function(e){switch(e.kind){case 284:return!!e.expression;case 11:return!e.containsOnlyTriviaWhiteSpaces;default:return!0}}))}function Ma(){var n=[],t=[],r=new e.Map,a=!1;return{add:o,lookup:i,getGlobalDiagnostics:s,getDiagnostics:c};function i(t){var a;if(a=t.file?r.get(t.file.fileName):n,a){var i=e.binarySearch(a,t,e.identity,Tc);return i>=0?a[i]:void 0}}function o(i){var o;i.file?(o=r.get(i.file.fileName),o||(o=[],r.set(i.file.fileName,o),e.insertSorted(t,i.file.fileName,e.compareStringsCaseSensitive))):(a&&(a=!1,n=n.slice()),o=n),e.insertSorted(o,i,Ec)}function s(){return a=!0,n}function c(a){if(a)return r.get(a)||[];var i=e.flatMapToMutable(t,(function(e){return r.get(e)}));return n.length?(i.unshift.apply(i,n),i):i}}e.isPartOfTypeNode=fn,e.isChildOfNodeWithKind=mn,e.forEachReturnStatement=_n,e.forEachYieldExpression=gn,e.getRestParameterElementType=yn,e.getMembersOfDeclaration=hn,e.isVariableLike=vn,e.isVariableLikeOrAccessor=bn,e.isVariableDeclarationInVariableStatement=En,e.isValidESSymbolDeclaration=Tn,e.introducesArgumentsExoticObject=Sn,e.unwrapInnermostStatementOfLabel=xn,e.isFunctionBlock=Ln,e.isObjectLiteralMethod=Dn,e.isObjectLiteralOrClassExpressionMethod=An,e.isIdentifierTypePredicate=Cn,e.isThisTypePredicate=In,e.getPropertyAssignment=Nn,e.getPropertyArrayElementValue=kn,e.getTsConfigObjectLiteralExpression=Rn,e.getTsConfigPropArrayElementValue=On,e.getTsConfigPropArray=wn,e.getContainingFunction=Pn,e.getContainingFunctionDeclaration=Mn,e.getContainingClass=Fn,e.getThisContainer=Gn,e.isInTopLevelContext=Bn,e.getNewTargetContainer=Un,e.getSuperContainer=Vn,e.getImmediatelyInvokedFunctionExpression=jn,e.isSuperOrSuperProperty=Kn,e.isSuperProperty=Hn,e.isThisProperty=Wn,e.isThisInitializedDeclaration=zn,e.isThisInitializedObjectBindingExpression=qn,e.getEntityNameFromTypeNode=Jn,e.getInvokedExpression=Xn,e.nodeCanBeDecorated=Yn,e.nodeIsDecorated=Qn,e.nodeOrChildIsDecorated=Zn,e.childIsDecorated=$n,e.isJSXTagName=et,e.isExpressionNode=nt,e.isInExpressionContext=tt,e.isPartOfTypeQuery=rt,e.isNamespaceReexportDeclaration=at,e.isExternalModuleImportEqualsDeclaration=it,e.getExternalModuleImportEqualsDeclarationExpression=ot,e.getExternalModuleRequireArgument=st,e.isInternalModuleImportEqualsDeclaration=ct,e.isSourceFileJS=lt,e.isSourceFileNotJS=ut,e.isInJSFile=dt,e.isInJsonFile=pt,e.isSourceFileNotJson=ft,e.isInJSDoc=mt,e.isJSDocIndexSignature=_t,e.isRequireCall=gt,e.isRequireVariableDeclaration=yt,e.isRequireVariableStatement=ht,e.isSingleOrDoubleQuote=vt,e.isStringDoubleQuoted=bt,e.isAssignmentDeclaration=Et,e.getEffectiveInitializer=Tt,e.getDeclaredExpandoInitializer=St,e.getAssignedExpandoInitializer=Lt,e.getExpandoInitializer=Dt,e.isDefaultedExpandoInitializer=Ct,e.getNameOfExpando=It,e.isSameEntityName=Nt,e.getRightMostAssignedExpression=kt,e.isExportsIdentifier=Rt,e.isModuleIdentifier=Ot,e.isModuleExportsAccessExpression=wt,e.getAssignmentDeclarationKind=Pt,e.isBindableObjectDefinePropertyCall=Mt,e.isLiteralLikeAccess=Ft,e.isLiteralLikeElementAccess=Gt,e.isBindableStaticAccessExpression=Bt,e.isBindableStaticElementAccessExpression=Ut,e.isBindableStaticNameExpression=Vt,e.getNameOrArgument=jt,e.getElementOrPropertyAccessArgumentExpressionOrName=Wt,e.getElementOrPropertyAccessName=zt,e.getAssignmentDeclarationPropertyAccessKind=qt,e.getInitializerOfBinaryExpression=Jt,e.isPrototypePropertyAssignment=Xt,e.isSpecialPropertyDeclaration=Yt,e.setValueDeclaration=Qt,e.isFunctionSymbol=Zt,e.tryGetModuleSpecifierFromDeclaration=$t,e.importFromModuleSpecifier=er,e.tryGetImportFromModuleSpecifier=nr,e.getExternalModuleName=tr,e.getNamespaceDeclarationNode=rr,e.isDefaultImport=ar,e.forEachImportClauseDeclaration=ir,e.hasQuestionToken=or,e.isJSDocConstructSignature=sr,e.isJSDocTypeAlias=cr,e.isTypeAlias=lr,e.getSingleInitializerOfVariableStatementOrPropertyDeclaration=pr,e.getSingleVariableOfVariableStatement=fr,e.getJSDocCommentsAndTags=_r,e.getNextJSDocCommentLocation=gr,e.getParameterSymbolFromJSDoc=yr,e.getHostSignatureFromJSDoc=hr,e.getEffectiveJSDocHost=vr,e.getJSDocHost=br,e.getJSDocRoot=Er,e.getTypeParameterFromJsDoc=Tr,e.hasRestParameter=Sr,e.isRestParameter=xr,e.hasTypeArguments=Lr,function(e){e[e["None"]=0]="None",e[e["Definite"]=1]="Definite",e[e["Compound"]=2]="Compound"}(e.AssignmentKind||(e.AssignmentKind={})),e.getAssignmentTargetKind=Dr,e.isAssignmentTarget=Ar,e.isNodeWithPossibleHoistedDeclaration=Cr,e.isValueSignatureDeclaration=Ir,e.walkUpParenthesizedTypes=kr,e.walkUpParenthesizedExpressions=Rr,e.walkUpParenthesizedTypesAndGetParentAndChild=Or,e.skipParentheses=wr,e.isDeleteTarget=Mr,e.isNodeDescendantOf=Fr,e.isDeclarationName=Gr,e.getDeclarationFromName=Br,e.isLiteralComputedPropertyDeclarationName=Ur,e.isIdentifierName=Vr,e.isAliasSymbolDeclaration=jr,e.getAliasDeclarationFromName=Kr,e.isAliasableExpression=Hr,e.exportAssignmentIsAlias=Wr,e.getExportAssignmentExpression=zr,e.getPropertyAssignmentAliasLikeExpression=qr,e.getEffectiveBaseTypeNode=Jr,e.getClassExtendsHeritageElement=Xr,e.getEffectiveImplementsTypeNodes=Yr,e.getAllSuperTypeNodes=Qr,e.getInterfaceBaseTypeNodes=Zr,e.getHeritageClause=$r,e.getAncestor=ea,e.isKeyword=na,e.isContextualKeyword=ta,e.isNonContextualKeyword=ra,e.isFutureReservedKeyword=aa,e.isStringANonContextualKeyword=ia,e.isStringAKeyword=oa,e.isIdentifierANonContextualKeyword=sa,e.isTrivia=ca,function(e){e[e["Normal"]=0]="Normal",e[e["Generator"]=1]="Generator",e[e["Async"]=2]="Async",e[e["Invalid"]=4]="Invalid",e[e["AsyncGenerator"]=3]="AsyncGenerator"}(e.FunctionFlags||(e.FunctionFlags={})),e.getFunctionFlags=la,e.isAsyncFunction=ua,e.isStringOrNumericLiteralLike=da,e.isSignedNumericLiteral=pa,e.hasDynamicName=fa,e.isDynamicName=ma,e.getPropertyNameForPropertyNameNode=_a,e.isPropertyNameLiteral=ga,e.getTextOfIdentifierOrLiteral=ya,e.getEscapedTextOfIdentifierOrLiteral=ha,e.getPropertyNameForUniqueESSymbol=va,e.getSymbolNameForPrivateIdentifier=ba,e.isKnownSymbol=Ea,e.isESSymbolIdentifier=Ta,e.isPushOrUnshiftIdentifier=Sa,e.isParameterDeclaration=xa,e.getRootDeclaration=La,e.nodeStartsNewLexicalEnvironment=Da,e.nodeIsSynthesized=Aa,e.getOriginalSourceFile=Ca,function(e){e[e["Left"]=0]="Left",e[e["Right"]=1]="Right"}(e.Associativity||(e.Associativity={})),e.getExpressionAssociativity=Ia,e.getOperatorAssociativity=Na,e.getExpressionPrecedence=ka,e.getOperator=Ra,function(e){e[e["Comma"]=0]="Comma",e[e["Spread"]=1]="Spread",e[e["Yield"]=2]="Yield",e[e["Assignment"]=3]="Assignment",e[e["Conditional"]=4]="Conditional",e[e["Coalesce"]=4]="Coalesce",e[e["LogicalOR"]=5]="LogicalOR",e[e["LogicalAND"]=6]="LogicalAND",e[e["BitwiseOR"]=7]="BitwiseOR",e[e["BitwiseXOR"]=8]="BitwiseXOR",e[e["BitwiseAND"]=9]="BitwiseAND",e[e["Equality"]=10]="Equality",e[e["Relational"]=11]="Relational",e[e["Shift"]=12]="Shift",e[e["Additive"]=13]="Additive",e[e["Multiplicative"]=14]="Multiplicative",e[e["Exponentiation"]=15]="Exponentiation",e[e["Unary"]=16]="Unary",e[e["Update"]=17]="Update",e[e["LeftHandSide"]=18]="LeftHandSide",e[e["Member"]=19]="Member",e[e["Primary"]=20]="Primary",e[e["Highest"]=20]="Highest",e[e["Lowest"]=0]="Lowest",e[e["Invalid"]=-1]="Invalid"}(e.OperatorPrecedence||(e.OperatorPrecedence={})),e.getOperatorPrecedence=Oa,e.getBinaryOperatorPrecedence=wa,e.getSemanticJsxChildren=Pa,e.createDiagnosticCollection=Ma;var Fa=/\$\{/g;function Ga(e){return e.replace(Fa,"\\${")}function Ba(n){return n&&!!(e.isNoSubstitutionTemplateLiteral(n)?n.templateFlags:n.head.templateFlags||e.some(n.templateSpans,(function(e){return!!e.literal.templateFlags})))}e.hasInvalidEscape=Ba;var Ua=/[\\\"\u0000-\u001f\t\v\f\b\r\n\u2028\u2029\u0085]/g,Va=/[\\\'\u0000-\u001f\t\v\f\b\r\n\u2028\u2029\u0085]/g,ja=/[\\`]/g,Ka=new e.Map(e.getEntries({"\t":"\\t","\v":"\\v","\f":"\\f","\b":"\\b","\r":"\\r","\n":"\\n","\\":"\\\\",'"':'\\"',"'":"\\'","`":"\\`","\u2028":"\\u2028","\u2029":"\\u2029","":"\\u0085"}));function Ha(e){var n=e.toString(16).toUpperCase(),t=("0000"+n).slice(-4);return"\\u"+t}function Wa(e,n,t){if(0===e.charCodeAt(0)){var r=t.charCodeAt(n+e.length);return r>=48&&r<=57?"\\x00":"\\0"}return Ka.get(e)||Ha(e.charCodeAt(0))}function za(e,n){var t=96===n?ja:39===n?Va:Ua;return e.replace(t,Wa)}e.escapeString=za;var qa=/[^\u0000-\u007F]/g;function Ja(e,n){return e=za(e,n),qa.test(e)?e.replace(qa,(function(e){return Ha(e.charCodeAt(0))})):e}e.escapeNonAsciiString=Ja;var Xa=/[\"\u0000-\u001f\u2028\u2029\u0085]/g,Ya=/[\'\u0000-\u001f\u2028\u2029\u0085]/g,Qa=new e.Map(e.getEntries({'"':"&quot;","'":"&apos;"}));function Za(e){var n=e.toString(16).toUpperCase();return"&#x"+n+";"}function $a(e){return 0===e.charCodeAt(0)?"&#0;":Qa.get(e)||Za(e.charCodeAt(0))}function ei(e,n){var t=39===n?Ya:Xa;return e.replace(t,$a)}function ni(e){var n=e.length;return n>=2&&e.charCodeAt(0)===e.charCodeAt(n-1)&&ti(e.charCodeAt(0))?e.substring(1,n-1):e}function ti(e){return 39===e||34===e||96===e}function ri(n){var t=n.charCodeAt(0);return t>=97&&t<=122||e.stringContains(n,"-")||e.stringContains(n,":")}e.escapeJsxAttributeString=ei,e.stripQuotes=ni,e.isIntrinsicJsxName=ri;var ai=["","    "];function ii(e){for(var n=ai[1],t=ai.length;t<=e;t++)ai.push(ai[t-1]+n);return ai[e]}function oi(){return ai[1].length}function si(n){var t,r,a,i,o,s=!1;function c(n){var r=e.computeLineStarts(n);r.length>1?(i=i+r.length-1,o=t.length-n.length+e.last(r),a=o-t.length===0):a=!1}function l(e){e&&e.length&&(a&&(e=ii(r)+e,a=!1),t+=e,c(e))}function u(e){e&&(s=!1),l(e)}function d(e){e&&(s=!0),l(e)}function p(){t="",r=0,a=!0,i=0,o=0,s=!1}function f(e){void 0!==e&&(t+=e,c(e),s=!1)}function m(e){e&&e.length&&u(e)}function _(e){a&&!e||(t+=n,i++,o=t.length,a=!0,s=!1)}function g(){return a?t.length:t.length+n.length}return p(),{write:u,rawWrite:f,writeLiteral:m,writeLine:_,increaseIndent:function(){r++},decreaseIndent:function(){r--},getIndent:function(){return r},getTextPos:function(){return t.length},getLine:function(){return i},getColumn:function(){return a?r*oi():t.length-o},getText:function(){return t},isAtStartOfLine:function(){return a},hasTrailingComment:function(){return s},hasTrailingWhitespace:function(){return!!t.length&&e.isWhiteSpaceLike(t.charCodeAt(t.length-1))},clear:p,reportInaccessibleThisError:e.noop,reportPrivateInBaseOfClassExpression:e.noop,reportInaccessibleUniqueSymbolError:e.noop,trackSymbol:e.noop,writeKeyword:u,writeOperator:u,writeParameter:u,writeProperty:u,writePunctuation:u,writeSpace:u,writeStringLiteral:u,writeSymbol:function(e,n){return u(e)},writeTrailingSemicolon:u,writeComment:d,getTextPosWithWriteLine:g}}function ci(e){var n=!1;function t(){n&&(e.writeTrailingSemicolon(";"),n=!1)}return o(o({},e),{writeTrailingSemicolon:function(){n=!0},writeLiteral:function(n){t(),e.writeLiteral(n)},writeStringLiteral:function(n){t(),e.writeStringLiteral(n)},writeSymbol:function(n,r){t(),e.writeSymbol(n,r)},writePunctuation:function(n){t(),e.writePunctuation(n)},writeKeyword:function(n){t(),e.writeKeyword(n)},writeOperator:function(n){t(),e.writeOperator(n)},writeParameter:function(n){t(),e.writeParameter(n)},writeSpace:function(n){t(),e.writeSpace(n)},writeProperty:function(n){t(),e.writeProperty(n)},writeComment:function(n){t(),e.writeComment(n)},writeLine:function(){t(),e.writeLine()},increaseIndent:function(){t(),e.increaseIndent()},decreaseIndent:function(){t(),e.decreaseIndent()}})}function li(e){return!!e.useCaseSensitiveFileNames&&e.useCaseSensitiveFileNames()}function ui(n){return e.createGetCanonicalFileName(li(n))}function di(e,n,t){return n.moduleName||mi(e,n.fileName,t&&t.fileName)}function pi(n,t){return n.getCanonicalFileName(e.getNormalizedAbsolutePath(t,n.getCurrentDirectory()))}function fi(n,t,r){var a=t.getExternalModuleFileFromDeclaration(r);if(a&&!a.isDeclarationFile){var i=tr(r);if(!i||!e.isStringLiteralLike(i)||e.pathIsRelative(i.text)||-1!==pi(n,a.path).indexOf(pi(n,e.ensureTrailingDirectorySeparator(n.getCommonSourceDirectory()))))return di(n,a)}}function mi(n,t,r){var a=function(e){return n.getCanonicalFileName(e)},i=e.toPath(r?e.getDirectoryPath(r):n.getCommonSourceDirectory(),n.getCurrentDirectory(),a),o=e.getNormalizedAbsolutePath(t,n.getCurrentDirectory()),s=e.getRelativePathToDirectoryOrUrl(i,o,i,a,!1),c=Pl(s);return r?e.ensurePathIsNonModuleName(c):c}function _i(e,n,t){var r,a=n.getCompilerOptions();return r=a.outDir?Pl(Ti(e,n,a.outDir)):Pl(e),r+t}function gi(e,n){return yi(e,n.getCompilerOptions(),n.getCurrentDirectory(),n.getCommonSourceDirectory(),(function(e){return n.getCanonicalFileName(e)}))}function yi(e,n,t,r,a){var i=n.declarationDir||n.outDir,o=i?Si(e,i,t,r,a):e;return Pl(o)+".d.ts"}function hi(e){return e.outFile||e.out}function vi(n,t){var r,a;if(n.paths)return null!==(r=n.baseUrl)&&void 0!==r?r:e.Debug.checkDefined(n.pathsBasePath||(null===(a=t.getCurrentDirectory)||void 0===a?void 0:a.call(t)),"Encountered 'paths' without a 'baseUrl', config file, or host 'getCurrentDirectory'.")}function bi(n,t,r){var a=n.getCompilerOptions();if(hi(a)){var i=Ac(a),o=a.emitDeclarationOnly||i===e.ModuleKind.AMD||i===e.ModuleKind.System;return e.filter(n.getSourceFiles(),(function(t){return(o||!e.isExternalModule(t))&&Ei(t,n,r)}))}var s=void 0===t?n.getSourceFiles():[t];return e.filter(s,(function(e){return Ei(e,n,r)}))}function Ei(e,n,t){var r=n.getCompilerOptions();return!(r.noEmitForJsFiles&&lt(e))&&!e.isDeclarationFile&&!n.isSourceFileFromExternalLibrary(e)&&(t||!(Je(e)&&n.getResolvedProjectReferenceToRedirect(e.fileName))&&!n.isSourceOfProjectReferenceRedirect(e.fileName))}function Ti(e,n,t){return Si(e,t,n.getCurrentDirectory(),n.getCommonSourceDirectory(),(function(e){return n.getCanonicalFileName(e)}))}function Si(n,t,r,a,i){var o=e.getNormalizedAbsolutePath(n,r),s=0===i(o).indexOf(i(a));return o=s?o.substring(a.length):o,e.combinePaths(t,o)}function xi(n,t,r,a,i,o){n.writeFile(r,a,i,(function(n){t.add(gc(e.Diagnostics.Could_not_write_file_0_Colon_1,r,n))}),o)}function Li(n,t,r){if(n.length>e.getRootLength(n)&&!r(n)){var a=e.getDirectoryPath(n);Li(a,t,r),t(n)}}function Di(n,t,r,a,i,o){try{a(n,t,r)}catch(s){Li(e.getDirectoryPath(e.normalizePath(n)),i,o),a(n,t,r)}}function Ai(n,t){var r=e.getLineStarts(n);return e.computeLineOfPosition(r,t)}function Ci(n,t){return e.computeLineOfPosition(n,t)}function Ii(n){return e.find(n.members,(function(n){return e.isConstructorDeclaration(n)&&M(n.body)}))}function Ni(e){if(e&&e.parameters.length>0){var n=2===e.parameters.length&&Oi(e.parameters[0]);return e.parameters[n?1:0]}}function ki(e){var n=Ni(e);return n&&n.type}function Ri(n){if(n.parameters.length&&!e.isJSDocSignature(n)){var t=n.parameters[0];if(Oi(t))return t}}function Oi(e){return wi(e.name)}function wi(e){return!!e&&78===e.kind&&Pi(e)}function Pi(e){return 107===e.originalKeywordKind}function Mi(n,t){var r,a,i,o;return fa(t)?(r=t,168===t.kind?i=t:169===t.kind?o=t:e.Debug.fail("Accessor has wrong kind")):e.forEach(n,(function(n){if(e.isAccessor(n)&&eo(n,32)===eo(t,32)){var s=_a(n.name),c=_a(t.name);s===c&&(r?a||(a=n):r=n,168!==n.kind||i||(i=n),169!==n.kind||o||(o=n))}})),{firstAccessor:r,secondAccessor:a,getAccessor:i,setAccessor:o}}function Fi(n){if(dt(n)||!e.isFunctionDeclaration(n)){var t=n.type;return t||!dt(n)?t:e.isJSDocPropertyLikeTag(n)?n.typeExpression&&n.typeExpression.type:e.getJSDocType(n)}}function Gi(e){return e.type}function Bi(n){return e.isJSDocSignature(n)?n.type&&n.type.typeExpression&&n.type.typeExpression.type:n.type||(dt(n)?e.getJSDocReturnType(n):void 0)}function Ui(n){return e.flatMap(e.getJSDocTags(n),(function(e){return Vi(e)?e.typeParameters:void 0}))}function Vi(n){return e.isJSDocTemplateTag(n)&&!(312===n.parent.kind&&n.parent.tags.some(cr))}function ji(e){var n=Ni(e);return n&&Fi(n)}function Ki(e,n,t,r){Hi(e,n,t.pos,r)}function Hi(e,n,t,r){r&&r.length&&t!==r[0].pos&&Ci(e,t)!==Ci(e,r[0].pos)&&n.writeLine()}function Wi(e,n,t,r){t!==r&&Ci(e,t)!==Ci(e,r)&&n.writeLine()}function zi(e,n,t,r,a,i,o,s){if(r&&r.length>0){a&&t.writeSpace(" ");for(var c=!1,l=0,u=r;l<u.length;l++){var d=u[l];c&&(t.writeSpace(" "),c=!1),s(e,n,t,d.pos,d.end,o),d.hasTrailingNewLine?t.writeLine():c=!0}c&&i&&t.writeSpace(" ")}}function qi(n,t,r,a,i,o,s){var c,l;if(s?0===i.pos&&(c=e.filter(e.getLeadingCommentRanges(n,i.pos),h)):c=e.getLeadingCommentRanges(n,i.pos),c){for(var u=[],d=void 0,p=0,f=c;p<f.length;p++){var m=f[p];if(d){var _=Ci(t,d.end),g=Ci(t,m.pos);if(g>=_+2)break}u.push(m),d=m}if(u.length){_=Ci(t,e.last(u).end);var y=Ci(t,e.skipTrivia(n,i.pos));y>=_+2&&(Ki(t,r,i,c),zi(n,t,r,u,!1,!0,o,a),l={nodePos:i.pos,detachedCommentEndPos:e.last(u).end})}}return l;function h(e){return W(n,e.pos)}}function Ji(n,t,r,a,i,o){if(42===n.charCodeAt(a+1))for(var s=e.computeLineAndCharacterOfPosition(t,a),c=t.length,l=void 0,u=a,d=s.line;u<i;d++){var p=d+1===c?n.length+1:t[d+1];if(u!==a){void 0===l&&(l=Yi(n,t[s.line],a));var f=r.getIndent()*oi(),m=f-l+Yi(n,u,p);if(m>0){var _=m%oi(),g=ii((m-_)/oi());r.rawWrite(g);while(_)r.rawWrite(" "),_--}else r.rawWrite("")}Xi(n,i,r,o,u,p),u=p}else r.writeComment(n.substring(a,i))}function Xi(e,n,t,r,a,i){var o=Math.min(n,i-1),s=e.substring(a,o).replace(/^\s+|\s+$/g,"");s?(t.writeComment(s),o!==n&&t.writeLine()):t.rawWrite(r)}function Yi(n,t,r){for(var a=0;t<r&&e.isWhiteSpaceSingleLine(n.charCodeAt(t));t++)9===n.charCodeAt(t)?a+=oi()-a%oi():a++;return a}function Qi(e){return 0!==lo(e)}function Zi(e){return 0!==po(e)}function $i(e,n){return!!oo(e,n)}function eo(e,n){return!!so(e,n)}function no(e){return eo(e,32)}function to(e){return $i(e,16384)}function ro(e){return eo(e,128)}function ao(e){return eo(e,2)}function io(e){return $i(e,64)}function oo(e,n){return lo(e)&n}function so(e,n){return po(e)&n}function co(e,n,t){return e.kind>=0&&e.kind<=157?0:(536870912&e.modifierFlagsCache||(e.modifierFlagsCache=536870912|_o(e)),!n||4096&e.modifierFlagsCache||!t&&!dt(e)||!e.parent||(e.modifierFlagsCache|=4096|fo(e)),-536875009&e.modifierFlagsCache)}function lo(e){return co(e,!0)}function uo(e){return co(e,!0,!0)}function po(e){return co(e,!1)}function fo(n){var t=0;return n.parent&&!e.isParameter(n)&&(dt(n)&&(e.getJSDocPublicTagNoCache(n)&&(t|=4),e.getJSDocPrivateTagNoCache(n)&&(t|=8),e.getJSDocProtectedTagNoCache(n)&&(t|=16),e.getJSDocReadonlyTagNoCache(n)&&(t|=64),e.getJSDocOverrideTagNoCache(n)&&(t|=16384)),e.getJSDocDeprecatedTagNoCache(n)&&(t|=8192)),t}function mo(e){return _o(e)|fo(e)}function _o(e){var n=go(e.modifiers);return(4&e.flags||78===e.kind&&e.isInJSDocNamespace)&&(n|=1),n}function go(e){var n=0;if(e)for(var t=0,r=e;t<r.length;t++){var a=r[t];n|=yo(a.kind)}return n}function yo(e){switch(e){case 123:return 32;case 122:return 4;case 121:return 16;case 120:return 8;case 125:return 128;case 92:return 1;case 133:return 2;case 84:return 2048;case 87:return 512;case 129:return 256;case 142:return 64;case 156:return 16384}return 0}function ho(n){return n?e.factory.createNodeArray(e.factory.createModifiersFromModifierFlags(n)):void 0}function vo(e){return 56===e||55===e||53===e}function bo(e){return 74===e||75===e||76===e}function Eo(e){return bo(e.operatorToken.kind)}function To(e){return e>=62&&e<=77}function So(e){var n=xo(e);return n&&!n.isImplements?n.class:void 0}function xo(n){return e.isExpressionWithTypeArguments(n)&&e.isHeritageClause(n.parent)&&e.isClassLike(n.parent.parent)?{class:n.parent.parent,isImplements:116===n.parent.token}:void 0}function Lo(n,t){return e.isBinaryExpression(n)&&(t?62===n.operatorToken.kind:To(n.operatorToken.kind))&&e.isLeftHandSideExpression(n.left)}function Do(e){return Lo(e.parent)&&e.parent.left===e}function Ao(e){if(Lo(e,!0)){var n=e.left.kind;return 201===n||200===n}return!1}function Co(e){return void 0!==So(e)}function Io(e){return 78===e.kind||Ro(e)}function No(e){switch(e.kind){case 78:return e;case 158:do{e=e.left}while(78!==e.kind);return e;case 202:do{e=e.expression}while(78!==e.kind);return e}}function ko(e){return 78===e.kind||107===e.kind||105===e.kind||227===e.kind||202===e.kind&&ko(e.expression)||208===e.kind&&ko(e.expression)}function Ro(n){return e.isPropertyAccessExpression(n)&&e.isIdentifier(n.name)&&Io(n.expression)}function Oo(n){if(e.isPropertyAccessExpression(n)){var t=Oo(n.expression);if(void 0!==t)return t+"."+Pe(n.name)}else if(e.isElementAccessExpression(n)){t=Oo(n.expression);if(void 0!==t&&e.isPropertyName(n.argumentExpression))return t+"."+_a(n.argumentExpression)}else if(e.isIdentifier(n))return e.unescapeLeadingUnderscores(n.escapedText)}function wo(e){return Bt(e)&&"prototype"===zt(e)}function Po(e){return 158===e.parent.kind&&e.parent.right===e||202===e.parent.kind&&e.parent.name===e}function Mo(e){return 201===e.kind&&0===e.properties.length}function Fo(e){return 200===e.kind&&0===e.elements.length}function Go(e){if(Bo(e)&&e.declarations)for(var n=0,t=e.declarations;n<t.length;n++){var r=t[n];if(r.localSymbol)return r.localSymbol}}function Bo(n){return n&&e.length(n.declarations)>0&&eo(n.declarations[0],512)}function Uo(n){return e.find(e.supportedTSExtensionsForExtractExtension,(function(t){return e.fileExtensionIs(n,t)}))}function Vo(n){for(var t=[],r=n.length,a=0;a<r;a++){var i=n.charCodeAt(a);i<128?t.push(i):i<2048?(t.push(i>>6|192),t.push(63&i|128)):i<65536?(t.push(i>>12|224),t.push(i>>6&63|128),t.push(63&i|128)):i<131072?(t.push(i>>18|240),t.push(i>>12&63|128),t.push(i>>6&63|128),t.push(63&i|128)):e.Debug.assert(!1,"Unexpected code point")}return t}e.getIndentString=ii,e.getIndentSize=oi,e.createTextWriter=si,e.getTrailingSemicolonDeferringWriter=ci,e.hostUsesCaseSensitiveFileNames=li,e.hostGetCanonicalFileName=ui,e.getResolvedExternalModuleName=di,e.getExternalModuleNameFromDeclaration=fi,e.getExternalModuleNameFromPath=mi,e.getOwnEmitOutputFilePath=_i,e.getDeclarationEmitOutputFilePath=gi,e.getDeclarationEmitOutputFilePathWorker=yi,e.outFile=hi,e.getPathsBasePath=vi,e.getSourceFilesToEmit=bi,e.sourceFileMayBeEmitted=Ei,e.getSourceFilePathInNewDir=Ti,e.getSourceFilePathInNewDirWorker=Si,e.writeFile=xi,e.writeFileEnsuringDirectories=Di,e.getLineOfLocalPosition=Ai,e.getLineOfLocalPositionFromLineMap=Ci,e.getFirstConstructorWithBody=Ii,e.getSetAccessorValueParameter=Ni,e.getSetAccessorTypeAnnotationNode=ki,e.getThisParameter=Ri,e.parameterIsThisKeyword=Oi,e.isThisIdentifier=wi,e.identifierIsThisKeyword=Pi,e.getAllAccessorDeclarations=Mi,e.getEffectiveTypeAnnotationNode=Fi,e.getTypeAnnotationNode=Gi,e.getEffectiveReturnTypeNode=Bi,e.getJSDocTypeParameterDeclarations=Ui,e.getEffectiveSetAccessorTypeAnnotationNode=ji,e.emitNewLineBeforeLeadingComments=Ki,e.emitNewLineBeforeLeadingCommentsOfPosition=Hi,e.emitNewLineBeforeLeadingCommentOfPosition=Wi,e.emitComments=zi,e.emitDetachedComments=qi,e.writeCommentRange=Ji,e.hasEffectiveModifiers=Qi,e.hasSyntacticModifiers=Zi,e.hasEffectiveModifier=$i,e.hasSyntacticModifier=eo,e.hasStaticModifier=no,e.hasOverrideModifier=to,e.hasAbstractModifier=ro,e.hasAmbientModifier=ao,e.hasEffectiveReadonlyModifier=io,e.getSelectedEffectiveModifierFlags=oo,e.getSelectedSyntacticModifierFlags=so,e.getEffectiveModifierFlags=lo,e.getEffectiveModifierFlagsAlwaysIncludeJSDoc=uo,e.getSyntacticModifierFlags=po,e.getEffectiveModifierFlagsNoCache=mo,e.getSyntacticModifierFlagsNoCache=_o,e.modifiersToFlags=go,e.modifierToFlag=yo,e.createModifiers=ho,e.isLogicalOperator=vo,e.isLogicalOrCoalescingAssignmentOperator=bo,e.isLogicalOrCoalescingAssignmentExpression=Eo,e.isAssignmentOperator=To,e.tryGetClassExtendingExpressionWithTypeArguments=So,e.tryGetClassImplementingOrExtendingExpressionWithTypeArguments=xo,e.isAssignmentExpression=Lo,e.isLeftHandSideOfAssignment=Do,e.isDestructuringAssignment=Ao,e.isExpressionWithTypeArgumentsInClassExtendsClause=Co,e.isEntityNameExpression=Io,e.getFirstIdentifier=No,e.isDottedName=ko,e.isPropertyAccessEntityNameExpression=Ro,e.tryGetPropertyAccessOrIdentifierToString=Oo,e.isPrototypeAccess=wo,e.isRightSideOfQualifiedNameOrPropertyAccess=Po,e.isEmptyObjectLiteral=Mo,e.isEmptyArrayLiteral=Fo,e.getLocalSymbolForExportDefault=Go,e.tryExtractTSExtension=Uo;var jo="ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/=";function Ko(e){var n,t,r,a,i="",o=Vo(e),s=0,c=o.length;while(s<c)n=o[s]>>2,t=(3&o[s])<<4|o[s+1]>>4,r=(15&o[s+1])<<2|o[s+2]>>6,a=63&o[s+2],s+1>=c?r=a=64:s+2>=c&&(a=64),i+=jo.charAt(n)+jo.charAt(t)+jo.charAt(r)+jo.charAt(a),s+=3;return i}function Ho(e){var n="",t=0,r=e.length;while(t<r){var a=e[t];if(a<128)n+=String.fromCharCode(a),t++;else if(192===(192&a)){var i=63&a;t++;var o=e[t];while(128===(192&o))i=i<<6|63&o,t++,o=e[t];n+=String.fromCharCode(i)}else n+=String.fromCharCode(a),t++}return n}function Wo(e,n){return e&&e.base64encode?e.base64encode(n):Ko(n)}function zo(e,n){if(e&&e.base64decode)return e.base64decode(n);var t=n.length,r=[],a=0;while(a<t){if(n.charCodeAt(a)===jo.charCodeAt(64))break;var i=jo.indexOf(n[a]),o=jo.indexOf(n[a+1]),s=jo.indexOf(n[a+2]),c=jo.indexOf(n[a+3]),l=(63&i)<<2|o>>4&3,u=(15&o)<<4|s>>2&15,d=(3&s)<<6|63&c;0===u&&0!==s?r.push(l):0===d&&0!==c?r.push(l,u):r.push(l,u,d),a+=4}return Ho(r)}function qo(n,t){try{var r=t.readFile(n);if(!r)return{};var a=e.parseConfigFileTextToJson(n,r);return a.error?{}:a.config}catch(i){return{}}}function Jo(e,n){return!n.directoryExists||n.directoryExists(e)}e.convertToBase64=Ko,e.base64encode=Wo,e.base64decode=zo,e.readJson=qo,e.directoryProbablyExists=Jo;var Xo,Yo="\r\n",Qo="\n";function Zo(n,t){switch(n.newLine){case 0:return Yo;case 1:return Qo}return t?t():e.sys?e.sys.newLine:Yo}function $o(n,t){return void 0===t&&(t=n),e.Debug.assert(t>=n||-1===t),{pos:n,end:t}}function es(e,n){return $o(e.pos,n)}function ns(e,n){return $o(n,e.end)}function ts(e){return e.decorators&&e.decorators.length>0?ns(e,e.decorators.end):e}function rs(e){return e.modifiers&&e.modifiers.length>0?ns(e,e.modifiers.end):ts(e)}function as(e){return e.pos===e.end}function is(n,t){return $o(n,n+e.tokenToString(t).length)}function os(e,n){return ls(e,e,n)}function ss(e,n,t){return ms(_s(e,t,!1),_s(n,t,!1),t)}function cs(e,n,t){return ms(e.end,n.end,t)}function ls(e,n,t){return ms(_s(e,t,!1),n.end,t)}function us(e,n,t){return ms(e.end,_s(n,t,!1),t)}function ds(n,t,r,a){var i=_s(t,r,a);return e.getLinesBetweenPositions(r,n.end,i)}function ps(n,t,r){return e.getLinesBetweenPositions(r,n.end,t.end)}function fs(e,n){return!ms(e.pos,e.end,n)}function ms(n,t,r){return 0===e.getLinesBetweenPositions(r,n,t)}function _s(n,t,r){return Ul(n.pos)?-1:e.skipTrivia(t.text,n.pos,!1,r)}function gs(n,t,r,a){var i=e.skipTrivia(r.text,n,!1,a),o=hs(i,t,r);return e.getLinesBetweenPositions(r,null!==o&&void 0!==o?o:t,i)}function ys(n,t,r,a){var i=e.skipTrivia(r.text,n,!1,a);return e.getLinesBetweenPositions(r,n,Math.min(t,i))}function hs(n,t,r){void 0===t&&(t=0);while(n-- >t)if(!e.isWhiteSpaceLike(r.text.charCodeAt(n)))return n}function vs(n){var t=e.getParseTreeNode(n);if(t)switch(t.parent.kind){case 256:case 257:return t===t.parent.name}return!1}function bs(n){return e.filter(n.declarations,Es)}function Es(e){return void 0!==e.initializer}function Ts(e){return e.watch&&e.hasOwnProperty("watch")}function Ss(e){e.close()}function xs(e){return 33554432&e.flags?e.checkFlags:0}function Ls(n,t){if(void 0===t&&(t=!1),n.valueDeclaration){var r=t&&n.declarations&&e.find(n.declarations,(function(e){return 169===e.kind}))||n.valueDeclaration,a=e.getCombinedModifierFlags(r);return n.parent&&32&n.parent.flags?a:-29&a}if(6&xs(n)){var i=n.checkFlags,o=1024&i?8:256&i?4:16,s=2048&i?32:0;return o|s}return 4194304&n.flags?36:0}function Ds(e,n){return 2097152&e.flags?n.getAliasedSymbol(e):e}function As(e){return e.exportSymbol?e.exportSymbol.flags|e.flags:e.flags}function Cs(e){return 1===Ns(e)}function Is(e){return 0!==Ns(e)}function Ns(e){var n=e.parent;if(!n)return 0;switch(n.kind){case 208:return Ns(n);case 216:case 215:var t=n.operator;return 45===t||46===t?s():0;case 217:var r=n,a=r.left,i=r.operatorToken;return a===e&&To(i.kind)?62===i.kind?1:s():0;case 202:return n.name!==e?0:Ns(n);case 289:var o=Ns(n.parent);return e===n.name?ks(o):o;case 290:return e===n.objectAssignmentInitializer?0:Ns(n.parent);case 200:return Ns(n);default:return 0}function s(){return n.parent&&234===Pr(n.parent).kind?1:2}}function ks(n){switch(n){case 0:return 1;case 1:return 0;case 2:return 2;default:return e.Debug.assertNever(n)}}function Rs(e,n){if(!e||!n||Object.keys(e).length!==Object.keys(n).length)return!1;for(var t in e)if("object"===typeof e[t]){if(!Rs(e[t],n[t]))return!1}else if("function"!==typeof e[t]&&e[t]!==n[t])return!1;return!0}function Os(e,n){e.forEach(n),e.clear()}function ws(e,n,t){var r=t.onDeleteValue,a=t.onExistingValue;e.forEach((function(t,i){var o=n.get(i);void 0===o?(e.delete(i),r(t,i)):a&&a(t,o,i)}))}function Ps(e,n,t){ws(e,n,t);var r=t.createNewValue;n.forEach((function(n,t){e.has(t)||e.set(t,r(t,n))}))}function Ms(e){if(32&e.flags){var n=Fs(e);return!!n&&eo(n,128)}return!1}function Fs(n){var t;return null===(t=n.declarations)||void 0===t?void 0:t.find(e.isClassLike)}function Gs(e){return 3899393&e.flags?e.objectFlags:0}function Bs(e,n){return 0!==n.getSignaturesOfType(e,0).length||0!==n.getSignaturesOfType(e,1).length}function Us(n,t){return!!e.forEachAncestorDirectory(n,(function(e){return!!t(e)||void 0}))}function Vs(n){return!!n&&!!n.declarations&&!!n.declarations[0]&&e.isNamespaceExportDeclaration(n.declarations[0])}function js(n){var t=n.moduleSpecifier;return e.isStringLiteral(t)?t.text:$(t)}function Ks(n){var t;return e.forEachChild(n,(function(e){M(e)&&(t=e)}),(function(e){for(var n=e.length-1;n>=0;n--)if(M(e[n])){t=e[n];break}})),t}function Hs(e,n,t){return void 0===t&&(t=!0),!e.has(n)&&(e.set(n,t),!0)}function Ws(n){return e.isClassLike(n)||e.isInterfaceDeclaration(n)||e.isTypeLiteralNode(n)}function zs(e){return e>=173&&e<=196||128===e||152===e||144===e||155===e||145===e||131===e||147===e||148===e||113===e||150===e||141===e||224===e||304===e||305===e||306===e||307===e||308===e||309===e||310===e}function qs(e){return 202===e.kind||203===e.kind}function Js(n){return 202===n.kind?n.name:(e.Debug.assert(203===n.kind),n.argumentExpression)}function Xs(e){switch(e.kind){case"text":case"internal":return!0;default:return!1}}function Ys(e){return 265===e.kind||269===e.kind}function Qs(e){while(qs(e))e=e.expression;return e}function Zs(e,n){while(1){switch(e.kind){case 216:e=e.operand;continue;case 217:e=e.left;continue;case 218:e=e.condition;continue;case 206:e=e.tag;continue;case 204:if(n)return e;case 225:case 203:case 202:case 226:case 340:e=e.expression;continue}return e}}function $s(e,n){this.flags=e,this.escapedName=n,this.declarations=void 0,this.valueDeclaration=void 0,this.id=void 0,this.mergeId=void 0,this.parent=void 0}function ec(n,t){this.flags=t,(e.Debug.isDebugging||e.tracing)&&(this.checker=n)}function nc(n,t){this.flags=t,e.Debug.isDebugging&&(this.checker=n)}function tc(e,n,t){this.pos=n,this.end=t,this.kind=e,this.id=0,this.flags=0,this.modifierFlagsCache=0,this.transformFlags=0,this.parent=void 0,this.original=void 0}function rc(e,n,t){this.pos=n,this.end=t,this.kind=e,this.id=0,this.flags=0,this.transformFlags=0,this.parent=void 0}function ac(e,n,t){this.pos=n,this.end=t,this.kind=e,this.id=0,this.flags=0,this.transformFlags=0,this.parent=void 0,this.original=void 0,this.flowNode=void 0}function ic(e,n,t){this.fileName=e,this.text=n,this.skipTrivia=t||function(e){return e}}function oc(n){e.objectAllocator=n}function sc(n,t,r){return void 0===r&&(r=0),n.replace(/{(\d+)}/g,(function(n,a){return""+e.Debug.checkDefined(t[+a+r])}))}function cc(n){e.localizedDiagnosticMessages=n}function lc(n){return e.localizedDiagnosticMessages&&e.localizedDiagnosticMessages[n.key]||n.message}function uc(e,n,t,r){Ue(void 0,n,t);var a=lc(r);return arguments.length>4&&(a=sc(a,arguments,4)),{file:void 0,start:n,length:t,messageText:a,category:r.category,code:r.code,reportsUnnecessary:r.reportsUnnecessary,fileName:e}}function dc(e){return void 0===e.file&&void 0!==e.start&&void 0!==e.length&&"string"===typeof e.fileName}function pc(n,t){var r=t.fileName||"",a=t.text.length;e.Debug.assertEqual(n.fileName,r),e.Debug.assertLessThanOrEqual(n.start,a),e.Debug.assertLessThanOrEqual(n.start+n.length,a);var i={file:t,start:n.start,length:n.length,messageText:n.messageText,category:n.category,code:n.code,reportsUnnecessary:n.reportsUnnecessary};if(n.relatedInformation){i.relatedInformation=[];for(var o=0,s=n.relatedInformation;o<s.length;o++){var c=s[o];dc(c)&&c.fileName===r?(e.Debug.assertLessThanOrEqual(c.start,a),e.Debug.assertLessThanOrEqual(c.start+c.length,a),i.relatedInformation.push(pc(c,t))):i.relatedInformation.push(c)}}return i}function fc(e,n){for(var t=[],r=0,a=e;r<a.length;r++){var i=a[r];t.push(pc(i,n))}return t}function mc(e,n,t,r){Ue(e,n,t);var a=lc(r);return arguments.length>4&&(a=sc(a,arguments,4)),{file:e,start:n,length:t,messageText:a,category:r.category,code:r.code,reportsUnnecessary:r.reportsUnnecessary,reportsDeprecated:r.reportsDeprecated}}function _c(e,n){var t=lc(n);return arguments.length>2&&(t=sc(t,arguments,2)),t}function gc(e){var n=lc(e);return arguments.length>1&&(n=sc(n,arguments,1)),{file:void 0,start:void 0,length:void 0,messageText:n,category:e.category,code:e.code,reportsUnnecessary:e.reportsUnnecessary,reportsDeprecated:e.reportsDeprecated}}function yc(e,n){return{file:void 0,start:void 0,length:void 0,code:e.code,category:e.category,messageText:e.next?e:e.messageText,relatedInformation:n}}function hc(e,n){var t=lc(n);return arguments.length>2&&(t=sc(t,arguments,2)),{messageText:t,category:n.category,code:n.code,next:void 0===e||Array.isArray(e)?e:[e]}}function vc(e,n){var t=e;while(t.next)t=t.next[0];t.next=[n]}function bc(e){return e.file?e.file.path:void 0}function Ec(e,n){return Tc(e,n)||Sc(e,n)||0}function Tc(n,t){return e.compareStringsCaseSensitive(bc(n),bc(t))||e.compareValues(n.start,t.start)||e.compareValues(n.length,t.length)||e.compareValues(n.code,t.code)||xc(n.messageText,t.messageText)||0}function Sc(n,t){return n.relatedInformation||t.relatedInformation?n.relatedInformation&&t.relatedInformation?e.compareValues(n.relatedInformation.length,t.relatedInformation.length)||e.forEach(n.relatedInformation,(function(e,n){var r=t.relatedInformation[n];return Ec(e,r)}))||0:n.relatedInformation?-1:1:0}function xc(n,t){if("string"===typeof n&&"string"===typeof t)return e.compareStringsCaseSensitive(n,t);if("string"===typeof n)return-1;if("string"===typeof t)return 1;var r=e.compareStringsCaseSensitive(n.messageText,t.messageText);if(r)return r;if(!n.next&&!t.next)return 0;if(!n.next)return-1;if(!t.next)return 1;for(var a=Math.min(n.next.length,t.next.length),i=0;i<a;i++)if(r=xc(n.next[i],t.next[i]),r)return r;return n.next.length<t.next.length?-1:n.next.length>t.next.length?1:0}function Lc(e){return 4===e||2===e||1===e||6===e?1:0}function Dc(e){return e.target||0}function Ac(n){return"number"===typeof n.module?n.module:Dc(n)>=2?e.ModuleKind.ES2015:e.ModuleKind.CommonJS}function Cc(n){var t=n.moduleResolution;return void 0===t&&(t=Ac(n)===e.ModuleKind.CommonJS?e.ModuleResolutionKind.NodeJs:e.ModuleResolutionKind.Classic),t}function Ic(n){switch(Ac(n)){case e.ModuleKind.CommonJS:case e.ModuleKind.AMD:case e.ModuleKind.ES2015:case e.ModuleKind.ES2020:case e.ModuleKind.ESNext:return!0;default:return!1}}function Nc(e){return!1===e.allowUnreachableCode}function kc(e){return!1===e.allowUnusedLabels}function Rc(e){return!(!wc(e)||!e.declarationMap)}function Oc(n){var t=Ac(n);return void 0!==n.allowSyntheticDefaultImports?n.allowSyntheticDefaultImports:n.esModuleInterop||t===e.ModuleKind.System}function wc(e){return!(!e.declaration&&!e.composite)}function Pc(e){return!(!e.preserveConstEnums&&!e.isolatedModules)}function Mc(e){return!(!e.incremental&&!e.composite)}function Fc(e,n){return void 0===e[n]?!!e.strict:!!e[n]}function Gc(e){return void 0===e.allowJs?!!e.checkJs:e.allowJs}function Bc(e){return void 0===e.useDefineForClassFields?99===e.target:e.useDefineForClassFields}function Uc(n,t){return t!==n&&e.semanticDiagnosticsOptionDeclarations.some((function(e){return!eu(jc(t,e),jc(n,e))}))}function Vc(n,t){return t!==n&&e.affectsEmitOptionDeclarations.some((function(e){return!eu(jc(t,e),jc(n,e))}))}function jc(e,n){return n.strictFlag?Fc(e,n.name):e[n.name]}function Kc(e){var n=e.jsx;return 2===n||4===n||5===n}function Hc(n,t){var r=null===t||void 0===t?void 0:t.pragmas.get("jsximportsource"),a=e.isArray(r)?r[r.length-1]:r;return 4===n.jsx||5===n.jsx||n.jsxImportSource||a?(null===a||void 0===a?void 0:a.arguments.factory)||n.jsxImportSource||"react":void 0}function Wc(e,n){return e?e+"/"+(5===n.jsx?"jsx-dev-runtime":"jsx-runtime"):void 0}function zc(e){for(var n=!1,t=0;t<e.length;t++)if(42===e.charCodeAt(t)){if(n)return!1;n=!0}return!0}function qc(n,t){var r,a,i;return{getSymlinkedFiles:function(){return i},getSymlinkedDirectories:function(){return r},getSymlinkedDirectoriesByRealpath:function(){return a},setSymlinkedFile:function(n,t){return(i||(i=new e.Map)).set(n,t)},setSymlinkedDirectory:function(i,o){var s=e.toPath(i,n,t);bu(s)||(s=e.ensureTrailingDirectorySeparator(s),!1===o||(null===r||void 0===r?void 0:r.has(s))||(a||(a=e.createMultiMap())).add(e.ensureTrailingDirectorySeparator(o.realPath),i),(r||(r=new e.Map)).set(s,o))},setSymlinkedDirectoryFromSymlinkedFile:function(r,a){this.setSymlinkedFile(e.toPath(r,n,t),a);var i=Xc(a,r,n,t)||e.emptyArray,o=i[0],s=i[1];o&&s&&this.setSymlinkedDirectory(s,{real:o,realPath:e.toPath(o,n,t)})}}}function Jc(n,t,r){for(var a=qc(r,t),i=e.flatMap(n,(function(n){var t=n.resolvedModules&&e.arrayFrom(e.mapDefinedIterator(n.resolvedModules.values(),(function(e){return(null===e||void 0===e?void 0:e.originalPath)?[e.resolvedFileName,e.originalPath]:void 0})));return e.concatenate(t,n.resolvedTypeReferenceDirectiveNames&&e.arrayFrom(e.mapDefinedIterator(n.resolvedTypeReferenceDirectiveNames.values(),(function(e){return(null===e||void 0===e?void 0:e.originalPath)&&e.resolvedFileName?[e.resolvedFileName,e.originalPath]:void 0}))))})),o=0,s=i;o<s.length;o++){var c=s[o],l=c[0],u=c[1];a.setSymlinkedFile(e.toPath(u,r,t),l);var d=Xc(l,u,r,t)||e.emptyArray,p=d[0],f=d[1];p&&f&&a.setSymlinkedDirectory(f,{real:p,realPath:e.toPath(p,r,t)})}return a}function Xc(n,t,r,a){var i=e.getPathComponents(e.getNormalizedAbsolutePath(n,r)),o=e.getPathComponents(e.getNormalizedAbsolutePath(t,r)),s=!1;while(!Yc(i[i.length-2],a)&&!Yc(o[o.length-2],a)&&a(i[i.length-1])===a(o[o.length-1]))i.pop(),o.pop(),s=!0;return s?[e.getPathFromPathComponents(i),e.getPathFromPathComponents(o)]:void 0}function Yc(n,t){return"node_modules"===t(n)||e.startsWith(n,"@")}function Qc(n){return e.isAnyDirectorySeparator(n.charCodeAt(0))?n.slice(1):void 0}function Zc(n,t,r){var a=e.tryRemovePrefix(n,t,r);return void 0===a?void 0:Qc(a)}e.getNewLineCharacter=Zo,e.createRange=$o,e.moveRangeEnd=es,e.moveRangePos=ns,e.moveRangePastDecorators=ts,e.moveRangePastModifiers=rs,e.isCollapsedRange=as,e.createTokenRange=is,e.rangeIsOnSingleLine=os,e.rangeStartPositionsAreOnSameLine=ss,e.rangeEndPositionsAreOnSameLine=cs,e.rangeStartIsOnSameLineAsRangeEnd=ls,e.rangeEndIsOnSameLineAsRangeStart=us,e.getLinesBetweenRangeEndAndRangeStart=ds,e.getLinesBetweenRangeEndPositions=ps,e.isNodeArrayMultiLine=fs,e.positionsAreOnSameLine=ms,e.getStartPositionOfRange=_s,e.getLinesBetweenPositionAndPrecedingNonWhitespaceCharacter=gs,e.getLinesBetweenPositionAndNextNonWhitespaceCharacter=ys,e.isDeclarationNameOfEnumOrNamespace=vs,e.getInitializedVariables=bs,e.isWatchSet=Ts,e.closeFileWatcher=Ss,e.getCheckFlags=xs,e.getDeclarationModifierFlagsFromSymbol=Ls,e.skipAlias=Ds,e.getCombinedLocalAndExportSymbolFlags=As,e.isWriteOnlyAccess=Cs,e.isWriteAccess=Is,function(e){e[e["Read"]=0]="Read",e[e["Write"]=1]="Write",e[e["ReadWrite"]=2]="ReadWrite"}(Xo||(Xo={})),e.compareDataObjects=Rs,e.clearMap=Os,e.mutateMapSkippingNewValues=ws,e.mutateMap=Ps,e.isAbstractConstructorSymbol=Ms,e.getClassLikeDeclarationOfSymbol=Fs,e.getObjectFlags=Gs,e.typeHasCallOrConstructSignatures=Bs,e.forSomeAncestorDirectory=Us,e.isUMDExportSymbol=Vs,e.showModuleSpecifier=js,e.getLastChild=Ks,e.addToSeen=Hs,e.isObjectTypeDeclaration=Ws,e.isTypeNodeKind=zs,e.isAccessExpression=qs,e.getNameOfAccessExpression=Js,e.isBundleFileTextLike=Xs,e.isNamedImportsOrExports=Ys,e.getLeftmostAccessExpression=Qs,e.getLeftmostExpression=Zs,e.objectAllocator={getNodeConstructor:function(){return tc},getTokenConstructor:function(){return rc},getIdentifierConstructor:function(){return ac},getPrivateIdentifierConstructor:function(){return tc},getSourceFileConstructor:function(){return tc},getSymbolConstructor:function(){return $s},getTypeConstructor:function(){return ec},getSignatureConstructor:function(){return nc},getSourceMapSourceConstructor:function(){return ic}},e.setObjectAllocator=oc,e.formatStringFromArgs=sc,e.setLocalizedDiagnosticMessages=cc,e.getLocaleSpecificMessage=lc,e.createDetachedDiagnostic=uc,e.attachFileToDiagnostics=fc,e.createFileDiagnostic=mc,e.formatMessage=_c,e.createCompilerDiagnostic=gc,e.createCompilerDiagnosticFromMessageChain=yc,e.chainDiagnosticMessages=hc,e.concatenateDiagnosticMessageChains=vc,e.compareDiagnostics=Ec,e.compareDiagnosticsSkipRelatedInformation=Tc,e.getLanguageVariant=Lc,e.getEmitScriptTarget=Dc,e.getEmitModuleKind=Ac,e.getEmitModuleResolutionKind=Cc,e.hasJsonModuleEmitEnabled=Ic,e.unreachableCodeIsError=Nc,e.unusedLabelIsError=kc,e.getAreDeclarationMapsEnabled=Rc,e.getAllowSyntheticDefaultImports=Oc,e.getEmitDeclarations=wc,e.shouldPreserveConstEnums=Pc,e.isIncrementalCompilation=Mc,e.getStrictOptionValue=Fc,e.getAllowJSCompilerOption=Gc,e.getUseDefineForClassFields=Bc,e.compilerOptionsAffectSemanticDiagnostics=Uc,e.compilerOptionsAffectEmit=Vc,e.getCompilerOptionValue=jc,e.getJSXTransformEnabled=Kc,e.getJSXImplicitImportBase=Hc,e.getJSXRuntimeImport=Wc,e.hasZeroOrOneAsteriskCharacter=zc,e.createSymlinkCache=qc,e.discoverProbableSymlinks=Jc,e.tryRemoveDirectoryPrefix=Zc;var $c=/[^\w\s\/]/g;function el(e){return e.replace($c,nl)}function nl(e){return"\\"+e}e.regExpEscape=el;var tl=[42,63];e.commonPackageFolders=["node_modules","bower_components","jspm_packages"];var rl="(?!("+e.commonPackageFolders.join("|")+")(/|$))",al={singleAsteriskRegexFragment:"([^./]|(\\.(?!min\\.js$))?)*",doubleAsteriskRegexFragment:"(/"+rl+"[^/.][^/]*)*?",replaceWildcardCharacter:function(e){return fl(e,al.singleAsteriskRegexFragment)}},il={singleAsteriskRegexFragment:"[^/]*",doubleAsteriskRegexFragment:"(/"+rl+"[^/.][^/]*)*?",replaceWildcardCharacter:function(e){return fl(e,il.singleAsteriskRegexFragment)}},ol={singleAsteriskRegexFragment:"[^/]*",doubleAsteriskRegexFragment:"(/.+?)?",replaceWildcardCharacter:function(e){return fl(e,ol.singleAsteriskRegexFragment)}},sl={files:al,directories:il,exclude:ol};function cl(e,n,t){var r=ll(e,n,t);if(r&&r.length){var a=r.map((function(e){return"("+e+")"})).join("|"),i="exclude"===t?"($|/)":"$";return"^("+a+")"+i}}function ll(n,t,r){if(void 0!==n&&0!==n.length)return e.flatMap(n,(function(e){return e&&pl(e,t,r,sl[r])}))}function ul(e){return!/[.*?]/.test(e)}function dl(e,n,t){var r=e&&pl(e,n,t,sl[t]);return r&&"^("+r+")"+("exclude"===t?"($|/)":"$")}function pl(n,t,r,a){var i=a.singleAsteriskRegexFragment,o=a.doubleAsteriskRegexFragment,s=a.replaceWildcardCharacter,c="",l=!1,u=e.getNormalizedPathComponents(n,t),d=e.last(u);if("exclude"===r||"**"!==d){u[0]=e.removeTrailingDirectorySeparator(u[0]),ul(d)&&u.push("**","*");for(var p=0,f=0,m=u;f<m.length;f++){var _=m[f];if("**"===_)c+=o;else if("directories"===r&&(c+="(",p++),l&&(c+=e.directorySeparator),"exclude"!==r){var g="";42===_.charCodeAt(0)?(g+="([^./]"+i+")?",_=_.substr(1)):63===_.charCodeAt(0)&&(g+="[^./]",_=_.substr(1)),g+=_.replace($c,s),g!==_&&(c+=rl),c+=g}else c+=_.replace($c,s);l=!0}while(p>0)c+=")?",p--;return c}}function fl(e,n){return"*"===e?n:"?"===e?"[^/]":"\\"+e}function ml(n,t,r,a,i){n=e.normalizePath(n),i=e.normalizePath(i);var o=e.combinePaths(i,n);return{includeFilePatterns:e.map(ll(r,o,"files"),(function(e){return"^"+e+"$"})),includeFilePattern:cl(r,o,"files"),includeDirectoryPattern:cl(r,o,"directories"),excludePattern:cl(t,o,"exclude"),basePaths:yl(n,r,a)}}function _l(e,n){return new RegExp(e,n?"":"i")}function gl(n,t,r,a,i,o,s,c,l){n=e.normalizePath(n),o=e.normalizePath(o);for(var u=ml(n,r,a,i,o),d=u.includeFilePatterns&&u.includeFilePatterns.map((function(e){return _l(e,i)})),p=u.includeDirectoryPattern&&_l(u.includeDirectoryPattern,i),f=u.excludePattern&&_l(u.excludePattern,i),m=d?d.map((function(){return[]})):[[]],_=new e.Map,g=e.createGetCanonicalFileName(i),y=0,h=u.basePaths;y<h.length;y++){var v=h[y];b(v,e.combinePaths(o,v),s)}return e.flatten(m);function b(n,r,a){var i=g(l(r));if(!_.has(i)){_.set(i,!0);for(var o=c(n),s=o.files,u=o.directories,y=function(a){var i=e.combinePaths(n,a),o=e.combinePaths(r,a);if(t&&!e.fileExtensionIsOneOf(i,t))return"continue";if(f&&f.test(o))return"continue";if(d){var s=e.findIndex(d,(function(e){return e.test(o)}));-1!==s&&m[s].push(i)}else m[0].push(i)},h=0,v=e.sort(s,e.compareStringsCaseSensitive);h<v.length;h++){var E=v[h];y(E)}if(void 0===a||(a--,0!==a))for(var T=0,S=e.sort(u,e.compareStringsCaseSensitive);T<S.length;T++){E=S[T];var x=e.combinePaths(n,E),L=e.combinePaths(r,E);p&&!p.test(L)||f&&f.test(L)||b(x,L,a)}}}}function yl(n,t,r){var a=[n];if(t){for(var i=[],o=0,s=t;o<s.length;o++){var c=s[o],l=e.isRootedDiskPath(c)?c:e.normalizePath(e.combinePaths(n,c));i.push(hl(l))}i.sort(e.getStringComparer(!r));for(var u=function(t){e.every(a,(function(a){return!e.containsPath(a,t,n,!r)}))&&a.push(t)},d=0,p=i;d<p.length;d++){var f=p[d];u(f)}}return a}function hl(n){var t=e.indexOfAnyCharCode(n,tl);return t<0?e.hasExtension(n)?e.removeTrailingDirectorySeparator(e.getDirectoryPath(n)):n:n.substring(0,n.lastIndexOf(e.directorySeparator,t))}function vl(e,n){return n||bl(e)||3}function bl(e){var n=e.substr(e.lastIndexOf("."));switch(n.toLowerCase()){case".js":return 1;case".jsx":return 2;case".ts":return 3;case".tsx":return 4;case".json":return 6;default:return 0}}e.getRegularExpressionForWildcard=cl,e.getRegularExpressionsForWildcards=ll,e.isImplicitGlob=ul,e.getPatternFromSpec=dl,e.getFileMatcherPatterns=ml,e.getRegexFromPattern=_l,e.matchFiles=gl,e.ensureScriptKind=vl,e.getScriptKindFromFileName=bl,e.supportedTSExtensions=[".ts",".tsx",".d.ts"],e.supportedTSExtensionsWithJson=[".ts",".tsx",".d.ts",".json"],e.supportedTSExtensionsForExtractExtension=[".d.ts",".ts",".tsx"],e.supportedJSExtensions=[".js",".jsx"],e.supportedJSAndJsonExtensions=[".js",".jsx",".json"];var El=i(i([],e.supportedTSExtensions),e.supportedJSExtensions),Tl=i(i(i([],e.supportedTSExtensions),e.supportedJSExtensions),[".json"]);function Sl(n,t){var r=n&&Gc(n);if(!t||0===t.length)return r?El:e.supportedTSExtensions;var a=i(i([],r?El:e.supportedTSExtensions),e.mapDefined(t,(function(e){return 7===e.scriptKind||r&&Ll(e.scriptKind)?e.extension:void 0})));return e.deduplicate(a,e.equateStringsCaseSensitive,e.compareStringsCaseSensitive)}function xl(n,t){return n&&n.resolveJsonModule?t===El?Tl:t===e.supportedTSExtensions?e.supportedTSExtensionsWithJson:i(i([],t),[".json"]):t}function Ll(e){return 1===e||2===e}function Dl(n){return e.some(e.supportedJSExtensions,(function(t){return e.fileExtensionIs(n,t)}))}function Al(n){return e.some(e.supportedTSExtensions,(function(t){return e.fileExtensionIs(n,t)}))}function Cl(n,t,r){if(!n)return!1;for(var a=Sl(t,r),i=0,o=xl(t,a);i<o.length;i++){var s=o[i];if(e.fileExtensionIs(n,s))return!0}return!1}function Il(e){var n=e.match(/\//g);return n?n.length:0}function Nl(n,t){return e.compareValues(Il(n),Il(t))}function kl(n,t){for(var r=t.length-1;r>=0;r--)if(e.fileExtensionIs(n,t[r]))return Rl(r,t);return 0}function Rl(e,n){return e<2?0:e<n.length?2:n.length}function Ol(e,n){return e<2?2:n.length}e.getSupportedExtensions=Sl,e.getSuppoertedExtensionsWithJsonIfResolveJsonModule=xl,e.hasJSFileExtension=Dl,e.hasTSFileExtension=Al,e.isSupportedSourceFileName=Cl,e.compareNumberOfDirectorySeparators=Nl,function(e){e[e["TypeScriptFiles"]=0]="TypeScriptFiles",e[e["DeclarationAndJavaScriptFiles"]=2]="DeclarationAndJavaScriptFiles",e[e["Highest"]=0]="Highest",e[e["Lowest"]=2]="Lowest"}(e.ExtensionPriority||(e.ExtensionPriority={})),e.getExtensionPriority=kl,e.adjustExtensionPriority=Rl,e.getNextLowestExtensionPriority=Ol;var wl=[".d.ts",".ts",".js",".tsx",".jsx",".json"];function Pl(e){for(var n=0,t=wl;n<t.length;n++){var r=t[n],a=Ml(e,r);if(void 0!==a)return a}return e}function Ml(n,t){return e.fileExtensionIs(n,t)?Fl(n,t):void 0}function Fl(e,n){return e.substring(0,e.length-n.length)}function Gl(n,t){return e.changeAnyExtension(n,t,wl,!1)}function Bl(n){e.Debug.assert(zc(n));var t=n.indexOf("*");return-1===t?void 0:{prefix:n.substr(0,t),suffix:n.substr(t+1)}}function Ul(e){return!(e>=0)}function Vl(e){return".ts"===e||".tsx"===e||".d.ts"===e}function jl(e){return Vl(e)||".json"===e}function Kl(n){var t=Wl(n);return void 0!==t?t:e.Debug.fail("File "+n+" has unknown extension.")}function Hl(e){return void 0!==Wl(e)}function Wl(n){return e.find(wl,(function(t){return e.fileExtensionIs(n,t)}))}function zl(e,n){return e.checkJsDirective?e.checkJsDirective.enabled:n.checkJs}function ql(n,t){for(var r=[],a=0,i=n;a<i.length;a++){var o=i[a];if(zc(o)){var s=Bl(o);if(s)r.push(s);else if(o===t)return o}}return e.findBestPatternMatch(r,(function(e){return e}),t)}function Jl(n,t){var r=n.indexOf(t);return e.Debug.assert(-1!==r),n.slice(r)}function Xl(n){for(var t,r=[],a=1;a<arguments.length;a++)r[a-1]=arguments[a];return r.length?(n.relatedInformation||(n.relatedInformation=[]),e.Debug.assert(n.relatedInformation!==e.emptyArray,"Diagnostic had empty array singleton for related info, but is still being constructed!"),(t=n.relatedInformation).push.apply(t,r),n):n}function Yl(n,t){e.Debug.assert(0!==n.length);for(var r=t(n[0]),a=r,i=1;i<n.length;i++){var o=t(n[i]);o<r?r=o:o>a&&(a=o)}return{min:r,max:a}}function Ql(e){return{pos:q(e),end:e.end}}function Zl(n,t){var r=t.pos-1,a=e.skipTrivia(n.text,t.end)+1;return{pos:r,end:a}}function $l(e,n,t){return n.skipLibCheck&&e.isDeclarationFile||n.skipDefaultLibCheck&&e.hasNoDefaultLib||t.isSourceOfProjectReferenceRedirect(e.fileName)}function eu(n,t){return n===t||"object"===typeof n&&null!==n&&"object"===typeof t&&null!==t&&e.equalOwnProperties(n,t,eu)}function nu(e){var n;switch(e.charCodeAt(1)){case 98:case 66:n=1;break;case 111:case 79:n=3;break;case 120:case 88:n=4;break;default:var t=e.length-1,r=0;while(48===e.charCodeAt(r))r++;return e.slice(r,t)||"0"}for(var a=2,i=e.length-1,o=(i-a)*n,s=new Uint16Array((o>>>4)+(15&o?1:0)),c=i-1,l=0;c>=a;c--,l+=n){var u=l>>>4,d=e.charCodeAt(c),p=d<=57?d-48:10+d-(d<=70?65:97),f=p<<(15&l);s[u]|=f;var m=f>>>16;m&&(s[u+1]|=m)}var _="",g=s.length-1,y=!0;while(y){var h=0;y=!1;for(u=g;u>=0;u--){var v=h<<16|s[u],b=v/10|0;s[u]=b,h=v-10*b,b&&!y&&(g=u,y=!0)}_=h+_}return _}function tu(e){var n=e.negative,t=e.base10Value;return(n&&"0"!==t?"-":"")+t}function ru(e){return!!(8388608&e.flags)||rt(e)||ou(e)||iu(e)||!nt(e)}function au(e){return 271===e.kind}function iu(e){while(78===e.kind||202===e.kind)e=e.parent;if(159!==e.kind)return!1;if(eo(e.parent,128))return!0;var n=e.parent.parent.kind;return 254===n||178===n}function ou(n){if(78!==n.kind)return!1;var t=e.findAncestor(n.parent,(function(e){switch(e.kind){case 287:return!0;case 202:case 224:return!1;default:return"quit"}}));return 116===(null===t||void 0===t?void 0:t.token)||254===(null===t||void 0===t?void 0:t.parent.kind)}function su(n){return e.isTypeReferenceNode(n)&&e.isIdentifier(n.typeName)}function cu(n,t){if(void 0===t&&(t=e.equateValues),n.length<2)return!0;for(var r=n[0],a=1,i=n.length;a<i;a++){var o=n[a];if(!t(r,o))return!1}return!0}function lu(e,n){return e.pos=n,e}function uu(e,n){return e.end=n,e}function du(e,n,t){return uu(lu(e,n),t)}function pu(e,n,t){return du(e,n,n+t)}function fu(e,n){return e&&(e.flags=n),e}function mu(e,n){return e&&n&&(e.parent=n),e}function _u(e,n){if(e)for(var t=0,r=e;t<r.length;t++){var a=r[t];mu(a,n)}return e}function gu(n,t){return n?(e.forEachChildRecursively(n,e.isJSDocNode(n)?r:i),n):n;function r(e,n){if(t&&e.parent===n)return"skip";mu(e,n)}function a(n){if(e.hasJSDocNodes(n))for(var t=0,a=n.jsDoc;t<a.length;t++){var i=a[t];r(i,n),e.forEachChildRecursively(i,r)}}function i(e,n){return r(e,n)||a(e)}}function yu(n){return!e.isOmittedExpression(n)}function hu(n){return e.isArrayLiteralExpression(n)&&e.every(n.elements,yu)}function vu(n){e.Debug.assertIsDefined(n.parent);while(1){var t=n.parent;if(e.isParenthesizedExpression(t))n=t;else{if(e.isExpressionStatement(t)||e.isVoidExpression(t)||e.isForStatement(t)&&(t.initializer===n||t.incrementor===n))return!0;if(e.isCommaListExpression(t)){if(n!==e.last(t.elements))return!0;n=t}else{if(!e.isBinaryExpression(t)||27!==t.operatorToken.kind)return!1;if(n===t.left)return!0;n=t}}}}function bu(n){return e.some(e.ignoredPaths,(function(t){return e.stringContains(n,t)}))}function Eu(n){if(n.parent){switch(n.kind){case 160:var t=n.parent;return 186===t.kind?void 0:t.typeParameters;case 161:return n.parent.parameters;case 195:return n.parent.templateSpans;case 229:return n.parent.templateSpans;case 162:return n.parent.decorators;case 287:return n.parent.heritageClauses}var r=n.parent;if(e.isJSDocTag(n))return e.isJSDocTypeLiteral(n.parent)?void 0:n.parent.tags;switch(r.kind){case 178:case 254:return e.isTypeElement(n)?r.members:void 0;case 183:case 184:return r.types;case 180:case 200:case 341:case 265:case 269:return r.elements;case 201:case 282:return r.properties;case 204:case 205:return e.isTypeNode(n)?r.typeArguments:r.expression===n?void 0:r.arguments;case 274:case 278:return e.isJsxChild(n)?r.children:void 0;case 276:case 275:return e.isTypeNode(n)?r.typeArguments:void 0;case 231:case 285:case 286:case 258:return r.statements;case 259:return r.clauses;case 253:case 222:return e.isClassElement(n)?r.members:void 0;case 256:return e.isEnumMember(n)?r.members:void 0;case 298:return r.statements}}}e.removeFileExtension=Pl,e.tryRemoveExtension=Ml,e.removeExtension=Fl,e.changeExtension=Gl,e.tryParsePattern=Bl,e.positionIsSynthesized=Ul,e.extensionIsTS=Vl,e.resolutionExtensionIsTSOrJson=jl,e.extensionFromPath=Kl,e.isAnySupportedFileExtension=Hl,e.tryGetExtensionFromPath=Wl,e.isCheckJsEnabledForFile=zl,e.emptyFileSystemEntries={files:e.emptyArray,directories:e.emptyArray},e.matchPatternOrExact=ql,e.sliceAfter=Jl,e.addRelatedInfo=Xl,e.minAndMax=Yl,e.rangeOfNode=Ql,e.rangeOfTypeParameters=Zl,e.skipTypeChecking=$l,e.isJsonEqual=eu,e.parsePseudoBigInt=nu,e.pseudoBigIntToString=tu,e.isValidTypeOnlyAliasUseSite=ru,e.typeOnlyDeclarationIsExport=au,e.isIdentifierTypeReference=su,e.arrayIsHomogeneous=cu,e.setTextRangePos=lu,e.setTextRangeEnd=uu,e.setTextRangePosEnd=du,e.setTextRangePosWidth=pu,e.setNodeFlags=fu,e.setParent=mu,e.setEachParent=_u,e.setParentRecursive=gu,e.isPackedArrayLiteral=hu,e.expressionResultIsUnused=vu,e.containsIgnoredPath=bu,e.getContainingNodeArray=Eu}(d||(d={})),function(e){function n(){var n,t,r,a,i;return{createBaseSourceFileNode:o,createBaseIdentifierNode:s,createBasePrivateIdentifierNode:c,createBaseTokenNode:l,createBaseNode:u};function o(n){return new(i||(i=e.objectAllocator.getSourceFileConstructor()))(n,-1,-1)}function s(n){return new(r||(r=e.objectAllocator.getIdentifierConstructor()))(n,-1,-1)}function c(n){return new(a||(a=e.objectAllocator.getPrivateIdentifierConstructor()))(n,-1,-1)}function l(n){return new(t||(t=e.objectAllocator.getTokenConstructor()))(n,-1,-1)}function u(t){return new(n||(n=e.objectAllocator.getNodeConstructor()))(t,-1,-1)}}e.createBaseNodeFactory=n}(d||(d={})),function(e){function n(n){var t,r;return{getParenthesizeLeftSideOfBinaryForOperator:a,getParenthesizeRightSideOfBinaryForOperator:i,parenthesizeLeftSideOfBinary:u,parenthesizeRightSideOfBinary:d,parenthesizeExpressionOfComputedPropertyName:p,parenthesizeConditionOfConditionalExpression:f,parenthesizeBranchOfConditionalExpression:m,parenthesizeExpressionOfExportDefault:_,parenthesizeExpressionOfNew:g,parenthesizeLeftSideOfAccess:y,parenthesizeOperandOfPostfixUnary:h,parenthesizeOperandOfPrefixUnary:v,parenthesizeExpressionsOfCommaDelimitedList:b,parenthesizeExpressionForDisallowedComma:E,parenthesizeExpressionOfExpressionStatement:T,parenthesizeConciseBodyOfArrowFunction:S,parenthesizeMemberOfConditionalType:x,parenthesizeMemberOfElementType:L,parenthesizeElementTypeOfArrayType:D,parenthesizeConstituentTypesOfUnionOrIntersectionType:A,parenthesizeTypeArguments:I};function a(n){t||(t=new e.Map);var r=t.get(n);return r||(r=function(e){return u(n,e)},t.set(n,r)),r}function i(n){r||(r=new e.Map);var t=r.get(n);return t||(t=function(e){return d(n,void 0,e)},r.set(n,t)),t}function o(n,t,r,a){var i=e.getOperatorPrecedence(217,n),o=e.getOperatorAssociativity(217,n),l=e.skipPartiallyEmittedExpressions(t);if(!r&&210===t.kind&&i>3)return!0;var u=e.getExpressionPrecedence(l);switch(e.compareValues(u,i)){case-1:return!(!r&&1===o&&220===t.kind);case 1:return!1;case 0:if(r)return 1===o;if(e.isBinaryExpression(l)&&l.operatorToken.kind===n){if(s(n))return!1;if(39===n){var d=a?c(a):0;if(e.isLiteralKind(d)&&d===c(l))return!1}}var p=e.getExpressionAssociativity(l);return 0===p}}function s(e){return 41===e||51===e||50===e||52===e}function c(n){if(n=e.skipPartiallyEmittedExpressions(n),e.isLiteralKind(n.kind))return n.kind;if(217===n.kind&&39===n.operatorToken.kind){if(void 0!==n.cachedLiteralKind)return n.cachedLiteralKind;var t=c(n.left),r=e.isLiteralKind(t)&&t===c(n.right)?t:0;return n.cachedLiteralKind=r,r}return 0}function l(t,r,a,i){var s=e.skipPartiallyEmittedExpressions(r);return 208===s.kind?r:o(t,r,a,i)?n.createParenthesizedExpression(r):r}function u(e,n){return l(e,n,!0)}function d(e,n,t){return l(e,t,!1,n)}function p(t){return e.isCommaSequence(t)?n.createParenthesizedExpression(t):t}function f(t){var r=e.getOperatorPrecedence(218,57),a=e.skipPartiallyEmittedExpressions(t),i=e.getExpressionPrecedence(a);return 1!==e.compareValues(i,r)?n.createParenthesizedExpression(t):t}function m(t){var r=e.skipPartiallyEmittedExpressions(t);return e.isCommaSequence(r)?n.createParenthesizedExpression(t):t}function _(t){var r=e.skipPartiallyEmittedExpressions(t),a=e.isCommaSequence(r);if(!a)switch(e.getLeftmostExpression(r,!1).kind){case 222:case 209:a=!0}return a?n.createParenthesizedExpression(t):t}function g(t){var r=e.getLeftmostExpression(t,!0);switch(r.kind){case 204:return n.createParenthesizedExpression(t);case 205:return r.arguments?t:n.createParenthesizedExpression(t)}return y(t)}function y(t){var r=e.skipPartiallyEmittedExpressions(t);return e.isLeftHandSideExpression(r)&&(205!==r.kind||r.arguments)?t:e.setTextRange(n.createParenthesizedExpression(t),t)}function h(t){return e.isLeftHandSideExpression(t)?t:e.setTextRange(n.createParenthesizedExpression(t),t)}function v(t){return e.isUnaryExpression(t)?t:e.setTextRange(n.createParenthesizedExpression(t),t)}function b(t){var r=e.sameMap(t,E);return e.setTextRange(n.createNodeArray(r,t.hasTrailingComma),t)}function E(t){var r=e.skipPartiallyEmittedExpressions(t),a=e.getExpressionPrecedence(r),i=e.getOperatorPrecedence(217,27);return a>i?t:e.setTextRange(n.createParenthesizedExpression(t),t)}function T(t){var r=e.skipPartiallyEmittedExpressions(t);if(e.isCallExpression(r)){var a=r.expression,i=e.skipPartiallyEmittedExpressions(a).kind;if(209===i||210===i){var o=n.updateCallExpression(r,e.setTextRange(n.createParenthesizedExpression(a),a),r.typeArguments,r.arguments);return n.restoreOuterExpressions(t,o,8)}}var s=e.getLeftmostExpression(r,!1).kind;return 201===s||209===s?e.setTextRange(n.createParenthesizedExpression(t),t):t}function S(t){return e.isBlock(t)||!e.isCommaSequence(t)&&201!==e.getLeftmostExpression(t,!1).kind?t:e.setTextRange(n.createParenthesizedExpression(t),t)}function x(e){return 185===e.kind?n.createParenthesizedType(e):e}function L(e){switch(e.kind){case 183:case 184:case 175:case 176:return n.createParenthesizedType(e)}return x(e)}function D(e){switch(e.kind){case 177:case 189:case 186:return n.createParenthesizedType(e)}return L(e)}function A(t){return n.createNodeArray(e.sameMap(t,L))}function C(t,r){return 0===r&&e.isFunctionOrConstructorTypeNode(t)&&t.typeParameters?n.createParenthesizedType(t):t}function I(t){if(e.some(t))return n.createNodeArray(e.sameMap(t,C))}}e.createParenthesizerRules=n,e.nullParenthesizerRules={getParenthesizeLeftSideOfBinaryForOperator:function(n){return e.identity},getParenthesizeRightSideOfBinaryForOperator:function(n){return e.identity},parenthesizeLeftSideOfBinary:function(e,n){return n},parenthesizeRightSideOfBinary:function(e,n,t){return t},parenthesizeExpressionOfComputedPropertyName:e.identity,parenthesizeConditionOfConditionalExpression:e.identity,parenthesizeBranchOfConditionalExpression:e.identity,parenthesizeExpressionOfExportDefault:e.identity,parenthesizeExpressionOfNew:function(n){return e.cast(n,e.isLeftHandSideExpression)},parenthesizeLeftSideOfAccess:function(n){return e.cast(n,e.isLeftHandSideExpression)},parenthesizeOperandOfPostfixUnary:function(n){return e.cast(n,e.isLeftHandSideExpression)},parenthesizeOperandOfPrefixUnary:function(n){return e.cast(n,e.isUnaryExpression)},parenthesizeExpressionsOfCommaDelimitedList:function(n){return e.cast(n,e.isNodeArray)},parenthesizeExpressionForDisallowedComma:e.identity,parenthesizeExpressionOfExpressionStatement:e.identity,parenthesizeConciseBodyOfArrowFunction:e.identity,parenthesizeMemberOfConditionalType:e.identity,parenthesizeMemberOfElementType:e.identity,parenthesizeElementTypeOfArrayType:e.identity,parenthesizeConstituentTypesOfUnionOrIntersectionType:function(n){return e.cast(n,e.isNodeArray)},parenthesizeTypeArguments:function(n){return n&&e.cast(n,e.isNodeArray)}}}(d||(d={})),function(e){function n(n){return{convertToFunctionBlock:t,convertToFunctionExpression:r,convertToArrayAssignmentElement:a,convertToObjectAssignmentElement:i,convertToAssignmentPattern:o,convertToObjectAssignmentPattern:s,convertToArrayAssignmentPattern:c,convertToAssignmentElementTarget:l};function t(t,r){if(e.isBlock(t))return t;var a=n.createReturnStatement(t);e.setTextRange(a,t);var i=n.createBlock([a],r);return e.setTextRange(i,t),i}function r(t){if(!t.body)return e.Debug.fail("Cannot convert a FunctionDeclaration without a body");var r=n.createFunctionExpression(t.modifiers,t.asteriskToken,t.name,t.typeParameters,t.parameters,t.type,t.body);return e.setOriginalNode(r,t),e.setTextRange(r,t),e.getStartsOnNewLine(t)&&e.setStartsOnNewLine(r,!0),r}function a(t){if(e.isBindingElement(t)){if(t.dotDotDotToken)return e.Debug.assertNode(t.name,e.isIdentifier),e.setOriginalNode(e.setTextRange(n.createSpreadElement(t.name),t),t);var r=l(t.name);return t.initializer?e.setOriginalNode(e.setTextRange(n.createAssignment(r,t.initializer),t),t):r}return e.cast(t,e.isExpression)}function i(t){if(e.isBindingElement(t)){if(t.dotDotDotToken)return e.Debug.assertNode(t.name,e.isIdentifier),e.setOriginalNode(e.setTextRange(n.createSpreadAssignment(t.name),t),t);if(t.propertyName){var r=l(t.name);return e.setOriginalNode(e.setTextRange(n.createPropertyAssignment(t.propertyName,t.initializer?n.createAssignment(r,t.initializer):r),t),t)}return e.Debug.assertNode(t.name,e.isIdentifier),e.setOriginalNode(e.setTextRange(n.createShorthandPropertyAssignment(t.name,t.initializer),t),t)}return e.cast(t,e.isObjectLiteralElementLike)}function o(e){switch(e.kind){case 198:case 200:return c(e);case 197:case 201:return s(e)}}function s(t){return e.isObjectBindingPattern(t)?e.setOriginalNode(e.setTextRange(n.createObjectLiteralExpression(e.map(t.elements,i)),t),t):e.cast(t,e.isObjectLiteralExpression)}function c(t){return e.isArrayBindingPattern(t)?e.setOriginalNode(e.setTextRange(n.createArrayLiteralExpression(e.map(t.elements,a)),t),t):e.cast(t,e.isArrayLiteralExpression)}function l(n){return e.isBindingPattern(n)?o(n):e.cast(n,e.isExpression)}}e.createNodeConverters=n,e.nullNodeConverters={convertToFunctionBlock:e.notImplemented,convertToFunctionExpression:e.notImplemented,convertToArrayAssignmentElement:e.notImplemented,convertToObjectAssignmentElement:e.notImplemented,convertToAssignmentPattern:e.notImplemented,convertToObjectAssignmentPattern:e.notImplemented,convertToArrayAssignmentPattern:e.notImplemented,convertToAssignmentElementTarget:e.notImplemented}}(d||(d={})),function(e){var n,t=0;function r(n,r){var c=8&n?a:o,d=e.memoize((function(){return 1&n?e.nullParenthesizerRules:e.createParenthesizerRules(A)})),_=e.memoize((function(){return 2&n?e.nullNodeConverters:e.createNodeConverters(A)})),g=e.memoizeOne((function(e){return function(n,t){return Ft(n,e,t)}})),y=e.memoizeOne((function(e){return function(n){return Ot(e,n)}})),h=e.memoizeOne((function(e){return function(n){return Pt(n,e)}})),v=e.memoizeOne((function(e){return function(){return Wa(e)}})),b=e.memoizeOne((function(e){return function(n){return za(e,n)}})),E=e.memoizeOne((function(e){return function(n,t){return qa(e,n,t)}})),T=e.memoizeOne((function(e){return function(n,t){return xi(e,n,t)}})),S=e.memoizeOne((function(e){return function(n,t,r){return Li(e,n,t,r)}})),x=e.memoizeOne((function(e){return function(n,t,r){return Di(e,n,t,r)}})),D=e.memoizeOne((function(e){return function(n,t,r,a){return Ai(e,n,t,r,a)}})),A={get parenthesizer(){return d()},get converters(){return _()},createNodeArray:C,createNumericLiteral:j,createBigIntLiteral:K,createStringLiteral:W,createStringLiteralFromNode:z,createRegularExpressionLiteral:q,createLiteralLikeNode:J,createIdentifier:Q,updateIdentifier:Z,createTempVariable:$,createLoopVariable:ee,createUniqueName:ne,getGeneratedNameForNode:te,createPrivateIdentifier:re,createToken:ie,createSuper:oe,createThis:se,createNull:ce,createTrue:le,createFalse:ue,createModifier:de,createModifiersFromModifierFlags:pe,createQualifiedName:fe,updateQualifiedName:me,createComputedPropertyName:_e,updateComputedPropertyName:ge,createTypeParameterDeclaration:ye,updateTypeParameterDeclaration:he,createParameterDeclaration:ve,updateParameterDeclaration:be,createDecorator:Ee,updateDecorator:Te,createPropertySignature:Se,updatePropertySignature:xe,createPropertyDeclaration:Le,updatePropertyDeclaration:De,createMethodSignature:Ae,updateMethodSignature:Ce,createMethodDeclaration:Ie,updateMethodDeclaration:Ne,createConstructorDeclaration:ke,updateConstructorDeclaration:Re,createGetAccessorDeclaration:Oe,updateGetAccessorDeclaration:we,createSetAccessorDeclaration:Pe,updateSetAccessorDeclaration:Me,createCallSignature:Fe,updateCallSignature:Ge,createConstructSignature:Be,updateConstructSignature:Ue,createIndexSignature:Ve,updateIndexSignature:je,createTemplateLiteralTypeSpan:Ke,updateTemplateLiteralTypeSpan:He,createKeywordTypeNode:We,createTypePredicateNode:ze,updateTypePredicateNode:qe,createTypeReferenceNode:Je,updateTypeReferenceNode:Xe,createFunctionTypeNode:Ye,updateFunctionTypeNode:Qe,createConstructorTypeNode:Ze,updateConstructorTypeNode:nn,createTypeQueryNode:an,updateTypeQueryNode:on,createTypeLiteralNode:sn,updateTypeLiteralNode:cn,createArrayTypeNode:ln,updateArrayTypeNode:un,createTupleTypeNode:dn,updateTupleTypeNode:pn,createNamedTupleMember:fn,updateNamedTupleMember:mn,createOptionalTypeNode:_n,updateOptionalTypeNode:gn,createRestTypeNode:yn,updateRestTypeNode:hn,createUnionTypeNode:En,updateUnionTypeNode:Tn,createIntersectionTypeNode:Sn,updateIntersectionTypeNode:xn,createConditionalTypeNode:Ln,updateConditionalTypeNode:Dn,createInferTypeNode:An,updateInferTypeNode:Cn,createImportTypeNode:kn,updateImportTypeNode:Rn,createParenthesizedType:On,updateParenthesizedType:wn,createThisTypeNode:Pn,createTypeOperatorNode:Mn,updateTypeOperatorNode:Fn,createIndexedAccessTypeNode:Gn,updateIndexedAccessTypeNode:Bn,createMappedTypeNode:Un,updateMappedTypeNode:Vn,createLiteralTypeNode:jn,updateLiteralTypeNode:Kn,createTemplateLiteralType:In,updateTemplateLiteralType:Nn,createObjectBindingPattern:Hn,updateObjectBindingPattern:Wn,createArrayBindingPattern:zn,updateArrayBindingPattern:qn,createBindingElement:Jn,updateBindingElement:Xn,createArrayLiteralExpression:Qn,updateArrayLiteralExpression:Zn,createObjectLiteralExpression:$n,updateObjectLiteralExpression:et,createPropertyAccessExpression:4&n?function(n,t){return e.setEmitFlags(nt(n,t),131072)}:nt,updatePropertyAccessExpression:tt,createPropertyAccessChain:4&n?function(n,t,r){return e.setEmitFlags(rt(n,t,r),131072)}:rt,updatePropertyAccessChain:at,createElementAccessExpression:it,updateElementAccessExpression:ot,createElementAccessChain:st,updateElementAccessChain:ct,createCallExpression:lt,updateCallExpression:ut,createCallChain:dt,updateCallChain:pt,createNewExpression:ft,updateNewExpression:mt,createTaggedTemplateExpression:_t,updateTaggedTemplateExpression:gt,createTypeAssertion:yt,updateTypeAssertion:ht,createParenthesizedExpression:vt,updateParenthesizedExpression:bt,createFunctionExpression:Et,updateFunctionExpression:Tt,createArrowFunction:St,updateArrowFunction:xt,createDeleteExpression:Lt,updateDeleteExpression:Dt,createTypeOfExpression:At,updateTypeOfExpression:Ct,createVoidExpression:It,updateVoidExpression:Nt,createAwaitExpression:kt,updateAwaitExpression:Rt,createPrefixUnaryExpression:Ot,updatePrefixUnaryExpression:wt,createPostfixUnaryExpression:Pt,updatePostfixUnaryExpression:Mt,createBinaryExpression:Ft,updateBinaryExpression:Bt,createConditionalExpression:Ut,updateConditionalExpression:Vt,createTemplateExpression:jt,updateTemplateExpression:Kt,createTemplateHead:zt,createTemplateMiddle:qt,createTemplateTail:Jt,createNoSubstitutionTemplateLiteral:Xt,createTemplateLiteralLikeNode:Wt,createYieldExpression:Yt,updateYieldExpression:Qt,createSpreadElement:Zt,updateSpreadElement:$t,createClassExpression:er,updateClassExpression:nr,createOmittedExpression:tr,createExpressionWithTypeArguments:rr,updateExpressionWithTypeArguments:ar,createAsExpression:ir,updateAsExpression:or,createNonNullExpression:sr,updateNonNullExpression:cr,createNonNullChain:lr,updateNonNullChain:ur,createMetaProperty:dr,updateMetaProperty:pr,createTemplateSpan:fr,updateTemplateSpan:mr,createSemicolonClassElement:_r,createBlock:gr,updateBlock:yr,createVariableStatement:hr,updateVariableStatement:vr,createEmptyStatement:br,createExpressionStatement:Er,updateExpressionStatement:Tr,createIfStatement:Sr,updateIfStatement:xr,createDoStatement:Lr,updateDoStatement:Dr,createWhileStatement:Ar,updateWhileStatement:Cr,createForStatement:Ir,updateForStatement:Nr,createForInStatement:kr,updateForInStatement:Rr,createForOfStatement:Or,updateForOfStatement:wr,createContinueStatement:Pr,updateContinueStatement:Mr,createBreakStatement:Fr,updateBreakStatement:Gr,createReturnStatement:Br,updateReturnStatement:Ur,createWithStatement:Vr,updateWithStatement:jr,createSwitchStatement:Kr,updateSwitchStatement:Hr,createLabeledStatement:Wr,updateLabeledStatement:zr,createThrowStatement:qr,updateThrowStatement:Jr,createTryStatement:Xr,updateTryStatement:Yr,createDebuggerStatement:Qr,createVariableDeclaration:Zr,updateVariableDeclaration:$r,createVariableDeclarationList:ea,updateVariableDeclarationList:na,createFunctionDeclaration:ta,updateFunctionDeclaration:ra,createClassDeclaration:aa,updateClassDeclaration:ia,createInterfaceDeclaration:oa,updateInterfaceDeclaration:sa,createTypeAliasDeclaration:ca,updateTypeAliasDeclaration:la,createEnumDeclaration:ua,updateEnumDeclaration:da,createModuleDeclaration:pa,updateModuleDeclaration:fa,createModuleBlock:ma,updateModuleBlock:_a,createCaseBlock:ga,updateCaseBlock:ya,createNamespaceExportDeclaration:ha,updateNamespaceExportDeclaration:va,createImportEqualsDeclaration:ba,updateImportEqualsDeclaration:Ea,createImportDeclaration:Ta,updateImportDeclaration:Sa,createImportClause:xa,updateImportClause:La,createNamespaceImport:Da,updateNamespaceImport:Aa,createNamespaceExport:Ca,updateNamespaceExport:Ia,createNamedImports:Na,updateNamedImports:ka,createImportSpecifier:Ra,updateImportSpecifier:Oa,createExportAssignment:wa,updateExportAssignment:Pa,createExportDeclaration:Ma,updateExportDeclaration:Fa,createNamedExports:Ga,updateNamedExports:Ba,createExportSpecifier:Ua,updateExportSpecifier:Va,createMissingDeclaration:ja,createExternalModuleReference:Ka,updateExternalModuleReference:Ha,get createJSDocAllType(){return v(304)},get createJSDocUnknownType(){return v(305)},get createJSDocNonNullableType(){return b(307)},get updateJSDocNonNullableType(){return E(307)},get createJSDocNullableType(){return b(306)},get updateJSDocNullableType(){return E(306)},get createJSDocOptionalType(){return b(308)},get updateJSDocOptionalType(){return E(308)},get createJSDocVariadicType(){return b(310)},get updateJSDocVariadicType(){return E(310)},get createJSDocNamepathType(){return b(311)},get updateJSDocNamepathType(){return E(311)},createJSDocFunctionType:Ja,updateJSDocFunctionType:Xa,createJSDocTypeLiteral:Ya,updateJSDocTypeLiteral:Qa,createJSDocTypeExpression:Za,updateJSDocTypeExpression:$a,createJSDocSignature:ei,updateJSDocSignature:ni,createJSDocTemplateTag:ai,updateJSDocTemplateTag:ii,createJSDocTypedefTag:oi,updateJSDocTypedefTag:si,createJSDocParameterTag:ci,updateJSDocParameterTag:li,createJSDocPropertyTag:ui,updateJSDocPropertyTag:di,createJSDocCallbackTag:pi,updateJSDocCallbackTag:fi,createJSDocAugmentsTag:mi,updateJSDocAugmentsTag:_i,createJSDocImplementsTag:gi,updateJSDocImplementsTag:Si,createJSDocSeeTag:yi,updateJSDocSeeTag:hi,createJSDocNameReference:vi,updateJSDocNameReference:bi,createJSDocLink:Ei,updateJSDocLink:Ti,get createJSDocTypeTag(){return x(333)},get updateJSDocTypeTag(){return D(333)},get createJSDocReturnTag(){return x(331)},get updateJSDocReturnTag(){return D(331)},get createJSDocThisTag(){return x(332)},get updateJSDocThisTag(){return D(332)},get createJSDocEnumTag(){return x(329)},get updateJSDocEnumTag(){return D(329)},get createJSDocAuthorTag(){return T(320)},get updateJSDocAuthorTag(){return S(320)},get createJSDocClassTag(){return T(322)},get updateJSDocClassTag(){return S(322)},get createJSDocPublicTag(){return T(323)},get updateJSDocPublicTag(){return S(323)},get createJSDocPrivateTag(){return T(324)},get updateJSDocPrivateTag(){return S(324)},get createJSDocProtectedTag(){return T(325)},get updateJSDocProtectedTag(){return S(325)},get createJSDocReadonlyTag(){return T(326)},get updateJSDocReadonlyTag(){return S(326)},get createJSDocOverrideTag(){return T(327)},get updateJSDocOverrideTag(){return S(327)},get createJSDocDeprecatedTag(){return T(321)},get updateJSDocDeprecatedTag(){return S(321)},createJSDocUnknownTag:Ci,updateJSDocUnknownTag:Ii,createJSDocText:Ni,updateJSDocText:ki,createJSDocComment:Ri,updateJSDocComment:Oi,createJsxElement:wi,updateJsxElement:Pi,createJsxSelfClosingElement:Mi,updateJsxSelfClosingElement:Fi,createJsxOpeningElement:Gi,updateJsxOpeningElement:Bi,createJsxClosingElement:Ui,updateJsxClosingElement:Vi,createJsxFragment:ji,createJsxText:Hi,updateJsxText:Wi,createJsxOpeningFragment:zi,createJsxJsxClosingFragment:qi,updateJsxFragment:Ki,createJsxAttribute:Ji,updateJsxAttribute:Xi,createJsxAttributes:Yi,updateJsxAttributes:Qi,createJsxSpreadAttribute:Zi,updateJsxSpreadAttribute:$i,createJsxExpression:eo,updateJsxExpression:no,createCaseClause:to,updateCaseClause:ro,createDefaultClause:ao,updateDefaultClause:io,createHeritageClause:oo,updateHeritageClause:so,createCatchClause:co,updateCatchClause:lo,createPropertyAssignment:uo,updatePropertyAssignment:fo,createShorthandPropertyAssignment:mo,updateShorthandPropertyAssignment:go,createSpreadAssignment:yo,updateSpreadAssignment:ho,createEnumMember:vo,updateEnumMember:bo,createSourceFile:Eo,updateSourceFile:So,createBundle:xo,updateBundle:Lo,createUnparsedSource:Do,createUnparsedPrologue:Co,createUnparsedPrepend:Io,createUnparsedTextLike:No,createUnparsedSyntheticReference:ko,createInputFiles:Ro,createSyntheticExpression:Oo,createSyntaxList:wo,createNotEmittedStatement:Po,createPartiallyEmittedExpression:Mo,updatePartiallyEmittedExpression:Fo,createCommaListExpression:Bo,updateCommaListExpression:Uo,createEndOfDeclarationMarker:Vo,createMergeDeclarationMarker:jo,createSyntheticReferenceExpression:Ko,updateSyntheticReferenceExpression:Ho,cloneNode:Wo,get createComma(){return g(27)},get createAssignment(){return g(62)},get createLogicalOr(){return g(56)},get createLogicalAnd(){return g(55)},get createBitwiseOr(){return g(51)},get createBitwiseXor(){return g(52)},get createBitwiseAnd(){return g(50)},get createStrictEquality(){return g(36)},get createStrictInequality(){return g(37)},get createEquality(){return g(34)},get createInequality(){return g(35)},get createLessThan(){return g(29)},get createLessThanEquals(){return g(32)},get createGreaterThan(){return g(31)},get createGreaterThanEquals(){return g(33)},get createLeftShift(){return g(47)},get createRightShift(){return g(48)},get createUnsignedRightShift(){return g(49)},get createAdd(){return g(39)},get createSubtract(){return g(40)},get createMultiply(){return g(41)},get createDivide(){return g(43)},get createModulo(){return g(44)},get createExponent(){return g(42)},get createPrefixPlus(){return y(39)},get createPrefixMinus(){return y(40)},get createPrefixIncrement(){return y(45)},get createPrefixDecrement(){return y(46)},get createBitwiseNot(){return y(54)},get createLogicalNot(){return y(53)},get createPostfixIncrement(){return h(45)},get createPostfixDecrement(){return h(46)},createImmediatelyInvokedFunctionExpression:zo,createImmediatelyInvokedArrowFunction:qo,createVoidZero:Jo,createExportDefault:Xo,createExternalModuleExport:Yo,createTypeCheck:Qo,createMethodCall:Zo,createGlobalMethodCall:ts,createFunctionBindCall:$o,createFunctionCallCall:es,createFunctionApplyCall:ns,createArraySliceCall:rs,createArrayConcatCall:as,createObjectDefinePropertyCall:is,createPropertyDescriptor:ss,createCallBinding:fs,inlineExpressions:ms,getInternalName:gs,getLocalName:ys,getExportName:hs,getDeclarationName:vs,getNamespaceMemberName:bs,getExternalModuleOrNamespaceExportName:Es,restoreOuterExpressions:us,restoreEnclosingLabel:ds,createUseStrictPrologue:xs,copyPrologue:Ts,copyStandardPrologue:Ls,copyCustomPrologue:Ds,ensureUseStrict:As,liftToBlock:Cs,mergeLexicalEnvironment:Ns,updateModifiers:ks};return A;function C(n,t){if(void 0===n||n===e.emptyArray)n=[];else if(e.isNodeArray(n))return void 0===n.transformFlags&&m(n),e.Debug.attachNodeArrayDebugInfo(n),n;var r=n.length,a=r>=1&&r<=4?n.slice():n;return e.setTextRangePosEnd(a,-1,-1),a.hasTrailingComma=!!t,m(a),e.Debug.attachNodeArrayDebugInfo(a),a}function I(e){return r.createBaseNode(e)}function N(e,n,t){var r=I(e);return r.decorators=Rs(n),r.modifiers=Rs(t),r.transformFlags|=f(r.decorators)|f(r.modifiers),r.symbol=void 0,r.localSymbol=void 0,r.locals=void 0,r.nextContainer=void 0,r}function k(n,t,r,a){var i=N(n,t,r);if(a=Os(a),i.name=a,a)switch(i.kind){case 166:case 168:case 169:case 164:case 289:if(e.isIdentifier(a)){i.transformFlags|=u(a);break}default:i.transformFlags|=p(a);break}return i}function R(e,n,t,r,a){var i=k(e,n,t,r);return i.typeParameters=Rs(a),i.transformFlags|=f(i.typeParameters),a&&(i.transformFlags|=1),i}function O(e,n,t,r,a,i,o){var s=R(e,n,t,r,a);return s.parameters=C(i),s.type=o,s.transformFlags|=f(s.parameters)|p(s.type),o&&(s.transformFlags|=1),s}function w(e,n){return n.typeArguments&&(e.typeArguments=n.typeArguments),c(e,n)}function P(e,n,t,r,a,i,o,s){var c=O(e,n,t,r,a,i,o);return c.body=s,c.transformFlags|=-16777217&p(c.body),s||(c.transformFlags|=1),c}function M(e,n){return n.exclamationToken&&(e.exclamationToken=n.exclamationToken),n.typeArguments&&(e.typeArguments=n.typeArguments),w(e,n)}function F(e,n,t,r,a,i){var o=R(e,n,t,r,a);return o.heritageClauses=Rs(i),o.transformFlags|=f(o.heritageClauses),o}function G(e,n,t,r,a,i,o){var s=F(e,n,t,r,a,i);return s.members=C(o),s.transformFlags|=f(s.members),s}function B(e,n,t,r,a){var i=k(e,n,t,r);return i.initializer=a,i.transformFlags|=p(i.initializer),i}function U(e,n,t,r,a,i){var o=B(e,n,t,r,i);return o.type=a,o.transformFlags|=p(a),a&&(o.transformFlags|=1),o}function V(e,n){var t=ae(e);return t.text=n,t}function j(e,n){void 0===n&&(n=0);var t=V(8,"number"===typeof e?e+"":e);return t.numericLiteralFlags=n,384&n&&(t.transformFlags|=512),t}function K(n){var t=V(9,"string"===typeof n?n:e.pseudoBigIntToString(n)+"n");return t.transformFlags|=4,t}function H(e,n){var t=V(10,e);return t.singleQuote=n,t}function W(e,n,t){var r=H(e,n);return r.hasExtendedUnicodeEscape=t,t&&(r.transformFlags|=512),r}function z(n){var t=H(e.getTextOfIdentifierOrLiteral(n),void 0);return t.textSourceNode=n,t}function q(e){var n=V(13,e);return n}function J(e,n){switch(e){case 8:return j(n,0);case 9:return K(n);case 10:return W(n,void 0);case 11:return Hi(n,!1);case 12:return Hi(n,!0);case 13:return q(n);case 14:return Wt(e,n,void 0,0)}}function X(n,t){void 0===t&&n&&(t=e.stringToToken(n)),78===t&&(t=void 0);var a=r.createBaseIdentifierNode(78);return a.originalKeywordKind=t,a.escapedText=e.escapeLeadingUnderscores(n),a}function Y(e,n){var r=X(e,void 0);return r.autoGenerateFlags=n,r.autoGenerateId=t,t++,r}function Q(e,n,t){var r=X(e,t);return n&&(r.typeArguments=C(n)),130===r.originalKeywordKind&&(r.transformFlags|=16777216),r}function Z(n,t){return n.typeArguments!==t?c(Q(e.idText(n),t),n):n}function $(e,n){var t=1;n&&(t|=8);var r=Y("",t);return e&&e(r),r}function ee(e){var n=2;return e&&(n|=8),Y("",n)}function ne(n,t){return void 0===t&&(t=0),e.Debug.assert(!(7&t),"Argument out of range: flags"),e.Debug.assert(32!==(48&t),"GeneratedIdentifierFlags.FileLevel cannot be set without also setting GeneratedIdentifierFlags.Optimistic"),Y(n,3|t)}function te(n,t){void 0===t&&(t=0),e.Debug.assert(!(7&t),"Argument out of range: flags");var r=Y(n&&e.isIdentifier(n)?e.idText(n):"",4|t);return r.original=n,r}function re(n){e.startsWith(n,"#")||e.Debug.fail("First character of private identifier must be #: "+n);var t=r.createBasePrivateIdentifierNode(79);return t.escapedText=e.escapeLeadingUnderscores(n),t.transformFlags|=8388608,t}function ae(e){return r.createBaseTokenNode(e)}function ie(n){e.Debug.assert(n>=0&&n<=157,"Invalid token"),e.Debug.assert(n<=14||n>=17,"Invalid token. Use 'createTemplateLiteralLikeNode' to create template literals."),e.Debug.assert(n<=8||n>=14,"Invalid token. Use 'createLiteralLikeNode' to create literals."),e.Debug.assert(78!==n,"Invalid token. Use 'createIdentifier' to create identifiers");var t=ae(n),r=0;switch(n){case 129:r=192;break;case 122:case 120:case 121:case 142:case 125:case 133:case 84:case 128:case 144:case 155:case 141:case 145:case 156:case 147:case 131:case 148:case 113:case 152:case 150:r=1;break;case 123:case 105:r=512;break;case 107:r=8192;break}return r&&(t.transformFlags|=r),t}function oe(){return ie(105)}function se(){return ie(107)}function ce(){return ie(103)}function le(){return ie(109)}function ue(){return ie(94)}function de(e){return ie(e)}function pe(e){var n=[];return 1&e&&n.push(de(92)),2&e&&n.push(de(133)),512&e&&n.push(de(87)),2048&e&&n.push(de(84)),4&e&&n.push(de(122)),8&e&&n.push(de(120)),16&e&&n.push(de(121)),128&e&&n.push(de(125)),32&e&&n.push(de(123)),16384&e&&n.push(de(156)),64&e&&n.push(de(142)),256&e&&n.push(de(129)),n}function fe(e,n){var t=I(158);return t.left=e,t.right=Os(n),t.transformFlags|=p(t.left)|u(t.right),t}function me(e,n,t){return e.left!==n||e.right!==t?c(fe(n,t),e):e}function _e(e){var n=I(159);return n.expression=d().parenthesizeExpressionOfComputedPropertyName(e),n.transformFlags|=66048|p(n.expression),n}function ge(e,n){return e.expression!==n?c(_e(n),e):e}function ye(e,n,t){var r=k(160,void 0,void 0,e);return r.constraint=n,r.default=t,r.transformFlags=1,r}function he(e,n,t,r){return e.name!==n||e.constraint!==t||e.default!==r?c(ye(n,t,r),e):e}function ve(n,t,r,a,i,o,s){var c=U(161,n,t,a,o,s&&d().parenthesizeExpressionForDisallowedComma(s));return c.dotDotDotToken=r,c.questionToken=i,e.isThisIdentifier(c.name)?c.transformFlags=1:(c.transformFlags|=p(c.dotDotDotToken)|p(c.questionToken),i&&(c.transformFlags|=1),16476&e.modifiersToFlags(c.modifiers)&&(c.transformFlags|=4096),(s||r)&&(c.transformFlags|=512)),c}function be(e,n,t,r,a,i,o,s){return e.decorators!==n||e.modifiers!==t||e.dotDotDotToken!==r||e.name!==a||e.questionToken!==i||e.type!==o||e.initializer!==s?c(ve(n,t,r,a,i,o,s),e):e}function Ee(e){var n=I(162);return n.expression=d().parenthesizeLeftSideOfAccess(e),n.transformFlags|=4097|p(n.expression),n}function Te(e,n){return e.expression!==n?c(Ee(n),e):e}function Se(e,n,t,r){var a=k(163,void 0,e,n);return a.type=r,a.questionToken=t,a.transformFlags=1,a}function xe(e,n,t,r,a){return e.modifiers!==n||e.name!==t||e.questionToken!==r||e.type!==a?c(Se(n,t,r,a),e):e}function Le(n,t,r,a,i,o){var s=U(164,n,t,r,i,o);return s.questionToken=a&&e.isQuestionToken(a)?a:void 0,s.exclamationToken=a&&e.isExclamationToken(a)?a:void 0,s.transformFlags|=p(s.questionToken)|p(s.exclamationToken)|8388608,(e.isComputedPropertyName(s.name)||e.hasStaticModifier(s)&&s.initializer)&&(s.transformFlags|=4096),(a||2&e.modifiersToFlags(s.modifiers))&&(s.transformFlags|=1),s}function De(n,t,r,a,i,o,s){return n.decorators!==t||n.modifiers!==r||n.name!==a||n.questionToken!==(void 0!==i&&e.isQuestionToken(i)?i:void 0)||n.exclamationToken!==(void 0!==i&&e.isExclamationToken(i)?i:void 0)||n.type!==o||n.initializer!==s?c(Le(t,r,a,i,o,s),n):n}function Ae(e,n,t,r,a,i){var o=O(165,void 0,e,n,r,a,i);return o.questionToken=t,o.transformFlags=1,o}function Ce(e,n,t,r,a,i,o){return e.modifiers!==n||e.name!==t||e.questionToken!==r||e.typeParameters!==a||e.parameters!==i||e.type!==o?w(Ae(n,t,r,a,i,o),e):e}function Ie(n,t,r,a,i,o,s,c,l){var u=P(166,n,t,a,o,s,c,l);return u.asteriskToken=r,u.questionToken=i,u.transformFlags|=p(u.asteriskToken)|p(u.questionToken)|512,i&&(u.transformFlags|=1),256&e.modifiersToFlags(u.modifiers)?u.transformFlags|=r?64:128:r&&(u.transformFlags|=1024),u}function Ne(e,n,t,r,a,i,o,s,c,l){return e.decorators!==n||e.modifiers!==t||e.asteriskToken!==r||e.name!==a||e.questionToken!==i||e.typeParameters!==o||e.parameters!==s||e.type!==c||e.body!==l?M(Ie(n,t,r,a,i,o,s,c,l),e):e}function ke(e,n,t,r){var a=P(167,e,n,void 0,void 0,t,void 0,r);return a.transformFlags|=512,a}function Re(e,n,t,r,a){return e.decorators!==n||e.modifiers!==t||e.parameters!==r||e.body!==a?M(ke(n,t,r,a),e):e}function Oe(e,n,t,r,a,i){return P(168,e,n,t,void 0,r,a,i)}function we(e,n,t,r,a,i,o){return e.decorators!==n||e.modifiers!==t||e.name!==r||e.parameters!==a||e.type!==i||e.body!==o?M(Oe(n,t,r,a,i,o),e):e}function Pe(e,n,t,r,a){return P(169,e,n,t,void 0,r,void 0,a)}function Me(e,n,t,r,a,i){return e.decorators!==n||e.modifiers!==t||e.name!==r||e.parameters!==a||e.body!==i?M(Pe(n,t,r,a,i),e):e}function Fe(e,n,t){var r=O(170,void 0,void 0,void 0,e,n,t);return r.transformFlags=1,r}function Ge(e,n,t,r){return e.typeParameters!==n||e.parameters!==t||e.type!==r?w(Fe(n,t,r),e):e}function Be(e,n,t){var r=O(171,void 0,void 0,void 0,e,n,t);return r.transformFlags=1,r}function Ue(e,n,t,r){return e.typeParameters!==n||e.parameters!==t||e.type!==r?w(Be(n,t,r),e):e}function Ve(e,n,t,r){var a=O(172,e,n,void 0,void 0,t,r);return a.transformFlags=1,a}function je(e,n,t,r,a){return e.parameters!==r||e.type!==a||e.decorators!==n||e.modifiers!==t?w(Ve(n,t,r,a),e):e}function Ke(e,n){var t=I(195);return t.type=e,t.literal=n,t.transformFlags=1,t}function He(e,n,t){return e.type!==n||e.literal!==t?c(Ke(n,t),e):e}function We(e){return ie(e)}function ze(e,n,t){var r=I(173);return r.assertsModifier=e,r.parameterName=Os(n),r.type=t,r.transformFlags=1,r}function qe(e,n,t,r){return e.assertsModifier!==n||e.parameterName!==t||e.type!==r?c(ze(n,t,r),e):e}function Je(e,n){var t=I(174);return t.typeName=Os(e),t.typeArguments=n&&d().parenthesizeTypeArguments(C(n)),t.transformFlags=1,t}function Xe(e,n,t){return e.typeName!==n||e.typeArguments!==t?c(Je(n,t),e):e}function Ye(e,n,t){var r=O(175,void 0,void 0,void 0,e,n,t);return r.transformFlags=1,r}function Qe(e,n,t,r){return e.typeParameters!==n||e.parameters!==t||e.type!==r?w(Ye(n,t,r),e):e}function Ze(){for(var n=[],t=0;t<arguments.length;t++)n[t]=arguments[t];return 4===n.length?$e.apply(void 0,n):3===n.length?en.apply(void 0,n):e.Debug.fail("Incorrect number of arguments specified.")}function $e(e,n,t,r){var a=O(176,void 0,e,void 0,n,t,r);return a.transformFlags=1,a}function en(e,n,t){return $e(void 0,e,n,t)}function nn(){for(var n=[],t=0;t<arguments.length;t++)n[t]=arguments[t];return 5===n.length?tn.apply(void 0,n):4===n.length?rn.apply(void 0,n):e.Debug.fail("Incorrect number of arguments specified.")}function tn(e,n,t,r,a){return e.modifiers!==n||e.typeParameters!==t||e.parameters!==r||e.type!==a?w(Ze(n,t,r,a),e):e}function rn(e,n,t,r){return tn(e,e.modifiers,n,t,r)}function an(e){var n=I(177);return n.exprName=e,n.transformFlags=1,n}function on(e,n){return e.exprName!==n?c(an(n),e):e}function sn(e){var n=I(178);return n.members=C(e),n.transformFlags=1,n}function cn(e,n){return e.members!==n?c(sn(n),e):e}function ln(e){var n=I(179);return n.elementType=d().parenthesizeElementTypeOfArrayType(e),n.transformFlags=1,n}function un(e,n){return e.elementType!==n?c(ln(n),e):e}function dn(e){var n=I(180);return n.elements=C(e),n.transformFlags=1,n}function pn(e,n){return e.elements!==n?c(dn(n),e):e}function fn(e,n,t,r){var a=I(193);return a.dotDotDotToken=e,a.name=n,a.questionToken=t,a.type=r,a.transformFlags=1,a}function mn(e,n,t,r,a){return e.dotDotDotToken!==n||e.name!==t||e.questionToken!==r||e.type!==a?c(fn(n,t,r,a),e):e}function _n(e){var n=I(181);return n.type=d().parenthesizeElementTypeOfArrayType(e),n.transformFlags=1,n}function gn(e,n){return e.type!==n?c(_n(n),e):e}function yn(e){var n=I(182);return n.type=e,n.transformFlags=1,n}function hn(e,n){return e.type!==n?c(yn(n),e):e}function vn(e,n){var t=I(e);return t.types=d().parenthesizeConstituentTypesOfUnionOrIntersectionType(n),t.transformFlags=1,t}function bn(e,n){return e.types!==n?c(vn(e.kind,n),e):e}function En(e){return vn(183,e)}function Tn(e,n){return bn(e,n)}function Sn(e){return vn(184,e)}function xn(e,n){return bn(e,n)}function Ln(e,n,t,r){var a=I(185);return a.checkType=d().parenthesizeMemberOfConditionalType(e),a.extendsType=d().parenthesizeMemberOfConditionalType(n),a.trueType=t,a.falseType=r,a.transformFlags=1,a}function Dn(e,n,t,r,a){return e.checkType!==n||e.extendsType!==t||e.trueType!==r||e.falseType!==a?c(Ln(n,t,r,a),e):e}function An(e){var n=I(186);return n.typeParameter=e,n.transformFlags=1,n}function Cn(e,n){return e.typeParameter!==n?c(An(n),e):e}function In(e,n){var t=I(194);return t.head=e,t.templateSpans=C(n),t.transformFlags=1,t}function Nn(e,n,t){return e.head!==n||e.templateSpans!==t?c(In(n,t),e):e}function kn(e,n,t,r){void 0===r&&(r=!1);var a=I(196);return a.argument=e,a.qualifier=n,a.typeArguments=t&&d().parenthesizeTypeArguments(t),a.isTypeOf=r,a.transformFlags=1,a}function Rn(e,n,t,r,a){return void 0===a&&(a=e.isTypeOf),e.argument!==n||e.qualifier!==t||e.typeArguments!==r||e.isTypeOf!==a?c(kn(n,t,r,a),e):e}function On(e){var n=I(187);return n.type=e,n.transformFlags=1,n}function wn(e,n){return e.type!==n?c(On(n),e):e}function Pn(){var e=I(188);return e.transformFlags=1,e}function Mn(e,n){var t=I(189);return t.operator=e,t.type=d().parenthesizeMemberOfElementType(n),t.transformFlags=1,t}function Fn(e,n){return e.type!==n?c(Mn(e.operator,n),e):e}function Gn(e,n){var t=I(190);return t.objectType=d().parenthesizeMemberOfElementType(e),t.indexType=n,t.transformFlags=1,t}function Bn(e,n,t){return e.objectType!==n||e.indexType!==t?c(Gn(n,t),e):e}function Un(e,n,t,r,a){var i=I(191);return i.readonlyToken=e,i.typeParameter=n,i.nameType=t,i.questionToken=r,i.type=a,i.transformFlags=1,i}function Vn(e,n,t,r,a,i){return e.readonlyToken!==n||e.typeParameter!==t||e.nameType!==r||e.questionToken!==a||e.type!==i?c(Un(n,t,r,a,i),e):e}function jn(e){var n=I(192);return n.literal=e,n.transformFlags=1,n}function Kn(e,n){return e.literal!==n?c(jn(n),e):e}function Hn(e){var n=I(197);return n.elements=C(e),n.transformFlags|=262656|f(n.elements),16384&n.transformFlags&&(n.transformFlags|=32832),n}function Wn(e,n){return e.elements!==n?c(Hn(n),e):e}function zn(e){var n=I(198);return n.elements=C(e),n.transformFlags|=262656|f(n.elements),n}function qn(e,n){return e.elements!==n?c(zn(n),e):e}function Jn(n,t,r,a){var i=B(199,void 0,void 0,r,a&&d().parenthesizeExpressionForDisallowedComma(a));return i.propertyName=Os(t),i.dotDotDotToken=n,i.transformFlags|=512|p(i.dotDotDotToken),i.propertyName&&(i.transformFlags|=e.isIdentifier(i.propertyName)?u(i.propertyName):p(i.propertyName)),n&&(i.transformFlags|=16384),i}function Xn(e,n,t,r,a){return e.propertyName!==t||e.dotDotDotToken!==n||e.name!==r||e.initializer!==a?c(Jn(n,t,r,a),e):e}function Yn(e){var n=I(e);return n}function Qn(e,n){var t=Yn(200);return t.elements=d().parenthesizeExpressionsOfCommaDelimitedList(C(e)),t.multiLine=n,t.transformFlags|=f(t.elements),t}function Zn(e,n){return e.elements!==n?c(Qn(n,e.multiLine),e):e}function $n(e,n){var t=Yn(201);return t.properties=C(e),t.multiLine=n,t.transformFlags|=f(t.properties),t}function et(e,n){return e.properties!==n?c($n(n,e.multiLine),e):e}function nt(n,t){var r=Yn(202);return r.expression=d().parenthesizeLeftSideOfAccess(n),r.name=Os(t),r.transformFlags=p(r.expression)|(e.isIdentifier(r.name)?u(r.name):p(r.name)),e.isSuperKeyword(n)&&(r.transformFlags|=192),r}function tt(n,t,r){return e.isPropertyAccessChain(n)?at(n,t,n.questionDotToken,e.cast(r,e.isIdentifier)):n.expression!==t||n.name!==r?c(nt(t,r),n):n}function rt(n,t,r){var a=Yn(202);return a.flags|=32,a.expression=d().parenthesizeLeftSideOfAccess(n),a.questionDotToken=t,a.name=Os(r),a.transformFlags|=16|p(a.expression)|p(a.questionDotToken)|(e.isIdentifier(a.name)?u(a.name):p(a.name)),a}function at(n,t,r,a){return e.Debug.assert(!!(32&n.flags),"Cannot update a PropertyAccessExpression using updatePropertyAccessChain. Use updatePropertyAccess instead."),n.expression!==t||n.questionDotToken!==r||n.name!==a?c(rt(t,r,a),n):n}function it(n,t){var r=Yn(203);return r.expression=d().parenthesizeLeftSideOfAccess(n),r.argumentExpression=ws(t),r.transformFlags|=p(r.expression)|p(r.argumentExpression),e.isSuperKeyword(n)&&(r.transformFlags|=192),r}function ot(n,t,r){return e.isElementAccessChain(n)?ct(n,t,n.questionDotToken,r):n.expression!==t||n.argumentExpression!==r?c(it(t,r),n):n}function st(e,n,t){var r=Yn(203);return r.flags|=32,r.expression=d().parenthesizeLeftSideOfAccess(e),r.questionDotToken=n,r.argumentExpression=ws(t),r.transformFlags|=p(r.expression)|p(r.questionDotToken)|p(r.argumentExpression)|16,r}function ct(n,t,r,a){return e.Debug.assert(!!(32&n.flags),"Cannot update a ElementAccessExpression using updateElementAccessChain. Use updateElementAccess instead."),n.expression!==t||n.questionDotToken!==r||n.argumentExpression!==a?c(st(t,r,a),n):n}function lt(n,t,r){var a=Yn(204);return a.expression=d().parenthesizeLeftSideOfAccess(n),a.typeArguments=Rs(t),a.arguments=d().parenthesizeExpressionsOfCommaDelimitedList(C(r)),a.transformFlags|=p(a.expression)|f(a.typeArguments)|f(a.arguments),a.typeArguments&&(a.transformFlags|=1),e.isImportKeyword(a.expression)?a.transformFlags|=4194304:e.isSuperProperty(a.expression)&&(a.transformFlags|=8192),a}function ut(n,t,r,a){return e.isCallChain(n)?pt(n,t,n.questionDotToken,r,a):n.expression!==t||n.typeArguments!==r||n.arguments!==a?c(lt(t,r,a),n):n}function dt(n,t,r,a){var i=Yn(204);return i.flags|=32,i.expression=d().parenthesizeLeftSideOfAccess(n),i.questionDotToken=t,i.typeArguments=Rs(r),i.arguments=d().parenthesizeExpressionsOfCommaDelimitedList(C(a)),i.transformFlags|=p(i.expression)|p(i.questionDotToken)|f(i.typeArguments)|f(i.arguments)|16,i.typeArguments&&(i.transformFlags|=1),e.isSuperProperty(i.expression)&&(i.transformFlags|=8192),i}function pt(n,t,r,a,i){return e.Debug.assert(!!(32&n.flags),"Cannot update a CallExpression using updateCallChain. Use updateCall instead."),n.expression!==t||n.questionDotToken!==r||n.typeArguments!==a||n.arguments!==i?c(dt(t,r,a,i),n):n}function ft(e,n,t){var r=Yn(205);return r.expression=d().parenthesizeExpressionOfNew(e),r.typeArguments=Rs(n),r.arguments=t?d().parenthesizeExpressionsOfCommaDelimitedList(t):void 0,r.transformFlags|=p(r.expression)|f(r.typeArguments)|f(r.arguments)|16,r.typeArguments&&(r.transformFlags|=1),r}function mt(e,n,t,r){return e.expression!==n||e.typeArguments!==t||e.arguments!==r?c(ft(n,t,r),e):e}function _t(n,t,r){var a=Yn(206);return a.tag=d().parenthesizeLeftSideOfAccess(n),a.typeArguments=Rs(t),a.template=r,a.transformFlags|=p(a.tag)|f(a.typeArguments)|p(a.template)|512,a.typeArguments&&(a.transformFlags|=1),e.hasInvalidEscape(a.template)&&(a.transformFlags|=64),a}function gt(e,n,t,r){return e.tag!==n||e.typeArguments!==t||e.template!==r?c(_t(n,t,r),e):e}function yt(e,n){var t=Yn(207);return t.expression=d().parenthesizeOperandOfPrefixUnary(n),t.type=e,t.transformFlags|=p(t.expression)|p(t.type)|1,t}function ht(e,n,t){return e.type!==n||e.expression!==t?c(yt(n,t),e):e}function vt(e){var n=Yn(208);return n.expression=e,n.transformFlags=p(n.expression),n}function bt(e,n){return e.expression!==n?c(vt(n),e):e}function Et(n,t,r,a,i,o,s){var c=P(209,void 0,n,r,a,i,o,s);return c.asteriskToken=t,c.transformFlags|=p(c.asteriskToken),c.typeParameters&&(c.transformFlags|=1),256&e.modifiersToFlags(c.modifiers)?c.asteriskToken?c.transformFlags|=64:c.transformFlags|=128:c.asteriskToken&&(c.transformFlags|=1024),c}function Tt(e,n,t,r,a,i,o,s){return e.name!==r||e.modifiers!==n||e.asteriskToken!==t||e.typeParameters!==a||e.parameters!==i||e.type!==o||e.body!==s?M(Et(n,t,r,a,i,o,s),e):e}function St(n,t,r,a,i,o){var s=P(210,void 0,n,void 0,t,r,a,d().parenthesizeConciseBodyOfArrowFunction(o));return s.equalsGreaterThanToken=null!==i&&void 0!==i?i:ie(38),s.transformFlags|=512|p(s.equalsGreaterThanToken),256&e.modifiersToFlags(s.modifiers)&&(s.transformFlags|=128),s}function xt(e,n,t,r,a,i,o){return e.modifiers!==n||e.typeParameters!==t||e.parameters!==r||e.type!==a||e.equalsGreaterThanToken!==i||e.body!==o?M(St(n,t,r,a,i,o),e):e}function Lt(e){var n=Yn(211);return n.expression=d().parenthesizeOperandOfPrefixUnary(e),n.transformFlags|=p(n.expression),n}function Dt(e,n){return e.expression!==n?c(Lt(n),e):e}function At(e){var n=Yn(212);return n.expression=d().parenthesizeOperandOfPrefixUnary(e),n.transformFlags|=p(n.expression),n}function Ct(e,n){return e.expression!==n?c(At(n),e):e}function It(e){var n=Yn(213);return n.expression=d().parenthesizeOperandOfPrefixUnary(e),n.transformFlags|=p(n.expression),n}function Nt(e,n){return e.expression!==n?c(It(n),e):e}function kt(e){var n=Yn(214);return n.expression=d().parenthesizeOperandOfPrefixUnary(e),n.transformFlags|=1048768|p(n.expression),n}function Rt(e,n){return e.expression!==n?c(kt(n),e):e}function Ot(e,n){var t=Yn(215);return t.operator=e,t.operand=d().parenthesizeOperandOfPrefixUnary(n),t.transformFlags|=p(t.operand),t}function wt(e,n){return e.operand!==n?c(Ot(e.operator,n),e):e}function Pt(e,n){var t=Yn(216);return t.operator=n,t.operand=d().parenthesizeOperandOfPostfixUnary(e),t.transformFlags=p(t.operand),t}function Mt(e,n){return e.operand!==n?c(Pt(n,e.operator),e):e}function Ft(n,t,r){var a=Yn(217),i=Ps(t),o=i.kind;return a.left=d().parenthesizeLeftSideOfBinary(o,n),a.operatorToken=i,a.right=d().parenthesizeRightSideOfBinary(o,a.left,r),a.transformFlags|=p(a.left)|p(a.operatorToken)|p(a.right),60===o?a.transformFlags|=16:62===o?e.isObjectLiteralExpression(a.left)?a.transformFlags|=2624|Gt(a.left):e.isArrayLiteralExpression(a.left)&&(a.transformFlags|=2560|Gt(a.left)):42===o||66===o?a.transformFlags|=256:e.isLogicalOrCoalescingAssignmentOperator(o)&&(a.transformFlags|=8),a}function Gt(n){if(32768&n.transformFlags)return 32768;if(64&n.transformFlags)for(var t=0,r=e.getElementsOfBindingOrAssignmentPattern(n);t<r.length;t++){var a=r[t],i=e.getTargetOfBindingOrAssignmentElement(a);if(i&&e.isAssignmentPattern(i)){if(32768&i.transformFlags)return 32768;if(64&i.transformFlags){var o=Gt(i);if(o)return o}}}return 0}function Bt(e,n,t,r){return e.left!==n||e.operatorToken!==t||e.right!==r?c(Ft(n,t,r),e):e}function Ut(e,n,t,r,a){var i=Yn(218);return i.condition=d().parenthesizeConditionOfConditionalExpression(e),i.questionToken=null!==n&&void 0!==n?n:ie(57),i.whenTrue=d().parenthesizeBranchOfConditionalExpression(t),i.colonToken=null!==r&&void 0!==r?r:ie(58),i.whenFalse=d().parenthesizeBranchOfConditionalExpression(a),i.transformFlags|=p(i.condition)|p(i.questionToken)|p(i.whenTrue)|p(i.colonToken)|p(i.whenFalse),i}function Vt(e,n,t,r,a,i){return e.condition!==n||e.questionToken!==t||e.whenTrue!==r||e.colonToken!==a||e.whenFalse!==i?c(Ut(n,t,r,a,i),e):e}function jt(e,n){var t=Yn(219);return t.head=e,t.templateSpans=C(n),t.transformFlags|=p(t.head)|f(t.templateSpans)|512,t}function Kt(e,n,t){return e.head!==n||e.templateSpans!==t?c(jt(n,t),e):e}function Ht(n,t,r,a){void 0===a&&(a=0),e.Debug.assert(!(-2049&a),"Unsupported template flags.");var i=void 0;if(void 0!==r&&r!==t&&(i=l(n,r),"object"===typeof i))return e.Debug.fail("Invalid raw text");if(void 0===t){if(void 0===i)return e.Debug.fail("Arguments 'text' and 'rawText' may not both be undefined.");t=i}else void 0!==i&&e.Debug.assert(t===i,"Expected argument 'text' to be the normalized (i.e. 'cooked') version of argument 'rawText'.");return Wt(n,t,r,a)}function Wt(e,n,t,r){var a=ae(e);return a.text=n,a.rawText=t,a.templateFlags=2048&r,a.transformFlags|=512,a.templateFlags&&(a.transformFlags|=64),a}function zt(e,n,t){return Ht(15,e,n,t)}function qt(e,n,t){return Ht(16,e,n,t)}function Jt(e,n,t){return Ht(17,e,n,t)}function Xt(e,n,t){return Ht(14,e,n,t)}function Yt(n,t){e.Debug.assert(!n||!!t,"A `YieldExpression` with an asteriskToken must have an expression.");var r=Yn(220);return r.expression=t&&d().parenthesizeExpressionForDisallowedComma(t),r.asteriskToken=n,r.transformFlags|=524864|(p(r.expression)|p(r.asteriskToken)),r}function Qt(e,n,t){return e.expression!==t||e.asteriskToken!==n?c(Yt(n,t),e):e}function Zt(e){var n=Yn(221);return n.expression=d().parenthesizeExpressionForDisallowedComma(e),n.transformFlags|=16896|p(n.expression),n}function $t(e,n){return e.expression!==n?c(Zt(n),e):e}function er(e,n,t,r,a,i){var o=G(222,e,n,t,r,a,i);return o.transformFlags|=512,o}function nr(e,n,t,r,a,i,o){return e.decorators!==n||e.modifiers!==t||e.name!==r||e.typeParameters!==a||e.heritageClauses!==i||e.members!==o?c(er(n,t,r,a,i,o),e):e}function tr(){return Yn(223)}function rr(e,n){var t=I(224);return t.expression=d().parenthesizeLeftSideOfAccess(e),t.typeArguments=n&&d().parenthesizeTypeArguments(n),t.transformFlags|=p(t.expression)|f(t.typeArguments)|512,t}function ar(e,n,t){return e.expression!==n||e.typeArguments!==t?c(rr(n,t),e):e}function ir(e,n){var t=Yn(225);return t.expression=e,t.type=n,t.transformFlags|=p(t.expression)|p(t.type)|1,t}function or(e,n,t){return e.expression!==n||e.type!==t?c(ir(n,t),e):e}function sr(e){var n=Yn(226);return n.expression=d().parenthesizeLeftSideOfAccess(e),n.transformFlags|=1|p(n.expression),n}function cr(n,t){return e.isNonNullChain(n)?ur(n,t):n.expression!==t?c(sr(t),n):n}function lr(e){var n=Yn(226);return n.flags|=32,n.expression=d().parenthesizeLeftSideOfAccess(e),n.transformFlags|=1|p(n.expression),n}function ur(n,t){return e.Debug.assert(!!(32&n.flags),"Cannot update a NonNullExpression using updateNonNullChain. Use updateNonNullExpression instead."),n.expression!==t?c(lr(t),n):n}function dr(n,t){var r=Yn(227);switch(r.keywordToken=n,r.name=t,r.transformFlags|=p(r.name),n){case 102:r.transformFlags|=512;break;case 99:r.transformFlags|=4;break;default:return e.Debug.assertNever(n)}return r}function pr(e,n){return e.name!==n?c(dr(e.keywordToken,n),e):e}function fr(e,n){var t=I(229);return t.expression=e,t.literal=n,t.transformFlags|=p(t.expression)|p(t.literal)|512,t}function mr(e,n,t){return e.expression!==n||e.literal!==t?c(fr(n,t),e):e}function _r(){var e=I(230);return e.transformFlags|=512,e}function gr(e,n){var t=I(231);return t.statements=C(e),t.multiLine=n,t.transformFlags|=f(t.statements),t}function yr(e,n){return e.statements!==n?c(gr(n,e.multiLine),e):e}function hr(n,t){var r=N(233,void 0,n);return r.declarationList=e.isArray(t)?ea(t):t,r.transformFlags|=p(r.declarationList),2&e.modifiersToFlags(r.modifiers)&&(r.transformFlags=1),r}function vr(e,n,t){return e.modifiers!==n||e.declarationList!==t?c(hr(n,t),e):e}function br(){return I(232)}function Er(e){var n=I(234);return n.expression=d().parenthesizeExpressionOfExpressionStatement(e),n.transformFlags|=p(n.expression),n}function Tr(e,n){return e.expression!==n?c(Er(n),e):e}function Sr(e,n,t){var r=I(235);return r.expression=e,r.thenStatement=Ms(n),r.elseStatement=Ms(t),r.transformFlags|=p(r.expression)|p(r.thenStatement)|p(r.elseStatement),r}function xr(e,n,t,r){return e.expression!==n||e.thenStatement!==t||e.elseStatement!==r?c(Sr(n,t,r),e):e}function Lr(e,n){var t=I(236);return t.statement=Ms(e),t.expression=n,t.transformFlags|=p(t.statement)|p(t.expression),t}function Dr(e,n,t){return e.statement!==n||e.expression!==t?c(Lr(n,t),e):e}function Ar(e,n){var t=I(237);return t.expression=e,t.statement=Ms(n),t.transformFlags|=p(t.expression)|p(t.statement),t}function Cr(e,n,t){return e.expression!==n||e.statement!==t?c(Ar(n,t),e):e}function Ir(e,n,t,r){var a=I(238);return a.initializer=e,a.condition=n,a.incrementor=t,a.statement=Ms(r),a.transformFlags|=p(a.initializer)|p(a.condition)|p(a.incrementor)|p(a.statement),a}function Nr(e,n,t,r,a){return e.initializer!==n||e.condition!==t||e.incrementor!==r||e.statement!==a?c(Ir(n,t,r,a),e):e}function kr(e,n,t){var r=I(239);return r.initializer=e,r.expression=n,r.statement=Ms(t),r.transformFlags|=p(r.initializer)|p(r.expression)|p(r.statement),r}function Rr(e,n,t,r){return e.initializer!==n||e.expression!==t||e.statement!==r?c(kr(n,t,r),e):e}function Or(e,n,t,r){var a=I(240);return a.awaitModifier=e,a.initializer=n,a.expression=d().parenthesizeExpressionForDisallowedComma(t),a.statement=Ms(r),a.transformFlags|=p(a.awaitModifier)|p(a.initializer)|p(a.expression)|p(a.statement)|512,e&&(a.transformFlags|=64),a}function wr(e,n,t,r,a){return e.awaitModifier!==n||e.initializer!==t||e.expression!==r||e.statement!==a?c(Or(n,t,r,a),e):e}function Pr(e){var n=I(241);return n.label=Os(e),n.transformFlags|=2097152|p(n.label),n}function Mr(e,n){return e.label!==n?c(Pr(n),e):e}function Fr(e){var n=I(242);return n.label=Os(e),n.transformFlags|=2097152|p(n.label),n}function Gr(e,n){return e.label!==n?c(Fr(n),e):e}function Br(e){var n=I(243);return n.expression=e,n.transformFlags|=2097216|p(n.expression),n}function Ur(e,n){return e.expression!==n?c(Br(n),e):e}function Vr(e,n){var t=I(244);return t.expression=e,t.statement=Ms(n),t.transformFlags|=p(t.expression)|p(t.statement),t}function jr(e,n,t){return e.expression!==n||e.statement!==t?c(Vr(n,t),e):e}function Kr(e,n){var t=I(245);return t.expression=d().parenthesizeExpressionForDisallowedComma(e),t.caseBlock=n,t.transformFlags|=p(t.expression)|p(t.caseBlock),t}function Hr(e,n,t){return e.expression!==n||e.caseBlock!==t?c(Kr(n,t),e):e}function Wr(e,n){var t=I(246);return t.label=Os(e),t.statement=Ms(n),t.transformFlags|=p(t.label)|p(t.statement),t}function zr(e,n,t){return e.label!==n||e.statement!==t?c(Wr(n,t),e):e}function qr(e){var n=I(247);return n.expression=e,n.transformFlags|=p(n.expression),n}function Jr(e,n){return e.expression!==n?c(qr(n),e):e}function Xr(e,n,t){var r=I(248);return r.tryBlock=e,r.catchClause=n,r.finallyBlock=t,r.transformFlags|=p(r.tryBlock)|p(r.catchClause)|p(r.finallyBlock),r}function Yr(e,n,t,r){return e.tryBlock!==n||e.catchClause!==t||e.finallyBlock!==r?c(Xr(n,t,r),e):e}function Qr(){return I(249)}function Zr(e,n,t,r){var a=U(250,void 0,void 0,e,t,r&&d().parenthesizeExpressionForDisallowedComma(r));return a.exclamationToken=n,a.transformFlags|=p(a.exclamationToken),n&&(a.transformFlags|=1),a}function $r(e,n,t,r,a){return e.name!==n||e.type!==r||e.exclamationToken!==t||e.initializer!==a?c(Zr(n,t,r,a),e):e}function ea(e,n){void 0===n&&(n=0);var t=I(251);return t.flags|=3&n,t.declarations=C(e),t.transformFlags|=2097152|f(t.declarations),3&n&&(t.transformFlags|=131584),t}function na(e,n){return e.declarations!==n?c(ea(n,e.flags),e):e}function ta(n,t,r,a,i,o,s,c){var l=P(252,n,t,a,i,o,s,c);return l.asteriskToken=r,!l.body||2&e.modifiersToFlags(l.modifiers)?l.transformFlags=1:(l.transformFlags|=2097152|p(l.asteriskToken),256&e.modifiersToFlags(l.modifiers)?l.asteriskToken?l.transformFlags|=64:l.transformFlags|=128:l.asteriskToken&&(l.transformFlags|=1024)),l}function ra(e,n,t,r,a,i,o,s,c){return e.decorators!==n||e.modifiers!==t||e.asteriskToken!==r||e.name!==a||e.typeParameters!==i||e.parameters!==o||e.type!==s||e.body!==c?M(ta(n,t,r,a,i,o,s,c),e):e}function aa(n,t,r,a,i,o){var s=G(253,n,t,r,a,i,o);return 2&e.modifiersToFlags(s.modifiers)?s.transformFlags=1:(s.transformFlags|=512,4096&s.transformFlags&&(s.transformFlags|=1)),s}function ia(e,n,t,r,a,i,o){return e.decorators!==n||e.modifiers!==t||e.name!==r||e.typeParameters!==a||e.heritageClauses!==i||e.members!==o?c(aa(n,t,r,a,i,o),e):e}function oa(e,n,t,r,a,i){var o=F(254,e,n,t,r,a);return o.members=C(i),o.transformFlags=1,o}function sa(e,n,t,r,a,i,o){return e.decorators!==n||e.modifiers!==t||e.name!==r||e.typeParameters!==a||e.heritageClauses!==i||e.members!==o?c(oa(n,t,r,a,i,o),e):e}function ca(e,n,t,r,a){var i=R(255,e,n,t,r);return i.type=a,i.transformFlags=1,i}function la(e,n,t,r,a,i){return e.decorators!==n||e.modifiers!==t||e.name!==r||e.typeParameters!==a||e.type!==i?c(ca(n,t,r,a,i),e):e}function ua(e,n,t,r){var a=k(256,e,n,t);return a.members=C(r),a.transformFlags|=1|f(a.members),a.transformFlags&=-16777217,a}function da(e,n,t,r,a){return e.decorators!==n||e.modifiers!==t||e.name!==r||e.members!==a?c(ua(n,t,r,a),e):e}function pa(n,t,r,a,i){void 0===i&&(i=0);var o=N(257,n,t);return o.flags|=1044&i,o.name=r,o.body=a,2&e.modifiersToFlags(o.modifiers)?o.transformFlags=1:o.transformFlags|=p(o.name)|p(o.body)|1,o.transformFlags&=-16777217,o}function fa(e,n,t,r,a){return e.decorators!==n||e.modifiers!==t||e.name!==r||e.body!==a?c(pa(n,t,r,a,e.flags),e):e}function ma(e){var n=I(258);return n.statements=C(e),n.transformFlags|=f(n.statements),n}function _a(e,n){return e.statements!==n?c(ma(n),e):e}function ga(e){var n=I(259);return n.clauses=C(e),n.transformFlags|=f(n.clauses),n}function ya(e,n){return e.clauses!==n?c(ga(n),e):e}function ha(e){var n=k(260,void 0,void 0,e);return n.transformFlags=1,n}function va(e,n){return e.name!==n?c(ha(n),e):e}function ba(n,t,r,a,i){var o=k(261,n,t,a);return o.isTypeOnly=r,o.moduleReference=i,o.transformFlags|=p(o.moduleReference),e.isExternalModuleReference(o.moduleReference)||(o.transformFlags|=1),o.transformFlags&=-16777217,o}function Ea(e,n,t,r,a,i){return e.decorators!==n||e.modifiers!==t||e.isTypeOnly!==r||e.name!==a||e.moduleReference!==i?c(ba(n,t,r,a,i),e):e}function Ta(e,n,t,r){var a=N(262,e,n);return a.importClause=t,a.moduleSpecifier=r,a.transformFlags|=p(a.importClause)|p(a.moduleSpecifier),a.transformFlags&=-16777217,a}function Sa(e,n,t,r,a){return e.decorators!==n||e.modifiers!==t||e.importClause!==r||e.moduleSpecifier!==a?c(Ta(n,t,r,a),e):e}function xa(e,n,t){var r=I(263);return r.isTypeOnly=e,r.name=n,r.namedBindings=t,r.transformFlags|=p(r.name)|p(r.namedBindings),e&&(r.transformFlags|=1),r.transformFlags&=-16777217,r}function La(e,n,t,r){return e.isTypeOnly!==n||e.name!==t||e.namedBindings!==r?c(xa(n,t,r),e):e}function Da(e){var n=I(264);return n.name=e,n.transformFlags|=p(n.name),n.transformFlags&=-16777217,n}function Aa(e,n){return e.name!==n?c(Da(n),e):e}function Ca(e){var n=I(270);return n.name=e,n.transformFlags|=4|p(n.name),n.transformFlags&=-16777217,n}function Ia(e,n){return e.name!==n?c(Ca(n),e):e}function Na(e){var n=I(265);return n.elements=C(e),n.transformFlags|=f(n.elements),n.transformFlags&=-16777217,n}function ka(e,n){return e.elements!==n?c(Na(n),e):e}function Ra(e,n){var t=I(266);return t.propertyName=e,t.name=n,t.transformFlags|=p(t.propertyName)|p(t.name),t.transformFlags&=-16777217,t}function Oa(e,n,t){return e.propertyName!==n||e.name!==t?c(Ra(n,t),e):e}function wa(e,n,t,r){var a=N(267,e,n);return a.isExportEquals=t,a.expression=t?d().parenthesizeRightSideOfBinary(62,void 0,r):d().parenthesizeExpressionOfExportDefault(r),a.transformFlags|=p(a.expression),a.transformFlags&=-16777217,a}function Pa(e,n,t,r){return e.decorators!==n||e.modifiers!==t||e.expression!==r?c(wa(n,t,e.isExportEquals,r),e):e}function Ma(e,n,t,r,a){var i=N(268,e,n);return i.isTypeOnly=t,i.exportClause=r,i.moduleSpecifier=a,i.transformFlags|=p(i.exportClause)|p(i.moduleSpecifier),i.transformFlags&=-16777217,i}function Fa(e,n,t,r,a,i){return e.decorators!==n||e.modifiers!==t||e.isTypeOnly!==r||e.exportClause!==a||e.moduleSpecifier!==i?c(Ma(n,t,r,a,i),e):e}function Ga(e){var n=I(269);return n.elements=C(e),n.transformFlags|=f(n.elements),n.transformFlags&=-16777217,n}function Ba(e,n){return e.elements!==n?c(Ga(n),e):e}function Ua(e,n){var t=I(271);return t.propertyName=Os(e),t.name=Os(n),t.transformFlags|=p(t.propertyName)|p(t.name),t.transformFlags&=-16777217,t}function Va(e,n,t){return e.propertyName!==n||e.name!==t?c(Ua(n,t),e):e}function ja(){var e=N(272,void 0,void 0);return e}function Ka(e){var n=I(273);return n.expression=e,n.transformFlags|=p(n.expression),n.transformFlags&=-16777217,n}function Ha(e,n){return e.expression!==n?c(Ka(n),e):e}function Wa(e){return I(e)}function za(e,n){var t=I(e);return t.type=n,t}function qa(e,n,t){return n.type!==t?c(za(e,t),n):n}function Ja(e,n){var t=O(309,void 0,void 0,void 0,void 0,e,n);return t}function Xa(e,n,t){return e.parameters!==n||e.type!==t?c(Ja(n,t),e):e}function Ya(e,n){void 0===n&&(n=!1);var t=I(314);return t.jsDocPropertyTags=Rs(e),t.isArrayType=n,t}function Qa(e,n,t){return e.jsDocPropertyTags!==n||e.isArrayType!==t?c(Ya(n,t),e):e}function Za(e){var n=I(302);return n.type=e,n}function $a(e,n){return e.type!==n?c(Za(n),e):e}function ei(e,n,t){var r=I(315);return r.typeParameters=Rs(e),r.parameters=C(n),r.type=t,r}function ni(e,n,t,r){return e.typeParameters!==n||e.parameters!==t||e.type!==r?c(ei(n,t,r),e):e}function ti(n){var t=s(n.kind);return n.tagName.escapedText===e.escapeLeadingUnderscores(t)?n.tagName:Q(t)}function ri(e,n,t){var r=I(e);return r.tagName=n,r.comment=t,r}function ai(e,n,t,r){var a=ri(334,null!==e&&void 0!==e?e:Q("template"),r);return a.constraint=n,a.typeParameters=C(t),a}function ii(e,n,t,r,a){return void 0===n&&(n=ti(e)),e.tagName!==n||e.constraint!==t||e.typeParameters!==r||e.comment!==a?c(ai(n,t,r,a),e):e}function oi(n,t,r,a){var i=ri(335,null!==n&&void 0!==n?n:Q("typedef"),a);return i.typeExpression=t,i.fullName=r,i.name=e.getJSDocTypeAliasName(r),i}function si(e,n,t,r,a){return void 0===n&&(n=ti(e)),e.tagName!==n||e.typeExpression!==t||e.fullName!==r||e.comment!==a?c(oi(n,t,r,a),e):e}function ci(e,n,t,r,a,i){var o=ri(330,null!==e&&void 0!==e?e:Q("param"),i);return o.typeExpression=r,o.name=n,o.isNameFirst=!!a,o.isBracketed=t,o}function li(e,n,t,r,a,i,o){return void 0===n&&(n=ti(e)),e.tagName!==n||e.name!==t||e.isBracketed!==r||e.typeExpression!==a||e.isNameFirst!==i||e.comment!==o?c(ci(n,t,r,a,i,o),e):e}function ui(e,n,t,r,a,i){var o=ri(337,null!==e&&void 0!==e?e:Q("prop"),i);return o.typeExpression=r,o.name=n,o.isNameFirst=!!a,o.isBracketed=t,o}function di(e,n,t,r,a,i,o){return void 0===n&&(n=ti(e)),e.tagName!==n||e.name!==t||e.isBracketed!==r||e.typeExpression!==a||e.isNameFirst!==i||e.comment!==o?c(ui(n,t,r,a,i,o),e):e}function pi(n,t,r,a){var i=ri(328,null!==n&&void 0!==n?n:Q("callback"),a);return i.typeExpression=t,i.fullName=r,i.name=e.getJSDocTypeAliasName(r),i}function fi(e,n,t,r,a){return void 0===n&&(n=ti(e)),e.tagName!==n||e.typeExpression!==t||e.fullName!==r||e.comment!==a?c(pi(n,t,r,a),e):e}function mi(e,n,t){var r=ri(318,null!==e&&void 0!==e?e:Q("augments"),t);return r.class=n,r}function _i(e,n,t,r){return void 0===n&&(n=ti(e)),e.tagName!==n||e.class!==t||e.comment!==r?c(mi(n,t,r),e):e}function gi(e,n,t){var r=ri(319,null!==e&&void 0!==e?e:Q("implements"),t);return r.class=n,r}function yi(e,n,t){var r=ri(336,null!==e&&void 0!==e?e:Q("see"),t);return r.name=n,r}function hi(e,n,t,r){return e.tagName!==n||e.name!==t||e.comment!==r?c(yi(n,t,r),e):e}function vi(e){var n=I(303);return n.name=e,n}function bi(e,n){return e.name!==n?c(vi(n),e):e}function Ei(e,n){var t=I(316);return t.name=e,t.text=n,t}function Ti(e,n,t){return e.name!==n?c(Ei(n,t),e):e}function Si(e,n,t,r){return void 0===n&&(n=ti(e)),e.tagName!==n||e.class!==t||e.comment!==r?c(gi(n,t,r),e):e}function xi(e,n,t){var r=ri(e,null!==n&&void 0!==n?n:Q(s(e)),t);return r}function Li(e,n,t,r){return void 0===t&&(t=ti(n)),n.tagName!==t||n.comment!==r?c(xi(e,t,r),n):n}function Di(e,n,t,r){var a=ri(e,null!==n&&void 0!==n?n:Q(s(e)),r);return a.typeExpression=t,a}function Ai(e,n,t,r,a){return void 0===t&&(t=ti(n)),n.tagName!==t||n.typeExpression!==r||n.comment!==a?c(Di(e,t,r,a),n):n}function Ci(e,n){var t=ri(317,e,n);return t}function Ii(e,n,t){return e.tagName!==n||e.comment!==t?c(Ci(n,t),e):e}function Ni(e){var n=I(313);return n.text=e,n}function ki(e,n){return e.text!==n?c(Ni(n),e):e}function Ri(e,n){var t=I(312);return t.comment=e,t.tags=Rs(n),t}function Oi(e,n,t){return e.comment!==n||e.tags!==t?c(Ri(n,t),e):e}function wi(e,n,t){var r=I(274);return r.openingElement=e,r.children=C(n),r.closingElement=t,r.transformFlags|=p(r.openingElement)|f(r.children)|p(r.closingElement)|2,r}function Pi(e,n,t,r){return e.openingElement!==n||e.children!==t||e.closingElement!==r?c(wi(n,t,r),e):e}function Mi(e,n,t){var r=I(275);return r.tagName=e,r.typeArguments=Rs(n),r.attributes=t,r.transformFlags|=p(r.tagName)|f(r.typeArguments)|p(r.attributes)|2,r.typeArguments&&(r.transformFlags|=1),r}function Fi(e,n,t,r){return e.tagName!==n||e.typeArguments!==t||e.attributes!==r?c(Mi(n,t,r),e):e}function Gi(e,n,t){var r=I(276);return r.tagName=e,r.typeArguments=Rs(n),r.attributes=t,r.transformFlags|=p(r.tagName)|f(r.typeArguments)|p(r.attributes)|2,n&&(r.transformFlags|=1),r}function Bi(e,n,t,r){return e.tagName!==n||e.typeArguments!==t||e.attributes!==r?c(Gi(n,t,r),e):e}function Ui(e){var n=I(277);return n.tagName=e,n.transformFlags|=2|p(n.tagName),n}function Vi(e,n){return e.tagName!==n?c(Ui(n),e):e}function ji(e,n,t){var r=I(278);return r.openingFragment=e,r.children=C(n),r.closingFragment=t,r.transformFlags|=p(r.openingFragment)|f(r.children)|p(r.closingFragment)|2,r}function Ki(e,n,t,r){return e.openingFragment!==n||e.children!==t||e.closingFragment!==r?c(ji(n,t,r),e):e}function Hi(e,n){var t=I(11);return t.text=e,t.containsOnlyTriviaWhiteSpaces=!!n,t.transformFlags|=2,t}function Wi(e,n,t){return e.text!==n||e.containsOnlyTriviaWhiteSpaces!==t?c(Hi(n,t),e):e}function zi(){var e=I(279);return e.transformFlags|=2,e}function qi(){var e=I(280);return e.transformFlags|=2,e}function Ji(e,n){var t=I(281);return t.name=e,t.initializer=n,t.transformFlags|=p(t.name)|p(t.initializer)|2,t}function Xi(e,n,t){return e.name!==n||e.initializer!==t?c(Ji(n,t),e):e}function Yi(e){var n=I(282);return n.properties=C(e),n.transformFlags|=2|f(n.properties),n}function Qi(e,n){return e.properties!==n?c(Yi(n),e):e}function Zi(e){var n=I(283);return n.expression=e,n.transformFlags|=2|p(n.expression),n}function $i(e,n){return e.expression!==n?c(Zi(n),e):e}function eo(e,n){var t=I(284);return t.dotDotDotToken=e,t.expression=n,t.transformFlags|=p(t.dotDotDotToken)|p(t.expression)|2,t}function no(e,n){return e.expression!==n?c(eo(e.dotDotDotToken,n),e):e}function to(e,n){var t=I(285);return t.expression=d().parenthesizeExpressionForDisallowedComma(e),t.statements=C(n),t.transformFlags|=p(t.expression)|f(t.statements),t}function ro(e,n,t){return e.expression!==n||e.statements!==t?c(to(n,t),e):e}function ao(e){var n=I(286);return n.statements=C(e),n.transformFlags=f(n.statements),n}function io(e,n){return e.statements!==n?c(ao(n),e):e}function oo(n,t){var r=I(287);switch(r.token=n,r.types=C(t),r.transformFlags|=f(r.types),n){case 93:r.transformFlags|=512;break;case 116:r.transformFlags|=1;break;default:return e.Debug.assertNever(n)}return r}function so(e,n){return e.types!==n?c(oo(e.token,n),e):e}function co(n,t){var r=I(288);return n=e.isString(n)?Zr(n,void 0,void 0,void 0):n,r.variableDeclaration=n,r.block=t,r.transformFlags|=p(r.variableDeclaration)|p(r.block),n||(r.transformFlags|=32),r}function lo(e,n,t){return e.variableDeclaration!==n||e.block!==t?c(co(n,t),e):e}function uo(e,n){var t=k(289,void 0,void 0,e);return t.initializer=d().parenthesizeExpressionForDisallowedComma(n),t.transformFlags|=p(t.name)|p(t.initializer),t}function po(e,n){return n.decorators&&(e.decorators=n.decorators),n.modifiers&&(e.modifiers=n.modifiers),n.questionToken&&(e.questionToken=n.questionToken),n.exclamationToken&&(e.exclamationToken=n.exclamationToken),c(e,n)}function fo(e,n,t){return e.name!==n||e.initializer!==t?po(uo(n,t),e):e}function mo(e,n){var t=k(290,void 0,void 0,e);return t.objectAssignmentInitializer=n&&d().parenthesizeExpressionForDisallowedComma(n),t.transformFlags|=512|p(t.objectAssignmentInitializer),t}function _o(e,n){return n.decorators&&(e.decorators=n.decorators),n.modifiers&&(e.modifiers=n.modifiers),n.equalsToken&&(e.equalsToken=n.equalsToken),n.questionToken&&(e.questionToken=n.questionToken),n.exclamationToken&&(e.exclamationToken=n.exclamationToken),c(e,n)}function go(e,n,t){return e.name!==n||e.objectAssignmentInitializer!==t?_o(mo(n,t),e):e}function yo(e){var n=I(291);return n.expression=d().parenthesizeExpressionForDisallowedComma(e),n.transformFlags|=32832|p(n.expression),n}function ho(e,n){return e.expression!==n?c(yo(n),e):e}function vo(e,n){var t=I(292);return t.name=Os(e),t.initializer=n&&d().parenthesizeExpressionForDisallowedComma(n),t.transformFlags|=p(t.name)|p(t.initializer)|1,t}function bo(e,n,t){return e.name!==n||e.initializer!==t?c(vo(n,t),e):e}function Eo(e,n,t){var a=r.createBaseSourceFileNode(298);return a.statements=C(e),a.endOfFileToken=n,a.flags|=t,a.fileName="",a.text="",a.languageVersion=0,a.languageVariant=0,a.scriptKind=0,a.isDeclarationFile=!1,a.hasNoDefaultLib=!1,a.transformFlags|=f(a.statements)|p(a.endOfFileToken),a}function To(n,t,a,i,o,s,c){var l=r.createBaseSourceFileNode(298);for(var u in n)"emitNode"!==u&&!e.hasProperty(l,u)&&e.hasProperty(n,u)&&(l[u]=n[u]);return l.flags|=n.flags,l.statements=C(t),l.endOfFileToken=n.endOfFileToken,l.isDeclarationFile=a,l.referencedFiles=i,l.typeReferenceDirectives=o,l.hasNoDefaultLib=s,l.libReferenceDirectives=c,l.transformFlags=f(l.statements)|p(l.endOfFileToken),l}function So(e,n,t,r,a,i,o){return void 0===t&&(t=e.isDeclarationFile),void 0===r&&(r=e.referencedFiles),void 0===a&&(a=e.typeReferenceDirectives),void 0===i&&(i=e.hasNoDefaultLib),void 0===o&&(o=e.libReferenceDirectives),e.statements!==n||e.isDeclarationFile!==t||e.referencedFiles!==r||e.typeReferenceDirectives!==a||e.hasNoDefaultLib!==i||e.libReferenceDirectives!==o?c(To(e,n,t,r,a,i,o),e):e}function xo(n,t){void 0===t&&(t=e.emptyArray);var r=I(299);return r.prepends=t,r.sourceFiles=n,r}function Lo(n,t,r){return void 0===r&&(r=e.emptyArray),n.sourceFiles!==t||n.prepends!==r?c(xo(t,r),n):n}function Do(n,t,r){var a=I(300);return a.prologues=n,a.syntheticReferences=t,a.texts=r,a.fileName="",a.text="",a.referencedFiles=e.emptyArray,a.libReferenceDirectives=e.emptyArray,a.getLineAndCharacterOfPosition=function(n){return e.getLineAndCharacterOfPosition(a,n)},a}function Ao(e,n){var t=I(e);return t.data=n,t}function Co(e){return Ao(293,e)}function Io(e,n){var t=Ao(294,e);return t.texts=n,t}function No(e,n){return Ao(n?296:295,e)}function ko(e){var n=I(297);return n.data=e.data,n.section=e,n}function Ro(){var e=I(301);return e.javascriptText="",e.declarationText="",e}function Oo(e,n,t){void 0===n&&(n=!1);var r=I(228);return r.type=e,r.isSpread=n,r.tupleNameSource=t,r}function wo(e){var n=I(338);return n._children=e,n}function Po(n){var t=I(339);return t.original=n,e.setTextRange(t,n),t}function Mo(n,t){var r=I(340);return r.expression=n,r.original=t,r.transformFlags|=1|p(r.expression),e.setTextRange(r,t),r}function Fo(e,n){return e.expression!==n?c(Mo(n,e.original),e):e}function Go(n){if(e.nodeIsSynthesized(n)&&!e.isParseTreeNode(n)&&!n.original&&!n.emitNode&&!n.id){if(e.isCommaListExpression(n))return n.elements;if(e.isBinaryExpression(n)&&e.isCommaToken(n.operatorToken))return[n.left,n.right]}return n}function Bo(n){var t=I(341);return t.elements=C(e.sameFlatMap(n,Go)),t.transformFlags|=f(t.elements),t}function Uo(e,n){return e.elements!==n?c(Bo(n),e):e}function Vo(e){var n=I(343);return n.emitNode={},n.original=e,n}function jo(e){var n=I(342);return n.emitNode={},n.original=e,n}function Ko(e,n){var t=I(344);return t.expression=e,t.thisArg=n,t.transformFlags|=p(t.expression)|p(t.thisArg),t}function Ho(e,n,t){return e.expression!==n||e.thisArg!==t?c(Ko(n,t),e):e}function Wo(n){if(void 0===n)return n;var t=e.isSourceFile(n)?r.createBaseSourceFileNode(298):e.isIdentifier(n)?r.createBaseIdentifierNode(78):e.isPrivateIdentifier(n)?r.createBasePrivateIdentifierNode(79):e.isNodeKind(n.kind)?r.createBaseNode(n.kind):r.createBaseTokenNode(n.kind);for(var a in t.flags|=-9&n.flags,t.transformFlags=n.transformFlags,L(t,n),n)!t.hasOwnProperty(a)&&n.hasOwnProperty(a)&&(t[a]=n[a]);return t}function zo(e,n,t){return lt(Et(void 0,void 0,void 0,void 0,n?[n]:[],void 0,gr(e,!0)),void 0,t?[t]:[])}function qo(e,n,t){return lt(St(void 0,void 0,n?[n]:[],void 0,void 0,gr(e,!0)),void 0,t?[t]:[])}function Jo(){return It(j("0"))}function Xo(e){return wa(void 0,void 0,!1,e)}function Yo(e){return Ma(void 0,void 0,!1,Ga([Ua(void 0,e)]))}function Qo(e,n){return"undefined"===n?A.createStrictEquality(e,Jo()):A.createStrictEquality(At(e),W(n))}function Zo(e,n,t){return lt(nt(e,n),void 0,t)}function $o(e,n,t){return Zo(e,"bind",i([n],t))}function es(e,n,t){return Zo(e,"call",i([n],t))}function ns(e,n,t){return Zo(e,"apply",[n,t])}function ts(e,n,t){return Zo(Q(e),n,t)}function rs(e,n){return Zo(e,"slice",void 0===n?[]:[ws(n)])}function as(e,n){return Zo(e,"concat",n)}function is(e,n,t){return ts("Object","defineProperty",[e,ws(n),t])}function os(e,n,t){return!!t&&(e.push(uo(n,t)),!0)}function ss(n,t){var r=[];os(r,"enumerable",ws(n.enumerable)),os(r,"configurable",ws(n.configurable));var a=os(r,"writable",ws(n.writable));a=os(r,"value",n.value)||a;var i=os(r,"get",n.get);return i=os(r,"set",n.set)||i,e.Debug.assert(!(a&&i),"A PropertyDescriptor may not be both an accessor descriptor and a data descriptor."),$n(r,!t)}function cs(e,n){switch(e.kind){case 208:return bt(e,n);case 207:return ht(e,e.type,n);case 225:return or(e,n,e.type);case 226:return cr(e,n);case 340:return Fo(e,n)}}function ls(n){return e.isParenthesizedExpression(n)&&e.nodeIsSynthesized(n)&&e.nodeIsSynthesized(e.getSourceMapRange(n))&&e.nodeIsSynthesized(e.getCommentRange(n))&&!e.some(e.getSyntheticLeadingComments(n))&&!e.some(e.getSyntheticTrailingComments(n))}function us(n,t,r){return void 0===r&&(r=15),n&&e.isOuterExpression(n,r)&&!ls(n)?cs(n,us(n.expression,t)):t}function ds(n,t,r){if(!t)return n;var a=zr(t,t.label,e.isLabeledStatement(t.statement)?ds(n,t.statement):n);return r&&r(t),a}function ps(n,t){var r=e.skipParentheses(n);switch(r.kind){case 78:return t;case 107:case 8:case 9:case 10:return!1;case 200:var a=r.elements;return 0!==a.length;case 201:return r.properties.length>0;default:return!0}}function fs(n,t,r,a){void 0===a&&(a=!1);var i,o,s=e.skipOuterExpressions(n,15);return e.isSuperProperty(s)?(i=se(),o=s):e.isSuperKeyword(s)?(i=se(),o=void 0!==r&&r<2?e.setTextRange(Q("_super"),s):s):4096&e.getEmitFlags(s)?(i=Jo(),o=d().parenthesizeLeftSideOfAccess(s)):e.isPropertyAccessExpression(s)?ps(s.expression,a)?(i=$(t),o=nt(e.setTextRange(A.createAssignment(i,s.expression),s.expression),s.name),e.setTextRange(o,s)):(i=s.expression,o=s):e.isElementAccessExpression(s)?ps(s.expression,a)?(i=$(t),o=it(e.setTextRange(A.createAssignment(i,s.expression),s.expression),s.argumentExpression),e.setTextRange(o,s)):(i=s.expression,o=s):(i=Jo(),o=d().parenthesizeLeftSideOfAccess(n)),{target:o,thisArg:i}}function ms(n){return n.length>10?Bo(n):e.reduceLeft(n,A.createComma)}function _s(n,t,r,a){void 0===a&&(a=0);var i=e.getNameOfDeclaration(n);if(i&&e.isIdentifier(i)&&!e.isGeneratedIdentifier(i)){var o=e.setParent(e.setTextRange(Wo(i),i),i.parent);return a|=e.getEmitFlags(i),r||(a|=48),t||(a|=1536),a&&e.setEmitFlags(o,a),o}return te(n)}function gs(e,n,t){return _s(e,n,t,49152)}function ys(e,n,t){return _s(e,n,t,16384)}function hs(e,n,t){return _s(e,n,t,8192)}function vs(e,n,t){return _s(e,n,t)}function bs(n,t,r,a){var i=nt(n,e.nodeIsSynthesized(t)?t:Wo(t));e.setTextRange(i,t);var o=0;return a||(o|=48),r||(o|=1536),o&&e.setEmitFlags(i,o),i}function Es(n,t,r,a){return n&&e.hasSyntacticModifier(t,1)?bs(n,_s(t),r,a):hs(t,r,a)}function Ts(e,n,t,r){var a=Ls(e,n,t);return Ds(e,n,a,r)}function Ss(n){return e.isStringLiteral(n.expression)&&"use strict"===n.expression.text}function xs(){return e.startOnNewLine(Er(W("use strict")))}function Ls(n,t,r){e.Debug.assert(0===t.length,"Prologue directives should be at the first statement in the target statements array");var a=!1,i=0,o=n.length;while(i<o){var s=n[i];if(!e.isPrologueDirective(s))break;Ss(s)&&(a=!0),t.push(s),i++}return r&&!a&&t.push(xs()),i}function Ds(n,t,r,a,i){void 0===i&&(i=e.returnTrue);var o=n.length;while(void 0!==r&&r<o){var s=n[r];if(!(1048576&e.getEmitFlags(s)&&i(s)))break;e.append(t,a?e.visitNode(s,a,e.isStatement):s),r++}return r}function As(n){var t=e.findUseStrictPrologue(n);return t?n:e.setTextRange(C(i([xs()],n)),n)}function Cs(n){return e.Debug.assert(e.every(n,e.isStatementOrBlock),"Cannot lift nodes to a Block."),e.singleOrUndefined(n)||gr(n)}function Is(e,n,t){var r=t;while(r<e.length&&n(e[r]))r++;return r}function Ns(n,t){if(!e.some(t))return n;var r=Is(n,e.isPrologueDirective,0),a=Is(n,e.isHoistedFunction,r),o=Is(n,e.isHoistedVariableStatement,a),s=Is(t,e.isPrologueDirective,0),c=Is(t,e.isHoistedFunction,s),l=Is(t,e.isHoistedVariableStatement,c),u=Is(t,e.isCustomPrologue,l);e.Debug.assert(u===t.length,"Expected declarations to be valid standard or custom prologues");var d=e.isNodeArray(n)?n.slice():n;if(u>l&&d.splice.apply(d,i([o,0],t.slice(l,u))),l>c&&d.splice.apply(d,i([a,0],t.slice(c,l))),c>s&&d.splice.apply(d,i([r,0],t.slice(s,c))),s>0)if(0===r)d.splice.apply(d,i([0,0],t.slice(0,s)));else{for(var p=new e.Map,f=0;f<r;f++){var m=n[f];p.set(m.expression.text,!0)}for(f=s-1;f>=0;f--){var _=t[f];p.has(_.expression.text)||d.unshift(_)}}return e.isNodeArray(n)?e.setTextRange(C(d,n.hasTrailingComma),n):n}function ks(n,t){var r;return"number"===typeof t&&(t=pe(t)),e.isParameter(n)?be(n,n.decorators,t,n.dotDotDotToken,n.name,n.questionToken,n.type,n.initializer):e.isPropertySignature(n)?xe(n,t,n.name,n.questionToken,n.type):e.isPropertyDeclaration(n)?De(n,n.decorators,t,n.name,null!==(r=n.questionToken)&&void 0!==r?r:n.exclamationToken,n.type,n.initializer):e.isMethodSignature(n)?Ce(n,t,n.name,n.questionToken,n.typeParameters,n.parameters,n.type):e.isMethodDeclaration(n)?Ne(n,n.decorators,t,n.asteriskToken,n.name,n.questionToken,n.typeParameters,n.parameters,n.type,n.body):e.isConstructorDeclaration(n)?Re(n,n.decorators,t,n.parameters,n.body):e.isGetAccessorDeclaration(n)?we(n,n.decorators,t,n.name,n.parameters,n.type,n.body):e.isSetAccessorDeclaration(n)?Me(n,n.decorators,t,n.name,n.parameters,n.body):e.isIndexSignatureDeclaration(n)?je(n,n.decorators,t,n.parameters,n.type):e.isFunctionExpression(n)?Tt(n,t,n.asteriskToken,n.name,n.typeParameters,n.parameters,n.type,n.body):e.isArrowFunction(n)?xt(n,t,n.typeParameters,n.parameters,n.type,n.equalsGreaterThanToken,n.body):e.isClassExpression(n)?nr(n,n.decorators,t,n.name,n.typeParameters,n.heritageClauses,n.members):e.isVariableStatement(n)?vr(n,t,n.declarationList):e.isFunctionDeclaration(n)?ra(n,n.decorators,t,n.asteriskToken,n.name,n.typeParameters,n.parameters,n.type,n.body):e.isClassDeclaration(n)?ia(n,n.decorators,t,n.name,n.typeParameters,n.heritageClauses,n.members):e.isInterfaceDeclaration(n)?sa(n,n.decorators,t,n.name,n.typeParameters,n.heritageClauses,n.members):e.isTypeAliasDeclaration(n)?la(n,n.decorators,t,n.name,n.typeParameters,n.type):e.isEnumDeclaration(n)?da(n,n.decorators,t,n.name,n.members):e.isModuleDeclaration(n)?fa(n,n.decorators,t,n.name,n.body):e.isImportEqualsDeclaration(n)?Ea(n,n.decorators,t,n.isTypeOnly,n.name,n.moduleReference):e.isImportDeclaration(n)?Sa(n,n.decorators,t,n.importClause,n.moduleSpecifier):e.isExportAssignment(n)?Pa(n,n.decorators,t,n.expression):e.isExportDeclaration(n)?Fa(n,n.decorators,t,n.isTypeOnly,n.exportClause,n.moduleSpecifier):e.Debug.assertNever(n)}function Rs(e){return e?C(e):void 0}function Os(e){return"string"===typeof e?Q(e):e}function ws(e){return"string"===typeof e?W(e):"number"===typeof e?j(e):"boolean"===typeof e?e?le():ue():e}function Ps(e){return"number"===typeof e?ie(e):e}function Ms(n){return n&&e.isNotEmittedStatement(n)?e.setTextRange(L(br(),n),n):n}}function a(n,t){return n!==t&&e.setTextRange(n,t),n}function o(n,t){return n!==t&&(L(n,t),e.setTextRange(n,t)),n}function s(n){switch(n){case 333:return"type";case 331:return"returns";case 332:return"this";case 329:return"enum";case 320:return"author";case 322:return"class";case 323:return"public";case 324:return"private";case 325:return"protected";case 326:return"readonly";case 327:return"override";case 334:return"template";case 335:return"typedef";case 330:return"param";case 337:return"prop";case 328:return"callback";case 318:return"augments";case 319:return"implements";default:return e.Debug.fail("Unsupported kind: "+e.Debug.formatSyntaxKind(n))}}(function(e){e[e["None"]=0]="None",e[e["NoParenthesizerRules"]=1]="NoParenthesizerRules",e[e["NoNodeConverters"]=2]="NoNodeConverters",e[e["NoIndentationOnFreshPropertyAccess"]=4]="NoIndentationOnFreshPropertyAccess",e[e["NoOriginalNode"]=8]="NoOriginalNode"})(e.NodeFactoryFlags||(e.NodeFactoryFlags={})),e.createNodeFactory=r;var c={};function l(t,r){switch(n||(n=e.createScanner(99,!1,0)),t){case 14:n.setText("`"+r+"`");break;case 15:n.setText("`"+r+"${");break;case 16:n.setText("}"+r+"${");break;case 17:n.setText("}"+r+"`");break}var a,i=n.scan();if(23===i&&(i=n.reScanTemplateToken(!1)),n.isUnterminated())return n.setText(void 0),c;switch(i){case 14:case 15:case 16:case 17:a=n.getTokenValue();break}return void 0===a||1!==n.scan()?(n.setText(void 0),c):(n.setText(void 0),a)}function u(e){return-16777217&p(e)}function d(e,n){return n|8192&e.transformFlags}function p(n){if(!n)return 0;var t=n.transformFlags&~_(n.kind);return e.isNamedDeclaration(n)&&e.isPropertyName(n.name)?d(n.name,t):t}function f(e){return e?e.transformFlags:0}function m(e){for(var n=0,t=0,r=e;t<r.length;t++){var a=r[t];n|=p(a)}e.transformFlags=n}function _(e){if(e>=173&&e<=196)return-2;switch(e){case 204:case 205:case 200:return 536887296;case 257:return 555888640;case 161:return 536870912;case 210:return 557748224;case 209:case 252:return 557756416;case 251:return 537165824;case 253:case 222:return 536940544;case 167:return 557752320;case 164:return 536879104;case 166:case 168:case 169:return 540975104;case 128:case 144:case 155:case 141:case 147:case 145:case 131:case 148:case 113:case 160:case 163:case 165:case 170:case 171:case 172:case 254:case 255:return-2;case 201:return 536973312;case 288:return 536903680;case 197:case 198:return 536887296;case 207:case 225:case 340:case 208:case 105:return 536870912;case 202:case 203:return 536870912;default:return 536870912}}e.getTransformFlagsSubtreeExclusions=_;var g=e.createBaseNodeFactory();function y(e){return e.flags|=8,e}var h,v={createBaseSourceFileNode:function(e){return y(g.createBaseSourceFileNode(e))},createBaseIdentifierNode:function(e){return y(g.createBaseIdentifierNode(e))},createBasePrivateIdentifierNode:function(e){return y(g.createBasePrivateIdentifierNode(e))},createBaseTokenNode:function(e){return y(g.createBaseTokenNode(e))},createBaseNode:function(e){return y(g.createBaseNode(e))}};function b(n,t,r){var a,i,o,s,c,l,u,d,p,f;e.isString(n)?(o="",s=n,c=n.length,l=t,u=r):(e.Debug.assert("js"===t||"dts"===t),o=("js"===t?n.javascriptPath:n.declarationPath)||"",l="js"===t?n.javascriptMapPath:n.declarationMapPath,d=function(){return"js"===t?n.javascriptText:n.declarationText},p=function(){return"js"===t?n.javascriptMapText:n.declarationMapText},c=function(){return d().length},n.buildInfo&&n.buildInfo.bundle&&(e.Debug.assert(void 0===r||"boolean"===typeof r),a=r,i="js"===t?n.buildInfo.bundle.js:n.buildInfo.bundle.dts,f=n.oldFileOfCurrentEmit));var m=f?T(e.Debug.assertDefined(i)):E(i,a,c);return m.fileName=o,m.sourceMapPath=l,m.oldFileOfCurrentEmit=f,d&&p?(Object.defineProperty(m,"text",{get:d}),Object.defineProperty(m,"sourceMapText",{get:p})):(e.Debug.assert(!f),m.text=null!==s&&void 0!==s?s:"",m.sourceMapText=u),m}function E(n,t,r){for(var a,i,o,s,c,l,u,d,p=0,f=n?n.sections:e.emptyArray;p<f.length;p++){var m=f[p];switch(m.kind){case"prologue":a=e.append(a,e.setTextRange(e.factory.createUnparsedPrologue(m.data),m));break;case"emitHelpers":i=e.append(i,e.getAllUnscopedEmitHelpers().get(m.data));break;case"no-default-lib":d=!0;break;case"reference":o=e.append(o,{pos:-1,end:-1,fileName:m.data});break;case"type":s=e.append(s,m.data);break;case"lib":c=e.append(c,{pos:-1,end:-1,fileName:m.data});break;case"prepend":for(var _=void 0,g=0,y=m.texts;g<y.length;g++){var h=y[g];t&&"internal"===h.kind||(_=e.append(_,e.setTextRange(e.factory.createUnparsedTextLike(h.data,"internal"===h.kind),h)))}l=e.addRange(l,_),u=e.append(u,e.factory.createUnparsedPrepend(m.data,null!==_&&void 0!==_?_:e.emptyArray));break;case"internal":if(t){u||(u=[]);break}case"text":u=e.append(u,e.setTextRange(e.factory.createUnparsedTextLike(m.data,"internal"===m.kind),m));break;default:e.Debug.assertNever(m)}}if(!u){var v=e.factory.createUnparsedTextLike(void 0,!1);e.setTextRangePosWidth(v,0,"function"===typeof r?r():r),u=[v]}var b=e.parseNodeFactory.createUnparsedSource(null!==a&&void 0!==a?a:e.emptyArray,void 0,u);return e.setEachParent(a,b),e.setEachParent(u,b),e.setEachParent(l,b),b.hasNoDefaultLib=d,b.helpers=i,b.referencedFiles=o||e.emptyArray,b.typeReferenceDirectives=s,b.libReferenceDirectives=c||e.emptyArray,b}function T(n){for(var t,r,a=0,i=n.sections;a<i.length;a++){var o=i[a];switch(o.kind){case"internal":case"text":t=e.append(t,e.setTextRange(e.factory.createUnparsedTextLike(o.data,"internal"===o.kind),o));break;case"no-default-lib":case"reference":case"type":case"lib":r=e.append(r,e.setTextRange(e.factory.createUnparsedSyntheticReference(o),o));break;case"prologue":case"emitHelpers":case"prepend":break;default:e.Debug.assertNever(o)}}var s=e.factory.createUnparsedSource(e.emptyArray,r,null!==t&&void 0!==t?t:e.emptyArray);return e.setEachParent(r,s),e.setEachParent(t,s),s.helpers=e.map(n.sources&&n.sources.helpers,(function(n){return e.getAllUnscopedEmitHelpers().get(n)})),s}function S(n,t,r,a,i,o,s,c,l,u,d){var p=e.parseNodeFactory.createInputFiles();if(e.isString(n))p.javascriptText=n,p.javascriptMapPath=r,p.javascriptMapText=a,p.declarationText=t,p.declarationMapPath=i,p.declarationMapText=o,p.javascriptPath=s,p.declarationPath=c,p.buildInfoPath=l,p.buildInfo=u,p.oldFileOfCurrentEmit=d;else{var f,m=new e.Map,_=function(e){if(void 0!==e){var t=m.get(e);return void 0===t&&(t=n(e),m.set(e,void 0!==t&&t)),!1!==t?t:void 0}},g=function(e){var n=_(e);return void 0!==n?n:"/* Input file "+e+" was missing */\r\n"},y=function(n){if(void 0===f){var t=n();f=void 0!==t&&e.getBuildInfo(t)}return f||void 0};p.javascriptPath=t,p.javascriptMapPath=r,p.declarationPath=e.Debug.assertDefined(a),p.declarationMapPath=i,p.buildInfoPath=o,Object.defineProperties(p,{javascriptText:{get:function(){return g(t)}},javascriptMapText:{get:function(){return _(r)}},declarationText:{get:function(){return g(e.Debug.assertDefined(a))}},declarationMapText:{get:function(){return _(i)}},buildInfo:{get:function(){return y((function(){return _(o)}))}}})}return p}function x(n,t,r){return new(h||(h=e.objectAllocator.getSourceMapSourceConstructor()))(n,t,r)}function L(e,n){if(e.original=n,n){var t=n.emitNode;t&&(e.emitNode=D(t,e.emitNode))}return e}function D(n,t){var r=n.flags,a=n.leadingComments,i=n.trailingComments,o=n.commentRange,s=n.sourceMapRange,c=n.tokenSourceMapRanges,l=n.constantValue,u=n.helpers,d=n.startsOnNewLine;if(t||(t={}),a&&(t.leadingComments=e.addRange(a.slice(),t.leadingComments)),i&&(t.trailingComments=e.addRange(i.slice(),t.trailingComments)),r&&(t.flags=r),o&&(t.commentRange=o),s&&(t.sourceMapRange=s),c&&(t.tokenSourceMapRanges=A(c,t.tokenSourceMapRanges)),void 0!==l&&(t.constantValue=l),u)for(var p=0,f=u;p<f.length;p++){var m=f[p];t.helpers=e.appendIfUnique(t.helpers,m)}return void 0!==d&&(t.startsOnNewLine=d),t}function A(e,n){for(var t in n||(n=[]),e)n[t]=e[t];return n}e.factory=r(4,v),e.createUnparsedSourceFile=b,e.createInputFiles=S,e.createSourceMapSource=x,e.setOriginalNode=L}(d||(d={})),function(e){function n(t){var r;if(!t.emitNode){if(e.isParseTreeNode(t)){if(298===t.kind)return t.emitNode={annotatedNodes:[t]};var a=null!==(r=e.getSourceFileOfNode(e.getParseTreeNode(e.getSourceFileOfNode(t))))&&void 0!==r?r:e.Debug.fail("Could not determine parsed source file.");n(a).annotatedNodes.push(t)}t.emitNode={}}return t.emitNode}function t(n){var t,r,a=null===(r=null===(t=e.getSourceFileOfNode(e.getParseTreeNode(n)))||void 0===t?void 0:t.emitNode)||void 0===r?void 0:r.annotatedNodes;if(a)for(var i=0,o=a;i<o.length;i++){var s=o[i];s.emitNode=void 0}}function r(e){var t=n(e);return t.flags|=1536,t.leadingComments=void 0,t.trailingComments=void 0,e}function a(e,t){return n(e).flags=t,e}function i(e,t){var r=n(e);return r.flags=r.flags|t,e}function o(e){var n,t;return null!==(t=null===(n=e.emitNode)||void 0===n?void 0:n.sourceMapRange)&&void 0!==t?t:e}function s(e,t){return n(e).sourceMapRange=t,e}function c(e,n){var t,r;return null===(r=null===(t=e.emitNode)||void 0===t?void 0:t.tokenSourceMapRanges)||void 0===r?void 0:r[n]}function l(e,t,r){var a,i=n(e),o=null!==(a=i.tokenSourceMapRanges)&&void 0!==a?a:i.tokenSourceMapRanges=[];return o[t]=r,e}function u(e){var n;return null===(n=e.emitNode)||void 0===n?void 0:n.startsOnNewLine}function d(e,t){return n(e).startsOnNewLine=t,e}function p(e){var n,t;return null!==(t=null===(n=e.emitNode)||void 0===n?void 0:n.commentRange)&&void 0!==t?t:e}function f(e,t){return n(e).commentRange=t,e}function m(e){var n;return null===(n=e.emitNode)||void 0===n?void 0:n.leadingComments}function _(e,t){return n(e).leadingComments=t,e}function g(n,t,r,a){return _(n,e.append(m(n),{kind:t,pos:-1,end:-1,hasTrailingNewLine:a,text:r}))}function y(e){var n;return null===(n=e.emitNode)||void 0===n?void 0:n.trailingComments}function h(e,t){return n(e).trailingComments=t,e}function v(n,t,r,a){return h(n,e.append(y(n),{kind:t,pos:-1,end:-1,hasTrailingNewLine:a,text:r}))}function b(e,t){_(e,m(t)),h(e,y(t));var r=n(t);return r.leadingComments=void 0,r.trailingComments=void 0,e}function E(e){var n;return null===(n=e.emitNode)||void 0===n?void 0:n.constantValue}function T(e,t){var r=n(e);return r.constantValue=t,e}function S(t,r){var a=n(t);return a.helpers=e.append(a.helpers,r),t}function x(t,r){if(e.some(r))for(var a=n(t),i=0,o=r;i<o.length;i++){var s=o[i];a.helpers=e.appendIfUnique(a.helpers,s)}return t}function L(n,t){var r,a=null===(r=n.emitNode)||void 0===r?void 0:r.helpers;return!!a&&e.orderedRemoveItem(a,t)}function D(e){var n;return null===(n=e.emitNode)||void 0===n?void 0:n.helpers}function A(t,r,a){var i=t.emitNode,o=i&&i.helpers;if(e.some(o)){for(var s=n(r),c=0,l=0;l<o.length;l++){var u=o[l];a(u)?(c++,s.helpers=e.appendIfUnique(s.helpers,u)):c>0&&(o[l-c]=u)}c>0&&(o.length-=c)}}function C(e){return n(e).flags|=134217728,e}e.getOrCreateEmitNode=n,e.disposeEmitNodes=t,e.removeAllComments=r,e.setEmitFlags=a,e.addEmitFlags=i,e.getSourceMapRange=o,e.setSourceMapRange=s,e.getTokenSourceMapRange=c,e.setTokenSourceMapRange=l,e.getStartsOnNewLine=u,e.setStartsOnNewLine=d,e.getCommentRange=p,e.setCommentRange=f,e.getSyntheticLeadingComments=m,e.setSyntheticLeadingComments=_,e.addSyntheticLeadingComment=g,e.getSyntheticTrailingComments=y,e.setSyntheticTrailingComments=h,e.addSyntheticTrailingComment=v,e.moveSyntheticComments=b,e.getConstantValue=E,e.setConstantValue=T,e.addEmitHelper=S,e.addEmitHelpers=x,e.removeEmitHelper=L,e.getEmitHelpers=D,e.moveEmitHelpers=A,e.ignoreSourceNewlines=C}(d||(d={})),function(e){function n(n){var t=n.factory;return{getUnscopedHelperName:r,createDecorateHelper:a,createMetadataHelper:o,createParamHelper:s,createAssignHelper:c,createAwaitHelper:l,createAsyncGeneratorHelper:u,createAsyncDelegatorHelper:d,createAsyncValuesHelper:p,createRestHelper:f,createAwaiterHelper:m,createExtendsHelper:_,createTemplateObjectHelper:g,createSpreadArrayHelper:y,createValuesHelper:h,createReadHelper:v,createGeneratorHelper:b,createCreateBindingHelper:E,createImportStarHelper:T,createImportStarCallbackHelper:S,createImportDefaultHelper:x,createExportStarHelper:L,createClassPrivateFieldGetHelper:D,createClassPrivateFieldSetHelper:A};function r(n){return e.setEmitFlags(t.createIdentifier(n),4098)}function a(a,i,o,s){n.requestEmitHelper(e.decorateHelper);var c=[];return c.push(t.createArrayLiteralExpression(a,!0)),c.push(i),o&&(c.push(o),s&&c.push(s)),t.createCallExpression(r("__decorate"),void 0,c)}function o(a,i){return n.requestEmitHelper(e.metadataHelper),t.createCallExpression(r("__metadata"),void 0,[t.createStringLiteral(a),i])}function s(a,i,o){return n.requestEmitHelper(e.paramHelper),e.setTextRange(t.createCallExpression(r("__param"),void 0,[t.createNumericLiteral(i+""),a]),o)}function c(a){return n.getCompilerOptions().target>=2?t.createCallExpression(t.createPropertyAccessExpression(t.createIdentifier("Object"),"assign"),void 0,a):(n.requestEmitHelper(e.assignHelper),t.createCallExpression(r("__assign"),void 0,a))}function l(a){return n.requestEmitHelper(e.awaitHelper),t.createCallExpression(r("__await"),void 0,[a])}function u(a,i){return n.requestEmitHelper(e.awaitHelper),n.requestEmitHelper(e.asyncGeneratorHelper),(a.emitNode||(a.emitNode={})).flags|=786432,t.createCallExpression(r("__asyncGenerator"),void 0,[i?t.createThis():t.createVoidZero(),t.createIdentifier("arguments"),a])}function d(a){return n.requestEmitHelper(e.awaitHelper),n.requestEmitHelper(e.asyncDelegator),t.createCallExpression(r("__asyncDelegator"),void 0,[a])}function p(a){return n.requestEmitHelper(e.asyncValues),t.createCallExpression(r("__asyncValues"),void 0,[a])}function f(a,i,o,s){n.requestEmitHelper(e.restHelper);for(var c=[],l=0,u=0;u<i.length-1;u++){var d=e.getPropertyNameOfBindingOrAssignmentElement(i[u]);if(d)if(e.isComputedPropertyName(d)){e.Debug.assertIsDefined(o,"Encountered computed property name but 'computedTempVariables' argument was not provided.");var p=o[l];l++,c.push(t.createConditionalExpression(t.createTypeCheck(p,"symbol"),void 0,p,void 0,t.createAdd(p,t.createStringLiteral(""))))}else c.push(t.createStringLiteralFromNode(d))}return t.createCallExpression(r("__rest"),void 0,[a,e.setTextRange(t.createArrayLiteralExpression(c),s)])}function m(a,i,o,s){n.requestEmitHelper(e.awaiterHelper);var c=t.createFunctionExpression(void 0,t.createToken(41),void 0,void 0,[],void 0,s);return(c.emitNode||(c.emitNode={})).flags|=786432,t.createCallExpression(r("__awaiter"),void 0,[a?t.createThis():t.createVoidZero(),i?t.createIdentifier("arguments"):t.createVoidZero(),o?e.createExpressionFromEntityName(t,o):t.createVoidZero(),c])}function _(a){return n.requestEmitHelper(e.extendsHelper),t.createCallExpression(r("__extends"),void 0,[a,t.createUniqueName("_super",48)])}function g(a,i){return n.requestEmitHelper(e.templateObjectHelper),t.createCallExpression(r("__makeTemplateObject"),void 0,[a,i])}function y(a,i){return n.requestEmitHelper(e.spreadArrayHelper),t.createCallExpression(r("__spreadArray"),void 0,[a,i])}function h(a){return n.requestEmitHelper(e.valuesHelper),t.createCallExpression(r("__values"),void 0,[a])}function v(a,i){return n.requestEmitHelper(e.readHelper),t.createCallExpression(r("__read"),void 0,void 0!==i?[a,t.createNumericLiteral(i+"")]:[a])}function b(a){return n.requestEmitHelper(e.generatorHelper),t.createCallExpression(r("__generator"),void 0,[t.createThis(),a])}function E(a,o,s){return n.requestEmitHelper(e.createBindingHelper),t.createCallExpression(r("__createBinding"),void 0,i([t.createIdentifier("exports"),a,o],s?[s]:[]))}function T(a){return n.requestEmitHelper(e.importStarHelper),t.createCallExpression(r("__importStar"),void 0,[a])}function S(){return n.requestEmitHelper(e.importStarHelper),r("__importStar")}function x(a){return n.requestEmitHelper(e.importDefaultHelper),t.createCallExpression(r("__importDefault"),void 0,[a])}function L(a,i){return void 0===i&&(i=t.createIdentifier("exports")),n.requestEmitHelper(e.exportStarHelper),n.requestEmitHelper(e.createBindingHelper),t.createCallExpression(r("__exportStar"),void 0,[a,i])}function D(a,i,o,s){var c;return n.requestEmitHelper(e.classPrivateFieldGetHelper),c=s?[a,i,t.createStringLiteral(o),s]:[a,i,t.createStringLiteral(o)],t.createCallExpression(r("__classPrivateFieldGet"),void 0,c)}function A(a,i,o,s,c){var l;return n.requestEmitHelper(e.classPrivateFieldSetHelper),l=c?[a,i,o,t.createStringLiteral(s),c]:[a,i,o,t.createStringLiteral(s)],t.createCallExpression(r("__classPrivateFieldSet"),void 0,l)}}function t(n,t){return n===t||n.priority===t.priority?0:void 0===n.priority?1:void 0===t.priority?-1:e.compareValues(n.priority,t.priority)}function r(e){for(var n=[],t=1;t<arguments.length;t++)n[t-1]=arguments[t];return function(t){for(var r="",a=0;a<n.length;a++)r+=e[a],r+=t(n[a]);return r+=e[e.length-1],r}}var a;function o(){return a||(a=e.arrayToMap([e.decorateHelper,e.metadataHelper,e.paramHelper,e.assignHelper,e.awaitHelper,e.asyncGeneratorHelper,e.asyncDelegator,e.asyncValues,e.restHelper,e.awaiterHelper,e.extendsHelper,e.templateObjectHelper,e.spreadArrayHelper,e.valuesHelper,e.readHelper,e.generatorHelper,e.importStarHelper,e.importDefaultHelper,e.exportStarHelper,e.classPrivateFieldGetHelper,e.classPrivateFieldSetHelper,e.createBindingHelper,e.setModuleDefaultHelper],(function(e){return e.name})))}function c(n,t){return e.isCallExpression(n)&&e.isIdentifier(n.expression)&&4096&e.getEmitFlags(n.expression)&&n.expression.escapedText===t}e.createEmitHelperFactory=n,e.compareEmitHelpers=t,e.helperString=r,e.decorateHelper={name:"typescript:decorate",importName:"__decorate",scoped:!1,priority:2,text:'\n            var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {\n                var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;\n                if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);\n                else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;\n                return c > 3 && r && Object.defineProperty(target, key, r), r;\n            };'},e.metadataHelper={name:"typescript:metadata",importName:"__metadata",scoped:!1,priority:3,text:'\n            var __metadata = (this && this.__metadata) || function (k, v) {\n                if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);\n            };'},e.paramHelper={name:"typescript:param",importName:"__param",scoped:!1,priority:4,text:"\n            var __param = (this && this.__param) || function (paramIndex, decorator) {\n                return function (target, key) { decorator(target, key, paramIndex); }\n            };"},e.assignHelper={name:"typescript:assign",importName:"__assign",scoped:!1,priority:1,text:"\n            var __assign = (this && this.__assign) || function () {\n                __assign = Object.assign || function(t) {\n                    for (var s, i = 1, n = arguments.length; i < n; i++) {\n                        s = arguments[i];\n                        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))\n                            t[p] = s[p];\n                    }\n                    return t;\n                };\n                return __assign.apply(this, arguments);\n            };"},e.awaitHelper={name:"typescript:await",importName:"__await",scoped:!1,text:"\n            var __await = (this && this.__await) || function (v) { return this instanceof __await ? (this.v = v, this) : new __await(v); }"},e.asyncGeneratorHelper={name:"typescript:asyncGenerator",importName:"__asyncGenerator",scoped:!1,dependencies:[e.awaitHelper],text:'\n            var __asyncGenerator = (this && this.__asyncGenerator) || function (thisArg, _arguments, generator) {\n                if (!Symbol.asyncIterator) throw new TypeError("Symbol.asyncIterator is not defined.");\n                var g = generator.apply(thisArg, _arguments || []), i, q = [];\n                return i = {}, verb("next"), verb("throw"), verb("return"), i[Symbol.asyncIterator] = function () { return this; }, i;\n                function verb(n) { if (g[n]) i[n] = function (v) { return new Promise(function (a, b) { q.push([n, v, a, b]) > 1 || resume(n, v); }); }; }\n                function resume(n, v) { try { step(g[n](v)); } catch (e) { settle(q[0][3], e); } }\n                function step(r) { r.value instanceof __await ? Promise.resolve(r.value.v).then(fulfill, reject) : settle(q[0][2], r); }\n                function fulfill(value) { resume("next", value); }\n                function reject(value) { resume("throw", value); }\n                function settle(f, v) { if (f(v), q.shift(), q.length) resume(q[0][0], q[0][1]); }\n            };'},e.asyncDelegator={name:"typescript:asyncDelegator",importName:"__asyncDelegator",scoped:!1,dependencies:[e.awaitHelper],text:'\n            var __asyncDelegator = (this && this.__asyncDelegator) || function (o) {\n                var i, p;\n                return i = {}, verb("next"), verb("throw", function (e) { throw e; }), verb("return"), i[Symbol.iterator] = function () { return this; }, i;\n                function verb(n, f) { i[n] = o[n] ? function (v) { return (p = !p) ? { value: __await(o[n](v)), done: n === "return" } : f ? f(v) : v; } : f; }\n            };'},e.asyncValues={name:"typescript:asyncValues",importName:"__asyncValues",scoped:!1,text:'\n            var __asyncValues = (this && this.__asyncValues) || function (o) {\n                if (!Symbol.asyncIterator) throw new TypeError("Symbol.asyncIterator is not defined.");\n                var m = o[Symbol.asyncIterator], i;\n                return m ? m.call(o) : (o = typeof __values === "function" ? __values(o) : o[Symbol.iterator](), i = {}, verb("next"), verb("throw"), verb("return"), i[Symbol.asyncIterator] = function () { return this; }, i);\n                function verb(n) { i[n] = o[n] && function (v) { return new Promise(function (resolve, reject) { v = o[n](v), settle(resolve, reject, v.done, v.value); }); }; }\n                function settle(resolve, reject, d, v) { Promise.resolve(v).then(function(v) { resolve({ value: v, done: d }); }, reject); }\n            };'},e.restHelper={name:"typescript:rest",importName:"__rest",scoped:!1,text:'\n            var __rest = (this && this.__rest) || function (s, e) {\n                var t = {};\n                for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)\n                    t[p] = s[p];\n                if (s != null && typeof Object.getOwnPropertySymbols === "function")\n                    for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {\n                        if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))\n                            t[p[i]] = s[p[i]];\n                    }\n                return t;\n            };'},e.awaiterHelper={name:"typescript:awaiter",importName:"__awaiter",scoped:!1,priority:5,text:'\n            var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {\n                function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }\n                return new (P || (P = Promise))(function (resolve, reject) {\n                    function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }\n                    function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }\n                    function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }\n                    step((generator = generator.apply(thisArg, _arguments || [])).next());\n                });\n            };'},e.extendsHelper={name:"typescript:extends",importName:"__extends",scoped:!1,priority:0,text:'\n            var __extends = (this && this.__extends) || (function () {\n                var extendStatics = function (d, b) {\n                    extendStatics = Object.setPrototypeOf ||\n                        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||\n                        function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };\n                    return extendStatics(d, b);\n                };\n\n                return function (d, b) {\n                    if (typeof b !== "function" && b !== null)\n                        throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");\n                    extendStatics(d, b);\n                    function __() { this.constructor = d; }\n                    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());\n                };\n            })();'},e.templateObjectHelper={name:"typescript:makeTemplateObject",importName:"__makeTemplateObject",scoped:!1,priority:0,text:'\n            var __makeTemplateObject = (this && this.__makeTemplateObject) || function (cooked, raw) {\n                if (Object.defineProperty) { Object.defineProperty(cooked, "raw", { value: raw }); } else { cooked.raw = raw; }\n                return cooked;\n            };'},e.readHelper={name:"typescript:read",importName:"__read",scoped:!1,text:'\n            var __read = (this && this.__read) || function (o, n) {\n                var m = typeof Symbol === "function" && o[Symbol.iterator];\n                if (!m) return o;\n                var i = m.call(o), r, ar = [], e;\n                try {\n                    while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);\n                }\n                catch (error) { e = { error: error }; }\n                finally {\n                    try {\n                        if (r && !r.done && (m = i["return"])) m.call(i);\n                    }\n                    finally { if (e) throw e.error; }\n                }\n                return ar;\n            };'},e.spreadArrayHelper={name:"typescript:spreadArray",importName:"__spreadArray",scoped:!1,text:"\n            var __spreadArray = (this && this.__spreadArray) || function (to, from) {\n                for (var i = 0, il = from.length, j = to.length; i < il; i++, j++)\n                    to[j] = from[i];\n                return to;\n            };"},e.valuesHelper={name:"typescript:values",importName:"__values",scoped:!1,text:'\n            var __values = (this && this.__values) || function(o) {\n                var s = typeof Symbol === "function" && Symbol.iterator, m = s && o[s], i = 0;\n                if (m) return m.call(o);\n                if (o && typeof o.length === "number") return {\n                    next: function () {\n                        if (o && i >= o.length) o = void 0;\n                        return { value: o && o[i++], done: !o };\n                    }\n                };\n                throw new TypeError(s ? "Object is not iterable." : "Symbol.iterator is not defined.");\n            };'},e.generatorHelper={name:"typescript:generator",importName:"__generator",scoped:!1,priority:6,text:'\n            var __generator = (this && this.__generator) || function (thisArg, body) {\n                var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;\n                return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;\n                function verb(n) { return function (v) { return step([n, v]); }; }\n                function step(op) {\n                    if (f) throw new TypeError("Generator is already executing.");\n                    while (_) try {\n                        if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;\n                        if (y = 0, t) op = [op[0] & 2, t.value];\n                        switch (op[0]) {\n                            case 0: case 1: t = op; break;\n                            case 4: _.label++; return { value: op[1], done: false };\n                            case 5: _.label++; y = op[1]; op = [0]; continue;\n                            case 7: op = _.ops.pop(); _.trys.pop(); continue;\n                            default:\n                                if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }\n                                if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }\n                                if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }\n                                if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }\n                                if (t[2]) _.ops.pop();\n                                _.trys.pop(); continue;\n                        }\n                        op = body.call(thisArg, _);\n                    } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }\n                    if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };\n                }\n            };'},e.createBindingHelper={name:"typescript:commonjscreatebinding",importName:"__createBinding",scoped:!1,priority:1,text:"\n            var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {\n                if (k2 === undefined) k2 = k;\n                Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });\n            }) : (function(o, m, k, k2) {\n                if (k2 === undefined) k2 = k;\n                o[k2] = m[k];\n            }));"},e.setModuleDefaultHelper={name:"typescript:commonjscreatevalue",importName:"__setModuleDefault",scoped:!1,priority:1,text:'\n            var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {\n                Object.defineProperty(o, "default", { enumerable: true, value: v });\n            }) : function(o, v) {\n                o["default"] = v;\n            });'},e.importStarHelper={name:"typescript:commonjsimportstar",importName:"__importStar",scoped:!1,dependencies:[e.createBindingHelper,e.setModuleDefaultHelper],priority:2,text:'\n            var __importStar = (this && this.__importStar) || function (mod) {\n                if (mod && mod.__esModule) return mod;\n                var result = {};\n                if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);\n                __setModuleDefault(result, mod);\n                return result;\n            };'},e.importDefaultHelper={name:"typescript:commonjsimportdefault",importName:"__importDefault",scoped:!1,text:'\n            var __importDefault = (this && this.__importDefault) || function (mod) {\n                return (mod && mod.__esModule) ? mod : { "default": mod };\n            };'},e.exportStarHelper={name:"typescript:export-star",importName:"__exportStar",scoped:!1,dependencies:[e.createBindingHelper],priority:2,text:'\n            var __exportStar = (this && this.__exportStar) || function(m, exports) {\n                for (var p in m) if (p !== "default" && !Object.prototype.hasOwnProperty.call(exports, p)) __createBinding(exports, m, p);\n            };'},e.classPrivateFieldGetHelper={name:"typescript:classPrivateFieldGet",importName:"__classPrivateFieldGet",scoped:!1,text:'\n            var __classPrivateFieldGet = (this && this.__classPrivateFieldGet) || function (receiver, state, kind, f) {\n                if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a getter");\n                if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot read private member from an object whose class did not declare it");\n                return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);\n            };'},e.classPrivateFieldSetHelper={name:"typescript:classPrivateFieldSet",importName:"__classPrivateFieldSet",scoped:!1,text:'\n            var __classPrivateFieldSet = (this && this.__classPrivateFieldSet) || function (receiver, state, value, kind, f) {\n                if (kind === "m") throw new TypeError("Private method is not writable");\n                if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a setter");\n                if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot write private member to an object whose class did not declare it");\n                return (kind === "a" ? f.call(receiver, value) : f ? f.value = value : state.set(receiver, value)), value;\n            };'},e.getAllUnscopedEmitHelpers=o,e.asyncSuperHelper={name:"typescript:async-super",scoped:!0,text:r(s(["\n            const "," = name => super[name];"],["\n            const "," = name => super[name];"]),"_superIndex")},e.advancedAsyncSuperHelper={name:"typescript:advanced-async-super",scoped:!0,text:r(s(["\n            const "," = (function (geti, seti) {\n                const cache = Object.create(null);\n                return name => cache[name] || (cache[name] = { get value() { return geti(name); }, set value(v) { seti(name, v); } });\n            })(name => super[name], (name, value) => super[name] = value);"],["\n            const "," = (function (geti, seti) {\n                const cache = Object.create(null);\n                return name => cache[name] || (cache[name] = { get value() { return geti(name); }, set value(v) { seti(name, v); } });\n            })(name => super[name], (name, value) => super[name] = value);"]),"_superIndex")},e.isCallToHelper=c}(d||(d={})),function(e){function n(e){return 8===e.kind}function t(e){return 9===e.kind}function r(e){return 10===e.kind}function a(e){return 11===e.kind}function i(e){return 13===e.kind}function o(e){return 14===e.kind}function s(e){return 15===e.kind}function c(e){return 16===e.kind}function l(e){return 17===e.kind}function u(e){return 25===e.kind}function d(e){return 27===e.kind}function p(e){return 39===e.kind}function f(e){return 40===e.kind}function m(e){return 41===e.kind}function _(e){return 53===e.kind}function g(e){return 57===e.kind}function y(e){return 58===e.kind}function h(e){return 28===e.kind}function v(e){return 38===e.kind}function b(e){return 78===e.kind}function E(e){return 79===e.kind}function T(e){return 92===e.kind}function S(e){return 129===e.kind}function x(e){return 127===e.kind}function L(e){return 130===e.kind}function D(e){return 142===e.kind}function A(e){return 123===e.kind}function C(e){return 105===e.kind}function I(e){return 99===e.kind}function N(e){return 158===e.kind}function k(e){return 159===e.kind}function R(e){return 160===e.kind}function O(e){return 161===e.kind}function w(e){return 162===e.kind}function P(e){return 163===e.kind}function M(e){return 164===e.kind}function F(e){return 165===e.kind}function G(e){return 166===e.kind}function B(e){return 167===e.kind}function U(e){return 168===e.kind}function V(e){return 169===e.kind}function j(e){return 170===e.kind}function K(e){return 171===e.kind}function H(e){return 172===e.kind}function W(e){return 173===e.kind}function z(e){return 174===e.kind}function q(e){return 175===e.kind}function J(e){return 176===e.kind}function X(e){return 177===e.kind}function Y(e){return 178===e.kind}function Q(e){return 179===e.kind}function Z(e){return 180===e.kind}function $(e){return 193===e.kind}function ee(e){return 181===e.kind}function ne(e){return 182===e.kind}function te(e){return 183===e.kind}function re(e){return 184===e.kind}function ae(e){return 185===e.kind}function ie(e){return 186===e.kind}function oe(e){return 187===e.kind}function se(e){return 188===e.kind}function ce(e){return 189===e.kind}function le(e){return 190===e.kind}function ue(e){return 191===e.kind}function de(e){return 192===e.kind}function pe(e){return 196===e.kind}function fe(e){return 195===e.kind}function me(e){return 194===e.kind}function _e(e){return 197===e.kind}function ge(e){return 198===e.kind}function ye(e){return 199===e.kind}function he(e){return 200===e.kind}function ve(e){return 201===e.kind}function be(e){return 202===e.kind}function Ee(e){return 203===e.kind}function Te(e){return 204===e.kind}function Se(e){return 205===e.kind}function xe(e){return 206===e.kind}function Le(e){return 207===e.kind}function De(e){return 208===e.kind}function Ae(e){return 209===e.kind}function Ce(e){return 210===e.kind}function Ie(e){return 211===e.kind}function Ne(e){return 212===e.kind}function ke(e){return 213===e.kind}function Re(e){return 214===e.kind}function Oe(e){return 215===e.kind}function we(e){return 216===e.kind}function Pe(e){return 217===e.kind}function Me(e){return 218===e.kind}function Fe(e){return 219===e.kind}function Ge(e){return 220===e.kind}function Be(e){return 221===e.kind}function Ue(e){return 222===e.kind}function Ve(e){return 223===e.kind}function je(e){return 224===e.kind}function Ke(e){return 225===e.kind}function He(e){return 226===e.kind}function We(e){return 227===e.kind}function ze(e){return 228===e.kind}function qe(e){return 340===e.kind}function Je(e){return 341===e.kind}function Xe(e){return 229===e.kind}function Ye(e){return 230===e.kind}function Qe(e){return 231===e.kind}function Ze(e){return 233===e.kind}function $e(e){return 232===e.kind}function en(e){return 234===e.kind}function nn(e){return 235===e.kind}function tn(e){return 236===e.kind}function rn(e){return 237===e.kind}function an(e){return 238===e.kind}function on(e){return 239===e.kind}function sn(e){return 240===e.kind}function cn(e){return 241===e.kind}function ln(e){return 242===e.kind}function un(e){return 243===e.kind}function dn(e){return 244===e.kind}function pn(e){return 245===e.kind}function fn(e){return 246===e.kind}function mn(e){return 247===e.kind}function _n(e){return 248===e.kind}function gn(e){return 249===e.kind}function yn(e){return 250===e.kind}function hn(e){return 251===e.kind}function vn(e){return 252===e.kind}function bn(e){return 253===e.kind}function En(e){return 254===e.kind}function Tn(e){return 255===e.kind}function Sn(e){return 256===e.kind}function xn(e){return 257===e.kind}function Ln(e){return 258===e.kind}function Dn(e){return 259===e.kind}function An(e){return 260===e.kind}function Cn(e){return 261===e.kind}function In(e){return 262===e.kind}function Nn(e){return 263===e.kind}function kn(e){return 264===e.kind}function Rn(e){return 270===e.kind}function On(e){return 265===e.kind}function wn(e){return 266===e.kind}function Pn(e){return 267===e.kind}function Mn(e){return 268===e.kind}function Fn(e){return 269===e.kind}function Gn(e){return 271===e.kind}function Bn(e){return 272===e.kind}function Un(e){return 339===e.kind}function Vn(e){return 344===e.kind}function jn(e){return 342===e.kind}function Kn(e){return 343===e.kind}function Hn(e){return 273===e.kind}function Wn(e){return 274===e.kind}function zn(e){return 275===e.kind}function qn(e){return 276===e.kind}function Jn(e){return 277===e.kind}function Xn(e){return 278===e.kind}function Yn(e){return 279===e.kind}function Qn(e){return 280===e.kind}function Zn(e){return 281===e.kind}function $n(e){return 282===e.kind}function et(e){return 283===e.kind}function nt(e){return 284===e.kind}function tt(e){return 285===e.kind}function rt(e){return 286===e.kind}function at(e){return 287===e.kind}function it(e){return 288===e.kind}function ot(e){return 289===e.kind}function st(e){return 290===e.kind}function ct(e){return 291===e.kind}function lt(e){return 292===e.kind}function ut(e){return 294===e.kind}function dt(e){return 298===e.kind}function pt(e){return 299===e.kind}function ft(e){return 300===e.kind}function mt(e){return 302===e.kind}function _t(e){return 303===e.kind}function gt(e){return 316===e.kind}function yt(e){return 304===e.kind}function ht(e){return 305===e.kind}function vt(e){return 306===e.kind}function bt(e){return 307===e.kind}function Et(e){return 308===e.kind}function Tt(e){return 309===e.kind}function St(e){return 310===e.kind}function xt(e){return 311===e.kind}function Lt(e){return 312===e.kind}function Dt(e){return 314===e.kind}function At(e){return 315===e.kind}function Ct(e){return 318===e.kind}function It(e){return 320===e.kind}function Nt(e){return 322===e.kind}function kt(e){return 328===e.kind}function Rt(e){return 323===e.kind}function Ot(e){return 324===e.kind}function wt(e){return 325===e.kind}function Pt(e){return 326===e.kind}function Mt(e){return 327===e.kind}function Ft(e){return 321===e.kind}function Gt(e){return 336===e.kind}function Bt(e){return 329===e.kind}function Ut(e){return 330===e.kind}function Vt(e){return 331===e.kind}function jt(e){return 332===e.kind}function Kt(e){return 333===e.kind}function Ht(e){return 334===e.kind}function Wt(e){return 335===e.kind}function zt(e){return 317===e.kind}function qt(e){return 337===e.kind}function Jt(e){return 319===e.kind}function Xt(e){return 338===e.kind}e.isNumericLiteral=n,e.isBigIntLiteral=t,e.isStringLiteral=r,e.isJsxText=a,e.isRegularExpressionLiteral=i,e.isNoSubstitutionTemplateLiteral=o,e.isTemplateHead=s,e.isTemplateMiddle=c,e.isTemplateTail=l,e.isDotDotDotToken=u,e.isCommaToken=d,e.isPlusToken=p,e.isMinusToken=f,e.isAsteriskToken=m,e.isExclamationToken=_,e.isQuestionToken=g,e.isColonToken=y,e.isQuestionDotToken=h,e.isEqualsGreaterThanToken=v,e.isIdentifier=b,e.isPrivateIdentifier=E,e.isExportModifier=T,e.isAsyncModifier=S,e.isAssertsKeyword=x,e.isAwaitKeyword=L,e.isReadonlyKeyword=D,e.isStaticModifier=A,e.isSuperKeyword=C,e.isImportKeyword=I,e.isQualifiedName=N,e.isComputedPropertyName=k,e.isTypeParameterDeclaration=R,e.isParameter=O,e.isDecorator=w,e.isPropertySignature=P,e.isPropertyDeclaration=M,e.isMethodSignature=F,e.isMethodDeclaration=G,e.isConstructorDeclaration=B,e.isGetAccessorDeclaration=U,e.isSetAccessorDeclaration=V,e.isCallSignatureDeclaration=j,e.isConstructSignatureDeclaration=K,e.isIndexSignatureDeclaration=H,e.isTypePredicateNode=W,e.isTypeReferenceNode=z,e.isFunctionTypeNode=q,e.isConstructorTypeNode=J,e.isTypeQueryNode=X,e.isTypeLiteralNode=Y,e.isArrayTypeNode=Q,e.isTupleTypeNode=Z,e.isNamedTupleMember=$,e.isOptionalTypeNode=ee,e.isRestTypeNode=ne,e.isUnionTypeNode=te,e.isIntersectionTypeNode=re,e.isConditionalTypeNode=ae,e.isInferTypeNode=ie,e.isParenthesizedTypeNode=oe,e.isThisTypeNode=se,e.isTypeOperatorNode=ce,e.isIndexedAccessTypeNode=le,e.isMappedTypeNode=ue,e.isLiteralTypeNode=de,e.isImportTypeNode=pe,e.isTemplateLiteralTypeSpan=fe,e.isTemplateLiteralTypeNode=me,e.isObjectBindingPattern=_e,e.isArrayBindingPattern=ge,e.isBindingElement=ye,e.isArrayLiteralExpression=he,e.isObjectLiteralExpression=ve,e.isPropertyAccessExpression=be,e.isElementAccessExpression=Ee,e.isCallExpression=Te,e.isNewExpression=Se,e.isTaggedTemplateExpression=xe,e.isTypeAssertionExpression=Le,e.isParenthesizedExpression=De,e.isFunctionExpression=Ae,e.isArrowFunction=Ce,e.isDeleteExpression=Ie,e.isTypeOfExpression=Ne,e.isVoidExpression=ke,e.isAwaitExpression=Re,e.isPrefixUnaryExpression=Oe,e.isPostfixUnaryExpression=we,e.isBinaryExpression=Pe,e.isConditionalExpression=Me,e.isTemplateExpression=Fe,e.isYieldExpression=Ge,e.isSpreadElement=Be,e.isClassExpression=Ue,e.isOmittedExpression=Ve,e.isExpressionWithTypeArguments=je,e.isAsExpression=Ke,e.isNonNullExpression=He,e.isMetaProperty=We,e.isSyntheticExpression=ze,e.isPartiallyEmittedExpression=qe,e.isCommaListExpression=Je,e.isTemplateSpan=Xe,e.isSemicolonClassElement=Ye,e.isBlock=Qe,e.isVariableStatement=Ze,e.isEmptyStatement=$e,e.isExpressionStatement=en,e.isIfStatement=nn,e.isDoStatement=tn,e.isWhileStatement=rn,e.isForStatement=an,e.isForInStatement=on,e.isForOfStatement=sn,e.isContinueStatement=cn,e.isBreakStatement=ln,e.isReturnStatement=un,e.isWithStatement=dn,e.isSwitchStatement=pn,e.isLabeledStatement=fn,e.isThrowStatement=mn,e.isTryStatement=_n,e.isDebuggerStatement=gn,e.isVariableDeclaration=yn,e.isVariableDeclarationList=hn,e.isFunctionDeclaration=vn,e.isClassDeclaration=bn,e.isInterfaceDeclaration=En,e.isTypeAliasDeclaration=Tn,e.isEnumDeclaration=Sn,e.isModuleDeclaration=xn,e.isModuleBlock=Ln,e.isCaseBlock=Dn,e.isNamespaceExportDeclaration=An,e.isImportEqualsDeclaration=Cn,e.isImportDeclaration=In,e.isImportClause=Nn,e.isNamespaceImport=kn,e.isNamespaceExport=Rn,e.isNamedImports=On,e.isImportSpecifier=wn,e.isExportAssignment=Pn,e.isExportDeclaration=Mn,e.isNamedExports=Fn,e.isExportSpecifier=Gn,e.isMissingDeclaration=Bn,e.isNotEmittedStatement=Un,e.isSyntheticReference=Vn,e.isMergeDeclarationMarker=jn,e.isEndOfDeclarationMarker=Kn,e.isExternalModuleReference=Hn,e.isJsxElement=Wn,e.isJsxSelfClosingElement=zn,e.isJsxOpeningElement=qn,e.isJsxClosingElement=Jn,e.isJsxFragment=Xn,e.isJsxOpeningFragment=Yn,e.isJsxClosingFragment=Qn,e.isJsxAttribute=Zn,e.isJsxAttributes=$n,e.isJsxSpreadAttribute=et,e.isJsxExpression=nt,e.isCaseClause=tt,e.isDefaultClause=rt,e.isHeritageClause=at,e.isCatchClause=it,e.isPropertyAssignment=ot,e.isShorthandPropertyAssignment=st,e.isSpreadAssignment=ct,e.isEnumMember=lt,e.isUnparsedPrepend=ut,e.isSourceFile=dt,e.isBundle=pt,e.isUnparsedSource=ft,e.isJSDocTypeExpression=mt,e.isJSDocNameReference=_t,e.isJSDocLink=gt,e.isJSDocAllType=yt,e.isJSDocUnknownType=ht,e.isJSDocNullableType=vt,e.isJSDocNonNullableType=bt,e.isJSDocOptionalType=Et,e.isJSDocFunctionType=Tt,e.isJSDocVariadicType=St,e.isJSDocNamepathType=xt,e.isJSDoc=Lt,e.isJSDocTypeLiteral=Dt,e.isJSDocSignature=At,e.isJSDocAugmentsTag=Ct,e.isJSDocAuthorTag=It,e.isJSDocClassTag=Nt,e.isJSDocCallbackTag=kt,e.isJSDocPublicTag=Rt,e.isJSDocPrivateTag=Ot,e.isJSDocProtectedTag=wt,e.isJSDocReadonlyTag=Pt,e.isJSDocOverrideTag=Mt,e.isJSDocDeprecatedTag=Ft,e.isJSDocSeeTag=Gt,e.isJSDocEnumTag=Bt,e.isJSDocParameterTag=Ut,e.isJSDocReturnTag=Vt,e.isJSDocThisTag=jt,e.isJSDocTypeTag=Kt,e.isJSDocTemplateTag=Ht,e.isJSDocTypedefTag=Wt,e.isJSDocUnknownTag=zt,e.isJSDocPropertyTag=qt,e.isJSDocImplementsTag=Jt,e.isSyntaxList=Xt}(d||(d={})),function(e){function n(e){return e.createExportDeclaration(void 0,void 0,!1,e.createNamedExports([]),void 0)}function t(n,t,r,a){if(e.isComputedPropertyName(r))return e.setTextRange(n.createElementAccessExpression(t,r.expression),a);var i=e.setTextRange(e.isMemberName(r)?n.createPropertyAccessExpression(t,r):n.createElementAccessExpression(t,r),r);return e.getOrCreateEmitNode(i).flags|=64,i}function r(n,t){var r=e.parseNodeFactory.createIdentifier(n||"React");return e.setParent(r,e.getParseTreeNode(t)),r}function a(n,t,i){if(e.isQualifiedName(t)){var o=a(n,t.left,i),s=n.createIdentifier(e.idText(t.right));return s.escapedText=t.right.escapedText,n.createPropertyAccessExpression(o,s)}return r(e.idText(t),i)}function o(e,n,t,i){return n?a(e,n,i):e.createPropertyAccessExpression(r(t,i),"createElement")}function s(e,n,t,i){return n?a(e,n,i):e.createPropertyAccessExpression(r(t,i),"Fragment")}function c(n,t,r,a,i,o){var s=[r];if(a&&s.push(a),i&&i.length>0)if(a||s.push(n.createNull()),i.length>1)for(var c=0,l=i;c<l.length;c++){var u=l[c];I(u),s.push(u)}else s.push(i[0]);return e.setTextRange(n.createCallExpression(t,void 0,s),o)}function l(n,t,r,a,i,c,l){var u=s(n,r,a,c),d=[u,n.createNull()];if(i&&i.length>0)if(i.length>1)for(var p=0,f=i;p<f.length;p++){var m=f[p];I(m),d.push(m)}else d.push(i[0]);return e.setTextRange(n.createCallExpression(o(n,t,a,c),void 0,d),l)}function u(n,t,r){if(e.isVariableDeclarationList(t)){var a=e.first(t.declarations),i=n.updateVariableDeclaration(a,a.name,void 0,void 0,r);return e.setTextRange(n.createVariableStatement(void 0,n.updateVariableDeclarationList(t,[i])),t)}var o=e.setTextRange(n.createAssignment(t,r),t);return e.setTextRange(n.createExpressionStatement(o),t)}function d(n,t,r){return e.isBlock(t)?n.updateBlock(t,e.setTextRange(n.createNodeArray(i([r],t.statements)),t.statements)):n.createBlock(n.createNodeArray([t,r]),!0)}function p(n,t){if(e.isQualifiedName(t)){var r=p(n,t.left),a=e.setParent(e.setTextRange(n.cloneNode(t.right),t.right),t.right.parent);return e.setTextRange(n.createPropertyAccessExpression(r,a),t)}return e.setParent(e.setTextRange(n.cloneNode(t),t),t.parent)}function f(n,t){return e.isIdentifier(t)?n.createStringLiteralFromNode(t):e.isComputedPropertyName(t)?e.setParent(e.setTextRange(n.cloneNode(t.expression),t.expression),t.expression.parent):e.setParent(e.setTextRange(n.cloneNode(t),t),t.parent)}function m(n,t,r,a,i){var o=e.getAllAccessorDeclarations(t,r),s=o.firstAccessor,c=o.getAccessor,l=o.setAccessor;if(r===s)return e.setTextRange(n.createObjectDefinePropertyCall(a,f(n,r.name),n.createPropertyDescriptor({enumerable:n.createFalse(),configurable:!0,get:c&&e.setTextRange(e.setOriginalNode(n.createFunctionExpression(c.modifiers,void 0,void 0,void 0,c.parameters,void 0,c.body),c),c),set:l&&e.setTextRange(e.setOriginalNode(n.createFunctionExpression(l.modifiers,void 0,void 0,void 0,l.parameters,void 0,l.body),l),l)},!i)),s)}function _(n,r,a){return e.setOriginalNode(e.setTextRange(n.createAssignment(t(n,a,r.name,r.name),r.initializer),r),r)}function g(n,r,a){return e.setOriginalNode(e.setTextRange(n.createAssignment(t(n,a,r.name,r.name),n.cloneNode(r.name)),r),r)}function y(n,r,a){return e.setOriginalNode(e.setTextRange(n.createAssignment(t(n,a,r.name,r.name),e.setOriginalNode(e.setTextRange(n.createFunctionExpression(r.modifiers,r.asteriskToken,void 0,void 0,r.parameters,void 0,r.body),r),r)),r),r)}function h(n,t,r,a){switch(r.name&&e.isPrivateIdentifier(r.name)&&e.Debug.failBadSyntaxKind(r.name,"Private identifiers are not allowed in object literals."),r.kind){case 168:case 169:return m(n,t.properties,r,a,!!t.multiLine);case 289:return _(n,r,a);case 290:return g(n,r,a);case 166:return y(n,r,a)}}function v(n){return 0!==(32768&e.getEmitFlags(n))}function b(n){return 0!==(16384&e.getEmitFlags(n))}function E(n){return 0!==(8192&e.getEmitFlags(n))}function T(n){return e.isStringLiteral(n.expression)&&"use strict"===n.expression.text}function S(n){for(var t=0,r=n;t<r.length;t++){var a=r[t];if(!e.isPrologueDirective(a))break;if(T(a))return a}}function x(n){var t=e.firstOrUndefined(n);return void 0!==t&&e.isPrologueDirective(t)&&T(t)}function L(e){return 217===e.kind&&27===e.operatorToken.kind||341===e.kind}function D(e,n){switch(void 0===n&&(n=15),e.kind){case 208:return 0!==(1&n);case 207:case 225:return 0!==(2&n);case 226:return 0!==(4&n);case 340:return 0!==(8&n)}return!1}function A(e,n){void 0===n&&(n=15);while(D(e,n))e=e.expression;return e}function C(e){return A(e,6)}function I(n){return e.setStartsOnNewLine(n,!0)}function N(n){var t=e.getOriginalNode(n,e.isSourceFile),r=t&&t.emitNode;return r&&r.externalHelpersModuleName}function k(n){var t=e.getOriginalNode(n,e.isSourceFile),r=t&&t.emitNode;return!!r&&(!!r.externalHelpersModuleName||!!r.externalHelpers)}function R(n,t,r,a,i,o,s){if(a.importHelpers&&e.isEffectiveExternalModule(r,a)){var c=void 0,l=e.getEmitModuleKind(a);if(l>=e.ModuleKind.ES2015&&l<=e.ModuleKind.ESNext){var u=e.getEmitHelpers(r);if(u){for(var d=[],p=0,f=u;p<f.length;p++){var m=f[p];if(!m.scoped){var _=m.importName;_&&e.pushIfUnique(d,_)}}if(e.some(d)){d.sort(e.compareStringsCaseSensitive),c=n.createNamedImports(e.map(d,(function(a){return e.isFileLevelUniqueName(r,a)?n.createImportSpecifier(void 0,n.createIdentifier(a)):n.createImportSpecifier(n.createIdentifier(a),t.getUnscopedHelperName(a))})));var g=e.getOriginalNode(r,e.isSourceFile),y=e.getOrCreateEmitNode(g);y.externalHelpers=!0}}}else{var h=O(n,r,a,i,o||s);h&&(c=n.createNamespaceImport(h))}if(c){var v=n.createImportDeclaration(void 0,void 0,n.createImportClause(!1,void 0,c),n.createStringLiteral(e.externalHelpersModuleNameText));return e.addEmitFlags(v,67108864),v}}}function O(n,t,r,a,i){if(r.importHelpers&&e.isEffectiveExternalModule(t,r)){var o=N(t);if(o)return o;var s=e.getEmitModuleKind(r),c=(a||r.esModuleInterop&&i)&&s!==e.ModuleKind.System&&s<e.ModuleKind.ES2015;if(!c){var l=e.getEmitHelpers(t);if(l)for(var u=0,d=l;u<d.length;u++){var p=d[u];if(!p.scoped){c=!0;break}}}if(c){var f=e.getOriginalNode(t,e.isSourceFile),m=e.getOrCreateEmitNode(f);return m.externalHelpersModuleName||(m.externalHelpersModuleName=n.createUniqueName(e.externalHelpersModuleNameText))}}}function w(n,t,r){var a=e.getNamespaceDeclarationNode(t);if(a&&!e.isDefaultImport(t)&&!e.isExportNamespaceAsDefaultDeclaration(t)){var i=a.name;return e.isGeneratedIdentifier(i)?i:n.createIdentifier(e.getSourceTextOfNodeFromSourceFile(r,i)||e.idText(i))}return 262===t.kind&&t.importClause||268===t.kind&&t.moduleSpecifier?n.getGeneratedNameForNode(t):void 0}function P(n,t,r,a,i,o){var s=e.getExternalModuleName(t);if(s&&e.isStringLiteral(s))return G(t,a,n,i,o)||M(n,s,r)||n.cloneNode(s)}function M(e,n,t){var r=t.renamedDependencies&&t.renamedDependencies.get(n.text);return r?e.createStringLiteral(r):void 0}function F(n,t,r,a){if(t)return t.moduleName?n.createStringLiteral(t.moduleName):!t.isDeclarationFile&&e.outFile(a)?n.createStringLiteral(e.getExternalModuleNameFromPath(r,t.fileName)):void 0}function G(e,n,t,r,a){return F(t,r.getExternalModuleFileFromDeclaration(e),n,a)}function B(n){if(e.isDeclarationBindingElement(n))return n.initializer;if(e.isPropertyAssignment(n)){var t=n.initializer;return e.isAssignmentExpression(t,!0)?t.right:void 0}return e.isShorthandPropertyAssignment(n)?n.objectAssignmentInitializer:e.isAssignmentExpression(n,!0)?n.right:e.isSpreadElement(n)?B(n.expression):void 0}function U(n){if(e.isDeclarationBindingElement(n))return n.name;if(!e.isObjectLiteralElementLike(n))return e.isAssignmentExpression(n,!0)?U(n.left):e.isSpreadElement(n)?U(n.expression):n;switch(n.kind){case 289:return U(n.initializer);case 290:return n.name;case 291:return U(n.expression)}}function V(e){switch(e.kind){case 161:case 199:return e.dotDotDotToken;case 221:case 291:return e}}function j(n){var t=K(n);return e.Debug.assert(!!t||e.isSpreadAssignment(n),"Invalid property name for binding element."),t}function K(n){switch(n.kind){case 199:if(n.propertyName){var t=n.propertyName;return e.isPrivateIdentifier(t)?e.Debug.failBadSyntaxKind(t):e.isComputedPropertyName(t)&&H(t.expression)?t.expression:t}break;case 289:if(n.name){t=n.name;return e.isPrivateIdentifier(t)?e.Debug.failBadSyntaxKind(t):e.isComputedPropertyName(t)&&H(t.expression)?t.expression:t}break;case 291:return n.name&&e.isPrivateIdentifier(n.name)?e.Debug.failBadSyntaxKind(n.name):n.name}var r=U(n);if(r&&e.isPropertyName(r))return r}function H(e){var n=e.kind;return 10===n||8===n}function W(e){switch(e.kind){case 197:case 198:case 200:return e.elements;case 201:return e.properties}}function z(n){if(n){var t=n;while(1){if(e.isIdentifier(t)||!t.body)return e.isIdentifier(t)?t:t.name;t=t.body}}}function q(e){var n=e.kind;return 161===n||163===n||164===n||165===n||166===n||167===n||168===n||169===n||172===n||209===n||210===n||222===n||233===n||252===n||253===n||254===n||255===n||256===n||257===n||261===n||262===n||267===n||268===n}function J(n){var t=n.kind;return 103===t||109===t||94===t||e.isLiteralExpression(n)||e.isPrefixUnaryExpression(n)}function X(e){return 42===e}function Y(e){return 41===e||43===e||44===e}function Q(e){return X(e)||Y(e)}function Z(e){return 39===e||40===e}function $(e){return Z(e)||Q(e)}function ee(e){return 47===e||48===e||49===e}function ne(e){return ee(e)||$(e)}function te(e){return 29===e||32===e||31===e||33===e||101===e||100===e}function re(e){return te(e)||ne(e)}function ae(e){return 34===e||36===e||35===e||37===e}function ie(e){return ae(e)||re(e)}function oe(e){return 50===e||51===e||52===e}function se(e){return oe(e)||ie(e)}function ce(e){return 55===e||56===e}function le(e){return ce(e)||se(e)}function ue(n){return 60===n||le(n)||e.isAssignmentOperator(n)}function de(e){return ue(e)||27===e}function pe(e){return de(e.kind)}var fe;e.createEmptyExports=n,e.createMemberAccessForPropertyName=t,e.createJsxFactoryExpression=o,e.createExpressionForJsxElement=c,e.createExpressionForJsxFragment=l,e.createForOfBindingStatement=u,e.insertLeadingStatement=d,e.createExpressionFromEntityName=p,e.createExpressionForPropertyName=f,e.createExpressionForObjectLiteralElementLike=h,e.isInternalName=v,e.isLocalName=b,e.isExportName=E,e.findUseStrictPrologue=S,e.startsWithUseStrict=x,e.isCommaSequence=L,e.isOuterExpression=D,e.skipOuterExpressions=A,e.skipAssertions=C,e.startOnNewLine=I,e.getExternalHelpersModuleName=N,e.hasRecordedExternalHelpers=k,e.createExternalHelpersImportDeclarationIfNeeded=R,e.getOrCreateExternalHelpersModuleNameIfNeeded=O,e.getLocalNameForExternalImport=w,e.getExternalModuleNameLiteral=P,e.tryGetModuleNameFromFile=F,e.getInitializerOfBindingOrAssignmentElement=B,e.getTargetOfBindingOrAssignmentElement=U,e.getRestIndicatorOfBindingOrAssignmentElement=V,e.getPropertyNameOfBindingOrAssignmentElement=j,e.tryGetPropertyNameOfBindingOrAssignmentElement=K,e.getElementsOfBindingOrAssignmentPattern=W,e.getJSDocTypeAliasName=z,e.canHaveModifiers=q,e.isTypeNodeOrTypeParameterDeclaration=e.or(e.isTypeNode,e.isTypeParameterDeclaration),e.isQuestionOrExclamationToken=e.or(e.isQuestionToken,e.isExclamationToken),e.isIdentifierOrThisTypeNode=e.or(e.isIdentifier,e.isThisTypeNode),e.isReadonlyKeywordOrPlusOrMinusToken=e.or(e.isReadonlyKeyword,e.isPlusToken,e.isMinusToken),e.isQuestionOrPlusOrMinusToken=e.or(e.isQuestionToken,e.isPlusToken,e.isMinusToken),e.isModuleName=e.or(e.isIdentifier,e.isStringLiteral),e.isLiteralTypeLikeExpression=J,e.isBinaryOperatorToken=pe,function(n){function t(n,r,a,i,o,s,l){var u=r>0?o[r-1]:void 0;return e.Debug.assertEqual(a[r],t),o[r]=n.onEnter(i[r],u,l),a[r]=c(n,t),r}function r(n,t,a,i,o,s,d){e.Debug.assertEqual(a[t],r),e.Debug.assertIsDefined(n.onLeft),a[t]=c(n,r);var p=n.onLeft(i[t].left,o[t],i[t]);return p?(u(t,i,p),l(t,a,i,o,p)):t}function a(n,t,r,i,o,s,l){return e.Debug.assertEqual(r[t],a),e.Debug.assertIsDefined(n.onOperator),r[t]=c(n,a),n.onOperator(i[t].operatorToken,o[t],i[t]),t}function i(n,t,r,a,o,s,d){e.Debug.assertEqual(r[t],i),e.Debug.assertIsDefined(n.onRight),r[t]=c(n,i);var p=n.onRight(a[t].right,o[t],a[t]);return p?(u(t,a,p),l(t,r,a,o,p)):t}function o(n,t,r,a,i,s,l){e.Debug.assertEqual(r[t],o),r[t]=c(n,o);var u=n.onExit(a[t],i[t]);if(t>0){if(t--,n.foldState){var d=r[t]===o?"right":"left";i[t]=n.foldState(i[t],u,d)}}else s.value=u;return t}function s(n,t,r,a,i,o,c){return e.Debug.assertEqual(r[t],s),t}function c(n,c){switch(c){case t:if(n.onLeft)return r;case r:if(n.onOperator)return a;case a:if(n.onRight)return i;case i:return o;case o:return s;case s:return s;default:e.Debug.fail("Invalid state")}}function l(e,n,r,a,i){return e++,n[e]=t,r[e]=i,a[e]=void 0,e}function u(n,t,r){if(e.Debug.shouldAssert(2))while(n>=0)e.Debug.assert(t[n]!==r,"Circular traversal detected."),n--}n.enter=t,n.left=r,n.operator=a,n.right=i,n.exit=o,n.done=s,n.nextState=c}(fe||(fe={}));var me=function(){function e(e,n,t,r,a,i){this.onEnter=e,this.onLeft=n,this.onOperator=t,this.onRight=r,this.onExit=a,this.foldState=i}return e}();function _e(n,t,r,a,i,o){var s=new me(n,t,r,a,i,o);return c;function c(n,t){var r={value:void 0},a=[fe.enter],i=[n],o=[void 0],c=0;while(a[c]!==fe.done)c=a[c](s,c,a,i,o,r,t);return e.Debug.assertEqual(c,0),r.value}}e.createBinaryExpressionTrampoline=_e}(d||(d={})),function(e){function n(n,t){return t?e.setTextRangePosEnd(n,t.pos,t.end):n}e.setTextRange=n}(d||(d={})),function(e){var n,t,r,a,i,o,s,c,l;function u(e,n){return n&&e(n)}function d(e,n,t){if(t){if(n)return n(t);for(var r=0,a=t;r<a.length;r++){var i=a[r],o=e(i);if(o)return o}}}function p(e,n){return 42===e.charCodeAt(n+1)&&42===e.charCodeAt(n+2)&&47!==e.charCodeAt(n+3)}function f(n,t,r){if(n&&!(n.kind<=157))switch(n.kind){case 158:return u(t,n.left)||u(t,n.right);case 160:return u(t,n.name)||u(t,n.constraint)||u(t,n.default)||u(t,n.expression);case 290:return d(t,r,n.decorators)||d(t,r,n.modifiers)||u(t,n.name)||u(t,n.questionToken)||u(t,n.exclamationToken)||u(t,n.equalsToken)||u(t,n.objectAssignmentInitializer);case 291:return u(t,n.expression);case 161:return d(t,r,n.decorators)||d(t,r,n.modifiers)||u(t,n.dotDotDotToken)||u(t,n.name)||u(t,n.questionToken)||u(t,n.type)||u(t,n.initializer);case 164:return d(t,r,n.decorators)||d(t,r,n.modifiers)||u(t,n.name)||u(t,n.questionToken)||u(t,n.exclamationToken)||u(t,n.type)||u(t,n.initializer);case 163:return d(t,r,n.decorators)||d(t,r,n.modifiers)||u(t,n.name)||u(t,n.questionToken)||u(t,n.type)||u(t,n.initializer);case 289:return d(t,r,n.decorators)||d(t,r,n.modifiers)||u(t,n.name)||u(t,n.questionToken)||u(t,n.initializer);case 250:return d(t,r,n.decorators)||d(t,r,n.modifiers)||u(t,n.name)||u(t,n.exclamationToken)||u(t,n.type)||u(t,n.initializer);case 199:return d(t,r,n.decorators)||d(t,r,n.modifiers)||u(t,n.dotDotDotToken)||u(t,n.propertyName)||u(t,n.name)||u(t,n.initializer);case 175:case 176:case 170:case 171:case 172:return d(t,r,n.decorators)||d(t,r,n.modifiers)||d(t,r,n.typeParameters)||d(t,r,n.parameters)||u(t,n.type);case 166:case 165:case 167:case 168:case 169:case 209:case 252:case 210:return d(t,r,n.decorators)||d(t,r,n.modifiers)||u(t,n.asteriskToken)||u(t,n.name)||u(t,n.questionToken)||u(t,n.exclamationToken)||d(t,r,n.typeParameters)||d(t,r,n.parameters)||u(t,n.type)||u(t,n.equalsGreaterThanToken)||u(t,n.body);case 174:return u(t,n.typeName)||d(t,r,n.typeArguments);case 173:return u(t,n.assertsModifier)||u(t,n.parameterName)||u(t,n.type);case 177:return u(t,n.exprName);case 178:return d(t,r,n.members);case 179:return u(t,n.elementType);case 180:return d(t,r,n.elements);case 183:case 184:return d(t,r,n.types);case 185:return u(t,n.checkType)||u(t,n.extendsType)||u(t,n.trueType)||u(t,n.falseType);case 186:return u(t,n.typeParameter);case 196:return u(t,n.argument)||u(t,n.qualifier)||d(t,r,n.typeArguments);case 187:case 189:return u(t,n.type);case 190:return u(t,n.objectType)||u(t,n.indexType);case 191:return u(t,n.readonlyToken)||u(t,n.typeParameter)||u(t,n.nameType)||u(t,n.questionToken)||u(t,n.type);case 192:return u(t,n.literal);case 193:return u(t,n.dotDotDotToken)||u(t,n.name)||u(t,n.questionToken)||u(t,n.type);case 197:case 198:return d(t,r,n.elements);case 200:return d(t,r,n.elements);case 201:return d(t,r,n.properties);case 202:return u(t,n.expression)||u(t,n.questionDotToken)||u(t,n.name);case 203:return u(t,n.expression)||u(t,n.questionDotToken)||u(t,n.argumentExpression);case 204:case 205:return u(t,n.expression)||u(t,n.questionDotToken)||d(t,r,n.typeArguments)||d(t,r,n.arguments);case 206:return u(t,n.tag)||u(t,n.questionDotToken)||d(t,r,n.typeArguments)||u(t,n.template);case 207:return u(t,n.type)||u(t,n.expression);case 208:return u(t,n.expression);case 211:return u(t,n.expression);case 212:return u(t,n.expression);case 213:return u(t,n.expression);case 215:return u(t,n.operand);case 220:return u(t,n.asteriskToken)||u(t,n.expression);case 214:return u(t,n.expression);case 216:return u(t,n.operand);case 217:return u(t,n.left)||u(t,n.operatorToken)||u(t,n.right);case 225:return u(t,n.expression)||u(t,n.type);case 226:return u(t,n.expression);case 227:return u(t,n.name);case 218:return u(t,n.condition)||u(t,n.questionToken)||u(t,n.whenTrue)||u(t,n.colonToken)||u(t,n.whenFalse);case 221:return u(t,n.expression);case 231:case 258:return d(t,r,n.statements);case 298:return d(t,r,n.statements)||u(t,n.endOfFileToken);case 233:return d(t,r,n.decorators)||d(t,r,n.modifiers)||u(t,n.declarationList);case 251:return d(t,r,n.declarations);case 234:return u(t,n.expression);case 235:return u(t,n.expression)||u(t,n.thenStatement)||u(t,n.elseStatement);case 236:return u(t,n.statement)||u(t,n.expression);case 237:return u(t,n.expression)||u(t,n.statement);case 238:return u(t,n.initializer)||u(t,n.condition)||u(t,n.incrementor)||u(t,n.statement);case 239:return u(t,n.initializer)||u(t,n.expression)||u(t,n.statement);case 240:return u(t,n.awaitModifier)||u(t,n.initializer)||u(t,n.expression)||u(t,n.statement);case 241:case 242:return u(t,n.label);case 243:return u(t,n.expression);case 244:return u(t,n.expression)||u(t,n.statement);case 245:return u(t,n.expression)||u(t,n.caseBlock);case 259:return d(t,r,n.clauses);case 285:return u(t,n.expression)||d(t,r,n.statements);case 286:return d(t,r,n.statements);case 246:return u(t,n.label)||u(t,n.statement);case 247:return u(t,n.expression);case 248:return u(t,n.tryBlock)||u(t,n.catchClause)||u(t,n.finallyBlock);case 288:return u(t,n.variableDeclaration)||u(t,n.block);case 162:return u(t,n.expression);case 253:case 222:return d(t,r,n.decorators)||d(t,r,n.modifiers)||u(t,n.name)||d(t,r,n.typeParameters)||d(t,r,n.heritageClauses)||d(t,r,n.members);case 254:return d(t,r,n.decorators)||d(t,r,n.modifiers)||u(t,n.name)||d(t,r,n.typeParameters)||d(t,r,n.heritageClauses)||d(t,r,n.members);case 255:return d(t,r,n.decorators)||d(t,r,n.modifiers)||u(t,n.name)||d(t,r,n.typeParameters)||u(t,n.type);case 256:return d(t,r,n.decorators)||d(t,r,n.modifiers)||u(t,n.name)||d(t,r,n.members);case 292:return u(t,n.name)||u(t,n.initializer);case 257:return d(t,r,n.decorators)||d(t,r,n.modifiers)||u(t,n.name)||u(t,n.body);case 261:return d(t,r,n.decorators)||d(t,r,n.modifiers)||u(t,n.name)||u(t,n.moduleReference);case 262:return d(t,r,n.decorators)||d(t,r,n.modifiers)||u(t,n.importClause)||u(t,n.moduleSpecifier);case 263:return u(t,n.name)||u(t,n.namedBindings);case 260:return u(t,n.name);case 264:return u(t,n.name);case 270:return u(t,n.name);case 265:case 269:return d(t,r,n.elements);case 268:return d(t,r,n.decorators)||d(t,r,n.modifiers)||u(t,n.exportClause)||u(t,n.moduleSpecifier);case 266:case 271:return u(t,n.propertyName)||u(t,n.name);case 267:return d(t,r,n.decorators)||d(t,r,n.modifiers)||u(t,n.expression);case 219:return u(t,n.head)||d(t,r,n.templateSpans);case 229:return u(t,n.expression)||u(t,n.literal);case 194:return u(t,n.head)||d(t,r,n.templateSpans);case 195:return u(t,n.type)||u(t,n.literal);case 159:return u(t,n.expression);case 287:return d(t,r,n.types);case 224:return u(t,n.expression)||d(t,r,n.typeArguments);case 273:return u(t,n.expression);case 272:return d(t,r,n.decorators);case 341:return d(t,r,n.elements);case 274:return u(t,n.openingElement)||d(t,r,n.children)||u(t,n.closingElement);case 278:return u(t,n.openingFragment)||d(t,r,n.children)||u(t,n.closingFragment);case 275:case 276:return u(t,n.tagName)||d(t,r,n.typeArguments)||u(t,n.attributes);case 282:return d(t,r,n.properties);case 281:return u(t,n.name)||u(t,n.initializer);case 283:return u(t,n.expression);case 284:return u(t,n.dotDotDotToken)||u(t,n.expression);case 277:return u(t,n.tagName);case 181:case 182:case 302:case 307:case 306:case 308:case 310:return u(t,n.type);case 309:return d(t,r,n.parameters)||u(t,n.type);case 312:return("string"===typeof n.comment?void 0:d(t,r,n.comment))||d(t,r,n.tags);case 336:return u(t,n.tagName)||u(t,n.name)||("string"===typeof n.comment?void 0:d(t,r,n.comment));case 303:return u(t,n.name);case 330:case 337:return u(t,n.tagName)||(n.isNameFirst?u(t,n.name)||u(t,n.typeExpression)||("string"===typeof n.comment?void 0:d(t,r,n.comment)):u(t,n.typeExpression)||u(t,n.name))||("string"===typeof n.comment?void 0:d(t,r,n.comment));case 320:return u(t,n.tagName)||("string"===typeof n.comment?void 0:d(t,r,n.comment));case 319:return u(t,n.tagName)||u(t,n.class)||("string"===typeof n.comment?void 0:d(t,r,n.comment));case 318:return u(t,n.tagName)||u(t,n.class)||("string"===typeof n.comment?void 0:d(t,r,n.comment));case 334:return u(t,n.tagName)||u(t,n.constraint)||d(t,r,n.typeParameters)||("string"===typeof n.comment?void 0:d(t,r,n.comment));case 335:return u(t,n.tagName)||(n.typeExpression&&302===n.typeExpression.kind?u(t,n.typeExpression)||u(t,n.fullName)||("string"===typeof n.comment?void 0:d(t,r,n.comment)):u(t,n.fullName)||u(t,n.typeExpression))||("string"===typeof n.comment?void 0:d(t,r,n.comment));case 328:return u(t,n.tagName)||u(t,n.fullName)||u(t,n.typeExpression)||("string"===typeof n.comment?void 0:d(t,r,n.comment));case 331:case 333:case 332:case 329:return u(t,n.tagName)||u(t,n.typeExpression)||("string"===typeof n.comment?void 0:d(t,r,n.comment));case 315:return e.forEach(n.typeParameters,t)||e.forEach(n.parameters,t)||u(t,n.type);case 316:return u(t,n.name);case 314:return e.forEach(n.jsDocPropertyTags,t);case 317:case 322:case 323:case 324:case 325:case 326:case 321:return u(t,n.tagName)||("string"===typeof n.comment?void 0:d(t,r,n.comment));case 340:return u(t,n.expression)}}function m(n,t,r){var a=_(n),i=[];while(i.length<a.length)i.push(n);while(0!==a.length){var o=a.pop(),s=i.pop();if(e.isArray(o)){if(r){var c=r(o,s);if(c){if("skip"===c)continue;return c}}for(var l=o.length-1;l>=0;--l)a.push(o[l]),i.push(s)}else{c=t(o,s);if(c){if("skip"===c)continue;return c}if(o.kind>=158)for(var u=0,d=_(o);u<d.length;u++){var p=d[u];a.push(p),i.push(o)}}}}function _(e){var n=[];return f(e,t,t),n;function t(e){n.unshift(e)}}function g(n,t,r,a,i){var o;return void 0===a&&(a=!1),null===e.tracing||void 0===e.tracing||e.tracing.push("parse","createSourceFile",{path:n},!0),e.performance.mark("beforeParse"),e.perfLogger.logStartParseSourceFile(n),o=100===r?c.parseSourceFile(n,t,r,void 0,a,6):c.parseSourceFile(n,t,r,void 0,a,i),e.perfLogger.logStopParseSourceFile(),e.performance.mark("afterParse"),e.performance.measure("Parse","beforeParse","afterParse"),null===e.tracing||void 0===e.tracing||e.tracing.pop(),o}function y(e,n){return c.parseIsolatedEntityName(e,n)}function h(e,n){return c.parseJsonText(e,n)}function v(e){return void 0!==e.externalModuleIndicator}function b(e,n,t,r){void 0===r&&(r=!1);var a=l.updateSourceFile(e,n,t,r);return a.flags|=3145728&e.flags,a}function E(e,n,t){var r=c.JSDocParser.parseIsolatedJSDocComment(e,n,t);return r&&r.jsDoc&&c.fixupParentReferences(r.jsDoc),r}function T(e,n,t){return c.JSDocParser.parseJSDocTypeExpressionForTests(e,n,t)}function S(n){return e.fileExtensionIs(n,".d.ts")}function x(n,t){for(var r=[],a=0,i=e.getLeadingCommentRanges(t,0)||e.emptyArray;a<i.length;a++){var o=i[a],s=t.substring(o.pos,o.end);N(r,o,s)}n.pragmas=new e.Map;for(var c=0,l=r;c<l.length;c++){var u=l[c];if(n.pragmas.has(u.name)){var d=n.pragmas.get(u.name);d instanceof Array?d.push(u.args):n.pragmas.set(u.name,[d,u.args])}else n.pragmas.set(u.name,u.args)}}function L(n,t){n.checkJsDirective=void 0,n.referencedFiles=[],n.typeReferenceDirectives=[],n.libReferenceDirectives=[],n.amdDependencies=[],n.hasNoDefaultLib=!1,n.pragmas.forEach((function(r,a){switch(a){case"reference":var i=n.referencedFiles,o=n.typeReferenceDirectives,s=n.libReferenceDirectives;e.forEach(e.toArray(r),(function(r){var a=r.arguments,c=a.types,l=a.lib,u=a.path;r.arguments["no-default-lib"]?n.hasNoDefaultLib=!0:c?o.push({pos:c.pos,end:c.end,fileName:c.value}):l?s.push({pos:l.pos,end:l.end,fileName:l.value}):u?i.push({pos:u.pos,end:u.end,fileName:u.value}):t(r.range.pos,r.range.end-r.range.pos,e.Diagnostics.Invalid_reference_directive_syntax)}));break;case"amd-dependency":n.amdDependencies=e.map(e.toArray(r),(function(e){return{name:e.arguments.name,path:e.arguments.path}}));break;case"amd-module":if(r instanceof Array)for(var c=0,l=r;c<l.length;c++){var u=l[c];n.moduleName&&t(u.range.pos,u.range.end-u.range.pos,e.Diagnostics.An_AMD_module_cannot_have_multiple_name_assignments),n.moduleName=u.arguments.name}else n.moduleName=r.arguments.name;break;case"ts-nocheck":case"ts-check":e.forEach(e.toArray(r),(function(e){(!n.checkJsDirective||e.range.pos>n.checkJsDirective.pos)&&(n.checkJsDirective={enabled:"ts-check"===a,end:e.range.end,pos:e.range.pos})}));break;case"jsx":case"jsxfrag":case"jsximportsource":case"jsxruntime":return;default:e.Debug.fail("Unhandled pragma kind")}}))}(function(e){e[e["None"]=0]="None",e[e["Yield"]=1]="Yield",e[e["Await"]=2]="Await",e[e["Type"]=4]="Type",e[e["IgnoreMissingOpenBrace"]=16]="IgnoreMissingOpenBrace",e[e["JSDoc"]=32]="JSDoc"})(n||(n={})),function(e){e[e["TryParse"]=0]="TryParse",e[e["Lookahead"]=1]="Lookahead",e[e["Reparse"]=2]="Reparse"}(t||(t={})),e.parseBaseNodeFactory={createBaseSourceFileNode:function(n){return new(s||(s=e.objectAllocator.getSourceFileConstructor()))(n,-1,-1)},createBaseIdentifierNode:function(n){return new(i||(i=e.objectAllocator.getIdentifierConstructor()))(n,-1,-1)},createBasePrivateIdentifierNode:function(n){return new(o||(o=e.objectAllocator.getPrivateIdentifierConstructor()))(n,-1,-1)},createBaseTokenNode:function(n){return new(a||(a=e.objectAllocator.getTokenConstructor()))(n,-1,-1)},createBaseNode:function(n){return new(r||(r=e.objectAllocator.getNodeConstructor()))(n,-1,-1)}},e.parseNodeFactory=e.createNodeFactory(1,e.parseBaseNodeFactory),e.isJSDocLikeText=p,e.forEachChild=f,e.forEachChildRecursively=m,e.createSourceFile=g,e.parseIsolatedEntityName=y,e.parseJsonText=h,e.isExternalModule=v,e.updateSourceFile=b,e.parseIsolatedJSDocComment=E,e.parseJSDocTypeExpressionForTests=T,function(n){var t,r,a,i,o,s=e.createScanner(99,!0),c=20480;function u(e){return A++,e}var d,m,_,g,y,h,b,E,T,D,A,C,I,N,k,R,w,P={createBaseSourceFileNode:function(e){return u(new o(e,0,0))},createBaseIdentifierNode:function(e){return u(new a(e,0,0))},createBasePrivateIdentifierNode:function(e){return u(new i(e,0,0))},createBaseTokenNode:function(e){return u(new r(e,0,0))},createBaseNode:function(e){return u(new t(e,0,0))}},M=e.createNodeFactory(11,P),F=!0,G=!1;function B(n,t,r,a,i,o){var s;if(void 0===i&&(i=!1),o=e.ensureScriptKind(n,o),6===o){var c=V(n,t,r,a,i);return e.convertToObjectWorker(c,null===(s=c.statements[0])||void 0===s?void 0:s.expression,c.parseDiagnostics,!1,void 0,void 0),c.referencedFiles=e.emptyArray,c.typeReferenceDirectives=e.emptyArray,c.libReferenceDirectives=e.emptyArray,c.amdDependencies=e.emptyArray,c.hasNoDefaultLib=!1,c.pragmas=e.emptyMap,c}j(n,t,r,a,o);var l=H(r,i,o);return K(),l}function U(e,n){j("",e,n,void 0,1),Ne();var t=tt(!0),r=1===Ae()&&!b.length;return K(),r?t:void 0}function V(n,t,r,a,i){void 0===r&&(r=2),void 0===i&&(i=!1),j(n,t,r,a,6),m=w,Ne();var o,s,c=Le();if(1===Ae())o=tn([],c,c),s=Ze();else{var l=void 0;while(1!==Ae()){var u=void 0;switch(Ae()){case 22:u=Za();break;case 109:case 94:case 103:u=Ze();break;case 40:u=Ve((function(){return 8===Ne()&&58!==Ne()}))?la():ei();break;case 8:case 10:if(Ve((function(){return 58!==Ne()}))){u=pt();break}default:u=ei();break}l&&e.isArray(l)?l.push(u):l?l=[l,u]:(l=u,1!==Ae()&&be(e.Diagnostics.Unexpected_token))}var d=e.isArray(l)?rn(M.createArrayLiteralExpression(l),c):e.Debug.checkDefined(l),p=M.createExpressionStatement(d);rn(p,c),o=tn([p],c),s=Ye(1,e.Diagnostics.Unexpected_token)}var f=$(n,2,6,!1,o,s,m);i&&Z(f),f.nodeCount=A,f.identifierCount=N,f.identifiers=C,f.parseDiagnostics=e.attachFileToDiagnostics(b,f),E&&(f.jsDocDiagnostics=e.attachFileToDiagnostics(E,f));var _=f;return K(),_}function j(n,c,l,u,p){switch(t=e.objectAllocator.getNodeConstructor(),r=e.objectAllocator.getTokenConstructor(),a=e.objectAllocator.getIdentifierConstructor(),i=e.objectAllocator.getPrivateIdentifierConstructor(),o=e.objectAllocator.getSourceFileConstructor(),d=e.normalizePath(n),_=c,g=l,T=u,y=p,h=e.getLanguageVariant(p),b=[],k=0,C=new e.Map,I=new e.Map,N=0,A=0,m=0,F=!0,y){case 1:case 2:w=131072;break;case 6:w=33685504;break;default:w=0;break}G=!1,s.setText(_),s.setOnError(xe),s.setScriptTarget(g),s.setLanguageVariant(h)}function K(){s.clearCommentDirectives(),s.setText(""),s.setOnError(void 0),_=void 0,g=void 0,T=void 0,y=void 0,h=void 0,m=0,b=void 0,E=void 0,k=0,C=void 0,R=void 0,F=!0}function H(n,t,r){var a=S(d);a&&(w|=8388608),m=w,Ne();var i=Mn(0,Oi);e.Debug.assert(1===Ae());var o=Y(Ze()),c=$(d,n,r,a,i,o,m);return x(c,_),L(c,l),c.commentDirectives=s.getCommentDirectives(),c.nodeCount=A,c.identifierCount=N,c.identifiers=C,c.parseDiagnostics=e.attachFileToDiagnostics(b,c),E&&(c.jsDocDiagnostics=e.attachFileToDiagnostics(E,c)),t&&Z(c),c;function l(n,t,r){b.push(e.createDetachedDiagnostic(d,n,t,r))}}function W(e,n){return n?Y(e):e}n.parseSourceFile=B,n.parseIsolatedEntityName=U,n.parseJsonText=V;var z,q,J,X=!1;function Y(n){e.Debug.assert(!n.jsDoc);var t=e.mapDefined(e.getJSDocCommentRanges(n,_),(function(e){return J.parseJSDocComment(n,e.pos,e.end-e.pos)}));return t.length&&(n.jsDoc=t),X&&(X=!1,n.flags|=134217728),n}function Q(n){var t=T,r=l.createSyntaxCursor(n);T={currentNode:g};var a=[],i=b;b=[];var o=0,c=m(n.statements,0),u=function(){var t=n.statements[o],r=n.statements[c];e.addRange(a,n.statements,o,c),o=_(n.statements,c);var l=e.findIndex(i,(function(e){return e.start>=t.pos})),u=l>=0?e.findIndex(i,(function(e){return e.start>=r.pos}),l):-1;l>=0&&e.addRange(b,i,l,u>=0?u:void 0),Ue((function(){var e=w;w|=32768,s.setTextPos(r.pos),Ne();while(1!==Ae()){var t=s.getStartPos(),i=Fn(0,Oi);if(a.push(i),t===s.getStartPos()&&Ne(),o>=0){var c=n.statements[o];if(i.end===c.pos)break;i.end>c.pos&&(o=_(n.statements,o+1))}}w=e}),2),c=o>=0?m(n.statements,o):-1};while(-1!==c)u();if(o>=0){var d=n.statements[o];e.addRange(a,n.statements,o);var p=e.findIndex(i,(function(e){return e.start>=d.pos}));p>=0&&e.addRange(b,i,p)}return T=t,M.updateSourceFile(n,e.setTextRange(M.createNodeArray(a),n.statements));function f(e){return!(32768&e.flags)&&!!(16777216&e.transformFlags)}function m(e,n){for(var t=n;t<e.length;t++)if(f(e[t]))return t;return-1}function _(e,n){for(var t=n;t<e.length;t++)if(!f(e[t]))return t;return-1}function g(e){var n=r.currentNode(e);return F&&n&&f(n)&&(n.intersectsChange=!0),n}}function Z(n){e.setParentRecursive(n,!0)}function $(n,t,r,a,i,o,s){var c=M.createSourceFile(i,o,s);return e.setTextRangePosWidth(c,0,_.length),Zo(c),!a&&v(c)&&16777216&c.transformFlags&&(c=Q(c)),c.text=_,c.bindDiagnostics=[],c.bindSuggestionDiagnostics=void 0,c.languageVersion=t,c.fileName=n,c.languageVariant=e.getLanguageVariant(r),c.isDeclarationFile=a,c.scriptKind=r,c}function ee(e,n){e?w|=n:w&=~n}function ne(e){ee(e,4096)}function te(e){ee(e,8192)}function re(e){ee(e,16384)}function ae(e){ee(e,32768)}function ie(e,n){var t=e&w;if(t){ee(!1,t);var r=n();return ee(!0,t),r}return n()}function oe(e,n){var t=e&~w;if(t){ee(!0,t);var r=n();return ee(!1,t),r}return n()}function se(e){return ie(4096,e)}function ce(e){return oe(4096,e)}function le(e){return oe(8192,e)}function ue(e){return oe(16384,e)}function de(e){return oe(32768,e)}function pe(e){return ie(32768,e)}function fe(e){return oe(40960,e)}function me(e){return ie(40960,e)}function _e(e){return 0!==(w&e)}function ge(){return _e(8192)}function ye(){return _e(4096)}function he(){return _e(16384)}function ve(){return _e(32768)}function be(e,n){Te(s.getTokenPos(),s.getTextPos(),e,n)}function Ee(n,t,r,a){var i=e.lastOrUndefined(b);i&&n===i.start||b.push(e.createDetachedDiagnostic(d,n,t,r,a)),G=!0}function Te(e,n,t,r){Ee(e,n-e,t,r)}function Se(e,n,t){Te(e.pos,e.end,n,t)}function xe(e,n){Ee(s.getTextPos(),n,e)}function Le(){return s.getStartPos()}function De(){return s.hasPrecedingJSDocComment()}function Ae(){return D}function Ce(){return D=s.scan()}function Ie(e){return Ne(),e()}function Ne(){return e.isKeyword(D)&&(s.hasUnicodeEscape()||s.hasExtendedUnicodeEscape())&&Te(s.getTokenPos(),s.getTextPos(),e.Diagnostics.Keywords_cannot_contain_escape_characters),Ce()}function ke(){return D=s.scanJsDocToken()}function Re(){return D=s.reScanGreaterToken()}function Oe(){return D=s.reScanSlashToken()}function we(e){return D=s.reScanTemplateToken(e)}function Pe(){return D=s.reScanTemplateHeadOrNoSubstitutionTemplate()}function Me(){return D=s.reScanLessThanToken()}function Fe(){return D=s.scanJsxIdentifier()}function Ge(){return D=s.scanJsxToken()}function Be(){return D=s.scanJsxAttributeValue()}function Ue(n,t){var r=D,a=b.length,i=G,o=w,c=0!==t?s.lookAhead(n):s.tryScan(n);return e.Debug.assert(o===w),c&&0===t||(D=r,2!==t&&(b.length=a),G=i),c}function Ve(e){return Ue(e,1)}function je(e){return Ue(e,0)}function Ke(){return 78===Ae()||Ae()>115}function He(){return 78===Ae()||(124!==Ae()||!ge())&&((130!==Ae()||!ve())&&Ae()>115)}function We(n,t,r){return void 0===r&&(r=!0),Ae()===n?(r&&Ne(),!0):(t?be(t):be(e.Diagnostics._0_expected,e.tokenToString(n)),!1)}function ze(n){return Ae()===n?(ke(),!0):(be(e.Diagnostics._0_expected,e.tokenToString(n)),!1)}function qe(e){return Ae()===e&&(Ne(),!0)}function Je(e){if(Ae()===e)return Ze()}function Xe(e){if(Ae()===e)return $e()}function Ye(n,t,r){return Je(n)||an(n,!1,t||e.Diagnostics._0_expected,r||e.tokenToString(n))}function Qe(n){return Xe(n)||an(n,!1,e.Diagnostics._0_expected,e.tokenToString(n))}function Ze(){var e=Le(),n=Ae();return Ne(),rn(M.createToken(n),e)}function $e(){var e=Le(),n=Ae();return ke(),rn(M.createToken(n),e)}function en(){return 26===Ae()||(19===Ae()||1===Ae()||s.hasPrecedingLineBreak())}function nn(){return en()?(26===Ae()&&Ne(),!0):We(26)}function tn(n,t,r,a){var i=M.createNodeArray(n,a);return e.setTextRangePosEnd(i,t,null!==r&&void 0!==r?r:s.getStartPos()),i}function rn(n,t,r){return e.setTextRangePosEnd(n,t,null!==r&&void 0!==r?r:s.getStartPos()),w&&(n.flags|=w),G&&(G=!1,n.flags|=65536),n}function an(n,t,r,a){t?Ee(s.getStartPos(),0,r,a):r&&be(r,a);var i=Le(),o=78===n?M.createIdentifier("",void 0,void 0):e.isTemplateLiteralKind(n)?M.createTemplateLiteralLikeNode(n,"","",void 0):8===n?M.createNumericLiteral("",void 0):10===n?M.createStringLiteral("",void 0):272===n?M.createMissingDeclaration():M.createToken(n);return rn(o,i)}function on(e){var n=C.get(e);return void 0===n&&C.set(e,n=e),n}function sn(n,t,r){if(n){N++;var a=Le(),i=Ae(),o=on(s.getTokenValue());return Ce(),rn(M.createIdentifier(o,void 0,i),a)}if(79===Ae())return be(r||e.Diagnostics.Private_identifiers_are_not_allowed_outside_class_bodies),sn(!0);if(0===Ae()&&s.tryScan((function(){return 78===s.reScanInvalidIdentifier()})))return sn(!0);N++;var c=1===Ae(),l=s.isReservedWord(),u=s.getTokenText(),d=l?e.Diagnostics.Identifier_expected_0_is_a_reserved_word_that_cannot_be_used_here:e.Diagnostics.Identifier_expected;return an(78,c,t||d,u)}function cn(e){return sn(Ke(),void 0,e)}function ln(e,n){return sn(He(),e,n)}function un(n){return sn(e.tokenIsIdentifierOrKeyword(Ae()),n)}function dn(){return e.tokenIsIdentifierOrKeyword(Ae())||10===Ae()||8===Ae()}function pn(e){if(10===Ae()||8===Ae()){var n=pt();return n.text=on(n.text),n}return e&&22===Ae()?mn():79===Ae()?gn():un()}function fn(){return pn(!0)}function mn(){var e=Le();We(22);var n=se(Vr);return We(23),rn(M.createComputedPropertyName(n),e)}function _n(e){var n=I.get(e);return void 0===n&&I.set(e,n=e),n}function gn(){var e=Le(),n=M.createPrivateIdentifier(_n(s.getTokenText()));return Ne(),rn(n,e)}function yn(e){return Ae()===e&&je(vn)}function hn(){return Ne(),!s.hasPrecedingLineBreak()&&Sn()}function vn(){switch(Ae()){case 84:return 91===Ne();case 92:return Ne(),87===Ae()?Ve(xn):149===Ae()?Ve(En):bn();case 87:return xn();case 123:return hn();case 134:case 146:return Ne(),Sn();default:return hn()}}function bn(){return 41!==Ae()&&126!==Ae()&&18!==Ae()&&Sn()}function En(){return Ne(),bn()}function Tn(){return e.isModifierKind(Ae())&&je(vn)}function Sn(){return 22===Ae()||18===Ae()||41===Ae()||25===Ae()||dn()}function xn(){return Ne(),83===Ae()||97===Ae()||117===Ae()||125===Ae()&&Ve(Li)||129===Ae()&&Ve(Di)}function Ln(n,t){var r=Gn(n);if(r)return!0;switch(n){case 0:case 1:case 3:return!(26===Ae()&&t)&&Ni();case 2:return 81===Ae()||87===Ae();case 4:return Ve(qt);case 5:return Ve(ao)||26===Ae()&&!t;case 6:return 22===Ae()||dn();case 12:switch(Ae()){case 22:case 41:case 25:case 24:return!0;default:return dn()}case 18:return dn();case 9:return 22===Ae()||25===Ae()||dn();case 7:return 18===Ae()?Ve(Dn):t?He()&&!Nn():Gr()&&!Nn();case 8:return Hi();case 10:return 27===Ae()||25===Ae()||Hi();case 19:return He();case 15:switch(Ae()){case 27:case 24:return!0}case 11:return 25===Ae()||Br();case 16:return Rt(!1);case 17:return Rt(!0);case 20:case 21:return 27===Ae()||yr();case 22:return To();case 23:return e.tokenIsIdentifierOrKeyword(Ae());case 13:return e.tokenIsIdentifierOrKeyword(Ae())||18===Ae();case 14:return!0}return e.Debug.fail("Non-exhaustive case in 'isListElement'.")}function Dn(){if(e.Debug.assert(18===Ae()),19===Ne()){var n=Ne();return 27===n||18===n||93===n||116===n}return!0}function An(){return Ne(),He()}function Cn(){return Ne(),e.tokenIsIdentifierOrKeyword(Ae())}function In(){return Ne(),e.tokenIsIdentifierOrKeywordOrGreaterThan(Ae())}function Nn(){return(116===Ae()||93===Ae())&&Ve(kn)}function kn(){return Ne(),Br()}function Rn(){return Ne(),yr()}function On(e){if(1===Ae())return!0;switch(e){case 1:case 2:case 4:case 5:case 6:case 12:case 9:case 23:return 19===Ae();case 3:return 19===Ae()||81===Ae()||87===Ae();case 7:return 18===Ae()||93===Ae()||116===Ae();case 8:return wn();case 19:return 31===Ae()||20===Ae()||18===Ae()||93===Ae()||116===Ae();case 11:return 21===Ae()||26===Ae();case 15:case 21:case 10:return 23===Ae();case 17:case 16:case 18:return 21===Ae()||23===Ae();case 20:return 27!==Ae();case 22:return 18===Ae()||19===Ae();case 13:return 31===Ae()||43===Ae();case 14:return 29===Ae()&&Ve(wo);default:return!1}}function wn(){return!!en()||(!!aa(Ae())||38===Ae())}function Pn(){for(var e=0;e<24;e++)if(k&1<<e&&(Ln(e,!0)||On(e)))return!0;return!1}function Mn(e,n){var t=k;k|=1<<e;var r=[],a=Le();while(!On(e))if(Ln(e,!1))r.push(Fn(e,n));else if(Xn(e))break;return k=t,tn(r,a)}function Fn(e,n){var t=Gn(e);return t?Bn(t):n()}function Gn(n){if(T&&Un(n)&&!G){var t=T.currentNode(s.getStartPos());if(!(e.nodeIsMissing(t)||t.intersectsChange||e.containsParseError(t))){var r=25358336&t.flags;if(r===w&&Vn(t,n))return t.jsDocCache&&(t.jsDocCache=void 0),t}}}function Bn(e){return s.setTextPos(e.end),Ne(),e}function Un(e){switch(e){case 5:case 2:case 0:case 1:case 3:case 6:case 4:case 8:case 17:case 16:return!0}return!1}function Vn(e,n){switch(n){case 5:return jn(e);case 2:return Kn(e);case 0:case 1:case 3:return Hn(e);case 6:return Wn(e);case 4:return zn(e);case 8:return qn(e);case 17:case 16:return Jn(e)}return!1}function jn(e){if(e)switch(e.kind){case 167:case 172:case 168:case 169:case 164:case 230:return!0;case 166:var n=e,t=78===n.name.kind&&132===n.name.originalKeywordKind;return!t}return!1}function Kn(e){if(e)switch(e.kind){case 285:case 286:return!0}return!1}function Hn(e){if(e)switch(e.kind){case 252:case 233:case 231:case 235:case 234:case 247:case 243:case 245:case 242:case 241:case 239:case 240:case 238:case 237:case 244:case 232:case 248:case 246:case 236:case 249:case 262:case 261:case 268:case 267:case 257:case 253:case 254:case 256:case 255:return!0}return!1}function Wn(e){return 292===e.kind}function zn(e){if(e)switch(e.kind){case 171:case 165:case 172:case 163:case 170:return!0}return!1}function qn(e){if(250!==e.kind)return!1;var n=e;return void 0===n.initializer}function Jn(e){if(161!==e.kind)return!1;var n=e;return void 0===n.initializer}function Xn(e){return Yn(e),!!Pn()||(Ne(),!1)}function Yn(n){switch(n){case 0:return be(e.Diagnostics.Declaration_or_statement_expected);case 1:return be(e.Diagnostics.Declaration_or_statement_expected);case 2:return be(e.Diagnostics.case_or_default_expected);case 3:return be(e.Diagnostics.Statement_expected);case 18:case 4:return be(e.Diagnostics.Property_or_signature_expected);case 5:return be(e.Diagnostics.Unexpected_token_A_constructor_method_accessor_or_property_was_expected);case 6:return be(e.Diagnostics.Enum_member_expected);case 7:return be(e.Diagnostics.Expression_expected);case 8:return e.isKeyword(Ae())?be(e.Diagnostics._0_is_not_allowed_as_a_variable_declaration_name,e.tokenToString(Ae())):be(e.Diagnostics.Variable_declaration_expected);case 9:return be(e.Diagnostics.Property_destructuring_pattern_expected);case 10:return be(e.Diagnostics.Array_element_destructuring_pattern_expected);case 11:return be(e.Diagnostics.Argument_expression_expected);case 12:return be(e.Diagnostics.Property_assignment_expected);case 15:return be(e.Diagnostics.Expression_or_comma_expected);case 17:return be(e.Diagnostics.Parameter_declaration_expected);case 16:return be(e.Diagnostics.Parameter_declaration_expected);case 19:return be(e.Diagnostics.Type_parameter_declaration_expected);case 20:return be(e.Diagnostics.Type_argument_expected);case 21:return be(e.Diagnostics.Type_expected);case 22:return be(e.Diagnostics.Unexpected_token_expected);case 23:return be(e.Diagnostics.Identifier_expected);case 13:return be(e.Diagnostics.Identifier_expected);case 14:return be(e.Diagnostics.Identifier_expected);default:return[void 0]}}function Qn(e,n,t){var r=k;k|=1<<e;var a=[],i=Le(),o=-1;while(1)if(Ln(e,!1)){var c=s.getStartPos();if(a.push(Fn(e,n)),o=s.getTokenPos(),qe(27))continue;if(o=-1,On(e))break;We(27,Zn(e)),t&&26===Ae()&&!s.hasPrecedingLineBreak()&&Ne(),c===s.getStartPos()&&Ne()}else{if(On(e))break;if(Xn(e))break}return k=r,tn(a,i,void 0,o>=0)}function Zn(n){return 6===n?e.Diagnostics.An_enum_member_name_must_be_followed_by_a_or:void 0}function $n(){var e=tn([],Le());return e.isMissingList=!0,e}function et(e){return!!e.isMissingList}function nt(e,n,t,r){if(We(t)){var a=Qn(e,n);return We(r),a}return $n()}function tt(e,n){var t=Le(),r=e?un(n):ln(n),a=Le();while(qe(24)){if(29===Ae()){r.jsdocDotPos=a;break}a=Le(),r=rn(M.createQualifiedName(r,at(e,!1)),t)}return r}function rt(e,n){return rn(M.createQualifiedName(e,n),e.pos)}function at(n,t){if(s.hasPrecedingLineBreak()&&e.tokenIsIdentifierOrKeyword(Ae())){var r=Ve(xi);if(r)return an(78,!0,e.Diagnostics.Identifier_expected)}if(79===Ae()){var a=gn();return t?a:an(78,!0,e.Diagnostics.Identifier_expected)}return n?un():ln()}function it(e){var n,t=Le(),r=[];do{n=dt(e),r.push(n)}while(16===n.literal.kind);return tn(r,t)}function ot(e){var n=Le();return rn(M.createTemplateExpression(ft(e),it(e)),n)}function st(){var e=Le();return rn(M.createTemplateLiteralType(ft(!1),ct()),e)}function ct(){var e,n=Le(),t=[];do{e=lt(),t.push(e)}while(16===e.literal.kind);return tn(t,n)}function lt(){var e=Le();return rn(M.createTemplateLiteralTypeSpan(Pr(),ut(!1)),e)}function ut(n){return 19===Ae()?(we(n),mt()):Ye(17,e.Diagnostics._0_expected,e.tokenToString(19))}function dt(e){var n=Le();return rn(M.createTemplateSpan(se(Vr),ut(e)),n)}function pt(){return gt(Ae())}function ft(n){n&&Pe();var t=gt(Ae());return e.Debug.assert(15===t.kind,"Template head has wrong token kind"),t}function mt(){var n=gt(Ae());return e.Debug.assert(16===n.kind||17===n.kind,"Template fragment has wrong token kind"),n}function _t(e){var n=14===e||17===e,t=s.getTokenText();return t.substring(1,t.length-(s.isUnterminated()?0:n?1:2))}function gt(n){var t=Le(),r=e.isTemplateLiteralKind(n)?M.createTemplateLiteralLikeNode(n,s.getTokenValue(),_t(n),2048&s.getTokenFlags()):8===n?M.createNumericLiteral(s.getTokenValue(),s.getNumericLiteralFlags()):10===n?M.createStringLiteral(s.getTokenValue(),void 0,s.hasExtendedUnicodeEscape()):e.isLiteralKind(n)?M.createLiteralLikeNode(n,s.getTokenValue()):e.Debug.fail();return s.hasExtendedUnicodeEscape()&&(r.hasExtendedUnicodeEscape=!0),s.isUnterminated()&&(r.isUnterminated=!0),Ne(),rn(r,t)}function yt(){return tt(!0,e.Diagnostics.Type_expected)}function ht(){if(!s.hasPrecedingLineBreak()&&29===Me())return nt(20,Pr,29,31)}function vt(){var e=Le();return rn(M.createTypeReferenceNode(yt(),ht()),e)}function bt(n){switch(n.kind){case 174:return e.nodeIsMissing(n.typeName);case 175:case 176:var t=n,r=t.parameters,a=t.type;return et(r)||bt(a);case 187:return bt(n.type);default:return!1}}function Et(e){return Ne(),rn(M.createTypePredicateNode(void 0,e,Pr()),e.pos)}function Tt(){var e=Le();return Ne(),rn(M.createThisTypeNode(),e)}function St(){var e=Le();return Ne(),rn(M.createJSDocAllType(),e)}function xt(){var e=Le();return Ne(),rn(M.createJSDocNonNullableType(gr()),e)}function Lt(){var e=Le();return Ne(),27===Ae()||19===Ae()||21===Ae()||31===Ae()||62===Ae()||51===Ae()?rn(M.createJSDocUnknownType(),e):rn(M.createJSDocNullableType(Pr()),e)}function Dt(){var e=Le(),n=De();if(Ve(Oo)){Ne();var t=Ut(36),r=Ft(58,!1);return W(rn(M.createJSDocFunctionType(t,r),e),n)}return rn(M.createTypeReferenceNode(un(),void 0),e)}function At(){var e,n=Le();return 107!==Ae()&&102!==Ae()||(e=un(),We(58)),rn(M.createParameterDeclaration(void 0,void 0,void 0,e,void 0,Ct(),void 0),n)}function Ct(){s.setInJSDocType(!0);var e=Le();if(qe(139)){var n=M.createJSDocNamepathType(void 0);e:while(1)switch(Ae()){case 19:case 1:case 27:case 5:break e;default:ke()}return s.setInJSDocType(!1),rn(n,e)}var t=qe(25),r=Rr();return s.setInJSDocType(!1),t&&(r=rn(M.createJSDocVariadicType(r),e)),62===Ae()?(Ne(),rn(M.createJSDocOptionalType(r),e)):r}function It(){var e=Le();return We(111),rn(M.createTypeQueryNode(tt(!0)),e)}function Nt(){var e,n,t=Le(),r=ln();qe(93)&&(yr()||!Br()?e=Pr():n=_a());var a=qe(62)?Pr():void 0,i=M.createTypeParameterDeclaration(r,e,a);return i.expression=n,rn(i,t)}function kt(){if(29===Ae())return nt(19,Nt,29,31)}function Rt(n){return 25===Ae()||Hi()||e.isModifierKind(Ae())||59===Ae()||yr(!n)}function Ot(n){var t=Wi(e.Diagnostics.Private_identifiers_cannot_be_used_as_parameters);return 0===e.getFullWidth(t)&&!e.some(n)&&e.isModifierKind(Ae())&&Ne(),t}function wt(){return Mt(!0)}function Pt(){return Mt(!1)}function Mt(n){var t=Le(),r=De(),a=n?de(so):so();if(107===Ae()){var i=M.createParameterDeclaration(a,void 0,void 0,sn(!0),void 0,Fr(),void 0);return a&&Se(a[0],e.Diagnostics.Decorators_may_not_be_applied_to_this_parameters),W(rn(i,t),r)}var o=F;F=!1;var s=lo(),c=W(rn(M.createParameterDeclaration(a,s,Je(25),Ot(s),Je(57),Fr(),jr()),t),r);return F=o,c}function Ft(e,n){if(Gt(e,n))return Rr()}function Gt(n,t){return 38===n?(We(n),!0):!!qe(58)||!(!t||38!==Ae())&&(be(e.Diagnostics._0_expected,e.tokenToString(58)),Ne(),!0)}function Bt(e){var n=ge(),t=ve();te(!!(1&e)),ae(!!(2&e));var r=32&e?Qn(17,At):Qn(16,t?wt:Pt);return te(n),ae(t),r}function Ut(e){if(!We(20))return $n();var n=Bt(e);return We(21),n}function Vt(){qe(27)||nn()}function jt(e){var n=Le(),t=De();171===e&&We(102);var r=kt(),a=Ut(4),i=Ft(58,!0);Vt();var o=170===e?M.createCallSignature(r,a,i):M.createConstructSignature(r,a,i);return W(rn(o,n),t)}function Kt(){return 22===Ae()&&Ve(Ht)}function Ht(){if(Ne(),25===Ae()||23===Ae())return!0;if(e.isModifierKind(Ae())){if(Ne(),He())return!0}else{if(!He())return!1;Ne()}return 58===Ae()||27===Ae()||57===Ae()&&(Ne(),58===Ae()||27===Ae()||23===Ae())}function Wt(e,n,t,r){var a=nt(16,Pt,22,23),i=Fr();Vt();var o=M.createIndexSignature(t,r,a,i);return W(rn(o,e),n)}function zt(e,n,t){var r,a=fn(),i=Je(57);if(20===Ae()||29===Ae()){var o=kt(),s=Ut(4),c=Ft(58,!0);r=M.createMethodSignature(t,a,i,o,s,c)}else{c=Fr();r=M.createPropertySignature(t,a,i,c),62===Ae()&&(r.initializer=jr())}return Vt(),W(rn(r,e),n)}function qt(){if(20===Ae()||29===Ae()||134===Ae()||146===Ae())return!0;var n=!1;while(e.isModifierKind(Ae()))n=!0,Ne();return 22===Ae()||(dn()&&(n=!0,Ne()),!!n&&(20===Ae()||29===Ae()||57===Ae()||58===Ae()||27===Ae()||en()))}function Jt(){if(20===Ae()||29===Ae())return jt(170);if(102===Ae()&&Ve(Xt))return jt(171);var e=Le(),n=De(),t=lo();return yn(134)?ro(e,n,void 0,t,168):yn(146)?ro(e,n,void 0,t,169):Kt()?Wt(e,n,void 0,t):zt(e,n,t)}function Xt(){return Ne(),20===Ae()||29===Ae()}function Yt(){return 24===Ne()}function Qt(){switch(Ne()){case 20:case 29:case 24:return!0}return!1}function Zt(){var e=Le();return rn(M.createTypeLiteralNode($t()),e)}function $t(){var e;return We(18)?(e=Mn(4,Jt),We(19)):e=$n(),e}function er(){return Ne(),39===Ae()||40===Ae()?142===Ne():(142===Ae()&&Ne(),22===Ae()&&An()&&100===Ne())}function nr(){var e=Le(),n=un();We(100);var t=Pr();return rn(M.createTypeParameterDeclaration(n,t,void 0),e)}function tr(){var e,n=Le();We(18),142!==Ae()&&39!==Ae()&&40!==Ae()||(e=Ze(),142!==e.kind&&We(142)),We(22);var t,r=nr(),a=qe(126)?Pr():void 0;We(23),57!==Ae()&&39!==Ae()&&40!==Ae()||(t=Ze(),57!==t.kind&&We(57));var i=Fr();return nn(),We(19),rn(M.createMappedTypeNode(e,r,a,t,i),n)}function rr(){var n=Le();if(qe(25))return rn(M.createRestTypeNode(Pr()),n);var t=Pr();if(e.isJSDocNullableType(t)&&t.pos===t.type.pos){var r=M.createOptionalTypeNode(t.type);return e.setTextRange(r,t),r.flags=t.flags,r}return t}function ar(){return 58===Ne()||57===Ae()&&58===Ne()}function ir(){return 25===Ae()?e.tokenIsIdentifierOrKeyword(Ne())&&ar():e.tokenIsIdentifierOrKeyword(Ae())&&ar()}function or(){if(Ve(ir)){var e=Le(),n=De(),t=Je(25),r=un(),a=Je(57);We(58);var i=rr(),o=M.createNamedTupleMember(t,r,a,i);return W(rn(o,e),n)}return rr()}function sr(){var e=Le();return rn(M.createTupleTypeNode(nt(21,or,22,23)),e)}function cr(){var e=Le();We(20);var n=Pr();return We(21),rn(M.createParenthesizedType(n),e)}function lr(){var e;if(125===Ae()){var n=Le();Ne();var t=rn(M.createToken(125),n);e=tn([t],n)}return e}function ur(){var e=Le(),n=De(),t=lr(),r=qe(102),a=kt(),i=Ut(4),o=Ft(38,!1),s=r?M.createConstructorTypeNode(t,a,i,o):M.createFunctionTypeNode(a,i,o);return r||(s.modifiers=t),W(rn(s,e),n)}function dr(){var e=Ze();return 24===Ae()?void 0:e}function pr(e){var n=Le();e&&Ne();var t=109===Ae()||94===Ae()||103===Ae()?Ze():gt(Ae());return e&&(t=rn(M.createPrefixUnaryExpression(40,t),n)),rn(M.createLiteralTypeNode(t),n)}function fr(){return Ne(),99===Ae()}function mr(){m|=1048576;var e=Le(),n=qe(111);We(99),We(20);var t=Pr();We(21);var r=qe(24)?yt():void 0,a=ht();return rn(M.createImportTypeNode(t,r,a,n),e)}function _r(){return Ne(),8===Ae()||9===Ae()}function gr(){switch(Ae()){case 128:case 152:case 147:case 144:case 155:case 148:case 131:case 150:case 141:case 145:return je(dr)||vt();case 65:s.reScanAsteriskEqualsToken();case 41:return St();case 60:s.reScanQuestionToken();case 57:return Lt();case 97:return Dt();case 53:return xt();case 14:case 10:case 8:case 9:case 109:case 94:case 103:return pr();case 40:return Ve(_r)?pr(!0):vt();case 113:return Ze();case 107:var e=Tt();return 137!==Ae()||s.hasPrecedingLineBreak()?e:Et(e);case 111:return Ve(fr)?mr():It();case 18:return Ve(er)?tr():Zt();case 22:return sr();case 20:return cr();case 99:return mr();case 127:return Ve(xi)?wr():vt();case 15:return st();default:return vt()}}function yr(e){switch(Ae()){case 128:case 152:case 147:case 144:case 155:case 131:case 142:case 148:case 151:case 113:case 150:case 103:case 107:case 111:case 141:case 18:case 22:case 29:case 51:case 50:case 102:case 10:case 8:case 9:case 109:case 94:case 145:case 41:case 57:case 53:case 25:case 135:case 99:case 127:case 14:case 15:return!0;case 97:return!e;case 40:return!e&&Ve(_r);case 20:return!e&&Ve(hr);default:return He()}}function hr(){return Ne(),21===Ae()||Rt(!1)||yr()}function vr(){var e=Le(),n=gr();while(!s.hasPrecedingLineBreak())switch(Ae()){case 53:Ne(),n=rn(M.createJSDocNonNullableType(n),e);break;case 57:if(Ve(Rn))return n;Ne(),n=rn(M.createJSDocNullableType(n),e);break;case 22:if(We(22),yr()){var t=Pr();We(23),n=rn(M.createIndexedAccessTypeNode(n,t),e)}else We(23),n=rn(M.createArrayTypeNode(n),e);break;default:return n}return n}function br(e){var n=Le();return We(e),rn(M.createTypeOperatorNode(e,Sr()),n)}function Er(){var e=Le();return rn(M.createTypeParameterDeclaration(ln(),void 0,void 0),e)}function Tr(){var e=Le();return We(135),rn(M.createInferTypeNode(Er()),e)}function Sr(){var e=Ae();switch(e){case 138:case 151:case 142:return br(e);case 135:return Tr()}return vr()}function xr(n){if(Ir()){var t=ur(),r=void 0;return r=e.isFunctionTypeNode(t)?n?e.Diagnostics.Function_type_notation_must_be_parenthesized_when_used_in_a_union_type:e.Diagnostics.Function_type_notation_must_be_parenthesized_when_used_in_an_intersection_type:n?e.Diagnostics.Constructor_type_notation_must_be_parenthesized_when_used_in_a_union_type:e.Diagnostics.Constructor_type_notation_must_be_parenthesized_when_used_in_an_intersection_type,Se(t,r),t}}function Lr(e,n,t){var r=Le(),a=51===e,i=qe(e),o=i&&xr(a)||n();if(Ae()===e||i){var s=[o];while(qe(e))s.push(xr(a)||n());o=rn(t(tn(s,r)),r)}return o}function Dr(){return Lr(50,Sr,M.createIntersectionTypeNode)}function Ar(){return Lr(51,Dr,M.createUnionTypeNode)}function Cr(){return Ne(),102===Ae()}function Ir(){return 29===Ae()||(!(20!==Ae()||!Ve(kr))||(102===Ae()||125===Ae()&&Ve(Cr)))}function Nr(){if(e.isModifierKind(Ae())&&lo(),He()||107===Ae())return Ne(),!0;if(22===Ae()||18===Ae()){var n=b.length;return Wi(),n===b.length}return!1}function kr(){if(Ne(),21===Ae()||25===Ae())return!0;if(Nr()){if(58===Ae()||27===Ae()||57===Ae()||62===Ae())return!0;if(21===Ae()&&(Ne(),38===Ae()))return!0}return!1}function Rr(){var e=Le(),n=He()&&je(Or),t=Pr();return n?rn(M.createTypePredicateNode(void 0,n,t),e):t}function Or(){var e=ln();if(137===Ae()&&!s.hasPrecedingLineBreak())return Ne(),e}function wr(){var e=Le(),n=Ye(127),t=107===Ae()?Tt():ln(),r=qe(137)?Pr():void 0;return rn(M.createTypePredicateNode(n,t,r),e)}function Pr(){return ie(40960,Mr)}function Mr(e){if(Ir())return ur();var n=Le(),t=Ar();if(!e&&!s.hasPrecedingLineBreak()&&qe(93)){var r=Mr(!0);We(57);var a=Mr();We(58);var i=Mr();return rn(M.createConditionalTypeNode(t,r,a,i),n)}return t}function Fr(){return qe(58)?Pr():void 0}function Gr(){switch(Ae()){case 107:case 105:case 103:case 109:case 94:case 8:case 9:case 10:case 14:case 15:case 20:case 22:case 18:case 97:case 83:case 102:case 43:case 67:case 78:return!0;case 99:return Ve(Qt);default:return He()}}function Br(){if(Gr())return!0;switch(Ae()){case 39:case 40:case 54:case 53:case 88:case 111:case 113:case 45:case 46:case 29:case 130:case 124:case 79:return!0;default:return!!oa()||He()}}function Ur(){return 18!==Ae()&&97!==Ae()&&83!==Ae()&&59!==Ae()&&Br()}function Vr(){var e=he();e&&re(!1);var n,t=Le(),r=Kr();while(n=Je(27))r=sa(r,n,Kr(),t);return e&&re(!0),r}function jr(){return qe(62)?Kr():void 0}function Kr(){if(Hr())return zr();var n=Jr()||Zr();if(n)return n;var t=Le(),r=ra(0);return 78===r.kind&&38===Ae()?qr(t,r,void 0):e.isLeftHandSideExpression(r)&&e.isAssignmentOperator(Re())?sa(r,Ze(),Kr(),t):ta(r,t)}function Hr(){return 124===Ae()&&(!!ge()||Ve(Ai))}function Wr(){return Ne(),!s.hasPrecedingLineBreak()&&He()}function zr(){var e=Le();return Ne(),s.hasPrecedingLineBreak()||41!==Ae()&&!Br()?rn(M.createYieldExpression(void 0,void 0),e):rn(M.createYieldExpression(Je(41),Kr()),e)}function qr(n,t,r){e.Debug.assert(38===Ae(),"parseSimpleArrowFunctionExpression should only have been called if we had a =>");var a=M.createParameterDeclaration(void 0,void 0,void 0,t,void 0,void 0,void 0);rn(a,t.pos);var i=tn([a],a.pos,a.end),o=Ye(38),s=na(!!r),c=M.createArrowFunction(r,void 0,i,void 0,o,s);return Y(rn(c,n))}function Jr(){var e=Xr();if(0!==e)return 1===e?ea(!0):je(Qr)}function Xr(){return 20===Ae()||29===Ae()||129===Ae()?Ve(Yr):38===Ae()?1:0}function Yr(){if(129===Ae()){if(Ne(),s.hasPrecedingLineBreak())return 0;if(20!==Ae()&&29!==Ae())return 0}var n=Ae(),t=Ne();if(20===n){if(21===t){var r=Ne();switch(r){case 38:case 58:case 18:return 1;default:return 0}}if(22===t||18===t)return 2;if(25===t)return 1;if(e.isModifierKind(t)&&129!==t&&Ve(An))return 1;if(!He()&&107!==t)return 0;switch(Ne()){case 58:return 1;case 57:return Ne(),58===Ae()||27===Ae()||62===Ae()||21===Ae()?1:0;case 27:case 62:case 21:return 2}return 0}if(e.Debug.assert(29===n),!He())return 0;if(1===h){var a=Ve((function(){var e=Ne();if(93===e){var n=Ne();switch(n){case 62:case 31:return!1;default:return!0}}else if(27===e)return!0;return!1}));return a?1:0}return 2}function Qr(){var n=s.getTokenPos();if(!(null===R||void 0===R?void 0:R.has(n))){var t=ea(!1);return t||(R||(R=new e.Set)).add(n),t}}function Zr(){if(129===Ae()&&1===Ve($r)){var e=Le(),n=uo(),t=ra(0);return qr(e,t,n)}}function $r(){if(129===Ae()){if(Ne(),s.hasPrecedingLineBreak()||38===Ae())return 0;var e=ra(0);if(!s.hasPrecedingLineBreak()&&78===e.kind&&38===Ae())return 1}return 0}function ea(n){var t,r=Le(),a=De(),i=uo(),o=e.some(i,e.isAsyncModifier)?2:0,s=kt();if(We(20)){if(t=Bt(o),!We(21)&&!n)return}else{if(!n)return;t=$n()}var c=Ft(58,!1);if(!c||n||!bt(c)){var l=c&&e.isJSDocFunctionType(c);if(n||38===Ae()||!l&&18===Ae()){var u=Ae(),d=Ye(38),p=38===u||18===u?na(e.some(i,e.isAsyncModifier)):ln(),f=M.createArrowFunction(i,s,t,c,d,p);return W(rn(f,r),a)}}}function na(e){if(18===Ae())return ii(e?2:0);if(26!==Ae()&&97!==Ae()&&83!==Ae()&&Ni()&&!Ur())return ii(16|(e?2:0));var n=F;F=!1;var t=e?de(Kr):pe(Kr);return F=n,t}function ta(n,t){var r,a=Je(57);return a?rn(M.createConditionalExpression(n,a,ie(c,Kr),r=Ye(58),e.nodeIsPresent(r)?Kr():an(78,!1,e.Diagnostics._0_expected,e.tokenToString(58))),t):n}function ra(e){var n=Le(),t=_a();return ia(e,t,n)}function aa(e){return 100===e||157===e}function ia(n,t,r){while(1){Re();var a=e.getBinaryOperatorPrecedence(Ae()),i=42===Ae()?a>=n:a>n;if(!i)break;if(100===Ae()&&ye())break;if(126===Ae()){if(s.hasPrecedingLineBreak())break;Ne(),t=ca(t,Pr())}else t=sa(t,Ze(),ra(a),r)}return t}function oa(){return(!ye()||100!==Ae())&&e.getBinaryOperatorPrecedence(Ae())>0}function sa(e,n,t,r){return rn(M.createBinaryExpression(e,n,t),r)}function ca(e,n){return rn(M.createAsExpression(e,n),e.pos)}function la(){var e=Le();return rn(M.createPrefixUnaryExpression(Ae(),Ie(ga)),e)}function ua(){var e=Le();return rn(M.createDeleteExpression(Ie(ga)),e)}function da(){var e=Le();return rn(M.createTypeOfExpression(Ie(ga)),e)}function pa(){var e=Le();return rn(M.createVoidExpression(Ie(ga)),e)}function fa(){return 130===Ae()&&(!!ve()||Ve(Ai))}function ma(){var e=Le();return rn(M.createAwaitExpression(Ie(ga)),e)}function _a(){if(ya()){var n=Le(),t=ha();return 42===Ae()?ia(e.getBinaryOperatorPrecedence(Ae()),t,n):t}var r=Ae(),a=ga();if(42===Ae()){n=e.skipTrivia(_,a.pos);var i=a.end;207===a.kind?Te(n,i,e.Diagnostics.A_type_assertion_expression_is_not_allowed_in_the_left_hand_side_of_an_exponentiation_expression_Consider_enclosing_the_expression_in_parentheses):Te(n,i,e.Diagnostics.An_unary_expression_with_the_0_operator_is_not_allowed_in_the_left_hand_side_of_an_exponentiation_expression_Consider_enclosing_the_expression_in_parentheses,e.tokenToString(r))}return a}function ga(){switch(Ae()){case 39:case 40:case 54:case 53:return la();case 88:return ua();case 111:return da();case 113:return pa();case 29:return wa();case 130:if(fa())return ma();default:return ha()}}function ya(){switch(Ae()){case 39:case 40:case 54:case 53:case 88:case 111:case 113:case 130:return!1;case 29:if(1!==h)return!1;default:return!0}}function ha(){if(45===Ae()||46===Ae()){var n=Le();return rn(M.createPrefixUnaryExpression(Ae(),Ie(va)),n)}if(1===h&&29===Ae()&&Ve(In))return Ta(!0);var t=va();if(e.Debug.assert(e.isLeftHandSideExpression(t)),(45===Ae()||46===Ae())&&!s.hasPrecedingLineBreak()){var r=Ae();return Ne(),rn(M.createPostfixUnaryExpression(t,r),t.pos)}return t}function va(){var e,n=Le();return 99===Ae()?Ve(Xt)?(m|=1048576,e=Ze()):Ve(Yt)?(Ne(),Ne(),e=rn(M.createMetaProperty(99,un()),n),m|=2097152):e=ba():e=105===Ae()?Ea():ba(),Ka(n,e)}function ba(){var e=Le(),n=qa();return Ua(e,n,!0)}function Ea(){var n=Le(),t=Ze();if(29===Ae()){var r=Le(),a=je(Wa);void 0!==a&&Te(r,Le(),e.Diagnostics.super_may_not_use_type_arguments)}return 20===Ae()||24===Ae()||22===Ae()?t:(Ye(24,e.Diagnostics.super_must_be_followed_by_an_argument_list_or_member_access),rn(M.createPropertyAccessExpression(t,at(!0,!0)),n))}function Ta(n,t){var r,a=Le(),i=Aa(n);if(276===i.kind){var o=La(i),s=Ra(n);O(i.tagName,s.tagName)||Se(s,e.Diagnostics.Expected_corresponding_JSX_closing_tag_for_0,e.getTextOfNodeFromSourceText(_,i.tagName)),r=rn(M.createJsxElement(i,o,s),a)}else 279===i.kind?r=rn(M.createJsxFragment(i,La(i),Oa(n)),a):(e.Debug.assert(275===i.kind),r=i);if(n&&29===Ae()){var c="undefined"===typeof t?r.pos:t,l=je((function(){return Ta(!0,c)}));if(l){var u=an(27,!1);return e.setTextRangePosWidth(u,l.pos,0),Te(e.skipTrivia(_,c),l.end,e.Diagnostics.JSX_expressions_must_have_one_parent_element),rn(M.createBinaryExpression(r,u,l),a)}}return r}function Sa(){var e=Le(),n=M.createJsxText(s.getTokenValue(),12===D);return D=s.scanJsxToken(),rn(n,e)}function xa(n,t){switch(t){case 1:if(e.isJsxOpeningFragment(n))Se(n,e.Diagnostics.JSX_fragment_has_no_corresponding_closing_tag);else{var r=n.tagName,a=e.skipTrivia(_,r.pos);Te(a,r.end,e.Diagnostics.JSX_element_0_has_no_corresponding_closing_tag,e.getTextOfNodeFromSourceText(_,n.tagName))}return;case 30:case 7:return;case 11:case 12:return Sa();case 18:return Ia(!1);case 29:return Ta(!1);default:return e.Debug.assertNever(t)}}function La(e){var n=[],t=Le(),r=k;k|=16384;while(1){var a=xa(e,D=s.reScanJsxToken());if(!a)break;n.push(a)}return k=r,tn(n,t)}function Da(){var e=Le();return rn(M.createJsxAttributes(Mn(13,Na)),e)}function Aa(e){var n=Le();if(We(29),31===Ae())return Ge(),rn(M.createJsxOpeningFragment(),n);var t,r=Ca(),a=0===(131072&w)?Eo():void 0,i=Da();return 31===Ae()?(Ge(),t=M.createJsxOpeningElement(r,a,i)):(We(43),e?We(31):(We(31,void 0,!1),Ge()),t=M.createJsxSelfClosingElement(r,a,i)),rn(t,n)}function Ca(){var e=Le();Fe();var n=107===Ae()?Ze():un();while(qe(24))n=rn(M.createPropertyAccessExpression(n,at(!0,!1)),e);return n}function Ia(e){var n,t,r=Le();if(We(18))return 19!==Ae()&&(n=Je(25),t=Vr()),e?We(19):We(19,void 0,!1)&&Ge(),rn(M.createJsxExpression(n,t),r)}function Na(){if(18===Ae())return ka();Fe();var e=Le();return rn(M.createJsxAttribute(un(),62!==Ae()?void 0:10===Be()?pt():Ia(!0)),e)}function ka(){var e=Le();We(18),We(25);var n=Vr();return We(19),rn(M.createJsxSpreadAttribute(n),e)}function Ra(e){var n=Le();We(30);var t=Ca();return e?We(31):(We(31,void 0,!1),Ge()),rn(M.createJsxClosingElement(t),n)}function Oa(n){var t=Le();return We(30),e.tokenIsIdentifierOrKeyword(Ae())&&Se(Ca(),e.Diagnostics.Expected_corresponding_closing_tag_for_JSX_fragment),n?We(31):(We(31,void 0,!1),Ge()),rn(M.createJsxJsxClosingFragment(),t)}function wa(){var e=Le();We(29);var n=Pr();We(31);var t=ga();return rn(M.createTypeAssertion(n,t),e)}function Pa(){return Ne(),e.tokenIsIdentifierOrKeyword(Ae())||22===Ae()||Va()}function Ma(){return 28===Ae()&&Ve(Pa)}function Fa(n){if(32&n.flags)return!0;if(e.isNonNullExpression(n)){var t=n.expression;while(e.isNonNullExpression(t)&&!(32&t.flags))t=t.expression;if(32&t.flags){while(e.isNonNullExpression(n))n.flags|=32,n=n.expression;return!0}}return!1}function Ga(n,t,r){var a=at(!0,!0),i=r||Fa(t),o=i?M.createPropertyAccessChain(t,r,a):M.createPropertyAccessExpression(t,a);return i&&e.isPrivateIdentifier(o.name)&&Se(o.name,e.Diagnostics.An_optional_chain_cannot_contain_private_identifiers),rn(o,n)}function Ba(n,t,r){var a;if(23===Ae())a=an(78,!0,e.Diagnostics.An_element_access_expression_should_take_an_argument);else{var i=se(Vr);e.isStringOrNumericLiteralLike(i)&&(i.text=on(i.text)),a=i}We(23);var o=r||Fa(t)?M.createElementAccessChain(t,r,a):M.createElementAccessExpression(t,a);return rn(o,n)}function Ua(n,t,r){while(1){var a=void 0,i=!1;if(r&&Ma()?(a=Ye(28),i=e.tokenIsIdentifierOrKeyword(Ae())):i=qe(24),i)t=Ga(n,t,a);else if(a||53!==Ae()||s.hasPrecedingLineBreak())if(!a&&he()||!qe(22)){if(!Va())return t;t=ja(n,t,a,void 0)}else t=Ba(n,t,a);else Ne(),t=rn(M.createNonNullExpression(t),n)}}function Va(){return 14===Ae()||15===Ae()}function ja(e,n,t,r){var a=M.createTaggedTemplateExpression(n,r,14===Ae()?(Pe(),pt()):ot(!0));return(t||32&n.flags)&&(a.flags|=32),a.questionDotToken=t,rn(a,e)}function Ka(n,t){while(1){t=Ua(n,t,!0);var r=Je(28);if(0!==(131072&w)||29!==Ae()&&47!==Ae()){if(20===Ae()){i=Ha(),o=r||Fa(t)?M.createCallChain(t,r,void 0,i):M.createCallExpression(t,void 0,i);t=rn(o,n);continue}}else{var a=je(Wa);if(a){if(Va()){t=ja(n,t,r,a);continue}var i=Ha(),o=r||Fa(t)?M.createCallChain(t,r,a,i):M.createCallExpression(t,a,i);t=rn(o,n);continue}}if(r){var s=an(78,!1,e.Diagnostics.Identifier_expected);t=rn(M.createPropertyAccessChain(t,r,s),n)}break}return t}function Ha(){We(20);var e=Qn(11,Qa);return We(21),e}function Wa(){if(0===(131072&w)&&29===Me()){Ne();var e=Qn(20,Pr);if(We(31))return e&&za()?e:void 0}}function za(){switch(Ae()){case 20:case 14:case 15:case 24:case 21:case 23:case 58:case 26:case 57:case 34:case 36:case 35:case 37:case 55:case 56:case 60:case 52:case 50:case 51:case 19:case 1:return!0;case 27:case 18:default:return!1}}function qa(){switch(Ae()){case 8:case 9:case 10:case 14:return pt();case 107:case 105:case 103:case 109:case 94:return Ze();case 20:return Ja();case 22:return Za();case 18:return ei();case 129:if(!Ve(Di))break;return ni();case 83:return fo();case 97:return ni();case 102:return ri();case 43:case 67:if(13===Oe())return pt();break;case 15:return ot(!1)}return ln(e.Diagnostics.Expression_expected)}function Ja(){var e=Le(),n=De();We(20);var t=se(Vr);return We(21),W(rn(M.createParenthesizedExpression(t),e),n)}function Xa(){var e=Le();We(25);var n=Kr();return rn(M.createSpreadElement(n),e)}function Ya(){return 25===Ae()?Xa():27===Ae()?rn(M.createOmittedExpression(),Le()):Kr()}function Qa(){return ie(c,Ya)}function Za(){var e=Le();We(22);var n=s.hasPrecedingLineBreak(),t=Qn(15,Ya);return We(23),rn(M.createArrayLiteralExpression(t,n),e)}function $a(){var e=Le(),n=De();if(Je(25)){var t=Kr();return W(rn(M.createSpreadAssignment(t),e),n)}var r=so(),a=lo();if(yn(134))return ro(e,n,r,a,168);if(yn(146))return ro(e,n,r,a,169);var i,o=Je(41),s=He(),c=fn(),l=Je(57),u=Je(53);if(o||20===Ae()||29===Ae())return eo(e,n,r,a,o,c,l,u);var d=s&&58!==Ae();if(d){var p=Je(62),f=p?se(Kr):void 0;i=M.createShorthandPropertyAssignment(c,f),i.equalsToken=p}else{We(58);var m=se(Kr);i=M.createPropertyAssignment(c,m)}return i.decorators=r,i.modifiers=a,i.questionToken=l,i.exclamationToken=u,W(rn(i,e),n)}function ei(){var n=Le(),t=s.getTokenPos();We(18);var r=s.hasPrecedingLineBreak(),a=Qn(12,$a,!0);if(!We(19)){var i=e.lastOrUndefined(b);i&&i.code===e.Diagnostics._0_expected.code&&e.addRelatedInfo(i,e.createDetachedDiagnostic(d,t,1,e.Diagnostics.The_parser_expected_to_find_a_to_match_the_token_here))}return rn(M.createObjectLiteralExpression(a,r),n)}function ni(){var n=he();n&&re(!1);var t=Le(),r=De(),a=lo();We(97);var i=Je(41),o=i?1:0,s=e.some(a,e.isAsyncModifier)?2:0,c=o&&s?fe(ti):o?le(ti):s?de(ti):ti(),l=kt(),u=Ut(o|s),d=Ft(58,!1),p=ii(o|s);n&&re(!0);var f=M.createFunctionExpression(a,i,c,l,u,d,p);return W(rn(f,t),r)}function ti(){return Ke()?cn():void 0}function ri(){var n=Le();if(We(102),qe(24)){var t=un();return rn(M.createMetaProperty(102,t),n)}var r,a,i=Le(),o=qa();while(1){o=Ua(i,o,!1),r=je(Wa),Va()&&(e.Debug.assert(!!r,"Expected a type argument list; all plain tagged template starts should be consumed in 'parseMemberExpressionRest'"),o=ja(i,o,void 0,r),r=void 0);break}return 20===Ae()?a=Ha():r&&Te(n,s.getStartPos(),e.Diagnostics.A_new_expression_with_type_arguments_must_always_be_followed_by_a_parenthesized_argument_list),rn(M.createNewExpression(o,r,a),n)}function ai(n,t){var r=Le(),a=De(),i=s.getTokenPos();if(We(18,t)||n){var o=s.hasPrecedingLineBreak(),c=Mn(1,Oi);if(!We(19)){var l=e.lastOrUndefined(b);l&&l.code===e.Diagnostics._0_expected.code&&e.addRelatedInfo(l,e.createDetachedDiagnostic(d,i,1,e.Diagnostics.The_parser_expected_to_find_a_to_match_the_token_here))}var u=W(rn(M.createBlock(c,o),r),a);return 62===Ae()&&(be(e.Diagnostics.Declaration_or_statement_expected_This_follows_a_block_of_statements_so_if_you_intended_to_write_a_destructuring_assignment_you_might_need_to_wrap_the_the_whole_assignment_in_parentheses),Ne()),u}c=$n();return W(rn(M.createBlock(c,void 0),r),a)}function ii(e,n){var t=ge();te(!!(1&e));var r=ve();ae(!!(2&e));var a=F;F=!1;var i=he();i&&re(!1);var o=ai(!!(16&e),n);return i&&re(!0),F=a,te(t),ae(r),o}function oi(){var e=Le(),n=De();return We(26),W(rn(M.createEmptyStatement(),e),n)}function si(){var e=Le(),n=De();We(98),We(20);var t=se(Vr);We(21);var r=Oi(),a=qe(90)?Oi():void 0;return W(rn(M.createIfStatement(t,r,a),e),n)}function ci(){var e=Le(),n=De();We(89);var t=Oi();We(114),We(20);var r=se(Vr);return We(21),qe(26),W(rn(M.createDoStatement(t,r),e),n)}function li(){var e=Le(),n=De();We(114),We(20);var t=se(Vr);We(21);var r=Oi();return W(rn(M.createWhileStatement(t,r),e),n)}function ui(){var e=Le(),n=De();We(96);var t,r,a=Je(130);if(We(20),26!==Ae()&&(t=112===Ae()||118===Ae()||84===Ae()?Ji(!0):ce(Vr)),a?We(157):qe(157)){var i=se(Kr);We(21),r=M.createForOfStatement(a,t,i,Oi())}else if(qe(100)){i=se(Vr);We(21),r=M.createForInStatement(t,i,Oi())}else{We(26);var o=26!==Ae()&&21!==Ae()?se(Vr):void 0;We(26);var s=21!==Ae()?se(Vr):void 0;We(21),r=M.createForStatement(t,o,s,Oi())}return W(rn(r,e),n)}function di(e){var n=Le(),t=De();We(242===e?80:85);var r=en()?void 0:ln();nn();var a=242===e?M.createBreakStatement(r):M.createContinueStatement(r);return W(rn(a,n),t)}function pi(){var e=Le(),n=De();We(104);var t=en()?void 0:se(Vr);return nn(),W(rn(M.createReturnStatement(t),e),n)}function fi(){var e=Le(),n=De();We(115),We(20);var t=se(Vr);We(21);var r=oe(16777216,Oi);return W(rn(M.createWithStatement(t,r),e),n)}function mi(){var e=Le();We(81);var n=se(Vr);We(58);var t=Mn(3,Oi);return rn(M.createCaseClause(n,t),e)}function _i(){var e=Le();We(87),We(58);var n=Mn(3,Oi);return rn(M.createDefaultClause(n),e)}function gi(){return 81===Ae()?mi():_i()}function yi(){var e=Le();We(18);var n=Mn(2,gi);return We(19),rn(M.createCaseBlock(n),e)}function hi(){var e=Le(),n=De();We(106),We(20);var t=se(Vr);We(21);var r=yi();return W(rn(M.createSwitchStatement(t,r),e),n)}function vi(){var e=Le(),n=De();We(108);var t=s.hasPrecedingLineBreak()?void 0:se(Vr);return void 0===t&&(N++,t=rn(M.createIdentifier(""),Le())),nn(),W(rn(M.createThrowStatement(t),e),n)}function bi(){var e=Le(),n=De();We(110);var t,r=ai(!1),a=82===Ae()?Ei():void 0;return a&&95!==Ae()||(We(95),t=ai(!1)),W(rn(M.createTryStatement(r,a,t),e),n)}function Ei(){var e,n=Le();We(82),qe(20)?(e=qi(),We(21)):e=void 0;var t=ai(!1);return rn(M.createCatchClause(e,t),n)}function Ti(){var e=Le(),n=De();return We(86),nn(),W(rn(M.createDebuggerStatement(),e),n)}function Si(){var n,t=Le(),r=De(),a=20===Ae(),i=se(Vr);return e.isIdentifier(i)&&qe(58)?n=M.createLabeledStatement(i,Oi()):(nn(),n=M.createExpressionStatement(i),a&&(r=!1)),W(rn(n,t),r)}function xi(){return Ne(),e.tokenIsIdentifierOrKeyword(Ae())&&!s.hasPrecedingLineBreak()}function Li(){return Ne(),83===Ae()&&!s.hasPrecedingLineBreak()}function Di(){return Ne(),97===Ae()&&!s.hasPrecedingLineBreak()}function Ai(){return Ne(),(e.tokenIsIdentifierOrKeyword(Ae())||8===Ae()||9===Ae()||10===Ae())&&!s.hasPrecedingLineBreak()}function Ci(){while(1)switch(Ae()){case 112:case 118:case 84:case 97:case 83:case 91:return!0;case 117:case 149:return Wr();case 139:case 140:return Gi();case 125:case 129:case 133:case 120:case 121:case 122:case 142:if(Ne(),s.hasPrecedingLineBreak())return!1;continue;case 154:return Ne(),18===Ae()||78===Ae()||92===Ae();case 99:return Ne(),10===Ae()||41===Ae()||18===Ae()||e.tokenIsIdentifierOrKeyword(Ae());case 92:var n=Ne();if(149===n&&(n=Ve(Ne)),62===n||41===n||18===n||87===n||126===n)return!0;continue;case 123:Ne();continue;default:return!1}}function Ii(){return Ve(Ci)}function Ni(){switch(Ae()){case 59:case 26:case 18:case 112:case 118:case 97:case 83:case 91:case 98:case 89:case 114:case 96:case 85:case 80:case 104:case 115:case 106:case 108:case 110:case 86:case 82:case 95:return!0;case 99:return Ii()||Ve(Qt);case 84:case 92:return Ii();case 129:case 133:case 117:case 139:case 140:case 149:case 154:return!0;case 122:case 120:case 121:case 123:case 142:return Ii()||!Ve(xi);default:return Br()}}function ki(){return Ne(),He()||18===Ae()||22===Ae()}function Ri(){return Ve(ki)}function Oi(){switch(Ae()){case 26:return oi();case 18:return ai(!1);case 112:return Yi(Le(),De(),void 0,void 0);case 118:if(Ri())return Yi(Le(),De(),void 0,void 0);break;case 97:return Qi(Le(),De(),void 0,void 0);case 83:return mo(Le(),De(),void 0,void 0);case 98:return si();case 89:return ci();case 114:return li();case 96:return ui();case 85:return di(241);case 80:return di(242);case 104:return pi();case 115:return fi();case 106:return hi();case 108:return vi();case 110:case 82:case 95:return bi();case 86:return Ti();case 59:return Pi();case 129:case 117:case 149:case 139:case 140:case 133:case 84:case 91:case 92:case 99:case 120:case 121:case 122:case 125:case 123:case 142:case 154:if(Ii())return Pi();break}return Si()}function wi(e){return 133===e.kind}function Pi(){var n=e.some(Ve((function(){return so(),lo()})),wi);if(n){var t=Mi();if(t)return t}var r=Le(),a=De(),i=so(),o=lo();if(n){for(var s=0,c=o;s<c.length;s++){var l=c[s];l.flags|=8388608}return oe(8388608,(function(){return Fi(r,a,i,o)}))}return Fi(r,a,i,o)}function Mi(){return oe(8388608,(function(){var e=Gn(k);if(e)return Bn(e)}))}function Fi(n,t,r,a){switch(Ae()){case 112:case 118:case 84:return Yi(n,t,r,a);case 97:return Qi(n,t,r,a);case 83:return mo(n,t,r,a);case 117:return xo(n,t,r,a);case 149:return Lo(n,t,r,a);case 91:return Ao(n,t,r,a);case 154:case 139:case 140:return ko(n,t,r,a);case 99:return Mo(n,t,r,a);case 92:switch(Ne(),Ae()){case 87:case 62:return Qo(n,t,r,a);case 126:return Po(n,t,r,a);default:return Yo(n,t,r,a)}default:if(r||a){var i=an(272,!0,e.Diagnostics.Declaration_expected);return e.setTextRangePos(i,n),i.decorators=r,i.modifiers=a,i}return}}function Gi(){return Ne(),!s.hasPrecedingLineBreak()&&(He()||10===Ae())}function Bi(e,n){if(18===Ae()||!en())return ii(e,n);nn()}function Ui(){var e=Le();if(27===Ae())return rn(M.createOmittedExpression(),e);var n=Je(25),t=Wi(),r=jr();return rn(M.createBindingElement(n,void 0,t,r),e)}function Vi(){var e,n=Le(),t=Je(25),r=Ke(),a=fn();r&&58!==Ae()?(e=a,a=void 0):(We(58),e=Wi());var i=jr();return rn(M.createBindingElement(t,a,e,i),n)}function ji(){var e=Le();We(18);var n=Qn(9,Vi);return We(19),rn(M.createObjectBindingPattern(n),e)}function Ki(){var e=Le();We(22);var n=Qn(10,Ui);return We(23),rn(M.createArrayBindingPattern(n),e)}function Hi(){return 18===Ae()||22===Ae()||79===Ae()||Ke()}function Wi(e){return 22===Ae()?Ki():18===Ae()?ji():cn(e)}function zi(){return qi(!0)}function qi(n){var t,r=Le(),a=De(),i=Wi(e.Diagnostics.Private_identifiers_are_not_allowed_in_variable_declarations);n&&78===i.kind&&53===Ae()&&!s.hasPrecedingLineBreak()&&(t=Ze());var o=Fr(),c=aa(Ae())?void 0:jr(),l=M.createVariableDeclaration(i,t,o,c);return W(rn(l,r),a)}function Ji(n){var t,r=Le(),a=0;switch(Ae()){case 112:break;case 118:a|=1;break;case 84:a|=2;break;default:e.Debug.fail()}if(Ne(),157===Ae()&&Ve(Xi))t=$n();else{var i=ye();ne(n),t=Qn(8,n?qi:zi),ne(i)}return rn(M.createVariableDeclarationList(t,a),r)}function Xi(){return An()&&21===Ne()}function Yi(e,n,t,r){var a=Ji(!1);nn();var i=M.createVariableStatement(r,a);return i.decorators=t,W(rn(i,e),n)}function Qi(n,t,r,a){var i=ve(),o=e.modifiersToFlags(a);We(97);var s=Je(41),c=512&o?ti():cn(),l=s?1:0,u=256&o?2:0,d=kt();1&o&&ae(!0);var p=Ut(l|u),f=Ft(58,!1),m=Bi(l|u,e.Diagnostics.or_expected);ae(i);var _=M.createFunctionDeclaration(r,a,s,c,d,p,f,m);return W(rn(_,n),t)}function Zi(){return 132===Ae()?We(132):10===Ae()&&20===Ve(Ne)?je((function(){var e=pt();return"constructor"===e.text?e:void 0})):void 0}function $i(n,t,r,a){return je((function(){if(Zi()){var i=kt(),o=Ut(0),s=Ft(58,!1),c=Bi(0,e.Diagnostics.or_expected),l=M.createConstructorDeclaration(r,a,o,c);return l.typeParameters=i,l.type=s,W(rn(l,n),t)}}))}function eo(n,t,r,a,i,o,s,c,l){var u=i?1:0,d=e.some(a,e.isAsyncModifier)?2:0,p=kt(),f=Ut(u|d),m=Ft(58,!1),_=Bi(u|d,l),g=M.createMethodDeclaration(r,a,i,o,s,p,f,m,_);return g.exclamationToken=c,W(rn(g,n),t)}function no(e,n,t,r,a,i){var o=i||s.hasPrecedingLineBreak()?void 0:Je(53),c=Fr(),l=ie(45056,jr);nn();var u=M.createPropertyDeclaration(t,r,a,i||o,c,l);return W(rn(u,e),n)}function to(n,t,r,a){var i=Je(41),o=fn(),s=Je(57);return i||20===Ae()||29===Ae()?eo(n,t,r,a,i,o,s,void 0,e.Diagnostics.or_expected):no(n,t,r,a,o,s)}function ro(e,n,t,r,a){var i=fn(),o=kt(),s=Ut(0),c=Ft(58,!1),l=Bi(0),u=168===a?M.createGetAccessorDeclaration(t,r,i,s,c,l):M.createSetAccessorDeclaration(t,r,i,s,l);return u.typeParameters=o,c&&169===u.kind&&(u.type=c),W(rn(u,e),n)}function ao(){var n;if(59===Ae())return!0;while(e.isModifierKind(Ae())){if(n=Ae(),e.isClassMemberModifier(n))return!0;Ne()}if(41===Ae())return!0;if(dn()&&(n=Ae(),Ne()),22===Ae())return!0;if(void 0!==n){if(!e.isKeyword(n)||146===n||134===n)return!0;switch(Ae()){case 20:case 29:case 53:case 58:case 62:case 57:return!0;default:return en()}}return!1}function io(){if(ve()&&130===Ae()){var n=Le(),t=ln(e.Diagnostics.Expression_expected);Ne();var r=Ua(n,t,!0);return Ka(n,r)}return va()}function oo(){var e=Le();if(qe(59)){var n=ue(io);return rn(M.createDecorator(n),e)}}function so(){var n,t,r=Le();while(t=oo())n=e.append(n,t);return n&&tn(n,r)}function co(e){var n=Le(),t=Ae();if(84===Ae()&&e){if(!je(hn))return}else if(!Tn())return;return rn(M.createToken(t),n)}function lo(n){var t,r,a=Le();while(r=co(n))t=e.append(t,r);return t&&tn(t,a)}function uo(){var e;if(129===Ae()){var n=Le();Ne();var t=rn(M.createToken(129),n);e=tn([t],n)}return e}function po(){var n=Le();if(26===Ae())return Ne(),rn(M.createSemicolonClassElement(),n);var t=De(),r=so(),a=lo(!0);if(yn(134))return ro(n,t,r,a,168);if(yn(146))return ro(n,t,r,a,169);if(132===Ae()||10===Ae()){var i=$i(n,t,r,a);if(i)return i}if(Kt())return Wt(n,t,r,a);if(e.tokenIsIdentifierOrKeyword(Ae())||10===Ae()||8===Ae()||41===Ae()||22===Ae()){var o=e.some(a,wi);if(o){for(var s=0,c=a;s<c.length;s++){var l=c[s];l.flags|=8388608}return oe(8388608,(function(){return to(n,t,r,a)}))}return to(n,t,r,a)}if(r||a){var u=an(78,!0,e.Diagnostics.Declaration_expected);return no(n,t,r,a,u,void 0)}return e.Debug.fail("Should not have attempted to parse class member declaration.")}function fo(){return _o(Le(),De(),void 0,void 0,222)}function mo(e,n,t,r){return _o(e,n,t,r,253)}function _o(n,t,r,a,i){var o=ve();We(83);var s=go(),c=kt();e.some(a,e.isExportModifier)&&ae(!0);var l,u=ho();We(18)?(l=So(),We(19)):l=$n(),ae(o);var d=253===i?M.createClassDeclaration(r,a,s,c,u,l):M.createClassExpression(r,a,s,c,u,l);return W(rn(d,n),t)}function go(){return Ke()&&!yo()?sn(Ke()):void 0}function yo(){return 116===Ae()&&Ve(Cn)}function ho(){if(To())return Mn(22,vo)}function vo(){var n=Le(),t=Ae();e.Debug.assert(93===t||116===t),Ne();var r=Qn(7,bo);return rn(M.createHeritageClause(t,r),n)}function bo(){var e=Le(),n=va(),t=Eo();return rn(M.createExpressionWithTypeArguments(n,t),e)}function Eo(){return 29===Ae()?nt(20,Pr,29,31):void 0}function To(){return 93===Ae()||116===Ae()}function So(){return Mn(5,po)}function xo(e,n,t,r){We(117);var a=ln(),i=kt(),o=ho(),s=$t(),c=M.createInterfaceDeclaration(t,r,a,i,o,s);return W(rn(c,e),n)}function Lo(e,n,t,r){We(149);var a=ln(),i=kt();We(62);var o=136===Ae()&&je(dr)||Pr();nn();var s=M.createTypeAliasDeclaration(t,r,a,i,o);return W(rn(s,e),n)}function Do(){var e=Le(),n=De(),t=fn(),r=se(jr);return W(rn(M.createEnumMember(t,r),e),n)}function Ao(e,n,t,r){We(91);var a,i=ln();We(18)?(a=me((function(){return Qn(6,Do)})),We(19)):a=$n();var o=M.createEnumDeclaration(t,r,i,a);return W(rn(o,e),n)}function Co(){var e,n=Le();return We(18)?(e=Mn(1,Oi),We(19)):e=$n(),rn(M.createModuleBlock(e),n)}function Io(e,n,t,r,a){var i=16&a,o=ln(),s=qe(24)?Io(Le(),!1,void 0,void 0,4|i):Co(),c=M.createModuleDeclaration(t,r,o,s,a);return W(rn(c,e),n)}function No(e,n,t,r){var a,i,o=0;154===Ae()?(a=ln(),o|=1024):(a=pt(),a.text=on(a.text)),18===Ae()?i=Co():nn();var s=M.createModuleDeclaration(t,r,a,i,o);return W(rn(s,e),n)}function ko(e,n,t,r){var a=0;if(154===Ae())return No(e,n,t,r);if(qe(140))a|=16;else if(We(139),10===Ae())return No(e,n,t,r);return Io(e,n,t,r,a)}function Ro(){return 143===Ae()&&Ve(Oo)}function Oo(){return 20===Ne()}function wo(){return 43===Ne()}function Po(e,n,t,r){We(126),We(140);var a=ln();nn();var i=M.createNamespaceExportDeclaration(a);return i.decorators=t,i.modifiers=r,W(rn(i,e),n)}function Mo(e,n,t,r){We(99);var a,i=s.getStartPos();He()&&(a=ln());var o,c=!1;if(153!==Ae()&&"type"===(null===a||void 0===a?void 0:a.escapedText)&&(He()||Fo())&&(c=!0,a=He()?ln():void 0),a&&!Go())return Bo(e,n,t,r,a,c);(a||41===Ae()||18===Ae())&&(o=Uo(a,i,c),We(153));var l=Ko();nn();var u=M.createImportDeclaration(t,r,o,l);return W(rn(u,e),n)}function Fo(){return 41===Ae()||18===Ae()}function Go(){return 27===Ae()||153===Ae()}function Bo(e,n,t,r,a,i){We(62);var o=Vo();nn();var s=M.createImportEqualsDeclaration(t,r,i,a,o),c=W(rn(s,e),n);return c}function Uo(e,n,t){var r;return e&&!qe(27)||(r=41===Ae()?Ho():Wo(265)),rn(M.createImportClause(t,e,r),n)}function Vo(){return Ro()?jo():tt(!1)}function jo(){var e=Le();We(143),We(20);var n=Ko();return We(21),rn(M.createExternalModuleReference(n),e)}function Ko(){if(10===Ae()){var e=pt();return e.text=on(e.text),e}return Vr()}function Ho(){var e=Le();We(41),We(126);var n=ln();return rn(M.createNamespaceImport(n),e)}function Wo(e){var n=Le(),t=265===e?M.createNamedImports(nt(23,qo,18,19)):M.createNamedExports(nt(23,zo,18,19));return rn(t,n)}function zo(){return Jo(271)}function qo(){return Jo(266)}function Jo(n){var t,r,a=Le(),i=e.isKeyword(Ae())&&!He(),o=s.getTokenPos(),c=s.getTextPos(),l=un();126===Ae()?(t=l,We(126),i=e.isKeyword(Ae())&&!He(),o=s.getTokenPos(),c=s.getTextPos(),r=un()):r=l,266===n&&i&&Te(o,c,e.Diagnostics.Identifier_expected);var u=266===n?M.createImportSpecifier(t,r):M.createExportSpecifier(t,r);return rn(u,a)}function Xo(e){return rn(M.createNamespaceExport(un()),e)}function Yo(e,n,t,r){var a,i,o=ve();ae(!0);var c=qe(149),l=Le();qe(41)?(qe(126)&&(a=Xo(l)),We(153),i=Ko()):(a=Wo(269),(153===Ae()||10===Ae()&&!s.hasPrecedingLineBreak())&&(We(153),i=Ko())),nn(),ae(o);var u=M.createExportDeclaration(t,r,c,a,i);return W(rn(u,e),n)}function Qo(e,n,t,r){var a,i=ve();ae(!0),qe(62)?a=!0:We(87);var o=Kr();nn(),ae(i);var s=M.createExportAssignment(t,r,a,o);return W(rn(s,e),n)}function Zo(n){n.externalModuleIndicator=e.forEach(n.statements,$o)||es(n)}function $o(n){return ts(n,92)||e.isImportEqualsDeclaration(n)&&e.isExternalModuleReference(n.moduleReference)||e.isImportDeclaration(n)||e.isExportAssignment(n)||e.isExportDeclaration(n)?n:void 0}function es(e){return 2097152&e.flags?ns(e):void 0}function ns(e){return rs(e)?e:f(e,ns)}function ts(n,t){return e.some(n.modifiers,(function(e){return e.kind===t}))}function rs(n){return e.isMetaProperty(n)&&99===n.keywordToken&&"meta"===n.name.escapedText}n.fixupParentReferences=Z,function(e){e[e["SourceElements"]=0]="SourceElements",e[e["BlockStatements"]=1]="BlockStatements",e[e["SwitchClauses"]=2]="SwitchClauses",e[e["SwitchClauseStatements"]=3]="SwitchClauseStatements",e[e["TypeMembers"]=4]="TypeMembers",e[e["ClassMembers"]=5]="ClassMembers",e[e["EnumMembers"]=6]="EnumMembers",e[e["HeritageClauseElement"]=7]="HeritageClauseElement",e[e["VariableDeclarations"]=8]="VariableDeclarations",e[e["ObjectBindingElements"]=9]="ObjectBindingElements",e[e["ArrayBindingElements"]=10]="ArrayBindingElements",e[e["ArgumentExpressions"]=11]="ArgumentExpressions",e[e["ObjectLiteralMembers"]=12]="ObjectLiteralMembers",e[e["JsxAttributes"]=13]="JsxAttributes",e[e["JsxChildren"]=14]="JsxChildren",e[e["ArrayLiteralMembers"]=15]="ArrayLiteralMembers",e[e["Parameters"]=16]="Parameters",e[e["JSDocParameters"]=17]="JSDocParameters",e[e["RestProperties"]=18]="RestProperties",e[e["TypeParameters"]=19]="TypeParameters",e[e["TypeArguments"]=20]="TypeArguments",e[e["TupleElementTypes"]=21]="TupleElementTypes",e[e["HeritageClauses"]=22]="HeritageClauses",e[e["ImportOrExportSpecifiers"]=23]="ImportOrExportSpecifiers",e[e["Count"]=24]="Count"}(z||(z={})),function(e){e[e["False"]=0]="False",e[e["True"]=1]="True",e[e["Unknown"]=2]="Unknown"}(q||(q={})),function(n){function t(n,t,a){j("file.js",n,99,void 0,1),s.setText(n,t,a),D=s.scan();var i=r(),o=$("file.js",99,1,!1,[],M.createToken(1),0),c=e.attachFileToDiagnostics(b,o);return E&&(o.jsDocDiagnostics=e.attachFileToDiagnostics(E,o)),K(),i?{jsDocTypeExpression:i,diagnostics:c}:void 0}function r(e){var n=Le(),t=(e?qe:We)(18),r=oe(4194304,Ct);e&&!t||ze(19);var a=M.createJSDocTypeExpression(r);return Z(a),rn(a,n)}function a(){var e=Le(),n=qe(18),t=tt(!1);n&&ze(19);var r=M.createJSDocNameReference(t);return Z(r),rn(r,e)}function i(n,t,r){j("",n,99,void 0,1);var a=oe(4194304,(function(){return u(t,r)})),i={languageVariant:0,text:n},o=e.attachFileToDiagnostics(b,i);return K(),a?{jsDoc:a,diagnostics:o}:void 0}function o(n,t,r){var a=D,i=b.length,o=G,s=oe(4194304,(function(){return u(t,r)}));return e.setParent(s,n),131072&w&&(E||(E=[]),E.push.apply(E,b)),D=a,b.length=i,G=o,s}var c,l;function u(n,t){void 0===n&&(n=0);var i=_,o=void 0===t?i.length:n+t;if(t=o-n,e.Debug.assert(n>=0),e.Debug.assert(n<=o),e.Debug.assert(o<=i.length),p(i,n)){var c,l,u,f,m,g=[],y=[];return s.scanRange(n+3,t-5,(function(){var t,r=1,a=n-(i.lastIndexOf("\n",n)+1)+4;function d(e){t||(t=a),g.push(e),a+=e.length}ke();while(le(5));le(4)&&(r=0,a=0);e:while(1){switch(Ae()){case 59:0===r||1===r?(v(g),m||(m=Le()),R(x(a)),r=0,t=void 0):d(s.getTokenText());break;case 4:g.push(s.getTokenText()),r=0,a=0;break;case 41:var p=s.getTokenText();1===r||2===r?(r=2,d(p)):(r=1,a+=p.length);break;case 5:var _=s.getTokenText();2===r?g.push(_):void 0!==t&&a+_.length>t&&g.push(_.slice(t-a)),a+=_.length;break;case 1:break e;case 18:r=2;var b=s.getStartPos(),E=s.getTextPos()-1,T=C(E);if(T){f||h(g),y.push(rn(M.createJSDocText(g.join("")),null!==f&&void 0!==f?f:n,b)),y.push(T),g=[],f=s.getTextPos();break}default:r=2,d(s.getTokenText());break}ke()}v(g),y.length&&g.length&&y.push(rn(M.createJSDocText(g.join("")),null!==f&&void 0!==f?f:n,m)),y.length&&c&&e.Debug.assertIsDefined(m,"having parsed tags implies that the end of the comment span should be set");var S=c&&tn(c,l,u);return rn(M.createJSDocComment(y.length?tn(y,n,m):g.length?g.join(""):void 0,S),n,o)}))}function h(e){while(e.length&&("\n"===e[0]||"\r"===e[0]))e.shift()}function v(e){while(e.length&&""===e[e.length-1].trim())e.pop()}function E(){while(1){if(ke(),1===Ae())return!0;if(5!==Ae()&&4!==Ae())return!1}}function T(){if(5!==Ae()&&4!==Ae()||!Ve(E))while(5===Ae()||4===Ae())ke()}function S(){if((5===Ae()||4===Ae())&&Ve(E))return"";var e=s.hasPrecedingLineBreak(),n=!1,t="";while(e&&41===Ae()||5===Ae()||4===Ae())t+=s.getTokenText(),4===Ae()?(e=!0,n=!0,t=""):41===Ae()&&(e=!1),ke();return n?t:""}function x(n){e.Debug.assert(59===Ae());var t=s.getTokenPos();ke();var r,a=de(void 0),i=S();switch(a.escapedText){case"author":r=j(t,a,n,i);break;case"implements":r=H(t,a,n,i);break;case"augments":case"extends":r=W(t,a,n,i);break;case"class":case"constructor":r=J(t,M.createJSDocClassTag,a,n,i);break;case"public":r=J(t,M.createJSDocPublicTag,a,n,i);break;case"private":r=J(t,M.createJSDocPrivateTag,a,n,i);break;case"protected":r=J(t,M.createJSDocProtectedTag,a,n,i);break;case"readonly":r=J(t,M.createJSDocReadonlyTag,a,n,i);break;case"override":r=J(t,M.createJSDocOverrideTag,a,n,i);break;case"deprecated":X=!0,r=J(t,M.createJSDocDeprecatedTag,a,n,i);break;case"this":r=Y(t,a,n,i);break;case"enum":r=Q(t,a,n,i);break;case"arg":case"argument":case"param":return F(t,a,2,n);case"return":case"returns":r=B(t,a,n,i);break;case"template":r=ce(t,a,n,i);break;case"type":r=U(t,a,n,i);break;case"typedef":r=Z(t,a,n,i);break;case"callback":r=ne(t,a,n,i);break;case"see":r=V(t,a,n,i);break;default:r=k(t,a,n,i);break}return r}function L(e,n,t,r){return r||(t+=n-e),D(t,r.slice(t))}function D(e,n){var t,r,a=Le(),i=[],o=[],c=0,l=!0;function u(n){r||(r=e),i.push(n),e+=n.length}void 0!==n&&(""!==n&&u(n),c=1);var d=Ae();e:while(1){switch(d){case 4:c=0,i.push(s.getTokenText()),e=0;break;case 59:if(3===c||2===c&&(!l||Ve(A))){i.push(s.getTokenText());break}s.setTextPos(s.getTextPos()-1);case 1:break e;case 5:if(2===c||3===c)u(s.getTokenText());else{var p=s.getTokenText();void 0!==r&&e+p.length>r&&i.push(p.slice(r-e)),e+=p.length}break;case 18:c=2;var f=s.getStartPos(),m=s.getTextPos()-1,_=C(m);_?(o.push(rn(M.createJSDocText(i.join("")),null!==t&&void 0!==t?t:a,f)),o.push(_),i=[],t=s.getTextPos()):u(s.getTokenText());break;case 61:c=3===c?2:3,u(s.getTokenText());break;case 41:if(0===c){c=1,e+=1;break}default:3!==c&&(c=2),u(s.getTokenText());break}l=5===Ae(),d=ke()}return h(i),v(i),o.length?(i.length&&o.push(rn(M.createJSDocText(i.join("")),null!==t&&void 0!==t?t:a)),tn(o,a,s.getTextPos())):i.length?i.join(""):void 0}function A(){var e=ke();return 5===e||4===e}function C(n){if(je(I)){ke(),T();var t=e.tokenIsIdentifierOrKeyword(Ae())?tt(!0):void 0,r=[];while(19!==Ae()&&4!==Ae()&&1!==Ae())r.push(s.getTokenText()),ke();return rn(M.createJSDocLink(t,r.join("")),n,s.getTextPos())}}function I(){return S(),18===Ae()&&59===ke()&&e.tokenIsIdentifierOrKeyword(ke())&&"link"===s.getTokenValue()}function k(e,n,t,r){return rn(M.createJSDocUnknownTag(n,L(e,Le(),t,r)),e)}function R(e){e&&(c?c.push(e):(c=[e],l=e.pos),u=e.end)}function O(){return S(),18===Ae()?r():void 0}function w(){var e=le(22);e&&T();var n=le(61),t=ue();return n&&Qe(61),e&&(T(),Je(62)&&Vr(),We(23)),{name:t,isBracketed:e}}function P(n){switch(n.kind){case 145:return!0;case 179:return P(n.elementType);default:return e.isTypeReferenceNode(n)&&e.isIdentifier(n.typeName)&&"Object"===n.typeName.escapedText&&!n.typeArguments}}function F(e,n,t,r){var a=O(),i=!a;S();var o=w(),s=o.name,c=o.isBracketed,l=S();i&&!Ve(I)&&(a=O());var u=L(e,Le(),r,l),d=4!==t&&G(a,s,t,r);d&&(a=d,i=!0);var p=1===t?M.createJSDocPropertyTag(n,s,c,a,i,u):M.createJSDocParameterTag(n,s,c,a,i,u);return rn(p,e)}function G(n,t,r,a){if(n&&P(n.type)){var i=Le(),o=void 0,s=void 0;while(o=je((function(){return ae(r,a,t)})))330!==o.kind&&337!==o.kind||(s=e.append(s,o));if(s){var c=rn(M.createJSDocTypeLiteral(s,179===n.type.kind),i);return rn(M.createJSDocTypeExpression(c),i)}}}function B(n,t,r,a){e.some(c,e.isJSDocReturnTag)&&Te(t.pos,s.getTokenPos(),e.Diagnostics._0_tag_already_specified,t.escapedText);var i=O();return rn(M.createJSDocReturnTag(t,i,L(n,Le(),r,a)),n)}function U(n,t,a,i){e.some(c,e.isJSDocTypeTag)&&Te(t.pos,s.getTokenPos(),e.Diagnostics._0_tag_already_specified,t.escapedText);var o=r(!0),l=void 0!==a&&void 0!==i?L(n,Le(),a,i):void 0;return rn(M.createJSDocTypeTag(t,o,l),n)}function V(n,t,r,i){var o=Ve((function(){return 59===ke()&&e.tokenIsIdentifierOrKeyword(ke())&&"link"===s.getTokenValue()})),c=o?void 0:a(),l=void 0!==r&&void 0!==i?L(n,Le(),r,i):void 0;return rn(M.createJSDocSeeTag(t,c,l),n)}function j(n,t,r,a){var i=Le(),o=K(),c=s.getStartPos(),l=L(n,c,r,a);l||(c=s.getStartPos());var u="string"!==typeof l?tn(e.concatenate([rn(o,i,c)],l),i):o.text+l;return rn(M.createJSDocAuthorTag(t,u),n)}function K(){var e=[],n=!1,t=s.getToken();while(1!==t&&4!==t){if(29===t)n=!0;else{if(59===t&&!n)break;if(31===t&&n){e.push(s.getTokenText()),s.setTextPos(s.getTokenPos()+1);break}}e.push(s.getTokenText()),t=ke()}return M.createJSDocText(e.join(""))}function H(e,n,t,r){var a=z();return rn(M.createJSDocImplementsTag(n,a,L(e,Le(),t,r)),e)}function W(e,n,t,r){var a=z();return rn(M.createJSDocAugmentsTag(n,a,L(e,Le(),t,r)),e)}function z(){var e=qe(18),n=Le(),t=q(),r=Eo(),a=M.createExpressionWithTypeArguments(t,r),i=rn(a,n);return e&&We(19),i}function q(){var e=Le(),n=de();while(qe(24)){var t=de();n=rn(M.createPropertyAccessExpression(n,t),e)}return n}function J(e,n,t,r,a){return rn(n(t,L(e,Le(),r,a)),e)}function Y(e,n,t,a){var i=r(!0);return T(),rn(M.createJSDocThisTag(n,i,L(e,Le(),t,a)),e)}function Q(e,n,t,a){var i=r(!0);return T(),rn(M.createJSDocEnumTag(n,i,L(e,Le(),t,a)),e)}function Z(n,t,r,a){var i,o=O();S();var s=$();T();var c,l=D(r);if(!o||P(o.type)){var u=void 0,p=void 0,f=void 0,m=!1;while(u=je((function(){return re(r)})))if(m=!0,333===u.kind){if(p){be(e.Diagnostics.A_JSDoc_typedef_comment_may_not_contain_multiple_type_tags);var _=e.lastOrUndefined(b);_&&e.addRelatedInfo(_,e.createDetachedDiagnostic(d,0,0,e.Diagnostics.The_tag_was_first_specified_here));break}p=u}else f=e.append(f,u);if(m){var g=o&&179===o.type.kind,y=M.createJSDocTypeLiteral(f,g);o=p&&p.typeExpression&&!P(p.typeExpression.type)?p.typeExpression:rn(y,n),c=o.end}}c=c||void 0!==l?Le():(null!==(i=null!==s&&void 0!==s?s:o)&&void 0!==i?i:t).end,l||(l=L(n,c,r,a));var h=M.createJSDocTypedefTag(t,o,s,l);return rn(h,n,c)}function $(n){var t=s.getTokenPos();if(e.tokenIsIdentifierOrKeyword(Ae())){var r=de();if(qe(24)){var a=$(!0),i=M.createModuleDeclaration(void 0,void 0,r,a,n?4:void 0);return rn(i,t)}return n&&(r.isInJSDocNamespace=!0),r}}function ee(n){var t,r,a=Le();while(t=je((function(){return ae(4,n)})))r=e.append(r,t);return tn(r||[],a)}function ne(e,n,t,r){var a=$();T();var i=D(t),o=ee(t),s=je((function(){if(le(59)){var e=x(t);if(e&&331===e.kind)return e}})),c=rn(M.createJSDocSignature(void 0,o,s),e);return i||(i=L(e,Le(),t,r)),rn(M.createJSDocCallbackTag(n,c,a,i),e)}function te(n,t){while(!e.isIdentifier(n)||!e.isIdentifier(t)){if(e.isIdentifier(n)||e.isIdentifier(t)||n.right.escapedText!==t.right.escapedText)return!1;n=n.left,t=t.left}return n.escapedText===t.escapedText}function re(e){return ae(1,e)}function ae(n,t,r){var a=!0,i=!1;while(1)switch(ke()){case 59:if(a){var o=ie(n,t);return!(o&&(330===o.kind||337===o.kind)&&4!==n&&r&&(e.isIdentifier(o.name)||!te(r,o.name.left)))&&o}i=!1;break;case 4:a=!0,i=!1;break;case 41:i&&(a=!1),i=!0;break;case 78:a=!1;break;case 1:return!1}}function ie(n,t){e.Debug.assert(59===Ae());var r=s.getStartPos();ke();var a,i=de();switch(T(),i.escapedText){case"type":return 1===n&&U(r,i);case"prop":case"property":a=1;break;case"arg":case"argument":case"param":a=6;break;default:return!1}return!!(n&a)&&F(r,i,n,t)}function oe(){var n=Le(),t=de(e.Diagnostics.Unexpected_token_A_type_parameter_name_was_expected_without_curly_braces);if(!e.nodeIsMissing(t))return rn(M.createTypeParameterDeclaration(t,void 0,void 0),n)}function se(){var e=Le(),n=[];do{T();var t=oe();void 0!==t&&n.push(t),S()}while(le(27));return tn(n,e)}function ce(e,n,t,a){var i=18===Ae()?r():void 0,o=se();return rn(M.createJSDocTemplateTag(n,i,o,L(e,Le(),t,a)),e)}function le(e){return Ae()===e&&(ke(),!0)}function ue(){var e=de();qe(22)&&We(23);while(qe(24)){var n=de();qe(22)&&We(23),e=rt(e,n)}return e}function de(n){if(!e.tokenIsIdentifierOrKeyword(Ae()))return an(78,!n,n||e.Diagnostics.Identifier_expected);N++;var t=s.getTokenPos(),r=s.getTextPos(),a=Ae(),i=on(s.getTokenValue()),o=rn(M.createIdentifier(i,void 0,a),t,r);return ke(),o}}n.parseJSDocTypeExpressionForTests=t,n.parseJSDocTypeExpression=r,n.parseJSDocNameReference=a,n.parseIsolatedJSDocComment=i,n.parseJSDocComment=o,function(e){e[e["BeginningOfLine"]=0]="BeginningOfLine",e[e["SawAsterisk"]=1]="SawAsterisk",e[e["SavingComments"]=2]="SavingComments",e[e["SavingBackticks"]=3]="SavingBackticks"}(c||(c={})),function(e){e[e["Property"]=1]="Property",e[e["Parameter"]=2]="Parameter",e[e["CallbackParameter"]=4]="CallbackParameter"}(l||(l={}))}(J=n.JSDocParser||(n.JSDocParser={}))}(c||(c={})),function(n){function t(n,t,a,i){if(i=i||e.Debug.shouldAssert(2),p(n,t,a,i),e.textChangeRangeIsUnchanged(a))return n;if(0===n.statements.length)return c.parseSourceFile(n.fileName,t,n.languageVersion,void 0,!0,n.scriptKind);var o=n;e.Debug.assert(!o.hasBeenIncrementallyParsed),o.hasBeenIncrementallyParsed=!0,c.fixupParentReferences(o);var s=n.text,d=m(n),f=u(n,a);p(n,t,f,i),e.Debug.assert(f.span.start<=a.span.start),e.Debug.assert(e.textSpanEnd(f.span)===e.textSpanEnd(a.span)),e.Debug.assert(e.textSpanEnd(e.textChangeRangeNewSpan(f))===e.textSpanEnd(e.textChangeRangeNewSpan(a)));var _=e.textChangeRangeNewSpan(f).length-f.span.length;l(o,f.span.start,e.textSpanEnd(f.span),e.textSpanEnd(e.textChangeRangeNewSpan(f)),_,s,t,i);var g=c.parseSourceFile(n.fileName,t,n.languageVersion,d,!0,n.scriptKind);return g.commentDirectives=r(n.commentDirectives,g.commentDirectives,f.span.start,e.textSpanEnd(f.span),_,s,t,i),g}function r(n,t,r,a,i,o,s,c){if(!n)return t;for(var l,u=!1,d=0,p=n;d<p.length;d++){var f=p[d],m=f.range,_=f.type;if(m.end<r)l=e.append(l,f);else if(m.pos>a){y();var g={range:{pos:m.pos+i,end:m.end+i},type:_};l=e.append(l,g),c&&e.Debug.assert(o.substring(m.pos,m.end)===s.substring(g.range.pos,g.range.end))}}return y(),l;function y(){u||(u=!0,l?t&&l.push.apply(l,t):l=t)}}function a(n,t,r,a,o,c){return void(t?u(n):l(n));function l(n){var t="";if(c&&i(n)&&(t=a.substring(n.pos,n.end)),n._children&&(n._children=void 0),e.setTextRangePosEnd(n,n.pos+r,n.end+r),c&&i(n)&&e.Debug.assert(t===o.substring(n.pos,n.end)),f(n,l,u),e.hasJSDocNodes(n))for(var d=0,p=n.jsDoc;d<p.length;d++){var m=p[d];l(m)}s(n,c)}function u(n){n._children=void 0,e.setTextRangePosEnd(n,n.pos+r,n.end+r);for(var t=0,a=n;t<a.length;t++){var i=a[t];l(i)}}}function i(e){switch(e.kind){case 10:case 8:case 78:return!0}return!1}function o(n,t,r,a,i){e.Debug.assert(n.end>=t,"Adjusting an element that was entirely before the change range"),e.Debug.assert(n.pos<=r,"Adjusting an element that was entirely after the change range"),e.Debug.assert(n.pos<=n.end);var o=Math.min(n.pos,a),s=n.end>=r?n.end+i:Math.min(n.end,a);e.Debug.assert(o<=s),n.parent&&(e.Debug.assertGreaterThanOrEqual(o,n.parent.pos),e.Debug.assertLessThanOrEqual(s,n.parent.end)),e.setTextRangePosEnd(n,o,s)}function s(n,t){if(t){var r=n.pos,a=function(n){e.Debug.assert(n.pos>=r),r=n.end};if(e.hasJSDocNodes(n))for(var i=0,o=n.jsDoc;i<o.length;i++){var s=o[i];a(s)}f(n,a),e.Debug.assert(r<=n.end)}}function l(n,t,r,i,c,l,u,d){return void p(n);function p(n){if(e.Debug.assert(n.pos<=n.end),n.pos>r)a(n,!1,c,l,u,d);else{var _=n.end;if(_>=t){if(n.intersectsChange=!0,n._children=void 0,o(n,t,r,i,c),f(n,p,m),e.hasJSDocNodes(n))for(var g=0,y=n.jsDoc;g<y.length;g++){var h=y[g];p(h)}s(n,d)}else e.Debug.assert(_<t)}}function m(n){if(e.Debug.assert(n.pos<=n.end),n.pos>r)a(n,!0,c,l,u,d);else{var s=n.end;if(s>=t){n.intersectsChange=!0,n._children=void 0,o(n,t,r,i,c);for(var f=0,m=n;f<m.length;f++){var _=m[f];p(_)}}else e.Debug.assert(s<t)}}}function u(n,t){for(var r=1,a=t.span.start,i=0;a>0&&i<=r;i++){var o=d(n,a);e.Debug.assert(o.pos<=a);var s=o.pos;a=Math.max(0,s-1)}var c=e.createTextSpanFromBounds(a,e.textSpanEnd(t.span)),l=t.newLength+(t.span.start-a);return e.createTextChangeRange(c,l)}function d(n,t){var r,a=n;if(f(n,s),r){var i=o(r);i.pos>a.pos&&(a=i)}return a;function o(n){while(1){var t=e.getLastChild(n);if(!t)return n;n=t}}function s(n){if(!e.nodeIsMissing(n))return n.pos<=t?(n.pos>=a.pos&&(a=n),t<n.end?(f(n,s),!0):(e.Debug.assert(n.end<=t),void(r=n))):(e.Debug.assert(n.pos>t),!0)}}function p(n,t,r,a){var i=n.text;if(r&&(e.Debug.assert(i.length-r.span.length+r.newLength===t.length),a||e.Debug.shouldAssert(3))){var o=i.substr(0,r.span.start),s=t.substr(0,r.span.start);e.Debug.assert(o===s);var c=i.substring(e.textSpanEnd(r.span),i.length),l=t.substring(e.textSpanEnd(e.textChangeRangeNewSpan(r)),t.length);e.Debug.assert(c===l)}}function m(n){var t=n.statements,r=0;e.Debug.assert(r<t.length);var a=t[r],i=-1;return{currentNode:function(n){return n!==i&&(a&&a.end===n&&r<t.length-1&&(r++,a=t[r]),a&&a.pos===n||o(n)),i=n,e.Debug.assert(!a||a.pos===n),a}};function o(e){return t=void 0,r=-1,a=void 0,void f(n,i,o);function i(n){return e>=n.pos&&e<n.end&&(f(n,i,o),!0)}function o(n){if(e>=n.pos&&e<n.end)for(var s=0;s<n.length;s++){var c=n[s];if(c){if(c.pos===e)return t=n,r=s,a=c,!0;if(c.pos<e&&e<c.end)return f(c,i,o),!0}}return!1}}}var _;n.updateSourceFile=t,n.createSyntaxCursor=m,function(e){e[e["Value"]=-1]="Value"}(_||(_={}))}(l||(l={})),e.isDeclarationFileName=S,e.processCommentPragmas=x,e.processPragmasIntoFields=L;var D=new e.Map;function A(e){if(D.has(e))return D.get(e);var n=new RegExp("(\\s"+e+"\\s*=\\s*)('|\")(.+?)\\2","im");return D.set(e,n),n}var C=/^\/\/\/\s*<(\S+)\s.*?\/>/im,I=/^\/\/\/?\s*@(\S+)\s*(.*)\s*$/im;function N(n,t,r){var a=2===t.kind&&C.exec(r);if(a){var i=a[1].toLowerCase(),o=e.commentPragmas[i];if(!o||!(1&o.kind))return;if(o.args){for(var s={},c=0,l=o.args;c<l.length;c++){var u=l[c],d=A(u.name),p=d.exec(r);if(!p&&!u.optional)return;if(p)if(u.captureSpan){var f=t.pos+p.index+p[1].length+p[2].length;s[u.name]={value:p[3],pos:f,end:f+p[3].length}}else s[u.name]=p[3]}n.push({name:i,args:{arguments:s,range:t}})}else n.push({name:i,args:{arguments:{},range:t}})}else{var m=2===t.kind&&I.exec(r);if(m)return k(n,t,2,m);if(3===t.kind){var _=/\s*@(\S+)\s*(.*)\s*$/gim,g=void 0;while(g=_.exec(r))k(n,t,4,g)}}}function k(n,t,r,a){if(a){var i=a[1].toLowerCase(),o=e.commentPragmas[i];if(o&&o.kind&r){var s=a[2],c=R(o,s);"fail"!==c&&n.push({name:i,args:{arguments:c,range:t}})}}}function R(n,t){if(!t)return{};if(!n.args)return{};for(var r=t.split(/\s+/),a={},i=0;i<n.args.length;i++){var o=n.args[i];if(!r[i]&&!o.optional)return"fail";if(o.captureSpan)return e.Debug.fail("Capture spans not yet implemented for non-xml pragmas");a[o.name]=r[i]}return a}function O(e,n){return e.kind===n.kind&&(78===e.kind?e.escapedText===n.escapedText:107===e.kind||e.name.escapedText===n.name.escapedText&&O(e.expression,n.expression))}e.tagNamesAreEquivalent=O}(d||(d={})),function(e){e.compileOnSaveCommandLineOption={name:"compileOnSave",type:"boolean"};var n=new e.Map(e.getEntries({preserve:1,"react-native":3,react:2,"react-jsx":4,"react-jsxdev":5}));e.inverseJsxOptionMap=new e.Map(e.arrayFrom(e.mapIterator(n.entries(),(function(e){var n=e[0],t=e[1];return[""+t,n]}))));var t=[["es5","lib.es5.d.ts"],["es6","lib.es2015.d.ts"],["es2015","lib.es2015.d.ts"],["es7","lib.es2016.d.ts"],["es2016","lib.es2016.d.ts"],["es2017","lib.es2017.d.ts"],["es2018","lib.es2018.d.ts"],["es2019","lib.es2019.d.ts"],["es2020","lib.es2020.d.ts"],["es2021","lib.es2021.d.ts"],["esnext","lib.esnext.d.ts"],["dom","lib.dom.d.ts"],["dom.iterable","lib.dom.iterable.d.ts"],["webworker","lib.webworker.d.ts"],["webworker.importscripts","lib.webworker.importscripts.d.ts"],["webworker.iterable","lib.webworker.iterable.d.ts"],["scripthost","lib.scripthost.d.ts"],["es2015.core","lib.es2015.core.d.ts"],["es2015.collection","lib.es2015.collection.d.ts"],["es2015.generator","lib.es2015.generator.d.ts"],["es2015.iterable","lib.es2015.iterable.d.ts"],["es2015.promise","lib.es2015.promise.d.ts"],["es2015.proxy","lib.es2015.proxy.d.ts"],["es2015.reflect","lib.es2015.reflect.d.ts"],["es2015.symbol","lib.es2015.symbol.d.ts"],["es2015.symbol.wellknown","lib.es2015.symbol.wellknown.d.ts"],["es2016.array.include","lib.es2016.array.include.d.ts"],["es2017.object","lib.es2017.object.d.ts"],["es2017.sharedmemory","lib.es2017.sharedmemory.d.ts"],["es2017.string","lib.es2017.string.d.ts"],["es2017.intl","lib.es2017.intl.d.ts"],["es2017.typedarrays","lib.es2017.typedarrays.d.ts"],["es2018.asyncgenerator","lib.es2018.asyncgenerator.d.ts"],["es2018.asynciterable","lib.es2018.asynciterable.d.ts"],["es2018.intl","lib.es2018.intl.d.ts"],["es2018.promise","lib.es2018.promise.d.ts"],["es2018.regexp","lib.es2018.regexp.d.ts"],["es2019.array","lib.es2019.array.d.ts"],["es2019.object","lib.es2019.object.d.ts"],["es2019.string","lib.es2019.string.d.ts"],["es2019.symbol","lib.es2019.symbol.d.ts"],["es2020.bigint","lib.es2020.bigint.d.ts"],["es2020.promise","lib.es2020.promise.d.ts"],["es2020.sharedmemory","lib.es2020.sharedmemory.d.ts"],["es2020.string","lib.es2020.string.d.ts"],["es2020.symbol.wellknown","lib.es2020.symbol.wellknown.d.ts"],["es2020.intl","lib.es2020.intl.d.ts"],["es2021.promise","lib.es2021.promise.d.ts"],["es2021.string","lib.es2021.string.d.ts"],["es2021.weakref","lib.es2021.weakref.d.ts"],["esnext.array","lib.es2019.array.d.ts"],["esnext.symbol","lib.es2019.symbol.d.ts"],["esnext.asynciterable","lib.es2018.asynciterable.d.ts"],["esnext.intl","lib.esnext.intl.d.ts"],["esnext.bigint","lib.es2020.bigint.d.ts"],["esnext.string","lib.es2021.string.d.ts"],["esnext.promise","lib.es2021.promise.d.ts"],["esnext.weakref","lib.es2021.weakref.d.ts"]];e.libs=t.map((function(e){return e[0]})),e.libMap=new e.Map(t),e.optionsForWatch=[{name:"watchFile",type:new e.Map(e.getEntries({fixedpollinginterval:e.WatchFileKind.FixedPollingInterval,prioritypollinginterval:e.WatchFileKind.PriorityPollingInterval,dynamicprioritypolling:e.WatchFileKind.DynamicPriorityPolling,fixedchunksizepolling:e.WatchFileKind.FixedChunkSizePolling,usefsevents:e.WatchFileKind.UseFsEvents,usefseventsonparentdirectory:e.WatchFileKind.UseFsEventsOnParentDirectory})),category:e.Diagnostics.Advanced_Options,description:e.Diagnostics.Specify_strategy_for_watching_file_Colon_FixedPollingInterval_default_PriorityPollingInterval_DynamicPriorityPolling_FixedChunkSizePolling_UseFsEvents_UseFsEventsOnParentDirectory},{name:"watchDirectory",type:new e.Map(e.getEntries({usefsevents:e.WatchDirectoryKind.UseFsEvents,fixedpollinginterval:e.WatchDirectoryKind.FixedPollingInterval,dynamicprioritypolling:e.WatchDirectoryKind.DynamicPriorityPolling,fixedchunksizepolling:e.WatchDirectoryKind.FixedChunkSizePolling})),category:e.Diagnostics.Advanced_Options,description:e.Diagnostics.Specify_strategy_for_watching_directory_on_platforms_that_don_t_support_recursive_watching_natively_Colon_UseFsEvents_default_FixedPollingInterval_DynamicPriorityPolling_FixedChunkSizePolling},{name:"fallbackPolling",type:new e.Map(e.getEntries({fixedinterval:e.PollingWatchKind.FixedInterval,priorityinterval:e.PollingWatchKind.PriorityInterval,dynamicpriority:e.PollingWatchKind.DynamicPriority,fixedchunksize:e.PollingWatchKind.FixedChunkSize})),category:e.Diagnostics.Advanced_Options,description:e.Diagnostics.Specify_strategy_for_creating_a_polling_watch_when_it_fails_to_create_using_file_system_events_Colon_FixedInterval_default_PriorityInterval_DynamicPriority_FixedChunkSize},{name:"synchronousWatchDirectory",type:"boolean",category:e.Diagnostics.Advanced_Options,description:e.Diagnostics.Synchronously_call_callbacks_and_update_the_state_of_directory_watchers_on_platforms_that_don_t_support_recursive_watching_natively},{name:"excludeDirectories",type:"list",element:{name:"excludeDirectory",type:"string",isFilePath:!0,extraValidation:Ze},category:e.Diagnostics.Advanced_Options,description:e.Diagnostics.Synchronously_call_callbacks_and_update_the_state_of_directory_watchers_on_platforms_that_don_t_support_recursive_watching_natively},{name:"excludeFiles",type:"list",element:{name:"excludeFile",type:"string",isFilePath:!0,extraValidation:Ze},category:e.Diagnostics.Advanced_Options,description:e.Diagnostics.Synchronously_call_callbacks_and_update_the_state_of_directory_watchers_on_platforms_that_don_t_support_recursive_watching_natively}],e.commonOptionsWithBuild=[{name:"help",shortName:"h",type:"boolean",showInSimplifiedHelpView:!0,category:e.Diagnostics.Command_line_Options,description:e.Diagnostics.Print_this_message},{name:"help",shortName:"?",type:"boolean"},{name:"watch",shortName:"w",type:"boolean",showInSimplifiedHelpView:!0,category:e.Diagnostics.Command_line_Options,description:e.Diagnostics.Watch_input_files},{name:"preserveWatchOutput",type:"boolean",showInSimplifiedHelpView:!1,category:e.Diagnostics.Command_line_Options,description:e.Diagnostics.Whether_to_keep_outdated_console_output_in_watch_mode_instead_of_clearing_the_screen},{name:"listFiles",type:"boolean",category:e.Diagnostics.Advanced_Options,description:e.Diagnostics.Print_names_of_files_part_of_the_compilation},{name:"explainFiles",type:"boolean",category:e.Diagnostics.Advanced_Options,description:e.Diagnostics.Print_names_of_files_and_the_reason_they_are_part_of_the_compilation},{name:"listEmittedFiles",type:"boolean",category:e.Diagnostics.Advanced_Options,description:e.Diagnostics.Print_names_of_generated_files_part_of_the_compilation},{name:"pretty",type:"boolean",showInSimplifiedHelpView:!0,category:e.Diagnostics.Command_line_Options,description:e.Diagnostics.Stylize_errors_and_messages_using_color_and_context_experimental},{name:"traceResolution",type:"boolean",category:e.Diagnostics.Advanced_Options,description:e.Diagnostics.Enable_tracing_of_the_name_resolution_process},{name:"diagnostics",type:"boolean",category:e.Diagnostics.Advanced_Options,description:e.Diagnostics.Show_diagnostic_information},{name:"extendedDiagnostics",type:"boolean",category:e.Diagnostics.Advanced_Options,description:e.Diagnostics.Show_verbose_diagnostic_information},{name:"generateCpuProfile",type:"string",isFilePath:!0,paramType:e.Diagnostics.FILE_OR_DIRECTORY,category:e.Diagnostics.Advanced_Options,description:e.Diagnostics.Generates_a_CPU_profile},{name:"generateTrace",type:"string",isFilePath:!0,isCommandLineOnly:!0,paramType:e.Diagnostics.DIRECTORY,category:e.Diagnostics.Advanced_Options,description:e.Diagnostics.Generates_an_event_trace_and_a_list_of_types},{name:"incremental",shortName:"i",type:"boolean",category:e.Diagnostics.Basic_Options,description:e.Diagnostics.Enable_incremental_compilation,transpileOptionValue:void 0},{name:"assumeChangesOnlyAffectDirectDependencies",type:"boolean",affectsSemanticDiagnostics:!0,affectsEmit:!0,category:e.Diagnostics.Advanced_Options,description:e.Diagnostics.Have_recompiles_in_incremental_and_watch_assume_that_changes_within_a_file_will_only_affect_files_directly_depending_on_it},{name:"locale",type:"string",category:e.Diagnostics.Advanced_Options,description:e.Diagnostics.The_locale_used_when_displaying_messages_to_the_user_e_g_en_us}],e.targetOptionDeclaration={name:"target",shortName:"t",type:new e.Map(e.getEntries({es3:0,es5:1,es6:2,es2015:2,es2016:3,es2017:4,es2018:5,es2019:6,es2020:7,es2021:8,esnext:99})),affectsSourceFile:!0,affectsModuleResolution:!0,affectsEmit:!0,paramType:e.Diagnostics.VERSION,showInSimplifiedHelpView:!0,category:e.Diagnostics.Basic_Options,description:e.Diagnostics.Specify_ECMAScript_target_version_Colon_ES3_default_ES5_ES2015_ES2016_ES2017_ES2018_ES2019_ES2020_ES2021_or_ESNEXT};var r=[{name:"all",type:"boolean",showInSimplifiedHelpView:!0,category:e.Diagnostics.Command_line_Options,description:e.Diagnostics.Show_all_compiler_options},{name:"version",shortName:"v",type:"boolean",showInSimplifiedHelpView:!0,category:e.Diagnostics.Command_line_Options,description:e.Diagnostics.Print_the_compiler_s_version},{name:"init",type:"boolean",showInSimplifiedHelpView:!0,category:e.Diagnostics.Command_line_Options,description:e.Diagnostics.Initializes_a_TypeScript_project_and_creates_a_tsconfig_json_file},{name:"project",shortName:"p",type:"string",isFilePath:!0,showInSimplifiedHelpView:!0,category:e.Diagnostics.Command_line_Options,paramType:e.Diagnostics.FILE_OR_DIRECTORY,description:e.Diagnostics.Compile_the_project_given_the_path_to_its_configuration_file_or_to_a_folder_with_a_tsconfig_json},{name:"build",type:"boolean",shortName:"b",showInSimplifiedHelpView:!0,category:e.Diagnostics.Command_line_Options,description:e.Diagnostics.Build_one_or_more_projects_and_their_dependencies_if_out_of_date},{name:"showConfig",type:"boolean",category:e.Diagnostics.Command_line_Options,isCommandLineOnly:!0,description:e.Diagnostics.Print_the_final_configuration_instead_of_building},{name:"listFilesOnly",type:"boolean",category:e.Diagnostics.Command_line_Options,affectsSemanticDiagnostics:!0,affectsEmit:!0,isCommandLineOnly:!0,description:e.Diagnostics.Print_names_of_files_that_are_part_of_the_compilation_and_then_stop_processing},e.targetOptionDeclaration,{name:"module",shortName:"m",type:new e.Map(e.getEntries({none:e.ModuleKind.None,commonjs:e.ModuleKind.CommonJS,amd:e.ModuleKind.AMD,system:e.ModuleKind.System,umd:e.ModuleKind.UMD,es6:e.ModuleKind.ES2015,es2015:e.ModuleKind.ES2015,es2020:e.ModuleKind.ES2020,esnext:e.ModuleKind.ESNext})),affectsModuleResolution:!0,affectsEmit:!0,paramType:e.Diagnostics.KIND,showInSimplifiedHelpView:!0,category:e.Diagnostics.Basic_Options,description:e.Diagnostics.Specify_module_code_generation_Colon_none_commonjs_amd_system_umd_es2015_es2020_or_ESNext},{name:"lib",type:"list",element:{name:"lib",type:e.libMap},affectsModuleResolution:!0,showInSimplifiedHelpView:!0,category:e.Diagnostics.Basic_Options,description:e.Diagnostics.Specify_library_files_to_be_included_in_the_compilation,transpileOptionValue:void 0},{name:"allowJs",type:"boolean",affectsModuleResolution:!0,showInSimplifiedHelpView:!0,category:e.Diagnostics.Basic_Options,description:e.Diagnostics.Allow_javascript_files_to_be_compiled},{name:"checkJs",type:"boolean",category:e.Diagnostics.Basic_Options,description:e.Diagnostics.Report_errors_in_js_files},{name:"jsx",type:n,affectsSourceFile:!0,affectsEmit:!0,affectsModuleResolution:!0,paramType:e.Diagnostics.KIND,showInSimplifiedHelpView:!0,category:e.Diagnostics.Basic_Options,description:e.Diagnostics.Specify_JSX_code_generation_Colon_preserve_react_native_react_react_jsx_or_react_jsxdev},{name:"declaration",shortName:"d",type:"boolean",affectsEmit:!0,showInSimplifiedHelpView:!0,category:e.Diagnostics.Basic_Options,description:e.Diagnostics.Generates_corresponding_d_ts_file,transpileOptionValue:void 0},{name:"declarationMap",type:"boolean",affectsEmit:!0,showInSimplifiedHelpView:!0,category:e.Diagnostics.Basic_Options,description:e.Diagnostics.Generates_a_sourcemap_for_each_corresponding_d_ts_file,transpileOptionValue:void 0},{name:"emitDeclarationOnly",type:"boolean",affectsEmit:!0,category:e.Diagnostics.Advanced_Options,description:e.Diagnostics.Only_emit_d_ts_declaration_files,transpileOptionValue:void 0},{name:"sourceMap",type:"boolean",affectsEmit:!0,showInSimplifiedHelpView:!0,category:e.Diagnostics.Basic_Options,description:e.Diagnostics.Generates_corresponding_map_file},{name:"outFile",type:"string",affectsEmit:!0,isFilePath:!0,paramType:e.Diagnostics.FILE,showInSimplifiedHelpView:!0,category:e.Diagnostics.Basic_Options,description:e.Diagnostics.Concatenate_and_emit_output_to_single_file,transpileOptionValue:void 0},{name:"outDir",type:"string",affectsEmit:!0,isFilePath:!0,paramType:e.Diagnostics.DIRECTORY,showInSimplifiedHelpView:!0,category:e.Diagnostics.Basic_Options,description:e.Diagnostics.Redirect_output_structure_to_the_directory},{name:"rootDir",type:"string",affectsEmit:!0,isFilePath:!0,paramType:e.Diagnostics.LOCATION,category:e.Diagnostics.Basic_Options,description:e.Diagnostics.Specify_the_root_directory_of_input_files_Use_to_control_the_output_directory_structure_with_outDir},{name:"composite",type:"boolean",affectsEmit:!0,isTSConfigOnly:!0,category:e.Diagnostics.Basic_Options,description:e.Diagnostics.Enable_project_compilation,transpileOptionValue:void 0},{name:"tsBuildInfoFile",type:"string",affectsEmit:!0,isFilePath:!0,paramType:e.Diagnostics.FILE,category:e.Diagnostics.Basic_Options,description:e.Diagnostics.Specify_file_to_store_incremental_compilation_information,transpileOptionValue:void 0},{name:"removeComments",type:"boolean",affectsEmit:!0,showInSimplifiedHelpView:!0,category:e.Diagnostics.Basic_Options,description:e.Diagnostics.Do_not_emit_comments_to_output},{name:"noEmit",type:"boolean",showInSimplifiedHelpView:!0,category:e.Diagnostics.Basic_Options,description:e.Diagnostics.Do_not_emit_outputs,transpileOptionValue:void 0},{name:"importHelpers",type:"boolean",affectsEmit:!0,category:e.Diagnostics.Basic_Options,description:e.Diagnostics.Import_emit_helpers_from_tslib},{name:"importsNotUsedAsValues",type:new e.Map(e.getEntries({remove:0,preserve:1,error:2})),affectsEmit:!0,affectsSemanticDiagnostics:!0,category:e.Diagnostics.Advanced_Options,description:e.Diagnostics.Specify_emit_Slashchecking_behavior_for_imports_that_are_only_used_for_types},{name:"downlevelIteration",type:"boolean",affectsEmit:!0,category:e.Diagnostics.Basic_Options,description:e.Diagnostics.Provide_full_support_for_iterables_in_for_of_spread_and_destructuring_when_targeting_ES5_or_ES3},{name:"isolatedModules",type:"boolean",category:e.Diagnostics.Basic_Options,description:e.Diagnostics.Transpile_each_file_as_a_separate_module_similar_to_ts_transpileModule,transpileOptionValue:!0},{name:"strict",type:"boolean",showInSimplifiedHelpView:!0,category:e.Diagnostics.Strict_Type_Checking_Options,description:e.Diagnostics.Enable_all_strict_type_checking_options},{name:"noImplicitAny",type:"boolean",affectsSemanticDiagnostics:!0,strictFlag:!0,showInSimplifiedHelpView:!0,category:e.Diagnostics.Strict_Type_Checking_Options,description:e.Diagnostics.Raise_error_on_expressions_and_declarations_with_an_implied_any_type},{name:"strictNullChecks",type:"boolean",affectsSemanticDiagnostics:!0,strictFlag:!0,showInSimplifiedHelpView:!0,category:e.Diagnostics.Strict_Type_Checking_Options,description:e.Diagnostics.Enable_strict_null_checks},{name:"strictFunctionTypes",type:"boolean",affectsSemanticDiagnostics:!0,strictFlag:!0,showInSimplifiedHelpView:!0,category:e.Diagnostics.Strict_Type_Checking_Options,description:e.Diagnostics.Enable_strict_checking_of_function_types},{name:"strictBindCallApply",type:"boolean",strictFlag:!0,showInSimplifiedHelpView:!0,category:e.Diagnostics.Strict_Type_Checking_Options,description:e.Diagnostics.Enable_strict_bind_call_and_apply_methods_on_functions},{name:"strictPropertyInitialization",type:"boolean",affectsSemanticDiagnostics:!0,strictFlag:!0,showInSimplifiedHelpView:!0,category:e.Diagnostics.Strict_Type_Checking_Options,description:e.Diagnostics.Enable_strict_checking_of_property_initialization_in_classes},{name:"noImplicitThis",type:"boolean",affectsSemanticDiagnostics:!0,strictFlag:!0,showInSimplifiedHelpView:!0,category:e.Diagnostics.Strict_Type_Checking_Options,description:e.Diagnostics.Raise_error_on_this_expressions_with_an_implied_any_type},{name:"alwaysStrict",type:"boolean",affectsSourceFile:!0,strictFlag:!0,showInSimplifiedHelpView:!0,category:e.Diagnostics.Strict_Type_Checking_Options,description:e.Diagnostics.Parse_in_strict_mode_and_emit_use_strict_for_each_source_file},{name:"noUnusedLocals",type:"boolean",affectsSemanticDiagnostics:!0,showInSimplifiedHelpView:!0,category:e.Diagnostics.Additional_Checks,description:e.Diagnostics.Report_errors_on_unused_locals},{name:"noUnusedParameters",type:"boolean",affectsSemanticDiagnostics:!0,showInSimplifiedHelpView:!0,category:e.Diagnostics.Additional_Checks,description:e.Diagnostics.Report_errors_on_unused_parameters},{name:"noImplicitReturns",type:"boolean",affectsSemanticDiagnostics:!0,showInSimplifiedHelpView:!0,category:e.Diagnostics.Additional_Checks,description:e.Diagnostics.Report_error_when_not_all_code_paths_in_function_return_a_value},{name:"noFallthroughCasesInSwitch",type:"boolean",affectsBindDiagnostics:!0,affectsSemanticDiagnostics:!0,showInSimplifiedHelpView:!0,category:e.Diagnostics.Additional_Checks,description:e.Diagnostics.Report_errors_for_fallthrough_cases_in_switch_statement},{name:"noUncheckedIndexedAccess",type:"boolean",affectsSemanticDiagnostics:!0,showInSimplifiedHelpView:!1,category:e.Diagnostics.Additional_Checks,description:e.Diagnostics.Include_undefined_in_index_signature_results},{name:"noImplicitOverride",type:"boolean",affectsSemanticDiagnostics:!0,showInSimplifiedHelpView:!1,category:e.Diagnostics.Additional_Checks,description:e.Diagnostics.Ensure_overriding_members_in_derived_classes_are_marked_with_an_override_modifier},{name:"noPropertyAccessFromIndexSignature",type:"boolean",showInSimplifiedHelpView:!1,category:e.Diagnostics.Additional_Checks,description:e.Diagnostics.Require_undeclared_properties_from_index_signatures_to_use_element_accesses},{name:"moduleResolution",type:new e.Map(e.getEntries({node:e.ModuleResolutionKind.NodeJs,classic:e.ModuleResolutionKind.Classic})),affectsModuleResolution:!0,paramType:e.Diagnostics.STRATEGY,category:e.Diagnostics.Module_Resolution_Options,description:e.Diagnostics.Specify_module_resolution_strategy_Colon_node_Node_js_or_classic_TypeScript_pre_1_6},{name:"baseUrl",type:"string",affectsModuleResolution:!0,isFilePath:!0,category:e.Diagnostics.Module_Resolution_Options,description:e.Diagnostics.Base_directory_to_resolve_non_absolute_module_names},{name:"paths",type:"object",affectsModuleResolution:!0,isTSConfigOnly:!0,category:e.Diagnostics.Module_Resolution_Options,description:e.Diagnostics.A_series_of_entries_which_re_map_imports_to_lookup_locations_relative_to_the_baseUrl,transpileOptionValue:void 0},{name:"rootDirs",type:"list",isTSConfigOnly:!0,element:{name:"rootDirs",type:"string",isFilePath:!0},affectsModuleResolution:!0,category:e.Diagnostics.Module_Resolution_Options,description:e.Diagnostics.List_of_root_folders_whose_combined_content_represents_the_structure_of_the_project_at_runtime,transpileOptionValue:void 0},{name:"typeRoots",type:"list",element:{name:"typeRoots",type:"string",isFilePath:!0},affectsModuleResolution:!0,category:e.Diagnostics.Module_Resolution_Options,description:e.Diagnostics.List_of_folders_to_include_type_definitions_from},{name:"types",type:"list",element:{name:"types",type:"string"},affectsModuleResolution:!0,showInSimplifiedHelpView:!0,category:e.Diagnostics.Module_Resolution_Options,description:e.Diagnostics.Type_declaration_files_to_be_included_in_compilation,transpileOptionValue:void 0},{name:"allowSyntheticDefaultImports",type:"boolean",affectsSemanticDiagnostics:!0,category:e.Diagnostics.Module_Resolution_Options,description:e.Diagnostics.Allow_default_imports_from_modules_with_no_default_export_This_does_not_affect_code_emit_just_typechecking},{name:"esModuleInterop",type:"boolean",affectsSemanticDiagnostics:!0,affectsEmit:!0,showInSimplifiedHelpView:!0,category:e.Diagnostics.Module_Resolution_Options,description:e.Diagnostics.Enables_emit_interoperability_between_CommonJS_and_ES_Modules_via_creation_of_namespace_objects_for_all_imports_Implies_allowSyntheticDefaultImports},{name:"preserveSymlinks",type:"boolean",category:e.Diagnostics.Module_Resolution_Options,description:e.Diagnostics.Do_not_resolve_the_real_path_of_symlinks},{name:"allowUmdGlobalAccess",type:"boolean",affectsSemanticDiagnostics:!0,category:e.Diagnostics.Module_Resolution_Options,description:e.Diagnostics.Allow_accessing_UMD_globals_from_modules},{name:"sourceRoot",type:"string",affectsEmit:!0,paramType:e.Diagnostics.LOCATION,category:e.Diagnostics.Source_Map_Options,description:e.Diagnostics.Specify_the_location_where_debugger_should_locate_TypeScript_files_instead_of_source_locations},{name:"mapRoot",type:"string",affectsEmit:!0,paramType:e.Diagnostics.LOCATION,category:e.Diagnostics.Source_Map_Options,description:e.Diagnostics.Specify_the_location_where_debugger_should_locate_map_files_instead_of_generated_locations},{name:"inlineSourceMap",type:"boolean",affectsEmit:!0,category:e.Diagnostics.Source_Map_Options,description:e.Diagnostics.Emit_a_single_file_with_source_maps_instead_of_having_a_separate_file},{name:"inlineSources",type:"boolean",affectsEmit:!0,category:e.Diagnostics.Source_Map_Options,description:e.Diagnostics.Emit_the_source_alongside_the_sourcemaps_within_a_single_file_requires_inlineSourceMap_or_sourceMap_to_be_set},{name:"experimentalDecorators",type:"boolean",affectsSemanticDiagnostics:!0,category:e.Diagnostics.Experimental_Options,description:e.Diagnostics.Enables_experimental_support_for_ES7_decorators},{name:"emitDecoratorMetadata",type:"boolean",affectsSemanticDiagnostics:!0,affectsEmit:!0,category:e.Diagnostics.Experimental_Options,description:e.Diagnostics.Enables_experimental_support_for_emitting_type_metadata_for_decorators},{name:"jsxFactory",type:"string",category:e.Diagnostics.Advanced_Options,description:e.Diagnostics.Specify_the_JSX_factory_function_to_use_when_targeting_react_JSX_emit_e_g_React_createElement_or_h},{name:"jsxFragmentFactory",type:"string",category:e.Diagnostics.Advanced_Options,description:e.Diagnostics.Specify_the_JSX_fragment_factory_function_to_use_when_targeting_react_JSX_emit_with_jsxFactory_compiler_option_is_specified_e_g_Fragment},{name:"jsxImportSource",type:"string",affectsSemanticDiagnostics:!0,affectsEmit:!0,affectsModuleResolution:!0,category:e.Diagnostics.Advanced_Options,description:e.Diagnostics.Specify_the_module_specifier_to_be_used_to_import_the_jsx_and_jsxs_factory_functions_from_eg_react},{name:"resolveJsonModule",type:"boolean",affectsModuleResolution:!0,category:e.Diagnostics.Advanced_Options,description:e.Diagnostics.Include_modules_imported_with_json_extension},{name:"out",type:"string",affectsEmit:!0,isFilePath:!1,category:e.Diagnostics.Advanced_Options,paramType:e.Diagnostics.FILE,description:e.Diagnostics.Deprecated_Use_outFile_instead_Concatenate_and_emit_output_to_single_file,transpileOptionValue:void 0},{name:"reactNamespace",type:"string",affectsEmit:!0,category:e.Diagnostics.Advanced_Options,description:e.Diagnostics.Deprecated_Use_jsxFactory_instead_Specify_the_object_invoked_for_createElement_when_targeting_react_JSX_emit},{name:"skipDefaultLibCheck",type:"boolean",category:e.Diagnostics.Advanced_Options,description:e.Diagnostics.Deprecated_Use_skipLibCheck_instead_Skip_type_checking_of_default_library_declaration_files},{name:"charset",type:"string",category:e.Diagnostics.Advanced_Options,description:e.Diagnostics.The_character_set_of_the_input_files},{name:"emitBOM",type:"boolean",affectsEmit:!0,category:e.Diagnostics.Advanced_Options,description:e.Diagnostics.Emit_a_UTF_8_Byte_Order_Mark_BOM_in_the_beginning_of_output_files},{name:"newLine",type:new e.Map(e.getEntries({crlf:0,lf:1})),affectsEmit:!0,paramType:e.Diagnostics.NEWLINE,category:e.Diagnostics.Advanced_Options,description:e.Diagnostics.Specify_the_end_of_line_sequence_to_be_used_when_emitting_files_Colon_CRLF_dos_or_LF_unix},{name:"noErrorTruncation",type:"boolean",affectsSemanticDiagnostics:!0,category:e.Diagnostics.Advanced_Options,description:e.Diagnostics.Do_not_truncate_error_messages},{name:"noLib",type:"boolean",affectsModuleResolution:!0,category:e.Diagnostics.Advanced_Options,description:e.Diagnostics.Do_not_include_the_default_library_file_lib_d_ts,transpileOptionValue:!0},{name:"noResolve",type:"boolean",affectsModuleResolution:!0,category:e.Diagnostics.Advanced_Options,description:e.Diagnostics.Do_not_add_triple_slash_references_or_imported_modules_to_the_list_of_compiled_files,transpileOptionValue:!0},{name:"stripInternal",type:"boolean",affectsEmit:!0,category:e.Diagnostics.Advanced_Options,description:e.Diagnostics.Do_not_emit_declarations_for_code_that_has_an_internal_annotation},{name:"disableSizeLimit",type:"boolean",affectsSourceFile:!0,category:e.Diagnostics.Advanced_Options,description:e.Diagnostics.Disable_size_limitations_on_JavaScript_projects},{name:"disableSourceOfProjectReferenceRedirect",type:"boolean",isTSConfigOnly:!0,category:e.Diagnostics.Advanced_Options,description:e.Diagnostics.Disable_use_of_source_files_instead_of_declaration_files_from_referenced_projects},{name:"disableSolutionSearching",type:"boolean",isTSConfigOnly:!0,category:e.Diagnostics.Advanced_Options,description:e.Diagnostics.Disable_solution_searching_for_this_project},{name:"disableReferencedProjectLoad",type:"boolean",isTSConfigOnly:!0,category:e.Diagnostics.Advanced_Options,description:e.Diagnostics.Disable_loading_referenced_projects},{name:"noImplicitUseStrict",type:"boolean",affectsSemanticDiagnostics:!0,category:e.Diagnostics.Advanced_Options,description:e.Diagnostics.Do_not_emit_use_strict_directives_in_module_output},{name:"noEmitHelpers",type:"boolean",affectsEmit:!0,category:e.Diagnostics.Advanced_Options,description:e.Diagnostics.Do_not_generate_custom_helper_functions_like_extends_in_compiled_output},{name:"noEmitOnError",type:"boolean",affectsEmit:!0,category:e.Diagnostics.Advanced_Options,description:e.Diagnostics.Do_not_emit_outputs_if_any_errors_were_reported,transpileOptionValue:void 0},{name:"preserveConstEnums",type:"boolean",affectsEmit:!0,category:e.Diagnostics.Advanced_Options,description:e.Diagnostics.Do_not_erase_const_enum_declarations_in_generated_code},{name:"declarationDir",type:"string",affectsEmit:!0,isFilePath:!0,paramType:e.Diagnostics.DIRECTORY,category:e.Diagnostics.Advanced_Options,description:e.Diagnostics.Output_directory_for_generated_declaration_files,transpileOptionValue:void 0},{name:"skipLibCheck",type:"boolean",category:e.Diagnostics.Advanced_Options,description:e.Diagnostics.Skip_type_checking_of_declaration_files},{name:"allowUnusedLabels",type:"boolean",affectsBindDiagnostics:!0,affectsSemanticDiagnostics:!0,category:e.Diagnostics.Advanced_Options,description:e.Diagnostics.Do_not_report_errors_on_unused_labels},{name:"allowUnreachableCode",type:"boolean",affectsBindDiagnostics:!0,affectsSemanticDiagnostics:!0,category:e.Diagnostics.Advanced_Options,description:e.Diagnostics.Do_not_report_errors_on_unreachable_code},{name:"suppressExcessPropertyErrors",type:"boolean",affectsSemanticDiagnostics:!0,category:e.Diagnostics.Advanced_Options,description:e.Diagnostics.Suppress_excess_property_checks_for_object_literals},{name:"suppressImplicitAnyIndexErrors",type:"boolean",affectsSemanticDiagnostics:!0,category:e.Diagnostics.Advanced_Options,description:e.Diagnostics.Suppress_noImplicitAny_errors_for_indexing_objects_lacking_index_signatures},{name:"forceConsistentCasingInFileNames",type:"boolean",affectsModuleResolution:!0,category:e.Diagnostics.Advanced_Options,description:e.Diagnostics.Disallow_inconsistently_cased_references_to_the_same_file},{name:"maxNodeModuleJsDepth",type:"number",affectsModuleResolution:!0,category:e.Diagnostics.Advanced_Options,description:e.Diagnostics.The_maximum_dependency_depth_to_search_under_node_modules_and_load_JavaScript_files},{name:"noStrictGenericChecks",type:"boolean",affectsSemanticDiagnostics:!0,category:e.Diagnostics.Advanced_Options,description:e.Diagnostics.Disable_strict_checking_of_generic_signatures_in_function_types},{name:"useDefineForClassFields",type:"boolean",affectsSemanticDiagnostics:!0,affectsEmit:!0,category:e.Diagnostics.Advanced_Options,description:e.Diagnostics.Emit_class_fields_with_Define_instead_of_Set},{name:"keyofStringsOnly",type:"boolean",category:e.Diagnostics.Advanced_Options,description:e.Diagnostics.Resolve_keyof_to_string_valued_property_names_only_no_numbers_or_symbols},{name:"plugins",type:"list",isTSConfigOnly:!0,element:{name:"plugin",type:"object"},description:e.Diagnostics.List_of_language_service_plugins}];e.optionDeclarations=i(i([],e.commonOptionsWithBuild),r),e.semanticDiagnosticsOptionDeclarations=e.optionDeclarations.filter((function(e){return!!e.affectsSemanticDiagnostics})),e.affectsEmitOptionDeclarations=e.optionDeclarations.filter((function(e){return!!e.affectsEmit})),e.moduleResolutionOptionDeclarations=e.optionDeclarations.filter((function(e){return!!e.affectsModuleResolution})),e.sourceFileAffectingCompilerOptions=e.optionDeclarations.filter((function(e){return!!e.affectsSourceFile||!!e.affectsModuleResolution||!!e.affectsBindDiagnostics})),e.transpileOptionValueCompilerOptions=e.optionDeclarations.filter((function(n){return e.hasProperty(n,"transpileOptionValue")}));var a,s=[{name:"verbose",shortName:"v",category:e.Diagnostics.Command_line_Options,description:e.Diagnostics.Enable_verbose_logging,type:"boolean"},{name:"dry",shortName:"d",category:e.Diagnostics.Command_line_Options,description:e.Diagnostics.Show_what_would_be_built_or_deleted_if_specified_with_clean,type:"boolean"},{name:"force",shortName:"f",category:e.Diagnostics.Command_line_Options,description:e.Diagnostics.Build_all_projects_including_those_that_appear_to_be_up_to_date,type:"boolean"},{name:"clean",category:e.Diagnostics.Command_line_Options,description:e.Diagnostics.Delete_the_outputs_of_all_projects,type:"boolean"}];function c(n){var t=new e.Map,r=new e.Map;return e.forEach(n,(function(e){t.set(e.name.toLowerCase(),e),e.shortName&&r.set(e.shortName,e.name)})),{optionsNameMap:t,shortOptionNames:r}}function l(){return a||(a=c(e.optionDeclarations))}e.buildOpts=i(i([],e.commonOptionsWithBuild),s),e.typeAcquisitionDeclarations=[{name:"enableAutoDiscovery",type:"boolean"},{name:"enable",type:"boolean"},{name:"include",type:"list",element:{name:"include",type:"string"}},{name:"exclude",type:"list",element:{name:"exclude",type:"string"}},{name:"disableFilenameBasedTypeAcquisition",type:"boolean"}],e.createOptionNameMap=c,e.getOptionsNameMap=l;var u,d={diagnostic:e.Diagnostics.Compiler_option_0_may_only_be_used_with_build,getOptionsNameMap:x};function p(e){return e&&void 0!==e.enableAutoDiscovery&&void 0===e.enable?{enable:e.enableAutoDiscovery,include:e.include||[],exclude:e.exclude||[]}:e}function f(n){return m(n,e.createCompilerDiagnostic)}function m(n,t){var r=e.arrayFrom(n.type.keys()).map((function(e){return"'"+e+"'"})).join(", ");return t(e.Diagnostics.Argument_for_0_option_must_be_Colon_1,"--"+n.name,r)}function _(e,n,t){return Ue(e,je(n||""),t)}function g(n,t,r){if(void 0===t&&(t=""),t=je(t),!e.startsWith(t,"-")){if(""===t)return[];var a=t.split(",");switch(n.element.type){case"number":return e.mapDefined(a,(function(e){return Be(n.element,parseInt(e),r)}));case"string":return e.mapDefined(a,(function(e){return Be(n.element,e||"",r)}));default:return e.mapDefined(a,(function(e){return _(n.element,e,r)}))}}}function y(e){return e.name}function h(n,t,r,a){var i;if(null===(i=t.alternateMode)||void 0===i?void 0:i.getOptionsNameMap().optionsNameMap.has(n.toLowerCase()))return r(t.alternateMode.diagnostic,n);var o=e.getSpellingSuggestion(n,t.optionDeclarations,y);return o?r(t.unknownDidYouMeanDiagnostic,a||n,o.name):r(t.unknownOptionDiagnostic,a||n)}function v(n,t,r){var a,i={},o=[],s=[];return c(t),{options:i,watchOptions:a,fileNames:o,errors:s};function c(t){var r=0;while(r<t.length){var c=t[r];if(r++,64===c.charCodeAt(0))l(c.slice(1));else if(45===c.charCodeAt(0)){var u=c.slice(45===c.charCodeAt(1)?2:1),d=S(n.getOptionsNameMap,u,!0);if(d)r=b(t,r,n,d,i,s);else{var p=S(j.getOptionsNameMap,u,!0);p?r=b(t,r,j,p,a||(a={}),s):s.push(h(u,n,e.createCompilerDiagnostic,c))}}else o.push(c)}}function l(n){var t=O(n,r||function(n){return e.sys.readFile(n)});if(e.isString(t)){var a=[],i=0;while(1){while(i<t.length&&t.charCodeAt(i)<=32)i++;if(i>=t.length)break;var o=i;if(34===t.charCodeAt(o)){i++;while(i<t.length&&34!==t.charCodeAt(i))i++;i<t.length?(a.push(t.substring(o+1,i)),i++):s.push(e.createCompilerDiagnostic(e.Diagnostics.Unterminated_quoted_string_in_response_file_0,n))}else{while(t.charCodeAt(i)>32)i++;a.push(t.substring(o,i))}}c(a)}else s.push(t)}}function b(n,t,r,a,i,o){if(a.isTSConfigOnly){var s=n[t];"null"===s?(i[a.name]=void 0,t++):"boolean"===a.type?"false"===s?(i[a.name]=Be(a,!1,o),t++):("true"===s&&t++,o.push(e.createCompilerDiagnostic(e.Diagnostics.Option_0_can_only_be_specified_in_tsconfig_json_file_or_set_to_false_or_null_on_command_line,a.name))):(o.push(e.createCompilerDiagnostic(e.Diagnostics.Option_0_can_only_be_specified_in_tsconfig_json_file_or_set_to_null_on_command_line,a.name)),s&&!e.startsWith(s,"-")&&t++)}else if(n[t]||"boolean"===a.type||o.push(e.createCompilerDiagnostic(r.optionTypeMismatchDiagnostic,a.name,Y(a))),"null"!==n[t])switch(a.type){case"number":i[a.name]=Be(a,parseInt(n[t]),o),t++;break;case"boolean":s=n[t];i[a.name]=Be(a,"false"!==s,o),"false"!==s&&"true"!==s||t++;break;case"string":i[a.name]=Be(a,n[t]||"",o),t++;break;case"list":var c=g(a,n[t],o);i[a.name]=c||[],c&&t++;break;default:i[a.name]=_(a,n[t],o),t++;break}else i[a.name]=void 0,t++;return t}function E(n,t){return v(e.compilerOptionsDidYouMeanDiagnostics,n,t)}function T(e,n){return S(l,e,n)}function S(e,n,t){void 0===t&&(t=!1),n=n.toLowerCase();var r=e(),a=r.optionsNameMap,i=r.shortOptionNames;if(t){var o=i.get(n);void 0!==o&&(n=o)}return a.get(n)}function x(){return u||(u=c(e.buildOpts))}e.defaultInitCompilerOptions={module:e.ModuleKind.CommonJS,target:1,strict:!0,esModuleInterop:!0,forceConsistentCasingInFileNames:!0,skipLibCheck:!0},e.convertEnableAutoDiscoveryToEnable=p,e.createCompilerDiagnosticForInvalidCustomType=f,e.parseCustomTypeOption=_,e.parseListTypeOption=g,e.parseCommandLineWorker=v,e.compilerOptionsDidYouMeanDiagnostics={alternateMode:d,getOptionsNameMap:l,optionDeclarations:e.optionDeclarations,unknownOptionDiagnostic:e.Diagnostics.Unknown_compiler_option_0,unknownDidYouMeanDiagnostic:e.Diagnostics.Unknown_compiler_option_0_Did_you_mean_1,optionTypeMismatchDiagnostic:e.Diagnostics.Compiler_option_0_expects_an_argument},e.parseCommandLine=E,e.getOptionFromName=T;var L={diagnostic:e.Diagnostics.Compiler_option_0_may_not_be_used_with_build,getOptionsNameMap:l},D={alternateMode:L,getOptionsNameMap:x,optionDeclarations:e.buildOpts,unknownOptionDiagnostic:e.Diagnostics.Unknown_build_option_0,unknownDidYouMeanDiagnostic:e.Diagnostics.Unknown_build_option_0_Did_you_mean_1,optionTypeMismatchDiagnostic:e.Diagnostics.Build_option_0_requires_a_value_of_type_1};function A(n){var t=v(D,n),r=t.options,a=t.watchOptions,i=t.fileNames,o=t.errors,s=r;return 0===i.length&&i.push("."),s.clean&&s.force&&o.push(e.createCompilerDiagnostic(e.Diagnostics.Options_0_and_1_cannot_be_combined,"clean","force")),s.clean&&s.verbose&&o.push(e.createCompilerDiagnostic(e.Diagnostics.Options_0_and_1_cannot_be_combined,"clean","verbose")),s.clean&&s.watch&&o.push(e.createCompilerDiagnostic(e.Diagnostics.Options_0_and_1_cannot_be_combined,"clean","watch")),s.watch&&s.dry&&o.push(e.createCompilerDiagnostic(e.Diagnostics.Options_0_and_1_cannot_be_combined,"watch","dry")),{buildOptions:s,watchOptions:a,projects:i,errors:o}}function C(n){for(var t=[],r=1;r<arguments.length;r++)t[r-1]=arguments[r];var a=e.createCompilerDiagnostic.apply(void 0,arguments);return a.messageText}function I(n,t,r,a,i,o){var s=O(n,(function(e){return r.readFile(e)}));if(e.isString(s)){var c=e.parseJsonText(n,s),l=r.getCurrentDirectory();return c.path=e.toPath(n,l,e.createGetCanonicalFileName(r.useCaseSensitiveFileNames)),c.resolvedPath=c.path,c.originalFileName=c.fileName,de(c,r,e.getNormalizedAbsolutePath(e.getDirectoryPath(n),l),t,e.getNormalizedAbsolutePath(n,l),void 0,o,a,i)}r.onUnRecoverableConfigFileDiagnostic(s)}function N(n,t){var r=O(n,t);return e.isString(r)?k(n,r):{config:{},error:r}}function k(n,t){var r=e.parseJsonText(n,t);return{config:q(r,r.parseDiagnostics,!1,void 0),error:r.parseDiagnostics.length?r.parseDiagnostics[0]:void 0}}function R(n,t){var r=O(n,t);return e.isString(r)?e.parseJsonText(n,r):{fileName:n,parseDiagnostics:[r]}}function O(n,t){var r;try{r=t(n)}catch(a){return e.createCompilerDiagnostic(e.Diagnostics.Cannot_read_file_0_Colon_1,n,a.message)}return void 0===r?e.createCompilerDiagnostic(e.Diagnostics.Cannot_read_file_0,n):r}function w(n){return e.arrayToMap(n,y)}e.parseBuildCommand=A,e.getDiagnosticText=C,e.getParsedCommandLineOfConfigFile=I,e.readConfigFile=N,e.parseConfigFileTextToJson=k,e.readJsonConfigFile=R,e.tryReadFile=O;var P,M={optionDeclarations:e.typeAcquisitionDeclarations,unknownOptionDiagnostic:e.Diagnostics.Unknown_type_acquisition_option_0,unknownDidYouMeanDiagnostic:e.Diagnostics.Unknown_type_acquisition_option_0_Did_you_mean_1};function F(){return P||(P=c(e.optionsForWatch))}var G,B,U,V,j={getOptionsNameMap:F,optionDeclarations:e.optionsForWatch,unknownOptionDiagnostic:e.Diagnostics.Unknown_watch_option_0,unknownDidYouMeanDiagnostic:e.Diagnostics.Unknown_watch_option_0_Did_you_mean_1,optionTypeMismatchDiagnostic:e.Diagnostics.Watch_option_0_requires_a_value_of_type_1};function K(){return G||(G=w(e.optionDeclarations))}function H(){return B||(B=w(e.optionsForWatch))}function W(){return U||(U=w(e.typeAcquisitionDeclarations))}function z(){return void 0===V&&(V={name:void 0,type:"object",elementOptions:w([{name:"compilerOptions",type:"object",elementOptions:K(),extraKeyDiagnostics:e.compilerOptionsDidYouMeanDiagnostics},{name:"watchOptions",type:"object",elementOptions:H(),extraKeyDiagnostics:j},{name:"typingOptions",type:"object",elementOptions:W(),extraKeyDiagnostics:M},{name:"typeAcquisition",type:"object",elementOptions:W(),extraKeyDiagnostics:M},{name:"extends",type:"string"},{name:"references",type:"list",element:{name:"references",type:"object"}},{name:"files",type:"list",element:{name:"files",type:"string"}},{name:"include",type:"list",element:{name:"include",type:"string"}},{name:"exclude",type:"list",element:{name:"exclude",type:"string"}},e.compileOnSaveCommandLineOption])}),V}function q(n,t,r,a){var i,o=null===(i=n.statements[0])||void 0===i?void 0:i.expression,s=r?z():void 0;if(o&&201!==o.kind){if(t.push(e.createDiagnosticForNodeInSourceFile(n,o,e.Diagnostics.The_root_value_of_a_0_file_must_be_an_object,"jsconfig.json"===e.getBaseFileName(n.fileName)?"jsconfig.json":"tsconfig.json")),e.isArrayLiteralExpression(o)){var c=e.find(o.elements,e.isObjectLiteralExpression);if(c)return X(n,c,t,!0,s,a)}return{}}return X(n,o,t,!0,s,a)}function J(e,n){var t;return X(e,null===(t=e.statements[0])||void 0===t?void 0:t.expression,n,!0,void 0,void 0)}function X(n,t,r,a,o,s){return t?d(t,o):a?{}:void 0;function c(e){return o&&o.elementOptions===e}function l(t,i,o,l){for(var u=a?{}:void 0,f=function(t){if(289!==t.kind)return r.push(e.createDiagnosticForNodeInSourceFile(n,t,e.Diagnostics.Property_assignment_expected)),"continue";t.questionToken&&r.push(e.createDiagnosticForNodeInSourceFile(n,t.questionToken,e.Diagnostics.The_0_modifier_can_only_be_used_in_TypeScript_files,"?")),p(t.name)||r.push(e.createDiagnosticForNodeInSourceFile(n,t.name,e.Diagnostics.String_literal_with_double_quotes_expected));var f=e.isComputedNonLiteralName(t.name)?void 0:e.getTextOfPropertyName(t.name),m=f&&e.unescapeLeadingUnderscores(f),_=m&&i?i.get(m):void 0;m&&o&&!_&&(i?r.push(h(m,o,(function(r,a,i){return e.createDiagnosticForNodeInSourceFile(n,t.name,r,a,i)}))):r.push(e.createDiagnosticForNodeInSourceFile(n,t.name,o.unknownOptionDiagnostic,m)));var g=d(t.initializer,_);if("undefined"!==typeof m&&(a&&(u[m]=g),s&&(l||c(i)))){var y=Q(_,g);l?y&&s.onSetValidOptionKeyValueInParent(l,_,g):c(i)&&(y?s.onSetValidOptionKeyValueInRoot(m,t.name,g,t.initializer):_||s.onSetUnknownOptionKeyValueInRoot(m,t.name,g,t.initializer))}},m=0,_=t.properties;m<_.length;m++){var g=_[m];f(g)}return u}function u(n,t){if(a)return e.filter(n.map((function(e){return d(e,t)})),(function(e){return void 0!==e}));n.forEach((function(e){return d(e,t)}))}function d(t,a){var o;switch(t.kind){case 109:return v(a&&"boolean"!==a.type),h(!0);case 94:return v(a&&"boolean"!==a.type),h(!1);case 103:return v(a&&"extends"===a.name),h(null);case 10:p(t)||r.push(e.createDiagnosticForNodeInSourceFile(n,t,e.Diagnostics.String_literal_with_double_quotes_expected)),v(a&&e.isString(a.type)&&"string"!==a.type);var s=t.text;if(a&&!e.isString(a.type)){var c=a;c.type.has(s.toLowerCase())||(r.push(m(c,(function(r,a,i){return e.createDiagnosticForNodeInSourceFile(n,t,r,a,i)}))),o=!0)}return h(s);case 8:return v(a&&"number"!==a.type),h(Number(t.text));case 215:if(40!==t.operator||8!==t.operand.kind)break;return v(a&&"number"!==a.type),h(-Number(t.operand.text));case 201:v(a&&"object"!==a.type);var d=t;if(a){var f=a,_=f.elementOptions,g=f.extraKeyDiagnostics,y=f.name;return h(l(d,_,g,y))}return h(l(d,void 0,void 0,void 0));case 200:return v(a&&"list"!==a.type),h(u(t.elements,a&&a.element))}return void(a?v(!0):r.push(e.createDiagnosticForNodeInSourceFile(n,t,e.Diagnostics.Property_value_can_only_be_string_literal_numeric_literal_true_false_null_object_literal_or_array_literal)));function h(s){var c;if(!o){var l=null===(c=null===a||void 0===a?void 0:a.extraValidation)||void 0===c?void 0:c.call(a,s);if(l)return void r.push(e.createDiagnosticForNodeInSourceFile.apply(void 0,i([n,t],l)))}return s}function v(i){i&&(r.push(e.createDiagnosticForNodeInSourceFile(n,t,e.Diagnostics.Compiler_option_0_requires_a_value_of_type_1,a.name,Y(a))),o=!0)}}function p(t){return e.isStringLiteral(t)&&e.isStringDoubleQuoted(t,n)}}function Y(n){return"list"===n.type?"Array":e.isString(n.type)?n.type:"string"}function Q(n,t){if(n){if(fe(t))return!0;if("list"===n.type)return e.isArray(t);var r=e.isString(n.type)?n.type:"string";return typeof t===r}return!1}function Z(n,t,r){var a,i,s,c=e.createGetCanonicalFileName(r.useCaseSensitiveFileNames),l=e.map(e.filter(n.fileNames,(null===(i=null===(a=n.options.configFile)||void 0===a?void 0:a.configFileSpecs)||void 0===i?void 0:i.validatedIncludeSpecs)?ne(t,n.options.configFile.configFileSpecs.validatedIncludeSpecs,n.options.configFile.configFileSpecs.validatedExcludeSpecs,r):e.returnTrue),(function(n){return e.getRelativePathFromFile(e.getNormalizedAbsolutePath(t,r.getCurrentDirectory()),e.getNormalizedAbsolutePath(n,r.getCurrentDirectory()),c)})),u=ae(n.options,{configFilePath:e.getNormalizedAbsolutePath(t,r.getCurrentDirectory()),useCaseSensitiveFileNames:r.useCaseSensitiveFileNames}),d=n.watchOptions&&ie(n.watchOptions),p=o(o({compilerOptions:o(o({},$(u)),{showConfig:void 0,configFile:void 0,configFilePath:void 0,help:void 0,init:void 0,listFiles:void 0,listEmittedFiles:void 0,project:void 0,build:void 0,version:void 0}),watchOptions:d&&$(d),references:e.map(n.projectReferences,(function(e){return o(o({},e),{path:e.originalPath?e.originalPath:"",originalPath:void 0})})),files:e.length(l)?l:void 0},(null===(s=n.options.configFile)||void 0===s?void 0:s.configFileSpecs)?{include:ee(n.options.configFile.configFileSpecs.validatedIncludeSpecs),exclude:n.options.configFile.configFileSpecs.validatedExcludeSpecs}:{}),{compileOnSave:!!n.compileOnSave||void 0});return p}function $(n){return o({},e.arrayFrom(n.entries()).reduce((function(e,n){var t;return o(o({},e),(t={},t[n[0]]=n[1],t))}),{}))}function ee(n){if(e.length(n)){if(1!==e.length(n))return n;if("**/*"!==n[0])return n}}function ne(n,t,r,a){if(!t)return e.returnTrue;var i=e.getFileMatcherPatterns(n,r,t,a.useCaseSensitiveFileNames,a.getCurrentDirectory()),o=i.excludePattern&&e.getRegexFromPattern(i.excludePattern,a.useCaseSensitiveFileNames),s=i.includeFilePattern&&e.getRegexFromPattern(i.includeFilePattern,a.useCaseSensitiveFileNames);return s?o?function(e){return!(s.test(e)&&!o.test(e))}:function(e){return!s.test(e)}:o?function(e){return o.test(e)}:e.returnTrue}function te(e){return"string"===e.type||"number"===e.type||"boolean"===e.type||"object"===e.type?void 0:"list"===e.type?te(e.element):e.type}function re(n,t){return e.forEachEntry(t,(function(e,t){if(e===n)return t}))}function ae(e,n){return oe(e,l(),n)}function ie(e){return oe(e,F())}function oe(n,t,r){var a=t.optionsNameMap,i=new e.Map,o=r&&e.createGetCanonicalFileName(r.useCaseSensitiveFileNames),s=function(t){if(e.hasProperty(n,t)){if(a.has(t)&&a.get(t).category===e.Diagnostics.Command_line_Options)return"continue";var s=n[t],c=a.get(t.toLowerCase());if(c){var l=te(c);l?"list"===c.type?i.set(t,s.map((function(e){return re(e,l)}))):i.set(t,re(s,l)):r&&c.isFilePath?i.set(t,e.getRelativePathFromFile(r.configFilePath,e.getNormalizedAbsolutePath(s,e.getDirectoryPath(r.configFilePath)),o)):i.set(t,s)}}};for(var c in n)s(c);return i}function se(n,t,r){var a=e.extend(n,e.defaultInitCompilerOptions),i=ae(a);return l();function o(n){switch(n.type){case"number":return 1;case"boolean":return!0;case"string":return n.isFilePath?"./":"";case"list":return[];case"object":return{};default:var t=n.type.keys().next();return t.done?e.Debug.fail("Expected 'option.type' to have entries."):t.value}}function s(e){return Array(e+1).join(" ")}function c(n){var t=n.category,r=n.name;return void 0!==t&&t!==e.Diagnostics.Command_line_Options&&(t!==e.Diagnostics.Advanced_Options||i.has(r))}function l(){for(var n=e.createMultiMap(),a=0,l=e.optionDeclarations;a<l.length;a++){var u=l[a],d=u.category;c(u)&&n.add(e.getLocaleSpecificMessage(d),u)}var p=0,f=0,m=[];n.forEach((function(n,t){0!==m.length&&m.push({value:""}),m.push({value:"/* "+t+" */"});for(var r=0,a=n;r<a.length;r++){var s=a[r],c=void 0;c=i.has(s.name)?'"'+s.name+'": '+JSON.stringify(i.get(s.name))+((f+=1)===i.size?"":","):'// "'+s.name+'": '+JSON.stringify(o(s))+",",m.push({value:c,description:"/* "+(s.description&&e.getLocaleSpecificMessage(s.description)||s.name)+" */"}),p=Math.max(c.length,p)}}));var _=s(2),g=[];g.push("{"),g.push(_+'"compilerOptions": {'),g.push(""+_+_+"/* "+e.getLocaleSpecificMessage(e.Diagnostics.Visit_https_Colon_Slash_Slashaka_ms_Slashtsconfig_json_to_read_more_about_this_file)+" */"),g.push("");for(var y=0,h=m;y<h.length;y++){var v=h[y],b=v.value,E=v.description,T=void 0===E?"":E;g.push(b&&""+_+_+b+(T&&s(p-b.length+2)+T))}if(t.length){g.push(_+"},"),g.push(_+'"files": [');for(var S=0;S<t.length;S++)g.push(""+_+_+JSON.stringify(t[S])+(S===t.length-1?"":","));g.push(_+"]")}else g.push(_+"}");return g.push("}"),g.join(r)+r}}function ce(n,t){var r={},a=l().optionsNameMap;for(var i in n)e.hasProperty(n,i)&&(r[i]=le(a.get(i.toLowerCase()),n[i],t));return r.configFilePath&&(r.configFilePath=t(r.configFilePath)),r}function le(e,n,t){if(e&&!fe(n))if("list"===e.type){var r=n;if(e.element.isFilePath&&r.length)return r.map(t)}else if(e.isFilePath)return t(n);return n}function ue(e,n,t,r,a,i,o,s,c){return _e(e,void 0,n,t,r,c,a,i,o,s)}function de(e,n,t,r,a,i,o,s,c){return _e(void 0,e,n,t,r,c,a,i,o,s)}function pe(e,n){n&&Object.defineProperty(e,"configFile",{enumerable:!1,writable:!1,value:n})}function fe(e){return void 0===e||null===e}function me(n,t){return e.getDirectoryPath(e.getNormalizedAbsolutePath(n,t))}function _e(n,t,r,a,i,o,s,c,l,u){void 0===i&&(i={}),void 0===c&&(c=[]),void 0===l&&(l=[]),e.Debug.assert(void 0===n&&void 0!==t||void 0!==n&&void 0===t);var d=[],p=Te(n,t,r,a,s,c,d,u),f=p.raw,m=e.extend(i,p.options||{}),_=o&&p.watchOptions?e.extend(o,p.watchOptions):p.watchOptions||o;m.configFilePath=s&&e.normalizeSlashes(s);var g=h();t&&(t.configFileSpecs=g),pe(m,t);var y=e.normalizePath(s?me(s,a):a);return{options:m,watchOptions:_,fileNames:v(y),projectReferences:b(y),typeAcquisition:p.typeAcquisition||Re(),raw:f,errors:d,wildcardDirectories:$e(g,y,r.useCaseSensitiveFileNames),compileOnSave:!!f.compileOnSave};function h(){var n=S("references",(function(e){return"object"===typeof e}),"object"),r=E(T("files"));if(r){var a="no-prop"===n||e.isArray(n)&&0===n.length,i=e.hasProperty(f,"extends");if(0===r.length&&a&&!i)if(t){var o=s||"tsconfig.json",c=e.Diagnostics.The_files_list_in_config_file_0_is_empty,l=e.firstDefined(e.getTsConfigPropArray(t,"files"),(function(e){return e.initializer})),u=l?e.createDiagnosticForNodeInSourceFile(t,l,c,o):e.createCompilerDiagnostic(c,o);d.push(u)}else x(e.Diagnostics.The_files_list_in_config_file_0_is_empty,s||"tsconfig.json")}var p,m,_=E(T("include")),g=T("exclude"),y=E(g);if("no-prop"===g&&f.compilerOptions){var h=f.compilerOptions.outDir,v=f.compilerOptions.declarationDir;(h||v)&&(y=[h,v].filter((function(e){return!!e})))}return void 0===r&&void 0===_&&(_=["**/*"]),_&&(p=Qe(_,d,!0,t,"include")),y&&(m=Qe(y,d,!1,t,"exclude")),{filesSpecs:r,includeSpecs:_,excludeSpecs:y,validatedFilesSpec:e.filter(r,e.isString),validatedIncludeSpecs:p,validatedExcludeSpecs:m}}function v(e){var n=qe(g,e,m,r,l);return he(n,ve(f),c)&&d.push(ye(g,s)),n}function b(n){var t,r=S("references",(function(e){return"object"===typeof e}),"object");if(e.isArray(r))for(var a=0,i=r;a<i.length;a++){var o=i[a];"string"!==typeof o.path?x(e.Diagnostics.Compiler_option_0_requires_a_value_of_type_1,"reference.path","string"):(t||(t=[])).push({path:e.getNormalizedAbsolutePath(o.path,n),originalPath:o.path,prepend:o.prepend,circular:o.circular})}return t}function E(n){return e.isArray(n)?n:void 0}function T(n){return S(n,e.isString,"string")}function S(n,r,a){if(e.hasProperty(f,n)&&!fe(f[n])){if(e.isArray(f[n])){var i=f[n];return t||e.every(i,r)||d.push(e.createCompilerDiagnostic(e.Diagnostics.Compiler_option_0_requires_a_value_of_type_1,n,a)),i}return x(e.Diagnostics.Compiler_option_0_requires_a_value_of_type_1,n,"Array"),"not-array"}return"no-prop"}function x(n,r,a){t||d.push(e.createCompilerDiagnostic(n,r,a))}}function ge(n){return n.code===e.Diagnostics.No_inputs_were_found_in_config_file_0_Specified_include_paths_were_1_and_exclude_paths_were_2.code}function ye(n,t){var r=n.includeSpecs,a=n.excludeSpecs;return e.createCompilerDiagnostic(e.Diagnostics.No_inputs_were_found_in_config_file_0_Specified_include_paths_were_1_and_exclude_paths_were_2,t||"tsconfig.json",JSON.stringify(r||[]),JSON.stringify(a||[]))}function he(e,n,t){return 0===e.length&&n&&(!t||0===t.length)}function ve(n){return!e.hasProperty(n,"files")&&!e.hasProperty(n,"references")}function be(n,t,r,a,i){var o=a.length;return he(n,i)?a.push(ye(r,t)):e.filterMutate(a,(function(e){return!ge(e)})),o!==a.length}function Ee(e){return!!e.options}function Te(n,t,r,a,o,s,c,l){var u;a=e.normalizeSlashes(a);var d=e.getNormalizedAbsolutePath(o||"",a);if(s.indexOf(d)>=0)return c.push(e.createCompilerDiagnostic(e.Diagnostics.Circularity_detected_while_resolving_configuration_Colon_0,i(i([],s),[d]).join(" -> "))),{raw:n||J(t,c)};var p=n?Se(n,r,a,o,c):xe(t,r,a,o,c);if((null===(u=p.options)||void 0===u?void 0:u.paths)&&(p.options.pathsBasePath=a),p.extendedConfigPath){s=s.concat([d]);var f=De(t,p.extendedConfigPath,r,s,c,l);if(f&&Ee(f)){var m,_=f.raw,g=p.raw,y=function(n){!g[n]&&_[n]&&(g[n]=e.map(_[n],(function(n){return e.isRootedDiskPath(n)?n:e.combinePaths(m||(m=e.convertToRelativePath(e.getDirectoryPath(p.extendedConfigPath),a,e.createGetCanonicalFileName(r.useCaseSensitiveFileNames))),n)})))};y("include"),y("exclude"),y("files"),void 0===g.compileOnSave&&(g.compileOnSave=_.compileOnSave),p.options=e.assign({},f.options,p.options),p.watchOptions=p.watchOptions&&f.watchOptions?e.assign({},f.watchOptions,p.watchOptions):p.watchOptions||f.watchOptions}}return p}function Se(n,t,r,a,i){e.hasProperty(n,"excludes")&&i.push(e.createCompilerDiagnostic(e.Diagnostics.Unknown_option_excludes_Did_you_mean_exclude));var o,s=ke(n.compilerOptions,r,i,a),c=Oe(n.typeAcquisition||n.typingOptions,r,i,a),l=we(n.watchOptions,r,i);if(n.compileOnSave=Ae(n,r,i),n.extends)if(e.isString(n.extends)){var u=a?me(a,r):r;o=Le(n.extends,t,u,i,e.createCompilerDiagnostic)}else i.push(e.createCompilerDiagnostic(e.Diagnostics.Compiler_option_0_requires_a_value_of_type_1,"extends","string"));return{raw:n,options:s,watchOptions:l,typeAcquisition:c,extendedConfigPath:o}}function xe(n,t,r,a,i){var o,s,c,l,u=Ne(a),d={onSetValidOptionKeyValueInParent:function(n,t,i){var l;switch(n){case"compilerOptions":l=u;break;case"watchOptions":l=c||(c={});break;case"typeAcquisition":l=o||(o=Re(a));break;case"typingOptions":l=s||(s=Re(a));break;default:e.Debug.fail("Unknown option")}l[t.name]=Fe(t,r,i)},onSetValidOptionKeyValueInRoot:function(o,s,c,u){switch(o){case"extends":var d=a?me(a,r):r;return void(l=Le(c,t,d,i,(function(t,r){return e.createDiagnosticForNodeInSourceFile(n,u,t,r)})))}},onSetUnknownOptionKeyValueInRoot:function(t,r,a,o){"excludes"===t&&i.push(e.createDiagnosticForNodeInSourceFile(n,r,e.Diagnostics.Unknown_option_excludes_Did_you_mean_exclude))}},p=q(n,i,!0,d);return o||(o=s?void 0!==s.enableAutoDiscovery?{enable:s.enableAutoDiscovery,include:s.include,exclude:s.exclude}:s:Re(a)),{raw:p,options:u,watchOptions:c,typeAcquisition:o,extendedConfigPath:l}}function Le(n,t,r,a,i){if(n=e.normalizeSlashes(n),e.isRootedDiskPath(n)||e.startsWith(n,"./")||e.startsWith(n,"../")){var o=e.getNormalizedAbsolutePath(n,r);return t.fileExists(o)||e.endsWith(o,".json")||(o+=".json",t.fileExists(o))?o:void a.push(i(e.Diagnostics.File_0_not_found,n))}var s=e.nodeModuleNameResolver(n,e.combinePaths(r,"tsconfig.json"),{moduleResolution:e.ModuleResolutionKind.NodeJs},t,void 0,void 0,!0);if(s.resolvedModule)return s.resolvedModule.resolvedFileName;a.push(i(e.Diagnostics.File_0_not_found,n))}function De(n,t,r,a,i,o){var s,c,l,u,d=r.useCaseSensitiveFileNames?t:e.toFileNameLowerCase(t);if(o&&(c=o.get(d))?(l=c.extendedResult,u=c.extendedConfig):(l=R(t,(function(e){return r.readFile(e)})),l.parseDiagnostics.length||(u=Te(void 0,l,r,e.getDirectoryPath(t),e.getBaseFileName(t),a,i,o)),o&&o.set(d,{extendedResult:l,extendedConfig:u})),n&&(n.extendedSourceFiles=[l.fileName],l.extendedSourceFiles&&(s=n.extendedSourceFiles).push.apply(s,l.extendedSourceFiles)),!l.parseDiagnostics.length)return u;i.push.apply(i,l.parseDiagnostics)}function Ae(n,t,r){if(!e.hasProperty(n,e.compileOnSaveCommandLineOption.name))return!1;var a=Me(e.compileOnSaveCommandLineOption,n.compileOnSave,t,r);return"boolean"===typeof a&&a}function Ce(e,n,t){var r=[],a=ke(e,n,r,t);return{options:a,errors:r}}function Ie(e,n,t){var r=[],a=Oe(e,n,r,t);return{options:a,errors:r}}function Ne(n){var t=n&&"jsconfig.json"===e.getBaseFileName(n)?{allowJs:!0,maxNodeModuleJsDepth:2,allowSyntheticDefaultImports:!0,skipLibCheck:!0,noEmit:!0}:{};return t}function ke(n,t,r,a){var i=Ne(a);return Pe(K(),n,t,i,e.compilerOptionsDidYouMeanDiagnostics,r),a&&(i.configFilePath=e.normalizeSlashes(a)),i}function Re(n){return{enable:!!n&&"jsconfig.json"===e.getBaseFileName(n),include:[],exclude:[]}}function Oe(e,n,t,r){var a=Re(r),i=p(e);return Pe(W(),i,n,a,M,t),a}function we(e,n,t){return Pe(H(),e,n,void 0,j,t)}function Pe(n,t,r,a,i,o){if(t){for(var s in t){var c=n.get(s);c?(a||(a={}))[c.name]=Me(c,t[s],r,o):o.push(h(s,i,e.createCompilerDiagnostic))}return a}}function Me(n,t,r,a){if(Q(n,t)){var i=n.type;if("list"===i&&e.isArray(t))return Ve(n,t,r,a);if(!e.isString(i))return Ue(n,t,a);var o=Be(n,t,a);return fe(o)?o:Ge(n,r,o)}a.push(e.createCompilerDiagnostic(e.Diagnostics.Compiler_option_0_requires_a_value_of_type_1,n.name,Y(n)))}function Fe(n,t,r){if(!fe(r)){if("list"===n.type){var a=n;return a.element.isFilePath||!e.isString(a.element.type)?e.filter(e.map(r,(function(e){return Fe(a.element,t,e)})),(function(e){return!!e})):r}return e.isString(n.type)?Ge(n,t,r):n.type.get(e.isString(r)?r.toLowerCase():r)}}function Ge(n,t,r){return n.isFilePath&&(r=e.getNormalizedAbsolutePath(r,t),""===r&&(r=".")),r}function Be(n,t,r){var a;if(!fe(t)){var i=null===(a=n.extraValidation)||void 0===a?void 0:a.call(n,t);if(!i)return t;r.push(e.createCompilerDiagnostic.apply(void 0,i))}}function Ue(e,n,t){if(!fe(n)){var r=n.toLowerCase(),a=e.type.get(r);if(void 0!==a)return Be(e,a,t);t.push(f(e))}}function Ve(n,t,r,a){return e.filter(e.map(t,(function(e){return Me(n.element,e,r,a)})),(function(e){return!!e}))}function je(e){return"function"===typeof e.trim?e.trim():e.replace(/^[\s]+|[\s]+$/g,"")}e.convertToObject=J,e.convertToObjectWorker=X,e.convertToTSConfig=Z,e.generateTSConfig=se,e.convertToOptionsWithAbsolutePaths=ce,e.parseJsonConfigFileContent=ue,e.parseJsonSourceFileConfigFileContent=de,e.setConfigFileInOptions=pe,e.canJsonReportNoInputFiles=ve,e.updateErrorForNoInputFiles=be,e.convertCompilerOptionsFromJson=Ce,e.convertTypeAcquisitionFromJson=Ie,e.convertJsonOption=Me;var Ke=/(^|\/)\*\*\/?$/,He=/(^|\/)\*\*\/(.*\/)?\.\.($|\/)/,We=/\/[^/]*?[*?][^/]*\//,ze=/^[^*?]*(?=\/[^/]*[*?])/;function qe(n,t,r,a,i){void 0===i&&(i=e.emptyArray),t=e.normalizePath(t);var o,s=e.createGetCanonicalFileName(a.useCaseSensitiveFileNames),c=new e.Map,l=new e.Map,u=new e.Map,d=n.validatedFilesSpec,p=n.validatedIncludeSpecs,f=n.validatedExcludeSpecs,m=e.getSupportedExtensions(r,i),_=e.getSuppoertedExtensionsWithJsonIfResolveJsonModule(r,m);if(d)for(var g=0,y=d;g<y.length;g++){var h=y[g],v=e.getNormalizedAbsolutePath(h,t);c.set(s(v),v)}if(p&&p.length>0)for(var b=function(n){if(e.fileExtensionIs(n,".json")){if(!o){var r=p.filter((function(n){return e.endsWith(n,".json")})),i=e.map(e.getRegularExpressionsForWildcards(r,t,"files"),(function(e){return"^"+e+"$"}));o=i?i.map((function(n){return e.getRegexFromPattern(n,a.useCaseSensitiveFileNames)})):e.emptyArray}var d=e.findIndex(o,(function(e){return e.test(n)}));if(-1!==d){var f=s(n);c.has(f)||u.has(f)||u.set(f,n)}return"continue"}if(nn(n,c,l,m,s))return"continue";tn(n,l,m,s);var _=s(n);c.has(_)||l.has(_)||l.set(_,n)},E=0,T=a.readDirectory(t,_,f,p,void 0);E<T.length;E++){v=T[E];b(v)}var S=e.arrayFrom(c.values()),x=e.arrayFrom(l.values());return S.concat(x,e.arrayFrom(u.values()))}function Je(n,t,r,a,i){var o=t.validatedFilesSpec,s=t.validatedIncludeSpecs,c=t.validatedExcludeSpecs;if(!e.length(s)||!e.length(c))return!1;r=e.normalizePath(r);var l=e.createGetCanonicalFileName(a);if(o)for(var u=0,d=o;u<d.length;u++){var p=d[u];if(l(e.getNormalizedAbsolutePath(p,r))===n)return!1}return Ye(n,c,a,i,r)}function Xe(n,t,r,a){return Ye(n,e.filter(t,(function(e){return!He.test(e)})),r,a)}function Ye(n,t,r,a,i){var o=e.getRegularExpressionForWildcard(t,e.combinePaths(e.normalizePath(a),i),"exclude"),s=o&&e.getRegexFromPattern(o,r);return!!s&&(!!s.test(n)||!e.hasExtension(n)&&s.test(e.ensureTrailingDirectorySeparator(n)))}function Qe(n,t,r,a,i){return n.filter((function(n){if(!e.isString(n))return!1;var a=Ze(n,r);return void 0!==a&&t.push(o.apply(void 0,a)),void 0===a}));function o(n,t){var r=e.getTsConfigPropArrayElementValue(a,i,t);return r?e.createDiagnosticForNodeInSourceFile(a,r,n,t):e.createCompilerDiagnostic(n,t)}}function Ze(n,t){return t&&Ke.test(n)?[e.Diagnostics.File_specification_cannot_end_in_a_recursive_directory_wildcard_Asterisk_Asterisk_Colon_0,n]:He.test(n)?[e.Diagnostics.File_specification_cannot_contain_a_parent_directory_that_appears_after_a_recursive_directory_wildcard_Asterisk_Asterisk_Colon_0,n]:void 0}function $e(n,t,r){var a=n.validatedIncludeSpecs,i=n.validatedExcludeSpecs,o=e.getRegularExpressionForWildcard(i,t,"exclude"),s=o&&new RegExp(o,r?"":"i"),c={};if(void 0!==a){for(var l=[],u=0,d=a;u<d.length;u++){var p=d[u],f=e.normalizePath(e.combinePaths(t,p));if(!s||!s.test(f)){var m=en(f,r);if(m){var _=m.key,g=m.flags,y=c[_];(void 0===y||y<g)&&(c[_]=g,1===g&&l.push(_))}}}for(var _ in c)if(e.hasProperty(c,_))for(var h=0,v=l;h<v.length;h++){var b=v[h];_!==b&&e.containsPath(b,_,t,!r)&&delete c[_]}}return c}function en(n,t){var r=ze.exec(n);return r?{key:t?r[0]:e.toFileNameLowerCase(r[0]),flags:We.test(n)?1:0}:e.isImplicitGlob(n)?{key:t?n:e.toFileNameLowerCase(n),flags:1}:void 0}function nn(n,t,r,a,i){for(var o=e.getExtensionPriority(n,a),s=e.adjustExtensionPriority(o,a),c=0;c<s;c++){var l=a[c],u=i(e.changeExtension(n,l));if(t.has(u)||r.has(u))return!0}return!1}function tn(n,t,r,a){for(var i=e.getExtensionPriority(n,r),o=e.getNextLowestExtensionPriority(i,r),s=o;s<r.length;s++){var c=r[s],l=a(e.changeExtension(n,c));t.delete(l)}}function rn(e){var n={};for(var t in e)if(e.hasOwnProperty(t)){var r=T(t);void 0!==r&&(n[t]=an(e[t],r))}return n}function an(n,t){switch(t.type){case"object":return"";case"string":return"";case"number":return"number"===typeof n?n:"";case"boolean":return"boolean"===typeof n?n:"";case"list":var r=t.element;return e.isArray(n)?n.map((function(e){return an(e,r)})):"";default:return e.forEachEntry(t.type,(function(e,t){if(e===n)return t}))}}e.getFileNamesFromConfigSpecs=qe,e.isExcludedFile=Je,e.matchesExclude=Xe,e.convertCompilerOptionsForTelemetry=rn}(d||(d={})),function(e){function n(n){n.trace(e.formatMessage.apply(void 0,arguments))}function t(e,n){return!!e.traceResolution&&void 0!==n.trace}function r(n,t){var r;if(t&&n){var a=n.packageJsonContent;"string"===typeof a.name&&"string"===typeof a.version&&(r={name:a.name,subModuleName:t.path.slice(n.packageDirectory.length+e.directorySeparator.length),version:a.version})}return t&&{path:t.path,extension:t.ext,packageId:r}}function a(e){return r(void 0,e)}function s(n){if(n)return e.Debug.assert(void 0===n.packageId),{path:n.path,ext:n.extension}}var c,l;function u(n){if(n)return e.Debug.assert(e.extensionIsTS(n.extension)),{fileName:n.path,packageId:n.packageId}}function d(e,n,t,r){var a;return r?((a=r.failedLookupLocations).push.apply(a,t),r):{resolvedModule:e&&{resolvedFileName:e.path,originalPath:!0===e.originalPath?void 0:e.originalPath,extension:e.extension,isExternalLibraryImport:n,packageId:e.packageId},failedLookupLocations:t}}function p(t,r,a,i){if(e.hasProperty(t,r)){var o=t[r];if(typeof o===a&&null!==o)return o;i.traceEnabled&&n(i.host,e.Diagnostics.Expected_type_of_0_field_in_package_json_to_be_1_got_2,r,a,null===o?"null":typeof o)}else i.traceEnabled&&n(i.host,e.Diagnostics.package_json_does_not_have_a_0_field,r)}function f(t,r,a,i){var o=p(t,r,"string",i);if(void 0!==o){if(o){var s=e.normalizePath(e.combinePaths(a,o));return i.traceEnabled&&n(i.host,e.Diagnostics.package_json_has_0_field_1_that_references_2,r,o,s),s}i.traceEnabled&&n(i.host,e.Diagnostics.package_json_had_a_falsy_0_field,r)}}function m(e,n,t){return f(e,"typings",n,t)||f(e,"types",n,t)}function _(e,n,t){return f(e,"tsconfig",n,t)}function g(e,n,t){return f(e,"main",n,t)}function y(t,r){var a=p(t,"typesVersions","object",r);if(void 0!==a)return r.traceEnabled&&n(r.host,e.Diagnostics.package_json_has_a_typesVersions_field_with_version_specific_path_mappings),a}function h(t,r){var a=y(t,r);if(void 0!==a){if(r.traceEnabled)for(var i in a)e.hasProperty(a,i)&&!e.VersionRange.tryParse(i)&&n(r.host,e.Diagnostics.package_json_has_a_typesVersions_entry_0_that_is_not_a_valid_semver_range,i);var o=v(a);if(o){var s=o.version,c=o.paths;if("object"===typeof c)return o;r.traceEnabled&&n(r.host,e.Diagnostics.Expected_type_of_0_field_in_package_json_to_be_1_got_2,"typesVersions['"+s+"']","object",typeof c)}else r.traceEnabled&&n(r.host,e.Diagnostics.package_json_does_not_have_a_typesVersions_entry_that_matches_version_0,e.versionMajorMinor)}}function v(n){for(var t in l||(l=new e.Version(e.version)),n)if(e.hasProperty(n,t)){var r=e.VersionRange.tryParse(t);if(void 0!==r&&r.test(l))return{version:t,paths:n[t]}}}function b(n,t){return n.typeRoots?n.typeRoots:(n.configFilePath?r=e.getDirectoryPath(n.configFilePath):t.getCurrentDirectory&&(r=t.getCurrentDirectory()),void 0!==r?E(r,t):void 0);var r}function E(n,t){return t.directoryExists?(e.forEachAncestorDirectory(e.normalizePath(n),(function(n){var a=e.combinePaths(n,T);t.directoryExists(a)&&(r||(r=[])).push(a)})),r):[e.combinePaths(n,T)];var r}e.trace=n,e.isTraceEnabled=t,function(e){e[e["TypeScript"]=0]="TypeScript",e[e["JavaScript"]=1]="JavaScript",e[e["Json"]=2]="Json",e[e["TSConfig"]=3]="TSConfig",e[e["DtsOnly"]=4]="DtsOnly"}(c||(c={})),e.getPackageJsonTypesVersionsPaths=v,e.getEffectiveTypeRoots=b;var T=e.combinePaths("node_modules","@types");function S(r,a,i,o,s,l){var d=t(i,o);s&&(i=s.commandLine.options);var p=a?e.getDirectoryPath(a):void 0,f=p?l&&l.getOrCreateCacheForDirectory(p,s):void 0,m=f&&f.get(r);if(m)return d&&(n(o,e.Diagnostics.Resolving_type_reference_directive_0_containing_file_1,r,a),s&&n(o,e.Diagnostics.Using_compiler_options_of_project_reference_redirect_0,s.sourceFile.fileName),n(o,e.Diagnostics.Resolution_for_type_reference_directive_0_was_found_in_cache_from_location_1,r,p),L(m)),m;var _=b(i,o);d&&(void 0===a?void 0===_?n(o,e.Diagnostics.Resolving_type_reference_directive_0_containing_file_not_set_root_directory_not_set,r):n(o,e.Diagnostics.Resolving_type_reference_directive_0_containing_file_not_set_root_directory_1,r,_):void 0===_?n(o,e.Diagnostics.Resolving_type_reference_directive_0_containing_file_1_root_directory_not_set,r,a):n(o,e.Diagnostics.Resolving_type_reference_directive_0_containing_file_1_root_directory_2,r,a,_),s&&n(o,e.Diagnostics.Using_compiler_options_of_project_reference_redirect_0,s.sourceFile.fileName));var g,y=[],h={compilerOptions:i,host:o,traceEnabled:d,failedLookupLocations:y,packageJsonInfoCache:l},v=D(),E=!0;if(v||(v=A(),E=!1),v){var T=v.fileName,S=v.packageId,x=i.preserveSymlinks?T:q(T,o,d);g={primary:E,resolvedFileName:x,originalPath:T===x?void 0:T,packageId:S,isExternalLibraryImport:X(T)}}return m={resolvedTypeReferenceDirective:g,failedLookupLocations:y},null===f||void 0===f||f.set(r,m),d&&L(m),m;function L(t){var a;(null===(a=t.resolvedTypeReferenceDirective)||void 0===a?void 0:a.resolvedFileName)?t.resolvedTypeReferenceDirective.packageId?n(o,e.Diagnostics.Type_reference_directive_0_was_successfully_resolved_to_1_with_Package_ID_2_primary_Colon_3,r,t.resolvedTypeReferenceDirective.resolvedFileName,e.packageIdToString(t.resolvedTypeReferenceDirective.packageId),t.resolvedTypeReferenceDirective.primary):n(o,e.Diagnostics.Type_reference_directive_0_was_successfully_resolved_to_1_primary_Colon_2,r,t.resolvedTypeReferenceDirective.resolvedFileName,t.resolvedTypeReferenceDirective.primary):n(o,e.Diagnostics.Type_reference_directive_0_was_not_resolved,r)}function D(){if(_&&_.length)return d&&n(o,e.Diagnostics.Resolving_with_primary_search_path_0,_.join(", ")),e.firstDefined(_,(function(t){var a=e.combinePaths(t,r),i=e.getDirectoryPath(a),s=e.directoryProbablyExists(i,o);return!s&&d&&n(o,e.Diagnostics.Directory_0_does_not_exist_skipping_all_lookups_in_it,i),u(te(c.DtsOnly,a,!s,h))}));d&&n(o,e.Diagnostics.Root_directory_cannot_be_determined_skipping_primary_search_paths)}function A(){var t=a&&e.getDirectoryPath(a);if(void 0!==t){var i;if(d&&n(o,e.Diagnostics.Looking_up_in_node_modules_folder_initial_location_0,t),e.isExternalModuleNameRelative(r)){var s=e.normalizePathAndParts(e.combinePaths(t,r)).path;i=J(c.DtsOnly,s,!1,h,!0)}else{var l=ce(c.DtsOnly,r,t,h,void 0,void 0);i=l&&l.value}return u(i)}d&&n(o,e.Diagnostics.Containing_file_is_not_specified_and_root_directory_cannot_be_determined_skipping_lookup_in_node_modules_folder)}}function x(n,t){if(n.types)return n.types;var r=[];if(t.directoryExists&&t.getDirectories){var a=b(n,t);if(a)for(var i=0,o=a;i<o.length;i++){var s=o[i];if(t.directoryExists(s))for(var c=0,l=t.getDirectories(s);c<l.length;c++){var u=l[c],d=e.normalizePath(u),p=e.combinePaths(s,d,"package.json"),f=t.fileExists(p)&&null===e.readJson(p,t).typings;if(!f){var m=e.getBaseFileName(d);46!==m.charCodeAt(0)&&r.push(m)}}}}return r}function L(n){var t=new e.Map,r=new e.Map;return{getOwnMap:a,redirectsMap:r,getOrCreateMapOfCacheRedirects:s,clear:c,setOwnOptions:i,setOwnMap:o};function a(){return t}function i(e){n=e}function o(e){t=e}function s(a){if(!a)return t;var i=a.sourceFile.path,o=r.get(i);return o||(o=!n||e.optionsHaveModuleResolutionChanges(n,a.commandLine.options)?new e.Map:t,r.set(i,o)),o}function c(){t.clear(),r.clear()}}function D(n,t){var r;return{getPackageJsonInfo:a,setPackageJsonInfo:i,clear:o};function a(a){return null===r||void 0===r?void 0:r.get(e.toPath(a,n,t))}function i(a,i){(r||(r=new e.Map)).set(e.toPath(a,n,t),i)}function o(){r=void 0}}function A(e,n,t,r){var a=e.getOrCreateMapOfCacheRedirects(n),i=a.get(t);return i||(i=r(),a.set(t,i)),i}function C(n,t,r){if(n.configFile){if(0===t.redirectsMap.size)e.Debug.assert(!r||0===r.redirectsMap.size),e.Debug.assert(0===t.getOwnMap().size),e.Debug.assert(!r||0===r.getOwnMap().size),t.redirectsMap.set(n.configFile.path,t.getOwnMap()),null===r||void 0===r||r.redirectsMap.set(n.configFile.path,r.getOwnMap());else{e.Debug.assert(!r||r.redirectsMap.size>0);var a={sourceFile:n.configFile,commandLine:{options:n}};t.setOwnMap(t.getOrCreateMapOfCacheRedirects(a)),null===r||void 0===r||r.setOwnMap(r.getOrCreateMapOfCacheRedirects(a))}t.setOwnOptions(n),null===r||void 0===r||r.setOwnOptions(n)}}function I(n,t,r){return{getOrCreateCacheForDirectory:o,clear:a,update:i};function a(){r.clear()}function i(e){C(e,r)}function o(a,i){var o=e.toPath(a,n,t);return A(r,i,o,(function(){return new e.Map}))}}function N(n,t,r,a,i){var s=I(n,t,a||(a=L(r)));i||(i=L(r));var c=D(n,t);return o(o(o({},c),s),{getOrCreateCacheForModuleName:d,clear:l,update:u,getPackageJsonInfoCache:function(){return c}});function l(){s.clear(),i.clear(),c.clear()}function u(e){C(e,a,i)}function d(n,t){return e.Debug.assert(!e.isExternalModuleNameRelative(n)),A(i,t,n,p)}function p(){var r=new e.Map;return{get:a,set:i};function a(a){return r.get(e.toPath(a,n,t))}function i(a,i){var s=e.toPath(a,n,t);if(!r.has(s)){r.set(s,i);var c=i.resolvedModule&&(i.resolvedModule.originalPath||i.resolvedModule.resolvedFileName),l=c&&o(s,c),u=s;while(u!==l){var d=e.getDirectoryPath(u);if(d===u||r.has(d))break;r.set(d,i),u=d}}}function o(r,a){var i=e.toPath(e.getDirectoryPath(a),n,t),o=0,s=Math.min(r.length,i.length);while(o<s&&r.charCodeAt(o)===i.charCodeAt(o))o++;if(o===r.length&&(i.length===o||i[o]===e.directorySeparator))return r;var c=e.getRootLength(r);if(!(o<c)){var l=r.lastIndexOf(e.directorySeparator,o-1);if(-1!==l)return r.substr(0,Math.max(l,c))}}}}function k(e,n,t,r,a){var i=I(e,n,a||(a=L(t)));return r||(r=D(e,n)),o(o(o({},r),i),{clear:s});function s(){i.clear(),r.clear()}}function R(n,t,r){var a=e.getDirectoryPath(t),i=r&&r.getOrCreateCacheForDirectory(a);return i&&i.get(n)}function O(r,a,i,o,s,c){var l=t(i,o);c&&(i=c.commandLine.options),l&&(n(o,e.Diagnostics.Resolving_module_0_from_1,r,a),c&&n(o,e.Diagnostics.Using_compiler_options_of_project_reference_redirect_0,c.sourceFile.fileName));var u=e.getDirectoryPath(a),d=s&&s.getOrCreateCacheForDirectory(u,c),p=d&&d.get(r);if(p)l&&n(o,e.Diagnostics.Resolution_for_module_0_was_found_in_cache_from_location_1,r,u);else{var f=i.moduleResolution;switch(void 0===f?(f=e.getEmitModuleKind(i)===e.ModuleKind.CommonJS?e.ModuleResolutionKind.NodeJs:e.ModuleResolutionKind.Classic,l&&n(o,e.Diagnostics.Module_resolution_kind_is_not_specified_using_0,e.ModuleResolutionKind[f])):l&&n(o,e.Diagnostics.Explicitly_specified_module_resolution_kind_Colon_0,e.ModuleResolutionKind[f]),e.perfLogger.logStartResolveModule(r),f){case e.ModuleResolutionKind.NodeJs:p=W(r,a,i,o,s,c);break;case e.ModuleResolutionKind.Classic:p=Ee(r,a,i,o,s,c);break;default:return e.Debug.fail("Unexpected moduleResolution: "+f)}p&&p.resolvedModule&&e.perfLogger.logInfoEvent('Module "'+r+'" resolved to "'+p.resolvedModule.resolvedFileName+'"'),e.perfLogger.logStopResolveModule(p&&p.resolvedModule?""+p.resolvedModule.resolvedFileName:"null"),d&&(d.set(r,p),e.isExternalModuleNameRelative(r)||s.getOrCreateCacheForModuleName(r,c).set(u,p))}return l&&(p.resolvedModule?p.resolvedModule.packageId?n(o,e.Diagnostics.Module_name_0_was_successfully_resolved_to_1_with_Package_ID_2,r,p.resolvedModule.resolvedFileName,e.packageIdToString(p.resolvedModule.packageId)):n(o,e.Diagnostics.Module_name_0_was_successfully_resolved_to_1,r,p.resolvedModule.resolvedFileName):n(o,e.Diagnostics.Module_name_0_was_not_resolved,r)),p}function w(n,t,r,a,i){var o=P(n,t,a,i);return o?o.value:e.isExternalModuleNameRelative(t)?M(n,t,r,a,i):F(n,t,a,i)}function P(t,r,a,i){var o=i.compilerOptions,s=o.baseUrl,c=o.paths;if(c&&!e.pathIsRelative(r)){i.traceEnabled&&(s&&n(i.host,e.Diagnostics.baseUrl_option_is_set_to_0_using_this_value_to_resolve_non_relative_module_name_1,s,r),n(i.host,e.Diagnostics.paths_option_is_specified_looking_for_a_pattern_to_match_module_name_0,r));var l=e.getPathsBasePath(i.compilerOptions,i.host);return fe(t,r,l,c,a,!1,i)}}function M(t,r,a,i,o){if(o.compilerOptions.rootDirs){o.traceEnabled&&n(o.host,e.Diagnostics.rootDirs_option_is_set_using_it_to_resolve_relative_module_name_0,r);for(var s,c,l=e.normalizePath(e.combinePaths(a,r)),u=0,d=o.compilerOptions.rootDirs;u<d.length;u++){var p=d[u],f=e.normalizePath(p);e.endsWith(f,e.directorySeparator)||(f+=e.directorySeparator);var m=e.startsWith(l,f)&&(void 0===c||c.length<f.length);o.traceEnabled&&n(o.host,e.Diagnostics.Checking_if_0_is_the_longest_matching_prefix_for_1_2,f,l,m),m&&(c=f,s=p)}if(c){o.traceEnabled&&n(o.host,e.Diagnostics.Longest_matching_prefix_for_0_is_1,l,c);var _=l.substr(c.length);o.traceEnabled&&n(o.host,e.Diagnostics.Loading_0_from_the_root_dir_1_candidate_location_2,_,c,l);var g=i(t,l,!e.directoryProbablyExists(a,o.host),o);if(g)return g;o.traceEnabled&&n(o.host,e.Diagnostics.Trying_other_entries_in_rootDirs);for(var y=0,h=o.compilerOptions.rootDirs;y<h.length;y++){p=h[y];if(p!==s){var v=e.combinePaths(e.normalizePath(p),_);o.traceEnabled&&n(o.host,e.Diagnostics.Loading_0_from_the_root_dir_1_candidate_location_2,_,p,v);var b=e.getDirectoryPath(v),E=i(t,v,!e.directoryProbablyExists(b,o.host),o);if(E)return E}}o.traceEnabled&&n(o.host,e.Diagnostics.Module_resolution_using_rootDirs_has_failed)}}}function F(t,r,a,i){var o=i.compilerOptions.baseUrl;if(o){i.traceEnabled&&n(i.host,e.Diagnostics.baseUrl_option_is_set_to_0_using_this_value_to_resolve_non_relative_module_name_1,o,r);var s=e.normalizePath(e.combinePaths(o,r));return i.traceEnabled&&n(i.host,e.Diagnostics.Resolving_module_name_0_relative_to_base_url_1_2,r,o,s),a(t,s,!e.directoryProbablyExists(e.getDirectoryPath(s),i.host),i)}}function G(e,n,t){var r=H(e,n,t),a=r.resolvedModule,i=r.failedLookupLocations;if(!a)throw new Error("Could not resolve JS module '"+e+"' starting at '"+n+"'. Looked in: "+i.join(", "));return a.resolvedFileName}function B(e,n,t){var r=H(e,n,t).resolvedModule;return r&&r.resolvedFileName}e.resolveTypeReferenceDirective=S,e.getAutomaticTypeDirectiveNames=x,e.createCacheWithRedirects=L,e.createModuleResolutionCache=N,e.createTypeReferenceDirectiveResolutionCache=k,e.resolveModuleNameFromCache=R,e.resolveModuleName=O,e.resolveJSModule=G,e.tryResolveJSModule=B;var U=[c.JavaScript],V=[c.TypeScript,c.JavaScript],j=i(i([],V),[c.Json]),K=[c.TSConfig];function H(n,t,r){return z(n,t,{moduleResolution:e.ModuleResolutionKind.NodeJs,allowJs:!0},r,void 0,U,void 0)}function W(n,t,r,a,i,o,s){return z(n,e.getDirectoryPath(t),r,a,i,s?K:r.resolveJsonModule?j:V,o)}function z(r,a,i,s,l,u,p){var f,m,_=t(i,s),g=[],y={compilerOptions:i,host:s,traceEnabled:_,failedLookupLocations:g,packageJsonInfoCache:l},h=e.forEach(u,(function(e){return v(e)}));return d(null===(f=null===h||void 0===h?void 0:h.value)||void 0===f?void 0:f.resolved,null===(m=null===h||void 0===h?void 0:h.value)||void 0===m?void 0:m.isExternalLibraryImport,g,y.resultFromCache);function v(t){var u=function(e,n,t,r){return J(e,n,t,r,!0)},d=w(t,r,a,u,y);if(d)return Se({resolved:d,isExternalLibraryImport:X(d.path)});if(e.isExternalModuleNameRelative(r)){var f=e.normalizePathAndParts(e.combinePaths(a,r)),m=f.path,g=f.parts,h=J(t,m,!1,y,!0);return h&&Se({resolved:h,isExternalLibraryImport:e.contains(g,"node_modules")})}_&&n(s,e.Diagnostics.Loading_module_0_from_node_modules_folder_target_file_type_1,r,c[t]);var v=ce(t,r,a,y,l,p);if(v){var b=v.value;if(!i.preserveSymlinks&&b&&!b.originalPath){var E=q(b.path,s,_),T=E===b.path?void 0:b.path;b=o(o({},b),{path:E,originalPath:T})}return{value:b&&{resolved:b,isExternalLibraryImport:!0}}}}}function q(t,r,a){if(!r.realpath)return t;var i=e.normalizePath(r.realpath(t));return a&&n(r,e.Diagnostics.Resolving_real_path_for_0_result_1,t,i),e.Debug.assert(r.fileExists(i),t+" linked to nonexistent file "+i),i}function J(t,a,i,o,s){if(o.traceEnabled&&n(o.host,e.Diagnostics.Loading_module_as_file_Slash_folder_candidate_module_location_0_target_file_type_1,a,c[t]),!e.hasTrailingDirectorySeparator(a)){if(!i){var l=e.getDirectoryPath(a);e.directoryProbablyExists(l,o.host)||(o.traceEnabled&&n(o.host,e.Diagnostics.Directory_0_does_not_exist_skipping_all_lookups_in_it,l),i=!0)}var u=$(t,a,i,o);if(u){var d=s?Y(u.path):void 0,p=d?re(d,!1,o):void 0;return r(p,u)}}if(!i){var f=e.directoryProbablyExists(a,o.host);f||(o.traceEnabled&&n(o.host,e.Diagnostics.Directory_0_does_not_exist_skipping_all_lookups_in_it,a),i=!0)}return te(t,a,i,o,s)}function X(n){return e.stringContains(n,e.nodeModulesPathPart)}function Y(n){var t=e.normalizePath(n),r=t.lastIndexOf(e.nodeModulesPathPart);if(-1!==r){var a=r+e.nodeModulesPathPart.length,i=Q(t,a);return 64===t.charCodeAt(a)&&(i=Q(t,i)),t.slice(0,i)}}function Q(n,t){var r=n.indexOf(e.directorySeparator,t+1);return-1===r?t:r}function Z(e,n,t,r){return a($(e,n,t,r))}function $(t,r,a,i){if(t===c.Json||t===c.TSConfig){var o=e.tryRemoveExtension(r,".json");return void 0===o&&t===c.Json?void 0:ee(o||r,t,a,i)}var s=ee(r,t,a,i);if(s)return s;if(e.hasJSFileExtension(r)){var l=e.removeFileExtension(r);if(i.traceEnabled){var u=r.substring(l.length);n(i.host,e.Diagnostics.File_name_0_has_a_1_extension_stripping_it,r,u)}return ee(l,t,a,i)}}function ee(n,t,r,a){if(!r){var i=e.getDirectoryPath(n);i&&(r=!e.directoryProbablyExists(i,a.host))}switch(t){case c.DtsOnly:return o(".d.ts");case c.TypeScript:return o(".ts")||o(".tsx")||o(".d.ts");case c.JavaScript:return o(".js")||o(".jsx");case c.TSConfig:case c.Json:return o(".json")}function o(e){var t=ne(n+e,r,a);return void 0===t?void 0:{path:t,ext:e}}}function ne(t,r,a){if(!r){if(a.host.fileExists(t))return a.traceEnabled&&n(a.host,e.Diagnostics.File_0_exist_use_it_as_a_name_resolution_result,t),t;a.traceEnabled&&n(a.host,e.Diagnostics.File_0_does_not_exist,t)}a.failedLookupLocations.push(t)}function te(e,n,t,a,i){void 0===i&&(i=!0);var o=i?re(n,t,a):void 0,s=o&&o.packageJsonContent,c=o&&o.versionPaths;return r(o,ae(e,n,t,a,s,c))}function re(t,r,a){var i,o,s,c=a.host,l=a.traceEnabled,u=e.combinePaths(t,"package.json");if(r)a.failedLookupLocations.push(u);else{var d=null===(i=a.packageJsonInfoCache)||void 0===i?void 0:i.getPackageJsonInfo(u);if(void 0!==d)return"boolean"!==typeof d?(l&&n(c,e.Diagnostics.File_0_exists_according_to_earlier_cached_lookups,u),d):(d&&l&&n(c,e.Diagnostics.File_0_does_not_exist_according_to_earlier_cached_lookups,u),void a.failedLookupLocations.push(u));var p=e.directoryProbablyExists(t,c);if(p&&c.fileExists(u)){var f=e.readJson(u,c);l&&n(c,e.Diagnostics.Found_package_json_at_0,u);var m=h(f,a),_={packageDirectory:t,packageJsonContent:f,versionPaths:m};return null===(o=a.packageJsonInfoCache)||void 0===o||o.setPackageJsonInfo(u,_),_}p&&l&&n(c,e.Diagnostics.File_0_does_not_exist,u),null===(s=a.packageJsonInfoCache)||void 0===s||s.setPackageJsonInfo(u,p),a.failedLookupLocations.push(u)}}function ae(t,r,i,o,l,u){var d;if(l)switch(t){case c.JavaScript:case c.Json:d=g(l,r,o);break;case c.TypeScript:d=m(l,r,o)||g(l,r,o);break;case c.DtsOnly:d=m(l,r,o);break;case c.TSConfig:d=_(l,r,o);break;default:return e.Debug.assertNever(t)}var p=function(t,r,i,o){var s=ne(r,i,o);if(s){var l=ie(t,s);if(l)return a(l);o.traceEnabled&&n(o.host,e.Diagnostics.File_0_has_an_unsupported_extension_so_skipping_it,s)}var u=t===c.DtsOnly?c.TypeScript:t;return J(u,r,i,o,!1)},f=d?!e.directoryProbablyExists(e.getDirectoryPath(d),o.host):void 0,y=i||!e.directoryProbablyExists(r,o.host),h=e.combinePaths(r,t===c.TSConfig?"tsconfig":"index");if(u&&(!d||e.containsPath(r,d))){var v=e.getRelativePathFromDirectory(r,d||h,!1);o.traceEnabled&&n(o.host,e.Diagnostics.package_json_has_a_typesVersions_entry_0_that_matches_compiler_version_1_looking_for_a_pattern_to_match_module_name_2,u.version,e.version,v);var b=fe(t,v,r,u.paths,p,f||y,o);if(b)return s(b.value)}var E=d&&s(p(t,d,f,o));return E||$(t,h,y,o)}function ie(n,t){var r=e.tryGetExtensionFromPath(t);return void 0!==r&&oe(n,r)?{path:t,ext:r}:void 0}function oe(e,n){switch(e){case c.JavaScript:return".js"===n||".jsx"===n;case c.TSConfig:case c.Json:return".json"===n;case c.TypeScript:return".ts"===n||".tsx"===n||".d.ts"===n;case c.DtsOnly:return".d.ts"===n}}function se(n){var t=n.indexOf(e.directorySeparator);return"@"===n[0]&&(t=n.indexOf(e.directorySeparator,t+1)),-1===t?{packageName:n,rest:""}:{packageName:n.slice(0,t),rest:n.slice(t+1)}}function ce(e,n,t,r,a,i){return ue(e,n,t,r,!1,a,i)}function le(e,n,t){return ue(c.DtsOnly,e,n,t,!0,void 0,void 0)}function ue(n,t,r,a,i,o,s){var c=o&&o.getOrCreateCacheForModuleName(t,s);return e.forEachAncestorDirectory(e.normalizeSlashes(r),(function(r){if("node_modules"!==e.getBaseFileName(r)){var o=be(c,t,r,a);return o||Se(de(n,t,r,a,i))}}))}function de(t,r,a,i,o){var s=e.combinePaths(a,"node_modules"),l=e.directoryProbablyExists(s,i.host);!l&&i.traceEnabled&&n(i.host,e.Diagnostics.Directory_0_does_not_exist_skipping_all_lookups_in_it,s);var u=o?void 0:pe(t,r,s,l,i);if(u)return u;if(t===c.TypeScript||t===c.DtsOnly){var d=e.combinePaths(s,"@types"),p=l;return l&&!e.directoryProbablyExists(d,i.host)&&(i.traceEnabled&&n(i.host,e.Diagnostics.Directory_0_does_not_exist_skipping_all_lookups_in_it,d),p=!1),pe(c.DtsOnly,_e(r,i),d,p,i)}}function pe(t,i,o,s,c){var l=e.normalizePath(e.combinePaths(o,i)),u=re(l,!s,c);if(u){var d=$(t,l,!s,c);if(d)return a(d);var p=ae(t,l,!s,c,u.packageJsonContent,u.versionPaths);return r(u,p)}var f=function(e,n,t,a){var i=$(e,n,t,a)||ae(e,n,t,a,u&&u.packageJsonContent,u&&u.versionPaths);return r(u,i)},m=se(i),_=m.packageName,g=m.rest;if(""!==g){var y=e.combinePaths(o,_);if(u=re(y,!s,c),u&&u.versionPaths){c.traceEnabled&&n(c.host,e.Diagnostics.package_json_has_a_typesVersions_entry_0_that_matches_compiler_version_1_looking_for_a_pattern_to_match_module_name_2,u.versionPaths.version,e.version,g);var h=s&&e.directoryProbablyExists(y,c.host),v=fe(t,g,y,u.versionPaths.paths,f,!h,c);if(v)return v.value}}return f(t,l,!s,c)}function fe(t,r,i,o,s,c,l){var u=e.matchPatternOrExact(e.getOwnKeys(o),r);if(u){var d=e.isString(u)?void 0:e.matchedText(u,r),p=e.isString(u)?u:e.patternText(u);l.traceEnabled&&n(l.host,e.Diagnostics.Module_name_0_matched_pattern_1,r,p);var f=e.forEach(o[p],(function(r){var o=d?r.replace("*",d):r,u=e.normalizePath(e.combinePaths(i,o));l.traceEnabled&&n(l.host,e.Diagnostics.Trying_substitution_0_candidate_module_location_Colon_1,r,o);var p=e.tryGetExtensionFromPath(r);if(void 0!==p){var f=ne(u,c,l);if(void 0!==f)return a({path:f,ext:p})}return s(t,u,c||!e.directoryProbablyExists(e.getDirectoryPath(u),l.host),l)}));return{value:f}}}e.nodeModuleNameResolver=W,e.nodeModulesPathPart="/node_modules/",e.pathContainsNodeModules=X,e.parseNodeModuleFromPath=Y,e.parsePackageName=se;var me="__";function _e(t,r){var a=ye(t);return r.traceEnabled&&a!==t&&n(r.host,e.Diagnostics.Scoped_package_detected_looking_in_0,a),a}function ge(e){return"@types/"+ye(e)}function ye(n){if(e.startsWith(n,"@")){var t=n.replace(e.directorySeparator,me);if(t!==n)return t.slice(1)}return n}function he(n){var t=e.removePrefix(n,"@types/");return t!==n?ve(t):n}function ve(n){return e.stringContains(n,me)?"@"+n.replace(me,e.directorySeparator):n}function be(t,r,a,i){var o=t&&t.get(a);if(o)return i.traceEnabled&&n(i.host,e.Diagnostics.Resolution_for_module_0_was_found_in_cache_from_location_1,r,a),i.resultFromCache=o,{value:o.resolvedModule&&{path:o.resolvedModule.resolvedFileName,originalPath:o.resolvedModule.originalPath||!0,extension:o.resolvedModule.extension,packageId:o.resolvedModule.packageId}}}function Ee(n,r,a,i,o,s){var l=t(a,i),u=[],p={compilerOptions:a,host:i,traceEnabled:l,failedLookupLocations:u,packageJsonInfoCache:o},f=e.getDirectoryPath(r),m=_(c.TypeScript)||_(c.JavaScript);return d(m&&m.value,!1,u,p.resultFromCache);function _(t){var r=w(t,n,f,Z,p);if(r)return{value:r};if(e.isExternalModuleNameRelative(n)){var a=e.normalizePath(e.combinePaths(f,n));return Se(Z(t,a,!1,p))}var i=o&&o.getOrCreateCacheForModuleName(n,s),l=e.forEachAncestorDirectory(f,(function(r){var a=be(i,n,r,p);if(a)return a;var o=e.normalizePath(e.combinePaths(r,n));return Se(Z(t,o,!1,p))}));return l||(t===c.TypeScript?le(n,f,p):void 0)}}function Te(r,a,i,o,s,l){var u=t(i,o);u&&n(o,e.Diagnostics.Auto_discovery_for_typings_is_enabled_in_project_0_Running_extra_resolution_pass_for_module_1_using_cache_location_2,a,r,s);var p=[],f={compilerOptions:i,host:o,traceEnabled:u,failedLookupLocations:p,packageJsonInfoCache:l},m=de(c.DtsOnly,r,s,f,!1);return d(m,!0,p,f.resultFromCache)}function Se(e){return void 0!==e?{value:e}:void 0}e.getTypesPackageName=ge,e.mangleScopedPackageName=ye,e.getPackageNameFromTypesPackageName=he,e.unmangleScopedPackageName=ve,e.classicNameResolver=Ee,e.loadModuleFromGlobalCache=Te}(d||(d={})),function(e){var n;function t(n,t){return n.body&&!n.body.parent&&(e.setParent(n.body,n),e.setParentRecursive(n.body,!1)),n.body?r(n.body,t):1}function r(n,t){void 0===t&&(t=new e.Map);var r=e.getNodeId(n);if(t.has(r))return t.get(r)||0;t.set(r,void 0);var i=a(n,t);return t.set(r,i),i}function a(n,a){switch(n.kind){case 254:case 255:return 0;case 256:if(e.isEnumConst(n))return 2;break;case 262:case 261:if(!e.hasSyntacticModifier(n,1))return 0;break;case 268:var i=n;if(!i.moduleSpecifier&&i.exportClause&&269===i.exportClause.kind){for(var o=0,c=0,l=i.exportClause.elements;c<l.length;c++){var u=l[c],d=s(u,a);if(d>o&&(o=d),1===o)return o}return o}break;case 258:var p=0;return e.forEachChild(n,(function(n){var t=r(n,a);switch(t){case 0:return;case 2:return void(p=2);case 1:return p=1,!0;default:e.Debug.assertNever(t)}})),p;case 257:return t(n,a);case 78:if(n.isInJSDocNamespace)return 0}return 1}function s(n,t){var a=n.propertyName||n.name,i=n.parent;while(i){if(e.isBlock(i)||e.isModuleBlock(i)||e.isSourceFile(i)){for(var o=i.statements,s=void 0,c=0,l=o;c<l.length;c++){var u=l[c];if(e.nodeHasName(u,a)){u.parent||(e.setParent(u,i),e.setParentRecursive(u,!1));var d=r(u,t);if((void 0===s||d>s)&&(s=d),1===s)return s}}if(void 0!==s)return s}i=i.parent}return 1}function c(n){return e.Debug.attachFlowNodeDebugInfo(n),n}(function(e){e[e["NonInstantiated"]=0]="NonInstantiated",e[e["Instantiated"]=1]="Instantiated",e[e["ConstEnumOnly"]=2]="ConstEnumOnly"})(e.ModuleInstanceState||(e.ModuleInstanceState={})),e.getModuleInstanceState=t,function(e){e[e["None"]=0]="None",e[e["IsContainer"]=1]="IsContainer",e[e["IsBlockScopedContainer"]=2]="IsBlockScopedContainer",e[e["IsControlFlowContainer"]=4]="IsControlFlowContainer",e[e["IsFunctionLike"]=8]="IsFunctionLike",e[e["IsFunctionExpression"]=16]="IsFunctionExpression",e[e["HasLocals"]=32]="HasLocals",e[e["IsInterface"]=64]="IsInterface",e[e["IsObjectLiteralOrClassExpressionMethod"]=128]="IsObjectLiteralOrClassExpressionMethod"}(n||(n={}));var l=d();function u(n,t){null===e.tracing||void 0===e.tracing||e.tracing.push("bind","bindSourceFile",{path:n.path},!0),e.performance.mark("beforeBind"),e.perfLogger.logStartBindFile(""+n.fileName),l(n,t),e.perfLogger.logStopBindFile(),e.performance.mark("afterBind"),e.performance.measure("Bind","beforeBind","afterBind"),null===e.tracing||void 0===e.tracing||e.tracing.pop()}function d(){var n,r,a,s,l,u,d,f,m,y,h,v,b,E,T,S,x,L,D,A,C,I,N,k,R=!1,O=0,w={flags:1},P={flags:1},M=ze();function F(t,r,a,i,o){return e.createDiagnosticForNodeInSourceFile(e.getSourceFileOfNode(t)||n,t,r,a,i,o)}function G(t,i){n=t,r=i,a=e.getEmitScriptTarget(r),I=B(n,i),k=new e.Set,O=0,N=e.objectAllocator.getSymbolConstructor(),e.Debug.attachFlowNodeDebugInfo(w),e.Debug.attachFlowNodeDebugInfo(P),n.locals||(Wn(n),n.symbolCount=O,n.classifiableNames=k,Sn()),n=void 0,r=void 0,a=void 0,s=void 0,l=void 0,u=void 0,d=void 0,f=void 0,m=void 0,y=!1,h=void 0,v=void 0,b=void 0,E=void 0,T=void 0,S=void 0,x=void 0,D=void 0,A=!1,R=!1,C=0}return G;function B(n,t){return!(!e.getStrictOptionValue(t,"alwaysStrict")||n.isDeclarationFile)||!!n.externalModuleIndicator}function U(e,n){return O++,new N(e,n)}function V(n,t,r){n.flags|=r,t.symbol=n,n.declarations=e.appendIfUnique(n.declarations,t),1955&r&&!n.exports&&(n.exports=e.createSymbolTable()),6240&r&&!n.members&&(n.members=e.createSymbolTable()),n.constEnumOnlyModule&&304&n.flags&&(n.constEnumOnlyModule=!1),111551&r&&e.setValueDeclaration(n,t)}function j(n){if(267===n.kind)return n.isExportEquals?"export=":"default";var t=e.getNameOfDeclaration(n);if(t){if(e.isAmbientModule(n)){var r=e.getTextOfIdentifierOrLiteral(t);return e.isGlobalScopeAugmentation(n)?"__global":'"'+r+'"'}if(159===t.kind){var a=t.expression;if(e.isStringOrNumericLiteralLike(a))return e.escapeLeadingUnderscores(a.text);if(e.isSignedNumericLiteral(a))return e.tokenToString(a.operator)+a.operand.text;e.Debug.fail("Only computed properties with literal names have declaration names")}if(e.isPrivateIdentifier(t)){var i=e.getContainingClass(n);if(!i)return;var o=i.symbol;return e.getSymbolNameForPrivateIdentifier(o,t.escapedText)}return e.isPropertyNameLiteral(t)?e.getEscapedTextOfIdentifierOrLiteral(t):void 0}switch(n.kind){case 167:return"__constructor";case 175:case 170:case 315:return"__call";case 176:case 171:return"__new";case 172:return"__index";case 268:return"__export";case 298:return"export=";case 217:if(2===e.getAssignmentDeclarationKind(n))return"export=";e.Debug.fail("Unknown binary declaration kind");break;case 309:return e.isJSDocConstructSignature(n)?"__new":"__call";case 161:e.Debug.assert(309===n.parent.kind,"Impossible parameter parent kind",(function(){return"parent is: "+(e.SyntaxKind?e.SyntaxKind[n.parent.kind]:n.parent.kind)+", expected JSDocFunctionType"}));var s=n.parent,c=s.parameters.indexOf(n);return"arg"+c}}function K(n){return e.isNamedDeclaration(n)?e.declarationNameToString(n.name):e.unescapeLeadingUnderscores(e.Debug.checkDefined(j(n)))}function H(t,r,a,o,s,c){e.Debug.assert(!e.hasDynamicName(a));var l,u=e.hasSyntacticModifier(a,512)||e.isExportSpecifier(a)&&"default"===a.name.escapedText,d=u&&r?"default":j(a);if(void 0===d)l=U(0,"__missing");else if(l=t.get(d),2885600&o&&k.add(d),l){if(c&&!l.isReplaceableByMethod)return l;if(l.flags&s)if(l.isReplaceableByMethod)t.set(d,l=U(0,d));else if(!(3&o&&67108864&l.flags)){e.isNamedDeclaration(a)&&e.setParent(a.name,a);var p=2&l.flags?e.Diagnostics.Cannot_redeclare_block_scoped_variable_0:e.Diagnostics.Duplicate_identifier_0,f=!0;(384&l.flags||384&o)&&(p=e.Diagnostics.Enum_declarations_can_only_merge_with_namespace_or_other_enum_declarations,f=!1);var m=!1;e.length(l.declarations)&&(u||l.declarations&&l.declarations.length&&267===a.kind&&!a.isExportEquals)&&(p=e.Diagnostics.A_module_cannot_have_multiple_default_exports,f=!1,m=!0);var _=[];e.isTypeAliasDeclaration(a)&&e.nodeIsMissing(a.type)&&e.hasSyntacticModifier(a,1)&&2887656&l.flags&&_.push(F(a,e.Diagnostics.Did_you_mean_0,"export type { "+e.unescapeLeadingUnderscores(a.name.escapedText)+" }"));var g=e.getNameOfDeclaration(a)||a;e.forEach(l.declarations,(function(t,r){var a=e.getNameOfDeclaration(t)||t,i=F(a,p,f?K(t):void 0);n.bindDiagnostics.push(m?e.addRelatedInfo(i,F(g,0===r?e.Diagnostics.Another_export_default_is_here:e.Diagnostics.and_here)):i),m&&_.push(F(a,e.Diagnostics.The_first_export_default_is_here))}));var y=F(g,p,f?K(a):void 0);n.bindDiagnostics.push(e.addRelatedInfo.apply(void 0,i([y],_))),l=U(0,d)}}else t.set(d,l=U(0,d)),c&&(l.isReplaceableByMethod=!0);return V(l,a,o),l.parent?e.Debug.assert(l.parent===r,"Existing symbol parent should match new one"):l.parent=r,l}function W(n,t,r){var a=!!(1&e.getCombinedModifierFlags(n))||z(n);if(2097152&t)return 271===n.kind||261===n.kind&&a?H(l.symbol.exports,l.symbol,n,t,r):H(l.locals,void 0,n,t,r);if(e.isJSDocTypeAlias(n)&&e.Debug.assert(e.isInJSFile(n)),!e.isAmbientModule(n)&&(a||64&l.flags)){if(!l.locals||e.hasSyntacticModifier(n,512)&&!j(n))return H(l.symbol.exports,l.symbol,n,t,r);var i=111551&t?1048576:0,o=H(l.locals,void 0,n,i,r);return o.exportSymbol=H(l.symbol.exports,l.symbol,n,t,r),n.localSymbol=o,o}return H(l.locals,void 0,n,t,r)}function z(n){if(n.parent&&e.isModuleDeclaration(n)&&(n=n.parent),!e.isJSDocTypeAlias(n))return!1;if(!e.isJSDocEnumTag(n)&&n.fullName)return!0;var t=e.getNameOfDeclaration(n);return!!t&&(!(!e.isPropertyAccessEntityNameExpression(t.parent)||!Et(t.parent))||!!(e.isDeclaration(t.parent)&&1&e.getCombinedModifierFlags(t.parent)))}function q(n,t){var r=l,a=u,i=d;if(1&t?(210!==n.kind&&(u=l),l=d=n,32&t&&(l.locals=e.createSymbolTable()),ln(l)):2&t&&(d=n,d.locals=void 0),4&t){var o=h,s=v,p=b,f=E,m=x,_=D,g=A,T=16&t&&!e.hasSyntacticModifier(n,256)&&!n.asteriskToken&&!!e.getImmediatelyInvokedFunctionExpression(n);T||(h=c({flags:2}),144&t&&(h.node=n)),E=T||167===n.kind||e.isInJSFile(n)&&(252===n.kind||209===n.kind)?oe():void 0,x=void 0,v=void 0,b=void 0,D=void 0,A=!1,Q(n),n.flags&=-2817,!(1&h.flags)&&8&t&&e.nodeIsPresent(n.body)&&(n.flags|=256,A&&(n.flags|=512),n.endFlowNode=h),298===n.kind&&(n.flags|=C,n.endFlowNode=h),E&&(ue(E,h),h=_e(E),(167===n.kind||e.isInJSFile(n)&&(252===n.kind||209===n.kind))&&(n.returnFlowNode=h)),T||(h=o),v=s,b=p,E=f,x=m,D=_,A=g}else 64&t?(y=!1,Q(n),n.flags=y?128|n.flags:-129&n.flags):Q(n);l=r,u=a,d=i}function J(e){X(e,(function(e){return 252===e.kind?Wn(e):void 0})),X(e,(function(e){return 252!==e.kind?Wn(e):void 0}))}function X(n,t){void 0===t&&(t=Wn),void 0!==n&&e.forEach(n,t)}function Y(n){e.forEachChild(n,Wn,X)}function Q(n){var t=R;if(R=!1,Gt(n))return Y(n),zn(n),void(R=t);switch(n.kind>=233&&n.kind<=249&&!r.allowUnreachableCode&&(n.flowNode=h),n.kind){case 237:xe(n);break;case 236:Le(n);break;case 238:De(n);break;case 239:case 240:Ae(n);break;case 235:Ce(n);break;case 243:case 247:Ie(n);break;case 242:case 241:Re(n);break;case 248:Oe(n);break;case 245:we(n);break;case 259:Pe(n);break;case 285:Me(n);break;case 234:Fe(n);break;case 246:Be(n);break;case 215:Ke(n);break;case 216:He(n);break;case 217:if(e.isDestructuringAssignment(n))return R=t,void We(n);M(n);break;case 211:qe(n);break;case 218:Je(n);break;case 250:Ye(n);break;case 202:case 203:on(n);break;case 204:sn(n);break;case 226:an(n);break;case 335:case 328:case 329:Ze(n);break;case 298:J(n.statements),Wn(n.endOfFileToken);break;case 231:case 258:J(n.statements);break;case 199:Qe(n);break;case 201:case 200:case 289:case 221:R=t;default:Y(n);break}zn(n),R=t}function Z(e){switch(e.kind){case 78:case 79:case 107:case 202:case 203:return ee(e);case 204:return ne(e);case 208:case 226:return Z(e.expression);case 217:return ae(e);case 215:return 53===e.operator&&Z(e.operand);case 212:return Z(e.expression)}return!1}function $(n){return e.isDottedName(n)||(e.isPropertyAccessExpression(n)||e.isNonNullExpression(n)||e.isParenthesizedExpression(n))&&$(n.expression)||e.isBinaryExpression(n)&&27===n.operatorToken.kind&&$(n.right)||e.isElementAccessExpression(n)&&e.isStringOrNumericLiteralLike(n.argumentExpression)&&$(n.expression)||e.isAssignmentExpression(n)&&$(n.left)}function ee(n){return $(n)||e.isOptionalChain(n)&&ee(n.expression)}function ne(e){if(e.arguments)for(var n=0,t=e.arguments;n<t.length;n++){var r=t[n];if(ee(r))return!0}return!(202!==e.expression.kind||!ee(e.expression.expression))}function te(n,t){return e.isTypeOfExpression(n)&&ie(n.expression)&&e.isStringLiteralLike(t)}function re(n,t){return e.isStringLiteralLike(n)&&Z(t)}function ae(e){switch(e.operatorToken.kind){case 62:case 74:case 75:case 76:return ee(e.left);case 34:case 35:case 36:case 37:return ie(e.left)||ie(e.right)||te(e.right,e.left)||te(e.left,e.right);case 101:return ie(e.left);case 100:return re(e.left,e.right);case 27:return Z(e.right)}return!1}function ie(e){switch(e.kind){case 208:return ie(e.expression);case 217:switch(e.operatorToken.kind){case 62:return ie(e.left);case 27:return ie(e.right)}}return ee(e)}function oe(){return c({flags:4,antecedents:void 0})}function se(){return c({flags:8,antecedents:void 0})}function ce(e,n,t){return c({flags:1024,target:e,antecedents:n,antecedent:t})}function le(e){e.flags|=2048&e.flags?4096:2048}function ue(n,t){1&t.flags||e.contains(n.antecedents,t)||((n.antecedents||(n.antecedents=[])).push(t),le(t))}function de(n,t,r){return 1&t.flags?t:r?!(109===r.kind&&64&n||94===r.kind&&32&n)||e.isExpressionOfOptionalChainRoot(r)||e.isNullishCoalesce(r.parent)?Z(r)?(le(t),c({flags:n,antecedent:t,node:r})):t:w:32&n?t:w}function pe(e,n,t,r){return le(e),c({flags:128,antecedent:e,switchStatement:n,clauseStart:t,clauseEnd:r})}function fe(e,n,t){le(n);var r=c({flags:e,antecedent:n,node:t});return x&&ue(x,r),r}function me(e,n){return le(e),c({flags:512,antecedent:e,node:n})}function _e(e){var n=e.antecedents;return n?1===n.length?n[0]:e:w}function ge(e){var n=e.parent;switch(n.kind){case 235:case 237:case 236:return n.expression===e;case 238:case 218:return n.condition===e}return!1}function ye(e){while(1)if(208===e.kind)e=e.expression;else{if(215!==e.kind||53!==e.operator)return 217===e.kind&&(55===e.operatorToken.kind||56===e.operatorToken.kind||60===e.operatorToken.kind);e=e.operand}}function he(n){return n=e.skipParentheses(n),e.isBinaryExpression(n)&&e.isLogicalOrCoalescingAssignmentOperator(n.operatorToken.kind)}function ve(n){while(e.isParenthesizedExpression(n.parent)||e.isPrefixUnaryExpression(n.parent)&&53===n.parent.operator)n=n.parent;return!ge(n)&&!he(n.parent)&&!ye(n.parent)&&!(e.isOptionalChain(n.parent)&&n.parent.expression===n)}function be(e,n,t,r){var a=T,i=S;T=t,S=r,e(n),T=a,S=i}function Ee(n,t,r){be(Wn,n,t,r),n&&(he(n)||ye(n)||e.isOptionalChain(n)&&e.isOutermostOptionalChain(n))||(ue(t,de(32,h,n)),ue(r,de(64,h,n)))}function Te(e,n,t){var r=v,a=b;v=n,b=t,Wn(e),v=r,b=a}function Se(e,n){var t=D;while(t&&246===e.parent.kind)t.continueTarget=n,t=t.next,e=e.parent;return n}function xe(e){var n=Se(e,se()),t=oe(),r=oe();ue(n,h),h=n,Ee(e.expression,t,r),h=_e(t),Te(e.statement,r,n),ue(n,h),h=_e(r)}function Le(e){var n=se(),t=Se(e,oe()),r=oe();ue(n,h),h=n,Te(e.statement,r,t),ue(t,h),h=_e(t),Ee(e.expression,n,r),h=_e(r)}function De(e){var n=Se(e,se()),t=oe(),r=oe();Wn(e.initializer),ue(n,h),h=n,Ee(e.condition,t,r),h=_e(t),Te(e.statement,r,n),Wn(e.incrementor),ue(n,h),h=_e(r)}function Ae(e){var n=Se(e,se()),t=oe();Wn(e.expression),ue(n,h),h=n,240===e.kind&&Wn(e.awaitModifier),ue(t,h),Wn(e.initializer),251!==e.initializer.kind&&Ve(e.initializer),Te(e.statement,t,n),ue(n,h),h=_e(t)}function Ce(e){var n=oe(),t=oe(),r=oe();Ee(e.expression,n,t),h=_e(n),Wn(e.thenStatement),ue(r,h),h=_e(t),Wn(e.elseStatement),ue(r,h),h=_e(r)}function Ie(e){Wn(e.expression),243===e.kind&&(A=!0,E&&ue(E,h)),h=w}function Ne(e){for(var n=D;n;n=n.next)if(n.name===e)return n}function ke(e,n,t){var r=242===e.kind?n:t;r&&(ue(r,h),h=w)}function Re(e){if(Wn(e.label),e.label){var n=Ne(e.label.escapedText);n&&(n.referenced=!0,ke(e,n.breakTarget,n.continueTarget))}else ke(e,v,b)}function Oe(n){var t=E,r=x,a=oe(),i=oe(),o=oe();if(n.finallyBlock&&(E=i),ue(o,h),x=o,Wn(n.tryBlock),ue(a,h),n.catchClause&&(h=_e(o),o=oe(),ue(o,h),x=o,Wn(n.catchClause),ue(a,h)),E=t,x=r,n.finallyBlock){var s=oe();s.antecedents=e.concatenate(e.concatenate(a.antecedents,o.antecedents),i.antecedents),h=s,Wn(n.finallyBlock),1&h.flags?h=w:(E&&i.antecedents&&ue(E,ce(s,i.antecedents,h)),x&&o.antecedents&&ue(x,ce(s,o.antecedents,h)),h=a.antecedents?ce(s,a.antecedents,h):w)}else h=_e(a)}function we(n){var t=oe();Wn(n.expression);var r=v,a=L;v=t,L=h,Wn(n.caseBlock),ue(t,h);var i=e.forEach(n.caseBlock.clauses,(function(e){return 286===e.kind}));n.possiblyExhaustive=!i&&!t.antecedents,i||ue(t,pe(L,n,0,0)),v=r,L=a,h=_e(t)}function Pe(e){for(var n=e.clauses,t=Z(e.parent.expression),a=w,i=0;i<n.length;i++){var o=i;while(!n[i].statements.length&&i+1<n.length)Wn(n[i]),i++;var s=oe();ue(s,t?pe(L,e.parent,o,i+1):L),ue(s,a),h=_e(s);var c=n[i];Wn(c),a=h,1&h.flags||i===n.length-1||!r.noFallthroughCasesInSwitch||(c.fallthroughFlowNode=h)}}function Me(e){var n=h;h=L,Wn(e.expression),h=n,X(e.statements)}function Fe(e){Wn(e.expression),Ge(e.expression)}function Ge(n){if(204===n.kind){var t=n;105!==t.expression.kind&&e.isDottedName(t.expression)&&(h=me(h,t))}}function Be(n){var t=oe();D={next:D,name:n.label.escapedText,breakTarget:t,continueTarget:void 0,referenced:!1},Wn(n.label),Wn(n.statement),D.referenced||r.allowUnusedLabels||jn(e.unusedLabelIsError(r),n.label,e.Diagnostics.Unused_label),D=D.next,ue(t,h),h=_e(t)}function Ue(e){217===e.kind&&62===e.operatorToken.kind?Ve(e.left):Ve(e)}function Ve(e){if($(e))h=fe(16,h,e);else if(200===e.kind)for(var n=0,t=e.elements;n<t.length;n++){var r=t[n];221===r.kind?Ve(r.expression):Ue(r)}else if(201===e.kind)for(var a=0,i=e.properties;a<i.length;a++){var o=i[a];289===o.kind?Ue(o.initializer):290===o.kind?Ve(o.name):291===o.kind&&Ve(o.expression)}}function je(n,t,r){var a=oe();55===n.operatorToken.kind||75===n.operatorToken.kind?Ee(n.left,a,r):Ee(n.left,t,a),h=_e(a),Wn(n.operatorToken),e.isLogicalOrCoalescingAssignmentOperator(n.operatorToken.kind)?(be(Wn,n.right,t,r),Ve(n.left),ue(t,de(32,h,n)),ue(r,de(64,h,n))):Ee(n.right,t,r)}function Ke(e){if(53===e.operator){var n=T;T=S,S=n,Y(e),S=T,T=n}else Y(e),45!==e.operator&&46!==e.operator||Ve(e.operand)}function He(e){Y(e),45!==e.operator&&46!==e.operator||Ve(e.operand)}function We(e){R?(R=!1,Wn(e.operatorToken),Wn(e.right),R=!0,Wn(e.left)):(R=!0,Wn(e.left),R=!1,Wn(e.operatorToken),Wn(e.right)),Ve(e.left)}function ze(){return e.createBinaryExpressionTrampoline(n,t,r,a,i,void 0);function n(n,t){if(t){t.stackIndex++,e.setParent(n,s);var r=I;Xn(n);var a=s;s=n,t.skip=!1,t.inStrictModeStack[t.stackIndex]=r,t.parentStack[t.stackIndex]=a}else t={stackIndex:0,skip:!1,inStrictModeStack:[void 0],parentStack:[void 0]};var i=n.operatorToken.kind;if(55===i||56===i||60===i||e.isLogicalOrCoalescingAssignmentOperator(i)){if(ve(n)){var o=oe();je(n,o,o),h=_e(o)}else je(n,T,S);t.skip=!0}return t}function t(e,n,t){if(!n.skip)return o(e)}function r(e,n,t){n.skip||(27===e.kind&&Ge(t.left),Wn(e))}function a(e,n,t){if(!n.skip)return o(e)}function i(n,t){if(!t.skip){var r=n.operatorToken.kind;if(e.isAssignmentOperator(r)&&!e.isAssignmentTarget(n)&&(Ve(n.left),62===r&&203===n.left.kind)){var a=n.left;ie(a.expression)&&(h=fe(256,h,n))}}var i=t.inStrictModeStack[t.stackIndex],o=t.parentStack[t.stackIndex];void 0!==i&&(I=i),void 0!==o&&(s=o),t.skip=!1,t.stackIndex--}function o(n){if(n&&e.isBinaryExpression(n)&&!e.isDestructuringAssignment(n))return n;Wn(n)}}function qe(e){Y(e),202===e.expression.kind&&Ve(e.expression)}function Je(e){var n=oe(),t=oe(),r=oe();Ee(e.condition,n,t),h=_e(n),Wn(e.questionToken),Wn(e.whenTrue),ue(r,h),h=_e(t),Wn(e.colonToken),Wn(e.whenFalse),ue(r,h),h=_e(r)}function Xe(n){var t=e.isOmittedExpression(n)?void 0:n.name;if(e.isBindingPattern(t))for(var r=0,a=t.elements;r<a.length;r++){var i=a[r];Xe(i)}else h=fe(16,h,n)}function Ye(n){Y(n),(n.initializer||e.isForInOrOfStatement(n.parent.parent))&&Xe(n)}function Qe(n){e.isBindingPattern(n.name)?(X(n.decorators),X(n.modifiers),Wn(n.dotDotDotToken),Wn(n.propertyName),Wn(n.initializer),Wn(n.name)):Y(n)}function Ze(n){e.setParent(n.tagName,n),329!==n.kind&&n.fullName&&(e.setParent(n.fullName,n),e.setParentRecursive(n.fullName,!1))}function $e(n){Y(n);var t=e.getHostSignatureFromJSDoc(n);t&&166!==t.kind&&V(t.symbol,t,32)}function en(n,t,r){be(Wn,n,t,r),e.isOptionalChain(n)&&!e.isOutermostOptionalChain(n)||(ue(t,de(32,h,n)),ue(r,de(64,h,n)))}function nn(e){switch(e.kind){case 202:Wn(e.questionDotToken),Wn(e.name);break;case 203:Wn(e.questionDotToken),Wn(e.argumentExpression);break;case 204:Wn(e.questionDotToken),X(e.typeArguments),X(e.arguments);break}}function tn(n,t,r){var a=e.isOptionalChainRoot(n)?oe():void 0;en(n.expression,a||t,r),a&&(h=_e(a)),be(nn,n,t,r),e.isOutermostOptionalChain(n)&&(ue(t,de(32,h,n)),ue(r,de(64,h,n)))}function rn(e){if(ve(e)){var n=oe();tn(e,n,n),h=_e(n)}else tn(e,T,S)}function an(n){e.isOptionalChain(n)?rn(n):Y(n)}function on(n){e.isOptionalChain(n)?rn(n):Y(n)}function sn(n){if(e.isOptionalChain(n))rn(n);else{var t=e.skipParentheses(n.expression);209===t.kind||210===t.kind?(X(n.typeArguments),X(n.arguments),Wn(n.expression)):(Y(n),105===n.expression.kind&&(h=me(h,n)))}if(202===n.expression.kind){var r=n.expression;e.isIdentifier(r.name)&&ie(r.expression)&&e.isPushOrUnshiftIdentifier(r.name)&&(h=fe(256,h,n))}}function cn(n){switch(n.kind){case 222:case 253:case 256:case 201:case 178:case 314:case 282:return 1;case 254:return 65;case 257:case 255:case 191:return 33;case 298:return 37;case 166:if(e.isObjectLiteralOrClassExpressionMethod(n))return 173;case 167:case 252:case 165:case 168:case 169:case 170:case 315:case 309:case 175:case 171:case 172:case 176:return 45;case 209:case 210:return 61;case 258:return 4;case 164:return n.initializer?4:0;case 288:case 238:case 239:case 240:case 259:return 2;case 231:return e.isFunctionLike(n.parent)?0:2}return 0}function ln(e){f&&(f.nextContainer=e),f=e}function un(e,n,t){switch(l.kind){case 257:return W(e,n,t);case 298:return pn(e,n,t);case 222:case 253:return dn(e,n,t);case 256:return H(l.symbol.exports,l.symbol,e,n,t);case 178:case 314:case 201:case 254:case 282:return H(l.symbol.members,l.symbol,e,n,t);case 175:case 176:case 170:case 171:case 315:case 172:case 166:case 165:case 167:case 168:case 169:case 252:case 209:case 210:case 309:case 335:case 328:case 255:case 191:return H(l.locals,void 0,e,n,t)}}function dn(n,t,r){return e.hasSyntacticModifier(n,32)?H(l.symbol.exports,l.symbol,n,t,r):H(l.symbol.members,l.symbol,n,t,r)}function pn(t,r,a){return e.isExternalModule(n)?W(t,r,a):H(n.locals,void 0,t,r,a)}function fn(n){var t=e.isSourceFile(n)?n:e.tryCast(n.body,e.isModuleBlock);return!!t&&t.statements.some((function(n){return e.isExportDeclaration(n)||e.isExportAssignment(n)}))}function mn(e){8388608&e.flags&&!fn(e)?e.flags|=64:e.flags&=-65}function _n(t){if(mn(t),e.isAmbientModule(t))if(e.hasSyntacticModifier(t,1)&&Vn(t,e.Diagnostics.export_modifier_cannot_be_applied_to_ambient_modules_and_module_augmentations_since_they_are_always_visible),e.isModuleAugmentationExternal(t))gn(t);else{var r=void 0;if(10===t.name.kind){var a=t.name.text;e.hasZeroOrOneAsteriskCharacter(a)?r=e.tryParsePattern(a):Vn(t.name,e.Diagnostics.Pattern_0_can_have_at_most_one_Asterisk_character,a)}var i=un(t,512,110735);n.patternAmbientModules=e.append(n.patternAmbientModules,r&&{pattern:r,symbol:i})}else{var o=gn(t);if(0!==o){i=t.symbol;i.constEnumOnlyModule=!(304&i.flags)&&2===o&&!1!==i.constEnumOnlyModule}}}function gn(e){var n=t(e),r=0!==n;return un(e,r?512:1024,r?110735:0),n}function yn(n){var t=U(131072,j(n));V(t,n,131072);var r=U(2048,"__type");V(r,n,2048),r.members=e.createSymbolTable(),r.members.set(t.escapedName,t)}function hn(t){var r;if(function(e){e[e["Property"]=1]="Property",e[e["Accessor"]=2]="Accessor"}(r||(r={})),I&&!e.isAssignmentTarget(t))for(var a=new e.Map,i=0,o=t.properties;i<o.length;i++){var s=o[i];if(291!==s.kind&&78===s.name.kind){var c=s.name,l=289===s.kind||290===s.kind||166===s.kind?1:2,u=a.get(c.escapedText);if(u){if(1===l&&1===u){var d=e.getErrorSpanForNode(n,c);n.bindDiagnostics.push(e.createFileDiagnostic(n,d.start,d.length,e.Diagnostics.An_object_literal_cannot_have_multiple_properties_with_the_same_name_in_strict_mode))}}else a.set(c.escapedText,l)}}return En(t,4096,"__object")}function vn(e){return En(e,4096,"__jsxAttributes")}function bn(e,n,t){return un(e,n,t)}function En(e,n,t){var r=U(n,t);return 106508&n&&(r.parent=l.symbol),V(r,e,n),r}function Tn(n,t,r){switch(d.kind){case 257:W(n,t,r);break;case 298:if(e.isExternalOrCommonJsModule(l)){W(n,t,r);break}default:d.locals||(d.locals=e.createSymbolTable(),ln(d)),H(d.locals,void 0,n,t,r)}}function Sn(){if(m){for(var t=l,r=f,a=d,i=s,o=h,u=0,p=m;u<p.length;u++){var g=p[u],y=g.parent.parent;l=e.findAncestor(y.parent,(function(e){return!!(1&cn(e))}))||n,d=e.getEnclosingBlockScopeContainer(y)||n,h=c({flags:2}),s=g,Wn(g.typeExpression);var v=e.getNameOfDeclaration(g);if((e.isJSDocEnumTag(g)||!g.fullName)&&v&&e.isPropertyAccessEntityNameExpression(v.parent)){var b=Et(v.parent);if(b){vt(n.symbol,v.parent,b,!!e.findAncestor(v,(function(n){return e.isPropertyAccessExpression(n)&&"prototype"===n.name.escapedText})),!1);var E=l;switch(e.getAssignmentDeclarationPropertyAccessKind(v.parent)){case 1:case 2:l=e.isExternalOrCommonJsModule(n)?n:void 0;break;case 4:l=v.parent.expression;break;case 3:l=v.parent.expression.name;break;case 5:l=_(n,v.parent.expression)?n:e.isPropertyAccessExpression(v.parent.expression)?v.parent.expression.name:v.parent.expression;break;case 0:return e.Debug.fail("Shouldn't have detected typedef or enum on non-assignment declaration")}l&&W(g,524288,788968),l=E}}else e.isJSDocEnumTag(g)||!g.fullName||78===g.fullName.kind?(s=g.parent,Tn(g,524288,788968)):Wn(g.fullName)}l=t,f=r,d=a,s=i,h=o}}function xn(t){n.parseDiagnostics.length||8388608&t.flags||4194304&t.flags||e.isIdentifierName(t)||(I&&t.originalKeywordKind>=116&&t.originalKeywordKind<=124?n.bindDiagnostics.push(F(t,Ln(t),e.declarationNameToString(t))):130===t.originalKeywordKind?e.isExternalModule(n)&&e.isInTopLevelContext(t)?n.bindDiagnostics.push(F(t,e.Diagnostics.Identifier_expected_0_is_a_reserved_word_at_the_top_level_of_a_module,e.declarationNameToString(t))):32768&t.flags&&n.bindDiagnostics.push(F(t,e.Diagnostics.Identifier_expected_0_is_a_reserved_word_that_cannot_be_used_here,e.declarationNameToString(t))):124===t.originalKeywordKind&&8192&t.flags&&n.bindDiagnostics.push(F(t,e.Diagnostics.Identifier_expected_0_is_a_reserved_word_that_cannot_be_used_here,e.declarationNameToString(t))))}function Ln(t){return e.getContainingClass(t)?e.Diagnostics.Identifier_expected_0_is_a_reserved_word_in_strict_mode_Class_definitions_are_automatically_in_strict_mode:n.externalModuleIndicator?e.Diagnostics.Identifier_expected_0_is_a_reserved_word_in_strict_mode_Modules_are_automatically_in_strict_mode:e.Diagnostics.Identifier_expected_0_is_a_reserved_word_in_strict_mode}function Dn(t){"#constructor"===t.escapedText&&(n.parseDiagnostics.length||n.bindDiagnostics.push(F(t,e.Diagnostics.constructor_is_a_reserved_word,e.declarationNameToString(t))))}function An(n){I&&e.isLeftHandSideExpression(n.left)&&e.isAssignmentOperator(n.operatorToken.kind)&&kn(n,n.left)}function Cn(e){I&&e.variableDeclaration&&kn(e,e.variableDeclaration.name)}function In(t){if(I&&78===t.expression.kind){var r=e.getErrorSpanForNode(n,t.expression);n.bindDiagnostics.push(e.createFileDiagnostic(n,r.start,r.length,e.Diagnostics.delete_cannot_be_called_on_an_identifier_in_strict_mode))}}function Nn(n){return e.isIdentifier(n)&&("eval"===n.escapedText||"arguments"===n.escapedText)}function kn(t,r){if(r&&78===r.kind){var a=r;if(Nn(a)){var i=e.getErrorSpanForNode(n,r);n.bindDiagnostics.push(e.createFileDiagnostic(n,i.start,i.length,Rn(t),e.idText(a)))}}}function Rn(t){return e.getContainingClass(t)?e.Diagnostics.Invalid_use_of_0_Class_definitions_are_automatically_in_strict_mode:n.externalModuleIndicator?e.Diagnostics.Invalid_use_of_0_Modules_are_automatically_in_strict_mode:e.Diagnostics.Invalid_use_of_0_in_strict_mode}function On(e){I&&kn(e,e.name)}function wn(t){return e.getContainingClass(t)?e.Diagnostics.Function_declarations_are_not_allowed_inside_blocks_in_strict_mode_when_targeting_ES3_or_ES5_Class_definitions_are_automatically_in_strict_mode:n.externalModuleIndicator?e.Diagnostics.Function_declarations_are_not_allowed_inside_blocks_in_strict_mode_when_targeting_ES3_or_ES5_Modules_are_automatically_in_strict_mode:e.Diagnostics.Function_declarations_are_not_allowed_inside_blocks_in_strict_mode_when_targeting_ES3_or_ES5}function Pn(t){if(a<2&&298!==d.kind&&257!==d.kind&&!e.isFunctionLike(d)){var r=e.getErrorSpanForNode(n,t);n.bindDiagnostics.push(e.createFileDiagnostic(n,r.start,r.length,wn(t)))}}function Mn(t){I&&32&t.numericLiteralFlags&&n.bindDiagnostics.push(F(t,e.Diagnostics.Octal_literals_are_not_allowed_in_strict_mode))}function Fn(e){I&&kn(e,e.operand)}function Gn(e){I&&(45!==e.operator&&46!==e.operator||kn(e,e.operand))}function Bn(n){I&&Vn(n,e.Diagnostics.with_statements_are_not_allowed_in_strict_mode)}function Un(n){I&&r.target>=2&&(e.isDeclarationStatement(n.statement)||e.isVariableStatement(n.statement))&&Vn(n.label,e.Diagnostics.A_label_is_not_allowed_here)}function Vn(t,r,a,i,o){var s=e.getSpanOfTokenAtPosition(n,t.pos);n.bindDiagnostics.push(e.createFileDiagnostic(n,s.start,s.length,r,a,i,o))}function jn(e,n,t){Kn(e,n,n,t)}function Kn(t,r,a,i){Hn(t,{pos:e.getTokenPosOfNode(r,n),end:a.end},i)}function Hn(t,r,a){var i=e.createFileDiagnostic(n,r.pos,r.end-r.pos,a);t?n.bindDiagnostics.push(i):n.bindSuggestionDiagnostics=e.append(n.bindSuggestionDiagnostics,o(o({},i),{category:e.DiagnosticCategory.Suggestion}))}function Wn(n){if(n){e.setParent(n,s);var t=I;if(Xn(n),n.kind>157){var r=s;s=n;var a=cn(n);0===a?Q(n):q(n,a),s=r}else{r=s;1===n.kind&&(s=n),zn(n),s=r}I=t}}function zn(n){if(e.hasJSDocNodes(n))if(e.isInJSFile(n))for(var t=0,r=n.jsDoc;t<r.length;t++){var a=r[t];Wn(a)}else for(var i=0,o=n.jsDoc;i<o.length;i++){a=o[i];e.setParent(a,n),e.setParentRecursive(a,!1)}}function qn(n){if(!I)for(var t=0,r=n;t<r.length;t++){var a=r[t];if(!e.isPrologueDirective(a))return;if(Jn(a))return void(I=!0)}}function Jn(t){var r=e.getSourceTextOfNodeFromSourceFile(n,t.expression);return'"use strict"'===r||"'use strict'"===r}function Xn(t){switch(t.kind){case 78:if(t.isInJSDocNamespace){var r=t.parent;while(r&&!e.isJSDocTypeAlias(r))r=r.parent;Tn(r,524288,788968);break}case 107:return h&&(e.isExpression(t)||290===s.kind)&&(t.flowNode=h),xn(t);case 158:h&&177===s.kind&&(t.flowNode=h);break;case 227:case 105:t.flowNode=h;break;case 79:return Dn(t);case 202:case 203:var a=t;h&&$(a)&&(a.flowNode=h),e.isSpecialPropertyDeclaration(a)&&pt(a),e.isInJSFile(a)&&n.commonJsModuleIndicator&&e.isModuleExportsAccessExpression(a)&&!g(d,"module")&&H(n.locals,void 0,a.expression,134217729,111550);break;case 217:var i=e.getAssignmentDeclarationKind(t);switch(i){case 1:ot(t);break;case 2:st(t);break;case 3:_t(t.left,t);break;case 6:ft(t);break;case 4:lt(t);break;case 5:var o=t.left.expression;if(e.isInJSFile(t)&&e.isIdentifier(o)){var c=g(d,o.escapedText);if(e.isThisInitializedDeclaration(null===c||void 0===c?void 0:c.valueDeclaration)){lt(t);break}}yt(t);break;case 0:break;default:e.Debug.fail("Unknown binary expression special property assignment kind")}return An(t);case 288:return Cn(t);case 211:return In(t);case 8:return Mn(t);case 216:return Fn(t);case 215:return Gn(t);case 244:return Bn(t);case 246:return Un(t);case 188:return void(y=!0);case 173:break;case 160:return Mt(t);case 161:return kt(t);case 250:return Nt(t);case 199:return t.flowNode=h,Nt(t);case 164:case 163:return Yn(t);case 289:case 290:return wt(t,4,0);case 292:return wt(t,8,900095);case 170:case 171:case 172:return un(t,131072,0);case 166:case 165:return wt(t,8192|(t.questionToken?16777216:0),e.isObjectLiteralMethod(t)?0:103359);case 252:return Rt(t);case 167:return un(t,16384,0);case 168:return wt(t,32768,46015);case 169:return wt(t,65536,78783);case 175:case 309:case 315:case 176:return yn(t);case 178:case 314:case 191:return Qn(t);case 322:return $e(t);case 201:return hn(t);case 209:case 210:return Ot(t);case 204:var l=e.getAssignmentDeclarationKind(t);switch(l){case 7:return gt(t);case 8:return it(t);case 9:return mt(t);case 0:break;default:return e.Debug.fail("Unknown call expression assignment declaration kind")}e.isInJSFile(t)&&At(t);break;case 222:case 253:return I=!0,Ct(t);case 254:return Tn(t,64,788872);case 255:return Tn(t,524288,788968);case 256:return It(t);case 257:return _n(t);case 282:return vn(t);case 281:return bn(t,4,0);case 261:case 264:case 266:case 271:return un(t,2097152,2097152);case 260:return nt(t);case 263:return rt(t);case 268:return tt(t);case 267:return et(t);case 298:return qn(t.statements),Zn();case 231:if(!e.isFunctionLike(t.parent))return;case 258:return qn(t.statements);case 330:if(315===t.parent.kind)return kt(t);if(314!==t.parent.kind)break;case 337:var u=t,p=u.isBracketed||u.typeExpression&&308===u.typeExpression.type.kind?16777220:4;return un(u,p,0);case 335:case 328:case 329:return(m||(m=[])).push(t)}}function Yn(e){return wt(e,4|(e.questionToken?16777216:0),0)}function Qn(e){return En(e,2048,"__type")}function Zn(){if(mn(n),e.isExternalModule(n))$n();else if(e.isJsonSourceFile(n)){$n();var t=n.symbol;H(n.symbol.exports,n.symbol,n,4,67108863),n.symbol=t}}function $n(){En(n,512,'"'+e.removeFileExtension(n.fileName)+'"')}function et(n){if(l.symbol&&l.symbol.exports){var t=e.exportAssignmentIsAlias(n)?2097152:4,r=H(l.symbol.exports,l.symbol,n,t,67108863);n.isExportEquals&&e.setValueDeclaration(r,n)}else En(n,111551,j(n))}function nt(t){t.modifiers&&t.modifiers.length&&n.bindDiagnostics.push(F(t,e.Diagnostics.Modifiers_cannot_appear_here));var r=e.isSourceFile(t.parent)?e.isExternalModule(t.parent)?t.parent.isDeclarationFile?void 0:e.Diagnostics.Global_module_exports_may_only_appear_in_declaration_files:e.Diagnostics.Global_module_exports_may_only_appear_in_module_files:e.Diagnostics.Global_module_exports_may_only_appear_at_top_level;r?n.bindDiagnostics.push(F(t,r)):(n.symbol.globalExports=n.symbol.globalExports||e.createSymbolTable(),H(n.symbol.globalExports,n.symbol,t,2097152,2097152))}function tt(n){l.symbol&&l.symbol.exports?n.exportClause?e.isNamespaceExport(n.exportClause)&&(e.setParent(n.exportClause,n),H(l.symbol.exports,l.symbol,n.exportClause,2097152,2097152)):H(l.symbol.exports,l.symbol,n,8388608,0):En(n,8388608,j(n))}function rt(e){e.name&&un(e,2097152,2097152)}function at(e){return!n.externalModuleIndicator&&(n.commonJsModuleIndicator||(n.commonJsModuleIndicator=e,$n()),!0)}function it(e){if(at(e)){var n=Dt(e.arguments[0],void 0,(function(e,n){return n&&V(n,e,67110400),n}));if(n){var t=1048580;H(n.exports,n,e,t,0)}}}function ot(n){if(at(n)){var t=Dt(n.left.expression,void 0,(function(e,n){return n&&V(n,e,67110400),n}));if(t){var r=e.isAliasableExpression(n.right)&&(e.isExportsIdentifier(n.left.expression)||e.isModuleExportsAccessExpression(n.left.expression)),a=r?2097152:1048580;e.setParent(n.left,n),H(t.exports,t,n.left,a,0)}}}function st(t){if(at(t)){var r=e.getRightMostAssignedExpression(t.right);if(!(e.isEmptyObjectLiteral(r)||l===n&&_(n,r)))if(e.isObjectLiteralExpression(r)&&e.every(r.properties,e.isShorthandPropertyAssignment))e.forEach(r.properties,ct);else{var a=e.exportAssignmentIsAlias(t)?2097152:1049092,i=H(n.symbol.exports,n.symbol,t,67108864|a,0);e.setValueDeclaration(i,t)}}}function ct(e){H(n.symbol.exports,n.symbol,e,69206016,0)}function lt(n){e.Debug.assert(e.isInJSFile(n));var t=e.isBinaryExpression(n)&&e.isPropertyAccessExpression(n.left)&&e.isPrivateIdentifier(n.left.name)||e.isPropertyAccessExpression(n)&&e.isPrivateIdentifier(n.name);if(!t){var r=e.getThisContainer(n,!1);switch(r.kind){case 252:case 209:var a=r.symbol;if(e.isBinaryExpression(r.parent)&&62===r.parent.operatorToken.kind){var i=r.parent.left;e.isBindableStaticAccessExpression(i)&&e.isPrototypeAccess(i.expression)&&(a=Lt(i.expression.expression,u))}a&&a.valueDeclaration&&(a.members=a.members||e.createSymbolTable(),e.hasDynamicName(n)?ut(n,a):H(a.members,a,n,67108868,0),V(a,a.valueDeclaration,32));break;case 167:case 164:case 166:case 168:case 169:var o=r.parent,s=e.hasSyntacticModifier(r,32)?o.symbol.exports:o.symbol.members;e.hasDynamicName(n)?ut(n,o.symbol):H(s,o.symbol,n,67108868,0,!0);break;case 298:if(e.hasDynamicName(n))break;r.commonJsModuleIndicator?H(r.symbol.exports,r.symbol,n,1048580,0):un(n,1,111550);break;default:e.Debug.failBadSyntaxKind(r)}}}function ut(e,n){En(e,4,"__computed"),dt(e,n)}function dt(n,t){t&&(t.assignmentDeclarationMembers||(t.assignmentDeclarationMembers=new e.Map)).set(e.getNodeId(n),n)}function pt(n){107===n.expression.kind?lt(n):e.isBindableStaticAccessExpression(n)&&298===n.parent.parent.kind&&(e.isPrototypeAccess(n.expression)?_t(n,n.parent):ht(n))}function ft(n){e.setParent(n.left,n),e.setParent(n.right,n),Tt(n.left.expression,n.left,!1,!0)}function mt(e){var n=Lt(e.arguments[0].expression);n&&n.valueDeclaration&&V(n,n.valueDeclaration,32),bt(e,n,!0)}function _t(n,t){var r=n.expression,a=r.expression;e.setParent(a,r),e.setParent(r,n),e.setParent(n,t),Tt(a,n,!0,!0)}function gt(e){var n=Lt(e.arguments[0]),t=298===e.parent.parent.kind;n=vt(n,e.arguments[0],t,!1,!1),bt(e,n,!1)}function yt(t){var r,a=Lt(t.left.expression,l)||Lt(t.left.expression,d);if(e.isInJSFile(t)||e.isFunctionSymbol(a)){var i=e.getLeftmostAccessExpression(t.left);if(!(e.isIdentifier(i)&&2097152&(null===(r=g(l,i.escapedText))||void 0===r?void 0:r.flags)))if(e.setParent(t.left,t),e.setParent(t.right,t),e.isIdentifier(t.left.expression)&&l===n&&_(n,t.left.expression))ot(t);else if(e.hasDynamicName(t)){En(t,67108868,"__computed");var o=vt(a,t.left.expression,Et(t.left),!1,!1);dt(t,o)}else ht(e.cast(t.left,e.isBindableStaticNameExpression))}}function ht(n){e.Debug.assert(!e.isIdentifier(n)),e.setParent(n.expression,n),Tt(n.expression,n,!1,!1)}function vt(t,r,a,i,o){if(2097152&(null===t||void 0===t?void 0:t.flags))return t;if(a&&!i){var s=67110400,c=110735;t=Dt(r,t,(function(t,r,a){if(r)return V(r,t,s),r;var i=a?a.exports:n.jsGlobalAugmentations||(n.jsGlobalAugmentations=e.createSymbolTable());return H(i,a,t,s,c)}))}return o&&t&&t.valueDeclaration&&V(t,t.valueDeclaration,32),t}function bt(n,t,r){if(t&&St(t)){var a=r?t.members||(t.members=e.createSymbolTable()):t.exports||(t.exports=e.createSymbolTable()),i=0,o=0;e.isFunctionLikeDeclaration(e.getAssignedExpandoInitializer(n))?(i=8192,o=103359):e.isCallExpression(n)&&e.isBindableObjectDefinePropertyCall(n)&&(e.some(n.arguments[2].properties,(function(n){var t=e.getNameOfDeclaration(n);return!!t&&e.isIdentifier(t)&&"set"===e.idText(t)}))&&(i|=65540,o|=78783),e.some(n.arguments[2].properties,(function(n){var t=e.getNameOfDeclaration(n);return!!t&&e.isIdentifier(t)&&"get"===e.idText(t)}))&&(i|=32772,o|=46015)),0===i&&(i=4,o=0),H(a,t,n,67108864|i,-67108865&o)}}function Et(n){return e.isBinaryExpression(n.parent)?298===xt(n.parent).parent.kind:298===n.parent.parent.kind}function Tt(e,n,t,r){var a=Lt(e,l)||Lt(e,d),i=Et(n);a=vt(a,n.expression,i,t,r),bt(n,a,t)}function St(n){if(1072&n.flags)return!0;var t=n.valueDeclaration;if(t&&e.isCallExpression(t))return!!e.getAssignedExpandoInitializer(t);var r=t?e.isVariableDeclaration(t)?t.initializer:e.isBinaryExpression(t)?t.right:e.isPropertyAccessExpression(t)&&e.isBinaryExpression(t.parent)?t.parent.right:void 0:void 0;if(r=r&&e.getRightMostAssignedExpression(r),r){var a=e.isPrototypeAccess(e.isVariableDeclaration(t)?t.name:e.isBinaryExpression(t)?t.left:t);return!!e.getExpandoInitializer(!e.isBinaryExpression(r)||56!==r.operatorToken.kind&&60!==r.operatorToken.kind?r:r.right,a)}return!1}function xt(n){while(e.isBinaryExpression(n.parent))n=n.parent;return n.parent}function Lt(n,t){if(void 0===t&&(t=l),e.isIdentifier(n))return g(t,n.escapedText);var r=Lt(n.expression);return r&&r.exports&&r.exports.get(e.getElementOrPropertyAccessName(n))}function Dt(t,r,a){if(_(n,t))return n.symbol;if(e.isIdentifier(t))return a(t,Lt(t),r);var i=Dt(t.expression,r,a),o=e.getNameOrArgument(t);return e.isPrivateIdentifier(o)&&e.Debug.fail("unexpected PrivateIdentifier"),a(o,i&&i.exports&&i.exports.get(e.getElementOrPropertyAccessName(t)),i)}function At(t){!n.commonJsModuleIndicator&&e.isRequireCall(t,!1)&&at(t)}function Ct(t){if(253===t.kind)Tn(t,32,899503);else{var r=t.name?t.name.escapedText:"__class";En(t,32,r),t.name&&k.add(t.name.escapedText)}var a=t.symbol,i=U(4194308,"prototype"),o=a.exports.get(i.escapedName);o&&(t.name&&e.setParent(t.name,t),n.bindDiagnostics.push(F(o.declarations[0],e.Diagnostics.Duplicate_identifier_0,e.symbolName(i)))),a.exports.set(i.escapedName,i),i.parent=a}function It(n){return e.isEnumConst(n)?Tn(n,128,899967):Tn(n,256,899327)}function Nt(n){I&&kn(n,n.name),e.isBindingPattern(n.name)||(e.isInJSFile(n)&&e.isRequireVariableDeclaration(n)&&!e.getJSDocTypeTag(n)?un(n,2097152,2097152):e.isBlockOrCatchScoped(n)?Tn(n,2,111551):e.isParameterDeclaration(n)?un(n,1,111551):un(n,1,111550))}function kt(n){if((330!==n.kind||315===l.kind)&&(!I||8388608&n.flags||kn(n,n.name),e.isBindingPattern(n.name)?En(n,1,"__"+n.parent.parameters.indexOf(n)):un(n,1,111551),e.isParameterPropertyDeclaration(n,n.parent))){var t=n.parent.parent;H(t.symbol.members,t.symbol,n,4|(n.questionToken?16777216:0),0)}}function Rt(t){n.isDeclarationFile||8388608&t.flags||e.isAsyncFunction(t)&&(C|=2048),On(t),I?(Pn(t),Tn(t,16,110991)):un(t,16,110991)}function Ot(t){n.isDeclarationFile||8388608&t.flags||e.isAsyncFunction(t)&&(C|=2048),h&&(t.flowNode=h),On(t);var r=t.name?t.name.escapedText:"__function";return En(t,16,r)}function wt(t,r,a){return n.isDeclarationFile||8388608&t.flags||!e.isAsyncFunction(t)||(C|=2048),h&&e.isObjectLiteralOrClassExpressionMethod(t)&&(t.flowNode=h),e.hasDynamicName(t)?En(t,r,"__computed"):un(t,r,a)}function Pt(n){var t=e.findAncestor(n,(function(n){return n.parent&&e.isConditionalTypeNode(n.parent)&&n.parent.extendsType===n}));return t&&t.parent}function Mt(n){if(e.isJSDocTemplateTag(n.parent)){var t=e.find(n.parent.parent.tags,e.isJSDocTypeAlias)||e.getHostSignatureFromJSDoc(n.parent);t?(t.locals||(t.locals=e.createSymbolTable()),H(t.locals,void 0,n,262144,526824)):un(n,262144,526824)}else if(186===n.parent.kind){var r=Pt(n.parent);r?(r.locals||(r.locals=e.createSymbolTable()),H(r.locals,void 0,n,262144,526824)):En(n,262144,j(n))}else un(n,262144,526824)}function Ft(n){var a=t(n);return 1===a||2===a&&e.shouldPreserveConstEnums(r)}function Gt(n){if(!(1&h.flags))return!1;if(h===w){var t=e.isStatementButNotDeclaration(n)&&232!==n.kind||253===n.kind||257===n.kind&&Ft(n);if(t&&(h=P,!r.allowUnreachableCode)){var a=e.unreachableCodeIsError(r)&&!(8388608&n.flags)&&(!e.isVariableStatement(n)||!!(3&e.getCombinedNodeFlags(n.declarationList))||n.declarationList.declarations.some((function(e){return!!e.initializer})));p(n,(function(n,t){return Kn(a,n,t,e.Diagnostics.Unreachable_code_detected)}))}}return!0}}function p(n,t){if(e.isStatement(n)&&f(n)&&e.isBlock(n.parent)){var r=n.parent.statements,a=e.sliceAfter(r,n);e.getRangesWhere(a,f,(function(e,n){return t(a[e],a[n-1])}))}else t(n,n)}function f(n){return!e.isFunctionDeclaration(n)&&!m(n)&&!e.isEnumDeclaration(n)&&!(e.isVariableStatement(n)&&!(3&e.getCombinedNodeFlags(n))&&n.declarationList.declarations.some((function(e){return!e.initializer})))}function m(n){switch(n.kind){case 254:case 255:return!0;case 257:return 1!==t(n);case 256:return e.hasSyntacticModifier(n,2048);default:return!1}}function _(n,t){var r=0,a=[t];while(a.length&&r<100){if(r++,t=a.shift(),e.isExportsIdentifier(t)||e.isModuleExportsAccessExpression(t))return!0;if(e.isIdentifier(t)){var i=g(n,t.escapedText);if(i&&i.valueDeclaration&&e.isVariableDeclaration(i.valueDeclaration)&&i.valueDeclaration.initializer){var o=i.valueDeclaration.initializer;a.push(o),e.isAssignmentExpression(o,!0)&&(a.push(o.left),a.push(o.right))}}}return!1}function g(n,t){var r=n.locals&&n.locals.get(t);return r?r.exportSymbol||r:e.isSourceFile(n)&&n.jsGlobalAugmentations&&n.jsGlobalAugmentations.has(t)?n.jsGlobalAugmentations.get(t):n.symbol&&n.symbol.exports&&n.symbol.exports.get(t)}e.bindSourceFile=u,e.isExportsOrModuleExportsOrAlias=_}(d||(d={})),function(e){function n(n,t,r,a,i,o,s,c,l,u,d){return p;function p(p){void 0===p&&(p=function(){return!0});var f=[],m=[];return{walkType:function(n){try{return _(n),{visitedTypes:e.getOwnValues(f),visitedSymbols:e.getOwnValues(m)}}finally{e.clear(f),e.clear(m)}},walkSymbol:function(n){try{return L(n),{visitedTypes:e.getOwnValues(f),visitedSymbols:e.getOwnValues(m)}}finally{e.clear(f),e.clear(m)}}};function _(e){if(e&&!f[e.id]){f[e.id]=e;var n=L(e.symbol);if(!n){if(524288&e.flags){var t=e,r=t.objectFlags;4&r&&g(e),32&r&&E(e),3&r&&S(e),24&r&&x(t)}262144&e.flags&&y(e),3145728&e.flags&&h(e),4194304&e.flags&&v(e),8388608&e.flags&&b(e)}}}function g(n){_(n.target),e.forEach(d(n),_)}function y(e){_(l(e))}function h(n){e.forEach(n.types,_)}function v(e){_(e.type)}function b(e){_(e.objectType),_(e.indexType),_(e.constraint)}function E(e){_(e.typeParameter),_(e.constraintType),_(e.templateType),_(e.modifiersType)}function T(a){var i=t(a);i&&_(i.type),e.forEach(a.typeParameters,_);for(var o=0,s=a.parameters;o<s.length;o++){var c=s[o];L(c)}_(n(a)),_(r(a))}function S(n){x(n),e.forEach(n.typeParameters,_),e.forEach(a(n),_),_(n.thisType)}function x(e){var n=c(e,0);_(n);var t=c(e,1);_(t);for(var r=i(e),a=0,o=r.callSignatures;a<o.length;a++){var s=o[a];T(s)}for(var l=0,u=r.constructSignatures;l<u.length;l++){s=u[l];T(s)}for(var d=0,p=r.properties;d<p.length;d++){var f=p[d];L(f)}}function L(n){if(!n)return!1;var t=e.getSymbolId(n);if(m[t])return!1;if(m[t]=n,!p(n))return!0;var r=o(n);return _(r),n.exports&&n.exports.forEach(L),e.forEach(n.declarations,(function(e){if(e.type&&177===e.type.kind){var n=e.type,t=s(u(n.exprName));L(t)}})),!1}}}e.createGetSymbolWalker=n}(d||(d={})),function(e){var n,t,r,a,s=/^".+"$/,l="(anonymous)",u=1,d=1,p=1,f=1;(function(e){e[e["AllowsSyncIterablesFlag"]=1]="AllowsSyncIterablesFlag",e[e["AllowsAsyncIterablesFlag"]=2]="AllowsAsyncIterablesFlag",e[e["AllowsStringInputFlag"]=4]="AllowsStringInputFlag",e[e["ForOfFlag"]=8]="ForOfFlag",e[e["YieldStarFlag"]=16]="YieldStarFlag",e[e["SpreadFlag"]=32]="SpreadFlag",e[e["DestructuringFlag"]=64]="DestructuringFlag",e[e["PossiblyOutOfBounds"]=128]="PossiblyOutOfBounds",e[e["Element"]=1]="Element",e[e["Spread"]=33]="Spread",e[e["Destructuring"]=65]="Destructuring",e[e["ForOf"]=13]="ForOf",e[e["ForAwaitOf"]=15]="ForAwaitOf",e[e["YieldStar"]=17]="YieldStar",e[e["AsyncYieldStar"]=19]="AsyncYieldStar",e[e["GeneratorReturnType"]=1]="GeneratorReturnType",e[e["AsyncGeneratorReturnType"]=2]="AsyncGeneratorReturnType"})(n||(n={})),function(e){e[e["Yield"]=0]="Yield",e[e["Return"]=1]="Return",e[e["Next"]=2]="Next"}(t||(t={})),function(e){e[e["Normal"]=0]="Normal",e[e["FunctionReturn"]=1]="FunctionReturn",e[e["GeneratorNext"]=2]="GeneratorNext",e[e["GeneratorYield"]=3]="GeneratorYield"}(r||(r={})),function(e){e[e["None"]=0]="None",e[e["TypeofEQString"]=1]="TypeofEQString",e[e["TypeofEQNumber"]=2]="TypeofEQNumber",e[e["TypeofEQBigInt"]=4]="TypeofEQBigInt",e[e["TypeofEQBoolean"]=8]="TypeofEQBoolean",e[e["TypeofEQSymbol"]=16]="TypeofEQSymbol",e[e["TypeofEQObject"]=32]="TypeofEQObject",e[e["TypeofEQFunction"]=64]="TypeofEQFunction",e[e["TypeofEQHostObject"]=128]="TypeofEQHostObject",e[e["TypeofNEString"]=256]="TypeofNEString",e[e["TypeofNENumber"]=512]="TypeofNENumber",e[e["TypeofNEBigInt"]=1024]="TypeofNEBigInt",e[e["TypeofNEBoolean"]=2048]="TypeofNEBoolean",e[e["TypeofNESymbol"]=4096]="TypeofNESymbol",e[e["TypeofNEObject"]=8192]="TypeofNEObject",e[e["TypeofNEFunction"]=16384]="TypeofNEFunction",e[e["TypeofNEHostObject"]=32768]="TypeofNEHostObject",e[e["EQUndefined"]=65536]="EQUndefined",e[e["EQNull"]=131072]="EQNull",e[e["EQUndefinedOrNull"]=262144]="EQUndefinedOrNull",e[e["NEUndefined"]=524288]="NEUndefined",e[e["NENull"]=1048576]="NENull",e[e["NEUndefinedOrNull"]=2097152]="NEUndefinedOrNull",e[e["Truthy"]=4194304]="Truthy",e[e["Falsy"]=8388608]="Falsy",e[e["All"]=16777215]="All",e[e["BaseStringStrictFacts"]=3735041]="BaseStringStrictFacts",e[e["BaseStringFacts"]=12582401]="BaseStringFacts",e[e["StringStrictFacts"]=16317953]="StringStrictFacts",e[e["StringFacts"]=16776705]="StringFacts",e[e["EmptyStringStrictFacts"]=12123649]="EmptyStringStrictFacts",e[e["EmptyStringFacts"]=12582401]="EmptyStringFacts",e[e["NonEmptyStringStrictFacts"]=7929345]="NonEmptyStringStrictFacts",e[e["NonEmptyStringFacts"]=16776705]="NonEmptyStringFacts",e[e["BaseNumberStrictFacts"]=3734786]="BaseNumberStrictFacts",e[e["BaseNumberFacts"]=12582146]="BaseNumberFacts",e[e["NumberStrictFacts"]=16317698]="NumberStrictFacts",e[e["NumberFacts"]=16776450]="NumberFacts",e[e["ZeroNumberStrictFacts"]=12123394]="ZeroNumberStrictFacts",e[e["ZeroNumberFacts"]=12582146]="ZeroNumberFacts",e[e["NonZeroNumberStrictFacts"]=7929090]="NonZeroNumberStrictFacts",e[e["NonZeroNumberFacts"]=16776450]="NonZeroNumberFacts",e[e["BaseBigIntStrictFacts"]=3734276]="BaseBigIntStrictFacts",e[e["BaseBigIntFacts"]=12581636]="BaseBigIntFacts",e[e["BigIntStrictFacts"]=16317188]="BigIntStrictFacts",e[e["BigIntFacts"]=16775940]="BigIntFacts",e[e["ZeroBigIntStrictFacts"]=12122884]="ZeroBigIntStrictFacts",e[e["ZeroBigIntFacts"]=12581636]="ZeroBigIntFacts",e[e["NonZeroBigIntStrictFacts"]=7928580]="NonZeroBigIntStrictFacts",e[e["NonZeroBigIntFacts"]=16775940]="NonZeroBigIntFacts",e[e["BaseBooleanStrictFacts"]=3733256]="BaseBooleanStrictFacts",e[e["BaseBooleanFacts"]=12580616]="BaseBooleanFacts",e[e["BooleanStrictFacts"]=16316168]="BooleanStrictFacts",e[e["BooleanFacts"]=16774920]="BooleanFacts",e[e["FalseStrictFacts"]=12121864]="FalseStrictFacts",e[e["FalseFacts"]=12580616]="FalseFacts",e[e["TrueStrictFacts"]=7927560]="TrueStrictFacts",e[e["TrueFacts"]=16774920]="TrueFacts",e[e["SymbolStrictFacts"]=7925520]="SymbolStrictFacts",e[e["SymbolFacts"]=16772880]="SymbolFacts",e[e["ObjectStrictFacts"]=7888800]="ObjectStrictFacts",e[e["ObjectFacts"]=16736160]="ObjectFacts",e[e["FunctionStrictFacts"]=7880640]="FunctionStrictFacts",e[e["FunctionFacts"]=16728e3]="FunctionFacts",e[e["UndefinedFacts"]=9830144]="UndefinedFacts",e[e["NullFacts"]=9363232]="NullFacts",e[e["EmptyObjectStrictFacts"]=16318463]="EmptyObjectStrictFacts",e[e["AllTypeofNE"]=556800]="AllTypeofNE",e[e["EmptyObjectFacts"]=16777215]="EmptyObjectFacts"}(a||(a={}));var m,_,g,y,h,v,b,E,T,S=new e.Map(e.getEntries({string:1,number:2,bigint:4,boolean:8,symbol:16,undefined:65536,object:32,function:64})),x=new e.Map(e.getEntries({string:256,number:512,bigint:1024,boolean:2048,symbol:4096,undefined:524288,object:8192,function:16384}));(function(e){e[e["Type"]=0]="Type",e[e["ResolvedBaseConstructorType"]=1]="ResolvedBaseConstructorType",e[e["DeclaredType"]=2]="DeclaredType",e[e["ResolvedReturnType"]=3]="ResolvedReturnType",e[e["ImmediateBaseConstraint"]=4]="ImmediateBaseConstraint",e[e["EnumTagType"]=5]="EnumTagType",e[e["ResolvedTypeArguments"]=6]="ResolvedTypeArguments",e[e["ResolvedBaseTypes"]=7]="ResolvedBaseTypes"})(m||(m={})),function(e){e[e["Normal"]=0]="Normal",e[e["Contextual"]=1]="Contextual",e[e["Inferential"]=2]="Inferential",e[e["SkipContextSensitive"]=4]="SkipContextSensitive",e[e["SkipGenericFunctions"]=8]="SkipGenericFunctions",e[e["IsForSignatureHelp"]=16]="IsForSignatureHelp"}(_||(_={})),function(e){e[e["None"]=0]="None",e[e["NoIndexSignatures"]=1]="NoIndexSignatures",e[e["Writing"]=2]="Writing",e[e["CacheSymbol"]=4]="CacheSymbol",e[e["NoTupleBoundsCheck"]=8]="NoTupleBoundsCheck",e[e["ExpressionPosition"]=16]="ExpressionPosition"}(g||(g={})),function(e){e[e["BivariantCallback"]=1]="BivariantCallback",e[e["StrictCallback"]=2]="StrictCallback",e[e["IgnoreReturnTypes"]=4]="IgnoreReturnTypes",e[e["StrictArity"]=8]="StrictArity",e[e["Callback"]=3]="Callback"}(y||(y={})),function(e){e[e["None"]=0]="None",e[e["Source"]=1]="Source",e[e["Target"]=2]="Target",e[e["PropertyCheck"]=4]="PropertyCheck",e[e["UnionIntersectionCheck"]=8]="UnionIntersectionCheck",e[e["InPropertyCheck"]=16]="InPropertyCheck"}(h||(h={})),function(e){e[e["IncludeReadonly"]=1]="IncludeReadonly",e[e["ExcludeReadonly"]=2]="ExcludeReadonly",e[e["IncludeOptional"]=4]="IncludeOptional",e[e["ExcludeOptional"]=8]="ExcludeOptional"}(v||(v={})),function(e){e[e["None"]=0]="None",e[e["Source"]=1]="Source",e[e["Target"]=2]="Target",e[e["Both"]=3]="Both"}(b||(b={})),function(e){e["resolvedExports"]="resolvedExports",e["resolvedMembers"]="resolvedMembers"}(E||(E={})),function(e){e[e["Local"]=0]="Local",e[e["Parameter"]=1]="Parameter"}(T||(T={}));var L,D,A,C,I=e.and(B,G);(function(e){e[e["GetAccessor"]=1]="GetAccessor",e[e["SetAccessor"]=2]="SetAccessor",e[e["PropertyAssignment"]=4]="PropertyAssignment",e[e["Method"]=8]="Method",e[e["PrivateStatic"]=16]="PrivateStatic",e[e["GetOrSetAccessor"]=3]="GetOrSetAccessor",e[e["PropertyAssignmentOrMethod"]=12]="PropertyAssignmentOrMethod"})(L||(L={})),function(e){e[e["None"]=0]="None",e[e["ExportValue"]=1]="ExportValue",e[e["ExportType"]=2]="ExportType",e[e["ExportNamespace"]=4]="ExportNamespace"}(D||(D={})),function(e){e[e["None"]=0]="None",e[e["StrongArityForUntypedJS"]=1]="StrongArityForUntypedJS",e[e["VoidIsNonOptional"]=2]="VoidIsNonOptional"}(A||(A={})),function(e){e[e["Uppercase"]=0]="Uppercase",e[e["Lowercase"]=1]="Lowercase",e[e["Capitalize"]=2]="Capitalize",e[e["Uncapitalize"]=3]="Uncapitalize"}(C||(C={}));var N,k=new e.Map(e.getEntries({Uppercase:0,Lowercase:1,Capitalize:2,Uncapitalize:3}));function R(){}function O(){this.flags=0}function w(e){return e.id||(e.id=d,d++),e.id}function P(e){return e.id||(e.id=u,u++),e.id}function M(n,t){var r=e.getModuleInstanceState(n);return 1===r||t&&2===r}function F(n,t){var r,a,u,d,m=e.memoize((function(){var t=new e.Set;return n.getSourceFiles().forEach((function(n){n.resolvedModules&&e.forEachEntry(n.resolvedModules,(function(e){e&&e.packageId&&t.add(e.packageId.name)}))})),t})),_=e.objectAllocator.getSymbolConstructor(),g=e.objectAllocator.getTypeConstructor(),y=e.objectAllocator.getSignatureConstructor(),h=0,v=0,b=0,E=0,T=0,L=0,D=e.createSymbolTable(),A=[1],C=n.getCompilerOptions(),F=e.getEmitScriptTarget(C),G=e.getEmitModuleKind(C),H=e.getUseDefineForClassFields(C),W=e.getAllowSyntheticDefaultImports(C),z=e.getStrictOptionValue(C,"strictNullChecks"),q=e.getStrictOptionValue(C,"strictFunctionTypes"),J=e.getStrictOptionValue(C,"strictBindCallApply"),X=e.getStrictOptionValue(C,"strictPropertyInitialization"),Y=e.getStrictOptionValue(C,"noImplicitAny"),Q=e.getStrictOptionValue(C,"noImplicitThis"),Z=!!C.keyofStringsOnly,$=C.suppressExcessPropertyErrors?0:16384,ee=jD(),ne=BR(),te=po(),re=e.createSymbolTable(),ae=Sr(4,"undefined");ae.declarations=[];var ie=Sr(1536,"globalThis",8);ie.exports=re,ie.declarations=[],re.set(ie.escapedName,ie);var oe,se=Sr(4,"arguments"),ce=Sr(4,"require"),le={getNodeCount:function(){return e.sum(n.getSourceFiles(),"nodeCount")},getIdentifierCount:function(){return e.sum(n.getSourceFiles(),"identifierCount")},getSymbolCount:function(){return e.sum(n.getSourceFiles(),"symbolCount")+v},getTypeCount:function(){return h},getInstantiationCount:function(){return E},getRelationCacheSizes:function(){return{assignable:sr.size,identity:lr.size,subtype:ir.size,strictSubtype:or.size}},isUndefinedSymbol:function(e){return e===ae},isArgumentsSymbol:function(e){return e===se},isUnknownSymbol:function(e){return e===Te},getMergedSymbol:gi,getDiagnostics:xk,getGlobalDiagnostics:Dk,getRecursionIdentity:Qg,getTypeOfSymbolAtLocation:function(n,t){var r=e.getParseTreeNode(t);return r?Rb(n,r):Ae},getSymbolsOfParameterPropertyDeclaration:function(n,t){var r=e.getParseTreeNode(n,e.isParameter);return void 0===r?e.Debug.fail("Cannot get symbols of a synthetic parameter that cannot be resolved to a parse-tree node."):Gr(r,e.escapeLeadingUnderscores(t))},getDeclaredTypeOfSymbol:mc,getPropertiesOfType:wl,getPropertyOfType:function(n,t){return _u(n,e.escapeLeadingUnderscores(t))},getPrivateIdentifierPropertyOfType:function(n,t,r){var a=e.getParseTreeNode(r);if(a){var i=e.escapeLeadingUnderscores(t),o=SS(i,a);return o?xS(n,o):void 0}},getTypeOfPropertyOfType:function(n,t){return Io(n,e.escapeLeadingUnderscores(t))},getIndexInfoOfType:bu,getSignaturesOfType:yu,getIndexTypeOfType:Eu,getBaseTypes:Qs,getBaseTypeOfLiteralType:Ty,getWidenedType:sh,getTypeFromTypeNode:function(n){var t=e.getParseTreeNode(n,e.isTypeNode);return t?zm(t):Ae},getParameterType:ML,getPromisedTypeOfPromise:mC,getAwaitedType:function(e){return yC(e)},getReturnTypeOfSignature:Hu,isNullableType:pS,getNullableType:Vy,getNonNullableType:Hy,getNonOptionalType:qy,getTypeArguments:Td,typeToTypeNode:te.typeToTypeNode,indexInfoToIndexSignatureDeclaration:te.indexInfoToIndexSignatureDeclaration,signatureToSignatureDeclaration:te.signatureToSignatureDeclaration,symbolToEntityName:te.symbolToEntityName,symbolToExpression:te.symbolToExpression,symbolToTypeParameterDeclarations:te.symbolToTypeParameterDeclarations,symbolToParameterDeclaration:te.symbolToParameterDeclaration,typeParameterToDeclaration:te.typeParameterToDeclaration,getSymbolsInScope:function(n,t){var r=e.getParseTreeNode(n);return r?Ck(r,t):[]},getSymbolAtLocation:function(n){var t=e.getParseTreeNode(n);return t?jk(t,!0):void 0},getShorthandAssignmentValueSymbol:function(n){var t=e.getParseTreeNode(n);return t?Kk(t):void 0},getExportSpecifierLocalTargetSymbol:function(n){var t=e.getParseTreeNode(n,e.isExportSpecifier);return t?Hk(t):void 0},getExportSymbolOfSymbol:function(e){return gi(e.exportSymbol||e)},getTypeAtLocation:function(n){var t=e.getParseTreeNode(n);return t?Wk(t):Ae},getTypeOfAssignmentPattern:function(n){var t=e.getParseTreeNode(n,e.isAssignmentPattern);return t&&zk(t)||Ae},getPropertySymbolOfDestructuringAssignment:function(n){var t=e.getParseTreeNode(n,e.isIdentifier);return t?qk(t):void 0},signatureToString:function(n,t,r,a){return ao(n,e.getParseTreeNode(t),r,a)},typeToString:function(n,t,r){return io(n,e.getParseTreeNode(t),r)},symbolToString:function(n,t,r,a){return ro(n,e.getParseTreeNode(t),r,a)},typePredicateToString:function(n,t,r){return fo(n,e.getParseTreeNode(t),r)},writeSignature:function(n,t,r,a,i){return ao(n,e.getParseTreeNode(t),r,a,i)},writeType:function(n,t,r,a){return io(n,e.getParseTreeNode(t),r,a)},writeSymbol:function(n,t,r,a,i){return ro(n,e.getParseTreeNode(t),r,a,i)},writeTypePredicate:function(n,t,r,a){return fo(n,e.getParseTreeNode(t),r,a)},getAugmentedPropertiesOfType:Qk,getRootSymbols:$k,getSymbolOfExpando:fL,getContextualType:function(n,t){var r=e.getParseTreeNode(n,e.isExpression);if(r){var a=e.findAncestor(r,e.isCallLikeExpression),i=a&&Pr(a).resolvedSignature;if(4&t&&a){var o=r;do{Pr(o).skipDirectInference=!0,o=o.parent}while(o&&o!==a);Pr(a).resolvedSignature=void 0}var s=JE(r,t);if(4&t&&a){o=r;do{Pr(o).skipDirectInference=void 0,o=o.parent}while(o&&o!==a);Pr(a).resolvedSignature=i}return s}},getContextualTypeForObjectLiteralElement:function(n){var t=e.getParseTreeNode(n,e.isObjectLiteralElementLike);return t?ME(t):void 0},getContextualTypeForArgumentAtIndex:function(n,t){var r=e.getParseTreeNode(n,e.isCallLikeExpression);return r&&DE(r,t)},getContextualTypeForJsxAttribute:function(n){var t=e.getParseTreeNode(n,e.isJsxAttributeLike);return t&&VE(t)},isContextSensitive:w_,getTypeOfPropertyOfContextualType:OE,getFullyQualifiedName:za,getResolvedSignature:function(e,n,t){return ue(e,n,t,0)},getResolvedSignatureForSignatureHelp:function(e,n,t){return ue(e,n,t,16)},getExpandedParameters:zc,hasEffectiveRestParameter:VL,getConstantValue:function(n){var t=e.getParseTreeNode(n,xR);return t?LR(t):void 0},isValidPropertyAccess:function(n,t){var r=e.getParseTreeNode(n,e.isPropertyAccessOrQualifiedNameOrImportTypeNode);return!!r&&XS(r,e.escapeLeadingUnderscores(t))},isValidPropertyAccessForCompletions:function(n,t,r){var a=e.getParseTreeNode(n,e.isPropertyAccessExpression);return!!a&&YS(a,t,r)},getSignatureFromDeclaration:function(n){var t=e.getParseTreeNode(n,e.isFunctionLike);return t?Ou(t):void 0},isImplementationOfOverload:function(n){var t=e.getParseTreeNode(n,e.isFunctionLike);return t?gR(t):void 0},getImmediateAliasedSymbol:xT,getAliasedSymbol:Fa,getEmitResolver:fr,getExportsOfModule:si,getExportsAndPropertiesOfModule:ci,getSymbolWalker:e.createGetSymbolWalker(qu,Vu,Hu,Qs,Nl,ws,rv,vu,Gl,e.getFirstIdentifier,Td),getAmbientModules:sw,getJsxIntrinsicTagNamesAt:eS,isOptionalParameter:function(n){var t=e.getParseTreeNode(n,e.isParameter);return!!t&&Au(t)},tryGetMemberInModuleExports:function(n,t){return li(e.escapeLeadingUnderscores(n),t)},tryGetMemberInModuleExportsAndProperties:function(n,t){return ui(e.escapeLeadingUnderscores(n),t)},tryFindAmbientModule:function(e){return Du(e,!0)},tryFindAmbientModuleWithoutAugmentations:function(e){return Du(e,!1)},getApparentType:au,getUnionType:Qp,isTypeAssignableTo:W_,createAnonymousType:Bi,createSignature:Vc,createSymbol:Sr,createIndexInfo:ud,getAnyType:function(){return xe},getStringType:function(){return Me},getNumberType:function(){return Fe},createPromiseType:QL,createArrayType:Ep,getElementTypeOfArrayType:uy,getBooleanType:function(){return Ke},getFalseType:function(e){return e?Be:Ue},getTrueType:function(e){return e?Ve:je},getVoidType:function(){return We},getUndefinedType:function(){return ke},getNullType:function(){return we},getESSymbolType:function(){return He},getNeverType:function(){return ze},getOptionalType:function(){return Oe},isSymbolAccessible:Yi,isArrayType:sy,isTupleType:Cy,isArrayLikeType:dy,isTypeInvalidDueToUnionDiscriminant:Pl,getAllPossiblePropertiesOfTypes:Ml,getSuggestedSymbolForNonexistentProperty:GS,getSuggestionForNonexistentProperty:US,getSuggestedSymbolForNonexistentJSXAttribute:BS,getSuggestedSymbolForNonexistentSymbol:function(n,t,r){return VS(n,e.escapeLeadingUnderscores(t),r)},getSuggestionForNonexistentSymbol:function(n,t,r){return jS(n,e.escapeLeadingUnderscores(t),r)},getSuggestedSymbolForNonexistentModule:KS,getSuggestionForNonexistentExport:HS,getBaseConstraintOfType:ql,getDefaultFromTypeParameter:function(e){return e&&262144&e.flags?$l(e):void 0},resolveName:function(n,t,r,a){return Vr(t,e.escapeLeadingUnderscores(n),r,void 0,void 0,!1,a)},getJsxNamespace:function(n){return e.unescapeLeadingUnderscores(pr(n))},getJsxFragmentFactory:function(n){var t=GR(n);return t&&e.unescapeLeadingUnderscores(e.getFirstIdentifier(t).escapedText)},getAccessibleSymbolChain:Ki,getTypePredicateOfSignature:Vu,resolveExternalModuleName:function(n){var t=e.getParseTreeNode(n,e.isExpression);return t&&Za(t,t,!0)},resolveExternalModuleSymbol:ri,tryGetThisTypeAt:function(n,t){var r=e.getParseTreeNode(n);return r&&aE(r,t)},getTypeArgumentConstraint:function(n){var t=e.getParseTreeNode(n,e.isTypeNode);return t&&qA(t)},getSuggestionDiagnostics:function(t,a){var i,s=e.getParseTreeNode(t,e.isSourceFile)||e.Debug.fail("Could not determine parsed source file.");if(e.skipTypeChecking(s,C,n))return e.emptyArray;try{return r=a,bk(s),e.Debug.assert(!!(1&Pr(s).flags)),i=e.addRange(i,tr.getDiagnostics(s.fileName)),UC(Tk(s),(function(n,t,r){e.containsParseError(n)||Ek(t,!!(8388608&n.flags))||(i||(i=[])).push(o(o({},r),{category:e.DiagnosticCategory.Suggestion}))})),i||e.emptyArray}finally{r=void 0}},runWithCancellationToken:function(e,n){try{return r=e,n(le)}finally{r=void 0}},getLocalTypeParametersOfClassOrInterfaceOrTypeAlias:Vs,isDeclarationVisible:Eo};function ue(n,t,r,a){var i=e.getParseTreeNode(n,e.isCallLikeExpression);oe=r;var o=i?lL(i,t,a):void 0;return oe=void 0,o}var de=new e.Map,pe=new e.Map,fe=new e.Map,me=new e.Map,_e=new e.Map,ge=new e.Map,ye=new e.Map,he=new e.Map,ve=new e.Map,be=[],Ee=new e.Map,Te=Sr(4,"unknown"),Se=Sr(0,"__resolving__"),xe=Ni(1,"any"),Le=Ni(1,"any"),De=Ni(1,"any"),Ae=Ni(1,"error"),Ce=Ni(1,"any",131072),Ie=Ni(1,"intrinsic"),Ne=Ni(2,"unknown"),ke=Ni(32768,"undefined"),Re=z?ke:Ni(32768,"undefined",131072),Oe=Ni(32768,"undefined"),we=Ni(65536,"null"),Pe=z?we:Ni(65536,"null",131072),Me=Ni(4,"string"),Fe=Ni(8,"number"),Ge=Ni(64,"bigint"),Be=Ni(512,"false"),Ue=Ni(512,"false"),Ve=Ni(512,"true"),je=Ni(512,"true");Ve.regularType=je,Ve.freshType=Ve,je.regularType=je,je.freshType=Ve,Be.regularType=Ue,Be.freshType=Be,Ue.regularType=Ue,Ue.freshType=Be;var Ke=ki([Ue,je]);ki([Ue,Ve]),ki([Be,je]),ki([Be,Ve]);var He=Ni(4096,"symbol"),We=Ni(16384,"void"),ze=Ni(131072,"never"),qe=Ni(131072,"never"),Je=Ni(131072,"never",524288),Xe=Ni(131072,"never"),Ye=Ni(131072,"never"),Qe=Ni(67108864,"object"),Ze=Qp([Me,Fe,He]),$e=Z?Me:Ze,en=Qp([Fe,Ge]),nn=Qp([Me,Fe,Ke,Ge,we,ke]),tn=n_((function(e){return 262144&e.flags?l_(e):e})),rn=n_((function(e){return 262144&e.flags?De:e})),an=Bi(void 0,D,e.emptyArray,e.emptyArray,void 0,void 0),on=Bi(void 0,D,e.emptyArray,e.emptyArray,void 0,void 0);on.objectFlags|=2048;var sn=Sr(2048,"__type");sn.members=e.createSymbolTable();var cn=Bi(sn,D,e.emptyArray,e.emptyArray,void 0,void 0),ln=Bi(void 0,D,e.emptyArray,e.emptyArray,void 0,void 0);ln.instantiations=new e.Map;var un=Bi(void 0,D,e.emptyArray,e.emptyArray,void 0,void 0);un.objectFlags|=524288;var dn=Bi(void 0,D,e.emptyArray,e.emptyArray,void 0,void 0),pn=Bi(void 0,D,e.emptyArray,e.emptyArray,void 0,void 0),fn=Bi(void 0,D,e.emptyArray,e.emptyArray,void 0,void 0),mn=wi(),_n=wi();_n.constraint=mn;var gn,yn,hn,vn,bn,En,Tn,Sn,xn,Ln,Dn,An,Cn,In,Nn,kn,Rn,On,wn,Pn,Mn,Fn,Gn,Bn,Un,Vn,jn,Kn,Hn,Wn,zn,qn,Jn,Xn,Yn,Qn,Zn,$n,et,nt,tt,rt,at,it,ot,st,ct,lt,ut=wi(),dt=Nu(1,"<<unresolved>>",0,xe),pt=Vc(void 0,void 0,void 0,e.emptyArray,xe,void 0,0,0),ft=Vc(void 0,void 0,void 0,e.emptyArray,Ae,void 0,0,0),mt=Vc(void 0,void 0,void 0,e.emptyArray,xe,void 0,0,0),_t=Vc(void 0,void 0,void 0,e.emptyArray,qe,void 0,0,0),gt=ud(Me,!0),yt=new e.Map,ht={get yieldType(){return e.Debug.fail("Not supported")},get returnType(){return e.Debug.fail("Not supported")},get nextType(){return e.Debug.fail("Not supported")}},vt=wI(xe,xe,xe),bt=wI(xe,xe,Ne),Et=wI(ze,xe,ke),Tt={iterableCacheKey:"iterationTypesOfAsyncIterable",iteratorCacheKey:"iterationTypesOfAsyncIterator",iteratorSymbolName:"asyncIterator",getGlobalIteratorType:ip,getGlobalIterableType:ap,getGlobalIterableIteratorType:op,getGlobalGeneratorType:sp,resolveIterationType:yC,mustHaveANextMethodDiagnostic:e.Diagnostics.An_async_iterator_must_have_a_next_method,mustBeAMethodDiagnostic:e.Diagnostics.The_0_property_of_an_async_iterator_must_be_a_method,mustHaveAValueDiagnostic:e.Diagnostics.The_type_returned_by_the_0_method_of_an_async_iterator_must_be_a_promise_for_a_type_with_a_value_property},St={iterableCacheKey:"iterationTypesOfIterable",iteratorCacheKey:"iterationTypesOfIterator",iteratorSymbolName:"iterator",getGlobalIteratorType:lp,getGlobalIterableType:cp,getGlobalIterableIteratorType:up,getGlobalGeneratorType:dp,resolveIterationType:function(e,n){return e},mustHaveANextMethodDiagnostic:e.Diagnostics.An_iterator_must_have_a_next_method,mustBeAMethodDiagnostic:e.Diagnostics.The_0_property_of_an_iterator_must_be_a_method,mustHaveAValueDiagnostic:e.Diagnostics.The_type_returned_by_the_0_method_of_an_iterator_must_have_a_value_property},xt=new e.Map,Lt=!1,Dt=new e.Map,At=0,Ct=0,It=0,Nt=!1,kt=0,Rt=Fm(""),Ot=Fm(0),wt=Fm({negative:!1,base10Value:"0"}),Pt=[],Mt=[],Ft=[],Gt=0,Bt=10,Ut=[],Vt=[],jt=[],Kt=[],Ht=[],Wt=[],zt=[],qt=[],Jt=[],Xt=[],Yt=[],Qt=[],Zt=[],$t=[],er=[],nr=e.createDiagnosticCollection(),tr=e.createDiagnosticCollection(),rr=new e.Map(e.getEntries({string:Me,number:Fe,bigint:Ge,boolean:Ke,symbol:He,undefined:ke})),ar=Oi(),ir=new e.Map,or=new e.Map,sr=new e.Map,cr=new e.Map,lr=new e.Map,ur=new e.Map,dr=e.createSymbolTable();return dr.set(ae.escapedName,ae),VR(),le;function pr(n){if(n){var t=e.getSourceFileOfNode(n);if(t)if(e.isJsxOpeningFragment(n)){if(t.localJsxFragmentNamespace)return t.localJsxFragmentNamespace;var r=t.pragmas.get("jsxfrag");if(r){var a=e.isArray(r)?r[0]:r;if(t.localJsxFragmentFactory=e.parseIsolatedEntityName(a.arguments.factory,F),e.visitNode(t.localJsxFragmentFactory,s),t.localJsxFragmentFactory)return t.localJsxFragmentNamespace=e.getFirstIdentifier(t.localJsxFragmentFactory).escapedText}var i=GR(n);if(i)return t.localJsxFragmentFactory=i,t.localJsxFragmentNamespace=e.getFirstIdentifier(i).escapedText}else{if(t.localJsxNamespace)return t.localJsxNamespace;var o=t.pragmas.get("jsx");if(o){a=e.isArray(o)?o[0]:o;if(t.localJsxFactory=e.parseIsolatedEntityName(a.arguments.factory,F),e.visitNode(t.localJsxFactory,s),t.localJsxFactory)return t.localJsxNamespace=e.getFirstIdentifier(t.localJsxFactory).escapedText}}}return st||(st="React",C.jsxFactory?(ct=e.parseIsolatedEntityName(C.jsxFactory,F),e.visitNode(ct,s),ct&&(st=e.getFirstIdentifier(ct).escapedText)):C.reactNamespace&&(st=e.escapeLeadingUnderscores(C.reactNamespace))),ct||(ct=e.factory.createQualifiedName(e.factory.createIdentifier(e.unescapeLeadingUnderscores(st)),"createElement")),st;function s(n){return e.setTextRangePosEnd(n,-1,-1),e.visitEachChild(n,s,e.nullTransformationContext)}}function fr(e,n){return xk(e,n),ne}function mr(n,t,r,a,i,o){var s=n?e.createDiagnosticForNode(n,t,r,a,i,o):e.createCompilerDiagnostic(t,r,a,i,o),c=nr.lookup(s);return c||(nr.add(s),s)}function _r(e,n,t,r,a,i,o){var s=gr(n,t,r,a,i,o);return s.skippedOn=e,s}function gr(n,t,r,a,i,o){var s=n?e.createDiagnosticForNode(n,t,r,a,i,o):e.createCompilerDiagnostic(t,r,a,i,o);return nr.add(s),s}function yr(n,t){n?nr.add(t):tr.add(o(o({},t),{category:e.DiagnosticCategory.Suggestion}))}function hr(n,t,r,a,i,o,s){if(t.pos<0||t.end<0){if(!n)return;var c=e.getSourceFileOfNode(t);yr(n,"message"in r?e.createFileDiagnostic(c,0,0,r,a,i,o,s):e.createDiagnosticForFileFromMessageChain(c,r))}else yr(n,"message"in r?e.createDiagnosticForNode(t,r,a,i,o,s):e.createDiagnosticForNodeFromMessageChain(t,r))}function vr(n,t,r,a,i,o,s){var c=gr(n,r,a,i,o,s);if(t){var l=e.createDiagnosticForNode(n,e.Diagnostics.Did_you_forget_to_use_await);e.addRelatedInfo(c,l)}return c}function br(n,t){var r=Array.isArray(n)?e.forEach(n,e.getJSDocDeprecatedTag):e.getJSDocDeprecatedTag(n);return r&&e.addRelatedInfo(t,e.createDiagnosticForNode(r,e.Diagnostics.The_declaration_was_marked_as_deprecated_here)),tr.add(t),t}function Er(n,t,r){var a=e.createDiagnosticForNode(n,e.Diagnostics._0_is_deprecated,r);return br(t,a)}function Tr(n,t,r,a){var i=r?e.createDiagnosticForNode(n,e.Diagnostics.The_signature_0_of_1_is_deprecated,a,r):e.createDiagnosticForNode(n,e.Diagnostics._0_is_deprecated,a);return br(t,i)}function Sr(e,n,t){v++;var r=new _(33554432|e,n);return r.checkFlags=t||0,r}function xr(e){var n=0;return 2&e&&(n|=111551),1&e&&(n|=111550),4&e&&(n|=0),8&e&&(n|=900095),16&e&&(n|=110991),32&e&&(n|=899503),64&e&&(n|=788872),256&e&&(n|=899327),128&e&&(n|=899967),512&e&&(n|=110735),8192&e&&(n|=103359),32768&e&&(n|=46015),65536&e&&(n|=78783),262144&e&&(n|=526824),524288&e&&(n|=788968),2097152&e&&(n|=2097152),n}function Lr(e,n){n.mergeId||(n.mergeId=p,p++),Ut[n.mergeId]=e}function Dr(n){var t=Sr(n.flags,n.escapedName);return t.declarations=n.declarations?n.declarations.slice():[],t.parent=n.parent,n.valueDeclaration&&(t.valueDeclaration=n.valueDeclaration),n.constEnumOnlyModule&&(t.constEnumOnlyModule=!0),n.members&&(t.members=new e.Map(n.members)),n.exports&&(t.exports=new e.Map(n.exports)),Lr(t,n),t}function Ar(n,t,r){if(void 0===r&&(r=!1),!(n.flags&xr(t.flags))||67108864&(t.flags|n.flags)){if(t===n)return n;if(!(33554432&n.flags)){var a=Ma(n);if(a===Te)return t;n=Dr(a)}512&t.flags&&512&n.flags&&n.constEnumOnlyModule&&!t.constEnumOnlyModule&&(n.constEnumOnlyModule=!1),n.flags|=t.flags,t.valueDeclaration&&e.setValueDeclaration(n,t.valueDeclaration),e.addRange(n.declarations,t.declarations),t.members&&(n.members||(n.members=e.createSymbolTable()),kr(n.members,t.members,r)),t.exports&&(n.exports||(n.exports=e.createSymbolTable()),kr(n.exports,t.exports,r)),r||Lr(n,t)}else if(1024&n.flags)n!==ie&&gr(t.declarations&&e.getNameOfDeclaration(t.declarations[0]),e.Diagnostics.Cannot_augment_module_0_with_value_exports_because_it_resolves_to_a_non_module_entity,ro(n));else{var i=!!(384&n.flags||384&t.flags),o=!!(2&n.flags||2&t.flags),s=i?e.Diagnostics.Enum_declarations_can_only_merge_with_namespace_or_other_enum_declarations:o?e.Diagnostics.Cannot_redeclare_block_scoped_variable_0:e.Diagnostics.Duplicate_identifier_0,c=t.declarations&&e.getSourceFileOfNode(t.declarations[0]),l=n.declarations&&e.getSourceFileOfNode(n.declarations[0]),u=ro(t);if(c&&l&&gn&&!i&&c!==l){var d=-1===e.comparePaths(c.path,l.path)?c:l,p=d===c?l:c,f=e.getOrUpdate(gn,d.path+"|"+p.path,(function(){return{firstFile:d,secondFile:p,conflictingSymbols:new e.Map}})),m=e.getOrUpdate(f.conflictingSymbols,u,(function(){return{isBlockScoped:o,firstFileLocations:[],secondFileLocations:[]}}));_(m.firstFileLocations,t),_(m.secondFileLocations,n)}else Cr(t,s,u,n),Cr(n,s,u,t)}return n;function _(n,t){if(t.declarations)for(var r=0,a=t.declarations;r<a.length;r++){var i=a[r];e.pushIfUnique(n,i)}}}function Cr(n,t,r,a){e.forEach(n.declarations,(function(e){Ir(e,t,r,a.declarations)}))}function Ir(n,t,r,a){for(var i=(e.getExpandoInitializer(n,!1)?e.getNameOfExpando(n):e.getNameOfDeclaration(n))||n,o=mr(i,t,r),s=function(n){var t=(e.getExpandoInitializer(n,!1)?e.getNameOfExpando(n):e.getNameOfDeclaration(n))||n;if(t===i)return"continue";o.relatedInformation=o.relatedInformation||[];var a=e.createDiagnosticForNode(t,e.Diagnostics._0_was_also_declared_here,r),s=e.createDiagnosticForNode(t,e.Diagnostics.and_here);if(e.length(o.relatedInformation)>=5||e.some(o.relatedInformation,(function(n){return 0===e.compareDiagnostics(n,s)||0===e.compareDiagnostics(n,a)})))return"continue";e.addRelatedInfo(o,e.length(o.relatedInformation)?s:a)},c=0,l=a||e.emptyArray;c<l.length;c++){var u=l[c];s(u)}}function Nr(n,t){if(!(null===n||void 0===n?void 0:n.size))return t;if(!(null===t||void 0===t?void 0:t.size))return n;var r=e.createSymbolTable();return kr(r,n),kr(r,t),r}function kr(e,n,t){void 0===t&&(t=!1),n.forEach((function(n,r){var a=e.get(r);e.set(r,a?Ar(a,n,t):n)}))}function Rr(n){var t,r,a,i=n.parent;if((null===(t=i.symbol.declarations)||void 0===t?void 0:t[0])===i)if(e.isGlobalScopeAugmentation(i))kr(re,i.symbol.exports);else{var o=8388608&n.parent.parent.flags?void 0:e.Diagnostics.Invalid_module_name_in_augmentation_module_0_cannot_be_found,s=$a(n,n,o,!0);if(!s)return;if(s=ri(s),1920&s.flags)if(e.some(hn,(function(e){return s===e.symbol}))){var c=Ar(i.symbol,s,!0);vn||(vn=new e.Map),vn.set(n.text,c)}else{if((null===(r=s.exports)||void 0===r?void 0:r.get("__export"))&&(null===(a=i.symbol.exports)||void 0===a?void 0:a.size))for(var l=wc(s,"resolvedExports"),u=0,d=e.arrayFrom(i.symbol.exports.entries());u<d.length;u++){var p=d[u],f=p[0],m=p[1];l.has(f)&&!s.exports.has(f)&&Ar(l.get(f),m)}Ar(s,i.symbol)}else gr(n,e.Diagnostics.Cannot_augment_module_0_because_it_resolves_to_a_non_module_entity,n.text)}else e.Debug.assert(i.symbol.declarations.length>1)}function Or(n,t,r){function a(n,t){return function(r){return nr.add(e.createDiagnosticForNode(r,t,n))}}t.forEach((function(t,i){var o=n.get(i);o?e.forEach(o.declarations,a(e.unescapeLeadingUnderscores(i),r)):n.set(i,t)}))}function wr(e){if(33554432&e.flags)return e;var n=P(e);return Vt[n]||(Vt[n]=new R)}function Pr(e){var n=w(e);return jt[n]||(jt[n]=new O)}function Mr(n){return 298===n.kind&&!e.isExternalOrCommonJsModule(n)}function Fr(n,t,r){if(r){var a=gi(n.get(t));if(a){if(e.Debug.assert(0===(1&e.getCheckFlags(a)),"Should never get an instantiated symbol here."),a.flags&r)return a;if(2097152&a.flags){var i=Fa(a);if(i===Te||i.flags&r)return a}}}}function Gr(n,t){var r=n.parent,a=n.parent.parent,i=Fr(r.locals,t,111551),o=Fr(Pc(a.symbol),t,111551);return i&&o?[i,o]:e.Debug.fail("There should exist two symbols, one as property declaration and one as parameter declaration")}function Br(t,r){var a=e.getSourceFileOfNode(t),i=e.getSourceFileOfNode(r),o=e.getEnclosingBlockScopeContainer(t);if(a!==i){if(G&&(a.externalModuleIndicator||i.externalModuleIndicator)||!e.outFile(C)||av(r)||8388608&t.flags)return!0;if(d(r,t))return!0;var s=n.getSourceFiles();return s.indexOf(a)<=s.indexOf(i)}if(t.pos<=r.pos&&(!e.isPropertyDeclaration(t)||!e.isThisProperty(r.parent)||t.initializer||t.exclamationToken)){if(199===t.kind){var c=e.getAncestor(r,199);return c?e.findAncestor(c,e.isBindingElement)!==e.findAncestor(t,e.isBindingElement)||t.pos<c.pos:Br(e.getAncestor(t,250),r)}return 250===t.kind?!u(t,r):e.isClassDeclaration(t)?!e.findAncestor(r,(function(n){return e.isComputedPropertyName(n)&&n.parent.parent===t})):e.isPropertyDeclaration(t)?!p(t,r,!1):!e.isParameterPropertyDeclaration(t,t.parent)||!(99===C.target&&H&&e.getContainingClass(t)===e.getContainingClass(r)&&d(r,t))}return!!(271===r.parent.kind||267===r.parent.kind&&r.parent.isExportEquals)||(!(267!==r.kind||!r.isExportEquals)||(!!(4194304&r.flags||av(r)||l())||!!d(r,t)&&(99!==C.target||!H||!e.getContainingClass(t)||!e.isPropertyDeclaration(t)&&!e.isParameterPropertyDeclaration(t,t.parent)||!p(t,r,!0))));function l(){return!!e.findAncestor(r,(function(n){return e.isInterfaceDeclaration(n)||e.isTypeAliasDeclaration(n)}))}function u(n,t){switch(n.parent.parent.kind){case 233:case 238:case 240:if(oa(t,n,o))return!0;break}var r=n.parent.parent;return e.isForInOrOfStatement(r)&&oa(t,r.expression,o)}function d(n,t){return!!e.findAncestor(n,(function(r){if(r===o)return"quit";if(e.isFunctionLike(r))return!0;var a=r.parent&&164===r.parent.kind&&r.parent.initializer===r;if(a)if(e.hasSyntacticModifier(r.parent,32)){if(166===t.kind)return!0}else{var i=164===t.kind&&!e.hasSyntacticModifier(t,32);if(!i||e.getContainingClass(n)!==e.getContainingClass(t))return!0}return!1}))}function p(n,t,r){if(t.end>n.end)return!1;var a=e.findAncestor(t,(function(t){if(t===n)return"quit";switch(t.kind){case 210:return!0;case 164:return!r||!(e.isPropertyDeclaration(n)&&t.parent===n.parent||e.isParameterPropertyDeclaration(n,n.parent)&&t.parent===n.parent.parent)||"quit";case 231:switch(t.parent.kind){case 168:case 166:case 169:return!0;default:return!1}default:return!1}}));return void 0===a}}function Ur(n,t,r){var a=e.getEmitScriptTarget(C),i=t;if(e.isParameter(r)&&i.body&&n.valueDeclaration&&n.valueDeclaration.pos>=i.body.pos&&n.valueDeclaration.end<=i.body.end&&a>=2){var o=Pr(i);return void 0===o.declarationRequiresScopeChange&&(o.declarationRequiresScopeChange=e.forEach(i.parameters,s)||!1),!o.declarationRequiresScopeChange}return!1;function s(e){return c(e.name)||!!e.initializer&&c(e.initializer)}function c(n){switch(n.kind){case 210:case 209:case 252:case 167:return!1;case 166:case 168:case 169:case 289:return c(n.name);case 164:return e.hasStaticModifier(n)?a<99||!H:c(n.name);default:return e.isNullishCoalesce(n)||e.isOptionalChain(n)?a<7:e.isBindingElement(n)&&n.dotDotDotToken&&e.isObjectBindingPattern(n.parent)?a<4:!e.isTypeNode(n)&&(e.forEachChild(n,c)||!1)}}}function Vr(e,n,t,r,a,i,o,s){return void 0===o&&(o=!1),jr(e,n,t,r,a,i,o,Fr,s)}function jr(n,t,r,a,i,o,s,c,l){var u,d,p,f,m,_,g,y=n,h=!1,v=n,b=!1;e:while(n){if(n.locals&&!Mr(n)&&(d=c(n.locals,t,r))){var E=!0;if(e.isFunctionLike(n)&&p&&p!==n.body?(r&d.flags&788968&&312!==p.kind&&(E=!!(262144&d.flags)&&(p===n.type||161===p.kind||160===p.kind)),r&d.flags&3&&(Ur(d,n,p)?E=!1:1&d.flags&&(E=161===p.kind||p===n.type&&!!e.findAncestor(d.valueDeclaration,e.isParameter)))):185===n.kind&&(E=p===n.trueType),E)break e;d=void 0}switch(h=h||Hr(n,p),n.kind){case 298:if(!e.isExternalOrCommonJsModule(n))break;b=!0;case 257:var T=yi(n).exports||D;if(298===n.kind||e.isModuleDeclaration(n)&&8388608&n.flags&&!e.isGlobalScopeAugmentation(n)){if(d=T.get("default")){var S=e.getLocalSymbolForExportDefault(d);if(S&&d.flags&r&&S.escapedName===t)break e;d=void 0}var x=T.get(t);if(x&&2097152===x.flags&&(e.getDeclarationOfKind(x,271)||e.getDeclarationOfKind(x,270)))break}if("default"!==t&&(d=c(T,t,2623475&r))){if(!e.isSourceFile(n)||!n.commonJsModuleIndicator||(null===(u=d.declarations)||void 0===u?void 0:u.some(e.isJSDocTypeAlias)))break e;d=void 0}break;case 256:if(d=c(yi(n).exports,t,8&r))break e;break;case 164:if(!e.hasSyntacticModifier(n,32)){var L=Ai(n.parent);L&&L.locals&&c(L.locals,t,111551&r)&&(m=n)}break;case 253:case 222:case 254:if(d=c(yi(n).members||D,t,788968&r)){if(!qr(d,n)){d=void 0;break}if(p&&e.hasSyntacticModifier(p,32))return void gr(v,e.Diagnostics.Static_members_cannot_reference_class_type_parameters);break e}if(222===n.kind&&32&r){var A=n.name;if(A&&t===A.escapedText){d=n.symbol;break e}}break;case 224:if(p===n.expression&&93===n.parent.token){var I=n.parent.parent;if(e.isClassLike(I)&&(d=c(yi(I).members,t,788968&r)))return void(a&&gr(v,e.Diagnostics.Base_class_expressions_cannot_reference_class_type_parameters))}break;case 159:if(g=n.parent.parent,(e.isClassLike(g)||254===g.kind)&&(d=c(yi(g).members,t,788968&r)))return void gr(v,e.Diagnostics.A_computed_property_name_cannot_reference_a_type_parameter_from_its_containing_type);break;case 210:if(C.target>=2)break;case 166:case 167:case 168:case 169:case 252:if(3&r&&"arguments"===t){d=se;break e}break;case 209:if(3&r&&"arguments"===t){d=se;break e}if(16&r){var N=n.name;if(N&&t===N.escapedText){d=n.symbol;break e}}break;case 162:n.parent&&161===n.parent.kind&&(n=n.parent),n.parent&&(e.isClassElement(n.parent)||253===n.parent.kind)&&(n=n.parent);break;case 335:case 328:case 329:var k=e.getJSDocRoot(n);k&&(n=k.parent);break;case 161:p&&(p===n.initializer||p===n.name&&e.isBindingPattern(p))&&(_||(_=n));break;case 199:p&&(p===n.initializer||p===n.name&&e.isBindingPattern(p))&&e.isParameterDeclaration(n)&&!_&&(_=n);break;case 186:if(262144&r){var R=n.typeParameter.name;if(R&&t===R.escapedText){d=n.typeParameter.symbol;break e}}break}Wr(n)&&(f=n),p=n,n=n.parent}if(!o||!d||f&&d===f.symbol||(d.isReferenced|=r),!d){if(p&&(e.Debug.assert(298===p.kind),p.commonJsModuleIndicator&&"exports"===t&&r&p.symbol.flags))return p.symbol;s||(d=c(re,t,r))}if(!d&&y&&e.isInJSFile(y)&&y.parent&&e.isRequireCall(y.parent,!1))return ce;if(d){if(a){if(m&&(99!==C.target||!H)){var O=m.name;return void gr(v,e.Diagnostics.Initializer_of_instance_member_variable_0_cannot_reference_identifier_1_declared_in_the_constructor,e.declarationNameToString(O),zr(i))}if(v&&(2&r||(32&r||384&r)&&111551===(111551&r))){var w=Li(d);(2&w.flags||32&w.flags||384&w.flags)&&ia(w,v)}if(d&&b&&111551===(111551&r)&&!(4194304&y.flags)){var P=gi(d);e.length(P.declarations)&&e.every(P.declarations,(function(n){return e.isNamespaceExportDeclaration(n)||e.isSourceFile(n)&&!!n.symbol.globalExports}))&&hr(!C.allowUmdGlobalAccess,v,e.Diagnostics._0_refers_to_a_UMD_global_but_the_current_file_is_a_module_Consider_adding_an_import_instead,e.unescapeLeadingUnderscores(t))}if(d&&_&&!h&&111551===(111551&r)){var M=gi(Mc(d));k=e.getRootDeclaration(_);M===yi(_)?gr(v,e.Diagnostics.Parameter_0_cannot_reference_itself,e.declarationNameToString(_.name)):M.valueDeclaration&&M.valueDeclaration.pos>_.pos&&k.parent.locals&&c(k.parent.locals,M.escapedName,r)===M&&gr(v,e.Diagnostics.Parameter_0_cannot_reference_identifier_1_declared_after_it,e.declarationNameToString(_.name),e.declarationNameToString(v))}d&&v&&111551&r&&2097152&d.flags&&Kr(d,t,v)}return d}if(a&&(!v||!Jr(v,t,i)&&!Xr(v)&&!Qr(v,t,r)&&!ea(v,t)&&!na(v,t,r)&&!aa(v,t,r)&&!Zr(v,t,r))){var F=void 0;if(l&&Gt<Bt){F=VS(y,t,r);var G=F&&F.valueDeclaration&&e.isAmbientModule(F.valueDeclaration)&&e.isGlobalScopeAugmentation(F.valueDeclaration);if(G&&(F=void 0),F){var B=ro(F),U=gr(v,l,zr(i),B);F.valueDeclaration&&e.addRelatedInfo(U,e.createDiagnosticForNode(F.valueDeclaration,e.Diagnostics._0_is_declared_here,B))}}if(!F&&i){var V=MS(i);V?gr(v,a,zr(i),V):gr(v,a,zr(i))}Gt++}}function Kr(n,t,r){if(!e.isValidTypeOnlyAliasUseSite(r)){var a=Va(n);if(a){var i=e.typeOnlyDeclarationIsExport(a),o=i?e.Diagnostics._0_cannot_be_used_as_a_value_because_it_was_exported_using_export_type:e.Diagnostics._0_cannot_be_used_as_a_value_because_it_was_imported_using_import_type,s=i?e.Diagnostics._0_was_exported_here:e.Diagnostics._0_was_imported_here,c=e.unescapeLeadingUnderscores(t);e.addRelatedInfo(gr(r,o,c),e.createDiagnosticForNode(a,s,c))}}}function Hr(n,t){return 210!==n.kind&&209!==n.kind?e.isTypeQueryNode(n)||(e.isFunctionLikeDeclaration(n)||164===n.kind&&!e.hasSyntacticModifier(n,32))&&(!t||t!==n.name):(!t||t!==n.name)&&(!(!n.asteriskToken&&!e.hasSyntacticModifier(n,256))||!e.getImmediatelyInvokedFunctionExpression(n))}function Wr(e){switch(e.kind){case 252:case 253:case 254:case 256:case 255:case 257:return!0;default:return!1}}function zr(n){return e.isString(n)?e.unescapeLeadingUnderscores(n):e.declarationNameToString(n)}function qr(n,t){if(n.declarations)for(var r=0,a=n.declarations;r<a.length;r++){var i=a[r];if(160===i.kind){var o=e.isJSDocTemplateTag(i.parent)?e.getJSDocHost(i.parent):i.parent;if(o===t)return!(e.isJSDocTemplateTag(i.parent)&&e.find(i.parent.parent.tags,e.isJSDocTypeAlias))}}return!1}function Jr(n,t,r){if(!e.isIdentifier(n)||n.escapedText!==t||kk(n)||av(n))return!1;var a=e.getThisContainer(n,!1),i=a;while(i){if(e.isClassLike(i.parent)){var o=yi(i.parent);if(!o)break;var s=ws(o);if(_u(s,t))return gr(n,e.Diagnostics.Cannot_find_name_0_Did_you_mean_the_static_member_1_0,zr(r),ro(o)),!0;if(i===a&&!e.hasSyntacticModifier(i,32)){var c=mc(o).thisType;if(_u(c,t))return gr(n,e.Diagnostics.Cannot_find_name_0_Did_you_mean_the_instance_member_this_0,zr(r)),!0}}i=i.parent}return!1}function Xr(n){var t=Yr(n);return!(!t||!qa(t,64,!0))&&(gr(n,e.Diagnostics.Cannot_extend_an_interface_0_Did_you_mean_implements,e.getTextOfNode(t)),!0)}function Yr(n){switch(n.kind){case 78:case 202:return n.parent?Yr(n.parent):void 0;case 224:if(e.isEntityNameExpression(n.expression))return n.expression;default:return}}function Qr(n,t,r){var a=1920|(e.isInJSFile(n)?111551:0);if(r===a){var i=Ma(Vr(n,t,788968&~a,void 0,void 0,!1)),o=n.parent;if(i){if(e.isQualifiedName(o)){e.Debug.assert(o.left===n,"Should only be resolving left side of qualified name as a namespace");var s=o.right.escapedText,c=_u(mc(i),s);if(c)return gr(o,e.Diagnostics.Cannot_access_0_1_because_0_is_a_type_but_not_a_namespace_Did_you_mean_to_retrieve_the_type_of_the_property_1_in_0_with_0_1,e.unescapeLeadingUnderscores(t),e.unescapeLeadingUnderscores(s)),!0}return gr(n,e.Diagnostics._0_only_refers_to_a_type_but_is_being_used_as_a_namespace_here,e.unescapeLeadingUnderscores(t)),!0}}return!1}function Zr(n,t,r){if(788584&r){var a=Ma(Vr(n,t,111127,void 0,void 0,!1));if(a&&!(1920&a.flags))return gr(n,e.Diagnostics._0_refers_to_a_value_but_is_being_used_as_a_type_here_Did_you_mean_typeof_0,e.unescapeLeadingUnderscores(t)),!0}return!1}function $r(e){return"any"===e||"string"===e||"number"===e||"boolean"===e||"never"===e||"unknown"===e}function ea(n,t){return!(!$r(t)||271!==n.parent.kind)&&(gr(n,e.Diagnostics.Cannot_export_0_Only_local_declarations_can_be_exported_from_a_module,t),!0)}function na(n,t,r){if(111551&r){if($r(t))return gr(n,e.Diagnostics._0_only_refers_to_a_type_but_is_being_used_as_a_value_here,e.unescapeLeadingUnderscores(t)),!0;var a=Ma(Vr(n,t,788544,void 0,void 0,!1));if(a&&!(1024&a.flags)){var i=e.unescapeLeadingUnderscores(t);return ra(t)?gr(n,e.Diagnostics._0_only_refers_to_a_type_but_is_being_used_as_a_value_here_Do_you_need_to_change_your_target_library_Try_changing_the_lib_compiler_option_to_es2015_or_later,i):ta(n,a)?gr(n,e.Diagnostics._0_only_refers_to_a_type_but_is_being_used_as_a_value_here_Did_you_mean_to_use_1_in_0,i,"K"===i?"P":"K"):gr(n,e.Diagnostics._0_only_refers_to_a_type_but_is_being_used_as_a_value_here,i),!0}}return!1}function ta(n,t){var r=e.findAncestor(n.parent,(function(n){return!e.isComputedPropertyName(n)&&!e.isPropertySignature(n)&&(e.isTypeLiteralNode(n)||"quit")}));if(r&&1===r.members.length){var a=mc(t);return!!(1048576&a.flags)&&ID(a,384,!0)}return!1}function ra(e){switch(e){case"Promise":case"Symbol":case"Map":case"WeakMap":case"Set":case"WeakSet":return!0}return!1}function aa(n,t,r){if(111127&r){var a=Ma(Vr(n,t,1024,void 0,void 0,!1));if(a)return gr(n,e.Diagnostics.Cannot_use_namespace_0_as_a_value,e.unescapeLeadingUnderscores(t)),!0}else if(788544&r){a=Ma(Vr(n,t,1536,void 0,void 0,!1));if(a)return gr(n,e.Diagnostics.Cannot_use_namespace_0_as_a_type,e.unescapeLeadingUnderscores(t)),!0}return!1}function ia(n,t){var r;if(e.Debug.assert(!!(2&n.flags||32&n.flags||384&n.flags)),!(67108881&n.flags&&32&n.flags)){var a=null===(r=n.declarations)||void 0===r?void 0:r.find((function(n){return e.isBlockOrCatchScoped(n)||e.isClassLike(n)||256===n.kind}));if(void 0===a)return e.Debug.fail("checkResolvedBlockScopedVariable could not find block-scoped declaration");if(!(8388608&a.flags)&&!Br(a,t)){var i=void 0,o=e.declarationNameToString(e.getNameOfDeclaration(a));2&n.flags?i=gr(t,e.Diagnostics.Block_scoped_variable_0_used_before_its_declaration,o):32&n.flags?i=gr(t,e.Diagnostics.Class_0_used_before_its_declaration,o):256&n.flags?i=gr(t,e.Diagnostics.Enum_0_used_before_its_declaration,o):(e.Debug.assert(!!(128&n.flags)),e.shouldPreserveConstEnums(C)&&(i=gr(t,e.Diagnostics.Enum_0_used_before_its_declaration,o))),i&&e.addRelatedInfo(i,e.createDiagnosticForNode(a,e.Diagnostics._0_is_declared_here,o))}}}function oa(n,t,r){return!!t&&!!e.findAncestor(n,(function(n){return n===r||e.isFunctionLike(n)?"quit":n===t}))}function sa(e){switch(e.kind){case 261:return e;case 263:return e.parent;case 264:return e.parent.parent;case 266:return e.parent.parent.parent;default:return}}function ca(n){return n.declarations&&e.findLast(n.declarations,la)}function la(n){return 261===n.kind||260===n.kind||263===n.kind&&!!n.name||264===n.kind||270===n.kind||266===n.kind||271===n.kind||267===n.kind&&e.exportAssignmentIsAlias(n)||e.isBinaryExpression(n)&&2===e.getAssignmentDeclarationKind(n)&&e.exportAssignmentIsAlias(n)||e.isAccessExpression(n)&&e.isBinaryExpression(n.parent)&&n.parent.left===n&&62===n.parent.operatorToken.kind&&ua(n.parent.right)||290===n.kind||289===n.kind&&ua(n.initializer)||e.isRequireVariableDeclaration(n)}function ua(n){return e.isAliasableExpression(n)||e.isFunctionExpression(n)&&uL(n)}function da(n,t){var r=Aa(n);if(r){var a=e.getLeftmostAccessExpression(r.expression).arguments[0];return e.isIdentifier(r.name)?Ma(_u(Bu(a),r.name.escapedText)):void 0}if(e.isVariableDeclaration(n)||273===n.moduleReference.kind){var i=Za(n,e.getExternalModuleRequireArgument(n)||e.getExternalModuleImportEqualsDeclarationExpression(n)),o=ri(i);return Ba(n,i,o,!1),o}var s=Wa(n.moduleReference,t);return pa(n,s),s}function pa(n,t){if(Ba(n,void 0,t,!1)&&!n.isTypeOnly){var r=Va(yi(n)),a=e.typeOnlyDeclarationIsExport(r),i=a?e.Diagnostics.An_import_alias_cannot_reference_a_declaration_that_was_exported_using_export_type:e.Diagnostics.An_import_alias_cannot_reference_a_declaration_that_was_imported_using_import_type,o=a?e.Diagnostics._0_was_exported_here:e.Diagnostics._0_was_imported_here,s=e.unescapeLeadingUnderscores(r.name.escapedText);e.addRelatedInfo(gr(n.moduleReference,i),e.createDiagnosticForNode(r,o,s))}}function fa(e,n,t,r){var a=e.exports.get("export="),i=a?_u(ws(a),n):e.exports.get(n),o=Ma(i,r);return Ba(t,i,o,!1),o}function ma(n){return e.isExportAssignment(n)&&!n.isExportEquals||e.hasSyntacticModifier(n,512)||e.isExportSpecifier(n)}function _a(n,t,r){if(!W)return!1;if(!n||n.isDeclarationFile){var a=fa(t,"default",void 0,!0);return(!a||!e.some(a.declarations,ma))&&!fa(t,e.escapeLeadingUnderscores("__esModule"),void 0,r)}return e.isSourceFileJS(n)?!n.externalModuleIndicator&&!fa(t,e.escapeLeadingUnderscores("__esModule"),void 0,r):oi(t)}function ga(n,t){var r,a=Za(n,n.parent.moduleSpecifier);if(a){var i=void 0;i=e.isShorthandAmbientModuleSymbol(a)?a:fa(a,"default",n,t);var o=null===(r=a.declarations)||void 0===r?void 0:r.find(e.isSourceFile),s=_a(o,a,t);if(i||s){if(s){var c=ri(a,t)||Ma(a,t);return Ba(n,a,c,!1),c}}else if(oi(a)){var l=G>=e.ModuleKind.ES2015?"allowSyntheticDefaultImports":"esModuleInterop",u=a.exports.get("export="),d=u.valueDeclaration,p=gr(n.name,e.Diagnostics.Module_0_can_only_be_default_imported_using_the_1_flag,ro(a),l);d&&e.addRelatedInfo(p,e.createDiagnosticForNode(d,e.Diagnostics.This_module_is_declared_with_using_export_and_can_only_be_used_with_a_default_import_when_using_the_0_flag,l))}else ya(a,n);return Ba(n,i,void 0,!1),i}}function ya(n,t){var r,a,i;if(null===(r=n.exports)||void 0===r?void 0:r.has(t.symbol.escapedName))gr(t.name,e.Diagnostics.Module_0_has_no_default_export_Did_you_mean_to_use_import_1_from_0_instead,ro(n),ro(t.symbol));else{var o=gr(t.name,e.Diagnostics.Module_0_has_no_default_export,ro(n)),s=null===(a=n.exports)||void 0===a?void 0:a.get("__export");if(s){var c=null===(i=s.declarations)||void 0===i?void 0:i.find((function(n){var t,r;return!!(e.isExportDeclaration(n)&&n.moduleSpecifier&&(null===(r=null===(t=Za(n,n.moduleSpecifier))||void 0===t?void 0:t.exports)||void 0===r?void 0:r.has("default")))}));c&&e.addRelatedInfo(o,e.createDiagnosticForNode(c,e.Diagnostics.export_Asterisk_does_not_re_export_a_default))}}}function ha(e,n){var t=e.parent.parent.moduleSpecifier,r=Za(e,t),a=ii(r,t,n,!1);return Ba(e,r,a,!1),a}function va(e,n){var t=e.parent.moduleSpecifier,r=t&&Za(e,t),a=t&&ii(r,t,n,!1);return Ba(e,r,a,!1),a}function ba(n,t){if(n===Te&&t===Te)return Te;if(790504&n.flags)return n;var r=Sr(n.flags|t.flags,n.escapedName);return r.declarations=e.deduplicate(e.concatenate(n.declarations,t.declarations),e.equateValues),r.parent=n.parent||t.parent,n.valueDeclaration&&(r.valueDeclaration=n.valueDeclaration),t.members&&(r.members=new e.Map(t.members)),n.exports&&(r.exports=new e.Map(n.exports)),r}function Ea(e,n,t,r){if(1536&e.flags){var a=pi(e).get(n.escapedText),i=Ma(a,r);return Ba(t,a,i,!1),i}}function Ta(e,n){if(3&e.flags){var t=e.valueDeclaration.type;if(t)return Ma(_u(zm(t),n))}}function Sa(n,t,r){var a,i;void 0===r&&(r=!1);var o=e.getExternalModuleRequireArgument(n)||n.moduleSpecifier,s=Za(n,o),c=!e.isPropertyAccessExpression(t)&&t.propertyName||t.name;if(e.isIdentifier(c)){var l="default"===c.escapedText&&!(!C.allowSyntheticDefaultImports&&!C.esModuleInterop),u=ii(s,o,!1,l);if(u&&c.escapedText){if(e.isShorthandAmbientModuleSymbol(s))return s;var d=void 0;d=s&&s.exports&&s.exports.get("export=")?_u(ws(u),c.escapedText,!0):Ta(u,c.escapedText),d=Ma(d,r);var p=Ea(u,c,t,r);if(void 0===p&&"default"===c.escapedText){var f=null===(a=s.declarations)||void 0===a?void 0:a.find(e.isSourceFile);_a(f,s,r)&&(p=ri(s,r)||Ma(s,r))}var m=p&&d&&p!==d?ba(d,p):p||d;if(!m){var _=za(s,n),g=e.declarationNameToString(c),y=KS(c,u);if(void 0!==y){var h=ro(y),v=gr(c,e.Diagnostics._0_has_no_exported_member_named_1_Did_you_mean_2,_,g,h);y.valueDeclaration&&e.addRelatedInfo(v,e.createDiagnosticForNode(y.valueDeclaration,e.Diagnostics._0_is_declared_here,h))}else(null===(i=s.exports)||void 0===i?void 0:i.has("default"))?gr(c,e.Diagnostics.Module_0_has_no_exported_member_1_Did_you_mean_to_use_import_1_from_0_instead,_,g):xa(n,c,g,s,_)}return m}}}function xa(n,t,r,a,o){var s,c,l=null===(c=null===(s=a.valueDeclaration)||void 0===s?void 0:s.locals)||void 0===c?void 0:c.get(t.escapedText),u=a.exports;if(l){var d=null===u||void 0===u?void 0:u.get("export=");if(d)xi(d,l)?La(n,t,r,o):gr(t,e.Diagnostics.Module_0_has_no_exported_member_1,o,r);else{var p=u?e.find(xu(u),(function(e){return!!xi(e,l)})):void 0,f=p?gr(t,e.Diagnostics.Module_0_declares_1_locally_but_it_is_exported_as_2,o,r,ro(p)):gr(t,e.Diagnostics.Module_0_declares_1_locally_but_it_is_not_exported,o,r);l.declarations&&e.addRelatedInfo.apply(void 0,i([f],e.map(l.declarations,(function(n,t){return e.createDiagnosticForNode(n,0===t?e.Diagnostics._0_is_declared_here:e.Diagnostics.and_here,r)}))))}}else gr(t,e.Diagnostics.Module_0_has_no_exported_member_1,o,r)}function La(n,t,r,a){if(G>=e.ModuleKind.ES2015){var i=C.esModuleInterop?e.Diagnostics._0_can_only_be_imported_by_using_a_default_import:e.Diagnostics._0_can_only_be_imported_by_turning_on_the_esModuleInterop_flag_and_using_a_default_import;gr(t,i,r)}else if(e.isInJSFile(n)){i=C.esModuleInterop?e.Diagnostics._0_can_only_be_imported_by_using_a_require_call_or_by_using_a_default_import:e.Diagnostics._0_can_only_be_imported_by_using_a_require_call_or_by_turning_on_the_esModuleInterop_flag_and_using_a_default_import;gr(t,i,r)}else{i=C.esModuleInterop?e.Diagnostics._0_can_only_be_imported_by_using_import_1_require_2_or_a_default_import:e.Diagnostics._0_can_only_be_imported_by_using_import_1_require_2_or_by_turning_on_the_esModuleInterop_flag_and_using_a_default_import;gr(t,i,r,r,a)}}function Da(n,t){var r=e.isBindingElement(n)?e.getRootDeclaration(n):n.parent.parent.parent,a=Aa(r),i=Sa(r,a||n,t),o=n.propertyName||n.name;return a&&i&&e.isIdentifier(o)?Ma(_u(ws(i),o.escapedText),t):(Ba(n,void 0,i,!1),i)}function Aa(n){if(e.isVariableDeclaration(n)&&n.initializer&&e.isPropertyAccessExpression(n.initializer))return n.initializer}function Ca(e,n){var t=ri(e.parent.symbol,n);return Ba(e,void 0,t,!1),t}function Ia(e,n,t){var r=e.parent.parent.moduleSpecifier?Sa(e.parent.parent,e,t):qa(e.propertyName||e.name,n,!1,t);return Ba(e,void 0,r,!1),r}function Na(n,t){var r=e.isExportAssignment(n)?n.expression:n.right,a=ka(r,t);return Ba(n,void 0,a,!1),a}function ka(n,t){if(e.isClassExpression(n))return $D(n).symbol;if(e.isEntityName(n)||e.isEntityNameExpression(n)){var r=qa(n,901119,!0,t);return r||($D(n),Pr(n).resolvedSymbol)}}function Ra(e,n){var t=e.initializer;return ka(t,n)}function Oa(n,t){if(e.isBinaryExpression(n.parent)&&n.parent.left===n&&62===n.parent.operatorToken.kind)return ka(n.parent.right,t)}function wa(n,t){switch(void 0===t&&(t=!1),n.kind){case 261:case 250:return da(n,t);case 263:return ga(n,t);case 264:return ha(n,t);case 270:return va(n,t);case 266:case 199:return Da(n,t);case 271:return Ia(n,901119,t);case 267:case 217:return Na(n,t);case 260:return Ca(n,t);case 290:return qa(n.name,901119,!0,t);case 289:return Ra(n,t);case 203:case 202:return Oa(n,t);default:return e.Debug.fail()}}function Pa(e,n){return void 0===n&&(n=901119),!!e&&(2097152===(e.flags&(2097152|n))||!!(2097152&e.flags&&67108864&e.flags))}function Ma(e,n){return!n&&Pa(e)?Fa(e):e}function Fa(n){e.Debug.assert(0!==(2097152&n.flags),"Should only get Alias here.");var t=wr(n);if(t.target)t.target===Se&&(t.target=Te);else{t.target=Se;var r=ca(n);if(!r)return e.Debug.fail();var a=wa(r);t.target===Se?t.target=a||Te:gr(r,e.Diagnostics.Circular_definition_of_import_alias_0,ro(n))}return t.target}function Ga(e){var n=wr(e);if(n.target!==Se)return Fa(e)}function Ba(n,t,r,a){if(!n||e.isPropertyAccessExpression(n))return!1;var i=yi(n);if(e.isTypeOnlyImportOrExportDeclaration(n)){var o=wr(i);return o.typeOnlyDeclaration=n,!0}var s=wr(i);return Ua(s,t,a)||Ua(s,r,a)}function Ua(n,t,r){var a,i,o;if(t&&(void 0===n.typeOnlyDeclaration||r&&!1===n.typeOnlyDeclaration)){var s=null!==(i=null===(a=t.exports)||void 0===a?void 0:a.get("export="))&&void 0!==i?i:t,c=s.declarations&&e.find(s.declarations,e.isTypeOnlyImportOrExportDeclaration);n.typeOnlyDeclaration=null!==(o=null!==c&&void 0!==c?c:wr(s).typeOnlyDeclaration)&&void 0!==o&&o}return!!n.typeOnlyDeclaration}function Va(e){if(2097152&e.flags){var n=wr(e);return n.typeOnlyDeclaration||void 0}}function ja(e){var n=yi(e),t=Fa(n);if(t){var r=t===Te||111551&t.flags&&!mR(t)&&!Va(n);r&&Ka(n)}}function Ka(n){var t=wr(n);if(!t.referenced){t.referenced=!0;var r=ca(n);if(!r)return e.Debug.fail();if(e.isInternalModuleImportEqualsDeclaration(r)){var a=Ma(n);(a===Te||111551&a.flags)&&$D(r.moduleReference)}}}function Ha(e){var n=wr(e);n.constEnumReferenced||(n.constEnumReferenced=!0)}function Wa(n,t){return 78===n.kind&&e.isRightSideOfQualifiedNameOrPropertyAccess(n)&&(n=n.parent),78===n.kind||158===n.parent.kind?qa(n,1920,!1,t):(e.Debug.assert(261===n.parent.kind),qa(n,901119,!1,t))}function za(e,n){return e.parent?za(e.parent,n)+"."+ro(e):ro(e,n,void 0,20)}function qa(n,t,r,a,i){if(!e.nodeIsMissing(n)){var o,s=1920|(e.isInJSFile(n)?111551&t:0);if(78===n.kind){var c=t===s||e.nodeIsSynthesized(n)?e.Diagnostics.Cannot_find_namespace_0:tv(e.getFirstIdentifier(n)),l=e.isInJSFile(n)&&!e.nodeIsSynthesized(n)?Ja(n,t):void 0;if(o=gi(Vr(i||n,n.escapedText,t,r||l?void 0:c,n,!0)),!o)return gi(l)}else{if(158!==n.kind&&202!==n.kind)throw e.Debug.assertNever(n,"Unknown entity name kind.");var u=158===n.kind?n.left:n.expression,d=158===n.kind?n.right:n.name,p=qa(u,s,r,!1,i);if(!p||e.nodeIsMissing(d))return;if(p===Te)return p;if(p.valueDeclaration&&e.isInJSFile(p.valueDeclaration)&&e.isVariableDeclaration(p.valueDeclaration)&&p.valueDeclaration.initializer&&EL(p.valueDeclaration.initializer)){var f=p.valueDeclaration.initializer.arguments[0],m=Za(f,f);if(m){var _=ri(m);_&&(p=_)}}if(o=gi(Fr(pi(p),d.escapedText,t)),!o){if(!r){var g=za(p),y=e.declarationNameToString(d),h=KS(d,p);h?gr(d,e.Diagnostics._0_has_no_exported_member_named_1_Did_you_mean_2,g,y,ro(h)):gr(d,e.Diagnostics.Namespace_0_has_no_exported_member_1,g,y)}return}}return e.Debug.assert(0===(1&e.getCheckFlags(o)),"Should never get an instantiated symbol here."),!e.nodeIsSynthesized(n)&&e.isEntityName(n)&&(2097152&o.flags||267===n.parent.kind)&&Ba(e.getAliasDeclarationFromName(n),o,void 0,!0),o.flags&t||a?o:Fa(o)}}function Ja(e,n){if(Md(e.parent)){var t=Xa(e.parent);if(t)return Vr(t,e.escapedText,n,void 0,e,!0)}}function Xa(n){var t=e.findAncestor(n,(function(n){return e.isJSDocNode(n)||4194304&n.flags?e.isJSDocTypeAlias(n):"quit"}));if(!t){var r=e.getJSDocHost(n);if(r&&e.isExpressionStatement(r)&&e.isBinaryExpression(r.expression)&&3===e.getAssignmentDeclarationKind(r.expression)){var a=yi(r.expression.left);if(a)return Ya(a)}if(r&&(e.isObjectLiteralMethod(r)||e.isPropertyAssignment(r))&&e.isBinaryExpression(r.parent.parent)&&6===e.getAssignmentDeclarationKind(r.parent.parent)){a=yi(r.parent.parent.left);if(a)return Ya(a)}var i=e.getEffectiveJSDocHost(n);if(i&&e.isFunctionLike(i)){a=yi(i);return a&&a.valueDeclaration}}}function Ya(n){var t=n.parent.valueDeclaration;if(t){var r=e.isAssignmentDeclaration(t)?e.getAssignedExpandoInitializer(t):e.hasOnlyExpressionInitializer(t)?e.getDeclaredExpandoInitializer(t):void 0;return r||t}}function Qa(n){var t=n.valueDeclaration;if(t&&e.isInJSFile(t)&&!(524288&n.flags)&&!e.getExpandoInitializer(t,!1)){var r=e.isVariableDeclaration(t)?e.getDeclaredExpandoInitializer(t):e.getAssignedExpandoInitializer(t);if(r){var a=yi(r);if(a)return dL(a,n)}}}function Za(n,t,r){var a=e.getEmitModuleResolutionKind(C)===e.ModuleResolutionKind.Classic,i=a?e.Diagnostics.Cannot_find_module_0_Did_you_mean_to_set_the_moduleResolution_option_to_node_or_to_add_aliases_to_the_paths_option:e.Diagnostics.Cannot_find_module_0_or_its_corresponding_type_declarations;return $a(n,t,r?void 0:i)}function $a(n,t,r,a){return void 0===a&&(a=!1),e.isStringLiteralLike(t)?ei(n,t.text,r,t,a):void 0}function ei(t,r,a,i,o){if(void 0===o&&(o=!1),e.startsWith(r,"@types/")){var s=e.Diagnostics.Cannot_import_type_declaration_files_Consider_importing_0_instead_of_1,c=e.removePrefix(r,"@types/");gr(i,s,c,r)}var l=Du(r,!0);if(l)return l;var u=e.getSourceFileOfNode(t),d=e.getResolvedModule(u,r),p=d&&e.getResolutionDiagnostic(C,d),f=d&&!p&&n.getSourceFile(d.resolvedFileName);if(f)return f.symbol?(d.isExternalLibraryImport&&!e.resolutionExtensionIsTSOrJson(d.extension)&&ni(!1,i,d,r),gi(f.symbol)):void(a&&gr(i,e.Diagnostics.File_0_is_not_a_module,f.fileName));if(hn){var m=e.findBestPatternMatch(hn,(function(e){return e.pattern}),r);if(m){var _=vn&&vn.get(r);return gi(_?_:m.symbol)}}if(d&&!e.resolutionExtensionIsTSOrJson(d.extension)&&void 0===p||p===e.Diagnostics.Could_not_find_a_declaration_file_for_module_0_1_implicitly_has_an_any_type)if(o){s=e.Diagnostics.Invalid_module_name_in_augmentation_Module_0_resolves_to_an_untyped_module_at_1_which_cannot_be_augmented;gr(i,s,r,d.resolvedFileName)}else ni(Y&&!!a,i,d,r);else if(a){if(d){var g=n.getProjectReferenceRedirect(d.resolvedFileName);if(g)return void gr(i,e.Diagnostics.Output_file_0_has_not_been_built_from_source_file_1,g,d.resolvedFileName)}if(p)gr(i,p,r,d.resolvedFileName);else{var y=e.tryExtractTSExtension(r);if(y){s=e.Diagnostics.An_import_path_cannot_end_with_a_0_extension_Consider_importing_1_instead;var h=e.removeExtension(r,y),v=h,b=e.getEmitModuleKind(C);b>=e.ModuleKind.ES2015&&(v+=".js"),gr(i,s,y,v)}else!C.resolveJsonModule&&e.fileExtensionIs(r,".json")&&e.getEmitModuleResolutionKind(C)===e.ModuleResolutionKind.NodeJs&&e.hasJsonModuleEmitEnabled(C)?gr(i,e.Diagnostics.Cannot_find_module_0_Consider_using_resolveJsonModule_to_import_module_with_json_extension,r):gr(i,a,r)}}}function ni(n,t,r,a){var i=r.packageId,o=r.resolvedFileName,s=!e.isExternalModuleNameRelative(a)&&i?ti(i.name)?e.chainDiagnosticMessages(void 0,e.Diagnostics.If_the_0_package_actually_exposes_this_module_consider_sending_a_pull_request_to_amend_https_Colon_Slash_Slashgithub_com_SlashDefinitelyTyped_SlashDefinitelyTyped_Slashtree_Slashmaster_Slashtypes_Slash_1,i.name,e.mangleScopedPackageName(i.name)):e.chainDiagnosticMessages(void 0,e.Diagnostics.Try_npm_i_save_dev_types_Slash_1_if_it_exists_or_add_a_new_declaration_d_ts_file_containing_declare_module_0,a,e.mangleScopedPackageName(i.name)):void 0;hr(n,t,e.chainDiagnosticMessages(s,e.Diagnostics.Could_not_find_a_declaration_file_for_module_0_1_implicitly_has_an_any_type,a,o))}function ti(n){return m().has(e.getTypesPackageName(n))}function ri(e,n){if(null===e||void 0===e?void 0:e.exports){var t=Ma(e.exports.get("export="),n),r=ai(gi(t),gi(e));return gi(r)||e}}function ai(n,t){if(!n||n===Te||n===t||1===t.exports.size||2097152&n.flags)return n;var r=wr(n);if(r.cjsExportMerged)return r.cjsExportMerged;var a=33554432&n.flags?n:Dr(n);return a.flags=512|a.flags,void 0===a.exports&&(a.exports=e.createSymbolTable()),t.exports.forEach((function(e,n){"export="!==n&&a.exports.set(n,a.exports.has(n)?Ar(a.exports.get(n),e):e)})),wr(a).cjsExportMerged=a,r.cjsExportMerged=a}function ii(n,t,r,a){var i=ri(n,r);if(!r&&i){if(!a&&!(1539&i.flags)&&!e.getDeclarationOfKind(i,298)){var o=G>=e.ModuleKind.ES2015?"allowSyntheticDefaultImports":"esModuleInterop";return gr(t,e.Diagnostics.This_module_can_only_be_referenced_with_ECMAScript_imports_Slashexports_by_turning_on_the_0_flag_and_referencing_its_default_export,o),i}if(C.esModuleInterop){var s=t.parent;if(e.isImportDeclaration(s)&&e.getNamespaceDeclarationNode(s)||e.isImportCall(s)){var c=ws(i),l=gu(c,0);if(l&&l.length||(l=gu(c,1)),l&&l.length){var u=bL(c,i,n),d=Sr(i.flags,i.escapedName);d.declarations=i.declarations?i.declarations.slice():[],d.parent=i.parent,d.target=i,d.originatingImport=s,i.valueDeclaration&&(d.valueDeclaration=i.valueDeclaration),i.constEnumOnlyModule&&(d.constEnumOnlyModule=!0),i.members&&(d.members=new e.Map(i.members)),i.exports&&(d.exports=new e.Map(i.exports));var p=Nl(u);return d.type=Bi(d,p.members,e.emptyArray,e.emptyArray,p.stringIndexInfo,p.numberIndexInfo),d}}}}return i}function oi(e){return void 0!==e.exports.get("export=")}function si(e){return xu(fi(e))}function ci(n){var t=si(n),r=ri(n);if(r!==n){var a=ws(r);di(a)&&e.addRange(t,wl(a))}return t}function li(e,n){var t=fi(n);if(t)return t.get(e)}function ui(e,n){var t=li(e,n);if(t)return t;var r=ri(n);if(r!==n){var a=ws(r);return di(a)?_u(a,e):void 0}}function di(n){return!(131068&n.flags||1&e.getObjectFlags(n)||sy(n)||Cy(n))}function pi(e){return 6256&e.flags?wc(e,"resolvedExports"):1536&e.flags?fi(e):e.exports||D}function fi(e){var n=wr(e);return n.resolvedExports||(n.resolvedExports=_i(e))}function mi(n,t,r,a){t&&t.forEach((function(t,i){if("default"!==i){var o=n.get(i);if(o){if(r&&a&&o&&Ma(o)!==Ma(t)){var s=r.get(i);s.exportsWithDuplicate?s.exportsWithDuplicate.push(a):s.exportsWithDuplicate=[a]}}else n.set(i,t),r&&a&&r.set(i,{specifierText:e.getTextOfNode(a.moduleSpecifier)})}}))}function _i(n){var t=[];return n=ri(n),r(n)||D;function r(n){if(n&&n.exports&&e.pushIfUnique(t,n)){var a=new e.Map(n.exports),i=n.exports.get("__export");if(i){var o=e.createSymbolTable(),s=new e.Map;if(i.declarations)for(var c=0,l=i.declarations;c<l.length;c++){var u=l[c],d=Za(u,u.moduleSpecifier),p=r(d);mi(o,p,s,u)}s.forEach((function(n,t){var r=n.exportsWithDuplicate;if("export="!==t&&r&&r.length&&!a.has(t))for(var i=0,o=r;i<o.length;i++){var c=o[i];nr.add(e.createDiagnosticForNode(c,e.Diagnostics.Module_0_has_already_exported_a_member_named_1_Consider_explicitly_re_exporting_to_resolve_the_ambiguity,s.get(t).specifierText,e.unescapeLeadingUnderscores(t)))}})),mi(a,o)}return a}}}function gi(e){var n;return e&&e.mergeId&&(n=Ut[e.mergeId])?n:e}function yi(e){return gi(e.symbol&&Mc(e.symbol))}function hi(e){return gi(e.parent&&Mc(e.parent))}function vi(t,r){var a,i=e.getSourceFileOfNode(r),o=w(i),s=wr(t);if(s.extendedContainersByFile&&(a=s.extendedContainersByFile.get(o)))return a;if(i&&i.imports){for(var c=0,l=i.imports;c<l.length;c++){var u=l[c];if(!e.nodeIsSynthesized(u)){var d=Za(r,u,!0);if(d){var p=Si(d,t);p&&(a=e.append(a,d))}}}if(e.length(a))return(s.extendedContainersByFile||(s.extendedContainersByFile=new e.Map)).set(o,a),a}if(s.extendedContainers)return s.extendedContainers;for(var f=n.getSourceFiles(),m=0,_=f;m<_.length;m++){var g=_[m];if(e.isExternalModule(g)){var y=yi(g);p=Si(y,t);p&&(a=e.append(a,y))}}return s.extendedContainers=a||e.emptyArray}function bi(n,t,r){var a=hi(n);if(a&&!(262144&n.flags)){var o=e.mapDefined(a.declarations,p),s=t&&vi(n,t),c=Ei(a,r);if(t&&a.flags&ji(r)&&Ki(a,t,1920,!1))return e.append(e.concatenate(e.concatenate([a],o),s),c);var l=!(a.flags&ji(r))&&788968&a.flags&&524288&mc(a).flags&&111551===r?Vi(t,(function(n){return e.forEachEntry(n,(function(e){if(e.flags&ji(r)&&ws(e)===mc(a))return e}))})):void 0,u=i(i(l?[l]:[],o),[a]);return u=e.append(u,c),u=e.addRange(u,s),u}var d=e.mapDefined(n.declarations,(function(n){return!e.isAmbientModule(n)&&n.parent&&eo(n.parent)?yi(n.parent):e.isClassExpression(n)&&e.isBinaryExpression(n.parent)&&62===n.parent.operatorToken.kind&&e.isAccessExpression(n.parent.left)&&e.isEntityNameExpression(n.parent.left.expression)?e.isModuleExportsAccessExpression(n.parent.left)||e.isExportsIdentifier(n.parent.left.expression)?yi(e.getSourceFileOfNode(n)):($D(n.parent.left.expression),Pr(n.parent.left.expression).resolvedSymbol):void 0}));if(e.length(d))return e.mapDefined(d,(function(e){return Si(e,n)?e:void 0}));function p(e){return a&&Ti(e,a)}}function Ei(n,t){var r=!!e.length(n.declarations)&&e.first(n.declarations);if(111551&t&&r&&r.parent&&e.isVariableDeclaration(r.parent)&&(e.isObjectLiteralExpression(r)&&r===r.parent.initializer||e.isTypeLiteralNode(r)&&r===r.parent.type))return yi(r.parent)}function Ti(e,n){var t=Zi(e),r=t&&t.exports&&t.exports.get("export=");return r&&xi(r,n)?t:void 0}function Si(n,t){if(n===hi(t))return t;var r=n.exports&&n.exports.get("export=");if(r&&xi(r,t))return n;var a=pi(n),i=a.get(t.escapedName);return i&&xi(i,t)?i:e.forEachEntry(a,(function(e){if(xi(e,t))return e}))}function xi(e,n){if(gi(Ma(gi(e)))===gi(Ma(gi(n))))return e}function Li(e){return gi(e&&0!==(1048576&e.flags)?e.exportSymbol:e)}function Di(e){return!!(111551&e.flags||2097152&e.flags&&111551&Fa(e).flags&&!Va(e))}function Ai(n){for(var t=n.members,r=0,a=t;r<a.length;r++){var i=a[r];if(167===i.kind&&e.nodeIsPresent(i.body))return i}}function Ci(n){var r=new g(le,n);return h++,r.id=h,t&&(null===e.tracing||void 0===e.tracing||e.tracing.recordType(r)),r}function Ii(e){return new g(le,e)}function Ni(e,n,t){void 0===t&&(t=0);var r=Ci(e);return r.intrinsicName=n,r.objectFlags=t,r}function ki(e){var n=Qp(e);return n.flags|=16,n.intrinsicName="boolean",n}function Ri(e,n){var t=Ci(524288);return t.objectFlags=e,t.symbol=n,t.members=void 0,t.properties=void 0,t.callSignatures=void 0,t.constructSignatures=void 0,t.stringIndexInfo=void 0,t.numberIndexInfo=void 0,t}function Oi(){return Qp(e.arrayFrom(S.keys(),Fm))}function wi(e){var n=Ci(262144);return e&&(n.symbol=e),n}function Pi(e){return 95===e.charCodeAt(0)&&95===e.charCodeAt(1)&&95!==e.charCodeAt(2)&&64!==e.charCodeAt(2)&&35!==e.charCodeAt(2)}function Mi(n){var t;return n.forEach((function(e,n){!Pi(n)&&Di(e)&&(t||(t=[])).push(e)})),t||e.emptyArray}function Fi(n){var t=Mi(n),r=od(n);return r?e.concatenate(t,[r]):t}function Gi(n,t,r,a,i,o){var s=n;return s.members=t,s.properties=e.emptyArray,s.callSignatures=r,s.constructSignatures=a,s.stringIndexInfo=i,s.numberIndexInfo=o,t!==D&&(s.properties=Mi(t)),s}function Bi(e,n,t,r,a,i){return Gi(Ri(16,e),n,t,r,a,i)}function Ui(n){if(0===n.constructSignatures.length)return n;if(n.objectTypeWithoutAbstractConstructSignatures)return n.objectTypeWithoutAbstractConstructSignatures;var t=e.filter(n.constructSignatures,(function(e){return!(4&e.flags)}));if(n.constructSignatures===t)return n;var r=Bi(n.symbol,n.members,n.callSignatures,e.some(t)?t:e.emptyArray,n.stringIndexInfo,n.numberIndexInfo);return n.objectTypeWithoutAbstractConstructSignatures=r,r.objectTypeWithoutAbstractConstructSignatures=r,r}function Vi(n,t){for(var r,a=function(n){if(n.locals&&!Mr(n)&&(r=t(n.locals,void 0,!0)))return{value:r};switch(n.kind){case 298:if(!e.isExternalOrCommonJsModule(n))break;case 257:var a=yi(n);if(r=t((null===a||void 0===a?void 0:a.exports)||D,void 0,!0))return{value:r};break;case 253:case 222:case 254:var i;if((yi(n).members||D).forEach((function(n,t){788968&n.flags&&(i||(i=e.createSymbolTable())).set(t,n)})),i&&(r=t(i)))return{value:r};break}},i=n;i;i=i.parent){var o=a(i);if("object"===typeof o)return o.value}return t(re,void 0,!0)}function ji(e){return 111551===e?111551:1920}function Ki(n,t,r,a,i){if(void 0===i&&(i=new e.Map),n&&!Wi(n)){var o=P(n),s=i.get(o);return s||i.set(o,s=[]),Vi(t,c)}function c(n,t,r){if(e.pushIfUnique(s,n)){var a=d(n,t,r);return s.pop(),a}}function l(e,n){return!Hi(e,t,n)||!!Ki(e.parent,t,ji(n),a,i)}function u(t,a,i){return(n===(a||t)||gi(n)===gi(a||t))&&!e.some(t.declarations,eo)&&(i||l(gi(t),r))}function d(r,i,o){if(u(r.get(n.escapedName),void 0,i))return[n];var s=e.forEachEntry(r,(function(r){if(2097152&r.flags&&"export="!==r.escapedName&&"default"!==r.escapedName&&!(e.isUMDExportSymbol(r)&&t&&e.isExternalModule(e.getSourceFileOfNode(t)))&&(!a||e.some(r.declarations,e.isExternalModuleImportEqualsDeclaration))&&(!o||!e.some(r.declarations,e.isNamespaceReexportDeclaration))&&(i||!e.getDeclarationOfKind(r,271))){var s=Fa(r),c=p(r,s,i);if(c)return c}if(r.escapedName===n.escapedName&&r.exportSymbol&&u(gi(r.exportSymbol),void 0,i))return[n]}));return s||(r===re?p(ie,ie,i):void 0)}function p(e,n,t){if(u(e,n,t))return[e];var a=pi(n),i=a&&c(a,!0);return i&&l(e,ji(r))?[e].concat(i):void 0}}function Hi(n,t,r){var a=!1;return Vi(t,(function(t){var i=gi(t.get(n.escapedName));return!!i&&(i===n||(i=2097152&i.flags&&!e.getDeclarationOfKind(i,271)?Fa(i):i,!!(i.flags&r)&&(a=!0,!0)))})),a}function Wi(e){if(e.declarations&&e.declarations.length){for(var n=0,t=e.declarations;n<t.length;n++){var r=t[n];switch(r.kind){case 164:case 166:case 168:case 169:continue;default:return!1}}return!0}return!1}function zi(e,n){var t=Qi(e,n,788968,!1,!0);return 0===t.accessibility}function qi(e,n){var t=Qi(e,n,111551,!1,!0);return 0===t.accessibility}function Ji(e,n,t){var r=Qi(e,n,t,!1,!1);return 0===r.accessibility}function Xi(n,t,r,a,i,o){if(e.length(n)){for(var s,c=!1,l=0,u=n;l<u.length;l++){var d=u[l],p=Ki(d,t,a,!1);if(p){s=d;var f=no(p[0],i);if(f)return f}if(o&&e.some(d.declarations,eo)){if(i){c=!0;continue}return{accessibility:0}}var m=bi(d,t,a),_=Xi(m,t,r,r===d?ji(a):a,i,o);if(_)return _}return c?{accessibility:0}:s?{accessibility:1,errorSymbolName:ro(r,t,a),errorModuleName:s!==r?ro(s,t,1920):void 0}:void 0}}function Yi(e,n,t,r){return Qi(e,n,t,r,!0)}function Qi(n,t,r,a,i){if(n&&t){var o=Xi([n],t,n,r,a,i);if(o)return o;var s=e.forEach(n.declarations,Zi);if(s){var c=Zi(t);if(s!==c)return{accessibility:2,errorSymbolName:ro(n,t,r),errorModuleName:ro(s),errorNode:e.isInJSFile(t)?t:void 0}}return{accessibility:1,errorSymbolName:ro(n,t,r)}}return{accessibility:0}}function Zi(n){var t=e.findAncestor(n,$i);return t&&yi(t)}function $i(n){return e.isAmbientModule(n)||298===n.kind&&e.isExternalOrCommonJsModule(n)}function eo(n){return e.isModuleWithStringLiteralName(n)||298===n.kind&&e.isExternalOrCommonJsModule(n)}function no(n,t){var r;if(e.every(e.filter(n.declarations,(function(e){return 78!==e.kind})),a))return{accessibility:0,aliasesToMakeVisible:r};function a(t){var r,a;if(!Eo(t)){var o=sa(t);return o&&!e.hasSyntacticModifier(o,1)&&Eo(o.parent)?i(t,o):e.isVariableDeclaration(t)&&e.isVariableStatement(t.parent.parent)&&!e.hasSyntacticModifier(t.parent.parent,1)&&Eo(t.parent.parent.parent)?i(t,t.parent.parent):e.isLateVisibilityPaintedStatement(t)&&!e.hasSyntacticModifier(t,1)&&Eo(t.parent)?i(t,t):!!(2097152&n.flags&&e.isBindingElement(t)&&e.isInJSFile(t)&&(null===(r=t.parent)||void 0===r?void 0:r.parent)&&e.isVariableDeclaration(t.parent.parent)&&(null===(a=t.parent.parent.parent)||void 0===a?void 0:a.parent)&&e.isVariableStatement(t.parent.parent.parent.parent)&&!e.hasSyntacticModifier(t.parent.parent.parent.parent,1)&&t.parent.parent.parent.parent.parent&&Eo(t.parent.parent.parent.parent.parent))&&i(t,t.parent.parent.parent.parent)}return!0}function i(n,a){return t&&(Pr(n).isVisible=!0,r=e.appendIfUnique(r,a)),!0}}function to(n,t){var r;r=177===n.parent.kind||e.isExpressionWithTypeArgumentsInClassExtendsClause(n.parent)||159===n.parent.kind?1160127:158===n.kind||202===n.kind||261===n.parent.kind?1920:788968;var a=e.getFirstIdentifier(n),i=Vr(t,a.escapedText,r,void 0,void 0,!1);return i&&262144&i.flags&&788968&r?{accessibility:0}:i&&no(i,!0)||{accessibility:1,errorSymbolName:e.getTextOfNode(a),errorNode:a}}function ro(n,t,r,a,i){void 0===a&&(a=4);var o=70221824;2&a&&(o|=128),1&a&&(o|=512),8&a&&(o|=16384),16&a&&(o|=134217728);var s=4&a?te.symbolToExpression:te.symbolToEntityName;return i?c(i).getText():e.usingSingleLineStringWriter(c);function c(a){var i=s(n,r,t,o),c=298===(null===t||void 0===t?void 0:t.kind)?e.createPrinter({removeComments:!0,neverAsciiEscape:!0}):e.createPrinter({removeComments:!0}),l=t&&e.getSourceFileOfNode(t);return c.writeNode(4,i,l,a),a}}function ao(n,t,r,a,i){return void 0===r&&(r=0),i?o(i).getText():e.usingSingleLineStringWriter(o);function o(i){var o;o=262144&r?1===a?176:175:1===a?171:170;var s=te.signatureToSignatureDeclaration(n,o,t,70222336|lo(r)),c=e.createPrinter({removeComments:!0,omitTrailingSemicolon:!0}),l=t&&e.getSourceFileOfNode(t);return c.writeNode(4,s,l,e.getTrailingSemicolonDeferringWriter(i)),i}}function io(n,t,r,a){void 0===r&&(r=1064960),void 0===a&&(a=e.createTextWriter(""));var i=C.noErrorTruncation||1&r,o=te.typeToTypeNode(n,t,70221824|lo(r)|(i?1:0),a);if(void 0===o)return e.Debug.fail("should always get typenode");var s={removeComments:!0},c=e.createPrinter(s),l=t&&e.getSourceFileOfNode(t);c.writeNode(4,o,l,a);var u=a.getText(),d=i?2*e.noTruncationMaximumTruncationLength:2*e.defaultMaximumTruncationLength;return d&&u&&u.length>=d?u.substr(0,d-"...".length)+"...":u}function oo(e,n){var t=co(e.symbol)?io(e,e.symbol.valueDeclaration):io(e),r=co(n.symbol)?io(n,n.symbol.valueDeclaration):io(n);return t===r&&(t=so(e),r=so(n)),[t,r]}function so(e){return io(e,void 0,64)}function co(n){return n&&!!n.valueDeclaration&&e.isExpression(n.valueDeclaration)&&!w_(n.valueDeclaration)}function lo(e){return void 0===e&&(e=0),814775659&e}function uo(n){return!!n.symbol&&!!(32&n.symbol.flags)&&(n===ac(n.symbol)||!!(524288&n.flags)&&!!(16777216&e.getObjectFlags(n)))}function po(){return{typeToTypeNode:function(e,n,r,a){return t(n,r,a,(function(n){return c(e,n)}))},indexInfoToIndexSignatureDeclaration:function(e,n,r,a,i){return t(r,a,i,(function(t){return m(e,n,t,void 0)}))},signatureToSignatureDeclaration:function(e,n,r,a,i){return t(r,a,i,(function(t){return _(e,n,t)}))},symbolToEntityName:function(e,n,r,a,i){return t(r,a,i,(function(t){return N(e,t,n,!1)}))},symbolToExpression:function(e,n,r,a,i){return t(r,a,i,(function(t){return k(e,t,n)}))},symbolToTypeParameterDeclarations:function(e,n,r,a){return t(n,r,a,(function(n){return T(e,n)}))},symbolToParameterDeclaration:function(e,n,r,a){return t(n,r,a,(function(n){return h(e,n)}))},typeParameterToDeclaration:function(e,n,r,a){return t(n,r,a,(function(n){return y(e,n)}))},symbolTableToDeclarationStatements:function(e,n,r,a,i){return t(n,r,a,(function(n){return q(e,n,i)}))}};function t(t,r,a,i){var o,s;e.Debug.assert(void 0===t||0===(8&t.flags));var c={enclosingDeclaration:t,flags:r||0,tracker:a&&a.trackSymbol?a:{trackSymbol:e.noop,moduleResolverHost:134217728&r?{getCommonSourceDirectory:n.getCommonSourceDirectory?function(){return n.getCommonSourceDirectory()}:function(){return""},getSourceFiles:function(){return n.getSourceFiles()},getCurrentDirectory:function(){return n.getCurrentDirectory()},getSymlinkCache:e.maybeBind(n,n.getSymlinkCache),useCaseSensitiveFileNames:e.maybeBind(n,n.useCaseSensitiveFileNames),redirectTargetsMap:n.redirectTargetsMap,getProjectReferenceRedirect:function(e){return n.getProjectReferenceRedirect(e)},isSourceOfProjectReferenceRedirect:function(e){return n.isSourceOfProjectReferenceRedirect(e)},fileExists:function(e){return n.fileExists(e)},getFileIncludeReasons:function(){return n.getFileIncludeReasons()}}:void 0},encounteredError:!1,visitedTypes:void 0,symbolDepth:void 0,inferTypeParameters:void 0,approximateLength:0},l=i(c);return c.truncating&&1&c.flags&&(null===(s=null===(o=c.tracker)||void 0===o?void 0:o.reportTruncationError)||void 0===s||s.call(o)),c.encounteredError?void 0:l}function a(n){return n.truncating?n.truncating:n.truncating=n.approximateLength>(1&n.flags?e.noTruncationMaximumTruncationLength:e.defaultMaximumTruncationLength)}function c(n,t){r&&r.throwIfCancellationRequested&&r.throwIfCancellationRequested();var i=8388608&t.flags;if(t.flags&=-8388609,!n)return 262144&t.flags?(t.approximateLength+=3,e.factory.createKeywordTypeNode(128)):void(t.encounteredError=!0);if(536870912&t.flags||(n=lu(n)),1&n.flags)return t.approximateLength+=3,e.factory.createKeywordTypeNode(n===Ie?136:128);if(2&n.flags)return e.factory.createKeywordTypeNode(152);if(4&n.flags)return t.approximateLength+=6,e.factory.createKeywordTypeNode(147);if(8&n.flags)return t.approximateLength+=6,e.factory.createKeywordTypeNode(144);if(64&n.flags)return t.approximateLength+=6,e.factory.createKeywordTypeNode(155);if(16&n.flags)return t.approximateLength+=7,e.factory.createKeywordTypeNode(131);if(1024&n.flags&&!(1048576&n.flags)){var o=hi(n.symbol),s=D(o,t,788968);if(mc(o)===n)return s;var u=e.symbolName(n.symbol);return e.isIdentifierText(u,0)?W(s,e.factory.createTypeReferenceNode(u,void 0)):e.isImportTypeNode(s)?(s.isTypeOf=!0,e.factory.createIndexedAccessTypeNode(s,e.factory.createLiteralTypeNode(e.factory.createStringLiteral(u)))):e.isTypeReferenceNode(s)?e.factory.createIndexedAccessTypeNode(e.factory.createTypeQueryNode(s.typeName),e.factory.createLiteralTypeNode(e.factory.createStringLiteral(u))):e.Debug.fail("Unhandled type node kind returned from `symbolToTypeNode`.")}if(1056&n.flags)return D(n.symbol,t,788968);if(128&n.flags)return t.approximateLength+=n.value.length+2,e.factory.createLiteralTypeNode(e.setEmitFlags(e.factory.createStringLiteral(n.value,!!(268435456&t.flags)),16777216));if(256&n.flags){var f=n.value;return t.approximateLength+=(""+f).length,e.factory.createLiteralTypeNode(f<0?e.factory.createPrefixUnaryExpression(40,e.factory.createNumericLiteral(-f)):e.factory.createNumericLiteral(f))}if(2048&n.flags)return t.approximateLength+=e.pseudoBigIntToString(n.value).length+1,e.factory.createLiteralTypeNode(e.factory.createBigIntLiteral(n.value));if(512&n.flags)return t.approximateLength+=n.intrinsicName.length,e.factory.createLiteralTypeNode("true"===n.intrinsicName?e.factory.createTrue():e.factory.createFalse());if(8192&n.flags){if(!(1048576&t.flags)){if(qi(n.symbol,t.enclosingDeclaration))return t.approximateLength+=6,D(n.symbol,t,111551);t.tracker.reportInaccessibleUniqueSymbolError&&t.tracker.reportInaccessibleUniqueSymbolError()}return t.approximateLength+=13,e.factory.createTypeOperatorNode(151,e.factory.createKeywordTypeNode(148))}if(16384&n.flags)return t.approximateLength+=4,e.factory.createKeywordTypeNode(113);if(32768&n.flags)return t.approximateLength+=9,e.factory.createKeywordTypeNode(150);if(65536&n.flags)return t.approximateLength+=4,e.factory.createLiteralTypeNode(e.factory.createNull());if(131072&n.flags)return t.approximateLength+=5,e.factory.createKeywordTypeNode(141);if(4096&n.flags)return t.approximateLength+=6,e.factory.createKeywordTypeNode(148);if(67108864&n.flags)return t.approximateLength+=6,e.factory.createKeywordTypeNode(145);if(Yf(n))return 4194304&t.flags&&(t.encounteredError||32768&t.flags||(t.encounteredError=!0),t.tracker.reportInaccessibleThisError&&t.tracker.reportInaccessibleThisError()),t.approximateLength+=4,e.factory.createThisTypeNode();if(!i&&n.aliasSymbol&&(16384&t.flags||zi(n.aliasSymbol,t.enclosingDeclaration))){var y=p(n.aliasTypeArguments,t);return!Pi(n.aliasSymbol.escapedName)||32&n.aliasSymbol.flags?D(n.aliasSymbol,t,788968,y):e.factory.createTypeReferenceNode(e.factory.createIdentifier(""),y)}var h=e.getObjectFlags(n);if(4&h)return e.Debug.assert(!!(524288&n.flags)),n.node?j(n,H):H(n);if(262144&n.flags||3&h){if(262144&n.flags&&e.contains(t.inferTypeParameters,n))return t.approximateLength+=e.symbolName(n.symbol).length+6,e.factory.createInferTypeNode(g(n,t,void 0));if(4&t.flags&&262144&n.flags&&!zi(n.symbol,t.enclosingDeclaration)){var v=I(n,t);return t.approximateLength+=e.idText(v).length,e.factory.createTypeReferenceNode(e.factory.createIdentifier(e.idText(v)),void 0)}return n.symbol?D(n.symbol,t,788968):e.factory.createTypeReferenceNode(e.factory.createIdentifier("?"),void 0)}if(1048576&n.flags&&n.origin&&(n=n.origin),3145728&n.flags){var b=1048576&n.flags?mo(n.types):n.types;if(1===e.length(b))return c(b[0],t);var E=p(b,t,!0);return E&&E.length>0?1048576&n.flags?e.factory.createUnionTypeNode(E):e.factory.createIntersectionTypeNode(E):void(t.encounteredError||262144&t.flags||(t.encounteredError=!0))}if(48&h)return e.Debug.assert(!!(524288&n.flags)),V(n);if(4194304&n.flags){var T=n.type;t.approximateLength+=6;var S=c(T,t);return e.factory.createTypeOperatorNode(138,S)}if(134217728&n.flags){var x=n.texts,L=n.types,A=e.factory.createTemplateHead(x[0]),C=e.factory.createNodeArray(e.map(L,(function(n,r){return e.factory.createTemplateLiteralTypeSpan(c(n,t),(r<L.length-1?e.factory.createTemplateMiddle:e.factory.createTemplateTail)(x[r+1]))})));return t.approximateLength+=2,e.factory.createTemplateLiteralType(A,C)}if(268435456&n.flags){var N=c(n.type,t);return D(n.symbol,t,788968,[N])}if(8388608&n.flags){var k=c(n.objectType,t);S=c(n.indexType,t);return t.approximateLength+=2,e.factory.createIndexedAccessTypeNode(k,S)}if(16777216&n.flags){var R=c(n.checkType,t),O=t.inferTypeParameters;t.inferTypeParameters=n.root.inferTypeParameters;var M=c(n.extendsType,t);t.inferTypeParameters=O;var F=B(mm(n)),G=B(_m(n));return t.approximateLength+=15,e.factory.createConditionalTypeNode(R,M,F,G)}return 33554432&n.flags?c(n.baseType,t):e.Debug.fail("Should be unreachable.");function B(e){var n,r,a;return 1048576&e.flags?(null===(n=t.visitedTypes)||void 0===n?void 0:n.has(Up(e)))?(131072&t.flags||(t.encounteredError=!0,null===(a=null===(r=t.tracker)||void 0===r?void 0:r.reportCyclicStructureError)||void 0===a||a.call(r)),l(t)):j(e,(function(e){return c(e,t)})):c(e,t)}function U(n){e.Debug.assert(!!(524288&n.flags));var r,a=n.declaration.readonlyToken?e.factory.createToken(n.declaration.readonlyToken.kind):void 0,i=n.declaration.questionToken?e.factory.createToken(n.declaration.questionToken.kind):void 0;r=Sl(n)?e.factory.createTypeOperatorNode(138,c(xl(n),t)):c(vl(n),t);var o=g(hl(n),t,r),s=n.declaration.nameType?c(bl(n),t):void 0,l=c(El(n),t),u=e.factory.createMappedTypeNode(a,o,s,i,l);return t.approximateLength+=10,e.setEmitFlags(u,1)}function V(n){var r,a=n.id,i=n.symbol;if(i){var o=uo(n)?788968:111551;if(uL(i.valueDeclaration))return D(i,t,o);if(32&i.flags&&!Ls(i)&&!(i.valueDeclaration&&222===i.valueDeclaration.kind&&2048&t.flags)||896&i.flags||c())return D(i,t,o);if(null===(r=t.visitedTypes)||void 0===r?void 0:r.has(a)){var s=go(n);return s?D(s,t,788968):l(t)}return j(n,K)}return K(n);function c(){var n,r=!!(8192&i.flags)&&e.some(i.declarations,(function(n){return e.hasSyntacticModifier(n,32)})),o=!!(16&i.flags)&&(i.parent||e.forEach(i.declarations,(function(e){return 298===e.parent.kind||258===e.parent.kind})));if(r||o)return(!!(4096&t.flags)||(null===(n=t.visitedTypes)||void 0===n?void 0:n.has(a)))&&(!(8&t.flags)||qi(i,t.enclosingDeclaration))}}function j(n,r){var a,i=n.id,o=16&e.getObjectFlags(n)&&n.symbol&&32&n.symbol.flags,s=4&e.getObjectFlags(n)&&n.node?"N"+w(n.node):n.symbol?(o?"+":"")+P(n.symbol):void 0;if(t.visitedTypes||(t.visitedTypes=new e.Set),s&&!t.symbolDepth&&(t.symbolDepth=new e.Map),s){if(a=t.symbolDepth.get(s)||0,a>10)return l(t);t.symbolDepth.set(s,a+1)}t.visitedTypes.add(i);var c=r(n);return t.visitedTypes.delete(i),s&&t.symbolDepth.set(s,a),c}function K(n){if(Il(n)||n.containsError)return U(n);var r=Nl(n);if(!r.properties.length&&!r.stringIndexInfo&&!r.numberIndexInfo){if(!r.callSignatures.length&&!r.constructSignatures.length)return t.approximateLength+=2,e.setEmitFlags(e.factory.createTypeLiteralNode(void 0),1);if(1===r.callSignatures.length&&!r.constructSignatures.length){var a=r.callSignatures[0],i=_(a,175,t);return i}if(1===r.constructSignatures.length&&!r.callSignatures.length){a=r.constructSignatures[0],i=_(a,176,t);return i}}var o=e.filter(r.constructSignatures,(function(e){return!!(4&e.flags)}));if(e.some(o)){var s=e.map(o,ad),l=r.callSignatures.length+(r.constructSignatures.length-o.length)+(r.stringIndexInfo?1:0)+(r.numberIndexInfo?1:0)+(2048&t.flags?e.countWhere(r.properties,(function(e){return!(4194304&e.flags)})):e.length(r.properties));return l&&s.push(Ui(r)),c(pf(s),t)}var u=t.flags;t.flags|=4194304;var d=q(r);t.flags=u;var p=e.factory.createTypeLiteralNode(d);return t.approximateLength+=2,e.setEmitFlags(p,1024&t.flags?0:1),p}function H(n){var r=Td(n);if(n.target===xn||n.target===Ln){if(2&t.flags){var a=c(r[0],t);return e.factory.createTypeReferenceNode(n.target===xn?"Array":"ReadonlyArray",[a])}var i=c(r[0],t),o=e.factory.createArrayTypeNode(i);return n.target===xn?o:e.factory.createTypeOperatorNode(142,o)}if(!(8&n.target.objectFlags)){if(2048&t.flags&&n.symbol.valueDeclaration&&e.isClassLike(n.symbol.valueDeclaration)&&!qi(n.symbol,t.enclosingDeclaration))return V(n);var s=n.target.outerTypeParameters,l=(T=0,void 0);if(s){var u=s.length;while(T<u){var d=T,f=_d(s[T]);do{T++}while(T<u&&_d(s[T])===f);if(!e.rangeEquals(s,r,d,T)){var m=p(r.slice(d,T),t),_=t.flags;t.flags|=16;var g=D(f,t,788968,m);t.flags=_,l=l?W(l,g):g}}}var y=void 0;if(r.length>0){var h=(n.target.typeParameters||e.emptyArray).length;y=p(r.slice(T,h),t)}S=t.flags;t.flags|=16;var v=D(n.symbol,t,788968,y);return t.flags=S,l?W(l,v):v}if(r.length>0){var b=Sd(n),E=p(r.slice(0,b),t);if(E){if(n.target.labeledElementDeclarations)for(var T=0;T<E.length;T++){var S=n.target.elementFlags[T];E[T]=e.factory.createNamedTupleMember(12&S?e.factory.createToken(25):void 0,e.factory.createIdentifier(e.unescapeLeadingUnderscores(RL(n.target.labeledElementDeclarations[T]))),2&S?e.factory.createToken(57):void 0,4&S?e.factory.createArrayTypeNode(E[T]):E[T])}else for(var T=0;T<Math.min(b,E.length);T++){var S=n.target.elementFlags[T];E[T]=12&S?e.factory.createRestTypeNode(4&S?e.factory.createArrayTypeNode(E[T]):E[T]):2&S?e.factory.createOptionalTypeNode(E[T]):E[T]}var x=e.setEmitFlags(e.factory.createTupleTypeNode(E),1);return n.target.readonly?e.factory.createTypeOperatorNode(142,x):x}}if(t.encounteredError||524288&t.flags){x=e.setEmitFlags(e.factory.createTupleTypeNode([]),1);return n.target.readonly?e.factory.createTypeOperatorNode(142,x):x}t.encounteredError=!0}function W(n,t){if(e.isImportTypeNode(n)){var r=n.typeArguments,a=n.qualifier;a&&(a=e.isIdentifier(a)?e.factory.updateIdentifier(a,r):e.factory.updateQualifiedName(a,a.left,e.factory.updateIdentifier(a.right,r))),r=t.typeArguments;for(var i=z(t),o=0,s=i;o<s.length;o++){var c=s[o];a=a?e.factory.createQualifiedName(a,c):c}return e.factory.updateImportTypeNode(n,n.argument,a,r,n.isTypeOf)}r=n.typeArguments;var l=n.typeName;l=e.isIdentifier(l)?e.factory.updateIdentifier(l,r):e.factory.updateQualifiedName(l,l.left,e.factory.updateIdentifier(l.right,r)),r=t.typeArguments;i=z(t);for(var u=0,d=i;u<d.length;u++){c=d[u];l=e.factory.createQualifiedName(l,c)}return e.factory.updateTypeReferenceNode(n,l,r)}function z(n){var t=n.typeName,r=[];while(!e.isIdentifier(t))r.unshift(t.right),t=t.left;return r.unshift(t),r}function q(n){if(a(t))return[e.factory.createPropertySignature(void 0,"...",void 0,void 0)];for(var r=[],i=0,o=n.callSignatures;i<o.length;i++){var s=o[i];r.push(_(s,170,t))}for(var c=0,u=n.constructSignatures;c<u.length;c++){s=u[c];4&s.flags||r.push(_(s,171,t))}if(n.stringIndexInfo){var p=void 0;p=1024&n.objectFlags?m(ud(xe,n.stringIndexInfo.isReadonly,n.stringIndexInfo.declaration),0,t,l(t)):m(n.stringIndexInfo,0,t,void 0),r.push(p)}n.numberIndexInfo&&r.push(m(n.numberIndexInfo,1,t,void 0));var f=n.properties;if(!f)return r;for(var g=0,y=0,h=f;y<h.length;y++){var v=h[y];if(g++,2048&t.flags){if(4194304&v.flags)continue;24&e.getDeclarationModifierFlagsFromSymbol(v)&&t.tracker.reportPrivateInBaseOfClassExpression&&t.tracker.reportPrivateInBaseOfClassExpression(e.unescapeLeadingUnderscores(v.escapedName))}if(a(t)&&g+2<f.length-1){r.push(e.factory.createPropertySignature(void 0,"... "+(f.length-g)+" more ...",void 0,void 0)),d(f[f.length-1],t,r);break}d(v,t,r)}return r.length?r:void 0}}function l(n){return n.approximateLength+=3,1&n.flags?e.factory.createKeywordTypeNode(128):e.factory.createTypeReferenceNode(e.factory.createIdentifier("..."),void 0)}function u(n,t){var r;return!!(8192&e.getCheckFlags(n))&&(e.contains(t.reverseMappedStack,n)||(null===(r=t.reverseMappedStack)||void 0===r?void 0:r[0])&&!(16&e.getObjectFlags(e.last(t.reverseMappedStack).propertyType)))}function d(n,t,r){var a,i=!!(8192&e.getCheckFlags(n)),o=u(n,t)?xe:ws(n),s=t.enclosingDeclaration;if(t.enclosingDeclaration=void 0,t.tracker.trackSymbol&&4096&e.getCheckFlags(n)&&Ac(n.escapedName)){var c=e.first(n.declarations);if(n.declarations&&Cc(c))if(e.isBinaryExpression(c)){var d=e.getNameOfDeclaration(c);d&&e.isElementAccessExpression(d)&&e.isPropertyAccessEntityNameExpression(d.argumentExpression)&&v(d.argumentExpression,s,t)}else v(c.name.expression,s,t)}t.enclosingDeclaration=n.valueDeclaration||(null===(a=n.declarations)||void 0===a?void 0:a[0])||s;var p=M(n,t);t.enclosingDeclaration=s,t.approximateLength+=e.symbolName(n).length+1;var f=16777216&n.flags?e.factory.createToken(57):void 0;if(8208&n.flags&&!kl(o).length&&!gD(n))for(var m=yu(nb(o,(function(e){return!(32768&e.flags)})),0),g=0,y=m;g<y.length;g++){var h=y[g],b=_(h,165,t,{name:p,questionToken:f});r.push(x(b))}else{var E=void 0;u(n,t)?E=l(t):(i&&(t.reverseMappedStack||(t.reverseMappedStack=[]),t.reverseMappedStack.push(n)),E=o?K(t,o,n,s):e.factory.createKeywordTypeNode(128),i&&t.reverseMappedStack.pop());var T=gD(n)?[e.factory.createToken(142)]:void 0;T&&(t.approximateLength+=9);var S=e.factory.createPropertySignature(T,p,f,E);r.push(x(S))}function x(t){var r;if(e.some(n.declarations,(function(e){return 337===e.kind}))){var a=null===(r=n.declarations)||void 0===r?void 0:r.find((function(e){return 337===e.kind})),i=e.getTextOfJSDocComment(a.comment);i&&e.setSyntheticLeadingComments(t,[{kind:3,text:"*\n * "+i.replace(/\n/g,"\n * ")+"\n ",pos:-1,end:-1,hasTrailingNewLine:!0}])}else n.valueDeclaration&&e.setCommentRange(t,n.valueDeclaration);return t}}function p(n,t,r){if(e.some(n)){if(a(t)){if(!r)return[e.factory.createTypeReferenceNode("...",void 0)];if(n.length>2)return[c(n[0],t),e.factory.createTypeReferenceNode("... "+(n.length-2)+" more ...",void 0),c(n[n.length-1],t)]}for(var i=!(64&t.flags),o=i?e.createUnderscoreEscapedMultiMap():void 0,s=[],l=0,u=0,d=n;u<d.length;u++){var p=d[u];if(l++,a(t)&&l+2<n.length-1){s.push(e.factory.createTypeReferenceNode("... "+(n.length-l)+" more ...",void 0));var m=c(n[n.length-1],t);m&&s.push(m);break}t.approximateLength+=2;var _=c(p,t);_&&(s.push(_),o&&e.isIdentifierTypeReference(_)&&o.add(_.typeName.escapedText,[p,s.length-1]))}if(o){var g=t.flags;t.flags|=64,o.forEach((function(n){if(!e.arrayIsHomogeneous(n,(function(e,n){var t=e[0],r=n[0];return f(t,r)})))for(var r=0,a=n;r<a.length;r++){var i=a[r],o=i[0],l=i[1];s[l]=c(o,t)}})),t.flags=g}return s}}function f(e,n){return e===n||!!e.symbol&&e.symbol===n.symbol||!!e.aliasSymbol&&e.aliasSymbol===n.aliasSymbol}function m(n,t,r,a){var i=e.getNameFromIndexInfo(n)||"x",o=e.factory.createKeywordTypeNode(0===t?147:144),s=e.factory.createParameterDeclaration(void 0,void 0,void 0,i,void 0,o,void 0);return a||(a=c(n.type||xe,r)),n.type||2097152&r.flags||(r.encounteredError=!0),r.approximateLength+=i.length+4,e.factory.createIndexSignature(void 0,n.isReadonly?[e.factory.createToken(142)]:void 0,[s],a)}function _(n,t,r,a){var i,o,s,l,u,d,p=256&r.flags;p&&(r.flags&=-257),32&r.flags&&n.target&&n.mapper&&n.target.typeParameters?d=n.target.typeParameters.map((function(e){return c(A_(e,n.mapper),r)})):u=n.typeParameters&&n.typeParameters.map((function(e){return y(e,r)}));var f,m=zc(n,!0)[0],_=(e.some(m,(function(n){return n!==m[m.length-1]&&!!(32768&e.getCheckFlags(n))}))?n.parameters:m).map((function(e){return h(e,r,167===t,null===a||void 0===a?void 0:a.privateSymbolVisitor,null===a||void 0===a?void 0:a.bundledImports)}));if(n.thisParameter){var g=h(n.thisParameter,r);_.unshift(g)}var v=Vu(n);if(v){var b=2===v.kind||3===v.kind?e.factory.createToken(127):void 0,E=1===v.kind||3===v.kind?e.setEmitFlags(e.factory.createIdentifier(v.parameterName),16777216):e.factory.createThisTypeNode(),T=v.type&&c(v.type,r);f=e.factory.createTypePredicateNode(b,E,T)}else{var S=Hu(n);!S||p&&ko(S)?p||(f=e.factory.createKeywordTypeNode(128)):f=H(r,S,n,null===a||void 0===a?void 0:a.privateSymbolVisitor,null===a||void 0===a?void 0:a.bundledImports)}var x=null===a||void 0===a?void 0:a.modifiers;if(176===t&&4&n.flags){var L=e.modifiersToFlags(x);x=e.factory.createModifiersFromModifierFlags(128|L)}r.approximateLength+=3;var D=170===t?e.factory.createCallSignature(u,_,f):171===t?e.factory.createConstructSignature(u,_,f):165===t?e.factory.createMethodSignature(x,null!==(i=null===a||void 0===a?void 0:a.name)&&void 0!==i?i:e.factory.createIdentifier(""),null===a||void 0===a?void 0:a.questionToken,u,_,f):166===t?e.factory.createMethodDeclaration(void 0,x,void 0,null!==(o=null===a||void 0===a?void 0:a.name)&&void 0!==o?o:e.factory.createIdentifier(""),void 0,u,_,f,void 0):167===t?e.factory.createConstructorDeclaration(void 0,x,_,void 0):168===t?e.factory.createGetAccessorDeclaration(void 0,x,null!==(s=null===a||void 0===a?void 0:a.name)&&void 0!==s?s:e.factory.createIdentifier(""),_,f,void 0):169===t?e.factory.createSetAccessorDeclaration(void 0,x,null!==(l=null===a||void 0===a?void 0:a.name)&&void 0!==l?l:e.factory.createIdentifier(""),_,void 0):172===t?e.factory.createIndexSignature(void 0,x,_,f):309===t?e.factory.createJSDocFunctionType(_,f):175===t?e.factory.createFunctionTypeNode(u,_,null!==f&&void 0!==f?f:e.factory.createTypeReferenceNode(e.factory.createIdentifier(""))):176===t?e.factory.createConstructorTypeNode(x,u,_,null!==f&&void 0!==f?f:e.factory.createTypeReferenceNode(e.factory.createIdentifier(""))):252===t?e.factory.createFunctionDeclaration(void 0,x,void 0,(null===a||void 0===a?void 0:a.name)?e.cast(a.name,e.isIdentifier):e.factory.createIdentifier(""),u,_,f,void 0):209===t?e.factory.createFunctionExpression(x,void 0,(null===a||void 0===a?void 0:a.name)?e.cast(a.name,e.isIdentifier):e.factory.createIdentifier(""),u,_,f,e.factory.createBlock([])):210===t?e.factory.createArrowFunction(x,u,_,f,void 0,e.factory.createBlock([])):e.Debug.assertNever(t);return d&&(D.typeArguments=e.factory.createNodeArray(d)),D}function g(n,t,r){var a=t.flags;t.flags&=-513;var i=I(n,t),o=$l(n),s=o&&c(o,t);return t.flags=a,e.factory.createTypeParameterDeclaration(i,r,s)}function y(e,n,t){void 0===t&&(t=Gl(e));var r=t&&c(t,n);return g(e,n,r)}function h(n,t,r,a,i){var o=e.getDeclarationOfKind(n,161);o||e.isTransientSymbol(n)||(o=e.getDeclarationOfKind(n,330));var s=ws(n);o&&yR(o)&&(s=jy(s)),1073741824&t.flags&&o&&!e.isJSDocParameterTag(o)&&vR(o)&&(s=Lv(s,524288));var c=K(t,s,n,t.enclosingDeclaration,a,i),l=!(8192&t.flags)&&r&&o&&o.modifiers?o.modifiers.map(e.factory.cloneNode):void 0,u=o&&e.isRestParameter(o)||32768&e.getCheckFlags(n),d=u?e.factory.createToken(25):void 0,p=o&&o.name?78===o.name.kind?e.setEmitFlags(e.factory.cloneNode(o.name),16777216):158===o.name.kind?e.setEmitFlags(e.factory.cloneNode(o.name.right),16777216):g(o.name):e.symbolName(n),f=o&&Au(o)||16384&e.getCheckFlags(n),m=f?e.factory.createToken(57):void 0,_=e.factory.createParameterDeclaration(void 0,l,d,p,m,c,void 0);return t.approximateLength+=e.symbolName(n).length+3,_;function g(n){return r(n);function r(n){t.tracker.trackSymbol&&e.isComputedPropertyName(n)&&Dc(n)&&v(n.expression,t.enclosingDeclaration,t);var a=e.visitEachChild(n,r,e.nullTransformationContext,void 0,r);return e.isBindingElement(a)&&(a=e.factory.updateBindingElement(a,a.dotDotDotToken,a.propertyName,a.name,void 0)),e.nodeIsSynthesized(a)||(a=e.factory.cloneNode(a)),e.setEmitFlags(a,16777217)}}}function v(n,t,r){if(r.tracker.trackSymbol){var a=e.getFirstIdentifier(n),i=Vr(a,a.escapedText,1160127,void 0,void 0,!0);i&&r.tracker.trackSymbol(i,t,111551)}}function b(e,n,t,r){return n.tracker.trackSymbol(e,n.enclosingDeclaration,t),E(e,n,t,r)}function E(n,t,r,a){var i,o=262144&n.flags;return o||!(t.enclosingDeclaration||64&t.flags)||134217728&t.flags?i=[n]:(i=e.Debug.checkDefined(s(n,r,!0)),e.Debug.assert(i&&i.length>0)),i;function s(n,r,i){var o,c=Ki(n,t.enclosingDeclaration,r,!!(128&t.flags));if(!c||Hi(c[0],t.enclosingDeclaration,1===c.length?r:ji(r))){var l=bi(c?c[0]:n,t.enclosingDeclaration,r);if(e.length(l)){o=l.map((function(n){return e.some(n.declarations,eo)?L(n,t):void 0}));var u=l.map((function(e,n){return n}));u.sort(g);for(var d=u.map((function(e){return l[e]})),p=0,f=d;p<f.length;p++){var m=f[p],_=s(m,ji(r),!1);if(_){if(m.exports&&m.exports.get("export=")&&xi(m.exports.get("export="),n)){c=_;break}c=_.concat(c||[Si(m,n)||n]);break}}}}if(c)return c;if(i||!(6144&n.flags)){if(!i&&!a&&e.forEach(n.declarations,eo))return;return[n]}function g(n,t){var r=o[n],a=o[t];if(r&&a){var i=e.pathIsRelative(a);return e.pathIsRelative(r)===i?e.moduleSpecifiers.countPathComponents(r)-e.moduleSpecifiers.countPathComponents(a):i?-1:1}return 0}}}function T(n,t){var r,a=AN(n);return 524384&a.flags&&(r=e.factory.createNodeArray(e.map(Vs(n),(function(e){return y(e,t)})))),r}function S(n,t,r){var a;e.Debug.assert(n&&0<=t&&t<n.length);var i=n[t],o=P(i);if(!(null===(a=r.typeParameterSymbolList)||void 0===a?void 0:a.has(o))){var s;if((r.typeParameterSymbolList||(r.typeParameterSymbolList=new e.Set)).add(o),512&r.flags&&t<n.length-1){var c=i,l=n[t+1];if(1&e.getCheckFlags(l)){var u=js(2097152&c.flags?Fa(c):c);s=p(e.map(u,(function(e){return Zm(e,l.mapper)})),r)}else s=T(i,r)}return s}}function x(n){return e.isIndexedAccessTypeNode(n.objectType)?x(n.objectType):n}function L(n,t){var r,a=e.getDeclarationOfKind(n,298);if(!a){var i=e.firstDefined(n.declarations,(function(e){return Ti(e,n)}));i&&(a=e.getDeclarationOfKind(i,298))}if(a&&void 0!==a.moduleName)return a.moduleName;if(!a){if(t.tracker.trackReferencedAmbientModule){var c=e.filter(n.declarations,e.isAmbientModule);if(e.length(c))for(var l=0,u=c;l<u.length;l++){var d=u[l];t.tracker.trackReferencedAmbientModule(d,n)}}if(s.test(n.escapedName))return n.escapedName.substring(1,n.escapedName.length-1)}if(!t.enclosingDeclaration||!t.tracker.moduleResolverHost)return s.test(n.escapedName)?n.escapedName.substring(1,n.escapedName.length-1):e.getSourceFileOfNode(e.getNonAugmentationDeclaration(n)).fileName;var p=e.getSourceFileOfNode(e.getOriginalNode(t.enclosingDeclaration)),f=wr(n),m=f.specifierCache&&f.specifierCache.get(p.path);if(!m){var _=!!e.outFile(C),g=t.tracker.moduleResolverHost,y=_?o(o({},C),{baseUrl:g.getCommonSourceDirectory()}):C;m=e.first(e.moduleSpecifiers.getModuleSpecifiers(n,le,y,p,g,{importModuleSpecifierPreference:_?"non-relative":"project-relative",importModuleSpecifierEnding:_?"minimal":void 0})),null!==(r=f.specifierCache)&&void 0!==r||(f.specifierCache=new e.Map),f.specifierCache.set(p.path,m)}return m}function D(n,t,r,a){var i=b(n,t,r,!(16384&t.flags)),o=111551===r;if(e.some(i[0].declarations,eo)){var s=i.length>1?g(i,i.length-1,1):void 0,c=a||S(i,0,t),l=L(i[0],t);!(67108864&t.flags)&&e.getEmitModuleResolutionKind(C)===e.ModuleResolutionKind.NodeJs&&l.indexOf("/node_modules/")>=0&&(t.encounteredError=!0,t.tracker.reportLikelyUnsafeImportRequiredError&&t.tracker.reportLikelyUnsafeImportRequiredError(l));var u=e.factory.createLiteralTypeNode(e.factory.createStringLiteral(l));if(t.tracker.trackExternalModuleSymbolOfImportTypeNode&&t.tracker.trackExternalModuleSymbolOfImportTypeNode(i[0]),t.approximateLength+=l.length+10,!s||e.isEntityName(s)){if(s){var d=e.isIdentifier(s)?s:s.right;d.typeArguments=void 0}return e.factory.createImportTypeNode(u,s,c,o)}var p=x(s),f=p.objectType.typeName;return e.factory.createIndexedAccessTypeNode(e.factory.createImportTypeNode(u,f,c,o),p.indexType)}var m=g(i,i.length-1,0);if(e.isIndexedAccessTypeNode(m))return m;if(o)return e.factory.createTypeQueryNode(m);d=e.isIdentifier(m)?m:m.right;var _=d.typeArguments;return d.typeArguments=void 0,e.factory.createTypeReferenceNode(m,_);function g(n,r,i){var o,s=r===n.length-1?a:S(n,r,t),c=n[r],l=n[r-1];if(0===r)t.flags|=16777216,o=bo(c,t),t.approximateLength+=(o?o.length:0)+1,t.flags^=16777216;else if(l&&pi(l)){var u=pi(l);e.forEachEntry(u,(function(n,t){if(xi(n,c)&&!Ac(t)&&"export="!==t)return o=e.unescapeLeadingUnderscores(t),!0}))}if(o||(o=bo(c,t)),t.approximateLength+=o.length+1,!(16&t.flags)&&l&&Pc(l)&&Pc(l).get(c.escapedName)&&xi(Pc(l).get(c.escapedName),c)){var d=g(n,r-1,i);return e.isIndexedAccessTypeNode(d)?e.factory.createIndexedAccessTypeNode(d,e.factory.createLiteralTypeNode(e.factory.createStringLiteral(o))):e.factory.createIndexedAccessTypeNode(e.factory.createTypeReferenceNode(d,s),e.factory.createLiteralTypeNode(e.factory.createStringLiteral(o)))}var p=e.setEmitFlags(e.factory.createIdentifier(o,s),16777216);if(p.symbol=c,r>i){d=g(n,r-1,i);return e.isEntityName(d)?e.factory.createQualifiedName(d,p):e.Debug.fail("Impossible construct - an export of an indexed access cannot be reachable")}return p}}function A(e,n,t){var r=Vr(n.enclosingDeclaration,e,788968,void 0,e,!1);return!!r&&!(262144&r.flags&&r===t.symbol)}function I(n,t){var r;if(4&t.flags&&t.typeParameterNames){var a=t.typeParameterNames.get(Up(n));if(a)return a}var i=N(n.symbol,t,788968,!0);if(!(78&i.kind))return e.factory.createIdentifier("(Missing type parameter)");if(4&t.flags){var o=i.escapedText,s=0,c=o;while((null===(r=t.typeParameterNamesByText)||void 0===r?void 0:r.has(c))||A(c,t,n))s++,c=o+"_"+s;c!==o&&(i=e.factory.createIdentifier(c,i.typeArguments)),(t.typeParameterNames||(t.typeParameterNames=new e.Map)).set(Up(n),i),(t.typeParameterNamesByText||(t.typeParameterNamesByText=new e.Set)).add(i.escapedText)}return i}function N(n,t,r,a){var i=b(n,t,r);return!a||1===i.length||t.encounteredError||65536&t.flags||(t.encounteredError=!0),o(i,i.length-1);function o(n,r){var a=S(n,r,t),i=n[r];0===r&&(t.flags|=16777216);var s=bo(i,t);0===r&&(t.flags^=16777216);var c=e.setEmitFlags(e.factory.createIdentifier(s,a),16777216);return c.symbol=i,r>0?e.factory.createQualifiedName(o(n,r-1),c):c}}function k(n,t,r){var a=b(n,t,r);return i(a,a.length-1);function i(n,r){var a=S(n,r,t),o=n[r];0===r&&(t.flags|=16777216);var s=bo(o,t);0===r&&(t.flags^=16777216);var c=s.charCodeAt(0);if(e.isSingleOrDoubleQuote(c)&&e.some(o.declarations,eo))return e.factory.createStringLiteral(L(o,t));var l=35===c?s.length>1&&e.isIdentifierStart(s.charCodeAt(1),F):e.isIdentifierStart(c,F);if(0===r||l){var u=e.setEmitFlags(e.factory.createIdentifier(s,a),16777216);return u.symbol=o,r>0?e.factory.createPropertyAccessExpression(i(n,r-1),u):u}91===c&&(s=s.substring(1,s.length-1),c=s.charCodeAt(0));var d=void 0;return e.isSingleOrDoubleQuote(c)?d=e.factory.createStringLiteral(s.substring(1,s.length-1).replace(/\\./g,(function(e){return e.substring(1)})),39===c):""+ +s===s&&(d=e.factory.createNumericLiteral(+s)),d||(d=e.setEmitFlags(e.factory.createIdentifier(s,a),16777216),d.symbol=o),e.factory.createElementAccessExpression(i(n,r-1),d)}}function R(n){var t=e.getNameOfDeclaration(n);return!!t&&e.isStringLiteral(t)}function O(n){var t=e.getNameOfDeclaration(n);return!!(t&&e.isStringLiteral(t)&&(t.singleQuote||!e.nodeIsSynthesized(t)&&e.startsWith(e.getTextOfNode(t,!1),"'")))}function M(n,t){var r=!!e.length(n.declarations)&&e.every(n.declarations,O),a=G(n,t,r);if(a)return a;var i=e.unescapeLeadingUnderscores(n.escapedName),o=!!e.length(n.declarations)&&e.every(n.declarations,R);return B(i,o,r)}function G(n,t,r){var a=wr(n).nameType;if(a){if(384&a.flags){var i=""+a.value;return e.isIdentifierText(i,C.target)||bT(i)?bT(i)&&e.startsWith(i,"-")?e.factory.createComputedPropertyName(e.factory.createNumericLiteral(+i)):B(i):e.factory.createStringLiteral(i,!!r)}if(8192&a.flags)return e.factory.createComputedPropertyName(k(a.symbol,t,111551))}}function B(n,t,r){return e.isIdentifierText(n,C.target)?e.factory.createIdentifier(n):!t&&bT(n)&&+n>=0?e.factory.createNumericLiteral(+n):e.factory.createStringLiteral(n,!!r)}function U(n){var t=o({},n);return t.typeParameterNames&&(t.typeParameterNames=new e.Map(t.typeParameterNames)),t.typeParameterNamesByText&&(t.typeParameterNamesByText=new e.Set(t.typeParameterNamesByText)),t.typeParameterSymbolList&&(t.typeParameterSymbolList=new e.Set(t.typeParameterSymbolList)),t}function V(n,t){return n.declarations&&e.find(n.declarations,(function(n){return!!e.getEffectiveTypeAnnotationNode(n)&&(!t||!!e.findAncestor(n,(function(e){return e===t})))}))}function j(n,t){return!(4&e.getObjectFlags(t))||!e.isTypeReferenceNode(n)||e.length(n.typeArguments)>=ku(t.target.typeParameters)}function K(n,t,r,a,i,o){if(t!==Ae&&a){var s=V(r,a);if(s&&!e.isFunctionLikeDeclaration(s)&&!e.isGetAccessorDeclaration(s)){var l=e.getEffectiveTypeAnnotationNode(s);if(zm(l)===t&&j(l,t)){var u=z(n,l,i,o);if(u)return u}}}var d=n.flags;8192&t.flags&&t.symbol===r&&(!n.enclosingDeclaration||e.some(r.declarations,(function(t){return e.getSourceFileOfNode(t)===e.getSourceFileOfNode(n.enclosingDeclaration)})))&&(n.flags|=1048576);var p=c(t,n);return n.flags=d,p}function H(n,t,r,a,i){if(t!==Ae&&n.enclosingDeclaration){var o=r.declaration&&e.getEffectiveReturnTypeNode(r.declaration);if(e.findAncestor(o,(function(e){return e===n.enclosingDeclaration}))&&o){var s=zm(o),l=262144&s.flags&&s.isThisType?A_(s,r.mapper):s;if(l===t&&j(o,t)){var u=z(n,o,a,i);if(u)return u}}}return c(t,n)}function W(n,t,r){var a,i,o=!1,s=e.getFirstIdentifier(n);if(e.isInJSFile(n)&&(e.isExportsIdentifier(s)||e.isModuleExportsAccessExpression(s.parent)||e.isQualifiedName(s.parent)&&e.isModuleIdentifier(s.parent.left)&&e.isExportsIdentifier(s.parent.right)))return o=!0,{introducesError:o,node:n};var c=qa(s,67108863,!0,!0);if(c&&(0!==Yi(c,t.enclosingDeclaration,67108863,!1).accessibility?o=!0:(null===(i=null===(a=t.tracker)||void 0===a?void 0:a.trackSymbol)||void 0===i||i.call(a,c,t.enclosingDeclaration,67108863),null===r||void 0===r||r(c)),e.isIdentifier(n))){var l=262144&c.flags?I(mc(c),t):e.factory.cloneNode(n);return l.symbol=c,{introducesError:o,node:e.setEmitFlags(e.setOriginalNode(l,n),16777216)}}return{introducesError:o,node:n}}function z(t,a,i,o){r&&r.throwIfCancellationRequested&&r.throwIfCancellationRequested();var s=!1,l=e.getSourceFileOfNode(a),u=e.visitNode(a,d);if(!s)return u===a?e.setTextRange(e.factory.cloneNode(a),a):u;function d(r){if(e.isJSDocAllType(r)||311===r.kind)return e.factory.createKeywordTypeNode(128);if(e.isJSDocUnknownType(r))return e.factory.createKeywordTypeNode(152);if(e.isJSDocNullableType(r))return e.factory.createUnionTypeNode([e.visitNode(r.type,d),e.factory.createLiteralTypeNode(e.factory.createNull())]);if(e.isJSDocOptionalType(r))return e.factory.createUnionTypeNode([e.visitNode(r.type,d),e.factory.createKeywordTypeNode(150)]);if(e.isJSDocNonNullableType(r))return e.visitNode(r.type,d);if(e.isJSDocVariadicType(r))return e.factory.createArrayTypeNode(e.visitNode(r.type,d));if(e.isJSDocTypeLiteral(r))return e.factory.createTypeLiteralNode(e.map(r.jsDocPropertyTags,(function(n){var a=e.isIdentifier(n.name)?n.name:n.name.right,i=Io(zm(r),a.escapedText),o=i&&n.typeExpression&&zm(n.typeExpression.type)!==i?c(i,t):void 0;return e.factory.createPropertySignature(void 0,a,n.isBracketed||n.typeExpression&&e.isJSDocOptionalType(n.typeExpression.type)?e.factory.createToken(57):void 0,o||n.typeExpression&&e.visitNode(n.typeExpression.type,d)||e.factory.createKeywordTypeNode(128))})));if(e.isTypeReferenceNode(r)&&e.isIdentifier(r.typeName)&&""===r.typeName.escapedText)return e.setOriginalNode(e.factory.createKeywordTypeNode(128),r);if((e.isExpressionWithTypeArguments(r)||e.isTypeReferenceNode(r))&&e.isJSDocIndexSignature(r))return e.factory.createTypeLiteralNode([e.factory.createIndexSignature(void 0,void 0,[e.factory.createParameterDeclaration(void 0,void 0,void 0,"x",void 0,e.visitNode(r.typeArguments[0],d))],e.visitNode(r.typeArguments[1],d))]);var a;if(e.isJSDocFunctionType(r))return e.isJSDocConstructSignature(r)?e.factory.createConstructorTypeNode(r.modifiers,e.visitNodes(r.typeParameters,d),e.mapDefined(r.parameters,(function(n,t){return n.name&&e.isIdentifier(n.name)&&"new"===n.name.escapedText?void(a=n.type):e.factory.createParameterDeclaration(void 0,void 0,_(n),g(n,t),n.questionToken,e.visitNode(n.type,d),void 0)})),e.visitNode(a||r.type,d)||e.factory.createKeywordTypeNode(128)):e.factory.createFunctionTypeNode(e.visitNodes(r.typeParameters,d),e.map(r.parameters,(function(n,t){return e.factory.createParameterDeclaration(void 0,void 0,_(n),g(n,t),n.questionToken,e.visitNode(n.type,d),void 0)})),e.visitNode(r.type,d)||e.factory.createKeywordTypeNode(128));if(e.isTypeReferenceNode(r)&&e.isInJSDoc(r)&&(!j(r,zm(r))||Gd(r)||Te===Id(Cd(r),788968,!0)))return e.setOriginalNode(c(zm(r),t),r);if(e.isLiteralImportTypeNode(r)){var u=Pr(r).resolvedSymbol;return!e.isInJSDoc(r)||!u||(r.isTypeOf||788968&u.flags)&&e.length(r.typeArguments)>=ku(Vs(u))?e.factory.updateImportTypeNode(r,e.factory.updateLiteralTypeNode(r.argument,y(r,r.argument.literal)),r.qualifier,e.visitNodes(r.typeArguments,d,e.isTypeNode),r.isTypeOf):e.setOriginalNode(c(zm(r),t),r)}if(e.isEntityName(r)||e.isEntityNameExpression(r)){var p=W(r,t,i),f=p.introducesError,m=p.node;if(s=s||f,m!==r)return m}return l&&e.isTupleTypeNode(r)&&e.getLineAndCharacterOfPosition(l,r.pos).line===e.getLineAndCharacterOfPosition(l,r.end).line&&e.setEmitFlags(r,1),e.visitEachChild(r,d,e.nullTransformationContext);function _(n){return n.dotDotDotToken||(n.type&&e.isJSDocVariadicType(n.type)?e.factory.createToken(25):void 0)}function g(n,t){return n.name&&e.isIdentifier(n.name)&&"this"===n.name.escapedText?"this":_(n)?"args":"arg"+t}function y(r,a){if(o){if(t.tracker&&t.tracker.moduleResolverHost){var i=UR(r);if(i){var s=e.createGetCanonicalFileName(!!n.useCaseSensitiveFileNames),c={getCanonicalFileName:s,getCurrentDirectory:function(){return t.tracker.moduleResolverHost.getCurrentDirectory()},getCommonSourceDirectory:function(){return t.tracker.moduleResolverHost.getCommonSourceDirectory()}},l=e.getResolvedExternalModuleName(c,i);return e.factory.createStringLiteral(l)}}}else if(t.tracker&&t.tracker.trackExternalModuleSymbolOfImportTypeNode){var u=$a(a,a,void 0);u&&t.tracker.trackExternalModuleSymbolOfImportTypeNode(u)}return a}}}function q(n,t,r){var a=le(e.factory.createPropertyDeclaration,166,!0),s=le((function(n,t,r,a,i){return e.factory.createPropertySignature(t,r,a,i)}),165,!1),l=t.enclosingDeclaration,u=[],d=new e.Set,p=[],f=t;t=o(o({},f),{usedSymbolNames:new e.Set(f.usedSymbolNames),remappedSymbolNames:new e.Map,tracker:o(o({},f.tracker),{trackSymbol:function(e,n,r){var a=Yi(e,n,r,!1);if(0===a.accessibility){var i=E(e,t,r);4&e.flags||B(i[0])}else f.tracker&&f.tracker.trackSymbol&&f.tracker.trackSymbol(e,n,r)}})}),e.forEachEntry(n,(function(n,t){var r=e.unescapeLeadingUnderscores(t);he(n,r)}));var g=!r,h=n.get("export=");return h&&n.size>1&&2097152&h.flags&&(n=e.createSymbolTable(),n.set("export=",h)),O(n),D(u);function v(e){return!!e&&78===e.kind}function b(n){return e.isVariableStatement(n)?e.filter(e.map(n.declarationList.declarations,e.getNameOfDeclaration),v):e.filter([e.getNameOfDeclaration(n)],v)}function T(n){var t=e.find(n,e.isExportAssignment),r=e.findIndex(n,e.isModuleDeclaration),a=-1!==r?n[r]:void 0;if(a&&t&&t.isExportEquals&&e.isIdentifier(t.expression)&&e.isIdentifier(a.name)&&e.idText(a.name)===e.idText(t.expression)&&a.body&&e.isModuleBlock(a.body)){var o=e.filter(n,(function(n){return!!(1&e.getEffectiveModifierFlags(n))})),s=a.name,c=a.body;if(e.length(o)&&(a=e.factory.updateModuleDeclaration(a,a.decorators,a.modifiers,a.name,c=e.factory.updateModuleBlock(c,e.factory.createNodeArray(i(i([],a.body.statements),[e.factory.createExportDeclaration(void 0,void 0,!1,e.factory.createNamedExports(e.map(e.flatMap(o,(function(e){return b(e)})),(function(n){return e.factory.createExportSpecifier(void 0,n)}))),void 0)])))),n=i(i(i([],n.slice(0,r)),[a]),n.slice(r+1))),!e.find(n,(function(n){return n!==a&&e.nodeHasName(n,s)}))){u=[];var l=!e.some(c.statements,(function(n){return e.hasSyntacticModifier(n,1)||e.isExportAssignment(n)||e.isExportDeclaration(n)}));e.forEach(c.statements,(function(e){H(e,l?1:0)})),n=i(i([],e.filter(n,(function(e){return e!==a&&e!==t}))),u)}}return n}function S(n){var t=e.filter(n,(function(n){return e.isExportDeclaration(n)&&!n.moduleSpecifier&&!!n.exportClause&&e.isNamedExports(n.exportClause)}));if(e.length(t)>1){var r=e.filter(n,(function(n){return!e.isExportDeclaration(n)||!!n.moduleSpecifier||!n.exportClause}));n=i(i([],r),[e.factory.createExportDeclaration(void 0,void 0,!1,e.factory.createNamedExports(e.flatMap(t,(function(n){return e.cast(n.exportClause,e.isNamedExports).elements}))),void 0)])}var a=e.filter(n,(function(n){return e.isExportDeclaration(n)&&!!n.moduleSpecifier&&!!n.exportClause&&e.isNamedExports(n.exportClause)}));if(e.length(a)>1){var o=e.group(a,(function(n){return e.isStringLiteral(n.moduleSpecifier)?">"+n.moduleSpecifier.text:">"}));if(o.length!==a.length)for(var s=function(t){t.length>1&&(n=i(i([],e.filter(n,(function(e){return-1===t.indexOf(e)}))),[e.factory.createExportDeclaration(void 0,void 0,!1,e.factory.createNamedExports(e.flatMap(t,(function(n){return e.cast(n.exportClause,e.isNamedExports).elements}))),t[0].moduleSpecifier)]))},c=0,l=o;c<l.length;c++){var u=l[c];s(u)}}return n}function x(n){var t=e.findIndex(n,(function(n){return e.isExportDeclaration(n)&&!n.moduleSpecifier&&!!n.exportClause&&e.isNamedExports(n.exportClause)}));if(t>=0){var r=n[t],a=e.mapDefined(r.exportClause.elements,(function(t){if(!t.propertyName){var r=e.indicesOf(n),a=e.filter(r,(function(r){return e.nodeHasName(n[r],t.name)}));if(e.length(a)&&e.every(a,(function(e){return A(n[e])}))){for(var i=0,o=a;i<o.length;i++){var s=o[i];n[s]=I(n[s])}return}}return t}));e.length(a)?n[t]=e.factory.updateExportDeclaration(r,r.decorators,r.modifiers,r.isTypeOnly,e.factory.updateNamedExports(r.exportClause,a),r.moduleSpecifier):e.orderedRemoveItemAt(n,t)}return n}function D(n){return n=T(n),n=S(n),n=x(n),l&&(e.isSourceFile(l)&&e.isExternalOrCommonJsModule(l)||e.isModuleDeclaration(l))&&(!e.some(n,e.isExternalModuleIndicator)||!e.hasScopeMarker(n)&&e.some(n,e.needsScopeMarker))&&n.push(e.createEmptyExports(e.factory)),n}function A(n){return e.isEnumDeclaration(n)||e.isVariableStatement(n)||e.isFunctionDeclaration(n)||e.isClassDeclaration(n)||e.isModuleDeclaration(n)&&!e.isExternalModuleAugmentation(n)&&!e.isGlobalScopeAugmentation(n)||e.isInterfaceDeclaration(n)||Nk(n)}function I(n){var t=-3&(1|e.getEffectiveModifierFlags(n));return e.factory.updateModifiers(n,t)}function R(n){var t=-2&e.getEffectiveModifierFlags(n);return e.factory.updateModifiers(n,t)}function O(n,t,r){t||p.push(new e.Map),n.forEach((function(e){w(e,!1,!!r)})),t||(p[p.length-1].forEach((function(e){w(e,!0,!!r)})),p.pop())}function w(n,r,a){var i=gi(n);if(!d.has(P(i))){d.add(P(i));var o=!r;if(o||e.length(n.declarations)&&e.some(n.declarations,(function(n){return!!e.findAncestor(n,(function(e){return e===l}))}))){var s=t;t=U(t);var c=G(n,r,a);return t=s,c}}}function G(n,a,i){var o,s,c=e.unescapeLeadingUnderscores(n.escapedName),u="default"===n.escapedName;if(!a||131072&t.flags||!e.isStringANonContextualKeyword(c)||u){var d=u&&!!(-113&n.flags||16&n.flags&&e.length(wl(ws(n))))&&!(2097152&n.flags),p=!d&&!a&&e.isStringANonContextualKeyword(c)&&!u;(d||p)&&(a=!0);var f=(a?0:1)|(u&&!d?512:0),m=1536&n.flags&&7&n.flags&&"export="!==n.escapedName,_=m&&ce(ws(n),n);if((8208&n.flags||_)&&$(ws(n),n,he(n,c),f),524288&n.flags&&q(n,c,f),7&n.flags&&"export="!==n.escapedName&&!(4194304&n.flags)&&!(32&n.flags)&&!_)if(i){var g=se(n);g&&(p=!1,d=!1)}else{var y=ws(n),h=he(n,c);if(16&n.flags||!ce(y,n)){var v=2&n.flags?Fb(n)?2:1:void 0,b=!d&&4&n.flags?ge(h,n):h,E=n.declarations&&e.find(n.declarations,(function(n){return e.isVariableDeclaration(n)}));E&&e.isVariableDeclarationList(E.parent)&&1===E.parent.declarations.length&&(E=E.parent.parent);var T=null===(o=n.declarations)||void 0===o?void 0:o.find(e.isPropertyAccessExpression);if(T&&e.isBinaryExpression(T.parent)&&e.isIdentifier(T.parent.right)&&(null===(s=y.symbol)||void 0===s?void 0:s.valueDeclaration)&&e.isSourceFile(y.symbol.valueDeclaration)){var S=h===T.parent.right.escapedText?void 0:T.parent.right;H(e.factory.createExportDeclaration(void 0,void 0,!1,e.factory.createNamedExports([e.factory.createExportSpecifier(S,h)])),0),t.tracker.trackSymbol(y.symbol,t.enclosingDeclaration,111551)}else{var x=e.setTextRange(e.factory.createVariableStatement(void 0,e.factory.createVariableDeclarationList([e.factory.createVariableDeclaration(b,void 0,K(t,y,n,l,B,r))],v)),E);H(x,b!==h?-2&f:f),b===h||a||(H(e.factory.createExportDeclaration(void 0,void 0,!1,e.factory.createNamedExports([e.factory.createExportSpecifier(b,h)])),0),p=!1,d=!1)}}else $(y,n,h,f)}if(384&n.flags&&Z(n,c,f),32&n.flags&&(4&n.flags&&n.valueDeclaration&&e.isBinaryExpression(n.valueDeclaration.parent)&&e.isClassExpression(n.valueDeclaration.parent.right)?ie(n,he(n,c),f):ae(n,he(n,c),f)),(1536&n.flags&&(!m||Y(n))||_)&&Q(n,c,f),64&n.flags&&!(32&n.flags)&&J(n,c,f),2097152&n.flags&&ie(n,he(n,c),f),4&n.flags&&"export="===n.escapedName&&se(n),8388608&n.flags&&n.declarations)for(var D=0,A=n.declarations;D<A.length;D++){var C=A[D],I=Za(C,C.moduleSpecifier);I&&H(e.factory.createExportDeclaration(void 0,void 0,!1,void 0,e.factory.createStringLiteral(L(I,t))),0)}d?H(e.factory.createExportAssignment(void 0,void 0,!1,e.factory.createIdentifier(he(n,c))),0):p&&H(e.factory.createExportDeclaration(void 0,void 0,!1,e.factory.createNamedExports([e.factory.createExportSpecifier(he(n,c),c)])),0)}else t.encounteredError=!0}function B(n){if(!e.some(n.declarations,e.isParameterDeclaration)){e.Debug.assertIsDefined(p[p.length-1]),ge(e.unescapeLeadingUnderscores(n.escapedName),n);var t=!!(2097152&n.flags)&&!e.some(n.declarations,(function(n){return!!e.findAncestor(n,e.isExportDeclaration)||e.isNamespaceExport(n)||e.isImportEqualsDeclaration(n)&&!e.isExternalModuleReference(n.moduleReference)}));p[t?0:p.length-1].set(P(n),n)}}function j(n){return e.isSourceFile(n)&&(e.isExternalOrCommonJsModule(n)||e.isJsonSourceFile(n))||e.isAmbientModule(n)&&!e.isGlobalScopeAugmentation(n)}function H(n,r){if(e.canHaveModifiers(n)){var a=0,i=t.enclosingDeclaration&&(e.isJSDocTypeAlias(t.enclosingDeclaration)?e.getSourceFileOfNode(t.enclosingDeclaration):t.enclosingDeclaration);1&r&&i&&(j(i)||e.isModuleDeclaration(i))&&A(n)&&(a|=1),!g||1&a||i&&8388608&i.flags||!(e.isEnumDeclaration(n)||e.isVariableStatement(n)||e.isFunctionDeclaration(n)||e.isClassDeclaration(n)||e.isModuleDeclaration(n))||(a|=2),512&r&&(e.isClassDeclaration(n)||e.isInterfaceDeclaration(n)||e.isFunctionDeclaration(n))&&(a|=512),a&&(n=e.factory.updateModifiers(n,a|e.getEffectiveModifierFlags(n)))}u.push(n)}function q(n,a,i){var o,s=ic(n),l=wr(n).typeParameters,u=e.map(l,(function(e){return y(e,t)})),d=null===(o=n.declarations)||void 0===o?void 0:o.find(e.isJSDocTypeAlias),p=e.getTextOfJSDocComment(d?d.comment||d.parent.comment:void 0),f=t.flags;t.flags|=8388608;var m=t.enclosingDeclaration;t.enclosingDeclaration=d;var _=d&&d.typeExpression&&e.isJSDocTypeExpression(d.typeExpression)&&z(t,d.typeExpression.type,B,r)||c(s,t);H(e.setSyntheticLeadingComments(e.factory.createTypeAliasDeclaration(void 0,void 0,he(n,a),u,_),p?[{kind:3,text:"*\n * "+p.replace(/\n/g,"\n * ")+"\n ",pos:-1,end:-1,hasTrailingNewLine:!0}]:[]),i),t.flags=f,t.enclosingDeclaration=m}function J(n,r,a){var o=ac(n),s=Vs(n),c=e.map(s,(function(e){return y(e,t)})),l=Qs(o),u=e.length(l)?pf(l):void 0,d=e.flatMap(wl(o),(function(e){return ue(e,u)})),p=de(0,o,u,170),f=de(1,o,u,171),m=pe(o,u),_=e.length(l)?[e.factory.createHeritageClause(93,e.mapDefined(l,(function(e){return me(e,111551)})))]:void 0;H(e.factory.createInterfaceDeclaration(void 0,void 0,he(n,r),c,_,i(i(i(i([],m),f),p),d)),a)}function X(n){return n.exports?e.filter(e.arrayFrom(n.exports.values()),te):[]}function Y(n){return e.every(X(n),(function(e){return!(111551&Ma(e).flags)}))}function Q(n,r,a){var i=X(n),o=e.arrayToMultiMap(i,(function(e){return e.parent&&e.parent===n?"real":"merged"})),s=o.get("real")||e.emptyArray,c=o.get("merged")||e.emptyArray;if(e.length(s)){var l=he(n,r);ne(s,l,a,!!(67108880&n.flags))}if(e.length(c)){var u=e.getSourceFileOfNode(t.enclosingDeclaration),d=(l=he(n,r),e.factory.createModuleBlock([e.factory.createExportDeclaration(void 0,void 0,!1,e.factory.createNamedExports(e.mapDefined(e.filter(c,(function(e){return"export="!==e.escapedName})),(function(r){var a,i,o=e.unescapeLeadingUnderscores(r.escapedName),s=he(r,o),c=r.declarations&&ca(r);if(!u||(c?u===e.getSourceFileOfNode(c):e.some(r.declarations,(function(n){return e.getSourceFileOfNode(n)===u})))){var l=c&&wa(c,!0);B(l||r);var d=l?he(l,e.unescapeLeadingUnderscores(l.escapedName)):s;return e.factory.createExportSpecifier(o===d?void 0:d,o)}null===(i=null===(a=t.tracker)||void 0===a?void 0:a.reportNonlocalAugmentation)||void 0===i||i.call(a,u,n,r)}))))]));H(e.factory.createModuleDeclaration(void 0,void 0,e.factory.createIdentifier(l),d,16),0)}}function Z(n,t,r){H(e.factory.createEnumDeclaration(void 0,e.factory.createModifiersFromModifierFlags(kD(n)?2048:0),he(n,t),e.map(e.filter(wl(ws(n)),(function(e){return!!(8&e.flags)})),(function(n){var t=n.declarations&&n.declarations[0]&&e.isEnumMember(n.declarations[0])?LR(n.declarations[0]):void 0;return e.factory.createEnumMember(e.unescapeLeadingUnderscores(n.escapedName),void 0===t?void 0:"string"===typeof t?e.factory.createStringLiteral(t):e.factory.createNumericLiteral(t))}))),r)}function $(n,a,i,o){for(var s=yu(n,0),c=0,l=s;c<l.length;c++){var u=l[c],d=_(u,252,t,{name:e.factory.createIdentifier(i),privateSymbolVisitor:B,bundledImports:r});H(e.setTextRange(d,ee(u)),o)}if(!(1536&a.flags&&a.exports&&a.exports.size)){var p=e.filter(wl(n),te);ne(p,i,o,!0)}}function ee(n){if(n.declaration&&n.declaration.parent){if(e.isBinaryExpression(n.declaration.parent)&&5===e.getAssignmentDeclarationKind(n.declaration.parent))return n.declaration.parent;if(e.isVariableDeclaration(n.declaration.parent)&&n.declaration.parent.parent)return n.declaration.parent.parent}return n.declaration}function ne(n,r,a,i){if(e.length(n)){var s=e.arrayToMultiMap(n,(function(n){return!e.length(n.declarations)||e.some(n.declarations,(function(n){return e.getSourceFileOfNode(n)===e.getSourceFileOfNode(t.enclosingDeclaration)}))?"local":"remote"})),c=s.get("local")||e.emptyArray,d=e.parseNodeFactory.createModuleDeclaration(void 0,void 0,e.factory.createIdentifier(r),e.factory.createModuleBlock([]),16);e.setParent(d,l),d.locals=e.createSymbolTable(n),d.symbol=n[0].parent;var p=u;u=[];var f=g;g=!1;var m=o(o({},t),{enclosingDeclaration:d}),_=t;t=m,O(e.createSymbolTable(c),i,!0),t=_,g=f;var y=u;u=p;var h=e.map(y,(function(n){return e.isExportAssignment(n)&&!n.isExportEquals&&e.isIdentifier(n.expression)?e.factory.createExportDeclaration(void 0,void 0,!1,e.factory.createNamedExports([e.factory.createExportSpecifier(n.expression,e.factory.createIdentifier("default"))])):n})),v=e.every(h,(function(n){return e.hasSyntacticModifier(n,1)}))?e.map(h,R):h;d=e.factory.updateModuleDeclaration(d,d.decorators,d.modifiers,d.name,e.factory.createModuleBlock(v)),H(d,a)}}function te(n){return!!(2887656&n.flags)||!(4194304&n.flags||"prototype"===n.escapedName||n.valueDeclaration&&32&e.getEffectiveModifierFlags(n.valueDeclaration)&&e.isClassLike(n.valueDeclaration.parent))}function re(n){var a=e.mapDefined(n,(function(n){var a,i=t.enclosingDeclaration;t.enclosingDeclaration=n;var o=n.expression;if(e.isEntityNameExpression(o)){if(e.isIdentifier(o)&&""===e.idText(o))return l(void 0);var s=void 0;if(a=W(o,t,B),s=a.introducesError,o=a.node,s)return l(void 0)}return l(e.factory.createExpressionWithTypeArguments(o,e.map(n.typeArguments,(function(e){return z(t,e,B,r)||c(zm(e),t)}))));function l(e){return t.enclosingDeclaration=i,e}}));if(a.length===n.length)return a}function ae(n,r,o){var s,c,l=null===(s=n.declarations)||void 0===s?void 0:s.find(e.isClassLike),u=t.enclosingDeclaration;t.enclosingDeclaration=l||u;var d=Vs(n),p=e.map(d,(function(e){return y(e,t)})),f=ac(n),m=Qs(f),_=l&&e.getEffectiveImplementsTypeNodes(l),g=_&&re(_)||e.mapDefined(Xs(f),_e),h=ws(n),v=!!(null===(c=h.symbol)||void 0===c?void 0:c.valueDeclaration)&&e.isClassLike(h.symbol.valueDeclaration),b=v?Js(h):xe,E=i(i([],e.length(m)?[e.factory.createHeritageClause(93,e.map(m,(function(e){return fe(e,b,r)})))]:[]),e.length(g)?[e.factory.createHeritageClause(116,g)]:[]),T=NN(f,m,wl(f)),S=e.filter(T,(function(n){var t=n.valueDeclaration;return!!t&&!(e.isNamedDeclaration(t)&&e.isPrivateIdentifier(t.name))})),x=e.some(T,(function(n){var t=n.valueDeclaration;return!!t&&e.isNamedDeclaration(t)&&e.isPrivateIdentifier(t.name)})),L=x?[e.factory.createPropertyDeclaration(void 0,void 0,e.factory.createPrivateIdentifier("#private"),void 0,void 0,void 0)]:e.emptyArray,D=e.flatMap(S,(function(e){return a(e,!1,m[0])})),A=e.flatMap(e.filter(wl(h),(function(e){return!(4194304&e.flags)&&"prototype"!==e.escapedName&&!te(e)})),(function(e){return a(e,!0,b)})),C=!v&&!!n.valueDeclaration&&e.isInJSFile(n.valueDeclaration)&&!e.some(yu(h,1)),I=C?[e.factory.createConstructorDeclaration(void 0,e.factory.createModifiersFromModifierFlags(8),[],void 0)]:de(1,h,b,167),N=pe(f,m[0]);t.enclosingDeclaration=u,H(e.setTextRange(e.factory.createClassDeclaration(void 0,void 0,r,p,E,i(i(i(i(i([],N),A),I),D),L)),n.declarations&&e.filter(n.declarations,(function(n){return e.isClassDeclaration(n)||e.isClassExpression(n)}))[0]),o)}function ie(n,r,a){var i,o,s,c,l,u=ca(n);if(!u)return e.Debug.fail();var d=gi(wa(u,!0));if(d){var p=e.unescapeLeadingUnderscores(d.escapedName);"export="===p&&(C.esModuleInterop||C.allowSyntheticDefaultImports)&&(p="default");var f=he(d,p);switch(B(d),u.kind){case 199:if(250===(null===(o=null===(i=u.parent)||void 0===i?void 0:i.parent)||void 0===o?void 0:o.kind)){var m=L(d.parent||d,t),_=u.propertyName;H(e.factory.createImportDeclaration(void 0,void 0,e.factory.createImportClause(!1,void 0,e.factory.createNamedImports([e.factory.createImportSpecifier(_&&e.isIdentifier(_)?e.factory.createIdentifier(e.idText(_)):void 0,e.factory.createIdentifier(r))])),e.factory.createStringLiteral(m)),0);break}e.Debug.failBadSyntaxKind((null===(s=u.parent)||void 0===s?void 0:s.parent)||u,"Unhandled binding element grandparent kind in declaration serialization");break;case 290:217===(null===(l=null===(c=u.parent)||void 0===c?void 0:c.parent)||void 0===l?void 0:l.kind)&&oe(e.unescapeLeadingUnderscores(n.escapedName),f);break;case 250:if(e.isPropertyAccessExpression(u.initializer)){var g=u.initializer,y=e.factory.createUniqueName(r),h=L(d.parent||d,t);H(e.factory.createImportEqualsDeclaration(void 0,void 0,!1,y,e.factory.createExternalModuleReference(e.factory.createStringLiteral(h))),0),H(e.factory.createImportEqualsDeclaration(void 0,void 0,!1,e.factory.createIdentifier(r),e.factory.createQualifiedName(y,g.name)),a);break}case 261:if("export="===d.escapedName&&e.some(d.declarations,e.isJsonSourceFile)){se(n);break}var v=!(512&d.flags)&&!e.isVariableDeclaration(u);H(e.factory.createImportEqualsDeclaration(void 0,void 0,!1,e.factory.createIdentifier(r),v?N(d,t,67108863,!1):e.factory.createExternalModuleReference(e.factory.createStringLiteral(L(d,t)))),v?a:0);break;case 260:H(e.factory.createNamespaceExportDeclaration(e.idText(u.name)),0);break;case 263:H(e.factory.createImportDeclaration(void 0,void 0,e.factory.createImportClause(!1,e.factory.createIdentifier(r),void 0),e.factory.createStringLiteral(L(d.parent||d,t))),0);break;case 264:H(e.factory.createImportDeclaration(void 0,void 0,e.factory.createImportClause(!1,void 0,e.factory.createNamespaceImport(e.factory.createIdentifier(r))),e.factory.createStringLiteral(L(d,t))),0);break;case 270:H(e.factory.createExportDeclaration(void 0,void 0,!1,e.factory.createNamespaceExport(e.factory.createIdentifier(r)),e.factory.createStringLiteral(L(d,t))),0);break;case 266:H(e.factory.createImportDeclaration(void 0,void 0,e.factory.createImportClause(!1,void 0,e.factory.createNamedImports([e.factory.createImportSpecifier(r!==p?e.factory.createIdentifier(p):void 0,e.factory.createIdentifier(r))])),e.factory.createStringLiteral(L(d.parent||d,t))),0);break;case 271:var b=u.parent.parent.moduleSpecifier;oe(e.unescapeLeadingUnderscores(n.escapedName),b?p:f,b&&e.isStringLiteralLike(b)?e.factory.createStringLiteral(b.text):void 0);break;case 267:se(n);break;case 217:case 202:case 203:"default"===n.escapedName||"export="===n.escapedName?se(n):oe(r,f);break;default:return e.Debug.failBadSyntaxKind(u,"Unhandled alias declaration kind in symbol serializer!")}}}function oe(n,t,r){H(e.factory.createExportDeclaration(void 0,void 0,!1,e.factory.createNamedExports([e.factory.createExportSpecifier(n!==t?t:void 0,n)]),r),0)}function se(n){if(4194304&n.flags)return!1;var a=e.unescapeLeadingUnderscores(n.escapedName),i="export="===a,o="default"===a,s=i||o,c=n.declarations&&ca(n),d=c&&wa(c,!0);if(d&&e.length(d.declarations)&&e.some(d.declarations,(function(n){return e.getSourceFileOfNode(n)===e.getSourceFileOfNode(l)}))){var p=c&&(e.isExportAssignment(c)||e.isBinaryExpression(c)?e.getExportAssignmentExpression(c):e.getPropertyAssignmentAliasLikeExpression(c)),f=p&&e.isEntityNameExpression(p)?qN(p):void 0,m=f&&qa(f,67108863,!0,!0,l);(m||d)&&B(m||d);var _=t.tracker.trackSymbol;if(t.tracker.trackSymbol=e.noop,s)u.push(e.factory.createExportAssignment(void 0,void 0,i,k(d,t,67108863)));else if(f===p&&f)oe(a,e.idText(f));else if(p&&e.isClassExpression(p))oe(a,he(d,e.symbolName(d)));else{var g=ge(a,n);H(e.factory.createImportEqualsDeclaration(void 0,void 0,!1,e.factory.createIdentifier(g),N(d,t,67108863,!1)),0),oe(a,g)}return t.tracker.trackSymbol=_,!0}g=ge(a,n);var y=sh(ws(gi(n)));if(ce(y,n))$(y,n,g,s?0:1);else{var h=e.factory.createVariableStatement(void 0,e.factory.createVariableDeclarationList([e.factory.createVariableDeclaration(g,void 0,K(t,y,n,l,B,r))],2));H(h,d&&4&d.flags&&"export="===d.escapedName?2:a===g?1:0)}return s?(u.push(e.factory.createExportAssignment(void 0,void 0,i,e.factory.createIdentifier(g))),!0):a!==g&&(oe(a,g),!0)}function ce(n,r){var a=e.getSourceFileOfNode(t.enclosingDeclaration);return 48&e.getObjectFlags(n)&&!bu(n,0)&&!bu(n,1)&&!uo(n)&&!(!e.length(e.filter(wl(n),te))&&!e.length(yu(n,0)))&&!e.length(yu(n,1))&&!V(r,l)&&!(n.symbol&&e.some(n.symbol.declarations,(function(n){return e.getSourceFileOfNode(n)!==a})))&&!e.some(wl(n),(function(e){return Ac(e.escapedName)}))&&!e.some(wl(n),(function(n){return e.some(n.declarations,(function(n){return e.getSourceFileOfNode(n)!==a}))}))&&e.every(wl(n),(function(n){return e.isIdentifierText(e.symbolName(n),F)}))}function le(n,a,i){return function(o,s,c){var u,d,p,f,m,g=e.getDeclarationModifierFlagsFromSymbol(o),y=!!(8&g);if(s&&2887656&o.flags)return[];if(4194304&o.flags||c&&_u(c,o.escapedName)&&gD(_u(c,o.escapedName))===gD(o)&&(16777216&o.flags)===(16777216&_u(c,o.escapedName).flags)&&U_(ws(o),Io(c,o.escapedName)))return[];var h=-257&g|(s?32:0),v=M(o,t),b=null===(u=o.declarations)||void 0===u?void 0:u.find(e.or(e.isPropertyDeclaration,e.isAccessor,e.isVariableDeclaration,e.isPropertySignature,e.isBinaryExpression,e.isPropertyAccessExpression));if(98304&o.flags&&i){var E=[];if(65536&o.flags&&E.push(e.setTextRange(e.factory.createSetAccessorDeclaration(void 0,e.factory.createModifiersFromModifierFlags(h),v,[e.factory.createParameterDeclaration(void 0,void 0,void 0,"arg",void 0,y?void 0:K(t,ws(o),o,l,B,r))],void 0),(null===(d=o.declarations)||void 0===d?void 0:d.find(e.isSetAccessor))||b)),32768&o.flags){var T=8&g;E.push(e.setTextRange(e.factory.createGetAccessorDeclaration(void 0,e.factory.createModifiersFromModifierFlags(h),v,[],T?void 0:K(t,ws(o),o,l,B,r),void 0),(null===(p=o.declarations)||void 0===p?void 0:p.find(e.isGetAccessor))||b))}return E}if(98311&o.flags)return e.setTextRange(n(void 0,e.factory.createModifiersFromModifierFlags((gD(o)?64:0)|h),v,16777216&o.flags?e.factory.createToken(57):void 0,y?void 0:K(t,ws(o),o,l,B,r),void 0),(null===(f=o.declarations)||void 0===f?void 0:f.find(e.or(e.isPropertyDeclaration,e.isVariableDeclaration)))||b);if(8208&o.flags){var S=ws(o),x=yu(S,0);if(8&h)return e.setTextRange(n(void 0,e.factory.createModifiersFromModifierFlags((gD(o)?64:0)|h),v,16777216&o.flags?e.factory.createToken(57):void 0,void 0,void 0),(null===(m=o.declarations)||void 0===m?void 0:m.find(e.isFunctionLikeDeclaration))||x[0]&&x[0].declaration||o.declarations&&o.declarations[0]);for(var L=[],D=0,A=x;D<A.length;D++){var C=A[D],I=_(C,a,t,{name:v,questionToken:16777216&o.flags?e.factory.createToken(57):void 0,modifiers:h?e.factory.createModifiersFromModifierFlags(h):void 0}),N=C.declaration&&e.isPrototypePropertyAssignment(C.declaration.parent)?C.declaration.parent:C.declaration;L.push(e.setTextRange(I,N))}return L}return e.Debug.fail("Unhandled class member kind! "+(o.__debugFlags||o.flags))}}function ue(e,n){return s(e,!1,n)}function de(n,r,a,i){var o=yu(r,n);if(1===n){if(!a&&e.every(o,(function(n){return 0===e.length(n.parameters)})))return[];if(a){var s=yu(a,1);if(!e.length(s)&&e.every(o,(function(n){return 0===e.length(n.parameters)})))return[];if(s.length===o.length){for(var c=!1,l=0;l<s.length;l++)if(!ny(o[l],s[l],!1,!1,!0,V_)){c=!0;break}if(!c)return[]}}for(var u=0,d=0,p=o;d<p.length;d++){var f=p[d];f.declaration&&(u|=e.getSelectedEffectiveModifierFlags(f.declaration,24))}if(u)return[e.setTextRange(e.factory.createConstructorDeclaration(void 0,e.factory.createModifiersFromModifierFlags(u),[],void 0),o[0].declaration)]}for(var m=[],g=0,y=o;g<y.length;g++){var h=y[g],v=_(h,i,t);m.push(e.setTextRange(v,h.declaration))}return m}function pe(e,n){for(var r=[],a=0,i=[0,1];a<i.length;a++){var o=i[a],s=bu(e,o);if(s){if(n){var c=bu(n,o);if(c&&U_(s.type,c.type))continue}r.push(m(s,o,t,void 0))}}return r}function fe(n,r,a){var i=me(n,111551);if(i)return i;var o=ge(a+"_base"),s=e.factory.createVariableStatement(void 0,e.factory.createVariableDeclarationList([e.factory.createVariableDeclaration(o,void 0,c(r,t))],2));return H(s,0),e.factory.createExpressionWithTypeArguments(e.factory.createIdentifier(o),void 0)}function me(n,r){var a,i;if(n.target&&Ji(n.target.symbol,l,r)?(a=e.map(Td(n),(function(e){return c(e,t)})),i=k(n.target.symbol,t,788968)):n.symbol&&Ji(n.symbol,l,r)&&(i=k(n.symbol,t,788968)),i)return e.factory.createExpressionWithTypeArguments(i,a)}function _e(n){var r=me(n,788968);return r||(n.symbol?e.factory.createExpressionWithTypeArguments(k(n.symbol,t,788968),void 0):void 0)}function ge(e,n){var r,a,i=n?P(n):void 0;if(i&&t.remappedSymbolNames.has(i))return t.remappedSymbolNames.get(i);n&&(e=ye(n,e));var o=0,s=e;while(null===(r=t.usedSymbolNames)||void 0===r?void 0:r.has(e))o++,e=s+"_"+o;return null===(a=t.usedSymbolNames)||void 0===a||a.add(e),i&&t.remappedSymbolNames.set(i,e),e}function ye(n,r){if("default"===r||"__class"===r||"__function"===r){var a=t.flags;t.flags|=16777216;var i=bo(n,t);t.flags=a,r=i.length>0&&e.isSingleOrDoubleQuote(i.charCodeAt(0))?e.stripQuotes(i):i}return"default"===r?r="_default":"export="===r&&(r="_exports"),r=e.isIdentifierText(r,F)&&!e.isStringANonContextualKeyword(r)?r:"_"+r.replace(/[^a-zA-Z0-9]/g,"_"),r}function he(e,n){var r=P(e);return t.remappedSymbolNames.has(r)?t.remappedSymbolNames.get(r):(n=ye(e,n),t.remappedSymbolNames.set(r,n),n)}}}function fo(n,t,r,a){return void 0===r&&(r=16384),a?i(a).getText():e.usingSingleLineStringWriter(i);function i(a){var i=e.factory.createTypePredicateNode(2===n.kind||3===n.kind?e.factory.createToken(127):void 0,1===n.kind||3===n.kind?e.factory.createIdentifier(n.parameterName):e.factory.createThisTypeNode(),n.type&&te.typeToTypeNode(n.type,t,70222336|lo(r))),o=e.createPrinter({removeComments:!0}),s=t&&e.getSourceFileOfNode(t);return o.writeNode(4,i,s,a),a}}function mo(e){for(var n=[],t=0,r=0;r<e.length;r++){var a=e[r];if(t|=a.flags,!(98304&a.flags)){if(1536&a.flags){var i=512&a.flags?Ke:lc(a);if(1048576&i.flags){var o=i.types.length;if(r+o<=e.length&&Pm(e[r+o-1])===Pm(i.types[o-1])){n.push(i),r+=o-1;continue}}}n.push(a)}}return 65536&t&&n.push(we),32768&t&&n.push(ke),n||e}function _o(e){return 8===e?"private":16===e?"protected":"public"}function go(n){if(n.symbol&&2048&n.symbol.flags&&n.symbol.declarations){var t=e.walkUpParenthesizedTypes(n.symbol.declarations[0].parent);if(255===t.kind)return yi(t)}}function yo(n){return n&&n.parent&&258===n.parent.kind&&e.isExternalModuleAugmentation(n.parent.parent)}function ho(n){return 298===n.kind||e.isAmbientModule(n)}function vo(n,t){var r=wr(n).nameType;if(r){if(384&r.flags){var a=""+r.value;return e.isIdentifierText(a,C.target)||bT(a)?bT(a)&&e.startsWith(a,"-")?"["+a+"]":a:'"'+e.escapeString(a,34)+'"'}if(8192&r.flags)return"["+bo(r.symbol,t)+"]"}}function bo(n,t){if(t&&"default"===n.escapedName&&!(16384&t.flags)&&(!(16777216&t.flags)||!n.declarations||t.enclosingDeclaration&&e.findAncestor(n.declarations[0],ho)!==e.findAncestor(t.enclosingDeclaration,ho)))return"default";if(n.declarations&&n.declarations.length){var r=e.firstDefined(n.declarations,(function(n){return e.getNameOfDeclaration(n)?n:void 0})),a=r&&e.getNameOfDeclaration(r);if(r&&a){if(e.isCallExpression(r)&&e.isBindableObjectDefinePropertyCall(r))return e.symbolName(n);if(e.isComputedPropertyName(a)&&!(4096&e.getCheckFlags(n))){var i=wr(n).nameType;if(i&&384&i.flags){var o=vo(n,t);if(void 0!==o)return o}}return e.declarationNameToString(a)}if(r||(r=n.declarations[0]),r.parent&&250===r.parent.kind)return e.declarationNameToString(r.parent.name);switch(r.kind){case 222:case 209:case 210:return!t||t.encounteredError||131072&t.flags||(t.encounteredError=!0),222===r.kind?"(Anonymous class)":"(Anonymous function)"}}var s=vo(n,t);return void 0!==s?s:e.symbolName(n)}function Eo(n){if(n){var t=Pr(n);return void 0===t.isVisible&&(t.isVisible=!!r()),t.isVisible}return!1;function r(){switch(n.kind){case 328:case 335:case 329:return!!(n.parent&&n.parent.parent&&n.parent.parent.parent&&e.isSourceFile(n.parent.parent.parent));case 199:return Eo(n.parent.parent);case 250:if(e.isBindingPattern(n.name)&&!n.name.elements.length)return!1;case 257:case 253:case 254:case 255:case 252:case 256:case 261:if(e.isExternalModuleAugmentation(n))return!0;var t=Ao(n);return 1&e.getCombinedModifierFlags(n)||261!==n.kind&&298!==t.kind&&8388608&t.flags?Eo(t):Mr(t);case 164:case 163:case 168:case 169:case 166:case 165:if(e.hasEffectiveModifier(n,24))return!1;case 167:case 171:case 170:case 172:case 161:case 258:case 175:case 176:case 178:case 174:case 179:case 180:case 183:case 184:case 187:case 193:return Eo(n.parent);case 263:case 264:case 266:return!1;case 160:case 298:case 260:return!0;case 267:return!1;default:return!1}}}function To(n,t){var r,a,i;return n.parent&&267===n.parent.kind?r=Vr(n,n.escapedText,2998271,void 0,n,!1):271===n.parent.kind&&(r=Ia(n.parent,2998271)),r&&(i=new e.Set,i.add(P(r)),o(r.declarations)),a;function o(n){e.forEach(n,(function(n){var r=sa(n)||n;if(t?Pr(n).isVisible=!0:(a=a||[],e.pushIfUnique(a,r)),e.isInternalModuleImportEqualsDeclaration(n)){var s=n.moduleReference,c=e.getFirstIdentifier(s),l=Vr(n,c.escapedText,901119,void 0,void 0,!1);l&&i&&e.tryAddToSet(i,P(l))&&o(l.declarations)}}))}}function So(e,n){var t=xo(e,n);if(t>=0){for(var r=Pt.length,a=t;a<r;a++)Mt[a]=!1;return!1}return Pt.push(e),Mt.push(!0),Ft.push(n),!0}function xo(e,n){for(var t=Pt.length-1;t>=0;t--){if(Lo(Pt[t],Ft[t]))return-1;if(Pt[t]===e&&Ft[t]===n)return t}return-1}function Lo(n,t){switch(t){case 0:return!!wr(n).type;case 5:return!!Pr(n).resolvedEnumType;case 2:return!!wr(n).declaredType;case 1:return!!n.resolvedBaseConstructorType;case 3:return!!n.resolvedReturnType;case 4:return!!n.immediateBaseConstraint;case 6:return!!n.resolvedTypeArguments;case 7:return!!n.baseTypesResolved}return e.Debug.assertNever(t)}function Do(){return Pt.pop(),Ft.pop(),Mt.pop()}function Ao(n){return e.findAncestor(e.getRootDeclaration(n),(function(e){switch(e.kind){case 250:case 251:case 266:case 265:case 264:case 263:return!1;default:return!0}})).parent}function Co(n){var t=mc(hi(n));return t.typeParameters?vd(t,e.map(t.typeParameters,(function(e){return xe}))):t}function Io(e,n){var t=_u(e,n);return t?ws(t):void 0}function No(e,n){return Io(e,n)||bT(n)&&Eu(e,1)||Eu(e,0)||Ne}function ko(e){return e&&0!==(1&e.flags)}function Ro(e){var n=yi(e);return n&&wr(n).type||zo(e,!1)}function Oo(n,t,r){if(n=nb(n,(function(e){return!(98304&e.flags)})),131072&n.flags)return an;if(1048576&n.flags)return rb(n,(function(e){return Oo(e,t,r)}));var a=Qp(e.map(t,Sf));if(Jf(n)||Xf(a)){if(131072&a.flags)return n;var i=gp();return i?Ld(i,[n,a]):Ae}for(var o=e.createSymbolTable(),s=0,c=wl(n);s<c.length;s++){var l=c[s];W_(Lf(l,8576),a)||24&e.getDeclarationModifierFlagsFromSymbol(l)||!Nm(l)||o.set(l.escapedName,km(l,!1))}var u=bu(n,0),d=bu(n,1),p=Bi(r,o,e.emptyArray,e.emptyArray,u,d);return p.objectFlags|=8388608,p}function wo(e){return!!(465829888&e.flags)&&AD(ql(e)||Ne,32768)}function Po(e){var n=Zv(e,wo)?rb(e,(function(e){return 465829888&e.flags?Jl(e):e})):e;return Lv(n,524288)}function Mo(e,n){var t=Fo(e);return t?kb(t,n):n}function Fo(n){var t=Go(n);if(t&&t.flowNode){var r=Bo(n);if(r){var a=e.setTextRange(e.parseNodeFactory.createStringLiteral(r),n),i=e.isLeftHandSideExpression(t)?t:e.parseNodeFactory.createParenthesizedExpression(t),o=e.setTextRange(e.parseNodeFactory.createElementAccessExpression(i,a),n);return e.setParent(a,o),e.setParent(o,n),i!==t&&e.setParent(i,o),o.flowNode=t.flowNode,o}}}function Go(e){var n=e.parent.parent;switch(n.kind){case 199:case 289:return Fo(n);case 200:return Fo(e.parent);case 250:return n.initializer;case 217:return n.right}}function Bo(e){var n=e.parent;return 199===e.kind&&197===n.kind?Uo(e.propertyName||e.name):289===e.kind||290===e.kind?Uo(e.name):""+n.elements.indexOf(e)}function Uo(e){var n=Sf(e);return 384&n.flags?""+n.value:void 0}function Vo(n){var t,r=n.parent,a=Ro(r.parent);if(!a||ko(a))return a;if(z&&8388608&n.flags&&e.isParameterDeclaration(n)?a=Hy(a):!z||!r.parent.initializer||65536&xv(Bv(r.parent.initializer))||(a=Lv(a,524288)),197===r.kind)if(n.dotDotDotToken){if(a=lu(a),2&a.flags||!DT(a))return gr(n,e.Diagnostics.Rest_types_may_only_be_created_from_object_types),Ae;for(var i=[],o=0,s=r.elements;o<s.length;o++){var c=s[o];c.dotDotDotToken||i.push(c.propertyName||c.name)}t=Oo(a,i,n.symbol)}else{var l=n.propertyName||n.name,u=Sf(l),d=im(a,u,void 0,l,void 0,void 0,16);t=Mo(n,d)}else{var p=NI(65|(n.dotDotDotToken?0:128),a,ke,r),f=r.elements.indexOf(n);if(n.dotDotDotToken)t=$v(a,Cy)?rb(a,(function(e){return Pp(e,f)})):Ep(p);else if(dy(a)){u=Fm(f);var m=mT(n)?8:0;d=sm(a,u,void 0,n.name,16|m)||Ae;t=Mo(n,d)}else t=p}return n.initializer?e.getEffectiveTypeAnnotationNode(e.walkUpBindingElementsAndPatterns(n))?!z||32768&Fy(nA(n))?t:Po(t):rA(n,Qp([Po(t),nA(n)],2)):t}function jo(n){var t=e.getJSDocType(n);if(t)return zm(t)}function Ko(n){var t=e.skipParentheses(n);return 103===t.kind||78===t.kind&&rv(t)===ae}function Ho(n){var t=e.skipParentheses(n);return 200===t.kind&&0===t.elements.length}function Wo(e,n){return void 0===n&&(n=!0),z&&n?jy(e):e}function zo(n,t){if(e.isVariableDeclaration(n)&&239===n.parent.parent.kind){var r=Cf(fS(TA(n.parent.parent.expression)));return 4456448&r.flags?If(r):Me}if(e.isVariableDeclaration(n)&&240===n.parent.parent.kind){var a=n.parent.parent;return II(a)||xe}if(e.isBindingPattern(n.parent))return Vo(n);var i=t&&(e.isParameter(n)&&Lu(n)||Iu(n)||!e.isBindingElement(n)&&!e.isVariableDeclaration(n)&&!!n.questionToken),o=ms(n);if(o)return Wo(o,i);if((Y||e.isInJSFile(n))&&e.isVariableDeclaration(n)&&!e.isBindingPattern(n.name)&&!(1&e.getCombinedModifierFlags(n))&&!(8388608&n.flags)){if(!(2&e.getCombinedNodeFlags(n))&&(!n.initializer||Ko(n.initializer)))return Le;if(n.initializer&&Ho(n.initializer))return Rn}if(e.isParameter(n)){var s=n.parent;if(169===s.kind&&Ic(s)){var c=e.getDeclarationOfKind(yi(n.parent),168);if(c){var l=Ou(c),u=CO(s);return u&&n===u?(e.Debug.assert(!u.type),ws(l.thisParameter)):Hu(l)}}if(e.isInJSFile(n)){var d=e.getJSDocType(s);if(d&&e.isFunctionTypeNode(d)){var p=Ou(d),f=s.parameters.indexOf(n);return n.dotDotDotToken?GL(p,f):ML(p,f)}}var m="this"===n.symbol.escapedName?fE(s):mE(n);if(m)return Wo(m,i)}if(e.hasOnlyExpressionInitializer(n)&&n.initializer){if(e.isInJSFile(n)&&!e.isParameter(n)){var _=es(n,yi(n),e.getDeclaredExpandoInitializer(n));if(_)return _}m=rA(n,nA(n));return Wo(m,i)}if(e.isPropertyDeclaration(n)&&!e.hasStaticModifier(n)&&(Y||e.isInJSFile(n))){var g=Ai(n.parent);m=g?Qo(n.symbol,g):2&e.getEffectiveModifierFlags(n)?zg(n.symbol):void 0;return m&&Wo(m,i)}return e.isJsxAttribute(n)?Ve:e.isBindingPattern(n.name)?ls(n.name,!1,!0):void 0}function qo(n){if(n.valueDeclaration&&e.isBinaryExpression(n.valueDeclaration)){var t=wr(n);return void 0===t.isConstructorDeclaredProperty&&(t.isConstructorDeclaredProperty=!1,t.isConstructorDeclaredProperty=!!Xo(n)&&e.every(n.declarations,(function(t){return e.isBinaryExpression(t)&&NE(t)&&(203!==t.left.kind||e.isStringOrNumericLiteralLike(t.left.argumentExpression))&&!ns(void 0,t,n,t)}))),t.isConstructorDeclaredProperty}return!1}function Jo(n){var t=n.valueDeclaration;return t&&e.isPropertyDeclaration(t)&&!e.getEffectiveTypeAnnotationNode(t)&&!t.initializer&&(Y||e.isInJSFile(t))}function Xo(n){if(n.declarations)for(var t=0,r=n.declarations;t<r.length;t++){var a=r[t],i=e.getThisContainer(a,!1);if(i&&(167===i.kind||uL(i)))return i}}function Yo(n){var t=e.getSourceFileOfNode(n.declarations[0]),r=e.unescapeLeadingUnderscores(n.escapedName),a=n.declarations.every((function(n){return e.isInJSFile(n)&&e.isAccessExpression(n)&&e.isModuleExportsAccessExpression(n.expression)})),i=a?e.factory.createPropertyAccessExpression(e.factory.createPropertyAccessExpression(e.factory.createIdentifier("module"),e.factory.createIdentifier("exports")),r):e.factory.createPropertyAccessExpression(e.factory.createIdentifier("exports"),r);return a&&e.setParent(i.expression.expression,i.expression),e.setParent(i.expression,i),e.setParent(i,t),i.flowNode=t.endFlowNode,kb(i,Le,ke)}function Qo(n,t){var r=e.startsWith(n.escapedName,"__#")?e.factory.createPrivateIdentifier(n.escapedName.split("@")[1]):e.unescapeLeadingUnderscores(n.escapedName),a=e.factory.createPropertyAccessExpression(e.factory.createThis(),r);e.setParent(a.expression,a),e.setParent(a,t),a.flowNode=t.returnFlowNode;var i=Zo(a,n);return!Y||i!==Le&&i!==Rn||gr(n.valueDeclaration,e.Diagnostics.Member_0_implicitly_has_an_1_type,ro(n),io(i)),$v(i,pS)?void 0:lI(i)}function Zo(n,t){var r=(null===t||void 0===t?void 0:t.valueDeclaration)&&(!Jo(t)||2&e.getEffectiveModifierFlags(t.valueDeclaration))&&zg(t)||ke;return kb(n,Le,r)}function $o(n,t){var r,a=e.getAssignedExpandoInitializer(n.valueDeclaration);if(a){var i=e.getJSDocTypeTag(a);if(i&&i.typeExpression)return zm(i.typeExpression);var o=n.valueDeclaration&&es(n.valueDeclaration,n,a);return o||Sy($D(a))}var s=!1,c=!1;if(qo(n)&&(r=Qo(n,Xo(n))),!r){var l=void 0;if(n.declarations){for(var u=void 0,d=0,p=n.declarations;d<p.length;d++){var f=p[d],m=e.isBinaryExpression(f)||e.isCallExpression(f)?f:e.isAccessExpression(f)?e.isBinaryExpression(f.parent)?f.parent:f:void 0;if(m){var _=e.isAccessExpression(m)?e.getAssignmentDeclarationPropertyAccessKind(m):e.getAssignmentDeclarationKind(m);(4===_||e.isBinaryExpression(m)&&NE(m,_))&&(as(m)?s=!0:c=!0),e.isCallExpression(m)||(u=ns(u,m,n,f)),u||(l||(l=[])).push(e.isBinaryExpression(m)||e.isCallExpression(m)?ts(n,t,m,_):ze)}}r=u}if(!r){if(!e.length(l))return Ae;var g=s&&n.declarations?is(l,n.declarations):void 0;if(c){var y=zg(n);y&&((g||(g=[])).push(y),s=!0)}var h=e.some(g,(function(e){return!!(-98305&e.flags)}))?g:l;r=Qp(h,2)}}var v=sh(Wo(r,c&&!s));return n.valueDeclaration&&nb(v,(function(e){return!!(-98305&e.flags)}))===ze?(uh(n.valueDeclaration,xe),xe):v}function es(n,t,r){var a,i;if(e.isInJSFile(n)&&r&&e.isObjectLiteralExpression(r)&&!r.properties.length){var o=e.createSymbolTable();while(e.isBinaryExpression(n)||e.isPropertyAccessExpression(n)){var s=yi(n);(null===(a=null===s||void 0===s?void 0:s.exports)||void 0===a?void 0:a.size)&&kr(o,s.exports),n=e.isBinaryExpression(n)?n.parent:n.parent.parent}var c=yi(n);(null===(i=null===c||void 0===c?void 0:c.exports)||void 0===i?void 0:i.size)&&kr(o,c.exports);var l=Bi(t,o,e.emptyArray,e.emptyArray,void 0,void 0);return l.objectFlags|=8192,l}}function ns(n,t,r,a){var i,o=e.getEffectiveTypeAnnotationNode(t.parent);if(o){var s=sh(zm(o));if(!n)return s;n===Ae||s===Ae||U_(n,s)||dI(void 0,n,a,s)}if(null===(i=r.parent)||void 0===i?void 0:i.valueDeclaration){var c=e.getEffectiveTypeAnnotationNode(r.parent.valueDeclaration);if(c)return Io(zm(c),r.escapedName)}return n}function ts(n,t,r,a){if(e.isCallExpression(r)){if(t)return ws(t);var i=$D(r.arguments[2]),o=Io(i,"value");if(o)return o;var s=Io(i,"get");if(s){var c=mx(s);if(c)return Hu(c)}var l=Io(i,"set");if(l){var u=mx(l);if(u)return HL(u)}return xe}if(rs(r.left,r.right))return xe;var d=t?ws(t):Sy($D(r.right));if(524288&d.flags&&2===a&&"export="===n.escapedName){var p=Nl(d),f=e.createSymbolTable();e.copyEntries(p.members,f);var m=f.size;t&&!t.exports&&(t.exports=e.createSymbolTable()),(t||n).exports.forEach((function(n,t){var r,a=f.get(t);if(a&&a!==n)if(111551&n.flags&&111551&a.flags){if(n.valueDeclaration&&a.valueDeclaration&&e.getSourceFileOfNode(n.valueDeclaration)!==e.getSourceFileOfNode(a.valueDeclaration)){var i=e.unescapeLeadingUnderscores(n.escapedName),o=(null===(r=e.tryCast(a.valueDeclaration,e.isNamedDeclaration))||void 0===r?void 0:r.name)||a.valueDeclaration;e.addRelatedInfo(gr(n.valueDeclaration,e.Diagnostics.Duplicate_identifier_0,i),e.createDiagnosticForNode(o,e.Diagnostics._0_was_also_declared_here,i)),e.addRelatedInfo(gr(o,e.Diagnostics.Duplicate_identifier_0,i),e.createDiagnosticForNode(n.valueDeclaration,e.Diagnostics._0_was_also_declared_here,i))}var s=Sr(n.flags|a.flags,t);s.type=Qp([ws(n),ws(a)]),s.valueDeclaration=a.valueDeclaration,s.declarations=e.concatenate(a.declarations,n.declarations),f.set(t,s)}else f.set(t,Ar(n,a));else f.set(t,n)}));var _=Bi(m!==f.size?void 0:p.symbol,f,p.callSignatures,p.constructSignatures,p.stringIndexInfo,p.numberIndexInfo);return _.objectFlags|=8192&e.getObjectFlags(d),_.symbol&&32&_.symbol.flags&&d===ac(_.symbol)&&(_.objectFlags|=16777216),_}return fy(d)?(uh(r,kn),kn):d}function rs(n,t){return e.isPropertyAccessExpression(n)&&107===n.expression.kind&&e.forEachChildRecursively(t,(function(e){return ov(n,e)}))}function as(n){var t=e.getThisContainer(n,!1);return 167===t.kind||252===t.kind||209===t.kind&&!e.isPrototypePropertyAssignment(t.parent)}function is(n,t){return e.Debug.assert(n.length===t.length),n.filter((function(n,r){var a=t[r],i=e.isBinaryExpression(a)?a:e.isBinaryExpression(a.parent)?a.parent:void 0;return i&&as(i)}))}function os(n,t,r){if(n.initializer){var a=e.isBindingPattern(n.name)?ls(n.name,!0,!1):Ne;return Wo(rA(n,nA(n,a)))}return e.isBindingPattern(n.name)?ls(n.name,t,r):(r&&!fs(n)&&uh(n,xe),t?Ce:xe)}function ss(n,t,r){var a,i=e.createSymbolTable(),o=262272;e.forEach(n.elements,(function(e){var n=e.propertyName||e.name;if(e.dotDotDotToken)a=ud(xe,!1);else{var s=Sf(n);if(Lc(s)){var c=kc(s),l=4|(e.initializer?16777216:0),u=Sr(l,c);u.type=os(e,t,r),u.bindingElement=e,i.set(u.escapedName,u)}else o|=512}}));var s=Bi(void 0,i,e.emptyArray,e.emptyArray,a,void 0);return s.objectFlags|=o,t&&(s.pattern=n,s.objectFlags|=262144),s}function cs(n,t,r){var a=n.elements,i=e.lastOrUndefined(a),o=i&&199===i.kind&&i.dotDotDotToken?i:void 0;if(0===a.length||1===a.length&&o)return F>=2?bp(xe):kn;var s=e.map(a,(function(n){return e.isOmittedExpression(n)?xe:os(n,t,r)})),c=e.findLastIndex(a,(function(n){return!(n===o||e.isOmittedExpression(n)||mT(n))}),a.length-1)+1,l=e.map(a,(function(e,n){return e===o?4:n>=c?2:1})),u=Np(s,l);return t&&(u=bd(u),u.pattern=n,u.objectFlags|=262144),u}function ls(e,n,t){return void 0===n&&(n=!1),void 0===t&&(t=!1),197===e.kind?ss(e,n,t):cs(e,n,t)}function us(e,n){return ps(zo(e,!0),e,n)}function ds(e){var n=yi(e),t=Zd(!1);return t&&n&&n===t}function ps(n,t,r){return n?(4096&n.flags&&ds(t.parent)&&(n=Um(t)),r&&dh(t,n),8192&n.flags&&(e.isBindingElement(t)||!t.type)&&n.symbol!==yi(t)&&(n=He),sh(n)):(n=e.isParameter(t)&&t.dotDotDotToken?kn:xe,r&&(fs(t)||uh(t,n)),n)}function fs(n){var t=e.getRootDeclaration(n),r=161===t.kind?t.parent:t;return lC(r)}function ms(n){var t=e.getEffectiveTypeAnnotationNode(n);if(t)return zm(t)}function _s(e){var n=wr(e);if(!n.type){var t=gs(e);n.type||(n.type=t)}return n.type}function gs(n){if(4194304&n.flags)return Co(n);if(n===ce)return xe;if(134217728&n.flags&&n.valueDeclaration){var t=yi(e.getSourceFileOfNode(n.valueDeclaration)),r=Sr(t.flags,"exports");r.declarations=t.declarations?t.declarations.slice():[],r.parent=n,r.target=t,t.valueDeclaration&&(r.valueDeclaration=t.valueDeclaration),t.members&&(r.members=new e.Map(t.members)),t.exports&&(r.exports=new e.Map(t.exports));var a=e.createSymbolTable();return a.set("exports",r),Bi(n,a,e.emptyArray,e.emptyArray,void 0,void 0)}e.Debug.assertIsDefined(n.valueDeclaration);var i,o=n.valueDeclaration;if(e.isCatchClauseVariableDeclarationOrBindingElement(o)){var s=e.getEffectiveTypeAnnotationNode(o);if(void 0===s)return xe;var c=Wk(s);return ko(c)||c===Ne?c:Ae}if(e.isSourceFile(o)&&e.isJsonSourceFile(o))return o.statements.length?sh(Sy(TA(o.statements[0].expression))):an;if(!So(n,0))return 512&n.flags&&!(67108864&n.flags)?Ds(n):ks(n);if(267===o.kind)i=ps($D(o.expression),o);else if(e.isBinaryExpression(o)||e.isInJSFile(o)&&(e.isCallExpression(o)||(e.isPropertyAccessExpression(o)||e.isBindableStaticElementAccessExpression(o))&&e.isBinaryExpression(o.parent)))i=$o(n);else if(e.isPropertyAccessExpression(o)||e.isElementAccessExpression(o)||e.isIdentifier(o)||e.isStringLiteralLike(o)||e.isNumericLiteral(o)||e.isClassDeclaration(o)||e.isFunctionDeclaration(o)||e.isMethodDeclaration(o)&&!e.isObjectLiteralMethod(o)||e.isMethodSignature(o)||e.isSourceFile(o)){if(9136&n.flags)return Ds(n);i=e.isBinaryExpression(o.parent)?$o(n):ms(o)||xe}else if(e.isPropertyAssignment(o))i=ms(o)||sA(o);else if(e.isJsxAttribute(o))i=ms(o)||wT(o);else if(e.isShorthandPropertyAssignment(o))i=ms(o)||oA(o.name,0);else if(e.isObjectLiteralMethod(o))i=ms(o)||cA(o,0);else if(e.isParameter(o)||e.isPropertyDeclaration(o)||e.isPropertySignature(o)||e.isVariableDeclaration(o)||e.isBindingElement(o)||e.isJSDocPropertyLikeTag(o))i=us(o,!0);else if(e.isEnumDeclaration(o))i=Ds(n);else if(e.isEnumMember(o))i=Cs(n);else{if(!e.isAccessor(o))return e.Debug.fail("Unhandled declaration kind! "+e.Debug.formatSyntaxKind(o.kind)+" for "+e.Debug.formatSymbol(n));i=xs(n)||e.Debug.fail("Non-write accessor resolution must always produce a type")}return Do()?i:512&n.flags&&!(67108864&n.flags)?Ds(n):ks(n)}function ys(n){if(n){if(168===n.kind){var t=e.getEffectiveReturnTypeNode(n);return t}var r=e.getEffectiveSetAccessorTypeAnnotationNode(n);return r}}function hs(e){var n=ys(e);return n&&zm(n)}function vs(e){var n=CO(e);return n&&n.symbol}function bs(e){return Uu(Ou(e))}function Es(n){var t=wr(n);return t.type||(t.type=Ss(n)||e.Debug.fail("Read type of accessor must always produce a type"))}function Ts(e){var n=wr(e);return n.writeType||(n.writeType=Ss(e,!0))}function Ss(n,t){if(void 0===t&&(t=!1),!So(n,0))return Ae;var r=xs(n,t);if(!Do()&&(r=xe,Y)){var a=e.getDeclarationOfKind(n,168);gr(a,e.Diagnostics._0_implicitly_has_return_type_any_because_it_does_not_have_a_return_type_annotation_and_is_referenced_directly_or_indirectly_in_one_of_its_return_expressions,ro(n))}return r}function xs(n,t){void 0===t&&(t=!1);var r=e.getDeclarationOfKind(n,168),a=e.getDeclarationOfKind(n,169),i=hs(a);if(t&&i)return l(i,n);if(r&&e.isInJSFile(r)){var o=jo(r);if(o)return l(o,n)}var s=hs(r);if(s)return l(s,n);if(i)return i;if(r&&r.body){var c=eD(r);return l(c,n)}return a?(lC(a)||hr(Y,a,e.Diagnostics.Property_0_implicitly_has_type_any_because_its_set_accessor_lacks_a_parameter_type_annotation,ro(n)),xe):r?(e.Debug.assert(!!r,"there must exist a getter as we are current checking either setter or getter in this function"),lC(r)||hr(Y,r,e.Diagnostics.Property_0_implicitly_has_type_any_because_its_get_accessor_lacks_a_return_type_annotation,ro(n)),xe):void 0;function l(n,t){if(1&e.getCheckFlags(t)){var r=wr(t);return A_(n,r.mapper)}return n}}function Ls(n){var t=Js(ac(n));return 8650752&t.flags?t:2097152&t.flags?e.find(t.types,(function(e){return!!(8650752&e.flags)})):void 0}function Ds(e){var n=wr(e),t=n;if(!n.type){var r=e.valueDeclaration&&fL(e.valueDeclaration,!1);if(r){var a=dL(e,r);a&&(e=n=a)}t.type=n.type=As(e)}return n.type}function As(n){var t=n.valueDeclaration;if(1536&n.flags&&e.isShorthandAmbientModuleSymbol(n))return xe;if(t&&(217===t.kind||e.isAccessExpression(t)&&217===t.parent.kind))return $o(n);if(512&n.flags&&t&&e.isSourceFile(t)&&t.commonJsModuleIndicator){var r=ri(n);if(r!==n){if(!So(n,0))return Ae;var a=gi(n.exports.get("export=")),i=$o(a,a===r?void 0:r);return Do()?i:ks(n)}}var o=Ri(16,n);if(32&n.flags){var s=Ls(n);return s?pf([o,s]):o}return z&&16777216&n.flags?jy(o):o}function Cs(e){var n=wr(e);return n.type||(n.type=dc(e))}function Is(e){var n=wr(e);if(!n.type){var t=Fa(e),r=e.declarations&&wa(ca(e),!0);n.type=(null===r||void 0===r?void 0:r.declarations)&&dk(r.declarations)&&e.declarations.length?Yo(r):dk(e.declarations)?Le:111551&t.flags?ws(t):Ae}return n.type}function Ns(e){var n=wr(e);if(!n.type){if(!So(e,0))return n.type=Ae;var t=A_(ws(n.target),n.mapper);Do()||(t=ks(e)),n.type=t}return n.type}function ks(n){var t=n.valueDeclaration;return e.getEffectiveTypeAnnotationNode(t)?(gr(n.valueDeclaration,e.Diagnostics._0_is_referenced_directly_or_indirectly_in_its_own_type_annotation,ro(n)),Ae):(Y&&(161!==t.kind||t.initializer)&&gr(n.valueDeclaration,e.Diagnostics._0_implicitly_has_type_any_because_it_does_not_have_a_type_annotation_and_is_referenced_directly_or_indirectly_in_its_own_initializer,ro(n)),xe)}function Rs(n){var t=wr(n);return t.type||(e.Debug.assertIsDefined(t.deferralParent),e.Debug.assertIsDefined(t.deferralConstituents),t.type=1048576&t.deferralParent.flags?Qp(t.deferralConstituents):pf(t.deferralConstituents)),t.type}function Os(e){if(98304&e.flags){var n=Ts(e);if(n)return n}return ws(e)}function ws(n){var t=e.getCheckFlags(n);return 65536&t?Rs(n):1&t?Ns(n):262144&t?yl(n):8192&t?Nh(n):7&n.flags?_s(n):9136&n.flags?Ds(n):8&n.flags?Cs(n):98304&n.flags?Es(n):2097152&n.flags?Is(n):Ae}function Ps(n,t){return void 0!==n&&void 0!==t&&0!==(4&e.getObjectFlags(n))&&n.target===t}function Ms(n){return 4&e.getObjectFlags(n)?n.target:n}function Fs(n,t){return r(n);function r(n){if(7&e.getObjectFlags(n)){var a=Ms(n);return a===t||e.some(Qs(a),r)}return!!(2097152&n.flags)&&e.some(n.types,r)}}function Gs(n,t){for(var r=0,a=t;r<a.length;r++){var i=a[r];n=e.appendIfUnique(n,pc(yi(i)))}return n}function Bs(n,t){while(1){if(n=n.parent,n&&e.isBinaryExpression(n)){var r=e.getAssignmentDeclarationKind(n);if(6===r||3===r){var a=yi(n.left);a&&a.parent&&!e.findAncestor(a.parent.valueDeclaration,(function(e){return n===e}))&&(n=a.parent.valueDeclaration)}}if(!n)return;switch(n.kind){case 253:case 222:case 254:case 170:case 171:case 165:case 175:case 176:case 309:case 252:case 166:case 209:case 210:case 255:case 334:case 335:case 329:case 328:case 191:case 185:var i=Bs(n,t);if(191===n.kind)return e.append(i,pc(yi(n.typeParameter)));if(185===n.kind)return e.concatenate(i,ym(n));var o=Gs(i,e.getEffectiveTypeParameterDeclarations(n)),s=t&&(253===n.kind||222===n.kind||254===n.kind||uL(n))&&ac(yi(n)).thisType;return s?e.append(o,s):o;case 330:var c=e.getParameterSymbolFromJSDoc(n);c&&(n=c.valueDeclaration);break;case 312:i=Bs(n,t);return n.tags?Gs(i,e.flatMap(n.tags,(function(n){return e.isJSDocTemplateTag(n)?n.typeParameters:void 0}))):i}}}function Us(n){var t=32&n.flags?n.valueDeclaration:e.getDeclarationOfKind(n,254);return e.Debug.assert(!!t,"Class was missing valueDeclaration -OR- non-class had no interface declarations"),Bs(t)}function Vs(n){if(n.declarations){for(var t,r=0,a=n.declarations;r<a.length;r++){var i=a[r];if(254===i.kind||253===i.kind||222===i.kind||uL(i)||e.isTypeAlias(i)){var o=i;t=Gs(t,e.getEffectiveTypeParameterDeclarations(o))}}return t}}function js(n){return e.concatenate(Us(n),Vs(n))}function Ks(e){var n=yu(e,1);if(1===n.length){var t=n[0];if(!t.typeParameters&&1===t.parameters.length&&j(t)){var r=kL(t.parameters[0]);return ko(r)||uy(r)===xe}}return!1}function Hs(e){if(yu(e,1).length>0)return!0;if(8650752&e.flags){var n=ql(e);return!!n&&Ks(n)}return!1}function Ws(n){return e.getEffectiveBaseTypeNode(n.symbol.valueDeclaration)}function zs(n,t,r){var a=e.length(t),i=e.isInJSFile(r);return e.filter(yu(n,1),(function(n){return(i||a>=ku(n.typeParameters))&&a<=e.length(n.typeParameters)}))}function qs(n,t,r){var a=zs(n,t,r),i=e.map(t,zm);return e.sameMap(a,(function(n){return e.some(n.typeParameters)?Xu(n,i,e.isInJSFile(r)):n}))}function Js(n){if(!n.resolvedBaseConstructorType){var t=n.symbol.valueDeclaration,r=e.getEffectiveBaseTypeNode(t),a=Ws(n);if(!a)return n.resolvedBaseConstructorType=ke;if(!So(n,1))return Ae;var i=TA(a.expression);if(r&&a!==r&&(e.Debug.assert(!r.typeArguments),TA(r.expression)),2621440&i.flags&&Nl(i),!Do())return gr(n.symbol.valueDeclaration,e.Diagnostics._0_is_referenced_directly_or_indirectly_in_its_own_base_expression,ro(n.symbol)),n.resolvedBaseConstructorType=Ae;if(!(1&i.flags)&&i!==Pe&&!Hs(i)){var o=gr(a.expression,e.Diagnostics.Type_0_is_not_a_constructor_function_type,io(i));if(262144&i.flags){var s=md(i),c=Ne;if(s){var l=yu(s,1);l[0]&&(c=Hu(l[0]))}i.symbol.declarations&&e.addRelatedInfo(o,e.createDiagnosticForNode(i.symbol.declarations[0],e.Diagnostics.Did_you_mean_for_0_to_be_constrained_to_type_new_args_Colon_any_1,ro(i.symbol),io(c)))}return n.resolvedBaseConstructorType=Ae}n.resolvedBaseConstructorType=i}return n.resolvedBaseConstructorType}function Xs(n){var t=e.emptyArray;if(n.symbol.declarations)for(var r=0,a=n.symbol.declarations;r<a.length;r++){var i=a[r],o=e.getEffectiveImplementsTypeNodes(i);if(o)for(var s=0,c=o;s<c.length;s++){var l=c[s],u=zm(l);u!==Ae&&(t===e.emptyArray?t=[u]:t.push(u))}}return t}function Ys(n,t){gr(n,e.Diagnostics.Type_0_recursively_references_itself_as_a_base_type,io(t,void 0,2))}function Qs(n){if(!n.baseTypesResolved){if(So(n,7)&&(8&n.objectFlags?n.resolvedBaseTypes=[Zs(n)]:96&n.symbol.flags?(32&n.symbol.flags&&$s(n),64&n.symbol.flags&&tc(n)):e.Debug.fail("type must be class or interface"),!Do()&&n.symbol.declarations))for(var t=0,r=n.symbol.declarations;t<r.length;t++){var a=r[t];253!==a.kind&&254!==a.kind||Ys(a,n)}n.baseTypesResolved=!0}return n.resolvedBaseTypes}function Zs(n){var t=e.sameMap(n.typeParameters,(function(e,t){return 8&n.elementFlags[t]?im(e,Fe):e}));return Ep(Qp(t||e.emptyArray),n.readonly)}function $s(n){n.resolvedBaseTypes=e.resolvingEmptyArray;var t=au(Js(n));if(!(2621441&t.flags))return n.resolvedBaseTypes=e.emptyArray;var r,a=Ws(n),i=t.symbol?mc(t.symbol):void 0;if(t.symbol&&32&t.symbol.flags&&ec(i))r=xd(a,t.symbol);else if(1&t.flags)r=t;else{var o=qs(t,a.typeArguments,a);if(!o.length)return gr(a.expression,e.Diagnostics.No_base_constructor_has_the_specified_number_of_type_arguments),n.resolvedBaseTypes=e.emptyArray;r=Hu(o[0])}if(r===Ae)return n.resolvedBaseTypes=e.emptyArray;var s=lu(r);if(!nc(s)){var c=mu(void 0,r),l=e.chainDiagnosticMessages(c,e.Diagnostics.Base_constructor_return_type_0_is_not_an_object_type_or_intersection_of_object_types_with_statically_known_members,io(s));return nr.add(e.createDiagnosticForNodeFromMessageChain(a.expression,l)),n.resolvedBaseTypes=e.emptyArray}return n===s||Fs(s,n)?(gr(n.symbol.valueDeclaration,e.Diagnostics.Type_0_recursively_references_itself_as_a_base_type,io(n,void 0,2)),n.resolvedBaseTypes=e.emptyArray):(n.resolvedBaseTypes===e.resolvingEmptyArray&&(n.members=void 0),n.resolvedBaseTypes=[s])}function ec(e){var n=e.outerTypeParameters;if(n){var t=n.length-1,r=Td(e);return n[t].symbol!==r[t].symbol}return!0}function nc(n){if(262144&n.flags){var t=ql(n);if(t)return nc(t)}return!!(67633153&n.flags&&!Il(n)||2097152&n.flags&&e.every(n.types,nc))}function tc(n){if(n.resolvedBaseTypes=n.resolvedBaseTypes||e.emptyArray,n.symbol.declarations)for(var t=0,r=n.symbol.declarations;t<r.length;t++){var a=r[t];if(254===a.kind&&e.getInterfaceBaseTypeNodes(a))for(var i=0,o=e.getInterfaceBaseTypeNodes(a);i<o.length;i++){var s=o[i],c=lu(zm(s));c!==Ae&&(nc(c)?n===c||Fs(c,n)?Ys(a,n):n.resolvedBaseTypes===e.emptyArray?n.resolvedBaseTypes=[c]:n.resolvedBaseTypes.push(c):gr(s,e.Diagnostics.An_interface_can_only_extend_an_object_type_or_intersection_of_object_types_with_statically_known_members))}}}function rc(n){if(!n.declarations)return!0;for(var t=0,r=n.declarations;t<r.length;t++){var a=r[t];if(254===a.kind){if(128&a.flags)return!1;var i=e.getInterfaceBaseTypeNodes(a);if(i)for(var o=0,s=i;o<s.length;o++){var c=s[o];if(e.isEntityNameExpression(c.expression)){var l=qa(c.expression,788968,!0);if(!l||!(64&l.flags)||ac(l).thisType)return!1}}}}return!0}function ac(n){var t=wr(n),r=t;if(!t.declaredType){var a=32&n.flags?1:2,i=dL(n,n.valueDeclaration&&pL(n.valueDeclaration));i&&(n=t=i);var o=r.declaredType=t.declaredType=Ri(a,n),s=Us(n),c=Vs(n);(s||c||1===a||!rc(n))&&(o.objectFlags|=4,o.typeParameters=e.concatenate(s,c),o.outerTypeParameters=s,o.localTypeParameters=c,o.instantiations=new e.Map,o.instantiations.set(gd(o.typeParameters),o),o.target=o,o.resolvedTypeArguments=o.typeParameters,o.thisType=wi(n),o.thisType.isThisType=!0,o.thisType.constraint=o)}return t.declaredType}function ic(n){var t,r=wr(n);if(!r.declaredType){if(!So(n,2))return Ae;var a=e.Debug.checkDefined(null===(t=n.declarations)||void 0===t?void 0:t.find(e.isTypeAlias),"Type alias symbol with no valid declaration found"),i=e.isJSDocTypeAlias(a)?a.typeExpression:a.type,o=i?zm(i):Ae;if(Do()){var s=Vs(n);s&&(r.typeParameters=s,r.instantiations=new e.Map,r.instantiations.set(gd(s),o))}else o=Ae,gr(e.isNamedDeclaration(a)?a.name:a||a,e.Diagnostics.Type_alias_0_circularly_references_itself,ro(n));r.declaredType=o}return r.declaredType}function oc(n){return!!e.isStringLiteralLike(n)||217===n.kind&&(oc(n.left)&&oc(n.right))}function sc(n){var t=n.initializer;if(!t)return!(8388608&n.flags);switch(t.kind){case 10:case 8:case 14:return!0;case 215:return 40===t.operator&&8===t.operand.kind;case 78:return e.nodeIsMissing(t)||!!yi(n.parent).exports.get(t.escapedText);case 217:return oc(t);default:return!1}}function cc(n){var t=wr(n);if(void 0!==t.enumKind)return t.enumKind;var r=!1;if(n.declarations)for(var a=0,i=n.declarations;a<i.length;a++){var o=i[a];if(256===o.kind)for(var s=0,c=o.members;s<c.length;s++){var l=c[s];if(l.initializer&&e.isStringLiteralLike(l.initializer))return t.enumKind=1;sc(l)||(r=!0)}}return t.enumKind=r?0:1}function lc(e){return 1024&e.flags&&!(1048576&e.flags)?mc(hi(e.symbol)):e}function uc(e){var n=wr(e);if(n.declaredType)return n.declaredType;if(1===cc(e)){b++;var t=[];if(e.declarations)for(var r=0,a=e.declarations;r<a.length;r++){var i=a[r];if(256===i.kind)for(var o=0,s=i.members;o<s.length;o++){var c=s[o],l=SR(c),u=wm(Fm(void 0!==l?l:0,b,yi(c)));wr(yi(c)).declaredType=u,t.push(Pm(u))}}if(t.length){var d=Qp(t,1,e,void 0);return 1048576&d.flags&&(d.flags|=1024,d.symbol=e),n.declaredType=d}}var p=Ci(32);return p.symbol=e,n.declaredType=p}function dc(e){var n=wr(e);if(!n.declaredType){var t=uc(hi(e));n.declaredType||(n.declaredType=t)}return n.declaredType}function pc(e){var n=wr(e);return n.declaredType||(n.declaredType=wi(e))}function fc(e){var n=wr(e);return n.declaredType||(n.declaredType=mc(Fa(e)))}function mc(e){return _c(e)||Ae}function _c(e){return 96&e.flags?ac(e):524288&e.flags?ic(e):262144&e.flags?pc(e):384&e.flags?uc(e):8&e.flags?dc(e):2097152&e.flags?fc(e):void 0}function gc(e){switch(e.kind){case 128:case 152:case 147:case 144:case 155:case 131:case 148:case 145:case 113:case 150:case 141:case 192:return!0;case 179:return gc(e.elementType);case 174:return!e.typeArguments||e.typeArguments.every(gc)}return!1}function yc(n){var t=e.getEffectiveConstraintOfTypeParameter(n);return!t||gc(t)}function hc(n){var t=e.getEffectiveTypeAnnotationNode(n);return t?gc(t):!e.hasInitializer(n)}function vc(n){var t=e.getEffectiveReturnTypeNode(n),r=e.getEffectiveTypeParameterDeclarations(n);return(167===n.kind||!!t&&gc(t))&&n.parameters.every(hc)&&r.every(yc)}function bc(e){if(e.declarations&&1===e.declarations.length){var n=e.declarations[0];if(n)switch(n.kind){case 164:case 163:return hc(n);case 166:case 165:case 167:case 168:case 169:return vc(n)}}return!1}function Ec(n,t,r){for(var a=e.createSymbolTable(),i=0,o=n;i<o.length;i++){var s=o[i];a.set(s.escapedName,r&&bc(s)?s:f_(s,t))}return a}function Tc(e,n){for(var t=0,r=n;t<r.length;t++){var a=r[t];e.has(a.escapedName)||Sc(a)||e.set(a.escapedName,a)}}function Sc(n){return!!n.valueDeclaration&&e.isPrivateIdentifierClassElementDeclaration(n.valueDeclaration)&&e.hasSyntacticModifier(n.valueDeclaration,32)}function xc(n){if(!n.declaredProperties){var t=n.symbol,r=Pc(t);n.declaredProperties=Mi(r),n.declaredCallSignatures=e.emptyArray,n.declaredConstructSignatures=e.emptyArray,n.declaredCallSignatures=Gu(r.get("__call")),n.declaredConstructSignatures=Gu(r.get("__new")),n.declaredStringIndexInfo=dd(t,0),n.declaredNumberIndexInfo=dd(t,1)}return n}function Lc(e){return!!(8576&e.flags)}function Dc(n){if(!e.isComputedPropertyName(n)&&!e.isElementAccessExpression(n))return!1;var t=e.isComputedPropertyName(n)?n.expression:n.argumentExpression;return e.isEntityNameExpression(t)&&Lc(e.isComputedPropertyName(n)?ET(n):$D(t))}function Ac(e){return 95===e.charCodeAt(0)&&95===e.charCodeAt(1)&&64===e.charCodeAt(2)}function Cc(n){var t=e.getNameOfDeclaration(n);return!!t&&Dc(t)}function Ic(n){return!e.hasDynamicName(n)||Cc(n)}function Nc(n){return e.isDynamicName(n)&&!Dc(n)}function kc(n){return 8192&n.flags?n.escapedName:384&n.flags?e.escapeLeadingUnderscores(""+n.value):e.Debug.fail()}function Rc(n,t,r){e.Debug.assert(!!(4096&e.getCheckFlags(n)),"Expected a late-bound symbol."),n.flags|=r,wr(t.symbol).lateSymbol=n,n.declarations?n.declarations.push(t):n.declarations=[t],111551&r&&(n.valueDeclaration&&n.valueDeclaration.kind===t.kind||(n.valueDeclaration=t))}function Oc(n,t,r,a){e.Debug.assert(!!a.symbol,"The member is expected to have a symbol.");var i=Pr(a);if(!i.resolvedSymbol){i.resolvedSymbol=a.symbol;var o=e.isBinaryExpression(a)?a.left:a.name,s=e.isElementAccessExpression(o)?$D(o.argumentExpression):ET(o);if(Lc(s)){var c=kc(s),l=a.symbol.flags,u=r.get(c);u||r.set(c,u=Sr(0,c,4096));var d=t&&t.get(c);if(u.flags&xr(l)||d){var p=d?e.concatenate(d.declarations,u.declarations):u.declarations,f=!(8192&s.flags)&&e.unescapeLeadingUnderscores(c)||e.declarationNameToString(o);e.forEach(p,(function(n){return gr(e.getNameOfDeclaration(n)||n,e.Diagnostics.Property_0_was_also_declared_here,f)})),gr(o||a,e.Diagnostics.Duplicate_property_0,f),u=Sr(0,c,4096)}return u.nameType=s,Rc(u,a,l),u.parent?e.Debug.assert(u.parent===n,"Existing symbol parent should match new one"):u.parent=n,i.resolvedSymbol=u}}return i.resolvedSymbol}function wc(n,t){var r=wr(n);if(!r[t]){var a="resolvedExports"===t,i=a?1536&n.flags?_i(n):n.exports:n.members;r[t]=i||D;for(var o=e.createSymbolTable(),s=0,c=n.declarations||e.emptyArray;s<c.length;s++){var l=c[s],u=e.getMembersOfDeclaration(l);if(u)for(var d=0,p=u;d<p.length;d++){var f=p[d];a===e.hasStaticModifier(f)&&Cc(f)&&Oc(n,i,o,f)}}var m=n.assignmentDeclarationMembers;if(m)for(var _=e.arrayFrom(m.values()),g=0,y=_;g<y.length;g++){f=y[g];var h=e.getAssignmentDeclarationKind(f),v=3===h||e.isBinaryExpression(f)&&NE(f,h)||9===h||6===h;a===!v&&Cc(f)&&Oc(n,i,o,f)}r[t]=Nr(i,o)||D}return r[t]}function Pc(e){return 6256&e.flags?wc(e,"resolvedMembers"):e.members||D}function Mc(n){if(106500&n.flags&&"__computed"===n.escapedName){var t=wr(n);if(!t.lateSymbol&&e.some(n.declarations,Cc)){var r=gi(n.parent);e.some(n.declarations,e.hasStaticModifier)?pi(r):Pc(r)}return t.lateSymbol||(t.lateSymbol=n)}return n}function Fc(n,t,r){if(4&e.getObjectFlags(n)){var a=n.target,i=Td(n);if(e.length(a.typeParameters)===e.length(i)){var o=vd(a,e.concatenate(i,[t||a.thisType]));return r?au(o):o}}else if(2097152&n.flags){var s=e.sameMap(n.types,(function(e){return Fc(e,t,r)}));return s!==n.types?pf(s):n}return r?au(n):n}function Gc(n,t,r,a){var i,o,s,c,l,u;e.rangeEquals(r,a,0,r.length)?(o=t.symbol?Pc(t.symbol):e.createSymbolTable(t.declaredProperties),s=t.declaredCallSignatures,c=t.declaredConstructSignatures,l=t.declaredStringIndexInfo,u=t.declaredNumberIndexInfo):(i=Qm(r,a),o=Ec(t.declaredProperties,i,1===r.length),s=Ym(t.declaredCallSignatures,i),c=Ym(t.declaredConstructSignatures,i),l=O_(t.declaredStringIndexInfo,i),u=O_(t.declaredNumberIndexInfo,i));var d=Qs(t);if(d.length){t.symbol&&o===Pc(t.symbol)&&(o=e.createSymbolTable(t.declaredProperties)),Gi(n,o,s,c,l,u);for(var p=e.lastOrUndefined(a),f=0,m=d;f<m.length;f++){var _=m[f],g=p?Fc(A_(_,i),p):_;Tc(o,wl(g)),s=e.concatenate(s,yu(g,0)),c=e.concatenate(c,yu(g,1)),l||(l=g===xe?ud(xe,!1):bu(g,0)),u=u||bu(g,1)}}Gi(n,o,s,c,l,u)}function Bc(n){Gc(n,xc(n),e.emptyArray,e.emptyArray)}function Uc(n){var t=xc(n.target),r=e.concatenate(t.typeParameters,[t.thisType]),a=Td(n),i=a.length===r.length?a:e.concatenate(a,[n]);Gc(n,t,r,i)}function Vc(e,n,t,r,a,i,o,s){var c=new y(le,s);return c.declaration=e,c.typeParameters=n,c.parameters=r,c.thisParameter=t,c.resolvedReturnType=a,c.resolvedTypePredicate=i,c.minArgumentCount=o,c.resolvedMinArgumentCount=void 0,c.target=void 0,c.mapper=void 0,c.compositeSignatures=void 0,c.compositeKind=void 0,c}function jc(e){var n=Vc(e.declaration,e.typeParameters,e.thisParameter,e.parameters,void 0,void 0,e.minArgumentCount,39&e.flags);return n.target=e.target,n.mapper=e.mapper,n.compositeSignatures=e.compositeSignatures,n.compositeKind=e.compositeKind,n}function Kc(e,n){var t=jc(e);return t.compositeSignatures=n,t.compositeKind=1048576,t.target=void 0,t.mapper=void 0,t}function Hc(e,n){if((24&e.flags)===n)return e;e.optionalCallSignatureCache||(e.optionalCallSignatureCache={});var t=8===n?"inner":"outer";return e.optionalCallSignatureCache[t]||(e.optionalCallSignatureCache[t]=Wc(e,n))}function Wc(n,t){e.Debug.assert(8===t||16===t,"An optional call signature can either be for an inner call chain or an outer call chain, but not both.");var r=jc(n);return r.flags|=t,r}function zc(n,t){if(j(n)){var r=n.parameters.length-1,a=ws(n.parameters[r]);if(Cy(a))return[i(a,r)];if(!t&&1048576&a.flags&&e.every(a.types,Cy))return e.map(a.types,(function(e){return i(e,r)}))}return[n.parameters];function i(t,r){var a=Td(t),i=t.target.labeledElementDeclarations,o=e.map(a,(function(e,a){var o=!!i&&RL(i[a]),s=o||OL(n,r+a,t),c=t.target.elementFlags[a],l=12&c?32768:2&c?16384:0,u=Sr(1,s,l);return u.type=4&c?Ep(e):e,u}));return e.concatenate(n.parameters.slice(0,r),o)}}function qc(n){var t=Js(n),r=yu(t,1),a=e.getClassLikeDeclarationOfSymbol(n.symbol),i=!!a&&e.hasSyntacticModifier(a,128);if(0===r.length)return[Vc(void 0,n.localTypeParameters,void 0,e.emptyArray,n,void 0,0,i?4:0)];for(var o=Ws(n),s=e.isInJSFile(o),c=Vd(o),l=e.length(c),u=[],d=0,p=r;d<p.length;d++){var f=p[d],m=ku(f.typeParameters),_=e.length(f.typeParameters);if(s||l>=m&&l<=_){var g=_?Qu(f,Ru(c,f.typeParameters,m,s)):jc(f);g.typeParameters=n.localTypeParameters,g.resolvedReturnType=n,g.flags=i?4|g.flags:-5&g.flags,u.push(g)}}return u}function Jc(e,n,t,r,a){for(var i=0,o=e;i<o.length;i++){var s=o[i];if(ny(s,n,t,r,a,t?K_:V_))return s}}function Xc(n,t,r){if(t.typeParameters){if(r>0)return;for(var a=1;a<n.length;a++)if(!Jc(n[a],t,!1,!1,!1))return;return[t]}var i;for(a=0;a<n.length;a++){var o=a===r?t:Jc(n[a],t,!0,!1,!0);if(!o)return;i=e.appendIfUnique(i,o)}return i}function Yc(n){for(var t,r,a=0;a<n.length;a++){if(0===n[a].length)return e.emptyArray;n[a].length>1&&(r=void 0===r?a:-1);for(var i=0,o=n[a];i<o.length;i++){var s=o[i];if(!t||!Jc(t,s,!1,!1,!0)){var c=Xc(n,s,a);if(c){var l=s;if(c.length>1){var u=s.thisParameter,d=e.forEach(c,(function(e){return e.thisParameter}));if(d){var p=pf(e.mapDefined(c,(function(e){return e.thisParameter&&ws(e.thisParameter)})));u=Zy(d,p)}l=Kc(s,c),l.thisParameter=u}(t||(t=[])).push(l)}}}}if(!e.length(t)&&-1!==r){for(var f=n[void 0!==r?r:0],m=f.slice(),_=function(n){if(n!==f){var t=n[0];if(e.Debug.assert(!!t,"getUnionSignatures bails early on empty signature lists and should not have empty lists on second pass"),m=t.typeParameters&&e.some(m,(function(e){return!!e.typeParameters&&!Qc(t.typeParameters,e.typeParameters)}))?void 0:e.map(m,(function(e){return el(e,t)})),!m)return"break"}},g=0,y=n;g<y.length;g++){var h=y[g],v=_(h);if("break"===v)break}t=m}return t||e.emptyArray}function Qc(n,t){if(e.length(n)!==e.length(t))return!1;if(!n||!t)return!0;for(var r=Qm(t,n),a=0;a<n.length;a++){var i=n[a],o=t[a];if(i!==o&&!U_(md(i)||Ne,A_(md(o)||Ne,r)))return!1}return!0}function Zc(e,n,t){if(!e||!n)return e||n;var r=pf([ws(e),A_(ws(n),t)]);return Zy(e,r)}function $c(e,n,t){for(var r=BL(e),a=BL(n),i=r>=a?e:n,o=i===e?n:e,s=i===e?r:a,c=VL(e)||VL(n),l=c&&!VL(i),u=new Array(s+(l?1:0)),d=0;d<s;d++){var p=FL(i,d);i===n&&(p=A_(p,t));var f=FL(o,d)||Ne;o===n&&(f=A_(f,t));var m=pf([p,f]),_=c&&!l&&d===s-1,g=d>=UL(i)&&d>=UL(o),y=d>=r?void 0:OL(e,d),h=d>=a?void 0:OL(n,d),v=y===h?y:y?h?void 0:y:h,b=Sr(1|(g&&!_?16777216:0),v||"arg"+d);b.type=_?Ep(m):m,u[d]=b}if(l){var E=Sr(1,"args");E.type=Ep(ML(o,s)),o===n&&(E.type=A_(E.type,t)),u[s]=E}return u}function el(n,t){var r,a=n.typeParameters||t.typeParameters;n.typeParameters&&t.typeParameters&&(r=Qm(t.typeParameters,n.typeParameters));var i=n.declaration,o=$c(n,t,r),s=Zc(n.thisParameter,t.thisParameter,r),c=Math.max(n.minArgumentCount,t.minArgumentCount),l=Vc(i,a,s,o,void 0,void 0,c,39&(n.flags|t.flags));return l.compositeKind=1048576,l.compositeSignatures=e.concatenate(2097152!==n.compositeKind&&n.compositeSignatures||[n],[t]),r&&(l.mapper=2097152!==n.compositeKind&&n.mapper&&n.compositeSignatures?i_(n.mapper,r):r),l}function nl(e,n){for(var t=[],r=!1,a=0,i=e;a<i.length;a++){var o=i[a],s=bu(au(o),n);if(!s)return;t.push(s.type),r=r||s.isReadonly}return ud(Qp(t,2),r)}function tl(n){var t=Yc(e.map(n.types,(function(e){return e===En?[ft]:yu(e,0)}))),r=Yc(e.map(n.types,(function(e){return yu(e,1)}))),a=nl(n.types,0),i=nl(n.types,1);Gi(n,D,t,r,a,i)}function rl(e,n){return e?n?pf([e,n]):e:n}function al(e,n){return e?n?ud(pf([e.type,n.type]),e.isReadonly&&n.isReadonly):e:n}function il(e,n){return e&&n&&ud(Qp([e.type,n.type]),e.isReadonly||n.isReadonly)}function ol(n){var t=e.countWhere(n,(function(e){return yu(e,1).length>0})),r=e.map(n,Ks);if(t>0&&t===e.countWhere(r,(function(e){return e}))){var a=r.indexOf(!0);r[a]=!1}return r}function sl(e,n,t,r){for(var a=[],i=0;i<n.length;i++)i===r?a.push(e):t[i]&&a.push(Hu(yu(n[i],1)[0]));return pf(a)}function cl(n){for(var t,r,a,i,o=n.types,s=ol(o),c=e.countWhere(s,(function(e){return e})),l=function(l){var u=n.types[l];if(!s[l]){var d=yu(u,1);d.length&&c>0&&(d=e.map(d,(function(e){var n=jc(e);return n.resolvedReturnType=sl(Hu(e),o,s,l),n}))),r=ll(r,d)}t=ll(t,yu(u,0)),a=al(a,bu(u,0)),i=al(i,bu(u,1))},u=0;u<o.length;u++)l(u);Gi(n,D,t||e.emptyArray,r||e.emptyArray,a,i)}function ll(n,t){for(var r=function(t){n&&!e.every(n,(function(e){return!ny(e,t,!1,!1,!1,V_)}))||(n=e.append(n,t))},a=0,i=t;a<i.length;a++){var o=i[a];r(o)}return n}function ul(n){var t=gi(n.symbol);if(n.target){Gi(n,D,e.emptyArray,e.emptyArray,void 0,void 0);var r=Ec(kl(n.target),n.mapper,!1),a=Ym(yu(n.target,0),n.mapper),i=Ym(yu(n.target,1),n.mapper),o=O_(bu(n.target,0),n.mapper),s=O_(bu(n.target,1),n.mapper);Gi(n,r,a,i,o,s)}else if(2048&t.flags){Gi(n,D,e.emptyArray,e.emptyArray,void 0,void 0);r=Pc(t),a=Gu(r.get("__call")),i=Gu(r.get("__new")),o=dd(t,0),s=dd(t,1);Gi(n,r,a,i,o,s)}else{r=D,o=void 0,s=void 0;if(t.exports&&(r=pi(t),t===ie)){var c=new e.Map;r.forEach((function(e){418&e.flags||c.set(e.escapedName,e)})),r=c}var l=void 0;if(Gi(n,r,e.emptyArray,e.emptyArray,void 0,void 0),32&t.flags){var u=ac(t),d=Js(u);11272192&d.flags?(r=e.createSymbolTable(Fi(r)),Tc(r,wl(d))):d===xe&&(l=ud(xe,!1))}var p=od(r);if(p?(o=pl(p,0),s=pl(p,1)):(o=l,384&t.flags&&(32&mc(t).flags||e.some(n.properties,(function(e){return!!(296&ws(e).flags)})))&&(s=gt)),Gi(n,r,e.emptyArray,e.emptyArray,o,s),8208&t.flags&&(n.callSignatures=Gu(t)),32&t.flags){var f=ac(t);i=t.members?Gu(t.members.get("__constructor")):e.emptyArray;16&t.flags&&(i=e.addRange(i.slice(),e.mapDefined(n.callSignatures,(function(e){return uL(e.declaration)?Vc(e.declaration,e.typeParameters,e.thisParameter,e.parameters,f,void 0,e.minArgumentCount,39&e.flags):void 0})))),i.length||(i=qc(f)),n.constructSignatures=i}}}function dl(e,n,t){return A_(e,Qm([n.indexType,n.objectType],[Fm(0),Np([t])]))}function pl(n,t){var r=ld(n,t);if(r)return ud(r.type?zm(r.type):xe,e.hasEffectiveModifier(r,64),r)}function fl(n){for(var t=bu(n.source,0),r=Ll(n.mappedType),a=!(1&r),i=4&r?0:16777216,o=t&&ud(kh(t.type,n.mappedType,n.constraintType),a&&t.isReadonly),s=e.createSymbolTable(),c=0,l=wl(n.source);c<l.length;c++){var u=l[c],d=8192|(a&&gD(u)?8:0),p=Sr(4|u.flags&i,u.escapedName,d);if(p.declarations=u.declarations,p.nameType=wr(u).nameType,p.propertyType=ws(u),8388608&n.constraintType.type.flags&&262144&n.constraintType.type.objectType.flags&&262144&n.constraintType.type.indexType.flags){var f=n.constraintType.type.objectType,m=dl(n.mappedType,n.constraintType.type,f);p.mappedType=m,p.constraintType=Cf(f)}else p.mappedType=n.mappedType,p.constraintType=n.constraintType;s.set(u.escapedName,p)}Gi(n,s,e.emptyArray,e.emptyArray,o,void 0)}function ml(n){if(4194304&n.flags){var t=au(n.type);return Iy(t)?Mp(t):Cf(t)}if(16777216&n.flags){if(n.root.isDistributive){var r=n.checkType,a=ml(r);if(a!==r)return L_(n,s_(n.root.checkType,a,n.mapper))}return n}return 1048576&n.flags?rb(n,ml):2097152&n.flags?pf(e.sameMap(n.types,ml)):n}function _l(n){return 4096&e.getCheckFlags(n)}function gl(n){var t,r,a=e.createSymbolTable();Gi(n,D,e.emptyArray,e.emptyArray,void 0,void 0);var i=hl(n),o=vl(n),s=bl(n.target||n),c=El(n.target||n),l=au(xl(n)),u=Ll(n),d=Z?128:8576;if(Sl(n)){for(var p=0,f=wl(l);p<f.length;p++){var m=f[p];_(Lf(m,d))}(1&l.flags||bu(l,0))&&_(Me),!Z&&bu(l,1)&&_(Fe)}else Qv(ml(o),_);function _(e){var t=s?A_(s,c_(n.mapper,i,e)):e;Qv(t,(function(n){return g(e,n)}))}function g(e,o){if(Lc(o)){var s=kc(o),d=a.get(s);if(d)d.nameType=Qp([d.nameType,o]),d.keyType=Qp([d.keyType,e]);else{var p=Lc(e)?_u(l,kc(e)):void 0,f=!!(4&u||!(8&u)&&p&&16777216&p.flags),m=!!(1&u||!(2&u)&&p&&gD(p)),_=z&&!f&&p&&16777216&p.flags,g=p?_l(p):0,y=Sr(4|(f?16777216:0),s,262144|g|(m?8:0)|(_?524288:0));y.mappedType=n,y.nameType=o,y.keyType=e,p&&(y.syntheticOrigin=p,y.declarations=p.declarations),a.set(s,y)}}else if(45&o.flags){var h=A_(c,c_(n.mapper,i,e));5&o.flags?t=ud(t?Qp([t.type,h]):h,!!(1&u)):r=ud(r?Qp([r.type,h]):h,!!(1&u))}}Gi(n,a,e.emptyArray,e.emptyArray,t,r)}function yl(n){if(!n.type){var t=n.mappedType;if(!So(n,0))return t.containsError=!0,Ae;var r=El(t.target||t),a=c_(t.mapper,hl(t),n.keyType),i=A_(r,a),o=z&&16777216&n.flags&&!AD(i,49152)?jy(i):524288&n.checkFlags?Lv(i,524288):i;Do()||(gr(d,e.Diagnostics.Type_of_property_0_circularly_references_itself_in_mapped_type_1,ro(n),io(t)),o=Ae),n.type=o}return n.type}function hl(e){return e.typeParameter||(e.typeParameter=pc(yi(e.declaration.typeParameter)))}function vl(e){return e.constraintType||(e.constraintType=Gl(hl(e))||Ae)}function bl(e){return e.declaration.nameType?e.nameType||(e.nameType=A_(zm(e.declaration.nameType),e.mapper)):void 0}function El(e){return e.templateType||(e.templateType=e.declaration.type?A_(Wo(zm(e.declaration.type),!!(4&Ll(e))),e.mapper):Ae)}function Tl(n){return e.getEffectiveConstraintOfTypeParameter(n.declaration.typeParameter)}function Sl(e){var n=Tl(e);return 189===n.kind&&138===n.operator}function xl(e){if(!e.modifiersType)if(Sl(e))e.modifiersType=A_(zm(Tl(e).type),e.mapper);else{var n=lm(e.declaration),t=vl(n),r=t&&262144&t.flags?Gl(t):t;e.modifiersType=r&&4194304&r.flags?A_(r.type,e.mapper):Ne}return e.modifiersType}function Ll(e){var n=e.declaration;return(n.readonlyToken?40===n.readonlyToken.kind?2:1:0)|(n.questionToken?40===n.questionToken.kind?8:4:0)}function Dl(e){var n=Ll(e);return 8&n?-1:4&n?1:0}function Al(e){var n=Dl(e),t=xl(e);return n||(Il(t)?Dl(t):0)}function Cl(n){return!!(32&e.getObjectFlags(n)&&4&Ll(n))}function Il(n){return!!(32&e.getObjectFlags(n))&&Xf(vl(n))}function Nl(e){return e.members||(524288&e.flags?4&e.objectFlags?Uc(e):3&e.objectFlags?Bc(e):1024&e.objectFlags?fl(e):16&e.objectFlags?ul(e):32&e.objectFlags&&gl(e):1048576&e.flags?tl(e):2097152&e.flags&&cl(e)),e}function kl(n){return 524288&n.flags?Nl(n).properties:e.emptyArray}function Rl(e,n){if(524288&e.flags){var t=Nl(e),r=t.members.get(n);if(r&&Di(r))return r}}function Ol(n){if(!n.resolvedProperties){for(var t=e.createSymbolTable(),r=0,a=n.types;r<a.length;r++){for(var i=a[r],o=0,s=wl(i);o<s.length;o++){var c=s[o];if(!t.has(c.escapedName)){var l=cu(n,c.escapedName);l&&t.set(c.escapedName,l)}}if(1048576&n.flags&&!bu(i,0)&&!bu(i,1))break}n.resolvedProperties=Mi(t)}return n.resolvedProperties}function wl(e){return e=iu(e),3145728&e.flags?Ol(e):kl(e)}function Pl(e,n){var t=n.properties;return t.some((function(n){var t=n.name&&Sf(n.name),r=t&&Lc(t)?kc(t):void 0,a=void 0===r?void 0:Io(e,r);return!!a&&Ey(a)&&!W_(Wk(n),a)}))}function Ml(n){var t=Qp(n);if(!(1048576&t.flags))return Qk(t);for(var r=e.createSymbolTable(),a=0,i=n;a<i.length;a++)for(var o=i[a],s=0,c=Qk(o);s<c.length;s++){var l=c[s].escapedName;if(!r.has(l)){var u=ou(t,l);u&&r.set(l,u)}}return e.arrayFrom(r.values())}function Fl(e){return 262144&e.flags?Gl(e):8388608&e.flags?Bl(e):16777216&e.flags?Wl(e):ql(e)}function Gl(e){return Xl(e)?md(e):void 0}function Bl(e){return Xl(e)?Vl(e):void 0}function Ul(e){var n=Qf(e,!1);return n!==e?n:Fl(e)}function Vl(e){var n=Ul(e.indexType);if(n&&n!==e.indexType){var t=sm(e.objectType,n,e.noUncheckedIndexedAccessCandidate);if(t)return t}var r=Ul(e.objectType);if(r&&r!==e.objectType)return sm(r,e.indexType,e.noUncheckedIndexedAccessCandidate)}function jl(e){if(!e.resolvedDefaultConstraint){var n=gm(e),t=_m(e);e.resolvedDefaultConstraint=ko(n)?t:ko(t)?n:Qp([n,t])}return e.resolvedDefaultConstraint}function Kl(e){if(e.root.isDistributive&&e.restrictiveInstantiation!==e){var n=Qf(e.checkType,!1),t=n===e.checkType?Fl(n):n;if(t&&t!==e.checkType){var r=L_(e,s_(e.root.checkType,t,e.mapper));if(!(131072&r.flags))return r}}}function Hl(e){return Kl(e)||jl(e)}function Wl(e){return Xl(e)?Hl(e):void 0}function zl(n,t){for(var r,a=!1,i=0,o=n;i<o.length;i++){var s=o[i];if(465829888&s.flags){var c=Fl(s);while(c&&21233664&c.flags)c=Fl(c);c&&(r=e.append(r,c),t&&(r=e.append(r,s)))}else 469892092&s.flags&&(a=!0)}if(r&&(t||a)){if(a)for(var l=0,u=n;l<u.length;l++){s=u[l];469892092&s.flags&&(r=e.append(r,s))}return pf(r)}}function ql(e){if(464781312&e.flags){var n=Yl(e);return n!==dn&&n!==pn?n:void 0}return 4194304&e.flags?$e:void 0}function Jl(e){return ql(e)||e}function Xl(e){return Yl(e)!==pn}function Yl(n){if(n.resolvedBaseConstraint)return n.resolvedBaseConstraint;var t=[];return n.resolvedBaseConstraint=Fc(r(n),n);function r(n){if(!n.immediateBaseConstraint){if(!So(n,4))return pn;var r=void 0;if((t.length<10||t.length<50&&!Yg(n,t,t.length))&&(t.push(n),r=i(Qf(n,!1)),t.pop()),!Do()){if(262144&n.flags){var a=pd(n);if(a){var o=gr(a,e.Diagnostics.Type_parameter_0_has_a_circular_constraint,io(n));!d||e.isNodeDescendantOf(a,d)||e.isNodeDescendantOf(d,a)||e.addRelatedInfo(o,e.createDiagnosticForNode(d,e.Diagnostics.Circularity_originates_in_type_at_this_location))}}r=pn}n.immediateBaseConstraint=r||dn}return n.immediateBaseConstraint}function a(e){var n=r(e);return n!==dn&&n!==pn?n:void 0}function i(n){if(262144&n.flags){var t=md(n);return n.isThisType||!t?t:a(t)}if(3145728&n.flags){for(var r=n.types,i=[],o=!1,s=0,c=r;s<c.length;s++){var l=c[s],u=a(l);u?(u!==l&&(o=!0),i.push(u)):o=!0}return o?1048576&n.flags&&i.length===r.length?Qp(i):2097152&n.flags&&i.length?pf(i):void 0:n}if(4194304&n.flags)return $e;if(134217728&n.flags){r=n.types;var d=e.mapDefined(r,a);return d.length===r.length?Of(n.texts,d):Me}if(268435456&n.flags){t=a(n.type);return t?Mf(n.symbol,t):Me}if(8388608&n.flags){var p=a(n.objectType),f=a(n.indexType),m=p&&f&&sm(p,f,n.noUncheckedIndexedAccessCandidate);return m&&a(m)}if(16777216&n.flags){t=Hl(n);return t&&a(t)}return 33554432&n.flags?a(n.substitute):n}}function Ql(e){return e.resolvedApparentType||(e.resolvedApparentType=Fc(e,e,!0))}function Zl(n){if(n.default)n.default===fn&&(n.default=pn);else if(n.target){var t=Zl(n.target);n.default=t?A_(t,n.mapper):dn}else{n.default=fn;var r=n.symbol&&e.forEach(n.symbol.declarations,(function(n){return e.isTypeParameterDeclaration(n)&&n.default})),a=r?zm(r):dn;n.default===fn&&(n.default=a)}return n.default}function $l(e){var n=Zl(e);return n!==dn&&n!==pn?n:void 0}function eu(e){return Zl(e)!==pn}function nu(n){return!(!n.symbol||!e.forEach(n.symbol.declarations,(function(n){return e.isTypeParameterDeclaration(n)&&n.default})))}function tu(e){return e.resolvedApparentType||(e.resolvedApparentType=ru(e))}function ru(e){var n=y_(e);if(n&&!e.declaration.nameType){var t=Gl(n);if(t&&(sy(t)||Cy(t)))return A_(e,s_(n,t,e.mapper))}return e}function au(n){var t=465829888&n.flags?ql(n)||Ne:n;return 32&e.getObjectFlags(t)?tu(t):2097152&t.flags?Ql(t):402653316&t.flags?Dn:296&t.flags?An:2112&t.flags?yp(F>=7):528&t.flags?Cn:12288&t.flags?$d(F>=2):67108864&t.flags?an:4194304&t.flags?$e:2&t.flags&&!z?an:t}function iu(e){return lu(au(lu(e)))}function ou(n,t,r){for(var a,i,o,s,c,l=1048576&n.flags,u=l?0:16777216,d=4,p=0,f=!1,m=0,_=n.types;m<_.length;m++){var g=_[m],y=au(g);if(!(y===Ae||131072&y.flags)){var h=_u(y,t,r),v=h?e.getDeclarationModifierFlagsFromSymbol(h):0;if(h){if(l?u|=16777216&h.flags:u&=h.flags,o){if(h!==o){var b=(AN(h)||h)===(AN(o)||o);if(b&&-1===$g(o,h,(function(e,n){return e===n?-1:0})))f=!!o.parent&&!!e.length(Vs(o.parent));else{s||(s=new e.Map,s.set(P(o),o));var E=P(h);s.has(E)||s.set(E,h)}}}else o=h;p|=(gD(h)?8:0)|(24&v?0:256)|(16&v?512:0)|(8&v?1024:0)|(32&v?2048:0),sS(h)||(d=2)}else if(l){var T=!Ac(t)&&(bT(t)&&bu(y,1)||bu(y,0));T?(p|=32|(T.isReadonly?8:0),c=e.append(c,Cy(y)?ky(y)||ke:T.type)):!Jh(y)||4194304&e.getObjectFlags(y)?p|=16:(p|=32,c=e.append(c,ke))}}}if(o&&!(l&&(s||48&p)&&1536&p)){if(!s&&!(16&p)&&!c){if(f){var S=Zy(o,o.type);return S.parent=null===(i=null===(a=o.valueDeclaration)||void 0===a?void 0:a.symbol)||void 0===i?void 0:i.parent,S.containingType=n,S.mapper=o.mapper,S}return o}for(var x,L,D,A,C=s?e.arrayFrom(s.values()):[o],I=[],N=!1,k=0,R=C;k<R.length;k++){h=R[k];A?h.valueDeclaration&&h.valueDeclaration!==A&&(N=!0):A=h.valueDeclaration,x=e.addRange(x,h.declarations);y=ws(h);L?y!==L&&(p|=64):(L=y,D=wr(h).nameType),Ey(y)&&(p|=128),131072&y.flags&&(p|=131072),I.push(y)}e.addRange(I,c);var O=Sr(4|u,t,d|p);return O.containingType=n,!N&&A&&(O.valueDeclaration=A,A.symbol.parent&&(O.parent=A.symbol.parent)),O.declarations=x,O.nameType=D,I.length>2?(O.checkFlags|=65536,O.deferralParent=n,O.deferralConstituents=I):O.type=l?Qp(I):pf(I),O}}function su(n,t,r){var a,i,o=(null===(a=n.propertyCacheWithoutObjectFunctionPropertyAugment)||void 0===a?void 0:a.get(t))||!r?null===(i=n.propertyCache)||void 0===i?void 0:i.get(t):void 0;if(!o&&(o=ou(n,t,r),o)){var s=r?n.propertyCacheWithoutObjectFunctionPropertyAugment||(n.propertyCacheWithoutObjectFunctionPropertyAugment=e.createSymbolTable()):n.propertyCache||(n.propertyCache=e.createSymbolTable());s.set(t,o)}return o}function cu(n,t,r){var a=su(n,t,r);return!a||16&e.getCheckFlags(a)?void 0:a}function lu(n){return 1048576&n.flags&&67108864&n.objectFlags?n.resolvedReducedType||(n.resolvedReducedType=uu(n)):2097152&n.flags?(67108864&n.objectFlags||(n.objectFlags|=67108864|(e.some(Ol(n),du)?134217728:0)),134217728&n.objectFlags?ze:n):n}function uu(n){var t=e.sameMap(n.types,lu);if(t===n.types)return n;var r=Qp(t);return 1048576&r.flags&&(r.resolvedReducedType=r),r}function du(e){return pu(e)||fu(e)}function pu(n){return!(16777216&n.flags)&&192===(131264&e.getCheckFlags(n))&&!!(131072&ws(n).flags)}function fu(n){return!n.valueDeclaration&&!!(1024&e.getCheckFlags(n))}function mu(n,t){if(2097152&t.flags&&134217728&e.getObjectFlags(t)){var r=e.find(Ol(t),pu);if(r)return e.chainDiagnosticMessages(n,e.Diagnostics.The_intersection_0_was_reduced_to_never_because_property_1_has_conflicting_types_in_some_constituents,io(t,void 0,536870912),ro(r));var a=e.find(Ol(t),fu);if(a)return e.chainDiagnosticMessages(n,e.Diagnostics.The_intersection_0_was_reduced_to_never_because_property_1_exists_in_multiple_constituents_and_is_private_in_some,io(t,void 0,536870912),ro(a))}return n}function _u(e,n,t){if(e=iu(e),524288&e.flags){var r=Nl(e),a=r.members.get(n);if(a&&Di(a))return a;if(t)return;var i=r===un?En:r.callSignatures.length?Tn:r.constructSignatures.length?Sn:void 0;if(i){var o=Rl(i,n);if(o)return o}return Rl(bn,n)}if(3145728&e.flags)return cu(e,n,t)}function gu(n,t){if(3670016&n.flags){var r=Nl(n);return 0===t?r.callSignatures:r.constructSignatures}return e.emptyArray}function yu(e,n){return gu(iu(e),n)}function hu(e,n){if(3670016&e.flags){var t=Nl(e);return 0===n?t.stringIndexInfo:t.numberIndexInfo}}function vu(e,n){var t=hu(e,n);return t&&t.type}function bu(e,n){return hu(iu(e),n)}function Eu(e,n){return vu(iu(e),n)}function Tu(n,t){if(Qy(n)){for(var r=[],a=0,i=wl(n);a<i.length;a++){var o=i[a];if(0===t||bT(o.escapedName)){var s=ws(o);r.push(16777216&o.flags?Lv(s,524288):s)}}if(0===t&&e.append(r,Eu(n,1)),r.length)return Qp(r)}}function Su(n){for(var t,r=0,a=e.getEffectiveTypeParameterDeclarations(n);r<a.length;r++){var i=a[r];t=e.appendIfUnique(t,pc(i.symbol))}return t}function xu(e){var n=[];return e.forEach((function(e,t){Pi(t)||n.push(e)})),n}function Lu(n){return e.isInJSFile(n)&&(n.type&&308===n.type.kind||e.getJSDocParameterTags(n).some((function(e){var n=e.isBracketed,t=e.typeExpression;return n||!!t&&308===t.type.kind})))}function Du(n,t){if(!e.isExternalModuleNameRelative(n)){var r=Fr(re,'"'+n+'"',512);return r&&t?gi(r):r}}function Au(n){if(e.hasQuestionToken(n)||Iu(n)||Lu(n))return!0;if(n.initializer){var t=Ou(n.parent),r=n.parent.parameters.indexOf(n);return e.Debug.assert(r>=0),r>=UL(t,3)}var a=e.getImmediatelyInvokedFunctionExpression(n.parent);return!!a&&(!n.type&&!n.dotDotDotToken&&n.parent.parameters.indexOf(n)>=a.arguments.length)}function Cu(n){return e.isPropertyDeclaration(n)&&n.questionToken}function Iu(n){if(!e.isJSDocPropertyLikeTag(n))return!1;var t=n.isBracketed,r=n.typeExpression;return t||!!r&&308===r.type.kind}function Nu(e,n,t,r){return{kind:e,parameterName:n,parameterIndex:t,type:r}}function ku(e){var n=0;if(e)for(var t=0;t<e.length;t++)nu(e[t])||(n=t+1);return n}function Ru(n,t,r,a){var i=e.length(t);if(!i)return[];var o=e.length(n);if(a||o>=r&&o<=i){for(var s=n?n.slice():[],c=o;c<i;c++)s[c]=Ae;var l=ev(a);for(c=o;c<i;c++){var u=$l(t[c]);a&&u&&(U_(u,Ne)||U_(u,an))&&(u=xe),s[c]=u?A_(u,Qm(t,s)):l}return s.length=t.length,s}return n&&n.slice()}function Ou(n){var t=Pr(n);if(!t.resolvedSignature){var r=[],a=0,i=0,o=void 0,s=!1,c=e.getImmediatelyInvokedFunctionExpression(n),l=e.isJSDocConstructSignature(n),u=!c&&e.isInJSFile(n)&&e.isValueSignatureDeclaration(n)&&!e.hasJSDocParameterTags(n)&&!e.getJSDocType(n);u&&(a|=32);for(var d=l?1:0;d<n.parameters.length;d++){var p=n.parameters[d],f=p.symbol,m=e.isJSDocParameterTag(p)?p.typeExpression&&p.typeExpression.type:p.type;if(f&&4&f.flags&&!e.isBindingPattern(p.name)){var _=Vr(p,f.escapedName,111551,void 0,void 0,!1);f=_}0===d&&"this"===f.escapedName?(s=!0,o=p.symbol):r.push(f),m&&192===m.kind&&(a|=2);var g=Iu(p)||p.initializer||p.questionToken||p.dotDotDotToken||c&&r.length>c.arguments.length&&!m||Lu(p);g||(i=r.length)}if((168===n.kind||169===n.kind)&&Ic(n)&&(!s||!o)){var y=168===n.kind?169:168,h=e.getDeclarationOfKind(yi(n),y);h&&(o=vs(h))}var v=167===n.kind?ac(gi(n.parent.symbol)):void 0,b=v?v.localTypeParameters:Su(n);(e.hasRestParameter(n)||e.isInJSFile(n)&&wu(n,r))&&(a|=1),(e.isConstructorTypeNode(n)&&e.hasSyntacticModifier(n,128)||e.isConstructorDeclaration(n)&&e.hasSyntacticModifier(n.parent,128))&&(a|=4),t.resolvedSignature=Vc(n,b,o,r,void 0,void 0,i,a)}return t.resolvedSignature}function wu(n,t){if(e.isJSDocSignature(n)||!Fu(n))return!1;var r=e.lastOrUndefined(n.parameters),a=r?e.getJSDocParameterTags(r):e.getJSDocTags(n).filter(e.isJSDocParameterTag),i=e.firstDefined(a,(function(n){return n.typeExpression&&e.isJSDocVariadicType(n.typeExpression.type)?n.typeExpression.type:void 0})),o=Sr(3,"args",32768);return o.type=i?Ep(zm(i.type)):kn,i&&t.pop(),t.push(o),!0}function Pu(n){if(e.isInJSFile(n)&&e.isFunctionLikeDeclaration(n)){var t=e.getJSDocTypeTag(n);return(null===t||void 0===t?void 0:t.typeExpression)&&mx(zm(t.typeExpression))}}function Mu(e){var n=Pu(e);return n&&Hu(n)}function Fu(n){var t=Pr(n);return void 0===t.containsArgumentsReference&&(8192&t.flags?t.containsArgumentsReference=!0:t.containsArgumentsReference=r(n.body)),t.containsArgumentsReference;function r(n){if(!n)return!1;switch(n.kind){case 78:return n.escapedText===se.escapedName&&rv(n)===se;case 164:case 166:case 168:case 169:return 159===n.name.kind&&r(n.name);case 202:case 203:return r(n.expression);default:return!e.nodeStartsNewLexicalEnvironment(n)&&!e.isPartOfTypeNode(n)&&!!e.forEachChild(n,r)}}}function Gu(n){if(!n||!n.declarations)return e.emptyArray;for(var t=[],r=0;r<n.declarations.length;r++){var a=n.declarations[r];if(e.isFunctionLike(a)){if(r>0&&a.body){var i=n.declarations[r-1];if(a.parent===i.parent&&a.kind===i.kind&&a.pos===i.end)continue}t.push(Ou(a))}}return t}function Bu(e){var n=Za(e,e);if(n){var t=ri(n);if(t)return ws(t)}return xe}function Uu(e){if(e.thisParameter)return ws(e.thisParameter)}function Vu(n){if(!n.resolvedTypePredicate){if(n.target){var t=Vu(n.target);n.resolvedTypePredicate=t?d_(t,n.mapper):dt}else if(n.compositeSignatures)n.resolvedTypePredicate=Zp(n.compositeSignatures,n.compositeKind)||dt;else{var r=n.declaration&&e.getEffectiveReturnTypeNode(n.declaration),a=void 0;if(!r&&e.isInJSFile(n.declaration)){var i=Pu(n.declaration);i&&n!==i&&(a=Vu(i))}n.resolvedTypePredicate=r&&e.isTypePredicateNode(r)?ju(r,n):a||dt}e.Debug.assert(!!n.resolvedTypePredicate)}return n.resolvedTypePredicate===dt?void 0:n.resolvedTypePredicate}function ju(n,t){var r=n.parameterName,a=n.type&&zm(n.type);return 188===r.kind?Nu(n.assertsModifier?2:0,void 0,void 0,a):Nu(n.assertsModifier?3:1,r.escapedText,e.findIndex(t.parameters,(function(e){return e.escapedName===r.escapedText})),a)}function Ku(e,n,t){return 2097152!==n?Qp(e,t):pf(e)}function Hu(n){if(!n.resolvedReturnType){if(!So(n,3))return Ae;var t=n.target?A_(Hu(n.target),n.mapper):n.compositeSignatures?A_(Ku(e.map(n.compositeSignatures,Hu),n.compositeKind,2),n.mapper):Wu(n.declaration)||(e.nodeIsMissing(n.declaration.body)?xe:eD(n.declaration));if(8&n.flags?t=Wy(t):16&n.flags&&(t=jy(t)),!Do()){if(n.declaration){var r=e.getEffectiveReturnTypeNode(n.declaration);if(r)gr(r,e.Diagnostics.Return_type_annotation_circularly_references_itself);else if(Y){var a=n.declaration,i=e.getNameOfDeclaration(a);i?gr(i,e.Diagnostics._0_implicitly_has_return_type_any_because_it_does_not_have_a_return_type_annotation_and_is_referenced_directly_or_indirectly_in_one_of_its_return_expressions,e.declarationNameToString(i)):gr(a,e.Diagnostics.Function_implicitly_has_return_type_any_because_it_does_not_have_a_return_type_annotation_and_is_referenced_directly_or_indirectly_in_one_of_its_return_expressions)}}t=xe}n.resolvedReturnType=t}return n.resolvedReturnType}function Wu(n){if(167===n.kind)return ac(gi(n.parent.symbol));if(e.isJSDocConstructSignature(n))return zm(n.parameters[0].type);var t=e.getEffectiveReturnTypeNode(n);if(t)return zm(t);if(168===n.kind&&Ic(n)){var r=e.isInJSFile(n)&&jo(n);if(r)return r;var a=e.getDeclarationOfKind(yi(n),169),i=hs(a);if(i)return i}return Mu(n)}function zu(e){return!e.resolvedReturnType&&xo(e,3)>=0}function qu(e){return Ju(e)||xe}function Ju(e){if(j(e)){var n=ws(e.parameters[e.parameters.length-1]),t=Cy(n)?ky(n):n;return t&&Eu(t,1)}}function Xu(e,n,t,r){var a=Yu(e,Ru(n,e.typeParameters,ku(e.typeParameters),t));if(r){var i=_x(Hu(a));if(i){var o=jc(i);o.typeParameters=r;var s=jc(a);return s.resolvedReturnType=ad(o),s}}return a}function Yu(n,t){var r=n.instantiations||(n.instantiations=new e.Map),a=gd(t),i=r.get(a);return i||r.set(a,i=Qu(n,t)),i}function Qu(e,n){return p_(e,Zu(e,n),!0)}function Zu(e,n){return Qm(e.typeParameters,n)}function $u(e){return e.typeParameters?e.erasedSignatureCache||(e.erasedSignatureCache=ed(e)):e}function ed(e){return p_(e,r_(e.typeParameters),!0)}function nd(e){return e.typeParameters?e.canonicalSignatureCache||(e.canonicalSignatureCache=td(e)):e}function td(n){return Xu(n,e.map(n.typeParameters,(function(e){return e.target&&!Gl(e.target)?e.target:e})),e.isInJSFile(n.declaration))}function rd(n){var t=n.typeParameters;if(t){if(n.baseSignatureCache)return n.baseSignatureCache;for(var r=r_(t),a=Qm(t,e.map(t,(function(e){return Gl(e)||Ne}))),i=e.map(t,(function(e){return A_(e,a)||Ne})),o=0;o<t.length-1;o++)i=Xm(i,a);return i=Xm(i,r),n.baseSignatureCache=p_(n,Qm(t,i),!0)}return n}function ad(n){if(!n.isolatedSignatureType){var t=n.declaration?n.declaration.kind:0,r=167===t||171===t||176===t,a=Ri(16);a.members=D,a.properties=e.emptyArray,a.callSignatures=r?e.emptyArray:[n],a.constructSignatures=r?[n]:e.emptyArray,n.isolatedSignatureType=a}return n.isolatedSignatureType}function id(e){return e.members?od(e.members):void 0}function od(e){return e.get("__index")}function sd(e,n){var t=e&&id(e);return t&&ld(t,n)}function cd(e,n){var t=e&&od(e);return t&&ld(t,n)}function ld(n,t){var r=1===t?144:147;if(null===n||void 0===n?void 0:n.declarations)for(var a=0,i=n.declarations;a<i.length;a++){var o=i[a],s=e.cast(o,e.isIndexSignatureDeclaration);if(1===s.parameters.length){var c=s.parameters[0];if(c.type&&c.type.kind===r)return s}}}function ud(e,n,t){return{type:e,isReadonly:n,declaration:t}}function dd(n,t){var r=sd(n,t);if(r)return ud(r.type?zm(r.type):xe,e.hasEffectiveModifier(r,64),r)}function pd(n){return e.mapDefined(e.filter(n.symbol&&n.symbol.declarations,e.isTypeParameterDeclaration),e.getEffectiveConstraintOfTypeParameter)[0]}function fd(n){var t,r;if(null===(t=n.symbol)||void 0===t?void 0:t.declarations)for(var a=0,i=n.symbol.declarations;a<i.length;a++){var o=i[a];if(186===o.parent.kind){var s=e.walkUpParenthesizedTypesAndGetParentAndChild(o.parent.parent),c=s[0],l=void 0===c?o.parent:c,u=s[1];if(174===u.kind){var d=u,p=WA(d);if(p){var f=d.typeArguments.indexOf(l);if(f<p.length){var m=Gl(p[f]);if(m){var _=Qm(p,KA(d,p)),g=A_(m,_);g!==n&&(r=e.append(r,g))}}}}else if(161===u.kind&&u.dotDotDotToken||182===u.kind||193===u.kind&&u.dotDotDotToken)r=e.append(r,Ep(Ne));else if(195===u.kind)r=e.append(r,Me);else if(160===u.kind&&191===u.parent.kind)r=e.append(r,$e);else if(191===u.kind&&u.type&&e.skipParentheses(u.type)===o.parent&&185===u.parent.kind&&u.parent.extendsType===u&&191===u.parent.checkType.kind&&u.parent.checkType.type){var y=u.parent.checkType,h=zm(y.type);r=e.append(r,A_(h,$m(pc(yi(y.typeParameter)),y.typeParameter.constraint?zm(y.typeParameter.constraint):$e)))}}}return r&&pf(r)}function md(e){if(!e.constraint)if(e.target){var n=Gl(e.target);e.constraint=n?A_(n,e.mapper):dn}else{var t=pd(e);if(t){var r=zm(t);1&r.flags&&r!==Ae&&(r=191===t.parent.parent.kind?$e:Ne),e.constraint=r}else e.constraint=fd(e)||dn}return e.constraint===dn?void 0:e.constraint}function _d(n){var t=e.getDeclarationOfKind(n.symbol,160),r=e.isJSDocTemplateTag(t.parent)?e.getHostSignatureFromJSDoc(t.parent):t.parent;return r&&yi(r)}function gd(e){var n="";if(e){var t=e.length,r=0;while(r<t){var a=e[r].id,i=1;while(r+i<t&&e[r+i].id===a+i)i++;n.length&&(n+=","),n+=a,i>1&&(n+=":"+i),r+=i}}return n}function yd(e,n){return e?"@"+P(e)+(n?":"+gd(n):""):""}function hd(n,t){for(var r=0,a=0,i=n;a<i.length;a++){var o=i[a];o.flags&t||(r|=e.getObjectFlags(o))}return 917504&r}function vd(e,n){var t=gd(n),r=e.instantiations.get(t);return r||(r=Ri(4,e.symbol),e.instantiations.set(t,r),r.objectFlags|=n?hd(n,0):0,r.target=e,r.resolvedTypeArguments=n),r}function bd(e){var n=Ci(e.flags);return n.symbol=e.symbol,n.objectFlags=e.objectFlags,n.target=e.target,n.resolvedTypeArguments=e.resolvedTypeArguments,n}function Ed(e,n,t,r,a){if(!r){r=xm(n);var i=Lm(r);a=t?Xm(i,t):i}var o=Ri(4,e.symbol);return o.target=e,o.node=n,o.mapper=t,o.aliasSymbol=r,o.aliasTypeArguments=a,o}function Td(n){var t,r;if(!n.resolvedTypeArguments){if(!So(n,6))return(null===(t=n.target.localTypeParameters)||void 0===t?void 0:t.map((function(){return Ae})))||e.emptyArray;var a=n.node,i=a?174===a.kind?e.concatenate(n.target.outerTypeParameters,KA(a,n.target.localTypeParameters)):179===a.kind?[zm(a.elementType)]:e.map(a.elements,zm):e.emptyArray;Do()?n.resolvedTypeArguments=n.mapper?Xm(i,n.mapper):i:(n.resolvedTypeArguments=(null===(r=n.target.localTypeParameters)||void 0===r?void 0:r.map((function(){return Ae})))||e.emptyArray,gr(n.node||d,n.target.symbol?e.Diagnostics.Type_arguments_for_0_circularly_reference_themselves:e.Diagnostics.Tuple_type_arguments_circularly_reference_themselves,n.target.symbol&&ro(n.target.symbol)))}return n.resolvedTypeArguments}function Sd(n){return e.length(n.target.typeParameters)}function xd(n,t){var r=mc(gi(t)),a=r.localTypeParameters;if(a){var i=e.length(n.typeArguments),o=ku(a),s=e.isInJSFile(n),c=!Y&&s;if(!c&&(i<o||i>a.length)){var l=s&&e.isExpressionWithTypeArguments(n)&&!e.isJSDocAugmentsTag(n.parent),u=o===a.length?l?e.Diagnostics.Expected_0_type_arguments_provide_these_with_an_extends_tag:e.Diagnostics.Generic_type_0_requires_1_type_argument_s:l?e.Diagnostics.Expected_0_1_type_arguments_provide_these_with_an_extends_tag:e.Diagnostics.Generic_type_0_requires_between_1_and_2_type_arguments,d=io(r,void 0,2);if(gr(n,u,d,o,a.length),!s)return Ae}if(174===n.kind&&Lp(n,e.length(n.typeArguments)!==a.length))return Ed(r,n,void 0);var p=e.concatenate(r.outerTypeParameters,Ru(Vd(n),a,o,s));return vd(r,p)}return Fd(n,t)?r:Ae}function Ld(n,t,r,a){var i=mc(n);if(i===Ie&&k.has(n.escapedName)&&t&&1===t.length)return Mf(n,t[0]);var o=wr(n),s=o.typeParameters,c=gd(t)+yd(r,a),l=o.instantiations.get(c);return l||o.instantiations.set(c,l=C_(i,Qm(s,Ru(t,s,ku(s),e.isInJSFile(n.valueDeclaration))),r,a)),l}function Dd(n,t){var r=mc(t),a=wr(t).typeParameters;if(a){var i=e.length(n.typeArguments),o=ku(a);if(i<o||i>a.length)return gr(n,o===a.length?e.Diagnostics.Generic_type_0_requires_1_type_argument_s:e.Diagnostics.Generic_type_0_requires_between_1_and_2_type_arguments,ro(t),o,a.length),Ae;var s=xm(n),c=!s||!Ad(t)&&Ad(s)?void 0:s;return Ld(t,Vd(n),c,Lm(c))}return Fd(n,t)?r:Ae}function Ad(n){var t,r=null===(t=n.declarations)||void 0===t?void 0:t.find(e.isTypeAlias);return!(!r||!e.getContainingFunction(r))}function Cd(n){switch(n.kind){case 174:return n.typeName;case 224:var t=n.expression;if(e.isEntityNameExpression(t))return t}}function Id(e,n,t){return e&&qa(e,n,t)||Te}function Nd(e,n){if(n===Te)return Ae;if(n=Qa(n)||n,96&n.flags)return xd(e,n);if(524288&n.flags)return Dd(e,n);var t=_c(n);if(t)return Fd(e,n)?Pm(t):Ae;if(111551&n.flags&&Md(e)){var r=kd(e,n);return r||(Id(Cd(e),788968),ws(n))}return Ae}function kd(e,n){var t=Pr(e);if(!t.resolvedJSDocType){var r=ws(n),a=r;if(n.valueDeclaration){var i=196===e.kind&&e.qualifier;r.symbol&&r.symbol!==n&&i&&(a=Nd(e,r.symbol))}t.resolvedJSDocType=a}return t.resolvedJSDocType}function Rd(e,n){if(3&n.flags||n===e)return e;var t=Up(e)+">"+Up(n),r=he.get(t);if(r)return r;var a=Ci(33554432);return a.baseType=e,a.substitute=n,he.set(t,a),a}function Od(e){return 180===e.kind&&1===e.elements.length}function wd(e,n,t){return Od(n)&&Od(t)?wd(e,n.elements[0],t.elements[0]):um(zm(n))===e?zm(t):void 0}function Pd(n,t){var r,a=!0;while(t&&!e.isStatement(t)&&312!==t.kind){var i=t.parent;if(161===i.kind&&(a=!a),(a||8650752&n.flags)&&185===i.kind&&t===i.trueType){var o=wd(n,i.checkType,i.extendsType);o&&(r=e.append(r,o))}t=i}return r?Rd(n,pf(e.append(r,n))):n}function Md(e){return!!(4194304&e.flags)&&(174===e.kind||196===e.kind)}function Fd(n,t){return!n.typeArguments||(gr(n,e.Diagnostics.Type_0_is_not_generic,t?ro(t):n.typeName?e.declarationNameToString(n.typeName):l),!1)}function Gd(n){if(e.isIdentifier(n.typeName)){var t=n.typeArguments;switch(n.typeName.escapedText){case"String":return Fd(n),Me;case"Number":return Fd(n),Fe;case"Boolean":return Fd(n),Ke;case"Void":return Fd(n),We;case"Undefined":return Fd(n),ke;case"Null":return Fd(n),we;case"Function":case"function":return Fd(n),En;case"array":return t&&t.length||Y?void 0:kn;case"promise":return t&&t.length||Y?void 0:QL(xe);case"Object":if(t&&2===t.length){if(e.isJSDocIndexSignature(n)){var r=zm(t[0]),a=zm(t[1]),i=ud(a,!1);return Bi(void 0,D,e.emptyArray,e.emptyArray,r===Me?i:void 0,r===Fe?i:void 0)}return xe}return Fd(n),Y?void 0:xe}}}function Bd(e){var n=zm(e.type);return z?Vy(n,65536):n}function Ud(n){var t=Pr(n);if(!t.resolvedType){if(e.isConstTypeReference(n)&&e.isAssertionExpression(n.parent))return t.resolvedSymbol=Te,t.resolvedType=$D(n.parent.expression);var r=void 0,a=void 0,i=788968;Md(n)&&(a=Gd(n),a||(r=Id(Cd(n),i,!0),r===Te?r=Id(Cd(n),111551|i):Id(Cd(n),i),a=Nd(n,r))),a||(r=Id(Cd(n),i),a=Nd(n,r)),t.resolvedSymbol=r,t.resolvedType=a}return t.resolvedType}function Vd(n){return e.map(n.typeArguments,zm)}function jd(e){var n=Pr(e);return n.resolvedType||(n.resolvedType=Pm(sh(TA(e.exprName)))),n.resolvedType}function Kd(n,t){function r(e){var n=e.declarations;if(n)for(var t=0,r=n;t<r.length;t++){var a=r[t];switch(a.kind){case 253:case 254:case 256:return a}}}if(!n)return t?ln:an;var a=mc(n);return 524288&a.flags?e.length(a.typeParameters)!==t?(gr(r(n),e.Diagnostics.Global_type_0_must_have_1_type_parameter_s,e.symbolName(n),t),t?ln:an):a:(gr(r(n),e.Diagnostics.Global_type_0_must_be_a_class_or_interface_type,e.symbolName(n)),t?ln:an)}function Hd(n,t){return zd(n,111551,t?e.Diagnostics.Cannot_find_global_value_0:void 0)}function Wd(n,t){return zd(n,788968,t?e.Diagnostics.Cannot_find_global_type_0:void 0)}function zd(e,n,t){return Vr(void 0,e,n,t,e,!1)}function qd(e,n,t){var r=Wd(e,t);return r||t?Kd(r,n):void 0}function Jd(){return Gn||(Gn=qd("TypedPropertyDescriptor",1,!0))||ln}function Xd(){return $n||($n=qd("TemplateStringsArray",0,!0))||an}function Yd(){return et||(et=qd("ImportMeta",0,!0))||an}function Qd(e){return Pn||(Pn=Hd("Symbol",e))}function Zd(e){return Mn||(Mn=Wd("SymbolConstructor",e))}function $d(e){return Fn||(Fn=qd("Symbol",0,e))||an}function ep(e){return Bn||(Bn=qd("Promise",1,e))||ln}function np(e){return Un||(Un=qd("PromiseLike",1,e))||ln}function tp(e){return Vn||(Vn=Hd("Promise",e))}function rp(e){return jn||(jn=qd("PromiseConstructorLike",0,e))||an}function ap(e){return Xn||(Xn=qd("AsyncIterable",1,e))||ln}function ip(e){return Yn||(Yn=qd("AsyncIterator",3,e))||ln}function op(e){return Qn||(Qn=qd("AsyncIterableIterator",1,e))||ln}function sp(e){return Zn||(Zn=qd("AsyncGenerator",3,e))||ln}function cp(e){return Kn||(Kn=qd("Iterable",1,e))||ln}function lp(e){return Hn||(Hn=qd("Iterator",3,e))||ln}function up(e){return Wn||(Wn=qd("IterableIterator",1,e))||ln}function dp(e){return zn||(zn=qd("Generator",3,e))||ln}function pp(e){return qn||(qn=qd("IteratorYieldResult",1,e))||ln}function fp(e){return Jn||(Jn=qd("IteratorReturnResult",1,e))||ln}function mp(e,n){void 0===n&&(n=0);var t=zd(e,788968,void 0);return t&&Kd(t,n)}function _p(){return nt||(nt=zd("Extract",524288,e.Diagnostics.Cannot_find_global_type_0))}function gp(){return tt||(tt=zd("Omit",524288,e.Diagnostics.Cannot_find_global_type_0))}function yp(e){return rt||(rt=qd("BigInt",0,e))||an}function hp(e,n){return e!==ln?vd(e,n):an}function vp(e){return hp(Jd(),[e])}function bp(e){return hp(cp(!0),[e])}function Ep(e,n){return hp(n?Ln:xn,[e])}function Tp(e){switch(e.kind){case 181:return 2;case 182:return Sp(e);case 193:return e.questionToken?2:e.dotDotDotToken?Sp(e):1;default:return 1}}function Sp(e){return Hm(e.type)?4:8}function xp(n){var t=Ip(n.parent),r=Hm(n);if(r)return t?Ln:xn;var a=e.map(n.elements,Tp),i=e.some(n.elements,(function(e){return 193!==e.kind}));return kp(a,t,i?void 0:n.elements)}function Lp(n,t){return!!xm(n)||Dp(n)&&(179===n.kind?Ap(n.elementType):180===n.kind?e.some(n.elements,Ap):t||e.some(n.typeArguments,Ap))}function Dp(e){var n=e.parent;switch(n.kind){case 187:case 193:case 174:case 183:case 184:case 190:case 185:case 189:case 179:case 180:return Dp(n);case 255:return!0}return!1}function Ap(n){switch(n.kind){case 174:return Md(n)||!!(524288&Id(n.typeName,788968).flags);case 177:return!0;case 189:return 151!==n.operator&&Ap(n.type);case 187:case 181:case 193:case 308:case 306:case 307:case 302:return Ap(n.type);case 182:return 179!==n.type.kind||Ap(n.type.elementType);case 183:case 184:return e.some(n.types,Ap);case 190:return Ap(n.objectType)||Ap(n.indexType);case 185:return Ap(n.checkType)||Ap(n.extendsType)||Ap(n.trueType)||Ap(n.falseType)}return!1}function Cp(n){var t=Pr(n);if(!t.resolvedType){var r=xp(n);if(r===ln)t.resolvedType=an;else if(180===n.kind&&e.some(n.elements,(function(e){return!!(8&Tp(e))}))||!Lp(n)){var a=179===n.kind?[zm(n.elementType)]:e.map(n.elements,zm);t.resolvedType=Op(r,a)}else t.resolvedType=180===n.kind&&0===n.elements.length?r:Ed(r,n,void 0)}return t.resolvedType}function Ip(n){return e.isTypeOperatorNode(n)&&142===n.operator}function Np(n,t,r,a){void 0===r&&(r=!1);var i=kp(t||e.map(n,(function(e){return 1})),r,a);return i===ln?an:n.length?Op(i,n):i}function kp(n,t,r){if(1===n.length&&4&n[0])return t?Ln:xn;var a=e.map(n,(function(e){return 1&e?"#":2&e?"?":4&e?".":"*"})).join()+(t?"R":"")+(r&&r.length?","+e.map(r,w).join(","):""),i=de.get(a);return i||de.set(a,i=Rp(n,t,r)),i}function Rp(n,t,r){var a,i=n.length,o=e.countWhere(n,(function(e){return!!(9&e)})),s=[],c=0;if(i){a=new Array(i);for(var l=0;l<i;l++){var u=a[l]=wi(),d=n[l];if(c|=d,!(12&c)){var p=Sr(4|(2&d?16777216:0),""+l,t?8:0);p.tupleLabelDeclaration=null===r||void 0===r?void 0:r[l],p.type=u,s.push(p)}}}var f=s.length,m=Sr(4,"length");if(12&c)m.type=Fe;else{var _=[];for(l=o;l<=i;l++)_.push(Fm(l));m.type=Qp(_)}s.push(m);var g=Ri(12);return g.typeParameters=a,g.outerTypeParameters=void 0,g.localTypeParameters=a,g.instantiations=new e.Map,g.instantiations.set(gd(g.typeParameters),g),g.target=g,g.resolvedTypeArguments=g.typeParameters,g.thisType=wi(),g.thisType.isThisType=!0,g.thisType.constraint=g,g.declaredProperties=s,g.declaredCallSignatures=e.emptyArray,g.declaredConstructSignatures=e.emptyArray,g.declaredStringIndexInfo=void 0,g.declaredNumberIndexInfo=void 0,g.elementFlags=n,g.minLength=o,g.fixedLength=f,g.hasRestElement=!!(12&c),g.combinedFlags=c,g.readonly=t,g.labeledElementDeclarations=r,g}function Op(e,n){return 8&e.objectFlags?wp(e,n):vd(e,n)}function wp(n,t){var r,a,i;if(!(14&n.combinedFlags))return vd(n,t);if(8&n.combinedFlags){var o=e.findIndex(t,(function(e,t){return!!(8&n.elementFlags[t]&&1179648&e.flags)}));if(o>=0)return mf(e.map(t,(function(e,t){return 8&n.elementFlags[t]?e:Ne})))?rb(t[o],(function(r){return wp(n,e.replaceElement(t,o,r))})):Ae}for(var s=[],c=[],l=[],u=-1,p=-1,f=-1,m=function(o){var c=t[o],l=n.elementFlags[o];if(8&l)if(58982400&c.flags||Il(c))h(c,8,null===(r=n.labeledElementDeclarations)||void 0===r?void 0:r[o]);else if(Cy(c)){var u=Td(c);if(u.length+s.length>=1e4)return gr(d,e.isPartOfTypeNode(d)?e.Diagnostics.Type_produces_a_tuple_type_that_is_too_large_to_represent:e.Diagnostics.Expression_produces_a_tuple_type_that_is_too_large_to_represent),{value:Ae};e.forEach(u,(function(e,n){var t;return h(e,c.target.elementFlags[n],null===(t=c.target.labeledElementDeclarations)||void 0===t?void 0:t[n])}))}else h(dy(c)&&Eu(c,1)||Ae,4,null===(a=n.labeledElementDeclarations)||void 0===a?void 0:a[o]);else h(c,l,null===(i=n.labeledElementDeclarations)||void 0===i?void 0:i[o])},_=0;_<t.length;_++){var g=m(_);if("object"===typeof g)return g.value}for(_=0;_<u;_++)2&c[_]&&(c[_]=1);p>=0&&p<f&&(s[p]=Qp(e.sameMap(s.slice(p,f+1),(function(e,n){return 8&c[p+n]?im(e,Fe):e}))),s.splice(p+1,f-p),c.splice(p+1,f-p),null===l||void 0===l||l.splice(p+1,f-p));var y=kp(c,n.readonly,l);return y===ln?an:c.length?vd(y,s):y;function h(e,n,t){1&n&&(u=c.length),4&n&&p<0&&(p=c.length),6&n&&(f=c.length),s.push(e),c.push(n),l&&t?l.push(t):l=void 0}}function Pp(n,t,r){void 0===r&&(r=0);var a=n.target,i=Sd(n)-r;return t>a.fixedLength?Ry(n)||Np(e.emptyArray):Np(Td(n).slice(t,i),a.elementFlags.slice(t,i),!1,a.labeledElementDeclarations&&a.labeledElementDeclarations.slice(t,i))}function Mp(n){return Qp(e.append(e.arrayOf(n.target.fixedLength,(function(e){return Fm(""+e)})),Cf(n.target.readonly?Ln:xn)))}function Fp(n,t){var r=e.findIndex(n.elementFlags,(function(e){return!(e&t)}));return r>=0?r:n.elementFlags.length}function Gp(n,t){return n.elementFlags.length-e.findLastIndex(n.elementFlags,(function(e){return!(e&t)}))-1}function Bp(e){var n=zm(e.type);return z?jy(n):n}function Up(e){return e.id}function Vp(n,t){return e.binarySearch(n,t,Up,e.compareValues)>=0}function jp(n,t){var r=e.binarySearch(n,t,Up,e.compareValues);return r<0&&(n.splice(~r,0,t),!0)}function Kp(n,t,r){var a=r.flags;if(1048576&a)return Hp(n,t|(Jp(r)?1048576:0),r.types);if(!(131072&a))if(t|=205258751&a,469499904&a&&(t|=262144),r===De&&(t|=8388608),!z&&98304&a)131072&e.getObjectFlags(r)||(t|=4194304);else{var i=n.length,o=i&&r.id>n[i-1].id?~i:e.binarySearch(n,r,Up,e.compareValues);o<0&&n.splice(~o,0,r)}return t}function Hp(e,n,t){for(var r=0,a=t;r<a.length;r++){var i=a[r];n=Kp(e,n,i)}return n}function Wp(n,t){var r=gd(n),a=ve.get(r);if(a)return a;var i=t&&e.some(n,(function(e){return!!(524288&e.flags)&&!Il(e)&&vg(Nl(e))})),o=n.length,s=o,c=0;while(s>0){s--;var l=n[s];if(i||469499904&l.flags)for(var u=61603840&l.flags?e.find(wl(l),(function(e){return hy(ws(e))})):void 0,p=u&&Pm(ws(u)),f=0,m=n;f<m.length;f++){var _=m[f];if(l!==_){if(1e5===c){var g=c/(o-s)*o;if(g>1e6)return null===e.tracing||void 0===e.tracing||e.tracing.instant("checkTypes","removeSubtypes_DepthLimit",{typeIds:n.map((function(e){return e.id}))}),void gr(d,e.Diagnostics.Expression_produces_a_union_type_that_is_too_complex_to_represent)}if(c++,u&&61603840&_.flags){var y=Io(_,u.escapedName);if(y&&hy(y)&&Pm(y)!==p)continue}if(Lg(l,_,or)&&(!(1&e.getObjectFlags(Ms(l)))||!(1&e.getObjectFlags(Ms(_)))||z_(l,_))){e.orderedRemoveItemAt(n,s);break}}}}return ve.set(r,n),n}function zp(n,t,r){var a=n.length;while(a>0){a--;var i=n[a],o=i.flags,s=128&o&&4&t||256&o&&8&t||2048&o&&64&t||8192&o&&4096&t||r&&32768&o&&16384&t||Mm(i)&&Vp(n,i.regularType);s&&e.orderedRemoveItemAt(n,a)}}function qp(n){var t=e.filter(n,qf);if(t.length){var r=n.length,a=function(){r--;var a=n[r];128&a.flags&&e.some(t,(function(e){return H_(a,e)}))&&e.orderedRemoveItemAt(n,r)};while(r>0)a()}}function Jp(e){return!!(1048576&e.flags&&(e.aliasSymbol||e.origin))}function Xp(n,t){for(var r=0,a=t;r<a.length;r++){var i=a[r];if(1048576&i.flags){var o=i.origin;i.aliasSymbol||o&&!(1048576&o.flags)?e.pushIfUnique(n,i):o&&1048576&o.flags&&Xp(n,o.types)}}}function Yp(e,n){var t=Ii(e);return t.types=n,t}function Qp(n,t,r,a,i){if(void 0===t&&(t=1),0===n.length)return ze;if(1===n.length)return n[0];var o=[],s=Hp(o,0,n);if(0!==t){if(3&s)return 1&s?8388608&s?De:xe:Ne;if((11136&s||16384&s&&32768&s)&&zp(o,s,!!(2&t)),128&s&&134217728&s&&qp(o),2===t&&(o=Wp(o,!!(524288&s)),!o))return Ae;if(0===o.length)return 65536&s?4194304&s?we:Pe:32768&s?4194304&s?ke:Re:ze}if(!i&&1048576&s){var c=[];Xp(c,n);for(var l=[],u=function(n){e.some(c,(function(e){return Vp(e.types,n)}))||l.push(n)},d=0,p=o;d<p.length;d++){var f=p[d];u(f)}if(!r&&1===c.length&&0===l.length)return c[0];var m=e.reduceLeft(c,(function(e,n){return e+n.types.length}),0);if(m+l.length===o.length){for(var _=0,g=c;_<g.length;_++){f=g[_];jp(l,f)}i=Yp(1048576,l)}}var y=(468598819&s?0:65536)|(2097152&s?67108864:0);return nf(o,y,r,a,i)}function Zp(e,n){for(var t,r=[],a=0,i=e;a<i.length;a++){var o=i[a],s=Vu(o);if(!s||2===s.kind||3===s.kind){if(2097152!==n)continue;return}if(t){if(!$p(t,s))return}else t=s;r.push(s.type)}if(t){var c=Ku(r,n);return Nu(t.kind,t.parameterName,t.parameterIndex,c)}}function $p(e,n){return e.kind===n.kind&&e.parameterIndex===n.parameterIndex}function ef(e,n,t,r){var a=Ci(1048576);return a.objectFlags=hd(e,98304),a.types=e,a.origin=r,a.aliasSymbol=n,a.aliasTypeArguments=t,a}function nf(e,n,t,r,a){if(0===e.length)return ze;if(1===e.length)return e[0];var i=a?1048576&a.flags?"|"+gd(a.types):2097152&a.flags?"&"+gd(a.types):"#"+a.type.id+"|"+gd(e):gd(e),o=i+yd(t,r),s=pe.get(o);return s||(s=ef(e,t,r,a),s.objectFlags|=n,pe.set(o,s)),s}function tf(n){var t=Pr(n);if(!t.resolvedType){var r=xm(n);t.resolvedType=Qp(e.map(n.types,zm),1,r,Lm(r))}return t.resolvedType}function rf(e,n,t){var r=t.flags;return 2097152&r?af(e,n,t.types):(Eg(t)?16777216&n||(n|=16777216,e.set(t.id.toString(),t)):(3&r?t===De&&(n|=8388608):!z&&98304&r||e.has(t.id.toString())||(109440&t.flags&&109440&n&&(n|=67108864),e.set(t.id.toString(),t)),n|=205258751&r),n)}function af(e,n,t){for(var r=0,a=t;r<a.length;r++){var i=a[r];n=rf(e,n,Pm(i))}return n}function of(n,t){var r=n.length;while(r>0){r--;var a=n[r],i=4&a.flags&&128&t||8&a.flags&&256&t||64&a.flags&&2048&t||4096&a.flags&&8192&t;i&&e.orderedRemoveItemAt(n,r)}}function sf(e,n){for(var t=0,r=e;t<r.length;t++){var a=r[t];if(!Vp(a.types,n)){var i=128&n.flags?Me:256&n.flags?Fe:2048&n.flags?Ge:8192&n.flags?He:void 0;if(!i||!Vp(a.types,i))return!1}}return!0}function cf(n){var t=n.length,r=e.filter(n,(function(e){return!!(128&e.flags)}));while(t>0){t--;var a=n[t];if(134217728&a.flags)for(var i=0,o=r;i<o.length;i++){var s=o[i];if(H_(s,a)){e.orderedRemoveItemAt(n,t);break}if(qf(a))return!0}}return!1}function lf(n,t){if(e.every(n,(function(n){return!!(1048576&n.flags)&&e.some(n.types,(function(e){return!!(e.flags&t)}))}))){for(var r=0;r<n.length;r++)n[r]=nb(n[r],(function(e){return!(e.flags&t)}));return!0}return!1}function uf(n){var t,r=e.findIndex(n,(function(n){return!!(65536&e.getObjectFlags(n))}));if(r<0)return!1;var a=r+1;while(a<n.length){var i=n[a];65536&e.getObjectFlags(i)?((t||(t=[n[r]])).push(i),e.orderedRemoveItemAt(n,a)):a++}if(!t)return!1;for(var o=[],s=[],c=0,l=t;c<l.length;c++)for(var u=l[c],d=0,p=u.types;d<p.length;d++){i=p[d];jp(o,i)&&sf(t,i)&&jp(s,i)}return n[r]=nf(s,65536),!0}function df(e,n,t){var r=Ci(2097152);return r.objectFlags=hd(e,98304),r.types=e,r.aliasSymbol=n,r.aliasTypeArguments=t,r}function pf(n,t,r){var a=new e.Map,i=af(a,0,n),o=e.arrayFrom(a.values());if(131072&i||z&&98304&i&&84410368&i||67108864&i&&402783228&i||402653316&i&&67238776&i||296&i&&469891796&i||2112&i&&469889980&i||12288&i&&469879804&i||49152&i&&469842940&i)return ze;if(134217728&i&&128&i&&cf(o))return ze;if(1&i)return 8388608&i?De:xe;if(!z&&98304&i)return 32768&i?ke:we;if((4&i&&128&i||8&i&&256&i||64&i&&2048&i||4096&i&&8192&i)&&of(o,i),16777216&i&&524288&i&&e.orderedRemoveItemAt(o,e.findIndex(o,Eg)),0===o.length)return Ne;if(1===o.length)return o[0];var s=gd(o)+yd(t,r),c=fe.get(s);if(!c){if(1048576&i)if(uf(o))c=pf(o,t,r);else if(lf(o,32768))c=Qp([pf(o),ke],1,t,r);else if(lf(o,65536))c=Qp([pf(o),we],1,t,r);else{if(!mf(o))return Ae;var l=_f(o),u=e.some(l,(function(e){return!!(2097152&e.flags)}))?Yp(2097152,o):void 0;c=Qp(l,1,t,r,u)}else c=df(o,t,r);fe.set(s,c)}return c}function ff(n){return e.reduceLeft(n,(function(e,n){return 1048576&n.flags?e*n.types.length:131072&n.flags?0:e}),1)}function mf(n){var t=ff(n);return!(t>=1e5)||(null===e.tracing||void 0===e.tracing||e.tracing.instant("checkTypes","checkCrossProductUnion_DepthLimit",{typeIds:n.map((function(e){return e.id})),size:t}),gr(d,e.Diagnostics.Expression_produces_a_union_type_that_is_too_complex_to_represent),!1)}function _f(e){for(var n=ff(e),t=[],r=0;r<n;r++){for(var a=e.slice(),i=r,o=e.length-1;o>=0;o--)if(1048576&e[o].flags){var s=e[o].types,c=s.length;a[o]=s[i%c],i=Math.floor(i/c)}var l=pf(a);131072&l.flags||t.push(l)}return t}function gf(n){var t=Pr(n);if(!t.resolvedType){var r=xm(n);t.resolvedType=pf(e.map(n.types,zm),r,Lm(r))}return t.resolvedType}function yf(e,n){var t=Ci(4194304);return t.type=e,t.stringsOnly=n,t}function hf(e){var n=Ii(4194304);return n.type=e,n}function vf(e,n){return n?e.resolvedStringIndexType||(e.resolvedStringIndexType=yf(e,!0)):e.resolvedIndexType||(e.resolvedIndexType=yf(e,!1))}function bf(e,n,t){return A_(e,c_(n.mapper,hl(n),t))}function Ef(n,t){var r=nb(vl(n),(function(e){return!(t&&5&e.flags)})),a=n.declaration.nameType&&zm(n.declaration.nameType),i=a&&$v(r,(function(e){return!!(131084&e.flags)}))&&wl(au(xl(n)));return a?Qp([rb(r,(function(e){return bf(a,n,e)})),rb(Qp(e.map(i||e.emptyArray,(function(e){return Lf(e,8576)}))),(function(e){return bf(a,n,e)}))]):r}function Tf(n){return!(!n||!(16777216&n.flags&&(!n.root.isDistributive||Tf(n.checkType))||137363456&n.flags&&e.some(n.types,Tf)||272629760&n.flags&&Tf(n.type)||8388608&n.flags&&Tf(n.indexType)||33554432&n.flags&&Tf(n.substitute)))}function Sf(n){return e.isPrivateIdentifier(n)?ze:e.isIdentifier(n)?Fm(e.unescapeLeadingUnderscores(n.escapedText)):Pm(e.isComputedPropertyName(n)?ET(n):TA(n))}function xf(n){return Fm({negative:!1,base10Value:e.parsePseudoBigInt(n.text)})}function Lf(n,t){if(!(24&e.getDeclarationModifierFlagsFromSymbol(n))){var r=wr(Mc(n)).nameType;if(!r)if("default"===n.escapedName)r=Fm("default");else{var a=n.valueDeclaration&&e.getNameOfDeclaration(n.valueDeclaration);r=a&&Sf(a)||(e.isKnownSymbol(n)?void 0:Fm(e.symbolName(n)))}if(r&&r.flags&t)return r}return ze}function Df(n,t,r){var a=r&&(7&e.getObjectFlags(n)||n.aliasSymbol)?hf(n):void 0;return Qp(e.map(wl(n),(function(e){return Lf(e,t)})),1,void 0,void 0,a)}function Af(e){var n=bu(e,1);return n!==gt?n:void 0}function Cf(n,t,r){void 0===t&&(t=Z);var a=t===Z&&!r;return n=lu(n),1048576&n.flags?pf(e.map(n.types,(function(e){return Cf(e,t,r)}))):2097152&n.flags?Qp(e.map(n.types,(function(e){return Cf(e,t,r)}))):58982400&n.flags||Iy(n)||Il(n)&&Tf(bl(n))?vf(n,t):32&e.getObjectFlags(n)?Ef(n,r):n===De?De:2&n.flags?ze:131073&n.flags?$e:t?!r&&bu(n,0)?Me:Df(n,128,a):!r&&bu(n,0)?Qp([Me,Fe,Df(n,8192,a)]):Af(n)?Qp([Fe,Df(n,8320,a)]):Df(n,8576,a)}function If(e){if(Z)return e;var n=_p();return n?Ld(n,[e,Me]):Me}function Nf(e){var n=If(Cf(e));return 131072&n.flags?Me:n}function kf(n){var t=Pr(n);if(!t.resolvedType)switch(n.operator){case 138:t.resolvedType=Cf(zm(n.type));break;case 151:t.resolvedType=148===n.type.kind?Um(e.walkUpParenthesizedTypes(n.parent)):Ae;break;case 142:t.resolvedType=zm(n.type);break;default:throw e.Debug.assertNever(n.operator)}return t.resolvedType}function Rf(n){var t=Pr(n);return t.resolvedType||(t.resolvedType=Of(i([n.head.text],e.map(n.templateSpans,(function(e){return e.literal.text}))),e.map(n.templateSpans,(function(e){return zm(e.type)})))),t.resolvedType}function Of(n,t){var r=e.findIndex(t,(function(e){return!!(1179648&e.flags)}));if(r>=0)return mf(t)?rb(t[r],(function(a){return Of(n,e.replaceElement(t,r,a))})):Ae;if(e.contains(t,De))return De;var a=[],i=[],o=n[0];if(!l(n,t))return Me;if(0===a.length)return Fm(o);if(i.push(o),e.every(i,(function(e){return""===e}))&&e.every(a,(function(e){return!!(4&e.flags)})))return Me;var s=gd(a)+"|"+e.map(i,(function(e){return e.length})).join(",")+"|"+i.join(""),c=ge.get(s);return c||ge.set(s,c=Pf(i,a)),c;function l(e,n){for(var t=0;t<n.length;t++){var r=n[t];if(101248&r.flags)o+=wf(r)||"",o+=e[t+1];else if(134217728&r.flags){if(o+=r.texts[0],!l(r.texts,r.types))return!1;o+=e[t+1]}else{if(!Xf(r)&&!zf(r))return!1;a.push(r),i.push(o),o=e[t+1]}}return!0}}function wf(n){return 128&n.flags?n.value:256&n.flags?""+n.value:2048&n.flags?e.pseudoBigIntToString(n.value):98816&n.flags?n.intrinsicName:void 0}function Pf(e,n){var t=Ci(134217728);return t.texts=e,t.types=n,t}function Mf(e,n){return 1179648&n.flags?rb(n,(function(n){return Mf(e,n)})):Xf(n)?Gf(e,n):128&n.flags?Fm(Ff(e,n.value)):n}function Ff(e,n){switch(k.get(e.escapedName)){case 0:return n.toUpperCase();case 1:return n.toLowerCase();case 2:return n.charAt(0).toUpperCase()+n.slice(1);case 3:return n.charAt(0).toLowerCase()+n.slice(1)}return n}function Gf(e,n){var t=P(e)+","+Up(n),r=ye.get(t);return r||ye.set(t,r=Bf(e,n)),r}function Bf(e,n){var t=Ci(268435456);return t.symbol=e,t.type=n,t}function Uf(e,n,t,r,a){var i=Ci(8388608);return i.objectType=e,i.indexType=n,i.aliasSymbol=t,i.aliasTypeArguments=r,i.noUncheckedIndexedAccessCandidate=a,i}function Vf(n){if(Y)return!1;if(8192&e.getObjectFlags(n))return!0;if(1048576&n.flags)return e.every(n.types,Vf);if(2097152&n.flags)return e.some(n.types,Vf);if(465829888&n.flags){var t=Yl(n);return t!==n&&Vf(t)}return!1}function jf(n,t){return Lc(n)?kc(n):t&&e.isPropertyName(t)?e.getPropertyNameForPropertyNameNode(t):void 0}function Kf(n,t){if(8208&t.flags){var r=e.findAncestor(n.parent,(function(n){return!e.isAccessExpression(n)}))||n.parent;return e.isCallLikeExpression(r)?e.isCallOrNewExpression(r)&&e.isIdentifier(n)&&vv(r,n):e.every(t.declarations,(function(n){return!e.isFunctionLike(n)||!!(134217728&e.getCombinedNodeFlags(n))}))}return!0}function Hf(n,t,r,a,i,o,s,c,l){var u,d=o&&203===o.kind?o:void 0,p=o&&e.isPrivateIdentifier(o)?void 0:jf(r,o);if(void 0!==p){var f=_u(t,p);if(f){if(l&&o&&f.declarations&&134217728&oS(f)&&Kf(o,f)){var m=null!==(u=null===d||void 0===d?void 0:d.argumentExpression)&&void 0!==u?u:e.isIndexedAccessTypeNode(o)?o.indexType:o;Er(m,f.declarations,p)}if(d){if(qS(f,d,JS(d.expression,t.symbol)),yD(d,f,e.getAssignmentTargetKind(d)))return void gr(d.argumentExpression,e.Diagnostics.Cannot_assign_to_0_because_it_is_a_read_only_property,ro(f));if(4&s&&(Pr(o).resolvedSymbol=f),DS(d,f))return Le}var _=ws(f);return d&&1!==e.getAssignmentTargetKind(d)?kb(d,_):_}if($v(t,Cy)&&bT(p)&&+p>=0){if(o&&$v(t,(function(e){return!e.target.hasRestElement}))&&!(8&s)){var g=Wf(o);Cy(t)?gr(g,e.Diagnostics.Tuple_type_0_of_length_1_has_no_element_at_index_2,io(t),Sd(t),e.unescapeLeadingUnderscores(p)):gr(g,e.Diagnostics.Property_0_does_not_exist_on_type_1,e.unescapeLeadingUnderscores(p),io(t))}return L(bu(t,1)),rb(t,(function(e){var n=ky(e)||ke;return c?Qp([n,ke]):n}))}}if(!(98304&r.flags)&&CD(r,402665900)){if(131073&t.flags)return t;var y=bu(t,0),h=CD(r,296)&&bu(t,1)||y;if(h){if(1&s&&h===y)return void(d&&gr(d,e.Diagnostics.Type_0_cannot_be_used_to_index_type_1,io(r),io(n)));if(o&&!CD(r,12)){g=Wf(o);return gr(g,e.Diagnostics.Type_0_cannot_be_used_as_an_index_type,io(r)),c?Qp([h.type,ke]):h.type}return L(h),c?Qp([h.type,ke]):h.type}if(131072&r.flags)return ze;if(Vf(t))return xe;if(d&&!ND(t)){if(Jh(t)){if(Y&&384&r.flags)return nr.add(e.createDiagnosticForNode(d,e.Diagnostics.Property_0_does_not_exist_on_type_1,r.value,io(t))),ke;if(12&r.flags){var v=e.map(t.properties,(function(e){return ws(e)}));return Qp(e.append(v,ke))}}if(t.symbol===ie&&void 0!==p&&ie.exports.has(p)&&418&ie.exports.get(p).flags)gr(d,e.Diagnostics.Property_0_does_not_exist_on_type_1,e.unescapeLeadingUnderscores(p),io(t));else if(Y&&!C.suppressImplicitAnyIndexErrors&&!i)if(void 0!==p&&PS(p,t)){var b=io(t);gr(d,e.Diagnostics.Property_0_does_not_exist_on_type_1_Did_you_mean_to_access_the_static_member_2_instead,p,b,b+"["+e.getTextOfNode(d.argumentExpression)+"]")}else if(Eu(t,1))gr(d.argumentExpression,e.Diagnostics.Element_implicitly_has_an_any_type_because_index_expression_is_not_of_type_number);else{var E=void 0;if(void 0!==p&&(E=US(p,t)))void 0!==E&&gr(d.argumentExpression,e.Diagnostics.Property_0_does_not_exist_on_type_1_Did_you_mean_2,p,io(t),E);else{var T=WS(t,d,r);if(void 0!==T)gr(d,e.Diagnostics.Element_implicitly_has_an_any_type_because_type_0_has_no_index_signature_Did_you_mean_to_call_1,io(t),T);else{var S=void 0;if(1024&r.flags)S=e.chainDiagnosticMessages(void 0,e.Diagnostics.Property_0_does_not_exist_on_type_1,"["+io(r)+"]",io(t));else if(8192&r.flags){var x=za(r.symbol,d);S=e.chainDiagnosticMessages(void 0,e.Diagnostics.Property_0_does_not_exist_on_type_1,"["+x+"]",io(t))}else 128&r.flags||256&r.flags?S=e.chainDiagnosticMessages(void 0,e.Diagnostics.Property_0_does_not_exist_on_type_1,r.value,io(t)):12&r.flags&&(S=e.chainDiagnosticMessages(void 0,e.Diagnostics.No_index_signature_with_a_parameter_of_type_0_was_found_on_type_1,io(r),io(t)));S=e.chainDiagnosticMessages(S,e.Diagnostics.Element_implicitly_has_an_any_type_because_expression_of_type_0_can_t_be_used_to_index_type_1,io(a),io(t)),nr.add(e.createDiagnosticForNodeFromMessageChain(d,S))}}}return}}if(Vf(t))return xe;if(o){g=Wf(o);384&r.flags?gr(g,e.Diagnostics.Property_0_does_not_exist_on_type_1,""+r.value,io(t)):12&r.flags?gr(g,e.Diagnostics.Type_0_has_no_matching_index_signature_for_type_1,io(t),io(r)):gr(g,e.Diagnostics.Type_0_cannot_be_used_as_an_index_type,io(r))}return ko(r)?r:void 0;function L(n){n&&n.isReadonly&&d&&(e.isAssignmentTarget(d)||e.isDeleteTarget(d))&&gr(d,e.Diagnostics.Index_signature_in_type_0_only_permits_reading,io(t))}}function Wf(e){return 203===e.kind?e.argumentExpression:190===e.kind?e.indexType:159===e.kind?e.expression:e}function zf(e){return!!(77&e.flags)}function qf(n){return!!(134217728&n.flags)&&e.every(n.types,zf)}function Jf(n){return 3145728&n.flags?(4194304&n.objectFlags||(n.objectFlags|=4194304|(e.some(n.types,Jf)?8388608:0)),!!(8388608&n.objectFlags)):33554432&n.flags?(4194304&n.objectFlags||(n.objectFlags|=4194304|(Jf(n.substitute)||Jf(n.baseType)?8388608:0)),!!(8388608&n.objectFlags)):!!(58982400&n.flags)||Il(n)||Iy(n)}function Xf(n){return 3145728&n.flags?(16777216&n.objectFlags||(n.objectFlags|=16777216|(e.some(n.types,Xf)?33554432:0)),!!(33554432&n.objectFlags)):33554432&n.flags?(16777216&n.objectFlags||(n.objectFlags|=16777216|(Xf(n.substitute)||Xf(n.baseType)?33554432:0)),!!(33554432&n.objectFlags)):!!(465829888&n.flags)&&!qf(n)}function Yf(e){return!!(262144&e.flags&&e.isThisType)}function Qf(e,n){return 8388608&e.flags?em(e,n):16777216&e.flags?tm(e,n):e}function Zf(n,t,r){if(3145728&n.flags){var a=e.map(n.types,(function(e){return Qf(im(e,t),r)}));return 2097152&n.flags||r?pf(a):Qp(a)}}function $f(n,t,r){if(1048576&t.flags){var a=e.map(t.types,(function(e){return Qf(im(n,e),r)}));return r?pf(a):Qp(a)}}function em(e,n){var t=n?"simplifiedForWriting":"simplifiedForReading";if(e[t])return e[t]===pn?e:e[t];e[t]=pn;var r=Qf(e.objectType,n),a=Qf(e.indexType,n),i=$f(r,a,n);if(i)return e[t]=i;if(!(465829888&a.flags)){var o=Zf(r,a,n);if(o)return e[t]=o}if(Iy(r)&&296&a.flags){var s=Oy(r,8&a.flags?0:r.target.fixedLength,0,n);if(s)return e[t]=s}return Il(r)?e[t]=rb(am(r,e.indexType),(function(e){return Qf(e,n)})):e[t]=e}function nm(n){var t=n.root.inferTypeParameters&&Qm(n.root.inferTypeParameters,e.map(n.root.inferTypeParameters,(function(){return De}))),r=n.checkType,a=n.extendsType;return W_(R_(r),R_(A_(a,t)))}function tm(e,n){var t=e.checkType,r=e.extendsType,a=mm(e),i=_m(e);if(131072&i.flags&&um(a)===um(t)){if(1&t.flags||W_(R_(t),R_(r)))return Qf(a,n);if(rm(t,r))return ze}else if(131072&a.flags&&um(i)===um(t)){if(!(1&t.flags)&&W_(R_(t),R_(r)))return ze;if(1&t.flags||rm(t,r))return Qf(i,n)}return e}function rm(e,n){return!!(131072&Qp([rl(e,n),ze]).flags)}function am(e,n){var t=Qm([hl(e)],[n]),r=i_(e.mapper,t);return A_(El(e),r)}function im(e,n,t,r,a,i,o){return void 0===o&&(o=0),sm(e,n,t,r,o,a,i)||(r?Ae:Ne)}function om(e,n){return $v(e,(function(e){if(384&e.flags){var t=kc(e);if(bT(t)){var r=+t;return r>=0&&r<n}}return!1}))}function sm(e,n,t,r,a,i,o){if(void 0===a&&(a=0),e===De||n===De)return De;var s=t||!!C.noUncheckedIndexedAccess&&16===(18&a);if(!Tg(e)||98304&n.flags||!CD(n,12)||(n=Me),Xf(n)||(r&&190!==r.kind?Iy(e)&&!om(n,e.target.fixedLength):Jf(e)&&(!Cy(e)||!om(n,e.target.fixedLength)))){if(3&e.flags)return e;var c=e.id+","+n.id+(s?"?":"")+yd(i,o),l=_e.get(c);return l||_e.set(c,l=Uf(e,n,i,o,s)),l}var u=iu(e);if(1048576&n.flags&&!(16&n.flags)){for(var d=[],p=!1,f=0,m=n.types;f<m.length;f++){var _=m[f],g=Hf(e,u,_,n,p,r,a,s);if(g)d.push(g);else{if(!r)return;p=!0}}if(p)return;return 2&a?pf(d,i,o):Qp(d,1,i,o)}return Hf(e,u,n,n,!1,r,4|a,s,!0)}function cm(e){var n=Pr(e);if(!n.resolvedType){var t=zm(e.objectType),r=zm(e.indexType),a=xm(e),i=im(t,r,void 0,e,a,Lm(a));n.resolvedType=8388608&i.flags&&i.objectType===t&&i.indexType===r?Pd(i,e):i}return n.resolvedType}function lm(e){var n=Pr(e);if(!n.resolvedType){var t=Ri(32,e.symbol);t.declaration=e,t.aliasSymbol=xm(e),t.aliasTypeArguments=Lm(t.aliasSymbol),n.resolvedType=t,vl(t)}return n.resolvedType}function um(e){return 33554432&e.flags?e.baseType:8388608&e.flags&&(33554432&e.objectType.flags||33554432&e.indexType.flags)?im(um(e.objectType),um(e.indexType)):e}function dm(n){return!n.isDistributive&&180===n.node.checkType.kind&&1===e.length(n.node.checkType.elements)&&180===n.node.extendsType.kind&&1===e.length(n.node.extendsType.elements)}function pm(e,n){return dm(e)&&Cy(n)?Td(n)[0]:n}function fm(n,t,r,a){var i,o;while(1){var s=dm(n),c=A_(pm(n,um(n.checkType)),t),l=Jf(c)||Xf(c),u=A_(pm(n,n.extendsType),t);if(c===De||u===De)return De;var d=void 0;if(n.inferTypeParameters){var p=mh(n.inferTypeParameters,void 0,0);l||Hh(p.inferences,c,u,1536),d=t?i_(p.mapper,t):p.mapper}var f=d?A_(pm(n,n.extendsType),d):u;if(!l&&!Jf(f)&&!Xf(f)){if(!(3&f.flags)&&(1&c.flags&&!s||!W_(k_(c),k_(f)))){1&c.flags&&!s&&(o||(o=[])).push(A_(zm(n.node.trueType),d||t));var m=zm(n.node.falseType);if(16777216&m.flags){var _=m.root;if(_.node.parent===n.node&&(!_.isDistributive||_.checkType===n.checkType)){n=_;continue}}i=A_(m,t);break}if(3&f.flags||W_(R_(c),R_(f))){i=A_(zm(n.node.trueType),d||t);break}}i=Ci(16777216),i.root=n,i.checkType=A_(n.checkType,t),i.extendsType=A_(n.extendsType,t),i.mapper=t,i.combinedMapper=d,i.aliasSymbol=r||n.aliasSymbol,i.aliasTypeArguments=r?a:Xm(n.aliasTypeArguments,t);break}return o?Qp(e.append(o,i)):i}function mm(e){return e.resolvedTrueType||(e.resolvedTrueType=A_(zm(e.root.node.trueType),e.mapper))}function _m(e){return e.resolvedFalseType||(e.resolvedFalseType=A_(zm(e.root.node.falseType),e.mapper))}function gm(e){return e.resolvedInferredTrueType||(e.resolvedInferredTrueType=e.combinedMapper?A_(zm(e.root.node.trueType),e.combinedMapper):mm(e))}function ym(n){var t;return n.locals&&n.locals.forEach((function(n){262144&n.flags&&(t=e.append(t,mc(n)))})),t}function hm(n){var t=Pr(n);if(!t.resolvedType){var r=zm(n.checkType),a=xm(n),i=Lm(a),o=Bs(n,!0),s=i?o:e.filter(o,(function(e){return g_(e,n)})),c={node:n,checkType:r,extendsType:zm(n.extendsType),isDistributive:!!(262144&r.flags),inferTypeParameters:ym(n),outerTypeParameters:s,instantiations:void 0,aliasSymbol:a,aliasTypeArguments:i};t.resolvedType=fm(c,void 0),s&&(c.instantiations=new e.Map,c.instantiations.set(gd(s),t.resolvedType))}return t.resolvedType}function vm(e){var n=Pr(e);return n.resolvedType||(n.resolvedType=pc(yi(e.typeParameter))),n.resolvedType}function bm(n){return e.isIdentifier(n)?[n]:e.append(bm(n.left),n.right)}function Em(n){var t=Pr(n);if(!t.resolvedType){if(n.isTypeOf&&n.typeArguments)return gr(n,e.Diagnostics.Type_arguments_cannot_be_used_here),t.resolvedSymbol=Te,t.resolvedType=Ae;if(!e.isLiteralImportTypeNode(n))return gr(n.argument,e.Diagnostics.String_literal_expected),t.resolvedSymbol=Te,t.resolvedType=Ae;var r=n.isTypeOf?111551:4194304&n.flags?900095:788968,a=Za(n,n.argument.literal);if(!a)return t.resolvedSymbol=Te,t.resolvedType=Ae;var i=ri(a,!1);if(e.nodeIsMissing(n.qualifier))if(i.flags&r)t.resolvedType=Tm(n,t,i,r);else{var o=111551===r?e.Diagnostics.Module_0_does_not_refer_to_a_value_but_is_used_as_a_value_here:e.Diagnostics.Module_0_does_not_refer_to_a_type_but_is_used_as_a_type_here_Did_you_mean_typeof_import_0;gr(n,o,n.argument.literal.text),t.resolvedSymbol=Te,t.resolvedType=Ae}else{var s=bm(n.qualifier),c=i,l=void 0;while(l=s.shift()){var u=s.length?1920:r,d=gi(Ma(c)),p=n.isTypeOf?_u(ws(d),l.escapedText):Fr(pi(d),l.escapedText,u);if(!p)return gr(l,e.Diagnostics.Namespace_0_has_no_exported_member_1,za(c),e.declarationNameToString(l)),t.resolvedType=Ae;Pr(l).resolvedSymbol=p,Pr(l.parent).resolvedSymbol=p,c=p}t.resolvedType=Tm(n,t,c,r)}}return t.resolvedType}function Tm(e,n,t,r){var a=Ma(t);return n.resolvedSymbol=a,111551===r?ws(t):Nd(e,a)}function Sm(n){var t=Pr(n);if(!t.resolvedType){var r=xm(n);if(0!==Pc(n.symbol).size||r){var a=Ri(16,n.symbol);a.aliasSymbol=r,a.aliasTypeArguments=Lm(r),e.isJSDocTypeLiteral(n)&&n.isArrayType&&(a=Ep(a)),t.resolvedType=a}else t.resolvedType=cn}return t.resolvedType}function xm(n){var t=n.parent;while(e.isParenthesizedTypeNode(t)||e.isJSDocTypeExpression(t)||e.isTypeOperatorNode(t)&&142===t.operator)t=t.parent;return e.isTypeAlias(t)?yi(t):void 0}function Lm(e){return e?Vs(e):void 0}function Dm(e){return!!(524288&e.flags)&&!Il(e)}function Am(e){return bg(e)||!!(474058748&e.flags)}function Cm(n,t){if(e.every(n.types,Am))return e.find(n.types,bg)||an;var r=e.find(n.types,(function(e){return!Am(e)}));if(r){var a=r&&e.find(n.types,(function(e){return e!==r&&!Am(e)}));if(!a)return i(r)}function i(n){for(var r=e.createSymbolTable(),a=0,i=wl(n);a<i.length;a++){var o=i[a];if(24&e.getDeclarationModifierFlagsFromSymbol(o));else if(Nm(o)){var s=65536&o.flags&&!(32768&o.flags),c=16777220,l=Sr(c,o.escapedName,_l(o)|(t?8:0));l.type=s?ke:Qp([ws(o),ke]),l.declarations=o.declarations,l.nameType=wr(o).nameType,l.syntheticOrigin=o,r.set(o.escapedName,l)}}var u=Bi(n.symbol,r,e.emptyArray,e.emptyArray,bu(n,0),bu(n,1));return u.objectFlags|=262272,u}}function Im(n,t,r,a,i){if(1&n.flags||1&t.flags)return xe;if(2&n.flags||2&t.flags)return Ne;if(131072&n.flags)return t;if(131072&t.flags)return n;if(1048576&n.flags){var o=Cm(n,i);return o?Im(o,t,r,a,i):mf([n,t])?rb(n,(function(e){return Im(e,t,r,a,i)})):Ae}if(1048576&t.flags){o=Cm(t,i);return o?Im(n,o,r,a,i):mf([n,t])?rb(t,(function(e){return Im(n,e,r,a,i)})):Ae}if(473960444&t.flags)return n;if(Jf(n)||Jf(t)){if(bg(n))return t;if(2097152&n.flags){var s=n.types,c=s[s.length-1];if(Dm(c)&&Dm(t))return pf(e.concatenate(s.slice(0,s.length-1),[Im(c,t,r,a,i)]))}return pf([n,t])}var l,u,d=e.createSymbolTable(),p=new e.Set;n===an?(l=bu(t,0),u=bu(t,1)):(l=il(bu(n,0),bu(t,0)),u=il(bu(n,1),bu(t,1)));for(var f=0,m=wl(t);f<m.length;f++){var _=m[f];24&e.getDeclarationModifierFlagsFromSymbol(_)?p.add(_.escapedName):Nm(_)&&d.set(_.escapedName,km(_,i))}for(var g=0,y=wl(n);g<y.length;g++){var h=y[g];if(!p.has(h.escapedName)&&Nm(h))if(d.has(h.escapedName)){_=d.get(h.escapedName);var v=ws(_);if(16777216&_.flags){var b=e.concatenate(h.declarations,_.declarations),E=4|16777216&h.flags,T=Sr(E,h.escapedName);T.type=Qp([ws(h),Lv(v,524288)]),T.leftSpread=h,T.rightSpread=_,T.declarations=b,T.nameType=wr(h).nameType,d.set(h.escapedName,T)}}else d.set(h.escapedName,km(h,i))}var S=Bi(r,d,e.emptyArray,e.emptyArray,Rm(l,i),Rm(u,i));return S.objectFlags|=4456576|a,S}function Nm(n){var t;return!e.some(n.declarations,e.isPrivateIdentifierClassElementDeclaration)&&(!(106496&n.flags)||!(null===(t=n.declarations)||void 0===t?void 0:t.some((function(n){return e.isClassLike(n.parent)}))))}function km(e,n){var t=65536&e.flags&&!(32768&e.flags);if(!t&&n===gD(e))return e;var r=4|16777216&e.flags,a=Sr(r,e.escapedName,_l(e)|(n?8:0));return a.type=t?ke:ws(e),a.declarations=e.declarations,a.nameType=wr(e).nameType,a.syntheticOrigin=e,a}function Rm(e,n){return e&&e.isReadonly!==n?ud(e.type,n,e.declaration):e}function Om(e,n,t){var r=Ci(e);return r.symbol=t,r.value=n,r}function wm(e){if(2944&e.flags){if(!e.freshType){var n=Om(e.flags,e.value,e.symbol);n.regularType=e,n.freshType=n,e.freshType=n}return e.freshType}return e}function Pm(e){return 2944&e.flags?e.regularType:1048576&e.flags?e.regularType||(e.regularType=rb(e,Pm)):e}function Mm(e){return!!(2944&e.flags)&&e.freshType===e}function Fm(n,t,r){var a="number"===typeof n?"#":"string"===typeof n?"@":"n",i=(t||"")+a+("object"===typeof n?e.pseudoBigIntToString(n):n),o=me.get(i);if(!o){var s=("number"===typeof n?256:"string"===typeof n?128:2048)|(t?1024:0);me.set(i,o=Om(s,n,r)),o.regularType=o}return o}function Gm(e){if(103===e.literal.kind)return we;var n=Pr(e);return n.resolvedType||(n.resolvedType=Pm(TA(e.literal))),n.resolvedType}function Bm(e){var n=Ci(8192);return n.symbol=e,n.escapedName="__@"+n.symbol.escapedName+"@"+P(n.symbol),n}function Um(n){if(e.isValidESSymbolDeclaration(n)){var t=yi(n),r=wr(t);return r.uniqueESSymbolType||(r.uniqueESSymbolType=Bm(t))}return He}function Vm(n){var t=e.getThisContainer(n,!1),r=t&&t.parent;if(r&&(e.isClassLike(r)||254===r.kind)&&!e.hasSyntacticModifier(t,32)&&(!e.isConstructorDeclaration(t)||e.isNodeDescendantOf(n,t.body)))return ac(yi(r)).thisType;if(r&&e.isObjectLiteralExpression(r)&&e.isBinaryExpression(r.parent)&&6===e.getAssignmentDeclarationKind(r.parent))return ac(yi(r.parent.left).parent).thisType;var a=4194304&n.flags?e.getHostSignatureFromJSDoc(n):void 0;return a&&e.isFunctionExpression(a)&&e.isBinaryExpression(a.parent)&&3===e.getAssignmentDeclarationKind(a.parent)?ac(yi(a.parent.left).parent).thisType:uL(t)&&e.isNodeDescendantOf(n,t.body)?ac(yi(t)).thisType:(gr(n,e.Diagnostics.A_this_type_is_available_only_in_a_non_static_member_of_a_class_or_interface),Ae)}function jm(e){var n=Pr(e);return n.resolvedType||(n.resolvedType=Vm(e)),n.resolvedType}function Km(e){return zm(Hm(e.type)||e.type)}function Hm(e){switch(e.kind){case 187:return Hm(e.type);case 180:if(1===e.elements.length&&(e=e.elements[0],182===e.kind||193===e.kind&&e.dotDotDotToken))return Hm(e.type);break;case 179:return e.elementType}}function Wm(e){var n=Pr(e);return n.resolvedType||(n.resolvedType=e.dotDotDotToken?Km(e):e.questionToken&&z?jy(zm(e.type)):zm(e.type))}function zm(e){return Pd(qm(e),e)}function qm(e){switch(e.kind){case 128:case 304:case 305:return xe;case 152:return Ne;case 147:return Me;case 144:return Fe;case 155:return Ge;case 131:return Ke;case 148:return He;case 113:return We;case 150:return ke;case 103:return we;case 141:return ze;case 145:return 131072&e.flags&&!Y?xe:Qe;case 136:return Ie;case 188:case 107:return jm(e);case 192:return Gm(e);case 174:return Ud(e);case 173:return e.assertsModifier?We:Ke;case 224:return Ud(e);case 177:return jd(e);case 179:case 180:return Cp(e);case 181:return Bp(e);case 183:return tf(e);case 184:return gf(e);case 306:return Bd(e);case 308:return Wo(zm(e.type));case 193:return Wm(e);case 187:case 307:case 302:return zm(e.type);case 182:return Km(e);case 310:return gk(e);case 175:case 176:case 178:case 314:case 309:case 315:return Sm(e);case 189:return kf(e);case 190:return cm(e);case 191:return lm(e);case 185:return hm(e);case 186:return vm(e);case 194:return Rf(e);case 196:return Em(e);case 78:case 158:case 202:var n=jk(e);return n?mc(n):Ae;default:return Ae}}function Jm(e,n,t){if(e&&e.length)for(var r=0;r<e.length;r++){var a=e[r],i=t(a,n);if(a!==i){var o=0===r?[]:e.slice(0,r);for(o.push(i),r++;r<e.length;r++)o.push(t(e[r],n));return o}}return e}function Xm(e,n){return Jm(e,n,A_)}function Ym(e,n){return Jm(e,n,p_)}function Qm(e,n){return 1===e.length?$m(e[0],n?n[0]:xe):e_(e,n)}function Zm(e,n){switch(n.kind){case 0:return e===n.source?n.target:e;case 1:for(var t=n.sources,r=n.targets,a=0;a<t.length;a++)if(e===t[a])return r?r[a]:xe;return e;case 2:return n.func(e);case 3:case 4:var i=Zm(e,n.mapper1);return i!==e&&3===n.kind?A_(i,n.mapper2):Zm(i,n.mapper2)}}function $m(e,n){return{kind:0,source:e,target:n}}function e_(e,n){return{kind:1,sources:e,targets:n}}function n_(e){return{kind:2,func:e}}function t_(e,n,t){return{kind:e,mapper1:n,mapper2:t}}function r_(e){return Qm(e,void 0)}function a_(n,t){return n_((function(r){return e.findIndex(n.inferences,(function(e){return e.typeParameter===r}))>=t?Ne:r}))}function i_(e,n){return e?t_(3,e,n):n}function o_(e,n){return e?t_(4,e,n):n}function s_(e,n,t){return t?t_(4,$m(e,n),t):$m(e,n)}function c_(e,n,t){return e?t_(4,e,$m(n,t)):$m(n,t)}function l_(e){return e.constraint===Ne?e:e.restrictiveInstantiation||(e.restrictiveInstantiation=wi(e.symbol),e.restrictiveInstantiation.constraint=Ne,e.restrictiveInstantiation)}function u_(e){var n=wi(e.symbol);return n.target=e,n}function d_(e,n){return Nu(e.kind,e.parameterName,e.parameterIndex,A_(e.type,n))}function p_(n,t,r){var a;if(n.typeParameters&&!r){a=e.map(n.typeParameters,u_),t=i_(Qm(n.typeParameters,a),t);for(var i=0,o=a;i<o.length;i++){var s=o[i];s.mapper=t}}var c=Vc(n.declaration,a,n.thisParameter&&f_(n.thisParameter,t),Jm(n.parameters,t,f_),void 0,void 0,n.minArgumentCount,39&n.flags);return c.target=n,c.mapper=t,c}function f_(n,t){var r=wr(n);if(r.type&&!Sh(r.type))return n;1&e.getCheckFlags(n)&&(n=r.target,t=i_(r.mapper,t));var a=Sr(n.flags,n.escapedName,1|53256&e.getCheckFlags(n));return a.declarations=n.declarations,a.parent=n.parent,a.target=n,a.mapper=t,n.valueDeclaration&&(a.valueDeclaration=n.valueDeclaration),r.nameType&&(a.nameType=r.nameType),a}function m_(n,t,r,a){var i=4&n.objectFlags?n.node:n.symbol.declarations[0],o=Pr(i),s=4&n.objectFlags?o.resolvedType:64&n.objectFlags?n.target:n,c=o.outerTypeParameters;if(!c){var l=Bs(i,!0);if(uL(i)){var u=Su(i);l=e.addRange(l,u)}c=l||e.emptyArray;var d=4&n.objectFlags?[i]:n.symbol.declarations;c=(4&s.objectFlags||8192&s.symbol.flags||2048&s.symbol.flags)&&!s.aliasTypeArguments?e.filter(c,(function(n){return e.some(d,(function(e){return g_(n,e)}))})):c,o.outerTypeParameters=c}if(c.length){var p=i_(n.mapper,t),f=e.map(c,(function(e){return Zm(e,p)})),m=r||n.aliasSymbol,_=r?a:Xm(n.aliasTypeArguments,t),g=gd(f)+yd(m,_);s.instantiations||(s.instantiations=new e.Map,s.instantiations.set(gd(c)+yd(s.aliasSymbol,s.aliasTypeArguments),s));var y=s.instantiations.get(g);if(!y){var h=Qm(c,f);y=4&s.objectFlags?Ed(n.target,n.node,h,m,_):32&s.objectFlags?h_(s,h,m,_):x_(s,h,m,_),s.instantiations.set(g,y)}return y}return n}function __(e){return!(158===e.kind||174===e.parent.kind&&e.parent.typeArguments&&e===e.parent.typeName||196===e.parent.kind&&e.parent.typeArguments&&e===e.parent.qualifier)}function g_(n,t){if(n.symbol&&n.symbol.declarations&&1===n.symbol.declarations.length){for(var r=n.symbol.declarations[0].parent,a=t;a!==r;a=a.parent)if(!a||231===a.kind||185===a.kind&&e.forEachChild(a.extendsType,i))return!0;return i(t)}return!0;function i(t){switch(t.kind){case 188:return!!n.isThisType;case 78:return!n.isThisType&&e.isPartOfTypeNode(t)&&__(t)&&qm(t)===n;case 177:return!0;case 166:case 165:return!t.type&&!!t.body||!!e.forEachChild(t,i)}return!!e.forEachChild(t,i)}}function y_(e){var n=vl(e);if(4194304&n.flags){var t=um(n.type);if(262144&t.flags)return t}}function h_(e,n,t,r){var a=y_(e);if(a){var i=A_(a,n);if(a!==i)return ab(lu(i),(function(t){if(61603843&t.flags&&t!==De&&t!==Ae){if(!e.declaration.nameType){if(sy(t))return E_(t,e,s_(a,t,n));if(Iy(t))return b_(t,e,a,n);if(Cy(t))return T_(t,e,s_(a,t,n))}return x_(e,s_(a,t,n))}return t}),t,r)}return A_(vl(e),n)===De?De:x_(e,n,t,r)}function v_(e,n){return!!(1&n)||!(2&n)&&e}function b_(n,t,r,a){var i=n.target.elementFlags,o=e.map(Td(n),(function(e,n){var o=8&i[n]?e:4&i[n]?Ep(e):Np([e],[i[n]]);return h_(t,s_(r,o,a))})),s=v_(n.target.readonly,Ll(t));return Np(o,e.map(o,(function(e){return 8})),s)}function E_(e,n,t){var r=S_(n,Fe,!0,t);return r===Ae?Ae:Ep(r,v_(cy(e),Ll(n)))}function T_(n,t,r){var a=n.target.elementFlags,i=e.map(Td(n),(function(e,n){return S_(t,Fm(""+n),!!(2&a[n]),r)})),o=Ll(t),s=4&o?e.map(a,(function(e){return 1&e?2:e})):8&o?e.map(a,(function(e){return 2&e?1:e})):a,c=v_(n.target.readonly,o);return e.contains(i,Ae)?Ae:Np(i,s,c,n.target.labeledElementDeclarations)}function S_(e,n,t,r){var a=c_(r,hl(e),n),i=A_(El(e.target||e),a),o=Ll(e);return z&&4&o&&!AD(i,49152)?jy(i):z&&8&o&&t?Lv(i,524288):i}function x_(e,n,t,r){var a=Ri(64|e.objectFlags,e.symbol);if(32&e.objectFlags){a.declaration=e.declaration;var i=hl(e),o=u_(i);a.typeParameter=o,n=i_($m(i,o),n),o.mapper=n}return a.target=e,a.mapper=n,a.aliasSymbol=t||e.aliasSymbol,a.aliasTypeArguments=t?r:Xm(e.aliasTypeArguments,n),a}function L_(n,t,r,a){var i=n.root;if(i.outerTypeParameters){var o=e.map(i.outerTypeParameters,(function(e){return Zm(e,t)})),s=gd(o)+yd(r,a),c=i.instantiations.get(s);if(!c){var l=Qm(i.outerTypeParameters,o);c=D_(i,l,r,a),i.instantiations.set(s,c)}return c}return n}function D_(e,n,t,r){if(e.isDistributive){var a=e.checkType,i=Zm(a,n);if(a!==i&&1179648&i.flags)return ab(i,(function(t){return fm(e,s_(a,t,n))}),t,r)}return fm(e,n,t,r)}function A_(e,n){return e&&n?C_(e,n,void 0,void 0):e}function C_(n,t,r,a){if(!Sh(n))return n;if(50===L||T>=5e6)return null===e.tracing||void 0===e.tracing||e.tracing.instant("checkTypes","instantiateType_DepthLimit",{typeId:n.id,instantiationDepth:L,instantiationCount:T}),gr(d,e.Diagnostics.Type_instantiation_is_excessively_deep_and_possibly_infinite),Ae;E++,T++,L++;var i=I_(n,t,r,a);return L--,i}function I_(e,n,t,r){var a=e.flags;if(262144&a)return Zm(e,n);if(524288&a){var i=e.objectFlags;if(52&i){if(4&i&&!e.node){var o=e.resolvedTypeArguments,s=Xm(o,n);return s!==o?Op(e.target,s):e}return 1024&i?N_(e,n):m_(e,n,t,r)}return e}if(3145728&a){var c=1048576&e.flags?e.origin:void 0,l=c&&3145728&c.flags?c.types:e.types,u=Xm(l,n);if(u===l&&t===e.aliasSymbol)return e;var d=t||e.aliasSymbol,p=t?r:Xm(e.aliasTypeArguments,n);return 2097152&a||c&&2097152&c.flags?pf(u,d,p):Qp(u,1,d,p)}if(4194304&a)return Cf(A_(e.type,n));if(134217728&a)return Of(e.texts,Xm(e.types,n));if(268435456&a)return Mf(e.symbol,A_(e.type,n));if(8388608&a){d=t||e.aliasSymbol,p=t?r:Xm(e.aliasTypeArguments,n);return im(A_(e.objectType,n),A_(e.indexType,n),e.noUncheckedIndexedAccessCandidate,void 0,d,p)}if(16777216&a)return L_(e,i_(e.mapper,n),t,r);if(33554432&a){var f=A_(e.baseType,n);if(8650752&f.flags)return Rd(f,A_(e.substitute,n));var m=A_(e.substitute,n);return 3&m.flags||W_(R_(f),R_(m))?f:m}return e}function N_(n,t){var r=A_(n.mappedType,t);if(!(32&e.getObjectFlags(r)))return n;var a=A_(n.constraintType,t);if(!(4194304&a.flags))return n;var i=Ah(A_(n.source,t),r,a);return i||n}function k_(e){return 262143&e.flags?e:e.permissiveInstantiation||(e.permissiveInstantiation=A_(e,rn))}function R_(e){return 262143&e.flags?e:(e.restrictiveInstantiation||(e.restrictiveInstantiation=A_(e,tn),e.restrictiveInstantiation.restrictiveInstantiation=e.restrictiveInstantiation),e.restrictiveInstantiation)}function O_(e,n){return e&&ud(A_(e.type,n),e.isReadonly,e.declaration)}function w_(n){switch(e.Debug.assert(166!==n.kind||e.isObjectLiteralMethod(n)),n.kind){case 209:case 210:case 166:case 252:return P_(n);case 201:return e.some(n.properties,w_);case 200:return e.some(n.elements,w_);case 218:return w_(n.whenTrue)||w_(n.whenFalse);case 217:return(56===n.operatorToken.kind||60===n.operatorToken.kind)&&(w_(n.left)||w_(n.right));case 289:return w_(n.initializer);case 208:return w_(n.expression);case 282:return e.some(n.properties,w_)||e.isJsxOpeningElement(n.parent)&&e.some(n.parent.parent.children,w_);case 281:var t=n.initializer;return!!t&&w_(t);case 284:var r=n.expression;return!!r&&w_(r)}return!1}function P_(n){return(!e.isFunctionDeclaration(n)||e.isInJSFile(n)&&!!jo(n))&&(M_(n)||F_(n))}function M_(n){if(!n.typeParameters){if(e.some(n.parameters,(function(n){return!e.getEffectiveTypeAnnotationNode(n)})))return!0;if(210!==n.kind){var t=e.firstOrUndefined(n.parameters);if(!t||!e.parameterIsThisKeyword(t))return!0}}return!1}function F_(n){return!n.typeParameters&&!e.getEffectiveReturnTypeNode(n)&&!!n.body&&231!==n.body.kind&&w_(n.body)}function G_(n){return(e.isInJSFile(n)&&e.isFunctionDeclaration(n)||lT(n)||e.isObjectLiteralMethod(n))&&P_(n)}function B_(n){if(524288&n.flags){var t=Nl(n);if(t.constructSignatures.length||t.callSignatures.length){var r=Ri(16,n.symbol);return r.members=t.members,r.properties=t.properties,r.callSignatures=e.emptyArray,r.constructSignatures=e.emptyArray,r}}else if(2097152&n.flags)return pf(e.map(n.types,B_));return n}function U_(e,n){return Lg(e,n,lr)}function V_(e,n){return Lg(e,n,lr)?-1:0}function j_(e,n){return Lg(e,n,sr)?-1:0}function K_(e,n){return Lg(e,n,ir)?-1:0}function H_(e,n){return Lg(e,n,ir)}function W_(e,n){return Lg(e,n,sr)}function z_(n,t){return 1048576&n.flags?e.every(n.types,(function(e){return z_(e,t)})):1048576&t.flags?e.some(t.types,(function(e){return z_(n,e)})):58982400&n.flags?z_(ql(n)||Ne,t):t===bn?!!(67633152&n.flags):t===En?!!(524288&n.flags)&&Sv(n):Fs(n,Ms(t))||sy(t)&&!cy(t)&&z_(n,Ln)}function q_(e,n){return Lg(e,n,cr)}function J_(e,n){return q_(e,n)||q_(n,e)}function X_(e,n,t,r,a,i){return Cg(e,n,sr,t,r,a,i)}function Y_(e,n,t,r,a,i){return Q_(e,n,sr,t,r,a,i,void 0)}function Q_(e,n,t,r,a,i,o,s){return!!Lg(e,n,t)||(!r||!$_(a,e,n,t,i,o,s))&&Cg(e,n,t,r,i,o,s)}function Z_(n){return!!(16777216&n.flags||2097152&n.flags&&e.some(n.types,Z_))}function $_(e,n,t,r,a,i,o){if(!e||Z_(t))return!1;if(!Cg(n,t,r,void 0)&&eg(e,n,t,r,a,i,o))return!0;switch(e.kind){case 284:case 208:return $_(e.expression,n,t,r,a,i,o);case 217:switch(e.operatorToken.kind){case 62:case 27:return $_(e.right,n,t,r,a,i,o)}break;case 201:return pg(e,n,t,r,i,o);case 200:return ug(e,n,t,r,i,o);case 282:return cg(e,n,t,r,i,o);case 210:return ng(e,n,t,r,i,o)}return!1}function eg(n,t,r,a,i,o,s){for(var c=yu(t,0),l=yu(t,1),u=0,d=[l,c];u<d.length;u++){var p=d[u];if(e.some(p,(function(e){var n=Hu(e);return!(131073&n.flags)&&Cg(n,r,a,void 0)}))){var f=s||{};X_(t,r,n,i,o,f);var m=f.errors[f.errors.length-1];return e.addRelatedInfo(m,e.createDiagnosticForNode(n,p===l?e.Diagnostics.Did_you_mean_to_use_new_with_this_expression:e.Diagnostics.Did_you_mean_to_call_this_expression)),!0}}return!1}function ng(n,t,r,a,i,o){if(e.isBlock(n.body))return!1;if(e.some(n.parameters,e.hasType))return!1;var s=mx(t);if(!s)return!1;var c=yu(r,0);if(!e.length(c))return!1;var l=n.body,u=Hu(s),d=Qp(e.map(c,Hu));if(!Cg(u,d,a,void 0)){var p=l&&$_(l,u,d,a,void 0,i,o);if(p)return p;var f=o||{};if(Cg(u,d,a,l,void 0,i,f),f.errors)return r.symbol&&e.length(r.symbol.declarations)&&e.addRelatedInfo(f.errors[f.errors.length-1],e.createDiagnosticForNode(r.symbol.declarations[0],e.Diagnostics.The_expected_type_comes_from_the_return_type_of_this_signature)),0===(2&e.getFunctionFlags(n))&&!Io(u,"then")&&Cg(QL(u),d,a,void 0)&&e.addRelatedInfo(f.errors[f.errors.length-1],e.createDiagnosticForNode(n,e.Diagnostics.Did_you_mean_to_mark_this_function_as_async)),!0}return!1}function tg(e,n,t){var r=sm(n,t);if(r)return r;if(1048576&n.flags){var a=Ng(e,n);if(a)return sm(a,t)}}function rg(e,n){e.contextualType=n;try{return oA(e,1,n)}finally{e.contextualType=void 0}}function ag(n,t,r,a,i,o){for(var s=!1,c=n.next();!c.done;c=n.next()){var l=c.value,u=l.errorNode,d=l.innerExpression,p=l.nameType,f=l.errorMessage,m=tg(t,r,p);if(m&&!(8388608&m.flags)){var _=sm(t,p);if(_&&!Cg(_,m,a,void 0)){var g=d&&$_(d,_,m,a,void 0,i,o);if(g)s=!0;else{var y=o||{},h=d?rg(d,_):_,v=Cg(h,m,a,u,f,i,y);if(v&&h!==_&&Cg(_,m,a,u,f,i,y),y.errors){var b=y.errors[y.errors.length-1],E=Lc(p)?kc(p):void 0,T=void 0!==E?_u(r,E):void 0,S=!1;if(!T){var x=CD(p,296)&&bu(r,1)||bu(r,0)||void 0;x&&x.declaration&&!e.getSourceFileOfNode(x.declaration).hasNoDefaultLib&&(S=!0,e.addRelatedInfo(b,e.createDiagnosticForNode(x.declaration,e.Diagnostics.The_expected_type_comes_from_this_index_signature)))}if(!S&&(T&&e.length(T.declarations)||r.symbol&&e.length(r.symbol.declarations))){var L=T&&e.length(T.declarations)?T.declarations[0]:r.symbol.declarations[0];e.getSourceFileOfNode(L).hasNoDefaultLib||e.addRelatedInfo(b,e.createDiagnosticForNode(L,e.Diagnostics.The_expected_type_comes_from_property_0_which_is_declared_here_on_type_1,!E||8192&p.flags?io(p):e.unescapeLeadingUnderscores(E),io(r)))}}s=!0}}}}return s}function ig(n){var t,r,a;return c(this,(function(i){switch(i.label){case 0:if(!e.length(n.properties))return[2];t=0,r=n.properties,i.label=1;case 1:return t<r.length?(a=r[t],e.isJsxSpreadAttribute(a)?[3,3]:[4,{errorNode:a.name,innerExpression:a.initializer,nameType:Fm(e.idText(a.name))}]):[3,4];case 2:i.sent(),i.label=3;case 3:return t++,[3,1];case 4:return[2]}}))}function og(n,t){var r,a,i,o,s;return c(this,(function(c){switch(c.label){case 0:if(!e.length(n.children))return[2];r=0,a=0,c.label=1;case 1:return a<n.children.length?(i=n.children[a],o=Fm(a-r),s=sg(i,o,t),s?[4,s]:[3,3]):[3,5];case 2:return c.sent(),[3,4];case 3:r++,c.label=4;case 4:return a++,[3,1];case 5:return[2]}}))}function sg(n,t,r){switch(n.kind){case 284:return{errorNode:n,innerExpression:n.expression,nameType:t};case 11:if(n.containsOnlyTriviaWhiteSpaces)break;return{errorNode:n,innerExpression:void 0,nameType:t,errorMessage:r()};case 274:case 275:case 278:return{errorNode:n,innerExpression:n,nameType:t};default:return e.Debug.assertNever(n,"Found invalid jsx child")}}function cg(n,t,r,a,i,s){var l,u=ag(ig(n),t,r,a,i,s);if(e.isJsxOpeningElement(n.parent)&&e.isJsxElement(n.parent.parent)){var d=n.parent.parent,p=zT(jT(n)),f=void 0===p?"children":e.unescapeLeadingUnderscores(p),m=Fm(f),_=im(r,m),g=e.getSemanticJsxChildren(d.children);if(!e.length(g))return u;var y=e.length(g)>1,h=nb(_,_y),v=nb(_,(function(e){return!_y(e)}));if(y){if(h!==ze){var b=Np(MT(d,0)),E=og(d,L);u=ag(E,b,h,a,i,s)||u}else if(!Lg(im(t,m),_,a)){u=!0;var T=gr(d.openingElement.tagName,e.Diagnostics.This_JSX_tag_s_0_prop_expects_a_single_child_of_type_1_but_multiple_children_were_provided,f,io(_));s&&s.skipLogging&&(s.errors||(s.errors=[])).push(T)}}else if(v!==ze){var S=g[0],x=sg(S,m,L);x&&(u=ag(function(){return c(this,(function(e){switch(e.label){case 0:return[4,x];case 1:return e.sent(),[2]}}))}(),t,r,a,i,s)||u)}else if(!Lg(im(t,m),_,a)){u=!0;T=gr(d.openingElement.tagName,e.Diagnostics.This_JSX_tag_s_0_prop_expects_type_1_which_requires_multiple_children_but_only_a_single_child_was_provided,f,io(_));s&&s.skipLogging&&(s.errors||(s.errors=[])).push(T)}}return u;function L(){if(!l){var t=e.getTextOfNode(n.parent.tagName),a=zT(jT(n)),i=void 0===a?"children":e.unescapeLeadingUnderscores(a),s=im(r,Fm(i)),c=e.Diagnostics._0_components_don_t_accept_text_as_child_elements_Text_in_JSX_has_the_type_string_but_the_expected_type_of_1_is_2;l=o(o({},c),{key:"!!ALREADY FORMATTED!!",message:e.formatMessage(void 0,c,t,i,io(s))})}return l}}function lg(n,t){var r,a,i,o;return c(this,(function(s){switch(s.label){case 0:if(r=e.length(n.elements),!r)return[2];a=0,s.label=1;case 1:return a<r?my(t)&&!_u(t,""+a)?[3,3]:(i=n.elements[a],e.isOmittedExpression(i)?[3,3]:(o=Fm(a),[4,{errorNode:i,innerExpression:i,nameType:o}])):[3,4];case 2:s.sent(),s.label=3;case 3:return a++,[3,1];case 4:return[2]}}))}function ug(e,n,t,r,a,i){if(131068&t.flags)return!1;if(my(n))return ag(lg(e,t),n,t,r,a,i);var o=e.contextualType;e.contextualType=t;try{var s=_T(e,1,!0);return e.contextualType=o,!!my(s)&&ag(lg(e,t),s,t,r,a,i)}finally{e.contextualType=o}}function dg(n){var t,r,a,i,o;return c(this,(function(s){switch(s.label){case 0:if(!e.length(n.properties))return[2];t=0,r=n.properties,s.label=1;case 1:if(!(t<r.length))return[3,8];if(a=r[t],e.isSpreadAssignment(a))return[3,7];if(i=Lf(yi(a),8576),!i||131072&i.flags)return[3,7];switch(o=a.kind,o){case 169:return[3,2];case 168:return[3,2];case 166:return[3,2];case 290:return[3,2];case 289:return[3,4]}return[3,6];case 2:return[4,{errorNode:a.name,innerExpression:void 0,nameType:i}];case 3:return s.sent(),[3,7];case 4:return[4,{errorNode:a.name,innerExpression:a.initializer,nameType:i,errorMessage:e.isComputedNonLiteralName(a.name)?e.Diagnostics.Type_of_computed_property_s_value_is_0_which_is_not_assignable_to_type_1:void 0}];case 5:return s.sent(),[3,7];case 6:e.Debug.assertNever(a),s.label=7;case 7:return t++,[3,1];case 8:return[2]}}))}function pg(e,n,t,r,a,i){return!(131068&t.flags)&&ag(dg(e),n,t,r,a,i)}function fg(e,n,t,r,a){return Cg(e,n,cr,t,r,a)}function mg(e,n,t){return 0!==gg(e,n,t?4:0,!1,void 0,void 0,j_,void 0)}function _g(e){return!e.typeParameters&&(!e.thisParameter||ko(kL(e.thisParameter)))&&1===e.parameters.length&&j(e)&&(kL(e.parameters[0])===kn||ko(kL(e.parameters[0])))&&ko(Hu(e))}function gg(n,t,r,a,i,o,s,c){if(n===t)return-1;if(_g(t))return-1;var l=BL(t),u=!VL(t)&&(8&r?VL(n)||BL(n)>l:UL(n)>l);if(u)return 0;n.typeParameters&&n.typeParameters!==t.typeParameters&&(t=nd(t),n=yx(n,t,void 0,s));var d=BL(n),p=KL(n),f=KL(t);if((p||f)&&A_(p||f,c),p&&f&&d!==l)return 0;var m=t.declaration?t.declaration.kind:0,_=!(3&r)&&q&&166!==m&&165!==m&&167!==m,g=-1,y=Uu(n);if(y&&y!==We){var h=Uu(t);if(h){var v=!_&&s(y,h,!1)||s(h,y,a);if(!v)return a&&i(e.Diagnostics.The_this_types_of_each_signature_are_incompatible),0;g&=v}}for(var b=p||f?Math.min(d,l):Math.max(d,l),E=p||f?b-1:-1,T=0;T<b;T++){var S=T===E?GL(n,T):FL(n,T),x=T===E?GL(t,T):FL(t,T);if(S&&x){var L=3&r?void 0:mx(Hy(S)),D=3&r?void 0:mx(Hy(x)),A=L&&D&&!Vu(L)&&!Vu(D)&&(98304&Fy(S))===(98304&Fy(x));v=A?gg(D,L,8&r|(_?2:1),a,i,o,s,c):!(3&r)&&!_&&s(S,x,!1)||s(x,S,a);if(v&&8&r&&T>=UL(n)&&T<UL(t)&&s(S,x,!1)&&(v=0),!v)return a&&i(e.Diagnostics.Types_of_parameters_0_and_1_are_incompatible,e.unescapeLeadingUnderscores(OL(n,T)),e.unescapeLeadingUnderscores(OL(t,T))),0;g&=v}}if(!(4&r)){var C=zu(t)?xe:t.declaration&&uL(t.declaration)?ac(gi(t.declaration.symbol)):Hu(t);if(C===We)return g;var I=zu(n)?xe:n.declaration&&uL(n.declaration)?ac(gi(n.declaration.symbol)):Hu(n),N=Vu(t);if(N){var k=Vu(n);if(k)g&=yg(k,N,a,i,s);else if(e.isIdentifierTypePredicate(N))return a&&i(e.Diagnostics.Signature_0_must_be_a_type_predicate,ao(n)),0}else g&=1&r&&s(C,I,!1)||s(I,C,a),!g&&a&&o&&o(I,C)}return g}function yg(n,t,r,a,i){if(n.kind!==t.kind)return r&&(a(e.Diagnostics.A_this_based_type_guard_is_not_compatible_with_a_parameter_based_type_guard),a(e.Diagnostics.Type_predicate_0_is_not_assignable_to_1,fo(n),fo(t))),0;if((1===n.kind||3===n.kind)&&n.parameterIndex!==t.parameterIndex)return r&&(a(e.Diagnostics.Parameter_0_is_not_in_the_same_position_as_parameter_1,n.parameterName,t.parameterName),a(e.Diagnostics.Type_predicate_0_is_not_assignable_to_1,fo(n),fo(t))),0;var o=n.type===t.type?-1:n.type&&t.type?i(n.type,t.type,r):0;return 0===o&&r&&a(e.Diagnostics.Type_predicate_0_is_not_assignable_to_1,fo(n),fo(t)),o}function hg(e,n){var t=$u(e),r=$u(n),a=Hu(t),i=Hu(r);return!(i!==We&&!Lg(i,a,sr)&&!Lg(a,i,sr))&&mg(t,r,!0)}function vg(e){return e!==un&&0===e.properties.length&&0===e.callSignatures.length&&0===e.constructSignatures.length&&!e.stringIndexInfo&&!e.numberIndexInfo}function bg(n){return 524288&n.flags?!Il(n)&&vg(Nl(n)):!!(67108864&n.flags)||(1048576&n.flags?e.some(n.types,bg):!!(2097152&n.flags)&&e.every(n.types,bg))}function Eg(n){return!!(16&e.getObjectFlags(n)&&(n.members&&vg(n)||n.symbol&&2048&n.symbol.flags&&0===Pc(n.symbol).size))}function Tg(n){return 524288&n.flags&&!Il(n)&&0===wl(n).length&&bu(n,0)&&!bu(n,1)||3145728&n.flags&&e.every(n.types,Tg)||!1}function Sg(n,t,r){if(n===t)return!0;var a=P(n)+","+P(t),i=ur.get(a);if(void 0!==i&&(4&i||!(2&i)||!r))return!!(1&i);if(n.escapedName!==t.escapedName||!(256&n.flags)||!(256&t.flags))return ur.set(a,6),!1;for(var o=ws(t),s=0,c=wl(ws(n));s<c.length;s++){var l=c[s];if(8&l.flags){var u=_u(o,l.escapedName);if(!u||!(8&u.flags))return r?(r(e.Diagnostics.Property_0_is_missing_in_type_1,e.symbolName(l),io(mc(t),void 0,64)),ur.set(a,6)):ur.set(a,2),!1}}return ur.set(a,1),!0}function xg(e,n,t,r){var a=e.flags,i=n.flags;if(3&i||131072&a||e===De)return!0;if(131072&i)return!1;if(402653316&a&&4&i)return!0;if(128&a&&1024&a&&128&i&&!(1024&i)&&e.value===n.value)return!0;if(296&a&&8&i)return!0;if(256&a&&1024&a&&256&i&&!(1024&i)&&e.value===n.value)return!0;if(2112&a&&64&i)return!0;if(528&a&&16&i)return!0;if(12288&a&&4096&i)return!0;if(32&a&&32&i&&Sg(e.symbol,n.symbol,r))return!0;if(1024&a&&1024&i){if(1048576&a&&1048576&i&&Sg(e.symbol,n.symbol,r))return!0;if(2944&a&&2944&i&&e.value===n.value&&Sg(hi(e.symbol),hi(n.symbol),r))return!0}if(32768&a&&(!z||49152&i))return!0;if(65536&a&&(!z||65536&i))return!0;if(524288&a&&67108864&i)return!0;if(t===sr||t===cr){if(1&a)return!0;if(264&a&&!(1024&a)&&(32&i||t===sr&&256&i&&1024&i))return!0}return!1}function Lg(e,n,t){if(Mm(e)&&(e=e.regularType),Mm(n)&&(n=n.regularType),e===n)return!0;if(t!==lr){if(t===cr&&!(131072&n.flags)&&xg(n,e,t)||xg(e,n,t))return!0}else if(!(3145728&e.flags)&&!(3145728&n.flags)&&e.flags!==n.flags&&!(469237760&e.flags))return!1;if(524288&e.flags&&524288&n.flags){var r=t.get(Kg(e,n,0,t));if(void 0!==r)return!!(1&r)}return!!(469499904&e.flags||469499904&n.flags)&&Cg(e,n,t,void 0)}function Dg(n,t){return 2048&e.getObjectFlags(n)&&!RT(t.escapedName)}function Ag(n,t){while(1){var r=Mm(n)?n.regularType:4&e.getObjectFlags(n)&&n.node?vd(n.target,Td(n)):3145728&n.flags?lu(n):33554432&n.flags?t?n.baseType:n.substitute:25165824&n.flags?Qf(n,t):n;if(r=py(r)||r,r===n)break;n=r}return n}function Cg(n,t,r,a,o,s,c){var u,p,f,m,_,g,y=0,h=0,v=0,b=!1,E=0,T=[],S=!1;e.Debug.assert(r!==lr||!a,"no error reporting in identity checking");var x=j(n,t,!!a,o);if(T.length&&M(),b){null===e.tracing||void 0===e.tracing||e.tracing.instant("checkTypes","checkTypeRelatedTo_DepthLimit",{sourceId:n.id,targetId:t.id,depth:h});var L=gr(a||d,e.Diagnostics.Excessive_stack_depth_comparing_types_0_and_1,io(n),io(t));c&&(c.errors||(c.errors=[])).push(L)}else if(u){if(s){var D=s();D&&(e.concatenateDiagnosticMessageChains(D,u),u=D)}var A=void 0;if(o&&a&&!x&&n.symbol){var I=wr(n.symbol);if(I.originatingImport&&!e.isImportCall(I.originatingImport)){var k=Cg(ws(I.target),t,r,void 0);if(k){var R=e.createDiagnosticForNode(I.originatingImport,e.Diagnostics.Type_originates_at_this_import_A_namespace_style_import_cannot_be_called_or_constructed_and_will_cause_a_failure_at_runtime_Consider_using_a_default_import_or_import_require_here_instead);A=e.append(A,R)}}}L=e.createDiagnosticForNodeFromMessageChain(a,u,A);p&&e.addRelatedInfo.apply(void 0,i([L],p)),c&&(c.errors||(c.errors=[])).push(L),c&&c.skipLogging||nr.add(L)}return a&&c&&c.skipLogging&&0===x&&e.Debug.assert(!!c.errors,"missed opportunity to interact with error."),0!==x;function O(e){u=e.errorInfo,g=e.lastSkippedInfo,T=e.incompatibleStack,E=e.overrideNextErrorInfo,p=e.relatedInfo}function w(){return{errorInfo:u,lastSkippedInfo:g,incompatibleStack:T.slice(),overrideNextErrorInfo:E,relatedInfo:p?p.slice():void 0}}function P(e,n,t,r,a){E++,g=void 0,T.push([e,n,t,r,a])}function M(){var n=T;T=[];var t=g;if(g=void 0,1===n.length)return F.apply(void 0,n[0]),void(t&&B.apply(void 0,i([void 0],t)));var r="",a=[];while(n.length){var o=n.pop(),s=o[0],c=o.slice(1);switch(s.code){case e.Diagnostics.Types_of_property_0_are_incompatible.code:0===r.indexOf("new ")&&(r="("+r+")");var l=""+c[0];r=0===r.length?""+l:e.isIdentifierText(l,C.target)?r+"."+l:"["===l[0]&&"]"===l[l.length-1]?""+r+l:r+"["+l+"]";break;case e.Diagnostics.Call_signature_return_types_0_and_1_are_incompatible.code:case e.Diagnostics.Construct_signature_return_types_0_and_1_are_incompatible.code:case e.Diagnostics.Call_signatures_with_no_arguments_have_incompatible_return_types_0_and_1.code:case e.Diagnostics.Construct_signatures_with_no_arguments_have_incompatible_return_types_0_and_1.code:if(0===r.length){var u=s;s.code===e.Diagnostics.Call_signatures_with_no_arguments_have_incompatible_return_types_0_and_1.code?u=e.Diagnostics.Call_signature_return_types_0_and_1_are_incompatible:s.code===e.Diagnostics.Construct_signatures_with_no_arguments_have_incompatible_return_types_0_and_1.code&&(u=e.Diagnostics.Construct_signature_return_types_0_and_1_are_incompatible),a.unshift([u,c[0],c[1]])}else{var d=s.code===e.Diagnostics.Construct_signature_return_types_0_and_1_are_incompatible.code||s.code===e.Diagnostics.Construct_signatures_with_no_arguments_have_incompatible_return_types_0_and_1.code?"new ":"",p=s.code===e.Diagnostics.Call_signatures_with_no_arguments_have_incompatible_return_types_0_and_1.code||s.code===e.Diagnostics.Construct_signatures_with_no_arguments_have_incompatible_return_types_0_and_1.code?"":"...";r=""+d+r+"("+p+")"}break;case e.Diagnostics.Type_at_position_0_in_source_is_not_compatible_with_type_at_position_1_in_target.code:a.unshift([e.Diagnostics.Type_at_position_0_in_source_is_not_compatible_with_type_at_position_1_in_target,c[0],c[1]]);break;case e.Diagnostics.Type_at_positions_0_through_1_in_source_is_not_compatible_with_type_at_position_2_in_target.code:a.unshift([e.Diagnostics.Type_at_positions_0_through_1_in_source_is_not_compatible_with_type_at_position_2_in_target,c[0],c[1],c[2]]);break;default:return e.Debug.fail("Unhandled Diagnostic: "+s.code)}}r?F(")"===r[r.length-1]?e.Diagnostics.The_types_returned_by_0_are_incompatible_between_these_types:e.Diagnostics.The_types_of_0_are_incompatible_between_these_types,r):a.shift();for(var f=0,m=a;f<m.length;f++){var _=m[f],y=(s=_[0],c=_.slice(1),s.elidedInCompatabilityPyramid);s.elidedInCompatabilityPyramid=!1,F.apply(void 0,i([s],c)),s.elidedInCompatabilityPyramid=y}t&&B.apply(void 0,i([void 0],t))}function F(n,t,r,i,o){e.Debug.assert(!!a),T.length&&M(),n.elidedInCompatabilityPyramid||(u=e.chainDiagnosticMessages(u,n,t,r,i,o))}function G(n){e.Debug.assert(!!u),p?p.push(n):p=[n]}function B(n,t,a){T.length&&M();var i=oo(t,a),o=i[0],s=i[1],c=t,l=o;if(Ey(t)&&!Ig(a)&&(c=Ty(t),e.Debug.assert(!W_(c,a),"generalized source shouldn't be assignable"),l=so(c)),262144&a.flags){var d=ql(a),p=void 0;d&&(W_(c,d)||(p=W_(t,d)))?F(e.Diagnostics._0_is_assignable_to_the_constraint_of_type_1_but_1_could_be_instantiated_with_a_different_subtype_of_constraint_2,p?o:l,s,io(d)):(u=void 0,F(e.Diagnostics._0_could_be_instantiated_with_an_arbitrary_type_which_could_be_unrelated_to_1,s,l))}n||(n=r===cr?e.Diagnostics.Type_0_is_not_comparable_to_type_1:o===s?e.Diagnostics.Type_0_is_not_assignable_to_type_1_Two_different_types_with_this_name_exist_but_they_are_unrelated:e.Diagnostics.Type_0_is_not_assignable_to_type_1),F(n,l,s)}function U(n,t){var r=co(n.symbol)?io(n,n.symbol.valueDeclaration):io(n),a=co(t.symbol)?io(t,t.symbol.valueDeclaration):io(t);(Dn===n&&Me===t||An===n&&Fe===t||Cn===n&&Ke===t||$d(!1)===n&&He===t)&&F(e.Diagnostics._0_is_a_primitive_but_1_is_a_wrapper_object_Prefer_using_0_when_possible,a,r)}function V(n,t,r){return Cy(n)?n.target.readonly&&ly(t)?(r&&F(e.Diagnostics.The_type_0_is_readonly_and_cannot_be_assigned_to_the_mutable_type_1,io(n),io(t)),!1):Cy(t)||sy(t):cy(n)&&ly(t)?(r&&F(e.Diagnostics.The_type_0_is_readonly_and_cannot_be_assigned_to_the_mutable_type_1,io(n),io(t)),!1):!Cy(t)||sy(n)}function j(n,t,i,o,s){if(void 0===i&&(i=!1),void 0===s&&(s=0),524288&n.flags&&131068&t.flags)return xg(n,t,r,i?F:void 0)?-1:(L(n,t,0,!!(2048&e.getObjectFlags(n))),0);var c=Ag(n,!1),l=Ag(t,!0);if(c===l)return-1;if(r===lr)return H(c,l);if(262144&c.flags&&Fl(c)===l)return-1;if(1048576&l.flags&&524288&c.flags&&l.types.length<=3&&AD(l,98304)){var d=ob(l,-98305);if(1179648&d.flags||(l=Ag(d,!0)),c===d)return-1}if(r===cr&&!(131072&l.flags)&&xg(l,c,r)||xg(c,l,r,i?F:void 0))return-1;var p=!!(2048&e.getObjectFlags(c)),f=!(2&s)&&Jh(c)&&16384&e.getObjectFlags(c);if(f&&q(c,l,i))return i&&B(o,c,t.aliasSymbol?t:l),0;var m=r!==cr&&!(2&s)&&2752508&c.flags&&c!==bn&&2621440&l.flags&&Rg(l)&&(wl(c).length>0||Zk(c));if(m&&!Og(c,l,p)){if(i){var _=io(n.aliasSymbol?n:c),y=io(t.aliasSymbol?t:l),h=yu(c,0),v=yu(c,1);h.length>0&&j(Hu(h[0]),l,!1)||v.length>0&&j(Hu(v[0]),l,!1)?F(e.Diagnostics.Value_of_type_0_has_no_properties_in_common_with_type_1_Did_you_mean_to_call_it,_,y):F(e.Diagnostics.Type_0_has_no_properties_in_common_with_type_1,_,y)}return 0}K(c,l);var b=0,T=w();if((3145728&c.flags||3145728&l.flags)&&(b=ib(c)*ib(l)>=4?re(c,l,i,8|s):ae(c,l,i,8|s)),b||1048576&c.flags||!(469499904&c.flags||469499904&l.flags)||(b=re(c,l,i,s))&&O(T),!b&&2359296&c.flags){var x=zl(2097152&c.flags?c.types:[c],!!(1048576&l.flags));x&&(2097152&c.flags||1048576&l.flags)&&$v(x,(function(e){return e!==c}))&&(b=j(x,l,!1,void 0,s))&&O(T)}return b&&!S&&(2097152&l.flags&&(f||m)||Dm(l)&&!sy(l)&&!Cy(l)&&2097152&c.flags&&3670016&au(c).flags&&!e.some(c.types,(function(n){return!!(524288&e.getObjectFlags(n))})))&&(S=!0,b&=re(c,l,i,4),S=!1),L(c,l,b,p),b;function L(r,s,c,l){if(!c&&i){var d=!!py(n),p=!!py(t);r=n.aliasSymbol||d?n:r,s=t.aliasSymbol||p?t:s;var f=E>0;if(f&&E--,524288&r.flags&&524288&s.flags){var m=u;V(r,s,i),u!==m&&(f=!!u)}if(524288&r.flags&&131068&s.flags)U(r,s);else if(r.symbol&&524288&r.flags&&bn===r)F(e.Diagnostics.The_Object_type_is_assignable_to_very_few_other_types_Did_you_mean_to_use_the_any_type_instead);else if(l&&2097152&s.flags){var _=s.types,y=BT(N.IntrinsicAttributes,a),h=BT(N.IntrinsicClassAttributes,a);if(y!==Ae&&h!==Ae&&(e.contains(_,y)||e.contains(_,h)))return c}else u=mu(u,t);if(!o&&f)return g=[r,s],c;B(o,r,s)}}}function K(n,t){if(e.tracing&&3145728&n.flags&&3145728&t.flags){var r=n,i=t;if(r.objectFlags&i.objectFlags&65536)return;var o=r.types.length,s=i.types.length;o*s>1e6&&e.tracing.instant("checkTypes","traceUnionsOrIntersectionsTooLarge_DepthLimit",{sourceId:n.id,sourceSize:o,targetId:t.id,targetSize:s,pos:null===a||void 0===a?void 0:a.pos,end:null===a||void 0===a?void 0:a.end})}}function H(e,n){var t=e.flags&n.flags;if(!(469237760&t))return 0;if(K(e,n),3145728&t){var r=X(e,n);return r&&(r&=X(n,e)),r}return re(e,n,!1,0)}function W(n,t){var r=function(n,r){r=au(r);var a=3145728&r.flags?cu(r,t):Rl(r,t),i=a&&ws(a)||bT(t)&&Eu(r,1)||Eu(r,0)||ke;return e.append(n,i)};return Qp(e.reduceLeft(n,r,void 0)||e.emptyArray)}function q(n,t,i){var o;if(!aS(t)||!Y&&8192&e.getObjectFlags(t))return!1;var s=!!(2048&e.getObjectFlags(n));if((r===sr||r===cr)&&(Xv(bn,t)||!s&&bg(t)))return!1;var c,l=t;1048576&t.flags&&(l=_w(n,t,j)||mw(t),c=1048576&l.flags?l.types:[l]);for(var u=function(t){if(J(t,n.symbol)&&!Dg(n,t)){if(!rS(l,t.escapedName,s)){if(i){var r=nb(l,aS);if(!a)return{value:e.Debug.fail()};if(e.isJsxAttributes(a)||e.isJsxOpeningLikeElement(a)||e.isJsxOpeningLikeElement(a.parent)){t.valueDeclaration&&e.isJsxAttribute(t.valueDeclaration)&&e.getSourceFileOfNode(a)===e.getSourceFileOfNode(t.valueDeclaration.name)&&(a=t.valueDeclaration.name);var u=ro(t),d=BS(u,r),p=d?ro(d):void 0;p?F(e.Diagnostics.Property_0_does_not_exist_on_type_1_Did_you_mean_2,u,io(r),p):F(e.Diagnostics.Property_0_does_not_exist_on_type_1,u,io(r))}else{var f=(null===(o=n.symbol)||void 0===o?void 0:o.declarations)&&e.firstOrUndefined(n.symbol.declarations);p=void 0;if(t.valueDeclaration&&e.findAncestor(t.valueDeclaration,(function(e){return e===f}))&&e.getSourceFileOfNode(f)===e.getSourceFileOfNode(a)){var m=t.valueDeclaration;e.Debug.assertNode(m,e.isObjectLiteralElementLike),a=m;var _=m.name;e.isIdentifier(_)&&(p=US(_,r))}void 0!==p?F(e.Diagnostics.Object_literal_may_only_specify_known_properties_but_0_does_not_exist_in_type_1_Did_you_mean_to_write_2,ro(t),io(r),p):F(e.Diagnostics.Object_literal_may_only_specify_known_properties_and_0_does_not_exist_in_type_1,ro(t),io(r))}}return{value:!0}}if(c&&!j(ws(t),W(c,t.escapedName),i))return i&&P(e.Diagnostics.Types_of_property_0_are_incompatible,ro(t)),{value:!0}}},d=0,p=wl(n);d<p.length;d++){var f=p[d],m=u(f);if("object"===typeof m)return m.value}return!1}function J(e,n){return e.valueDeclaration&&n.valueDeclaration&&e.valueDeclaration.parent===n.valueDeclaration}function X(e,n){for(var t=-1,r=e.types,a=0,i=r;a<i.length;a++){var o=i[a],s=Q(o,n,!1);if(!s)return 0;t&=s}return t}function Q(e,n,t){var r=n.types;if(1048576&n.flags){if(Vp(r,e))return-1;var a=gv(n,e);if(a){var i=j(e,a,!1);if(i)return i}}for(var o=0,s=r;o<s.length;o++){var c=s[o];i=j(e,c,!1);if(i)return i}if(t){var l=Ng(e,n,j);j(e,l||r[r.length-1],!0)}return 0}function Z(e,n,t,r){for(var a=-1,i=n.types,o=0,s=i;o<s.length;o++){var c=s[o],l=j(e,c,t,void 0,r);if(!l)return 0;a&=l}return a}function $(e,n,t,r){var a=e.types;if(1048576&e.flags&&Vp(a,n))return-1;for(var i=a.length,o=0;o<i;o++){var s=j(a[o],n,t&&o===i-1,void 0,r);if(s)return s}return 0}function ee(e,n){return 1048576&e.flags&&1048576&n.flags&&!(32768&e.types[0].flags)&&32768&n.types[0].flags?ob(n,-32769):n}function ne(e,n,t,r){for(var a=-1,i=e.types,o=ee(e,n),s=0;s<i.length;s++){var c=i[s];if(1048576&o.flags&&i.length>=o.types.length&&i.length%o.types.length===0){var l=j(c,o.types[s%o.types.length],!1,void 0,r);if(l){a&=l;continue}}var u=j(c,n,t,void 0,r);if(!u)return 0;a&=u}return a}function te(n,t,a,i,o){if(void 0===n&&(n=e.emptyArray),void 0===t&&(t=e.emptyArray),void 0===a&&(a=e.emptyArray),n.length!==t.length&&r===lr)return 0;for(var s=n.length<=t.length?n.length:t.length,c=-1,l=0;l<s;l++){var u=l<a.length?a[l]:1,d=7&u;if(4!==d){var p=n[l],f=t[l],m=-1;if(8&u?m=r===lr?j(p,f,!1):V_(p,f):1===d?m=j(p,f,i,void 0,o):2===d?m=j(f,p,i,void 0,o):3===d?(m=j(f,p,!1),m||(m=j(p,f,i,void 0,o))):(m=j(p,f,i,void 0,o),m&&(m&=j(f,p,i,void 0,o))),!m)return 0;c&=m}}return c}function re(n,t,a,i){if(b)return 0;var o=Kg(n,t,i|(S?16:0),r),s=r.get(o);if(void 0!==s&&(!(a&&2&s)||4&s)){if(lt){var c=24&s;8&c&&A_(n,n_(oe)),16&c&&A_(n,n_(se))}return 1&s?-1:0}if(f){for(var l=o.split(",").map((function(n){return n.replace(/-\d+/g,(function(n,t){var r=e.length(o.slice(0,t).match(/[-=]/g)||void 0);return"="+r}))})).join(","),u=0;u<y;u++)if(o===f[u]||l===f[u])return 3;if(100===h)return b=!0,0}else f=[],m=[],_=[];var d=y;f[y]=o,y++,m[h]=n,_[h]=t,h++;var p,g=v;1&v||!Yg(n,m,h)||(v|=1),2&v||!Yg(t,_,h)||(v|=2);var E=0;lt&&(p=lt,lt=function(e){return E|=e?16:8,p(e)}),3===v&&(null===e.tracing||void 0===e.tracing||e.tracing.instant("checkTypes","recursiveTypeRelatedTo_DepthLimit",{sourceId:n.id,sourceIdStack:m.map((function(e){return e.id})),targetId:t.id,targetIdStack:_.map((function(e){return e.id})),depth:h}));var T=3!==v?ae(n,t,a,i):3;if(lt&&(lt=p),v=g,h--,T){if(-1===T||0===h){if(-1===T||3===T)for(u=d;u<y;u++)r.set(f[u],1|E);y=d}}else r.set(o,2|(a?4:0)|E),y=d;return T}function ae(n,t,r,a){null===e.tracing||void 0===e.tracing||e.tracing.push("checkTypes","structuredTypeRelatedTo",{sourceId:n.id,targetId:t.id});var i=ie(n,t,r,a);return null===e.tracing||void 0===e.tracing||e.tracing.pop(),i}function ie(n,t,a,i){if(4&i)return me(n,t,a,void 0,0);if(8&i){if(1048576&n.flags)return r===cr?$(n,t,a&&!(131068&n.flags),-9&i):ne(n,t,a&&!(131068&n.flags),-9&i);if(1048576&t.flags)return Q(eh(n),t,a&&!(131068&n.flags)&&!(131068&t.flags));if(2097152&t.flags)return Z(eh(n),t,a,2);if(r===cr&&131068&t.flags){var o=e.sameMap(n.types,(function(e){return 131068&e.flags?e:ql(e)||Ne}));if(o!==n.types&&(n=pf(o),!(2097152&n.flags)))return j(n,t,!1)}return $(n,t,!1,1)}var s,c,l=n.flags&t.flags;if(r===lr&&!(524288&l)){if(4194304&l)return j(n.type,t.type,!1);var d=0;return 8388608&l&&(d=j(n.objectType,t.objectType,!1))&&(d&=j(n.indexType,t.indexType,!1))||16777216&l&&n.root.isDistributive===t.root.isDistributive&&(d=j(n.checkType,t.checkType,!1))&&(d&=j(n.extendsType,t.extendsType,!1))&&(d&=j(mm(n),mm(t),!1))&&(d&=j(_m(n),_m(t),!1))?d:33554432&l?j(n.substitute,t.substitute,!1):0}var p=!1,f=w();if(17301504&n.flags&&n.aliasSymbol&&n.aliasTypeArguments&&n.aliasSymbol===t.aliasSymbol&&!n.aliasTypeArgumentsContainsMarker&&!t.aliasTypeArgumentsContainsMarker){var m=Pg(n.aliasSymbol);if(m===e.emptyArray)return 1;var _=de(n.aliasTypeArguments,t.aliasTypeArguments,m,i);if(void 0!==_)return _}if(Ny(n)&&!n.target.readonly&&(s=j(Td(n)[0],t))||Ny(t)&&(t.target.readonly||ly(ql(n)||n))&&(s=j(n,Td(t)[0])))return s;if(262144&t.flags){if(32&e.getObjectFlags(n)&&!n.declaration.nameType&&j(Cf(t),vl(n))&&!(4&Ll(n))){var g=El(n),y=im(t,hl(n));if(s=j(g,y,a))return s}}else if(4194304&t.flags){var h=t.type;if(4194304&n.flags&&(s=j(h,n.type,!1)))return s;if(Cy(h)){if(s=j(n,Mp(h),a))return s}else{var v=Ul(h);if(v&&-1===j(n,Cf(v,t.stringsOnly),a))return-1}}else if(8388608&t.flags){if(8388608&n.flags){if((s=j(n.objectType,t.objectType,a))&&(s&=j(n.indexType,t.indexType,a)),s)return O(f),s;a&&(c=u)}if(r===sr||r===cr){var b=t.objectType,E=t.indexType,T=ql(b)||b,S=ql(E)||E;if(!Jf(T)&&!Xf(S)){var x=2|(T!==b?1:0);v=sm(T,S,t.noUncheckedIndexedAccessCandidate,void 0,x);if(v){if(a&&c&&O(f),s=j(n,v,a))return s;a&&c&&u&&(u=ue([c])<=ue([u])?c:u)}}}a&&(c=void 0)}else if(Il(t)&&!t.declaration.nameType){var L=El(t),D=Ll(t);if(!(8&D)){if(8388608&L.flags&&L.objectType===n&&L.indexType===hl(t))return-1;if(!Il(n)){var A=vl(t),C=Cf(n,void 0,!0),I=4&D,N=I?rl(A,C):void 0;if(I?!(131072&N.flags):j(A,C)){g=El(t);var k=hl(t),R=ob(g,-98305);if(8388608&R.flags&&R.indexType===k){if(s=j(n,R.objectType,a))return s}else{var P=N?pf([N,k]):k;y=im(n,P);if(s=j(y,g,a))return s}}c=u,O(f)}}}else if(16777216&t.flags){var M=t,F=!W_(k_(M.checkType),k_(M.extendsType)),G=!F&&nm(M),B=void 0,U=um(M.root.checkType);if(M.root.isDistributive&&262144&U.flags){var V=u_(U);B=s_(U,V,M.mapper),V.mapper=B}var K=void 0;if((F||(K=j(n,B?A_(zm(M.root.node.trueType),B):mm(M),!1)))&&(G||(K=(K||3)&j(n,B?A_(zm(M.root.node.falseType),B):_m(M),!1))),K)return O(f),K}else if(134217728&t.flags){134217728&n.flags&&A_(n,n_(se));var H=Vh(n,t);if(H&&e.every(H,(function(e,n){return Uh(e,t.types[n])})))return-1}if(8650752&n.flags){if(!(8388608&n.flags&&8388608&t.flags)){v=Fl(n);if(!v||262144&n.flags&&1&v.flags){if(s=j(an,ob(t,-67108865)))return O(f),s}else{if(s=j(v,t,!1,void 0,i))return O(f),s;if(s=j(Fc(v,n),t,a&&!(t.flags&n.flags&262144),void 0,i))return O(f),s}}}else if(4194304&n.flags){if(s=j($e,t,a))return O(f),s}else if(134217728&n.flags){if(!(134217728&t.flags)){var W=ql(n);v=W&&W!==n?W:Me;if(s=j(v,t,a))return O(f),s}}else if(268435456&n.flags)if(268435456&t.flags&&n.symbol===t.symbol){if(s=j(n.type,t.type,a))return O(f),s}else{v=ql(n);if(v&&(s=j(v,t,a)))return O(f),s}else if(16777216&n.flags){if(16777216&t.flags){var z=n.root.inferTypeParameters,q=n.extendsType,J=void 0;if(z){var X=mh(z,void 0,0,j);Hh(X.inferences,t.extendsType,q,1536),q=A_(q,X.mapper),J=X.mapper}if(U_(q,t.extendsType)&&(j(n.checkType,t.checkType)||j(t.checkType,n.checkType))&&((s=j(A_(mm(n),J),mm(t),a))&&(s&=j(_m(n),_m(t),a)),s))return O(f),s}else{var Y=Kl(n);if(Y&&(s=j(Y,t,a)))return O(f),s}var ee=jl(n);if(ee&&(s=j(ee,t,a)))return O(f),s}else{if(r!==ir&&r!==or&&Cl(t)&&bg(n))return-1;if(Il(t))return Il(n)&&(s=ce(n,t,a))?(O(f),s):0;var re=!!(131068&n.flags);if(r!==lr)n=au(n);else if(Il(n))return 0;if(4&e.getObjectFlags(n)&&4&e.getObjectFlags(t)&&n.target===t.target&&!(4096&e.getObjectFlags(n)||4096&e.getObjectFlags(t))){m=Fg(n.target);if(m===e.emptyArray)return 1;_=de(Td(n),Td(t),m,i);if(void 0!==_)return _}else{if(cy(t)?sy(n)||Cy(n):sy(t)&&Cy(n)&&!n.target.readonly)return r!==lr?j(Eu(n,1)||xe,Eu(t,1)||xe,a):0;if((r===ir||r===or)&&bg(t)&&16384&e.getObjectFlags(t)&&!bg(n))return 0}if(2621440&n.flags&&524288&t.flags){var ae=a&&u===f.errorInfo&&!re;if(s=me(n,t,ae,void 0,i),s&&(s&=ge(n,t,0,ae),s&&(s&=ge(n,t,1,ae),s&&(s&=Se(n,t,0,re,ae,i),s&&(s&=Se(n,t,1,re,ae,i))))),p&&s)u=c||u||f.errorInfo;else if(s)return s}if(2621440&n.flags&&1048576&t.flags){var ie=ob(t,36175872);if(1048576&ie.flags){var oe=le(n,ie);if(oe)return oe}}}return 0;function ue(n){return n?e.reduceLeft(n,(function(e,n){return e+1+ue(n.next)}),0):0}function de(n,t,r,i){if(s=te(n,t,r,a,i))return s;if(e.some(r,(function(e){return!!(24&e)})))return c=void 0,void O(f);var o=t&&Gg(t,r);if(p=!o,r!==e.emptyArray&&!o){if(p&&(!a||!e.some(r,(function(e){return 0===(7&e)}))))return 0;c=u,O(f)}}}function oe(e){return!lt||e!==mn&&e!==_n&&e!==ut||lt(!1),e}function se(e){return!lt||e!==mn&&e!==_n&&e!==ut||lt(!0),e}function ce(e,n,t){var a=r===cr||(r===lr?Ll(e)===Ll(n):Al(e)<=Al(n));if(a){var i,o=vl(n),s=A_(vl(e),n_(Al(e)<0?oe:se));if(i=j(o,s,t)){var c=Qm([hl(e)],[hl(n)]);if(A_(bl(e),c)===A_(bl(n),c))return i&j(A_(El(e),c),El(n),t)}}return 0}function le(n,t){var a=wl(n),i=pv(a,t);if(!i)return 0;for(var o=1,s=0,c=i;s<c.length;s++){var l=c[s];if(o*=tb(ws(l)),o>25)return null===e.tracing||void 0===e.tracing||e.tracing.instant("checkTypes","typeRelatedToDiscriminatedType_DepthLimit",{sourceId:n.id,targetId:t.id,numCombinations:o}),0}for(var u=new Array(i.length),d=new e.Set,p=0;p<i.length;p++){l=i[p];var f=ws(l);u[p]=1048576&f.flags?f.types:[f],d.add(l.escapedName)}for(var m=e.cartesianProduct(u),_=[],g=function(a){var o=!1;e:for(var s=0,c=t.types;s<c.length;s++){for(var l=c[s],u=function(e){var o=i[e],s=_u(l,o.escapedName);if(!s)return"continue-outer";if(o===s)return"continue";var c=pe(n,t,o,s,(function(n){return a[e]}),!1,0,z||r===cr);return c?void 0:"continue-outer"},d=0;d<i.length;d++){var p=u(d);switch(p){case"continue-outer":continue e}}e.pushIfUnique(_,l,e.equateValues),o=!0}if(!o)return{value:0}},y=0,h=m;y<h.length;y++){var v=h[y],b=g(v);if("object"===typeof b)return b.value}for(var E=-1,T=0,S=_;T<S.length;T++){var x=S[T];if(E&=me(n,x,!1,d,0),E&&(E&=ge(n,x,0,!1),E&&(E&=ge(n,x,1,!1),E&&(E&=Se(n,x,0,!1,!1,0),!E||Cy(n)&&Cy(x)||(E&=Se(n,x,1,!1,!1,0))))),!E)return E}return E}function ue(e,n){if(!n||0===e.length)return e;for(var t,r=0;r<e.length;r++)n.has(e[r].escapedName)?t||(t=e.slice(0,r)):t&&t.push(e[r]);return t||e}function de(n,t,r,a,i){var o=z&&!!(48&e.getCheckFlags(t)),s=r(n);if(65536&e.getCheckFlags(t)&&!wr(t).type){var c=wr(t);e.Debug.assertIsDefined(c.deferralParent),e.Debug.assertIsDefined(c.deferralConstituents);for(var l=!!(1048576&c.deferralParent.flags),u=l?0:-1,d=c.deferralConstituents,p=0,f=d;p<f.length;p++){var m=f[p],_=j(s,m,!1,void 0,l?0:2);if(l){if(_)return _}else{if(!_)return j(s,Wo(ws(t),o),a);u&=_}}return l&&!u&&o&&(u=j(s,ke)),l&&!u&&a?j(s,Wo(ws(t),o),a):u}return j(s,Wo(ws(t),o),a,void 0,i)}function pe(n,t,r,a,i,o,s,c){var l=e.getDeclarationModifierFlagsFromSymbol(r),u=e.getDeclarationModifierFlagsFromSymbol(a);if(8&l||8&u){if(r.valueDeclaration!==a.valueDeclaration)return o&&(8&l&&8&u?F(e.Diagnostics.Types_have_separate_declarations_of_a_private_property_0,ro(a)):F(e.Diagnostics.Property_0_is_private_in_type_1_but_not_in_type_2,ro(a),io(8&l?n:t),io(8&l?t:n))),0}else if(16&u){if(!Jg(r,a))return o&&F(e.Diagnostics.Property_0_is_protected_but_type_1_is_not_a_class_derived_from_2,ro(a),io(Wg(r)||n),io(Wg(a)||t)),0}else if(16&l)return o&&F(e.Diagnostics.Property_0_is_protected_in_type_1_but_public_in_type_2,ro(a),io(n),io(t)),0;var d=de(r,a,i,o,s);return d?c||!(16777216&r.flags)||16777216&a.flags?d:(o&&F(e.Diagnostics.Property_0_is_optional_in_type_1_but_required_in_type_2,ro(a),io(n),io(t)),0):(o&&P(e.Diagnostics.Types_of_property_0_are_incompatible,ro(a)),0)}function fe(n,t,r,a){var s=!1;if(r.valueDeclaration&&e.isNamedDeclaration(r.valueDeclaration)&&e.isPrivateIdentifier(r.valueDeclaration.name)&&n.symbol&&32&n.symbol.flags){var c=r.valueDeclaration.name.escapedText,d=e.getSymbolNameForPrivateIdentifier(n.symbol,c);if(d&&_u(n,d)){var p=e.factory.getDeclarationName(n.symbol.valueDeclaration),f=e.factory.getDeclarationName(t.symbol.valueDeclaration);return void F(e.Diagnostics.Property_0_in_type_1_refers_to_a_different_member_that_cannot_be_accessed_from_within_type_2,zr(c),zr(""===p.escapedText?l:p),zr(""===f.escapedText?l:f))}}var m=e.arrayFrom(Rh(n,t,a,!1));if((!o||o.code!==e.Diagnostics.Class_0_incorrectly_implements_interface_1.code&&o.code!==e.Diagnostics.Class_0_incorrectly_implements_class_1_Did_you_mean_to_extend_1_and_inherit_its_members_as_a_subclass.code)&&(s=!0),1===m.length){var _=ro(r);F.apply(void 0,i([e.Diagnostics.Property_0_is_missing_in_type_1_but_required_in_type_2,_],oo(n,t))),e.length(r.declarations)&&G(e.createDiagnosticForNode(r.declarations[0],e.Diagnostics._0_is_declared_here,_)),s&&u&&E++}else V(n,t,!1)&&(m.length>5?F(e.Diagnostics.Type_0_is_missing_the_following_properties_from_type_1_Colon_2_and_3_more,io(n),io(t),e.map(m.slice(0,4),(function(e){return ro(e)})).join(", "),m.length-4):F(e.Diagnostics.Type_0_is_missing_the_following_properties_from_type_1_Colon_2,io(n),io(t),e.map(m,(function(e){return ro(e)})).join(", ")),s&&u&&E++)}function me(n,t,a,i,o){if(r===lr)return _e(n,t,i);var s=-1;if(Cy(t)){if(sy(n)||Cy(n)){if(!t.target.readonly&&(cy(n)||Cy(n)&&n.target.readonly))return 0;var c=Sd(n),l=Sd(t),u=Cy(n)?4&n.target.combinedFlags:4,d=4&t.target.combinedFlags,p=Cy(n)?n.target.minLength:0,f=t.target.minLength;if(!u&&c<f)return a&&F(e.Diagnostics.Source_has_0_element_s_but_target_requires_1,c,f),0;if(!d&&l<p)return a&&F(e.Diagnostics.Source_has_0_element_s_but_target_allows_only_1,p,l),0;if(!d&&u)return a&&(p<f?F(e.Diagnostics.Target_requires_0_element_s_but_source_may_have_fewer,f):F(e.Diagnostics.Target_allows_only_0_element_s_but_source_may_have_more,l)),0;for(var m=Td(n),_=Td(t),g=Math.min(Cy(n)?Fp(n.target,11):0,Fp(t.target,11)),y=Math.min(Cy(n)?Gp(n.target,11):0,d?Gp(t.target,11):0),h=!!i,v=0;v<l;v++){var b=v<l-y?v:v+c-l,E=Cy(n)&&(v<g||v>=l-y)?n.target.elementFlags[b]:4,T=t.target.elementFlags[v];if(8&T&&!(8&E))return a&&F(e.Diagnostics.Source_provides_no_match_for_variadic_element_at_position_0_in_target,v),0;if(8&E&&!(12&T))return a&&F(e.Diagnostics.Variadic_element_at_position_0_in_source_does_not_match_element_at_position_1_in_target,b,v),0;if(1&T&&!(1&E))return a&&F(e.Diagnostics.Source_provides_no_match_for_required_element_at_position_0_in_target,v),0;if(!(h&&((12&E||12&T)&&(h=!1),h&&(null===i||void 0===i?void 0:i.has(""+v))))){var S=Cy(n)?v<g||v>=l-y?m[b]:Oy(n,g,y)||ze:m[0],x=_[v],L=8&E&&4&T?Ep(x):x,D=j(S,L,a,void 0,o);if(!D)return a&&(v<g||v>=l-y||c-g-y===1?P(e.Diagnostics.Type_at_position_0_in_source_is_not_compatible_with_type_at_position_1_in_target,b,v):P(e.Diagnostics.Type_at_positions_0_through_1_in_source_is_not_compatible_with_type_at_position_2_in_target,g,c-y-1,v)),0;s&=D}}return s}if(12&t.target.combinedFlags)return 0}var A=(r===ir||r===or)&&!Jh(n)&&!fy(n)&&!Cy(n),C=Oh(n,t,A,!1);if(C)return a&&fe(n,t,C,A),0;if(Jh(t))for(var I=0,N=ue(wl(n),i);I<N.length;I++){var k=N[I];if(!Rl(t,k.escapedName)){S=ws(k);if(S!==ke&&S!==Re&&S!==Oe)return a&&F(e.Diagnostics.Property_0_does_not_exist_on_type_1,ro(k),io(t)),0}}for(var R=wl(t),O=Cy(n)&&Cy(t),w=0,M=ue(R,i);w<M.length;w++){var G=M[w],B=G.escapedName;if(!(4194304&G.flags)&&(!O||bT(B)||"length"===B)){k=_u(n,B);if(k&&k!==G){D=pe(n,t,k,G,ws,a,o,r===cr);if(!D)return 0;s&=D}}}return s}function _e(e,n,t){if(!(524288&e.flags&&524288&n.flags))return 0;var r=ue(kl(e),t),a=ue(kl(n),t);if(r.length!==a.length)return 0;for(var i=-1,o=0,s=r;o<s.length;o++){var c=s[o],l=Rl(n,c.escapedName);if(!l)return 0;var u=$g(c,l,j);if(!u)return 0;i&=u}return i}function ge(n,t,a,i){var o,s;if(r===lr)return be(n,t,a);if(t===un||n===un)return-1;var c=n.symbol&&uL(n.symbol.valueDeclaration),l=t.symbol&&uL(t.symbol.valueDeclaration),u=yu(n,c&&1===a?0:a),d=yu(t,l&&1===a?0:a);if(1===a&&u.length&&d.length){var p=!!(4&u[0].flags),f=!!(4&d[0].flags);if(p&&!f)return i&&F(e.Diagnostics.Cannot_assign_an_abstract_constructor_type_to_a_non_abstract_constructor_type),0;if(!De(u[0],d[0],i))return 0}var m=-1,_=w(),g=1===a?he:ye,y=e.getObjectFlags(n),h=e.getObjectFlags(t);if(64&y&&64&h&&n.symbol===t.symbol)for(var v=0;v<d.length;v++){var b=ve(u[v],d[v],!0,i,g(u[v],d[v]));if(!b)return 0;m&=b}else if(1===u.length&&1===d.length){var E=r===cr||!!C.noStrictGenericChecks,T=e.first(u),S=e.first(d);if(m=ve(T,S,E,i,g(T,S)),!m&&i&&1===a&&y&h&&(167===(null===(o=S.declaration)||void 0===o?void 0:o.kind)||167===(null===(s=T.declaration)||void 0===s?void 0:s.kind))){var x=function(e){return ao(e,void 0,262144,a)};return F(e.Diagnostics.Type_0_is_not_assignable_to_type_1,x(T),x(S)),F(e.Diagnostics.Types_of_construct_signatures_are_incompatible),m}}else e:for(var L=0,D=d;L<D.length;L++){for(var A=D[L],I=i,N=0,k=u;N<k.length;N++){var R=k[N];b=ve(R,A,!0,I,g(R,A));if(b){m&=b,O(_);continue e}I=!1}return I&&F(e.Diagnostics.Type_0_provides_no_match_for_the_signature_1,io(n),ao(A,void 0,void 0,a)),0}return m}function ye(n,t){return 0===n.parameters.length&&0===t.parameters.length?function(n,t){return P(e.Diagnostics.Call_signatures_with_no_arguments_have_incompatible_return_types_0_and_1,io(n),io(t))}:function(n,t){return P(e.Diagnostics.Call_signature_return_types_0_and_1_are_incompatible,io(n),io(t))}}function he(n,t){return 0===n.parameters.length&&0===t.parameters.length?function(n,t){return P(e.Diagnostics.Construct_signatures_with_no_arguments_have_incompatible_return_types_0_and_1,io(n),io(t))}:function(n,t){return P(e.Diagnostics.Construct_signature_return_types_0_and_1_are_incompatible,io(n),io(t))}}function ve(e,n,t,a,i){return gg(t?$u(e):e,t?$u(n):n,r===or?8:0,a,F,i,j,n_(se))}function be(e,n,t){var r=yu(e,t),a=yu(n,t);if(r.length!==a.length)return 0;for(var i=-1,o=0;o<r.length;o++){var s=ny(r[o],a[o],!1,!1,!1,j);if(!s)return 0;i&=s}return i}function Ee(n,t,r,a){for(var i=-1,o=2097152&n.flags?Ol(n):kl(n),s=0,c=o;s<c.length;s++){var l=c[s];if(!Dg(n,l)){var u=wr(l).nameType;if(!(u&&8192&u.flags)&&(0===r||bT(l.escapedName))){var d=ws(l),p=32768&d.flags||!(0===r&&16777216&l.flags)?d:Lv(d,524288),f=j(p,t,a);if(!f)return a&&F(e.Diagnostics.Property_0_is_incompatible_with_index_signature,ro(l)),0;i&=f}}}return i}function Te(n,t,r){var a=j(n,t,r);return!a&&r&&F(e.Diagnostics.Index_signatures_are_incompatible),a}function Se(n,t,a,i,o,s){if(r===lr)return Le(n,t,a);var c=Eu(t,a);if(!c)return-1;if(1&c.flags&&!i){var l=0===a?c:Eu(t,0);if(l&&1&l.flags)return-1}if(Il(n))return Eu(t,0)?j(El(n),c,o):0;var u=Eu(n,a)||1===a&&Eu(n,0);if(u)return Te(u,c,o);if(!(1&s)&&Qy(n)){var d=Ee(n,c,a,o);if(d&&0===a){var p=Eu(n,1);p&&(d&=Te(p,c,o))}return d}return o&&F(e.Diagnostics.Index_signature_is_missing_in_type_0,io(n)),0}function Le(e,n,t){var r=bu(n,t),a=bu(e,t);return a||r?a&&r&&a.isReadonly===r.isReadonly?j(a.type,r.type):0:-1}function De(n,t,r){if(!n.declaration||!t.declaration)return!0;var a=e.getSelectedEffectiveModifierFlags(n.declaration,24),i=e.getSelectedEffectiveModifierFlags(t.declaration,24);return 8===i||(16===i&&8!==a||(16!==i&&!a||(r&&F(e.Diagnostics.Cannot_assign_a_0_constructor_type_to_a_1_constructor_type,_o(a),_o(i)),!1)))}}function Ig(n){if(16&n.flags)return!1;if(3145728&n.flags)return!!e.forEach(n.types,Ig);if(465829888&n.flags){var t=Fl(n);if(t&&t!==n)return Ig(t)}return hy(n)||!!(134217728&n.flags)}function Ng(e,n,t){return void 0===t&&(t=j_),_w(e,n,t,!0)||uw(e,n)||dw(e,n)||pw(e,n)||fw(e,n)}function kg(n,t,r,a,i){for(var o=n.types.map((function(e){})),s=0,c=t;s<c.length;s++){var l=c[s],u=l[0],d=l[1],p=su(n,d);if(!(i&&p&&16&e.getCheckFlags(p)))for(var f=0,m=0,_=n.types;m<_.length;m++){var g=_[m],y=Io(g,d);y&&r(u(),y)?o[f]=void 0===o[f]||o[f]:o[f]=!1,f++}}var h=o.indexOf(!0);if(-1===h)return a;var v=o.indexOf(!0,h+1);while(-1!==v){if(!U_(n.types[h],n.types[v]))return a;v=o.indexOf(!0,v+1)}return n.types[h]}function Rg(n){if(524288&n.flags){var t=Nl(n);return 0===t.callSignatures.length&&0===t.constructSignatures.length&&!t.stringIndexInfo&&!t.numberIndexInfo&&t.properties.length>0&&e.every(t.properties,(function(e){return!!(16777216&e.flags)}))}return!!(2097152&n.flags)&&e.every(n.types,Rg)}function Og(e,n,t){for(var r=0,a=wl(e);r<a.length;r++){var i=a[r];if(rS(n,i.escapedName,t))return!0}return!1}function wg(n,t,r){var a=vd(n,e.map(n.typeParameters,(function(e){return e===t?r:e})));return a.objectFlags|=4096,a}function Pg(e){var n=wr(e);return Mg(n.typeParameters,n,(function(t,r,a){var i=Ld(e,Xm(n.typeParameters,$m(r,a)));return i.aliasTypeArgumentsContainsMarker=!0,i}))}function Mg(n,t,r){var a,i,o;void 0===n&&(n=e.emptyArray);var s=t.variances;if(!s){null===e.tracing||void 0===e.tracing||e.tracing.push("checkTypes","getVariancesWorker",{arity:n.length,id:null!==(o=null!==(a=t.id)&&void 0!==a?a:null===(i=t.declaredType)||void 0===i?void 0:i.id)&&void 0!==o?o:-1}),t.variances=e.emptyArray,s=[];for(var c=function(e){var n=!1,a=!1,i=lt;lt=function(e){return e?a=!0:n=!0};var o=r(t,e,mn),c=r(t,e,_n),l=(W_(c,o)?1:0)|(W_(o,c)?2:0);3===l&&W_(r(t,e,ut),o)&&(l=4),lt=i,(n||a)&&(n&&(l|=8),a&&(l|=16)),s.push(l)},l=0,u=n;l<u.length;l++){var d=u[l];c(d)}t.variances=s,null===e.tracing||void 0===e.tracing||e.tracing.pop()}return s}function Fg(e){return e===xn||e===Ln||8&e.objectFlags?A:Mg(e.typeParameters,e,wg)}function Gg(e,n){for(var t=0;t<n.length;t++)if(1===(7&n[t])&&16384&e[t].flags)return!0;return!1}function Bg(e){return 262144&e.flags&&!Gl(e)}function Ug(n){return!!(4&e.getObjectFlags(n))&&!n.node}function Vg(n){return Ug(n)&&e.some(Td(n),(function(e){return!!(262144&e.flags)||Vg(e)}))}function jg(e,n,t){void 0===t&&(t=0);for(var r=""+e.target.id,a=0,i=Td(e);a<i.length;a++){var o=i[a];if(Bg(o)){var s=n.indexOf(o);s<0&&(s=n.length,n.push(o)),r+="="+s}else t<4&&Vg(o)?r+="<"+jg(o,n,t+1)+">":r+="-"+o.id}return r}function Kg(e,n,t,r){if(r===lr&&e.id>n.id){var a=e;e=n,n=a}var i=t?":"+t:"";if(Vg(e)&&Vg(n)){var o=[];return jg(e,o)+","+jg(n,o)+i}return e.id+","+n.id+i}function Hg(n,t){if(!(6&e.getCheckFlags(n)))return t(n);for(var r=0,a=n.containingType.types;r<a.length;r++){var i=a[r],o=_u(i,n.escapedName),s=o&&Hg(o,t);if(s)return s}}function Wg(e){return e.parent&&32&e.parent.flags?mc(hi(e)):void 0}function zg(e){var n=Wg(e),t=n&&Qs(n)[0];return t&&Io(t,e.escapedName)}function qg(e,n){return Hg(e,(function(e){var t=Wg(e);return!!t&&Fs(t,n)}))}function Jg(n,t){return!Hg(t,(function(t){return!!(16&e.getDeclarationModifierFlagsFromSymbol(t))&&!qg(n,Wg(t))}))}function Xg(n,t,r){return Hg(t,(function(t){return!!(16&e.getDeclarationModifierFlagsFromSymbol(t,r))&&!Fs(n,Wg(t))}))?void 0:n}function Yg(e,n,t){if(t>=5)for(var r=Qg(e),a=0,i=0;i<t;i++)if(Qg(n[i])===r&&(a++,a>=5))return!0;return!1}function Qg(n){if(524288&n.flags&&!Xh(n)){if(e.getObjectFlags(n)&&n.node)return n.node;if(n.symbol&&!(16&e.getObjectFlags(n)&&32&n.symbol.flags))return n.symbol;if(Cy(n))return n.target}if(262144&n.flags)return n.symbol;if(8388608&n.flags){do{n=n.objectType}while(8388608&n.flags);return n}return 16777216&n.flags?n.root:n}function Zg(e,n){return 0!==$g(e,n,V_)}function $g(n,t,r){if(n===t)return-1;var a=24&e.getDeclarationModifierFlagsFromSymbol(n),i=24&e.getDeclarationModifierFlagsFromSymbol(t);if(a!==i)return 0;if(a){if(AN(n)!==AN(t))return 0}else if((16777216&n.flags)!==(16777216&t.flags))return 0;return gD(n)!==gD(t)?0:r(ws(n),ws(t))}function ey(e,n,t){var r=BL(e),a=BL(n),i=UL(e),o=UL(n),s=VL(e),c=VL(n);return r===a&&i===o&&s===c||!!(t&&i<=o)}function ny(n,t,r,a,i,o){if(n===t)return-1;if(!ey(n,t,r))return 0;if(e.length(n.typeParameters)!==e.length(t.typeParameters))return 0;if(t.typeParameters){for(var s=Qm(n.typeParameters,t.typeParameters),c=0;c<t.typeParameters.length;c++){var l=n.typeParameters[c],u=t.typeParameters[c];if(!(l===u||o(A_(md(l),s)||Ne,md(u)||Ne)&&o(A_($l(l),s)||Ne,$l(u)||Ne)))return 0}n=p_(n,s,!0)}var d=-1;if(!a){var p=Uu(n);if(p){var f=Uu(t);if(f){var m=o(p,f);if(!m)return 0;d&=m}}}var _=BL(t);for(c=0;c<_;c++){l=ML(n,c),u=ML(t,c),m=o(u,l);if(!m)return 0;d&=m}if(!i){var g=Vu(n),y=Vu(t);d&=g||y?ty(g,y,o):o(Hu(n),Hu(t))}return d}function ty(e,n,t){return e&&n&&$p(e,n)?e.type===n.type?-1:e.type&&n.type?t(e.type,n.type):0:0}function ry(e){for(var n,t=0,r=e;t<r.length;t++){var a=r[t],i=Ty(a);if(n||(n=i),i===a||i!==n)return!1}return!0}function ay(n){return 1===n.length?n[0]:ry(n)?Qp(n):e.reduceLeft(n,(function(e,n){return H_(e,n)?n:e}))}function iy(n){if(!z)return ay(n);var t=e.filter(n,(function(e){return!(98304&e.flags)}));return t.length?Vy(ay(t),98304&My(n)):Qp(n,2)}function oy(n){return e.reduceLeft(n,(function(e,n){return H_(n,e)?n:e}))}function sy(n){return!!(4&e.getObjectFlags(n))&&(n.target===xn||n.target===Ln)}function cy(n){return!!(4&e.getObjectFlags(n))&&n.target===Ln}function ly(e){return sy(e)&&!cy(e)||Cy(e)&&!e.target.readonly}function uy(e){return sy(e)?Td(e)[0]:void 0}function dy(e){return sy(e)||!(98304&e.flags)&&W_(e,On)}function py(n){if(4&e.getObjectFlags(n)&&3&e.getObjectFlags(n.target)){if(33554432&e.getObjectFlags(n))return 67108864&e.getObjectFlags(n)?n.cachedEquivalentBaseType:void 0;n.objectFlags|=33554432;var t=n.target,r=Qs(t);if(1===r.length&&!Pc(n.symbol).size){var a=e.length(t.typeParameters)?A_(r[0],Qm(t.typeParameters,Td(n).slice(0,t.typeParameters.length))):r[0];return e.length(Td(n))>e.length(t.typeParameters)&&(a=Fc(a,e.last(Td(n)))),n.objectFlags|=67108864,n.cachedEquivalentBaseType=a}}}function fy(e){var n=uy(e);return z?n===Xe:n===Re}function my(e){return Cy(e)||!!_u(e,"0")}function _y(e){return dy(e)||my(e)}function gy(e,n){var t=Io(e,""+n);return t||($v(e,Cy)?rb(e,(function(e){return ky(e)||ke})):void 0)}function yy(e){return!(240512&e.flags)}function hy(e){return!!(109440&e.flags)}function vy(n){return 2097152&n.flags?e.some(n.types,hy):!!(109440&n.flags)}function by(n){return 2097152&n.flags&&e.find(n.types,hy)||n}function Ey(n){return!!(16&n.flags)||(1048576&n.flags?!!(1024&n.flags)||e.every(n.types,hy):hy(n))}function Ty(e){return 1024&e.flags?lc(e):128&e.flags?Me:256&e.flags?Fe:2048&e.flags?Ge:512&e.flags?Ke:1048576&e.flags?rb(e,Ty):e}function Sy(e){return 1024&e.flags&&Mm(e)?lc(e):128&e.flags&&Mm(e)?Me:256&e.flags&&Mm(e)?Fe:2048&e.flags&&Mm(e)?Ge:512&e.flags&&Mm(e)?Ke:1048576&e.flags?rb(e,Sy):e}function xy(e){return 8192&e.flags?He:1048576&e.flags?rb(e,xy):e}function Ly(e,n){return aA(e,n)||(e=xy(Sy(e))),e}function Dy(e,n,t){if(e&&hy(e)){var r=n?t?mC(n):n:void 0;e=Ly(e,r)}return e}function Ay(e,n,t,r){if(e&&hy(e)){var a=n?tN(t,n,r):void 0;e=Ly(e,a)}return e}function Cy(n){return!!(4&e.getObjectFlags(n)&&8&n.target.objectFlags)}function Iy(e){return Cy(e)&&!!(8&e.target.combinedFlags)}function Ny(e){return Iy(e)&&1===e.target.elementFlags.length}function ky(e){return Oy(e,e.target.fixedLength)}function Ry(e){var n=ky(e);return n&&Ep(n)}function Oy(e,n,t,r){void 0===t&&(t=0),void 0===r&&(r=!1);var a=Sd(e)-t;if(n<a){for(var i=Td(e),o=[],s=n;s<a;s++){var c=i[s];o.push(8&e.target.elementFlags[s]?im(c,Fe):c)}return r?pf(o):Qp(o)}}function wy(n,t){return Sd(n)===Sd(t)&&e.every(n.target.elementFlags,(function(e,n){return(12&e)===(12&t.target.elementFlags[n])}))}function Py(e){var n=e.value;return"0"===n.base10Value}function My(e){for(var n=0,t=0,r=e;t<r.length;t++){var a=r[t];n|=Fy(a)}return n}function Fy(e){return 1048576&e.flags?My(e.types):128&e.flags?""===e.value?128:0:256&e.flags?0===e.value?256:0:2048&e.flags?Py(e)?2048:0:512&e.flags?e===Be||e===Ue?512:0:117724&e.flags}function Gy(e){return 117632&Fy(e)?nb(e,(function(e){return!(117632&Fy(e))})):e}function By(e){return rb(e,Uy)}function Uy(e){return 4&e.flags?Rt:8&e.flags?Ot:64&e.flags?wt:e===Ue||e===Be||114691&e.flags||128&e.flags&&""===e.value||256&e.flags&&0===e.value||2048&e.flags&&Py(e)?e:ze}function Vy(e,n){var t=n&~e.flags&98304;return 0===t?e:Qp(32768===t?[e,ke]:65536===t?[e,we]:[e,ke,we])}function jy(n){return e.Debug.assert(z),32768&n.flags?n:Qp([n,ke])}function Ky(e){var n=Lv(e,2097152);return wn||(wn=zd("NonNullable",524288,void 0)||Te),wn!==Te?Ld(wn,[n]):n}function Hy(e){return z?Ky(e):e}function Wy(e){return z?Qp([e,Oe]):e}function zy(e){return e!==Oe}function qy(e){return z?nb(e,zy):e}function Jy(n,t,r){return r?e.isOutermostOptionalChain(t)?jy(n):Wy(n):n}function Xy(n,t){return e.isExpressionOfOptionalChainRoot(t)?Hy(n):e.isOptionalChain(t)?qy(n):n}function Yy(e,n){return 0!==(524&e.flags)&&0!==(28&n.flags)}function Qy(n){return 2097152&n.flags?e.every(n.types,Qy):!(!n.symbol||0===(7040&n.symbol.flags)||Zk(n))||!!(1024&e.getObjectFlags(n)&&Qy(n.source))}function Zy(n,t){var r=Sr(n.flags,n.escapedName,8&e.getCheckFlags(n));r.declarations=n.declarations,r.parent=n.parent,r.type=t,r.target=n,n.valueDeclaration&&(r.valueDeclaration=n.valueDeclaration);var a=wr(n).nameType;return a&&(r.nameType=a),r}function $y(n,t){for(var r=e.createSymbolTable(),a=0,i=kl(n);a<i.length;a++){var o=i[a],s=ws(o),c=t(s);r.set(o.escapedName,c===s?o:Zy(o,c))}return r}function eh(n){if(!(Jh(n)&&16384&e.getObjectFlags(n)))return n;var t=n.regularType;if(t)return t;var r=n,a=$y(n,eh),i=Bi(r.symbol,a,r.callSignatures,r.constructSignatures,r.stringIndexInfo,r.numberIndexInfo);return i.flags=r.flags,i.objectFlags|=-16385&r.objectFlags,n.regularType=i,i}function nh(e,n,t){return{parent:e,propertyName:n,siblings:t,resolvedProperties:void 0}}function th(e){if(!e.siblings){for(var n=[],t=0,r=th(e.parent);t<r.length;t++){var a=r[t];if(Jh(a)){var i=Rl(a,e.propertyName);i&&Qv(ws(i),(function(e){n.push(e)}))}}e.siblings=n}return e.siblings}function rh(n){if(!n.resolvedProperties){for(var t=new e.Map,r=0,a=th(n);r<a.length;r++){var i=a[r];if(Jh(i)&&!(4194304&e.getObjectFlags(i)))for(var o=0,s=wl(i);o<s.length;o++){var c=s[o];t.set(c.escapedName,c)}}n.resolvedProperties=e.arrayFrom(t.values())}return n.resolvedProperties}function ah(e,n){if(!(4&e.flags))return e;var t=ws(e),r=n&&nh(n,e.escapedName,void 0),a=ch(t,r);return a===t?e:Zy(e,a)}function ih(e){var n=Ee.get(e.escapedName);if(n)return n;var t=Zy(e,ke);return t.flags|=16777216,Ee.set(e.escapedName,t),t}function oh(n,t){for(var r=e.createSymbolTable(),a=0,i=kl(n);a<i.length;a++){var o=i[a];r.set(o.escapedName,ah(o,t))}if(t)for(var s=0,c=rh(t);s<c.length;s++){o=c[s];r.has(o.escapedName)||r.set(o.escapedName,ih(o))}var l=bu(n,0),u=bu(n,1),d=Bi(n.symbol,r,e.emptyArray,e.emptyArray,l&&ud(sh(l.type),l.isReadonly),u&&ud(sh(u.type),u.isReadonly));return d.objectFlags|=532480&e.getObjectFlags(n),d}function sh(e){return ch(e,void 0)}function ch(n,t){if(393216&e.getObjectFlags(n)){if(void 0===t&&n.widened)return n.widened;var r=void 0;if(98305&n.flags)r=xe;else if(Jh(n))r=oh(n,t);else if(1048576&n.flags){var a=t||nh(void 0,void 0,n.types),i=e.sameMap(n.types,(function(e){return 98304&e.flags?e:ch(e,a)}));r=Qp(i,e.some(i,bg)?2:1)}else 2097152&n.flags?r=pf(e.sameMap(n.types,sh)):(sy(n)||Cy(n))&&(r=vd(n.target,e.sameMap(Td(n),sh)));return r&&void 0===t&&(n.widened=r),r||n}return n}function lh(n){var t=!1;if(131072&e.getObjectFlags(n)){if(1048576&n.flags)if(e.some(n.types,bg))t=!0;else for(var r=0,a=n.types;r<a.length;r++){var i=a[r];lh(i)&&(t=!0)}if(sy(n)||Cy(n))for(var o=0,s=Td(n);o<s.length;o++){i=s[o];lh(i)&&(t=!0)}if(Jh(n))for(var c=0,l=kl(n);c<l.length;c++){var u=l[c];i=ws(u);131072&e.getObjectFlags(i)&&(lh(i)||gr(u.valueDeclaration,e.Diagnostics.Object_literal_s_property_0_implicitly_has_an_1_type,ro(u),io(sh(i))),t=!0)}}return t}function uh(n,t,r){var a=io(sh(t));if(!e.isInJSFile(n)||e.isCheckJsEnabledForFile(e.getSourceFileOfNode(n),C)){var i;switch(n.kind){case 217:case 164:case 163:i=Y?e.Diagnostics.Member_0_implicitly_has_an_1_type:e.Diagnostics.Member_0_implicitly_has_an_1_type_but_a_better_type_may_be_inferred_from_usage;break;case 161:var o=n;if(e.isIdentifier(o.name)&&(e.isCallSignatureDeclaration(o.parent)||e.isMethodSignature(o.parent)||e.isFunctionTypeNode(o.parent))&&o.parent.parameters.indexOf(o)>-1&&(Vr(o,o.name.escapedText,788968,void 0,o.name.escapedText,!0)||o.name.originalKeywordKind&&e.isTypeNodeKind(o.name.originalKeywordKind))){var s="arg"+o.parent.parameters.indexOf(o);return void hr(Y,n,e.Diagnostics.Parameter_has_a_name_but_no_type_Did_you_mean_0_Colon_1,s,e.declarationNameToString(o.name))}i=n.dotDotDotToken?Y?e.Diagnostics.Rest_parameter_0_implicitly_has_an_any_type:e.Diagnostics.Rest_parameter_0_implicitly_has_an_any_type_but_a_better_type_may_be_inferred_from_usage:Y?e.Diagnostics.Parameter_0_implicitly_has_an_1_type:e.Diagnostics.Parameter_0_implicitly_has_an_1_type_but_a_better_type_may_be_inferred_from_usage;break;case 199:if(i=e.Diagnostics.Binding_element_0_implicitly_has_an_1_type,!Y)return;break;case 309:return void gr(n,e.Diagnostics.Function_type_which_lacks_return_type_annotation_implicitly_has_an_0_return_type,a);case 252:case 166:case 165:case 168:case 169:case 209:case 210:if(Y&&!n.name)return void gr(n,3===r?e.Diagnostics.Generator_implicitly_has_yield_type_0_because_it_does_not_yield_any_values_Consider_supplying_a_return_type_annotation:e.Diagnostics.Function_expression_which_lacks_return_type_annotation_implicitly_has_an_0_return_type,a);i=Y?3===r?e.Diagnostics._0_which_lacks_return_type_annotation_implicitly_has_an_1_yield_type:e.Diagnostics._0_which_lacks_return_type_annotation_implicitly_has_an_1_return_type:e.Diagnostics._0_implicitly_has_an_1_return_type_but_a_better_type_may_be_inferred_from_usage;break;case 191:return void(Y&&gr(n,e.Diagnostics.Mapped_object_type_implicitly_has_an_any_template_type));default:i=Y?e.Diagnostics.Variable_0_implicitly_has_an_1_type:e.Diagnostics.Variable_0_implicitly_has_an_1_type_but_a_better_type_may_be_inferred_from_usage}hr(Y,n,i,e.declarationNameToString(e.getNameOfDeclaration(n)),a)}}function dh(n,r,a){!(t&&Y&&131072&e.getObjectFlags(r))||a&&uT(n)||lh(r)||uh(n,r,a)}function ph(e,n,t){var r=BL(e),a=BL(n),i=jL(e),o=jL(n),s=o?a-1:a,c=i?s:Math.min(r,s),l=Uu(e);if(l){var u=Uu(n);u&&t(l,u)}for(var d=0;d<c;d++)t(ML(e,d),ML(n,d));o&&t(GL(e,c),o)}function fh(e,n,t){var r=Vu(e),a=Vu(n);r&&a&&$p(r,a)&&r.type&&a.type?t(r.type,a.type):t(Hu(e),Hu(n))}function mh(e,n,t,r){return gh(e.map(vh),n,t,r||j_)}function _h(n,t){return void 0===t&&(t=0),n&&gh(e.map(n.inferences,bh),n.signature,n.flags|t,n.compareTypes)}function gh(e,n,t,r){var a={inferences:e,signature:n,flags:t,compareTypes:r,mapper:n_((function(e){return yh(a,e,!0)})),nonFixingMapper:n_((function(e){return yh(a,e,!1)}))};return a}function yh(e,n,t){for(var r=e.inferences,a=0;a<r.length;a++){var i=r[a];if(n===i.typeParameter)return t&&!i.isFixed&&(hh(r),i.isFixed=!0),$h(e,a)}return n}function hh(e){for(var n=0,t=e;n<t.length;n++){var r=t[n];r.isFixed||(r.inferredType=void 0)}}function vh(e){return{typeParameter:e,candidates:void 0,contraCandidates:void 0,inferredType:void 0,priority:void 0,topLevel:!0,isFixed:!1,impliedArity:void 0}}function bh(e){return{typeParameter:e.typeParameter,candidates:e.candidates&&e.candidates.slice(),contraCandidates:e.contraCandidates&&e.contraCandidates.slice(),inferredType:e.inferredType,priority:e.priority,topLevel:e.topLevel,isFixed:e.isFixed,impliedArity:e.impliedArity}}function Eh(n){var t=e.filter(n.inferences,dA);return t.length?gh(e.map(t,bh),n.signature,n.flags,n.compareTypes):void 0}function Th(e){return e&&e.mapper}function Sh(n){var t=e.getObjectFlags(n);if(1048576&t)return!!(2097152&t);var r=!!(465829888&n.flags||524288&n.flags&&!xh(n)&&(4&t&&(n.node||e.forEach(Td(n),Sh))||16&t&&n.symbol&&14384&n.symbol.flags&&n.symbol.declarations||8389664&t)||3145728&n.flags&&!(1024&n.flags)&&!xh(n)&&e.some(n.types,Sh));return 3899393&n.flags&&(n.objectFlags|=1048576|(r?2097152:0)),r}function xh(n){if(n.aliasSymbol&&!n.aliasTypeArguments){var t=e.getDeclarationOfKind(n.aliasSymbol,255);return!(!t||!e.findAncestor(t.parent,(function(e){return 298===e.kind||257!==e.kind&&"quit"})))}return!1}function Lh(n,t){return!!(n===t||3145728&n.flags&&e.some(n.types,(function(e){return Lh(e,t)}))||16777216&n.flags&&(mm(n)===t||_m(n)===t))}function Dh(n){var t=e.createSymbolTable();Qv(n,(function(n){if(128&n.flags){var r=e.escapeLeadingUnderscores(n.value),a=Sr(4,r);a.type=xe,n.symbol&&(a.declarations=n.symbol.declarations,a.valueDeclaration=n.symbol.valueDeclaration),t.set(r,a)}}));var r=4&n.flags?ud(an,!1):void 0;return Bi(void 0,t,e.emptyArray,e.emptyArray,r,void 0)}function Ah(e,n,t){if(!Lt){var r=e.id+","+n.id+","+t.id;if(xt.has(r))return xt.get(r);Lt=!0;var a=Ih(e,n,t);return Lt=!1,xt.set(r,a),a}}function Ch(n){return!(524288&e.getObjectFlags(n))||Jh(n)&&e.some(wl(n),(function(e){return Ch(ws(e))}))||Cy(n)&&e.some(Td(n),Ch)}function Ih(n,t,r){if(bu(n,0)||0!==wl(n).length&&Ch(n)){if(sy(n))return Ep(kh(Td(n)[0],t,r),cy(n));if(Cy(n)){var a=e.map(Td(n),(function(e){return kh(e,t,r)})),i=4&Ll(t)?e.sameMap(n.target.elementFlags,(function(e){return 2&e?1:e})):n.target.elementFlags;return Np(a,i,n.target.readonly,n.target.labeledElementDeclarations)}var o=Ri(1040,void 0);return o.source=n,o.mappedType=t,o.constraintType=r,o}}function Nh(e){var n=wr(e);return n.type||(n.type=kh(e.propertyType,e.mappedType,e.constraintType)),n.type}function kh(e,n,t){var r=im(t.type,hl(n)),a=El(n),i=vh(r);return Hh([i],e,a),Mh(i)||Ne}function Rh(n,t,r,a){var i,o,s,l,u,d,p;return c(this,(function(c){switch(c.label){case 0:i=wl(t),o=0,s=i,c.label=1;case 1:return o<s.length?(l=s[o],Sc(l)||!r&&(16777216&l.flags||48&e.getCheckFlags(l))?[3,5]:(u=_u(n,l.escapedName),u?[3,3]:[4,l])):[3,6];case 2:return c.sent(),[3,5];case 3:return a?(d=ws(l),109440&d.flags?(p=ws(u),1&p.flags||Pm(p)===Pm(d)?[3,5]:[4,l]):[3,5]):[3,5];case 4:c.sent(),c.label=5;case 5:return o++,[3,1];case 6:return[2]}}))}function Oh(e,n,t,r){var a=Rh(e,n,t,r).next();if(!a.done)return a.value}function wh(e,n){return!(8&n.target.combinedFlags)&&n.target.minLength>e.target.minLength||!n.target.hasRestElement&&(e.target.hasRestElement||n.target.fixedLength<e.target.fixedLength)}function Ph(e,n){return Cy(e)&&Cy(n)?wh(e,n):!!Oh(e,n,!1,!0)&&!!Oh(n,e,!1,!1)}function Mh(e){return e.candidates?Qp(e.candidates,2):e.contraCandidates?pf(e.contraCandidates):void 0}function Fh(e){return!!Pr(e).skipDirectInference}function Gh(n){return!(!n.symbol||!e.some(n.symbol.declarations,Fh))}function Bh(n){var t=e.createScanner(99,!1),r=!0;t.setOnError((function(){return r=!1})),t.setText(n+"n");var a=t.scan();40===a&&(a=t.scan());var i=t.getTokenFlags();return r&&9===a&&t.getTextPos()===n.length+1&&!(512&i)}function Uh(e,n){if(e===n||5&n.flags)return!0;if(128&e.flags){var t=e.value;return!!(8&n.flags&&""!==t&&isFinite(+t)||64&n.flags&&""!==t&&Bh(t)||98816&n.flags&&t===n.intrinsicName)}if(134217728&e.flags){var r=e.texts;return 2===r.length&&""===r[0]&&""===r[1]&&W_(e.types[0],n)}return W_(e,n)}function Vh(n,t){return 128&n.flags?Kh([n.value],e.emptyArray,t):134217728&n.flags?e.arraysEqual(n.texts,t.texts)?e.map(n.types,jh):Kh(n.texts,n.types,t):void 0}function jh(e){return 402653317&e.flags?e:Of(["",""],[e])}function Kh(e,n,t){var r=e.length-1,a=e[0],o=e[r],s=t.texts,c=s.length-1,l=s[0],u=s[c];if(!(0===r&&a.length<l.length+u.length)&&a.startsWith(l)&&o.endsWith(u)){for(var d=o.slice(0,o.length-u.length),p=[],f=0,m=l.length,_=1;_<c;_++){var g=s[_];if(g.length>0){var y=f,h=m;while(1){if(h=v(y).indexOf(g,h),h>=0)break;if(y++,y===e.length)return;h=0}b(y,h),m+=g.length}else if(m<v(f).length)b(f,m+1);else{if(!(f<r))return;b(f+1,0)}}return b(r,v(r).length),p}function v(n){return n<r?e[n]:d}function b(t,r){var a=t===f?Fm(v(t).slice(m,r)):Of(i(i([e[f].slice(m)],e.slice(f+1,t)),[v(t).slice(0,r)]),n.slice(f,t));p.push(a),f=t,m=r}}function Hh(n,t,r,a,i){void 0===a&&(a=0),void 0===i&&(i=!1);var o,s,c,l,u=!1,d=2048,p=!0,f=0;function m(t,s){if(Sh(s)){if(t===De){var c=o;return o=t,m(s,s),void(o=c)}if(t.aliasSymbol&&t.aliasTypeArguments&&t.aliasSymbol===s.aliasSymbol)h(t.aliasTypeArguments,s.aliasTypeArguments,Pg(t.aliasSymbol));else if(t===s&&3145728&t.flags)for(var l=0,f=t.types;l<f.length;l++){var v=f[l];m(v,v)}else{if(1048576&s.flags){var E=y(1048576&t.flags?t.types:[t],s.types,Wh),S=E[0],A=E[1],C=y(S,A,zh),I=C[0],N=C[1];if(0===N.length)return;if(s=Qp(N),0===I.length)return void _(t,s,1);t=Qp(I)}else if(2097152&s.flags&&e.some(s.types,(function(e){return!!b(e)||Il(e)&&!!b(y_(e)||ze)}))){if(!(1048576&t.flags)){var k=y(2097152&t.flags?t.types:[t],s.types,U_);I=k[0],N=k[1];if(0===I.length||0===N.length)return;t=pf(I),s=pf(N)}}else 41943040&s.flags&&(s=um(s));if(8650752&s.flags){if(524288&e.getObjectFlags(t)||t===Ce||t===qe||128&a&&(t===Le||t===Rn)||Gh(t))return;var R=b(s);if(R){if(!R.isFixed){if((void 0===R.priority||a<R.priority)&&(R.candidates=void 0,R.contraCandidates=void 0,R.topLevel=!0,R.priority=a),a===R.priority){var O=o||t;i&&!u?e.contains(R.contraCandidates,O)||(R.contraCandidates=e.append(R.contraCandidates,O),hh(n)):e.contains(R.candidates,O)||(R.candidates=e.append(R.candidates,O),hh(n))}!(128&a)&&262144&s.flags&&R.topLevel&&!Lh(r,s)&&(R.topLevel=!1,hh(n))}return void(d=Math.min(d,a))}var w=Qf(s,!1);if(w!==s)g(t,w,m);else if(8388608&s.flags){var P=Qf(s.indexType,!1);if(465829888&P.flags){var M=Zf(Qf(s.objectType,!1),P,!1);M&&M!==s&&g(t,M,m)}}}if(!(4&e.getObjectFlags(t)&&4&e.getObjectFlags(s)&&(t.target===s.target||sy(t)&&sy(s)))||t.node&&s.node)if(4194304&t.flags&&4194304&s.flags)i=!i,m(t.type,s.type),i=!i;else if((Ey(t)||4&t.flags)&&4194304&s.flags){var F=Dh(t);i=!i,_(F,s.type,256),i=!i}else if(8388608&t.flags&&8388608&s.flags)m(t.objectType,s.objectType),m(t.indexType,s.indexType);else if(268435456&t.flags&&268435456&s.flags)t.symbol===s.symbol&&m(t.type,s.type);else if(33554432&t.flags){m(t.baseType,s);var G=a;a|=4,m(t.substitute,s),a=G}else if(16777216&s.flags)g(t,s,x);else if(3145728&s.flags)T(t,s.types,s.flags);else if(1048576&t.flags)for(var B=t.types,U=0,V=B;U<V.length;U++){var j=V[U];m(j,s)}else if(134217728&s.flags)L(t,s);else{if(t=lu(t),!(512&a&&467927040&t.flags)){var K=au(t);if(K!==t&&p&&!(2621440&K.flags))return p=!1,m(K,s);t=K}2621440&t.flags&&g(t,s,D)}else h(Td(t),Td(s),Fg(t.target))}}}function _(e,n,t){var r=a;a|=t,m(e,n),a=r}function g(n,t,r){var a=n.id+","+t.id,i=s&&s.get(a);if(void 0===i){(s||(s=new e.Map)).set(a,-1);var o=d;d=2048;var u=f,p=Qg(n),m=Qg(t);e.contains(c,p)&&(f|=1),e.contains(l,m)&&(f|=2),3!==f?((c||(c=[])).push(p),(l||(l=[])).push(m),r(n,t),l.pop(),c.pop()):d=-1,f=u,s.set(a,d),d=Math.min(d,o)}else d=Math.min(d,i)}function y(n,t,r){for(var a,i,o=0,s=t;o<s.length;o++)for(var c=s[o],l=0,u=n;l<u.length;l++){var d=u[l];r(d,c)&&(m(d,c),a=e.appendIfUnique(a,d),i=e.appendIfUnique(i,c))}return[a?e.filter(n,(function(n){return!e.contains(a,n)})):n,i?e.filter(t,(function(n){return!e.contains(i,n)})):t]}function h(e,n,t){for(var r=e.length<n.length?e.length:n.length,a=0;a<r;a++)a<t.length&&2===(7&t[a])?v(e[a],n[a]):m(e[a],n[a])}function v(e,n){q||1024&a?(i=!i,m(e,n),i=!i):m(e,n)}function b(e){if(8650752&e.flags)for(var t=0,r=n;t<r.length;t++){var a=r[t];if(e===a.typeParameter)return a}}function E(n){for(var t,r=0,a=n;r<a.length;r++){var i=a[r],o=2097152&i.flags&&e.find(i.types,(function(e){return!!b(e)}));if(!o||t&&o!==t)return;t=o}return t}function T(n,t,r){var i=0;if(1048576&r){for(var o=void 0,s=1048576&n.flags?n.types:[n],c=new Array(s.length),l=!1,u=0,p=t;u<p.length;u++){var f=p[u];if(b(f))o=f,i++;else for(var g=0;g<s.length;g++){var y=d;d=2048,m(s[g],f),d===a&&(c[g]=!0),l=l||-1===d,d=Math.min(d,y)}}if(0===i){var h=E(t);return void(h&&_(n,h,1))}if(1===i&&!l){var v=e.flatMap(s,(function(e,n){return c[n]?void 0:e}));if(v.length)return void m(Qp(v),o)}}else for(var T=0,S=t;T<S.length;T++){f=S[T];b(f)?i++:m(n,f)}if(2097152&r?1===i:i>0)for(var x=0,L=t;x<L.length;x++){f=L[x];b(f)&&_(n,f,1)}}function S(n,t,r){if(1048576&r.flags){for(var a=!1,i=0,o=r.types;i<o.length;i++){var s=o[i];a=S(n,t,s)||a}return a}if(4194304&r.flags){var c=b(r.type);if(c&&!c.isFixed&&!Gh(n)){var l=Ah(n,t,r);l&&_(l,c.typeParameter,524288&e.getObjectFlags(n)?16:8)}return!0}if(262144&r.flags){_(Cf(n),r,32);var u=Fl(r);if(u&&S(n,t,u))return!0;var d=e.map(wl(n),ws),p=Eu(n,0),f=Af(n),g=f&&f.type;return m(Qp(e.append(e.append(d,p),g)),El(t)),!0}return!1}function x(e,n){if(16777216&e.flags)m(e.checkType,n.checkType),m(e.extendsType,n.extendsType),m(mm(e),mm(n)),m(_m(e),_m(n));else{var t=a;a|=i?64:0;var r=[mm(n),_m(n)];T(e,r,n.flags),a=t}}function L(e,n){for(var t=Vh(e,n),r=n.types,a=0;a<r.length;a++)m(t?t[a]:ze,r[a])}function D(n,t){if(4&e.getObjectFlags(n)&&4&e.getObjectFlags(t)&&(n.target===t.target||sy(n)&&sy(t)))h(Td(n),Td(t),Fg(n.target));else{if(Il(n)&&Il(t)){m(vl(n),vl(t)),m(El(n),El(t));var r=bl(n),a=bl(t);r&&a&&m(r,a)}if(32&e.getObjectFlags(t)&&!t.declaration.nameType){var i=vl(t);if(S(n,t,i))return}if(!Ph(n,t)){if(sy(n)||Cy(n)){if(Cy(t)){var o=Sd(n),s=Sd(t),c=Td(t),l=t.target.elementFlags;if(Cy(n)&&wy(n,t)){for(var u=0;u<s;u++)m(Td(n)[u],c[u]);return}var d=Cy(n)?Math.min(n.target.fixedLength,t.target.fixedLength):0,p=Math.min(Cy(n)?Gp(n.target,3):0,t.target.hasRestElement?Gp(t.target,3):0);for(u=0;u<d;u++)m(Td(n)[u],c[u]);if(!Cy(n)||o-d-p===1&&4&n.target.elementFlags[d]){var f=Td(n)[d];for(u=d;u<s-p;u++)m(8&l[u]?Ep(f):f,c[u])}else{var g=s-d-p;if(2===g&&l[d]&l[d+1]&8&&Cy(n)){var y=b(c[d]);y&&void 0!==y.impliedArity&&(m(Pp(n,d,p+o-y.impliedArity),c[d]),m(Pp(n,d+y.impliedArity,p),c[d+1]))}else if(1===g&&8&l[d]){var v=2&t.target.elementFlags[s-1],E=Cy(n)?Pp(n,d,p):Ep(Td(n)[0]);_(E,c[d],v?2:0)}else if(1===g&&4&l[d]){f=Cy(n)?Oy(n,d,p):Td(n)[0];f&&m(f,c[d])}}for(u=0;u<p;u++)m(Td(n)[o-u-1],c[s-u-1]);return}if(sy(t))return void N(n,t)}A(n,t),C(n,t,0),C(n,t,1),N(n,t)}}}function A(e,n){for(var t=kl(n),r=0,a=t;r<a.length;r++){var i=a[r],o=_u(e,i.escapedName);o&&m(ws(o),ws(i))}}function C(n,t,r){for(var a=yu(n,r),i=yu(t,r),o=a.length,s=i.length,c=o<s?o:s,l=!!(524288&e.getObjectFlags(n)),u=0;u<c;u++)I(rd(a[o-c+u]),$u(i[s-c+u]),l)}function I(e,n,t){if(!t){var r=u,a=n.declaration?n.declaration.kind:0;u=u||166===a||165===a||167===a,ph(e,n,v),u=r}fh(e,n,m)}function N(e,n){var t=Eu(n,0);if(t){var r=Eu(e,0)||Tu(e,0);r&&m(r,t)}var a=Eu(n,1);if(a){r=Eu(e,1)||Eu(e,0)||Tu(e,1);r&&m(r,a)}}m(t,r)}function Wh(e,n){return U_(e,n)||!!(4&n.flags&&128&e.flags||8&n.flags&&256&e.flags)}function zh(e,n){return!!(524288&e.flags&&524288&n.flags&&e.symbol&&e.symbol===n.symbol||e.aliasSymbol&&e.aliasTypeArguments&&e.aliasSymbol===n.aliasSymbol)}function qh(e){var n=Gl(e);return!!n&&AD(16777216&n.flags?jl(n):n,406978556)}function Jh(n){return!!(128&e.getObjectFlags(n))}function Xh(n){return!!(32896&e.getObjectFlags(n))}function Yh(n){if(n.length>1){var t=e.filter(n,Xh);if(t.length){var r=Qp(t,2);return e.concatenate(e.filter(n,(function(e){return!Xh(e)})),[r])}}return n}function Qh(e){return 416&e.priority?pf(e.contraCandidates):oy(e.contraCandidates)}function Zh(n,t){var r=Yh(n.candidates),a=qh(n.typeParameter),i=!a&&n.topLevel&&(n.isFixed||!Lh(Hu(t),n.typeParameter)),o=a?e.sameMap(r,Pm):i?e.sameMap(r,Sy):r,s=416&n.priority?Qp(o,2):iy(o);return sh(s)}function $h(e,n){var t=e.inferences[n];if(!t.inferredType){var r=void 0,a=e.signature;if(a){var i=t.candidates?Zh(t,a):void 0;if(t.contraCandidates){var o=Qh(t);r=!i||131072&i.flags||!H_(i,o)?o:i}else if(i)r=i;else if(1&e.flags)r=qe;else{var s=$l(t.typeParameter);s&&(r=A_(s,o_(a_(e,n),e.nonFixingMapper)))}}else r=Mh(t);t.inferredType=r||ev(!!(2&e.flags));var c=Gl(t.typeParameter);if(c){var l=A_(c,e.nonFixingMapper);r&&e.compareTypes(r,Fc(l,r))||(t.inferredType=r=l)}}return t.inferredType}function ev(e){return e?xe:Ne}function nv(e){for(var n=[],t=0;t<e.inferences.length;t++)n.push($h(e,t));return n}function tv(n){switch(n.escapedText){case"document":case"console":return e.Diagnostics.Cannot_find_name_0_Do_you_need_to_change_your_target_library_Try_changing_the_lib_compiler_option_to_include_dom;case"$":return C.types?e.Diagnostics.Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_jQuery_Try_npm_i_save_dev_types_Slashjquery_and_then_add_jquery_to_the_types_field_in_your_tsconfig:e.Diagnostics.Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_jQuery_Try_npm_i_save_dev_types_Slashjquery;case"describe":case"suite":case"it":case"test":return C.types?e.Diagnostics.Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_a_test_runner_Try_npm_i_save_dev_types_Slashjest_or_npm_i_save_dev_types_Slashmocha_and_then_add_jest_or_mocha_to_the_types_field_in_your_tsconfig:e.Diagnostics.Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_a_test_runner_Try_npm_i_save_dev_types_Slashjest_or_npm_i_save_dev_types_Slashmocha;case"process":case"require":case"Buffer":case"module":return C.types?e.Diagnostics.Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_node_Try_npm_i_save_dev_types_Slashnode_and_then_add_node_to_the_types_field_in_your_tsconfig:e.Diagnostics.Cannot_find_name_0_Do_you_need_to_install_type_definitions_for_node_Try_npm_i_save_dev_types_Slashnode;case"Map":case"Set":case"Promise":case"Symbol":case"WeakMap":case"WeakSet":case"Iterator":case"AsyncIterator":case"SharedArrayBuffer":case"Atomics":case"AsyncIterable":case"AsyncIterableIterator":case"AsyncGenerator":case"AsyncGeneratorFunction":case"BigInt":case"Reflect":case"BigInt64Array":case"BigUint64Array":return e.Diagnostics.Cannot_find_name_0_Do_you_need_to_change_your_target_library_Try_changing_the_lib_compiler_option_to_1_or_later;default:return 290===n.parent.kind?e.Diagnostics.No_value_exists_in_scope_for_the_shorthand_property_0_Either_declare_one_or_provide_an_initializer:e.Diagnostics.Cannot_find_name_0}}function rv(n){var t=Pr(n);return t.resolvedSymbol||(t.resolvedSymbol=!e.nodeIsMissing(n)&&Vr(n,n.escapedText,1160127,tv(n),n,!e.isWriteOnlyAccess(n),!1,e.Diagnostics.Cannot_find_name_0_Did_you_mean_1)||Te),t.resolvedSymbol}function av(n){return!!e.findAncestor(n,(function(e){return 177===e.kind||78!==e.kind&&158!==e.kind&&"quit"}))}function iv(e,n,t,r){switch(e.kind){case 78:var a=rv(e);return a!==Te?(r?w(r):"-1")+"|"+Up(n)+"|"+Up(t)+"|"+P(a):void 0;case 107:return"0|"+(r?w(r):"-1")+"|"+Up(n)+"|"+Up(t);case 226:case 208:return iv(e.expression,n,t,r);case 202:case 203:var i=cv(e);if(void 0!==i){var o=iv(e.expression,n,t,r);return o&&o+"."+i}}}function ov(n,t){switch(t.kind){case 208:case 226:return ov(n,t.expression);case 217:return e.isAssignmentExpression(t)&&ov(n,t.left)||e.isBinaryExpression(t)&&27===t.operatorToken.kind&&ov(n,t.right)}switch(n.kind){case 227:return 227===t.kind&&n.keywordToken===t.keywordToken&&n.name.escapedText===t.name.escapedText;case 78:case 79:return 78===t.kind&&rv(n)===rv(t)||(250===t.kind||199===t.kind)&&Li(rv(n))===yi(t);case 107:return 107===t.kind;case 105:return 105===t.kind;case 226:case 208:return ov(n.expression,t);case 202:case 203:return e.isAccessExpression(t)&&cv(n)===cv(t)&&ov(n.expression,t.expression);case 158:return e.isAccessExpression(t)&&n.right.escapedText===cv(t)&&ov(n.left,t.expression);case 217:return e.isBinaryExpression(n)&&27===n.operatorToken.kind&&ov(n.right,t)}return!1}function sv(e,n){return ov(e,n)||217===n.kind&&55===n.operatorToken.kind&&(sv(e,n.left)||sv(e,n.right))}function cv(n){return 202===n.kind?n.name.escapedText:e.isStringOrNumericLiteralLike(n.argumentExpression)?e.escapeLeadingUnderscores(n.argumentExpression.text):void 0}function lv(n,t){while(e.isAccessExpression(n))if(n=n.expression,ov(n,t))return!0;return!1}function uv(n,t){while(e.isOptionalChain(n))if(n=n.expression,ov(n,t))return!0;return!1}function dv(n,t){if(n&&1048576&n.flags){var r=su(n,t);if(r&&2&e.getCheckFlags(r))return void 0===r.isDiscriminantProperty&&(r.isDiscriminantProperty=192===(192&r.checkFlags)&&!AD(ws(r),465829888)),!!r.isDiscriminantProperty}return!1}function pv(e,n){for(var t,r=0,a=e;r<a.length;r++){var i=a[r];if(dv(n,i.escapedName)){if(t){t.push(i);continue}t=[i]}}return t}function fv(n,t){for(var r=new e.Map,a=0,i=function(e){if(61603840&e.flags){var n=Io(e,t);if(n){if(!Ey(n))return{value:void 0};var i=!1;Qv(n,(function(n){var t=Up(Pm(n)),a=r.get(t);a?a!==Ne&&(r.set(t,Ne),i=!0):r.set(t,e)})),i||a++}}},o=0,s=n;o<s.length;o++){var c=s[o],l=i(c);if("object"===typeof l)return l.value}return a>=10&&2*a>=n.length?r:void 0}function mv(n){var t=n.types;if(!(t.length<10||65536&e.getObjectFlags(n))){if(void 0===n.keyPropertyName){var r=e.forEach(t,(function(n){return 59506688&n.flags?e.forEach(wl(n),(function(e){return hy(ws(e))?e.escapedName:void 0})):void 0})),a=r&&fv(t,r);n.keyPropertyName=a?r:"",n.constituentMap=a}return n.keyPropertyName.length?n.keyPropertyName:void 0}}function _v(e,n){var t,r=null===(t=e.constituentMap)||void 0===t?void 0:t.get(Up(Pm(n)));return r!==Ne?r:void 0}function gv(e,n){var t=mv(e),r=t&&Io(n,t);return r&&_v(e,r)}function yv(n,t){var r=mv(n),a=r&&e.find(t.properties,(function(e){return e.symbol&&289===e.kind&&e.symbol.escapedName===r&&jE(e.initializer)})),i=a&&vA(a.initializer);return i&&_v(n,i)}function hv(e,n){return ov(e,n)||lv(e,n)}function vv(e,n){if(e.arguments)for(var t=0,r=e.arguments;t<r.length;t++){var a=r[t];if(hv(n,a))return!0}return!(202!==e.expression.kind||!hv(n,e.expression.expression))}function bv(e){return(!e.id||e.id<0)&&(e.id=f,f++),e.id}function Ev(e,n){if(!(1048576&e.flags))return W_(e,n);for(var t=0,r=e.types;t<r.length;t++){var a=r[t];if(W_(a,n))return!0}return!1}function Tv(e,n){if(e!==n){if(131072&n.flags)return n;var t=nb(e,(function(e){return Ev(n,e)}));if(512&n.flags&&Mm(n)&&(t=rb(t,wm)),W_(n,t))return t}return e}function Sv(e){var n=Nl(e);return!!(n.callSignatures.length||n.constructSignatures.length||n.members.get("bind")&&H_(e,En))}function xv(n,t){void 0===t&&(t=!1);var r=n.flags;if(4&r)return z?16317953:16776705;if(128&r){var a=""===n.value;return z?a?12123649:7929345:a?12582401:16776705}if(40&r)return z?16317698:16776450;if(256&r){var i=0===n.value;return z?i?12123394:7929090:i?12582146:16776450}if(64&r)return z?16317188:16775940;if(2048&r){i=Py(n);return z?i?12122884:7928580:i?12581636:16775940}return 16&r?z?16316168:16774920:528&r?z?n===Be||n===Ue?12121864:7927560:n===Be||n===Ue?12580616:16774920:524288&r&&!t?16&e.getObjectFlags(n)&&bg(n)?z?16318463:16777215:Sv(n)?z?7880640:16728e3:z?7888800:16736160:49152&r?9830144:65536&r?9363232:12288&r?z?7925520:16772880:67108864&r?z?7888800:16736160:131072&r?0:465829888&r?qf(n)?z?7929345:16776705:xv(ql(n)||Ne,t):1048576&r?e.reduceLeft(n.types,(function(e,n){return e|xv(n,t)}),0):2097152&r?(t||(t=AD(n,131068)),e.reduceLeft(n.types,(function(e,n){return e&xv(n,t)}),16777215)):16777215}function Lv(e,n){return nb(e,(function(e){return 0!==(xv(e)&n)}))}function Dv(e,n){return n?Qp([Po(e),vA(n)]):e}function Av(e,n){var t=Sf(n);if(!Lc(t))return Ae;var r=kc(t);return Io(e,r)||bT(r)&&Iv(Eu(e,1))||Iv(Eu(e,0))||Ae}function Cv(e,n){return $v(e,my)&&gy(e,n)||Iv(NI(65,e,ke,void 0))||Ae}function Iv(e){return e&&C.noUncheckedIndexedAccess?Qp([e,ke]):e}function Nv(e){return Ep(NI(65,e,ke,void 0)||Ae)}function kv(e){var n=200===e.parent.kind&&Rv(e.parent)||289===e.parent.kind&&Rv(e.parent.parent);return n?Dv(Fv(e),e.right):vA(e.right)}function Rv(e){return 217===e.parent.kind&&e.parent.left===e||240===e.parent.kind&&e.parent.initializer===e}function Ov(e,n){return Cv(Fv(e),e.elements.indexOf(n))}function wv(e){return Nv(Fv(e.parent))}function Pv(e){return Av(Fv(e.parent),e.name)}function Mv(e){return Dv(Pv(e),e.objectAssignmentInitializer)}function Fv(e){var n=e.parent;switch(n.kind){case 239:return Me;case 240:return II(n)||Ae;case 217:return kv(n);case 211:return ke;case 200:return Ov(n,e);case 221:return wv(n);case 289:return Pv(n);case 290:return Mv(n)}return Ae}function Gv(e){var n=e.parent,t=Vv(n.parent),r=197===n.kind?Av(t,e.propertyName||e.name):e.dotDotDotToken?Nv(t):Cv(t,n.elements.indexOf(e));return Dv(r,e.initializer)}function Bv(e){var n=Pr(e);return n.resolvedType||vA(e)}function Uv(e){return e.initializer?Bv(e.initializer):239===e.parent.parent.kind?Me:240===e.parent.parent.kind&&II(e.parent.parent)||Ae}function Vv(e){return 250===e.kind?Uv(e):Gv(e)}function jv(e){return 250===e.kind&&e.initializer&&Ho(e.initializer)||199!==e.kind&&217===e.parent.kind&&Ho(e.parent.right)}function Kv(e){switch(e.kind){case 208:return Kv(e.expression);case 217:switch(e.operatorToken.kind){case 62:case 74:case 75:case 76:return Kv(e.left);case 27:return Kv(e.right)}}return e}function Hv(e){var n=e.parent;return 208===n.kind||217===n.kind&&62===n.operatorToken.kind&&n.left===e||217===n.kind&&27===n.operatorToken.kind&&n.right===e?Hv(n):e}function Wv(e){return 285===e.kind?Pm(vA(e.expression)):ze}function zv(e){var n=Pr(e);if(!n.switchTypes){n.switchTypes=[];for(var t=0,r=e.caseBlock.clauses;t<r.length;t++){var a=r[t];n.switchTypes.push(Wv(a))}}return n.switchTypes}function qv(n,t){for(var r=[],a=0,i=n.caseBlock.clauses;a<i.length;a++){var o=i[a];if(285===o.kind){if(e.isStringLiteralLike(o.expression)){r.push(o.expression.text);continue}return e.emptyArray}t&&r.push(void 0)}return r}function Jv(n,t){return 1048576&n.flags?!e.forEach(n.types,(function(n){return!e.contains(t,n)})):e.contains(t,n)}function Xv(e,n){return e===n||1048576&n.flags&&Yv(e,n)}function Yv(e,n){if(1048576&e.flags){for(var t=0,r=e.types;t<r.length;t++){var a=r[t];if(!Vp(n.types,a))return!1}return!0}return!!(1024&e.flags&&lc(e)===n)||Vp(n.types,e)}function Qv(n,t){return 1048576&n.flags?e.forEach(n.types,t):t(n)}function Zv(n,t){return 1048576&n.flags?e.some(n.types,t):t(n)}function $v(n,t){return 1048576&n.flags?e.every(n.types,t):t(n)}function eb(n,t){return 3145728&n.flags?e.every(n.types,t):t(n)}function nb(n,t){if(1048576&n.flags){var r=n.types,a=e.filter(r,t);if(a===r)return n;var i=n.origin,o=void 0;if(i&&1048576&i.flags){var s=i.types,c=e.filter(s,(function(e){return!!(1048576&e.flags)||t(e)}));if(s.length-c.length===r.length-a.length){if(1===c.length)return c[0];o=Yp(1048576,c)}}return nf(a,n.objectFlags,void 0,void 0,o)}return 131072&n.flags||t(n)?n:ze}function tb(e){return 1048576&e.flags?e.types.length:1}function rb(e,n,t){if(131072&e.flags)return e;if(!(1048576&e.flags))return n(e);for(var r,a=e.origin,i=a&&1048576&a.flags?a.types:e.types,o=!1,s=0,c=i;s<c.length;s++){var l=c[s],u=1048576&l.flags?rb(l,n,t):n(l);o||(o=l!==u),u&&(r?r.push(u):r=[u])}return o?r&&Qp(r,t?0:1):e}function ab(n,t,r,a){return 1048576&n.flags&&r?Qp(e.map(n.types,t),1,r,a):rb(n,t)}function ib(e){return 3145728&e.flags?e.types.length:1}function ob(e,n){return nb(e,(function(e){return 0!==(e.flags&n)}))}function sb(e,n){return Xv(Me,e)&&AD(n,128)||Xv(Fe,e)&&AD(n,256)||Xv(Ge,e)&&AD(n,2048)?rb(e,(function(e){return 4&e.flags?ob(n,132):8&e.flags?ob(n,264):64&e.flags?ob(n,2112):e})):e}function cb(e){return 0===e.flags}function lb(e){return 0===e.flags?e.type:e}function ub(e,n){return n?{flags:0,type:131072&e.flags?qe:e}:e}function db(e){var n=Ri(256);return n.elementType=e,n}function pb(e){return be[e.id]||(be[e.id]=db(e))}function fb(e,n){var t=eh(Ty(EA(n)));return Xv(t,e.elementType)?e:pb(Qp([e.elementType,t]))}function mb(e){return 131072&e.flags?Rn:Ep(1048576&e.flags?Qp(e.types,2):e)}function _b(e){return e.finalArrayType||(e.finalArrayType=mb(e.elementType))}function gb(n){return 256&e.getObjectFlags(n)?_b(n):n}function yb(n){return 256&e.getObjectFlags(n)?n.elementType:ze}function hb(n){for(var t=!1,r=0,a=n;r<a.length;r++){var i=a[r];if(!(131072&i.flags)){if(!(256&e.getObjectFlags(i)))return!1;t=!0}}return t}function vb(n){var t=Hv(n),r=t.parent,a=e.isPropertyAccessExpression(r)&&("length"===r.name.escapedText||204===r.parent.kind&&e.isIdentifier(r.name)&&e.isPushOrUnshiftIdentifier(r.name)),i=203===r.kind&&r.expression===t&&217===r.parent.kind&&62===r.parent.operatorToken.kind&&r.parent.left===r&&!e.isAssignmentTarget(r.parent)&&CD(vA(r.argumentExpression),296);return a||i}function bb(n){return(250===n.kind||161===n.kind||164===n.kind||163===n.kind)&&!!e.getEffectiveTypeAnnotationNode(n)}function Eb(n,t){if(8752&n.flags)return ws(n);if(7&n.flags){if(262144&e.getCheckFlags(n)){var r=n.syntheticOrigin;if(r&&Eb(r))return ws(n)}var a=n.valueDeclaration;if(a){if(bb(a))return ws(n);if(e.isVariableDeclaration(a)&&240===a.parent.parent.kind){var i=a.parent.parent,o=Tb(i.expression,void 0);if(o){var s=i.awaitModifier?15:13;return NI(s,o,ke,void 0)}}t&&e.addRelatedInfo(t,e.createDiagnosticForNode(a,e.Diagnostics._0_needs_an_explicit_type_annotation,ro(n)))}}}function Tb(n,t){if(!(16777216&n.flags))switch(n.kind){case 78:var r=Li(rv(n));return Eb(2097152&r.flags?Fa(r):r,t);case 107:return iE(n);case 105:return lE(n);case 202:var a=Tb(n.expression,t);if(a){var i=n.name,o=void 0;if(e.isPrivateIdentifier(i)){if(!a.symbol)return;o=_u(a,e.getSymbolNameForPrivateIdentifier(a.symbol,i.escapedText))}else o=_u(a,i.escapedText);return o&&Eb(o,t)}return;case 208:return Tb(n.expression,t)}}function Sb(n){var t=Pr(n),r=t.effectsSignature;if(void 0===r){var a=void 0;234===n.parent.kind?a=Tb(n.expression,void 0):105!==n.expression.kind&&(a=e.isOptionalChain(n)?yS(Xy(TA(n.expression),n.expression),n.expression):dS(n.expression));var i=yu(a&&au(a)||Ne,0),o=1!==i.length||i[0].typeParameters?e.some(i,xb)?lL(n):void 0:i[0];r=t.effectsSignature=o&&xb(o)?o:ft}return r===ft?void 0:r}function xb(e){return!!(Vu(e)||e.declaration&&131072&(Wu(e.declaration)||Ne).flags)}function Lb(n,t){if(1===n.kind||3===n.kind)return t.arguments[n.parameterIndex];var r=e.skipParentheses(t.expression);return e.isAccessExpression(r)?e.skipParentheses(r.expression):void 0}function Db(n){var t=e.findAncestor(n,e.isFunctionOrModuleBlock),r=e.getSourceFileOfNode(n),a=e.getSpanOfTokenAtPosition(r,t.statements.pos);nr.add(e.createFileDiagnostic(r,a.start,a.length,e.Diagnostics.The_containing_function_or_module_body_is_too_large_for_control_flow_analysis))}function Ab(e){var n=Ib(e,!1);return at=e,it=n,n}function Cb(n){var t=e.skipParentheses(n);return 94===t.kind||217===t.kind&&(55===t.operatorToken.kind&&(Cb(t.left)||Cb(t.right))||56===t.operatorToken.kind&&Cb(t.left)&&Cb(t.right))}function Ib(n,t){while(1){if(n===at)return it;var r=n.flags;if(4096&r){if(!t){var a=bv(n),i=Xt[a];return void 0!==i?i:Xt[a]=Ib(n,!0)}t=!1}if(368&r)n=n.antecedent;else if(512&r){var o=Sb(n.node);if(o){var s=Vu(o);if(s&&3===s.kind&&!s.type){var c=n.node.arguments[s.parameterIndex];if(c&&Cb(c))return!1}if(131072&Hu(o).flags)return!1}n=n.antecedent}else{if(4&r)return e.some(n.antecedents,(function(e){return Ib(e,!1)}));if(8&r){var l=n.antecedents;if(void 0===l||0===l.length)return!1;n=l[0]}else{if(!(128&r)){if(1024&r){at=void 0;var u=n.target,d=u.antecedents;u.antecedents=n.antecedents;var p=Ib(n.antecedent,!1);return u.antecedents=d,p}return!(1&r)}if(n.clauseStart===n.clauseEnd&&iD(n.switchStatement))return!1;n=n.antecedent}}}}function Nb(n,t){while(1){var r=n.flags;if(4096&r){if(!t){var a=bv(n),i=Yt[a];return void 0!==i?i:Yt[a]=Nb(n,!0)}t=!1}if(496&r)n=n.antecedent;else if(512&r){if(105===n.node.expression.kind)return!0;n=n.antecedent}else{if(4&r)return e.every(n.antecedents,(function(e){return Nb(e,!1)}));if(!(8&r)){if(1024&r){var o=n.target,s=o.antecedents;o.antecedents=n.antecedents;var c=Nb(n.antecedent,!1);return o.antecedents=s,c}return!!(1&r)}n=n.antecedents[0]}}}function kb(n,t,r,a,i){var o;void 0===r&&(r=t);var s=!1,c=0;if(Nt)return Ae;if(!n.flowNode||!i&&!(536624127&t.flags))return t;kt++;var l=It,u=lb(f(n.flowNode));It=l;var d=256&e.getObjectFlags(u)&&vb(n)?Rn:gb(u);return d===Ye||n.parent&&226===n.parent.kind&&!(131072&d.flags)&&131072&Lv(d,2097152).flags?t:d;function p(){return s?o:(s=!0,o=iv(n,t,r,a))}function f(i){if(2e3===c)return null===e.tracing||void 0===e.tracing||e.tracing.instant("checkTypes","getTypeAtFlowNode_DepthLimit",{flowId:i.id}),Nt=!0,Db(n),Ae;var o;c++;while(1){var s=i.flags;if(4096&s){for(var u=l;u<It;u++)if(qt[u]===i)return c--,Jt[u];o=i}var d=void 0;if(16&s){if(d=_(i),!d){i=i.antecedent;continue}}else if(512&s){if(d=y(i),!d){i=i.antecedent;continue}}else if(96&s)d=v(i);else if(128&s)d=b(i);else if(12&s){if(1===i.antecedents.length){i=i.antecedents[0];continue}d=4&s?E(i):T(i)}else if(256&s){if(d=h(i),!d){i=i.antecedent;continue}}else if(1024&s){var p=i.target,m=p.antecedents;p.antecedents=i.antecedents,d=f(i.antecedent),p.antecedents=m}else if(2&s){var g=i.node;if(g&&g!==a&&202!==n.kind&&203!==n.kind&&107!==n.kind){i=g.flowNode;continue}d=r}else d=lI(t);return o&&(qt[It]=o,Jt[It]=d,It++),c--,d}}function m(e){var t=e.node;return Kb(250===t.kind||199===t.kind?Vv(t):Fv(t),n)}function _(r){var a=r.node;if(ov(n,a)){if(!Ab(r))return Ye;if(2===e.getAssignmentTargetKind(a)){var i=f(r.antecedent);return ub(Ty(lb(i)),cb(i))}if(t===Le||t===Rn){if(jv(a))return pb(ze);var o=Sy(m(r));return W_(o,t)?o:kn}return 1048576&t.flags?Tv(t,m(r)):t}if(lv(n,a)){if(!Ab(r))return Ye;if(e.isVariableDeclaration(a)&&(e.isInJSFile(a)||e.isVarConst(a))){var s=e.getDeclaredExpandoInitializer(a);if(s&&(209===s.kind||210===s.kind))return f(r.antecedent)}return t}if(e.isVariableDeclaration(a)&&239===a.parent.parent.kind&&ov(n,a.parent.parent.expression))return fS(lb(f(r.antecedent)))}function g(n,t){var r=e.skipParentheses(t);if(94===r.kind)return Ye;if(217===r.kind){if(55===r.operatorToken.kind)return g(g(n,r.left),r.right);if(56===r.operatorToken.kind)return Qp([g(n,r.left),g(n,r.right)])}return X(n,r,!0)}function y(e){var n=Sb(e.node);if(n){var t=Vu(n);if(t&&(2===t.kind||3===t.kind)){var r=f(e.antecedent),a=gb(lb(r)),i=t.type?J(a,t,e.node,!0):3===t.kind&&t.parameterIndex>=0&&t.parameterIndex<e.node.arguments.length?g(a,e.node.arguments[t.parameterIndex]):a;return i===a?r:ub(i,cb(r))}if(131072&Hu(n).flags)return Ye}}function h(r){if(t===Le||t===Rn){var a=r.node,i=204===a.kind?a.expression.expression:a.left.expression;if(ov(n,Kv(i))){var o=f(r.antecedent),s=lb(o);if(256&e.getObjectFlags(s)){var c=s;if(204===a.kind)for(var l=0,u=a.arguments;l<u.length;l++){var d=u[l];c=fb(c,d)}else{var p=EA(a.left.argumentExpression);CD(p,296)&&(c=fb(c,a.right))}return c===s?o:ub(c,cb(o))}return o}}}function v(e){var n=f(e.antecedent),t=lb(n);if(131072&t.flags)return n;var r=0!==(32&e.flags),a=gb(t),i=X(a,e.node,r);return i===a?n:ub(i,cb(n))}function b(e){var t=e.switchStatement.expression,r=f(e.antecedent),a=lb(r);return ov(n,t)?a=G(a,e.switchStatement,e.clauseStart,e.clauseEnd):212===t.kind&&ov(n,t.expression)?a=V(a,e.switchStatement,e.clauseStart,e.clauseEnd):(z&&(uv(t,n)?a=F(a,e.switchStatement,e.clauseStart,e.clauseEnd,(function(e){return!(163840&e.flags)})):212===t.kind&&uv(t.expression,n)&&(a=F(a,e.switchStatement,e.clauseStart,e.clauseEnd,(function(e){return!(131072&e.flags||128&e.flags&&"undefined"===e.value)})))),D(t,a)&&(a=I(a,t,e.switchStatement,e.clauseStart,e.clauseEnd))),ub(a,cb(r))}function E(n){for(var a,i=[],o=!1,s=!1,c=0,l=n.antecedents;c<l.length;c++){var u=l[c];if(!a&&128&u.flags&&u.clauseStart===u.clauseEnd)a=u;else{var d=f(u),p=lb(d);if(p===t&&t===r)return p;e.pushIfUnique(i,p),Xv(p,t)||(o=!0),cb(d)&&(s=!0)}}if(a){d=f(a),p=lb(d);if(!e.contains(i,p)&&!iD(a.switchStatement)){if(p===t&&t===r)return p;i.push(p),Xv(p,t)||(o=!0),cb(d)&&(s=!0)}}return ub(L(i,o?2:1),s)}function T(n){var r=bv(n),a=Kt[r]||(Kt[r]=new e.Map),i=p();if(!i)return t;var o=a.get(i);if(o)return o;for(var s=At;s<Ct;s++)if(Ht[s]===n&&Wt[s]===i&&zt[s].length)return ub(L(zt[s],1),!0);for(var c,l=[],u=!1,d=0,m=n.antecedents;d<m.length;d++){var _=m[d],g=void 0;if(c){Ht[Ct]=n,Wt[Ct]=i,zt[Ct]=l,Ct++;var y=ot;ot=void 0,g=f(_),ot=y,Ct--;var h=a.get(i);if(h)return h}else g=c=f(_);var v=lb(g);if(e.pushIfUnique(l,v),Xv(v,t)||(u=!0),v===t)break}var b=L(l,u?2:1);return cb(c)?ub(b,!0):(a.set(i,b),b)}function L(n,r){if(hb(n))return pb(Qp(e.map(n,yb)));var a=Qp(e.sameMap(n,gb),r);return a!==t&&a.flags&t.flags&1048576&&e.arraysEqual(a.types,t.types)?t:a}function D(r,a){var i=1048576&t.flags?t:a;if(!(1048576&i.flags)||!e.isAccessExpression(r))return!1;var o=cv(r);return void 0!==o&&(ov(n,r.expression)&&dv(i,o))}function A(n,t,r){var a=cv(t);if(void 0===a)return n;var i=z&&e.isOptionalChain(t)&&AD(n,98304),o=Io(i?Lv(n,2097152):n,a);if(!o)return n;o=i?jy(o):o;var s=r(o);return nb(n,(function(e){var n=No(e,a);return!(131072&n.flags)&&q_(n,s)}))}function C(e,n,t,r,a){if((36===t||37===t)&&1048576&e.flags){var i=mv(e);if(i&&i===cv(n)){var o=_v(e,vA(r));if(o)return t===(a?36:37)?o:hy(Io(o,i)||Ne)?nb(e,(function(e){return e!==o})):e}}return A(e,n,(function(e){return P(e,t,r,a)}))}function I(n,t,r,a,i){if(a<i&&1048576&n.flags&&mv(n)===cv(t)){var o=zv(r).slice(a,i),s=Qp(e.map(o,(function(e){return _v(n,e)||Ne})));if(s!==Ne)return s}return A(n,t,(function(e){return G(e,r,a,i)}))}function N(e,t,r){return ov(n,t)?Lv(e,r?4194304:8388608):(z&&r&&uv(t,n)&&(e=Lv(e,2097152)),D(t,e)?A(e,t,(function(e){return Lv(e,r?4194304:8388608)})):e)}function k(e,n,t){if(bu(e,0))return!0;var r=_u(e,n);return r?!!(16777216&r.flags)||t:!t}function R(n,r,a){if(1048576&n.flags||524288&n.flags&&t!==n||Yf(n)||2097152&n.flags&&e.every(n.types,(function(e){return e.symbol!==ie}))){var i=e.escapeLeadingUnderscores(r.text);return nb(n,(function(e){return k(e,i,a)}))}return n}function O(t,r,a){switch(r.operatorToken.kind){case 62:case 74:case 75:case 76:return N(X(t,r.right,a),r.left,a);case 34:case 35:case 36:case 37:var i=r.operatorToken.kind,o=Kv(r.left),s=Kv(r.right);if(212===o.kind&&e.isStringLiteralLike(s))return M(t,o,i,s,a);if(212===s.kind&&e.isStringLiteralLike(o))return M(t,s,i,o,a);if(ov(n,o))return P(t,i,s,a);if(ov(n,s))return P(t,i,o,a);if(z&&(uv(o,n)?t=w(t,i,s,a):uv(s,n)&&(t=w(t,i,o,a))),D(o,t))return C(t,o,i,s,a);if(D(s,t))return C(t,s,i,o,a);if(j(o))return K(t,i,s,a);if(j(s))return K(t,i,o,a);break;case 101:return H(t,r,a);case 100:var c=Kv(r.right);if(e.isStringLiteralLike(r.left)&&ov(n,c))return R(t,r.left,a);break;case 27:return X(t,r.right,a)}return t}function w(e,n,t,r){var a=34===n||36===n,i=34===n||35===n?98304:32768,o=vA(t),s=a!==r&&$v(o,(function(e){return!!(e.flags&i)}))||a===r&&$v(o,(function(e){return!(e.flags&(3|i))}));return s?Lv(e,2097152):e}function P(e,n,t,r){if(1&e.flags)return e;35!==n&&37!==n||(r=!r);var a=vA(t);if(2&e.flags&&r&&(36===n||37===n))return 67239932&a.flags?a:524288&a.flags?Qe:e;if(98304&a.flags){if(!z)return e;var i=34===n||35===n,o=i?r?262144:2097152:65536&a.flags?r?131072:1048576:r?65536:524288;return Lv(e,o)}if(r){var s=34===n?function(e){return J_(e,a)||Yy(e,a)}:function(e){return J_(e,a)};return sb(nb(e,s),a)}return hy(a)?nb(e,(function(e){return!(vy(e)&&J_(e,a))})):e}function M(e,t,r,a,i){35!==r&&37!==r||(i=!i);var o=Kv(t.expression);if(!ov(n,o))return z&&uv(o,n)&&i===("undefined"!==a.text)?Lv(e,2097152):e;if(1&e.flags&&"function"===a.text)return e;if(i&&2&e.flags&&"object"===a.text){if(217===t.parent.parent.kind){var s=t.parent.parent;if(55===s.operatorToken.kind&&s.right===t.parent&&sv(n,s.left))return Qe}return Qp([Qe,we])}var c=i?S.get(a.text)||128:x.get(a.text)||32768,l=B(e,a.text);return Lv(i&&l?rb(e,U(l)):e,c)}function F(n,t,r,a,i){var o=r!==a&&e.every(zv(t).slice(r,a),i);return o?Lv(n,2097152):n}function G(n,t,r,a){var i=zv(t);if(!i.length)return n;var o=i.slice(r,a),s=r===a||e.contains(o,ze);if(2&n.flags&&!s){for(var c=void 0,l=0;l<o.length;l+=1){var u=o[l];if(67239932&u.flags)void 0!==c&&c.push(u);else{if(!(524288&u.flags))return n;void 0===c&&(c=o.slice(0,l)),c.push(Qe)}}return Qp(void 0===c?o:c)}var d=Qp(o),p=131072&d.flags?ze:sb(nb(n,(function(e){return J_(d,e)})),d);if(!s)return p;var f=nb(n,(function(n){return!(vy(n)&&e.contains(i,Pm(by(n))))}));return 131072&p.flags?f:Qp([p,f])}function B(e,n){switch(n){case"function":return 1&e.flags?e:En;case"object":return 2&e.flags?Qp([Qe,we]):e;default:return rr.get(n)}}function U(e){return function(n){if(H_(n,e))return n;if(H_(e,n))return e;if(465829888&n.flags){var t=ql(n)||xe;if(H_(e,t))return pf([n,e])}return n}}function V(n,t,r,a){var i=qv(t,!0);if(!i.length)return n;var o,s,c=e.findIndex(i,(function(e){return void 0===e})),l=r===a||c>=r&&c<a;if(c>-1){var u=i.filter((function(e){return void 0!==e})),d=c<r?r-1:r,p=c<a?a-1:a;o=u.slice(d,p),s=aD(d,p,u,l)}else o=i.slice(r,a),s=aD(r,a,i,l);if(l)return nb(n,(function(e){return(xv(e)&s)===s}));var f=Lv(Qp(o.map((function(e){return B(n,e)||n}))),s);return Lv(rb(n,U(f)),s)}function j(t){return(e.isPropertyAccessExpression(t)&&"constructor"===e.idText(t.name)||e.isElementAccessExpression(t)&&e.isStringLiteralLike(t.argumentExpression)&&"constructor"===t.argumentExpression.text)&&ov(n,t.expression)}function K(n,t,r,a){if(a?34!==t&&36!==t:35!==t&&37!==t)return n;var i=vA(r);if(!DR(i)&&!Hs(i))return n;var o=_u(i,"prototype");if(!o)return n;var s=ws(o),c=ko(s)?void 0:s;return c&&c!==bn&&c!==En?ko(n)?c:nb(n,(function(e){return l(e,c)})):n;function l(n,t){return 524288&n.flags&&1&e.getObjectFlags(n)||524288&t.flags&&1&e.getObjectFlags(t)?n.symbol===t.symbol:H_(n,t)}}function H(t,r,a){var i=Kv(r.left);if(!ov(n,i))return a&&z&&uv(i,n)?Lv(t,2097152):t;var o,s=vA(r.right);if(!z_(s,En))return t;var c=_u(s,"prototype");if(c){var l=ws(c);ko(l)||(o=l)}if(ko(t)&&(o===bn||o===En))return t;if(!o){var u=yu(s,1);o=u.length?Qp(e.map(u,(function(e){return Hu($u(e))}))):an}if(!a&&1048576&s.flags){var d=e.find(s.types,(function(e){return!Hs(e)}));if(!d)return t}return W(t,o,a,z_)}function W(e,n,t,r){if(!t)return nb(e,(function(e){if(!r(e,n))return!0;var t=ql(e);return!(!t||t===e)&&!r(t,n)}));if(1048576&e.flags){var a=nb(e,(function(e){return r(e,n)}));if(!(131072&a.flags))return a}return H_(n,e)?n:W_(e,n)?e:W_(n,e)?n:pf([e,n])}function q(t,r,a){if(vv(r,n)){var i=a||!e.isCallChain(r)?Sb(r):void 0,o=i&&Vu(i);if(o&&(0===o.kind||1===o.kind))return J(t,o,r,a)}return t}function J(e,t,r,a){if(t.type&&(!ko(e)||t.type!==bn&&t.type!==En)){var i=Lb(t,r);if(i){if(ov(n,i))return W(e,t.type,a,H_);if(z&&a&&uv(i,n)&&!(65536&xv(t.type))&&(e=Lv(e,2097152)),D(i,e))return A(e,i,(function(e){return W(e,t.type,a,H_)}))}}return e}function X(n,t,r){if(e.isExpressionOfOptionalChainRoot(t)||e.isBinaryExpression(t.parent)&&60===t.parent.operatorToken.kind&&t.parent.left===t)return Y(n,t,r);switch(t.kind){case 78:case 107:case 105:case 202:case 203:return N(n,t,r);case 204:return q(n,t,r);case 208:case 226:return X(n,t.expression,r);case 217:return O(n,t,r);case 215:if(53===t.operator)return X(n,t.operand,!r);break}return n}function Y(e,t,r){return ov(n,t)?Lv(e,r?2097152:262144):D(t,e)?A(e,t,(function(e){return Lv(e,r?2097152:262144)})):e}}function Rb(n,t){if(n=n.exportSymbol||n,(78===t.kind||79===t.kind)&&(e.isRightSideOfQualifiedNameOrPropertyAccess(t)&&(t=t.parent),e.isExpressionNode(t)&&(!e.isAssignmentTarget(t)||e.isWriteAccess(t)))){var r=vA(t);if(Li(Pr(t).resolvedSymbol)===n)return r}return e.isDeclarationName(t)&&e.isSetAccessor(t.parent)&&ys(t.parent)?xs(t.parent.symbol,!0):ws(n)}function Ob(n){return e.findAncestor(n.parent,(function(n){return e.isFunctionLike(n)&&!e.getImmediatelyInvokedFunctionExpression(n)||258===n.kind||298===n.kind||164===n.kind}))}function wb(n){if(!n.valueDeclaration)return!1;var t=e.getRootDeclaration(n.valueDeclaration).parent,r=Pr(t);return 8388608&r.flags||(r.flags|=8388608,Pb(t)||Mb(t)),n.isAssigned||!1}function Pb(n){return!!e.findAncestor(n.parent,(function(n){return e.isFunctionLike(n)&&!!(8388608&Pr(n).flags)}))}function Mb(n){if(78===n.kind){if(e.isAssignmentTarget(n)){var t=rv(n);t.valueDeclaration&&161===e.getRootDeclaration(t.valueDeclaration).kind&&(t.isAssigned=!0)}}else e.forEachChild(n,Mb)}function Fb(e){return 3&e.flags&&0!==(2&oS(e))&&ws(e)!==Rn}function Gb(e,n){if(So(n.symbol,2)){var t=z&&161===n.kind&&n.initializer&&32768&Fy(e)&&!(32768&Fy(TA(n.initializer)));return Do(),t?Lv(e,524288):e}return ks(n.symbol),e}function Bb(e){var n=e.parent;return 202===n.kind||204===n.kind&&n.expression===e||203===n.kind&&n.expression===e&&!Xf(vA(n.argumentExpression))}function Ub(e){return!!(465829888&e.flags&&1146880&Jl(e).flags)}function Vb(n){return!!(465829888&n.flags||3145728&n.flags&&e.some(n.types,Vb))}function jb(n){var t=(e.isIdentifier(n)||e.isPropertyAccessExpression(n)||e.isElementAccessExpression(n))&&!((e.isJsxOpeningElement(n.parent)||e.isJsxSelfClosingElement(n.parent))&&n.parent.tagName===n)&&JE(n);return t&&!Zv(t,Vb)}function Kb(e,n,t){var r=!(t&&2&t)&&Zv(e,Ub)&&(Bb(n)||jb(n));return r?rb(e,(function(e){return 465829888&e.flags?Jl(e):e})):e}function Hb(n){return!!e.findAncestor(n,(function(n){return n.parent&&e.isExportAssignment(n.parent)&&n.parent.expression===n&&e.isEntityNameExpression(n)}))}function Wb(n,t){if(Pa(n,111551)&&!av(t)&&!Va(n)){var r=Fa(n);111551&r.flags&&(C.isolatedModules||e.shouldPreserveConstEnums(C)&&Hb(t)||!mR(r)?Ka(n):Ha(n))}}function zb(n,t){var r=rv(n);if(r===Te)return Ae;if(r===se){var a=e.getContainingFunction(n);return F<2&&(210===a.kind?gr(n,e.Diagnostics.The_arguments_object_cannot_be_referenced_in_an_arrow_function_in_ES3_and_ES5_Consider_using_a_standard_function_expression):e.hasSyntacticModifier(a,256)&&gr(n,e.Diagnostics.The_arguments_object_cannot_be_referenced_in_an_async_function_or_method_in_ES3_and_ES5_Consider_using_a_standard_function_or_method)),Pr(a).flags|=8192,ws(r)}n.parent&&e.isPropertyAccessExpression(n.parent)&&n.parent.expression===n||Wb(r,n);var i=Li(r),o=2097152&i.flags?Fa(i):i;o.declarations&&134217728&oS(o)&&Kf(n,o)&&Er(n,o.declarations,n.escapedText);var s=i.valueDeclaration;if(s&&32&i.flags)if(253===s.kind&&e.nodeIsDecorated(s)){a=e.getContainingClass(n);while(void 0!==a){if(a===s&&a.name!==n){Pr(s).flags|=16777216,Pr(n).flags|=33554432;break}a=e.getContainingClass(a)}}else if(222===s.kind){a=e.getThisContainer(n,!1);while(298!==a.kind){if(a.parent===s){164===a.kind&&e.hasSyntacticModifier(a,32)&&(Pr(s).flags|=16777216,Pr(n).flags|=33554432);break}a=e.getThisContainer(a,!1)}}Yb(n,r);var c=ws(i),l=e.getAssignmentTargetKind(n);if(l){if(!(3&i.flags)&&!(e.isInJSFile(n)&&512&i.flags)){var u=384&i.flags?e.Diagnostics.Cannot_assign_to_0_because_it_is_an_enum:32&i.flags?e.Diagnostics.Cannot_assign_to_0_because_it_is_a_class:1536&i.flags?e.Diagnostics.Cannot_assign_to_0_because_it_is_a_namespace:16&i.flags?e.Diagnostics.Cannot_assign_to_0_because_it_is_a_function:2097152&i.flags?e.Diagnostics.Cannot_assign_to_0_because_it_is_an_import:e.Diagnostics.Cannot_assign_to_0_because_it_is_not_a_variable;return gr(n,u,ro(r)),Ae}if(gD(i))return 3&i.flags?gr(n,e.Diagnostics.Cannot_assign_to_0_because_it_is_a_constant,ro(r)):gr(n,e.Diagnostics.Cannot_assign_to_0_because_it_is_a_read_only_property,ro(r)),Ae}var d=2097152&i.flags;if(3&i.flags){if(1===l)return c}else{if(!d)return c;s=ca(r)}if(!s)return c;c=Kb(c,n,t);var p=161===e.getRootDeclaration(s).kind,f=Ob(s),m=Ob(n),_=m!==f,g=n.parent&&n.parent.parent&&e.isSpreadAssignment(n.parent)&&Rv(n.parent.parent),y=134217728&r.flags;while(m!==f&&(209===m.kind||210===m.kind||e.isObjectLiteralOrClassExpressionMethod(m))&&(Fb(i)||p&&!wb(i)))m=Ob(m);var h=p||d||_||g||y||e.isBindingElement(s)||c!==Le&&c!==Rn&&(!z||0!==(16387&c.flags)||av(n)||271===n.parent.kind)||226===n.parent.kind||250===s.kind&&s.exclamationToken||8388608&s.flags,v=h?p?Gb(c,s):c:c===Le||c===Rn?ke:jy(c),b=kb(n,c,v,m,!h);if(vb(n)||c!==Le&&c!==Rn){if(!h&&!(32768&Fy(c))&&32768&Fy(b))return gr(n,e.Diagnostics.Variable_0_is_used_before_being_assigned,ro(r)),c}else if(b===Le||b===Rn)return Y&&(gr(e.getNameOfDeclaration(s),e.Diagnostics.Variable_0_implicitly_has_type_1_in_some_locations_where_its_type_cannot_be_determined,ro(r),io(b)),gr(n,e.Diagnostics.Variable_0_implicitly_has_an_1_type,ro(r),io(b))),lI(b);return l?Ty(b):b}function qb(n,t){return!!e.findAncestor(n,(function(n){return n===t?"quit":e.isFunctionLike(n)||n.parent&&e.isPropertyDeclaration(n.parent)&&!e.hasStaticModifier(n.parent)&&n.parent.initializer===n}))}function Jb(n,t){return e.findAncestor(n,(function(e){return e===t?"quit":e===t.initializer||e===t.condition||e===t.incrementor||e===t.statement}))}function Xb(n){return e.findAncestor(n,(function(n){return!n||e.nodeStartsNewLexicalEnvironment(n)?"quit":e.isIterationStatement(n,!1)}))}function Yb(n,t){if(!(F>=2||0===(34&t.flags)||!t.valueDeclaration||e.isSourceFile(t.valueDeclaration)||288===t.valueDeclaration.parent.kind)){var r=e.getEnclosingBlockScopeContainer(t.valueDeclaration),a=qb(n,r),i=Xb(r);if(i){if(a){var o=!0;if(e.isForStatement(r)){var s=e.getAncestor(t.valueDeclaration,251);if(s&&s.parent===r){var c=Jb(n.parent,r);if(c){var l=Pr(c);l.flags|=131072;var u=l.capturedBlockScopeBindings||(l.capturedBlockScopeBindings=[]);e.pushIfUnique(u,t),c===r.initializer&&(o=!1)}}}o&&(Pr(i).flags|=65536)}if(e.isForStatement(r)){s=e.getAncestor(t.valueDeclaration,251);s&&s.parent===r&&Zb(n,r)&&(Pr(t.valueDeclaration).flags|=4194304)}Pr(t.valueDeclaration).flags|=524288}a&&(Pr(t.valueDeclaration).flags|=262144)}}function Qb(n,t){var r=Pr(n);return!!r&&e.contains(r.capturedBlockScopeBindings,yi(t))}function Zb(n,t){var r=n;while(208===r.parent.kind)r=r.parent;var a=!1;if(e.isAssignmentTarget(r))a=!0;else if(215===r.parent.kind||216===r.parent.kind){var i=r.parent;a=45===i.operator||46===i.operator}return!!a&&!!e.findAncestor(r,(function(e){return e===t?"quit":e===t.statement}))}function $b(e,n){if(Pr(e).flags|=2,164===n.kind||167===n.kind){var t=n.parent;Pr(t).flags|=4}else Pr(n).flags|=4}function eE(n){return e.isSuperCall(n)?n:e.isFunctionLike(n)?void 0:e.forEachChild(n,eE)}function nE(e){var n=yi(e),t=mc(n),r=Js(t);return r===Pe}function tE(n,t,r){var a=t.parent,i=e.getClassExtendsHeritageElement(a);i&&!nE(a)&&n.flowNode&&!Nb(n.flowNode,!1)&&gr(n,r)}function rE(n){var t=e.getThisContainer(n,!0),r=!1;switch(167===t.kind&&tE(n,t,e.Diagnostics.super_must_be_called_before_accessing_this_in_the_constructor_of_a_derived_class),210===t.kind&&(t=e.getThisContainer(t,!1),r=!0),t.kind){case 257:gr(n,e.Diagnostics.this_cannot_be_referenced_in_a_module_or_namespace_body);break;case 256:gr(n,e.Diagnostics.this_cannot_be_referenced_in_current_location);break;case 167:cE(n,t)&&gr(n,e.Diagnostics.this_cannot_be_referenced_in_constructor_arguments);break;case 164:case 163:!e.hasSyntacticModifier(t,32)||99===C.target&&H||gr(n,e.Diagnostics.this_cannot_be_referenced_in_a_static_property_initializer);break;case 159:gr(n,e.Diagnostics.this_cannot_be_referenced_in_a_computed_property_name);break}r&&F<2&&$b(n,t);var a=aE(n,!0,t);if(Q){var i=ws(ie);if(a===i&&r)gr(n,e.Diagnostics.The_containing_arrow_function_captures_the_global_value_of_this);else if(!a){var o=gr(n,e.Diagnostics.this_implicitly_has_type_any_because_it_does_not_have_a_type_annotation);if(!e.isSourceFile(t)){var s=aE(t);s&&s!==i&&e.addRelatedInfo(o,e.createDiagnosticForNode(t,e.Diagnostics.An_outer_value_of_this_is_shadowed_by_this_container))}}}return a||xe}function aE(n,t,r){void 0===t&&(t=!0),void 0===r&&(r=e.getThisContainer(n,!1));var a=e.isInJSFile(n);if(e.isFunctionLike(r)&&(!TE(n)||e.getThisParameter(r))){var i=bs(r)||a&&sE(r);if(!i){var o=oE(r);if(a&&o){var s=TA(o).symbol;s&&s.members&&16&s.flags&&(i=mc(s).thisType)}else uL(r)&&(i=mc(gi(r.symbol)).thisType);i||(i=fE(r))}if(i)return kb(n,i)}if(e.isClassLike(r.parent)){var c=yi(r.parent),l=e.hasSyntacticModifier(r,32)?ws(c):mc(c).thisType;return kb(n,l)}if(e.isSourceFile(r)){if(r.commonJsModuleIndicator){var u=yi(r);return u&&ws(u)}if(r.externalModuleIndicator)return ke;if(t)return ws(ie)}}function iE(n){var t=e.getThisContainer(n,!1);if(e.isFunctionLike(t)){var r=Ou(t);if(r.thisParameter)return Eb(r.thisParameter)}if(e.isClassLike(t.parent)){var a=yi(t.parent);return e.hasSyntacticModifier(t,32)?ws(a):mc(a).thisType}}function oE(n){return 209===n.kind&&e.isBinaryExpression(n.parent)&&3===e.getAssignmentDeclarationKind(n.parent)?n.parent.left.expression.expression:166===n.kind&&201===n.parent.kind&&e.isBinaryExpression(n.parent.parent)&&6===e.getAssignmentDeclarationKind(n.parent.parent)?n.parent.parent.left.expression:209===n.kind&&289===n.parent.kind&&201===n.parent.parent.kind&&e.isBinaryExpression(n.parent.parent.parent)&&6===e.getAssignmentDeclarationKind(n.parent.parent.parent)?n.parent.parent.parent.left.expression:209===n.kind&&e.isPropertyAssignment(n.parent)&&e.isIdentifier(n.parent.name)&&("value"===n.parent.name.escapedText||"get"===n.parent.name.escapedText||"set"===n.parent.name.escapedText)&&e.isObjectLiteralExpression(n.parent.parent)&&e.isCallExpression(n.parent.parent.parent)&&n.parent.parent.parent.arguments[2]===n.parent.parent&&9===e.getAssignmentDeclarationKind(n.parent.parent.parent)?n.parent.parent.parent.arguments[0].expression:e.isMethodDeclaration(n)&&e.isIdentifier(n.name)&&("value"===n.name.escapedText||"get"===n.name.escapedText||"set"===n.name.escapedText)&&e.isObjectLiteralExpression(n.parent)&&e.isCallExpression(n.parent.parent)&&n.parent.parent.arguments[2]===n.parent&&9===e.getAssignmentDeclarationKind(n.parent.parent)?n.parent.parent.arguments[0].expression:void 0}function sE(n){var t=e.getJSDocType(n);if(t&&309===t.kind){var r=t;if(r.parameters.length>0&&r.parameters[0].name&&"this"===r.parameters[0].name.escapedText)return zm(r.parameters[0].type)}var a=e.getJSDocThisTag(n);if(a&&a.typeExpression)return zm(a.typeExpression)}function cE(n,t){return!!e.findAncestor(n,(function(n){return e.isFunctionLikeDeclaration(n)?"quit":161===n.kind&&n.parent===t}))}function lE(n){var t=204===n.parent.kind&&n.parent.expression===n,r=e.getSuperContainer(n,!0),a=r,i=!1;if(!t)while(a&&210===a.kind)a=e.getSuperContainer(a,!0),i=F<2;var o=p(a),s=0;if(!o){var c=e.findAncestor(n,(function(e){return e===a?"quit":159===e.kind}));return c&&159===c.kind?gr(n,e.Diagnostics.super_cannot_be_referenced_in_a_computed_property_name):t?gr(n,e.Diagnostics.Super_calls_are_not_permitted_outside_constructors_or_in_nested_functions_inside_constructors):a&&a.parent&&(e.isClassLike(a.parent)||201===a.parent.kind)?gr(n,e.Diagnostics.super_property_access_is_permitted_only_in_a_constructor_member_function_or_member_accessor_of_a_derived_class):gr(n,e.Diagnostics.super_can_only_be_referenced_in_members_of_derived_classes_or_object_literal_expressions),Ae}if(t||167!==r.kind||tE(n,a,e.Diagnostics.super_must_be_called_before_accessing_a_property_of_super_in_the_constructor_of_a_derived_class),s=e.hasSyntacticModifier(a,32)||t?512:256,Pr(n).flags|=s,166===a.kind&&e.hasSyntacticModifier(a,256)&&(e.isSuperProperty(n.parent)&&e.isAssignmentTarget(n.parent)?Pr(a).flags|=4096:Pr(a).flags|=2048),i&&$b(n.parent,a),201===a.parent.kind)return F<2?(gr(n,e.Diagnostics.super_is_only_allowed_in_members_of_object_literal_expressions_when_option_target_is_ES2015_or_higher),Ae):xe;var l=a.parent;if(!e.getClassExtendsHeritageElement(l))return gr(n,e.Diagnostics.super_can_only_be_referenced_in_a_derived_class),Ae;var u=mc(yi(l)),d=u&&Qs(u)[0];return d?167===a.kind&&cE(n,a)?(gr(n,e.Diagnostics.super_cannot_be_referenced_in_constructor_arguments),Ae):512===s?Js(u):Fc(d,u.thisType):Ae;function p(n){return!!n&&(t?167===n.kind:!(!e.isClassLike(n.parent)&&201!==n.parent.kind)&&(e.hasSyntacticModifier(n,32)?166===n.kind||165===n.kind||168===n.kind||169===n.kind:166===n.kind||165===n.kind||168===n.kind||169===n.kind||164===n.kind||163===n.kind||167===n.kind))}}function uE(e){return 166!==e.kind&&168!==e.kind&&169!==e.kind||201!==e.parent.kind?209===e.kind&&289===e.parent.kind?e.parent.parent:void 0:e.parent}function dE(n){return 4&e.getObjectFlags(n)&&n.target===Nn?Td(n)[0]:void 0}function pE(n){return rb(n,(function(n){return 2097152&n.flags?e.forEach(n.types,dE):dE(n)}))}function fE(n){if(210!==n.kind){if(G_(n)){var t=dT(n);if(t){var r=t.thisParameter;if(r)return ws(r)}}var a=e.isInJSFile(n);if(Q||a){var i=uE(n);if(i){var o=WE(i),s=i,c=o;while(c){var l=pE(c);if(l)return A_(l,Th(XE(i)));if(289!==s.parent.kind)break;s=s.parent.parent,c=WE(s)}return sh(o?Hy(o):$D(i))}var u=e.walkUpParenthesizedExpressions(n.parent);if(217===u.kind&&62===u.operatorToken.kind){var d=u.left;if(e.isAccessExpression(d)){var p=d.expression;if(a&&e.isIdentifier(p)){var f=e.getSourceFileOfNode(u);if(f.commonJsModuleIndicator&&rv(p)===f.symbol)return}return sh($D(p))}}}}}function mE(n){var t=n.parent;if(G_(t)){var r=e.getImmediatelyInvokedFunctionExpression(t);if(r&&r.arguments){var a=Ix(r),i=t.parameters.indexOf(n);if(n.dotDotDotToken)return Tx(a,i,a.length,xe,void 0,0);var o=Pr(r),s=o.resolvedSignature;o.resolvedSignature=pt;var c=i<a.length?Sy(TA(a[i])):n.initializer?void 0:Re;return o.resolvedSignature=s,c}var l=dT(t);if(l){var u=t.parameters.indexOf(n)-(e.getThisParameter(t)?1:0);return n.dotDotDotToken&&e.lastOrUndefined(t.parameters)===n?GL(l,u):FL(l,u)}}}function _E(n){var t=e.getEffectiveTypeAnnotationNode(n);if(t)return zm(t);switch(n.kind){case 161:return mE(n);case 199:return gE(n);case 164:if(e.hasSyntacticModifier(n,32))return yE(n)}}function gE(n){var t=n.parent.parent,r=n.propertyName||n.name,a=_E(t)||199!==t.kind&&t.initializer&&nA(t);if(a&&!e.isBindingPattern(r)&&!e.isComputedNonLiteralName(r)){if(198===t.name.kind){var i=e.indexOfNode(n.parent.elements,n);if(i<0)return;return FE(a,i)}var o=Sf(r);if(Lc(o)){var s=kc(o);return Io(a,s)}}}function yE(n){var t=e.isExpression(n.parent)&&JE(n.parent);if(t)return OE(t,yi(n).escapedName)}function hE(n,t){var r=n.parent;if(e.hasInitializer(r)&&n===r.initializer){var a=_E(r);if(a)return a;if(!(8&t)&&e.isBindingPattern(r.name))return ls(r.name,!0,!1)}}function vE(n){var t=e.getContainingFunction(n);if(t){var r=xE(t);if(r){var a=e.getFunctionFlags(t);if(1&a){var i=2&a?2:1,o=GI(r,i,void 0);if(!o)return;r=o.returnType}if(2&a){var s=rb(r,yC);return s&&Qp([s,ZL(s)])}return r}}}function bE(e,n){var t=JE(e,n);if(t){var r=yC(t);return r&&Qp([r,ZL(r)])}}function EE(n){var t=e.getContainingFunction(n);if(t){var r=e.getFunctionFlags(t),a=xE(t);if(a)return n.asteriskToken?a:tN(0,a,0!==(2&r))}}function TE(n){var t=!1;while(n.parent&&!e.isFunctionLike(n.parent)){if(e.isParameter(n.parent)&&(t||n.parent.initializer===n))return!0;e.isBindingElement(n.parent)&&n.parent.initializer===n&&(t=!0),n=n.parent}return!1}function SE(n,t){var r=!!(2&e.getFunctionFlags(t)),a=xE(t);if(a)return tN(n,a,r)||void 0}function xE(e){var n=Wu(e);if(n)return n;var t=uT(e);return t&&!zu(t)?Hu(t):void 0}function LE(e,n){var t=Ix(e),r=t.indexOf(n);return-1===r?void 0:DE(e,r)}function DE(n,t){var r=Pr(n).resolvedSignature===mt?mt:lL(n);return e.isJsxOpeningLikeElement(n)&&0===t?QE(r,n):ML(r,t)}function AE(e,n){if(206===e.parent.kind)return LE(e.parent,n)}function CE(n,t){var r=n.parent,a=r.left,i=r.operatorToken,o=r.right;switch(i.kind){case 62:case 75:case 74:case 76:return n===o?IE(r):void 0;case 56:case 60:var s=JE(r,t);return n===o&&(s&&s.pattern||!s&&!e.isDefaultedExpandoInitializer(r))?vA(a):s;case 55:case 27:return n===o?JE(r,t):void 0;default:return}}function IE(n){var t,r,a=e.getAssignmentDeclarationKind(n);switch(a){case 0:return vA(n.left);case 4:return kE(n);case 5:if(NE(n,a))return kE(n);if(n.left.symbol){var i=n.left.symbol.valueDeclaration;if(!i)return;var o=e.cast(n.left,e.isAccessExpression),s=e.getEffectiveTypeAnnotationNode(i);if(s)return zm(s);if(e.isIdentifier(o.expression)){var c=o.expression,l=Vr(c,c.escapedText,111551,void 0,c.escapedText,!0);if(l){var u=l.valueDeclaration&&e.getEffectiveTypeAnnotationNode(l.valueDeclaration);if(u){var d=e.getElementOrPropertyAccessName(o);if(void 0!==d)return OE(zm(u),d)}return}}return e.isInJSFile(i)?void 0:vA(n.left)}return vA(n.left);case 1:case 6:case 3:var p=null===(t=n.left.symbol)||void 0===t?void 0:t.valueDeclaration;case 2:p||(p=null===(r=n.symbol)||void 0===r?void 0:r.valueDeclaration);var f=p&&e.getEffectiveTypeAnnotationNode(p);return f?zm(f):void 0;case 7:case 8:case 9:return e.Debug.fail("Does not apply");default:return e.Debug.assertNever(a)}}function NE(n,t){if(void 0===t&&(t=e.getAssignmentDeclarationKind(n)),4===t)return!0;if(!e.isInJSFile(n)||5!==t||!e.isIdentifier(n.left.expression))return!1;var r=n.left.expression.escapedText,a=Vr(n.left,r,111551,void 0,void 0,!0,!0);return e.isThisInitializedDeclaration(null===a||void 0===a?void 0:a.valueDeclaration)}function kE(n){if(!n.symbol)return vA(n.left);if(n.symbol.valueDeclaration){var t=e.getEffectiveTypeAnnotationNode(n.symbol.valueDeclaration);if(t){var r=zm(t);if(r)return r}}var a=e.cast(n.left,e.isAccessExpression);if(e.isObjectLiteralMethod(e.getThisContainer(a.expression,!1))){var i=rE(a.expression),o=e.getElementOrPropertyAccessName(a);return void 0!==o&&OE(i,o)||void 0}}function RE(n){return!!(262144&e.getCheckFlags(n)&&!n.type&&xo(n,0)>=0)}function OE(n,t){return rb(n,(function(n){if(Il(n)){var r=vl(n),a=ql(r)||r,i=Fm(e.unescapeLeadingUnderscores(t));if(W_(i,a))return am(n,i)}else if(3670016&n.flags){var o=_u(n,t);if(o)return RE(o)?void 0:ws(o);if(Cy(n)){var s=ky(n);if(s&&bT(t)&&+t>=0)return s}return bT(t)&&wE(n,1)||wE(n,0)}}),!0)}function wE(e,n){return rb(e,(function(e){return vu(e,n)}),!0)}function PE(n,t){if(e.Debug.assert(e.isObjectLiteralMethod(n)),!(16777216&n.flags))return ME(n,t)}function ME(n,t){var r=n.parent,a=e.isPropertyAssignment(n)&&_E(n);if(a)return a;var i=WE(r,t);if(i){if(Ic(n)){var o=yi(n).escapedName,s=OE(i,o);if(s)return s}return yT(n.name)&&wE(i,1)||wE(i,0)}}function FE(e,n){return e&&(OE(e,""+n)||rb(e,(function(e){return kI(1,e,ke,void 0,!1)}),!0))}function GE(e,n){var t=e.parent;return e===t.whenTrue||e===t.whenFalse?JE(t,n):void 0}function BE(n,t){var r=WE(n.openingElement.tagName),a=zT(jT(n));if(r&&!ko(r)&&a&&""!==a){var i=e.getSemanticJsxChildren(n.children),o=i.indexOf(t),s=OE(r,a);return s&&(1===i.length?s:rb(s,(function(e){return dy(e)?im(e,Fm(o)):e}),!0))}}function UE(n){var t=n.parent;return e.isJsxAttributeLike(t)?JE(n):e.isJsxElement(t)?BE(t,n):void 0}function VE(n){if(e.isJsxAttribute(n)){var t=WE(n.parent);if(!t||ko(t))return;return OE(t,n.name.escapedText)}return JE(n.parent)}function jE(e){switch(e.kind){case 10:case 8:case 9:case 14:case 109:case 94:case 103:case 78:case 150:return!0;case 202:case 208:return jE(e.expression);case 284:return!e.expression||jE(e.expression)}return!1}function KE(n,t){return yv(t,n)||kg(t,e.concatenate(e.map(e.filter(n.properties,(function(e){return!!e.symbol&&289===e.kind&&jE(e.initializer)&&dv(t,e.symbol.escapedName)})),(function(e){return[function(){return EA(e.initializer)},e.symbol.escapedName]})),e.map(e.filter(wl(t),(function(e){var r;return!!(16777216&e.flags)&&!!(null===(r=null===n||void 0===n?void 0:n.symbol)||void 0===r?void 0:r.members)&&!n.symbol.members.has(e.escapedName)&&dv(t,e.escapedName)})),(function(e){return[function(){return ke},e.escapedName]}))),W_,t)}function HE(n,t){return kg(t,e.concatenate(e.map(e.filter(n.properties,(function(e){return!!e.symbol&&281===e.kind&&dv(t,e.symbol.escapedName)&&(!e.initializer||jE(e.initializer))})),(function(e){return[e.initializer?function(){return TA(e.initializer)}:function(){return Ve},e.symbol.escapedName]})),e.map(e.filter(wl(t),(function(e){var r;return!!(16777216&e.flags)&&!!(null===(r=null===n||void 0===n?void 0:n.symbol)||void 0===r?void 0:r.members)&&!n.symbol.members.has(e.escapedName)&&dv(t,e.escapedName)})),(function(e){return[function(){return ke},e.escapedName]}))),W_,t)}function WE(n,t){var r=e.isObjectLiteralMethod(n)?PE(n,t):JE(n,t),a=zE(r,n,t);if(a&&!(t&&2&t&&8650752&a.flags)){var i=rb(a,au,!0);return 1048576&i.flags&&e.isObjectLiteralExpression(n)?KE(n,i):1048576&i.flags&&e.isJsxAttributes(n)?HE(n,i):i}}function zE(n,t,r){if(n&&AD(n,465829888)){var a=XE(t);if(a&&e.some(a.inferences,dA)){if(r&&1&r)return qE(n,a.nonFixingMapper);if(a.returnMapper)return qE(n,a.returnMapper)}}return n}function qE(n,t){return 465829888&n.flags?A_(n,t):1048576&n.flags?Qp(e.map(n.types,(function(e){return qE(e,t)})),0):2097152&n.flags?pf(e.map(n.types,(function(e){return qE(e,t)}))):n}function JE(n,t){if(16777216&n.flags);else{if(n.contextualType)return n.contextualType;var r=n.parent;switch(r.kind){case 250:case 161:case 164:case 163:case 199:return hE(n,t);case 210:case 243:return vE(n);case 220:return EE(r);case 214:return bE(r,t);case 204:if(99===r.expression.kind)return Me;case 205:return LE(r,n);case 207:case 225:return e.isConstTypeReference(r.type)?s(r):zm(r.type);case 217:return CE(n,t);case 289:case 290:return ME(r,t);case 291:return JE(r.parent,t);case 200:var a=r,i=WE(a,t);return FE(i,e.indexOfNode(a.elements,n));case 218:return GE(n,t);case 229:return e.Debug.assert(219===r.parent.kind),AE(r.parent,n);case 208:var o=e.isInJSFile(r)?e.getJSDocTypeTag(r):void 0;return o?zm(o.typeExpression.type):JE(r,t);case 226:return JE(r,t);case 284:return UE(r);case 281:case 283:return VE(r);case 276:case 275:return YE(r,t)}}function s(e){return JE(e)}}function XE(n){var t=e.findAncestor(n,(function(e){return!!e.inferenceContext}));return t&&t.inferenceContext}function YE(n,t){return e.isJsxOpeningElement(n)&&n.parent.contextualType&&4!==t?n.parent.contextualType:DE(n,0)}function QE(e,n){return 0!==xx(n)?ZE(e,n):tT(e,n)}function ZE(e,n){var t=WL(e,Ne);t=nT(n,jT(n),t);var r=BT(N.IntrinsicAttributes,n);return r!==Ae&&(t=rl(r,t)),t}function $E(e,n){if(e.compositeSignatures){for(var t=[],r=0,a=e.compositeSignatures;r<a.length;r++){var i=a[r],o=Hu(i);if(ko(o))return o;var s=Io(o,n);if(!s)return;t.push(s)}return pf(t)}var c=Hu(e);return ko(c)?c:Io(c,n)}function eT(e){if(OT(e.tagName)){var n=YT(e),t=iL(e,n);return ad(t)}var r=$D(e.tagName);if(128&r.flags){n=JT(r,e);if(!n)return Ae;t=iL(e,n);return ad(t)}return r}function nT(n,t,r){var a=HT(t);if(a){var i=mc(a),o=eT(n);if(524288&a.flags){var s=wr(a).typeParameters;if(e.length(s)>=2){var c=Ru([o,r],s,2,e.isInJSFile(n));return Ld(a,c)}}if(e.length(i.typeParameters)>=2){c=Ru([o,r],i.typeParameters,2,e.isInJSFile(n));return vd(i,c)}}return r}function tT(n,t){var r=jT(t),a=WT(r),i=void 0===a?WL(n,Ne):""===a?Hu(n):$E(n,a);if(!i)return a&&e.length(t.attributes.properties)&&gr(t,e.Diagnostics.JSX_element_class_does_not_support_attributes_because_it_does_not_have_a_0_property,e.unescapeLeadingUnderscores(a)),Ne;if(i=nT(t,r,i),ko(i))return i;var o=i,s=BT(N.IntrinsicClassAttributes,t);if(s!==Ae){var c=Vs(s.symbol),l=Hu(n);o=rl(c?vd(s,Ru([l],c,ku(c),e.isInJSFile(t))):s,o)}var u=BT(N.IntrinsicAttributes,t);return u!==Ae&&(o=rl(u,o)),o}function rT(n){return e.getStrictOptionValue(C,"noImplicitAny")?e.reduceLeft(n,(function(e,n){return e!==n&&e?Qc(e.typeParameters,n.typeParameters)?oT(e,n):void 0:e})):void 0}function aT(e,n,t){if(!e||!n)return e||n;var r=Qp([ws(e),A_(ws(n),t)]);return Zy(e,r)}function iT(e,n,t){for(var r=BL(e),a=BL(n),i=r>=a?e:n,o=i===e?n:e,s=i===e?r:a,c=VL(e)||VL(n),l=c&&!VL(i),u=new Array(s+(l?1:0)),d=0;d<s;d++){var p=FL(i,d);i===n&&(p=A_(p,t));var f=FL(o,d)||Ne;o===n&&(f=A_(f,t));var m=Qp([p,f]),_=c&&!l&&d===s-1,g=d>=UL(i)&&d>=UL(o),y=d>=r?void 0:OL(e,d),h=d>=a?void 0:OL(n,d),v=y===h?y:y?h?void 0:y:h,b=Sr(1|(g&&!_?16777216:0),v||"arg"+d);b.type=_?Ep(m):m,u[d]=b}if(l){var E=Sr(1,"args");E.type=Ep(ML(o,s)),o===n&&(E.type=A_(E.type,t)),u[s]=E}return u}function oT(n,t){var r,a=n.typeParameters||t.typeParameters;n.typeParameters&&t.typeParameters&&(r=Qm(t.typeParameters,n.typeParameters));var i=n.declaration,o=iT(n,t,r),s=aT(n.thisParameter,t.thisParameter,r),c=Math.max(n.minArgumentCount,t.minArgumentCount),l=Vc(i,a,s,o,void 0,void 0,c,39&(n.flags|t.flags));return l.compositeKind=2097152,l.compositeSignatures=e.concatenate(2097152===n.compositeKind&&n.compositeSignatures||[n],[t]),r&&(l.mapper=2097152===n.compositeKind&&n.mapper&&n.compositeSignatures?i_(n.mapper,r):r),l}function sT(n,t){var r=yu(n,0),a=e.filter(r,(function(e){return!cT(e,t)}));return 1===a.length?a[0]:rT(a)}function cT(n,t){for(var r=0;r<t.parameters.length;r++){var a=t.parameters[r];if(a.initializer||a.questionToken||a.dotDotDotToken||Lu(a))break}return t.parameters.length&&e.parameterIsThisKeyword(t.parameters[0])&&r--,!VL(n)&&BL(n)<r}function lT(e){return 209===e.kind||210===e.kind}function uT(n){return lT(n)||e.isObjectLiteralMethod(n)?dT(n):void 0}function dT(n){e.Debug.assert(166!==n.kind||e.isObjectLiteralMethod(n));var t=Pu(n);if(t)return t;var r=WE(n,1);if(r){if(!(1048576&r.flags))return sT(r,n);for(var a,i=r.types,o=0,s=i;o<s.length;o++){var c=s[o],l=sT(c,n);if(l)if(a){if(!ny(a[0],l,!1,!0,!0,V_))return;a.push(l)}else a=[l]}return a?1===a.length?a[0]:Kc(a[0],a):void 0}}function pT(e,n){F<2&&jR(e,C.downlevelIteration?1536:1024);var t=TA(e.expression,n);return NI(33,t,ke,e.expression)}function fT(e){return e.isSpread?im(e.type,Fe):e.type}function mT(e){return 199===e.kind&&!!e.initializer||217===e.kind&&62===e.operatorToken.kind}function _T(n,t,r){for(var a=n.elements,i=a.length,o=[],s=[],c=WE(n),l=e.isAssignmentTarget(n),u=iA(n),d=0;d<i;d++){var p=a[d];if(221===p.kind){F<2&&jR(p,C.downlevelIteration?1536:1024);var f=TA(p.expression,t,r);if(dy(f))o.push(f),s.push(8);else if(l){var m=Eu(f,1)||kI(65,f,ke,void 0,!1)||Ne;o.push(m),s.push(4)}else o.push(NI(33,f,ke,p.expression)),s.push(4)}else{var _=FE(c,o.length),g=oA(p,t,_,r);o.push(g),s.push(1)}}return l?Np(o,s):r||u||c&&Zv(c,my)?gT(Np(o,s,u)):gT(Ep(o.length?Qp(e.sameMap(o,(function(e,n){return 8&s[n]?sm(e,Fe)||xe:e})),2):z?Xe:Re,u))}function gT(n){if(!(4&e.getObjectFlags(n)))return n;var t=n.literalType;return t||(t=n.literalType=bd(n),t.objectFlags|=294912),t}function yT(e){switch(e.kind){case 159:return hT(e);case 78:return bT(e.escapedText);case 8:case 10:return bT(e.text);default:return!1}}function hT(e){return CD(ET(e),296)}function vT(e){return"Infinity"===e||"-Infinity"===e||"NaN"===e}function bT(e){return(+e).toString()===e}function ET(n){var t=Pr(n.expression);if(!t.resolvedType){if(t.resolvedType=TA(n.expression),e.isPropertyDeclaration(n.parent)&&!e.hasStaticModifier(n.parent)&&e.isClassExpression(n.parent.parent)){var r=e.getEnclosingBlockScopeContainer(n.parent.parent),a=Xb(r);a&&(Pr(a).flags|=65536,Pr(n).flags|=524288,Pr(n.parent.parent).flags|=524288)}(98304&t.resolvedType.flags||!CD(t.resolvedType,402665900)&&!W_(t.resolvedType,Ze))&&gr(n,e.Diagnostics.A_computed_property_name_must_be_of_type_string_number_symbol_or_any)}return t.resolvedType}function TT(n){var t,r=null===(t=n.declarations)||void 0===t?void 0:t[0];return bT(n.escapedName)||r&&e.isNamedDeclaration(r)&&yT(r.name)}function ST(e,n,t,r){for(var a=[],i=n;i<t.length;i++)(0===r||TT(t[i]))&&a.push(ws(t[i]));var o=a.length?Qp(a,2):ke;return ud(o,iA(e))}function xT(n){e.Debug.assert(0!==(2097152&n.flags),"Should only get Alias here.");var t=wr(n);if(!t.immediateTarget){var r=ca(n);if(!r)return e.Debug.fail();t.immediateTarget=wa(r,!0)}return t.immediateTarget}function LT(n,t){var r=e.isAssignmentTarget(n);EO(n,r);for(var a=z?e.createSymbolTable():void 0,i=e.createSymbolTable(),o=[],s=an,c=WE(n),l=c&&c.pattern&&(197===c.pattern.kind||201===c.pattern.kind),u=iA(n),d=u?8:0,p=e.isInJSFile(n)&&!e.isInJsonFile(n),f=e.getJSDocEnumTag(n),m=!c&&p&&!f,_=$,g=!1,y=!1,h=!1,v=0,b=n.properties;v<b.length;v++){var E=b[v];E.name&&e.isComputedPropertyName(E.name)&&ET(E.name)}for(var T=0,S=0,x=n.properties;S<x.length;S++){var L=x[S],D=yi(L),A=L.name&&159===L.name.kind?ET(L.name):void 0;if(289===L.kind||290===L.kind||e.isObjectLiteralMethod(L)){var I=289===L.kind?sA(L,t):290===L.kind?oA(!r&&L.objectAssignmentInitializer?L.objectAssignmentInitializer:L.name,t):cA(L,t);if(p){var N=jo(L);N?(X_(I,N,L),I=N):f&&f.typeExpression&&X_(I,zm(f.typeExpression),L)}_|=917504&e.getObjectFlags(I);var k=A&&Lc(A)?A:void 0,R=k?Sr(4|D.flags,kc(k),4096|d):Sr(4|D.flags,D.escapedName,d);if(k&&(R.nameType=k),r){var O=289===L.kind&&mT(L.initializer)||290===L.kind&&L.objectAssignmentInitializer;O&&(R.flags|=16777216)}else if(l&&!(512&e.getObjectFlags(c))){var w=_u(c,D.escapedName);w?R.flags|=16777216&w.flags:C.suppressExcessPropertyErrors||bu(c,0)||gr(L.name,e.Diagnostics.Object_literal_may_only_specify_known_properties_and_0_does_not_exist_in_type_1,ro(D),io(c))}R.declarations=D.declarations,R.parent=D.parent,D.valueDeclaration&&(R.valueDeclaration=D.valueDeclaration),R.type=I,R.target=D,D=R,null===a||void 0===a||a.set(R.escapedName,R)}else{if(291===L.kind){F<2&&jR(L,2),o.length>0&&(s=Im(s,G(),n.symbol,_,u),o=[],i=e.createSymbolTable(),y=!1,h=!1);I=lu(TA(L.expression));if(DT(I)){if(a&&FT(I,a,L),T=o.length,s===Ae)continue;s=Im(s,I,n.symbol,_,u)}else gr(L,e.Diagnostics.Spread_types_may_only_be_created_from_object_types),s=Ae;continue}e.Debug.assert(168===L.kind||169===L.kind),yk(L)}!A||8576&A.flags?i.set(D.escapedName,D):W_(A,Ze)&&(W_(A,Fe)?h=!0:y=!0,r&&(g=!0)),o.push(D)}if(l&&291!==n.parent.kind)for(var P=0,M=wl(c);P<M.length;P++){R=M[P];i.get(R.escapedName)||_u(s,R.escapedName)||(16777216&R.flags||gr(R.valueDeclaration||R.bindingElement,e.Diagnostics.Initializer_provides_no_value_for_this_binding_element_and_the_binding_element_has_no_default_value),i.set(R.escapedName,R),o.push(R))}return s===Ae?Ae:s!==an?(o.length>0&&(s=Im(s,G(),n.symbol,_,u),o=[],i=e.createSymbolTable(),y=!1,h=!1),rb(s,(function(e){return e===an?G():e}))):G();function G(){var t=y?ST(n,T,o,0):void 0,a=h?ST(n,T,o,1):void 0,s=Bi(n.symbol,i,e.emptyArray,e.emptyArray,t,a);return s.objectFlags|=262272|_,m&&(s.objectFlags|=8192),g&&(s.objectFlags|=512),r&&(s.pattern=n),s}}function DT(n){if(465829888&n.flags){var t=ql(n);if(void 0!==t)return DT(t)}return!!(126615553&n.flags||117632&Fy(n)&&DT(Gy(n))||3145728&n.flags&&e.every(n.types,DT))}function AT(e){tS(e)}function CT(e,n){return yk(e),ZT(e)||xe}function IT(e){tS(e.openingElement),OT(e.closingElement.tagName)?UT(e.closingElement):TA(e.closingElement.tagName),MT(e)}function NT(e,n){return yk(e),ZT(e)||xe}function kT(n){tS(n.openingFragment);var t=e.getSourceFileOfNode(n);return!e.getJSXTransformEnabled(C)||!C.jsxFactory&&!t.pragmas.has("jsx")||C.jsxFragmentFactory||t.pragmas.has("jsxfrag")||gr(n,C.jsxFactory?e.Diagnostics.The_jsxFragmentFactory_compiler_option_must_be_provided_to_use_JSX_fragments_with_the_jsxFactory_compiler_option:e.Diagnostics.An_jsxFrag_pragma_is_required_when_using_an_jsx_pragma_with_JSX_fragments),MT(n),ZT(n)||xe}function RT(n){return!e.stringContains(n,"-")}function OT(n){return 78===n.kind&&e.isIntrinsicJsxName(n.escapedText)}function wT(e,n){return e.initializer?oA(e.initializer,n):Ve}function PT(n,t){for(var r,a=n.attributes,i=z?e.createSymbolTable():void 0,o=e.createSymbolTable(),s=on,c=!1,l=!1,u=2048,d=zT(jT(n)),p=0,f=a.properties;p<f.length;p++){var m=f[p],_=m.symbol;if(e.isJsxAttribute(m)){var g=wT(m,t);u|=917504&e.getObjectFlags(g);var y=Sr(4|_.flags,_.escapedName);y.declarations=_.declarations,y.parent=_.parent,_.valueDeclaration&&(y.valueDeclaration=_.valueDeclaration),y.type=g,y.target=_,o.set(y.escapedName,y),null===i||void 0===i||i.set(y.escapedName,y),m.name.escapedText===d&&(l=!0)}else{e.Debug.assert(283===m.kind),o.size>0&&(s=Im(s,x(),a.symbol,u,!1),o=e.createSymbolTable());g=lu($D(m.expression,t));ko(g)&&(c=!0),DT(g)?(s=Im(s,g,a.symbol,u,!1),i&&FT(g,i,m)):r=r?pf([r,g]):g}}c||o.size>0&&(s=Im(s,x(),a.symbol,u,!1));var h=274===n.parent.kind?n.parent:void 0;if(h&&h.openingElement===n&&h.children.length>0){var v=MT(h,t);if(!c&&d&&""!==d){l&&gr(a,e.Diagnostics._0_are_specified_twice_The_attribute_named_0_will_be_overwritten,e.unescapeLeadingUnderscores(d));var b=WE(n.attributes),E=b&&OE(b,d),T=Sr(4,d);T.type=1===v.length?v[0]:E&&Zv(E,my)?Np(v):Ep(Qp(v)),T.valueDeclaration=e.factory.createPropertySignature(void 0,e.unescapeLeadingUnderscores(d),void 0,void 0),e.setParent(T.valueDeclaration,a),T.valueDeclaration.symbol=T;var S=e.createSymbolTable();S.set(d,T),s=Im(s,Bi(a.symbol,S,e.emptyArray,e.emptyArray,void 0,void 0),a.symbol,u,!1)}}return c?xe:r&&s!==on?pf([r,s]):r||(s===on?x():s);function x(){u|=$;var n=Bi(a.symbol,o,e.emptyArray,e.emptyArray,void 0,void 0);return n.objectFlags|=262272|u,n}}function MT(e,n){for(var t=[],r=0,a=e.children;r<a.length;r++){var i=a[r];if(11===i.kind)i.containsOnlyTriviaWhiteSpaces||t.push(Me);else{if(284===i.kind&&!i.expression)continue;t.push(oA(i,n))}}return t}function FT(n,t,r){for(var a=0,i=wl(n);a<i.length;a++){var o=i[a],s=t.get(o.escapedName),c=ws(o);if(s&&!AD(c,98304)&&!(AD(c,3)&&16777216&o.flags)){var l=gr(s.valueDeclaration,e.Diagnostics._0_is_specified_more_than_once_so_this_usage_will_be_overwritten,e.unescapeLeadingUnderscores(s.escapedName));e.addRelatedInfo(l,e.createDiagnosticForNode(r,e.Diagnostics.This_spread_always_overwrites_this_property))}}}function GT(e,n){return PT(e.parent,n)}function BT(e,n){var t=jT(n),r=t&&pi(t),a=r&&Fr(r,e,788968);return a?mc(a):Ae}function UT(n){var t=Pr(n);if(!t.resolvedSymbol){var r=BT(N.IntrinsicElements,n);if(r!==Ae){if(!e.isIdentifier(n.tagName))return e.Debug.fail();var a=_u(r,n.tagName.escapedText);if(a)return t.jsxFlags|=1,t.resolvedSymbol=a;var i=Eu(r,0);return i?(t.jsxFlags|=2,t.resolvedSymbol=r.symbol):(gr(n,e.Diagnostics.Property_0_does_not_exist_on_type_1,e.idText(n.tagName),"JSX."+N.IntrinsicElements),t.resolvedSymbol=Te)}return Y&&gr(n,e.Diagnostics.JSX_element_implicitly_has_type_any_because_no_interface_JSX_0_exists,e.unescapeLeadingUnderscores(N.IntrinsicElements)),t.resolvedSymbol=Te}return t.resolvedSymbol}function VT(n){var t=n&&e.getSourceFileOfNode(n),r=t&&Pr(t);if(!r||!1!==r.jsxImplicitImportContainer){if(r&&r.jsxImplicitImportContainer)return r.jsxImplicitImportContainer;var a=e.getJSXRuntimeImport(e.getJSXImplicitImportBase(C,t),C);if(a){var i=e.getEmitModuleResolutionKind(C)===e.ModuleResolutionKind.Classic,o=i?e.Diagnostics.Cannot_find_module_0_Did_you_mean_to_set_the_moduleResolution_option_to_node_or_to_add_aliases_to_the_paths_option:e.Diagnostics.Cannot_find_module_0_or_its_corresponding_type_declarations,s=ei(n,a,o,n),c=s&&s!==Te?gi(Ma(s)):void 0;return r&&(r.jsxImplicitImportContainer=c||!1),c}}}function jT(e){var n=e&&Pr(e);if(n&&n.jsxNamespace)return n.jsxNamespace;if(!n||!1!==n.jsxNamespace){var t=VT(e);if(!t||t===Te){var r=pr(e);t=Vr(e,r,1920,void 0,r,!1)}if(t){var a=Ma(Fr(pi(Ma(t)),N.JSX,1920));if(a&&a!==Te)return n&&(n.jsxNamespace=a),a}n&&(n.jsxNamespace=!1)}var i=Ma(zd(N.JSX,1920,void 0));return i!==Te?i:void 0}function KT(n,t){var r=t&&Fr(t.exports,n,788968),a=r&&mc(r),i=a&&wl(a);if(i){if(0===i.length)return"";if(1===i.length)return i[0].escapedName;i.length>1&&r.declarations&&gr(r.declarations[0],e.Diagnostics.The_global_type_JSX_0_may_not_have_more_than_one_property,e.unescapeLeadingUnderscores(n))}}function HT(e){return e&&Fr(e.exports,N.LibraryManagedAttributes,788968)}function WT(e){return KT(N.ElementAttributesPropertyNameContainer,e)}function zT(e){return KT(N.ElementChildrenAttributeNameContainer,e)}function qT(n,t){if(4&n.flags)return[pt];if(128&n.flags){var r=JT(n,t);if(r){var a=iL(t,r);return[a]}return gr(t,e.Diagnostics.Property_0_does_not_exist_on_type_1,n.value,"JSX."+N.IntrinsicElements),e.emptyArray}var i=au(n),o=yu(i,1);return 0===o.length&&(o=yu(i,0)),0===o.length&&1048576&i.flags&&(o=Yc(e.map(i.types,(function(e){return qT(e,t)})))),o}function JT(n,t){var r=BT(N.IntrinsicElements,t);if(r!==Ae){var a=n.value,i=_u(r,e.escapeLeadingUnderscores(a));if(i)return ws(i);var o=Eu(r,0);return o||void 0}return xe}function XT(n,t,r){if(1===n){var a=$T(r);a&&Cg(t,a,sr,r.tagName,e.Diagnostics.Its_return_type_0_is_not_a_valid_JSX_element,s)}else if(0===n){var i=QT(r);i&&Cg(t,i,sr,r.tagName,e.Diagnostics.Its_instance_type_0_is_not_a_valid_JSX_element,s)}else{a=$T(r),i=QT(r);if(!a||!i)return;var o=Qp([a,i]);Cg(t,o,sr,r.tagName,e.Diagnostics.Its_element_type_0_is_not_a_valid_JSX_element,s)}function s(){var n=e.getTextOfNode(r.tagName);return e.chainDiagnosticMessages(void 0,e.Diagnostics._0_cannot_be_used_as_a_JSX_component,n)}}function YT(n){e.Debug.assert(OT(n.tagName));var t=Pr(n);if(!t.resolvedJsxElementAttributesType){var r=UT(n);return 1&t.jsxFlags?t.resolvedJsxElementAttributesType=ws(r)||Ae:2&t.jsxFlags?t.resolvedJsxElementAttributesType=Eu(BT(N.IntrinsicElements,n),0)||Ae:t.resolvedJsxElementAttributesType=Ae}return t.resolvedJsxElementAttributesType}function QT(e){var n=BT(N.ElementClass,e);if(n!==Ae)return n}function ZT(e){return BT(N.Element,e)}function $T(e){var n=ZT(e);if(n)return Qp([n,we])}function eS(n){var t=BT(N.IntrinsicElements,n);return t?wl(t):e.emptyArray}function nS(n){0===(C.jsx||0)&&gr(n,e.Diagnostics.Cannot_use_JSX_unless_the_jsx_flag_is_provided),void 0===ZT(n)&&Y&&gr(n,e.Diagnostics.JSX_element_implicitly_has_type_any_because_the_global_type_JSX_Element_does_not_exist)}function tS(n){var t=e.isJsxOpeningLikeElement(n);if(t&&TO(n),nS(n),!VT(n)){var r=nr&&2===C.jsx?e.Diagnostics.Cannot_find_name_0:void 0,a=pr(n),i=t?n.tagName:n,o=void 0;e.isJsxOpeningFragment(n)&&"null"===a||(o=Vr(i,a,111551,r,a,!0)),o&&(o.isReferenced=67108863,2097152&o.flags&&!Va(o)&&Ka(o))}if(t){var s=n,c=lL(s);gL(c,n),XT(xx(s),Hu(c),s)}}function rS(e,n,t){if(524288&e.flags){var r=Nl(e);if(r.stringIndexInfo||r.numberIndexInfo&&bT(n)||Rl(e,n)||t&&!RT(n))return!0}else if(3145728&e.flags&&aS(e))for(var a=0,i=e.types;a<i.length;a++){var o=i[a];if(rS(o,n,t))return!0}return!1}function aS(n){return!!(524288&n.flags&&!(512&e.getObjectFlags(n))||67108864&n.flags||1048576&n.flags&&e.some(n.types,aS)||2097152&n.flags&&e.every(n.types,aS))}function iS(n,t){if(xO(n),n.expression){var r=TA(n.expression,t);return n.dotDotDotToken&&r!==xe&&!sy(r)&&gr(n,e.Diagnostics.JSX_spread_child_must_be_an_array_type),r}return Ae}function oS(n){return n.valueDeclaration?e.getCombinedNodeFlags(n.valueDeclaration):0}function sS(n){if(8192&n.flags||4&e.getCheckFlags(n))return!0;if(e.isInJSFile(n.valueDeclaration)){var t=n.valueDeclaration.parent;return t&&e.isBinaryExpression(t)&&3===e.getAssignmentDeclarationKind(t)}}function cS(n,t,r,a,i,o){void 0===o&&(o=!0);var s=e.getDeclarationModifierFlagsFromSymbol(i,r),c=158===n.kind?n.right:196===n.kind?n:199===n.kind&&n.propertyName?n.propertyName:n.name;if(t){if(F<2&&uS(i))return o&&gr(c,e.Diagnostics.Only_public_and_protected_methods_of_the_base_class_are_accessible_via_the_super_keyword),!1;if(128&s)return o&&gr(c,e.Diagnostics.Abstract_method_0_in_class_1_cannot_be_accessed_via_super_expression,ro(i),io(Wg(i))),!1}if(128&s&&uS(i)&&(e.isThisProperty(n)||e.isThisInitializedObjectBindingExpression(n)||e.isObjectBindingPattern(n.parent)&&e.isThisInitializedDeclaration(n.parent.parent))){var l=e.getClassLikeDeclarationOfSymbol(hi(i));if(l&&Pk(n))return o&&gr(c,e.Diagnostics.Abstract_property_0_in_class_1_cannot_be_accessed_in_the_constructor,ro(i),e.getTextOfIdentifierOrLiteral(l.name)),!1}if(!(24&s))return!0;if(8&s){l=e.getClassLikeDeclarationOfSymbol(hi(i));return!!Mk(n,l)||(o&&gr(c,e.Diagnostics.Property_0_is_private_and_only_accessible_within_class_1,ro(i),io(Wg(i))),!1)}if(t)return!0;var u=wk(n,(function(e){var n=mc(yi(e));return Xg(n,i,r)?n:void 0}));if(!u){var d=void 0;if(32&s||!(d=lS(n))||!d.type)return o&&gr(c,e.Diagnostics.Property_0_is_protected_and_only_accessible_within_class_1_and_its_subclasses,ro(i),io(Wg(i)||a)),!1;var p=zm(d.type);u=(262144&p.flags?Gl(p):p).target}return!!(32&s)||(262144&a.flags&&(a=a.isThisType?Gl(a):ql(a)),!(!a||!Fs(a,u))||(o&&gr(c,e.Diagnostics.Property_0_is_protected_and_only_accessible_through_an_instance_of_class_1_This_is_an_instance_of_class_2,ro(i),io(u),io(a)),!1))}function lS(n){var t=e.getThisContainer(n,!1);return t&&e.isFunctionLike(t)?e.getThisParameter(t):void 0}function uS(e){return!!Hg(e,(function(e){return!(8192&e.flags)}))}function dS(e){return yS(TA(e),e)}function pS(e){return!!(98304&(z?Fy(e):e.flags))}function fS(e){return pS(e)?Hy(e):e}function mS(n,t){gr(n,32768&t?65536&t?e.Diagnostics.Object_is_possibly_null_or_undefined:e.Diagnostics.Object_is_possibly_undefined:e.Diagnostics.Object_is_possibly_null)}function _S(n,t){gr(n,32768&t?65536&t?e.Diagnostics.Cannot_invoke_an_object_which_is_possibly_null_or_undefined:e.Diagnostics.Cannot_invoke_an_object_which_is_possibly_undefined:e.Diagnostics.Cannot_invoke_an_object_which_is_possibly_null)}function gS(n,t,r){if(z&&2&n.flags)return gr(t,e.Diagnostics.Object_is_of_type_unknown),Ae;var a=98304&(z?Fy(n):n.flags);if(a){r(t,a);var i=Hy(n);return 229376&i.flags?Ae:i}return n}function yS(e,n){return gS(e,n,mS)}function hS(n,t){var r=yS(n,t);return r!==Ae&&16384&r.flags&&gr(t,e.Diagnostics.Object_is_possibly_undefined),r}function vS(e,n){return 32&e.flags?bS(e,n):AS(e,e.expression,dS(e.expression),e.name,n)}function bS(e,n){var t=TA(e.expression),r=Xy(t,e.expression);return Jy(AS(e,e.expression,yS(r,e.expression),e.name,n),e,r!==t)}function ES(e,n){return AS(e,e.left,dS(e.left),e.right,n)}function TS(n){while(208===n.parent.kind)n=n.parent;return e.isCallOrNewExpression(n.parent)&&n.parent.expression===n}function SS(n,t){for(var r=e.getContainingClass(t);r;r=e.getContainingClass(r)){var a=r.symbol,i=e.getSymbolNameForPrivateIdentifier(a,n),o=a.members&&a.members.get(i)||a.exports&&a.exports.get(i);if(o)return o}}function xS(e,n){return _u(e,n.escapedName)}function LS(n,t,r){var a,i=wl(n);i&&e.forEach(i,(function(n){var r=n.valueDeclaration;if(r&&e.isNamedDeclaration(r)&&e.isPrivateIdentifier(r.name)&&r.name.escapedText===t.escapedText)return a=n,!0}));var o=zr(t);if(a){var s=e.Debug.checkDefined(a.valueDeclaration),c=e.Debug.checkDefined(e.getContainingClass(s));if(null===r||void 0===r?void 0:r.valueDeclaration){var u=r.valueDeclaration,d=e.getContainingClass(u);if(e.Debug.assert(!!d),e.findAncestor(d,(function(e){return c===e}))){var p=gr(t,e.Diagnostics.The_property_0_cannot_be_accessed_on_type_1_within_this_class_because_it_is_shadowed_by_another_private_identifier_with_the_same_spelling,o,io(n));return e.addRelatedInfo(p,e.createDiagnosticForNode(u,e.Diagnostics.The_shadowing_declaration_of_0_is_defined_here,o),e.createDiagnosticForNode(s,e.Diagnostics.The_declaration_of_0_that_you_probably_intended_to_use_is_defined_here,o)),!0}}return gr(t,e.Diagnostics.Property_0_is_not_accessible_outside_class_1_because_it_has_a_private_identifier,o,zr(c.name||l)),!0}return!1}function DS(n,t){return(qo(t)||e.isThisProperty(n)&&Jo(t))&&e.getThisContainer(n,!0)===Xo(t)}function AS(n,t,r,a,i){var o,s,c=Pr(t).resolvedSymbol,l=e.getAssignmentTargetKind(n),u=au(0!==l||TS(n)?sh(r):r),d=ko(u)||u===qe;if(e.isPrivateIdentifier(a)){F<99&&(0!==l&&jR(n,1048576),1!==l&&jR(n,524288));var p=SS(a.escapedText,a);if(l&&p&&p.valueDeclaration&&e.isMethodDeclaration(p.valueDeclaration)&&XO(a,e.Diagnostics.Cannot_assign_to_private_method_0_Private_methods_are_not_writable,e.idText(a)),(null===p||void 0===p?void 0:p.valueDeclaration)&&99===C.target&&!H){var f=e.getContainingClass(p.valueDeclaration),m=e.findAncestor(n,(function(n){return n===f?"quit":!(!e.isPropertyDeclaration(n.parent)||!e.hasStaticModifier(n.parent)||n.parent.initializer!==n||n.parent.parent!==f)}));if(m){var _=yi(m.parent);e.Debug.assert(_,"Initializer without declaration symbol");var g=gr(n,e.Diagnostics.Property_0_may_not_be_used_in_a_static_property_s_initializer_in_the_same_class_when_target_is_esnext_and_useDefineForClassFields_is_false,e.symbolName(p));e.addRelatedInfo(g,e.createDiagnosticForNode(m.parent,e.Diagnostics.Initializer_for_property_0,e.symbolName(_)))}}if(d){if(p)return u;if(!e.getContainingClass(a))return XO(a,e.Diagnostics.Private_identifiers_are_not_allowed_outside_class_bodies),xe}if(o=p?xS(r,p):void 0,!o&&LS(r,a,p))return Ae;var y=o&&65536&o.flags&&!(32768&o.flags);y&&1!==l&&gr(n,e.Diagnostics.Private_accessor_was_defined_without_a_getter)}else{if(d)return e.isIdentifier(t)&&c&&Wb(c,n),u;o=_u(u,a.escapedText)}if(e.isIdentifier(t)&&c&&(C.isolatedModules||!o||!mR(o)||e.shouldPreserveConstEnums(C)&&Hb(n))&&Wb(c,n),o){o.declarations&&134217728&oS(o)&&Kf(n,o)&&Er(a,o.declarations,a.escapedText),IS(o,n,a),qS(o,n,JS(t,c)),Pr(n).resolvedSymbol=o;var h=e.isWriteAccess(n);if(cS(n,105===t.kind,h,u,o),yD(n,o,l))return gr(a,e.Diagnostics.Cannot_assign_to_0_because_it_is_a_read_only_property,e.idText(a)),Ae;s=DS(n,o)?Le:h?Os(o):ws(o)}else{var v=e.isPrivateIdentifier(a)||0!==l&&Jf(r)&&!Yf(r)?void 0:bu(u,0);if(!v||!v.type)return Vf(r)?xe:r.symbol===ie?(ie.exports.has(a.escapedText)&&418&ie.exports.get(a.escapedText).flags?gr(a,e.Diagnostics.Property_0_does_not_exist_on_type_1,e.unescapeLeadingUnderscores(a.escapedText),io(r)):Y&&gr(a,e.Diagnostics.Element_implicitly_has_an_any_type_because_type_0_has_no_index_signature,io(r)),xe):(a.escapedText&&!Xr(n)&&OS(a,Yf(r)?u:r),Ae);v.isReadonly&&(e.isAssignmentTarget(n)||e.isDeleteTarget(n))&&gr(n,e.Diagnostics.Index_signature_in_type_0_only_permits_reading,io(u)),s=C.noUncheckedIndexedAccess&&!e.isAssignmentTarget(n)?Qp([v.type,ke]):v.type,C.noPropertyAccessFromIndexSignature&&e.isPropertyAccessExpression(n)&&gr(a,e.Diagnostics.Property_0_comes_from_an_index_signature_so_it_must_be_accessed_with_0,e.unescapeLeadingUnderscores(a.escapedText))}return CS(n,o,s,a,i)}function CS(n,t,r,a,i){var o=e.getAssignmentTargetKind(n);if(1===o||t&&!(98311&t.flags)&&!(8192&t.flags&&1048576&r.flags)&&!dk(t.declarations))return r;if(r===Le)return Zo(n,t);r=Kb(r,n,i);var s=!1;if(z&&X&&e.isAccessExpression(n)&&107===n.expression.kind){var c=t&&t.valueDeclaration;if(c&&ON(c)){var l=Ob(n);167!==l.kind||l.parent!==c.parent||8388608&c.flags||(s=!0)}}else z&&t&&t.valueDeclaration&&e.isPropertyAccessExpression(t.valueDeclaration)&&e.getAssignmentDeclarationPropertyAccessKind(t.valueDeclaration)&&Ob(n)===Ob(t.valueDeclaration)&&(s=!0);var u=kb(n,r,s?jy(r):r);return s&&!(32768&Fy(r))&&32768&Fy(u)?(gr(a,e.Diagnostics.Property_0_is_used_before_being_assigned,ro(t)),r):o?Ty(u):u}function IS(n,t,r){var a=n.valueDeclaration;if(a&&!e.getSourceFileOfNode(t).isDeclarationFile){var i,o=e.idText(r);!NS(t)||Cu(a)||e.isAccessExpression(t)&&e.isAccessExpression(t.expression)||Br(a,r)||!C.useDefineForClassFields&&kS(n)?253!==a.kind||174===t.parent.kind||8388608&a.flags||Br(a,r)||(i=gr(r,e.Diagnostics.Class_0_used_before_its_declaration,o)):i=gr(r,e.Diagnostics.Property_0_is_used_before_its_initialization,o),i&&e.addRelatedInfo(i,e.createDiagnosticForNode(a,e.Diagnostics._0_is_declared_here,o))}}function NS(n){return!!e.findAncestor(n,(function(n){switch(n.kind){case 164:return!0;case 289:case 166:case 168:case 169:case 291:case 159:case 229:case 284:case 281:case 282:case 283:case 276:case 224:case 287:return!1;default:return!e.isExpressionNode(n)&&"quit"}}))}function kS(e){if(!(32&e.parent.flags))return!1;var n=ws(e.parent);while(1){if(n=n.symbol&&RS(n),!n)return!1;var t=_u(n,e.escapedName);if(t&&t.valueDeclaration)return!0}}function RS(e){var n=Qs(e);if(0!==n.length)return pf(n)}function OS(n,t){var r,a;if(!e.isPrivateIdentifier(n)&&1048576&t.flags&&!(131068&t.flags))for(var i=0,o=t.types;i<o.length;i++){var s=o[i];if(!_u(s,n.escapedText)&&!bu(s,0)){r=e.chainDiagnosticMessages(r,e.Diagnostics.Property_0_does_not_exist_on_type_1,e.declarationNameToString(n),io(s));break}}if(PS(n.escapedText,t)){var c=e.declarationNameToString(n),l=io(t);r=e.chainDiagnosticMessages(r,e.Diagnostics.Property_0_does_not_exist_on_type_1_Did_you_mean_to_access_the_static_member_2_instead,c,l,l+"."+c)}else{var u=mC(t);if(u&&_u(u,n.escapedText))r=e.chainDiagnosticMessages(r,e.Diagnostics.Property_0_does_not_exist_on_type_1,e.declarationNameToString(n),io(t)),a=e.createDiagnosticForNode(n,e.Diagnostics.Did_you_forget_to_use_await);else{var d=e.declarationNameToString(n),p=io(t),f=FS(d,t);if(void 0!==f)r=e.chainDiagnosticMessages(r,e.Diagnostics.Property_0_does_not_exist_on_type_1_Do_you_need_to_change_your_target_library_Try_changing_the_lib_compiler_option_to_2_or_later,d,p,f);else{var m=GS(n,t);if(void 0!==m){var _=e.symbolName(m);r=e.chainDiagnosticMessages(r,e.Diagnostics.Property_0_does_not_exist_on_type_1_Did_you_mean_2,d,p,_),a=m.valueDeclaration&&e.createDiagnosticForNode(m.valueDeclaration,e.Diagnostics._0_is_declared_here,_)}else{var g=wS(t)?e.Diagnostics.Property_0_does_not_exist_on_type_1_Try_changing_the_lib_compiler_option_to_include_dom:e.Diagnostics.Property_0_does_not_exist_on_type_1;r=e.chainDiagnosticMessages(mu(r,t),g,d,p)}}}}var y=e.createDiagnosticForNodeFromMessageChain(n,r);a&&e.addRelatedInfo(y,a),nr.add(y)}function wS(n){return C.lib&&!C.lib.includes("dom")&&eb(n,(function(n){return n.symbol&&/^(EventTarget|Node|((HTML[a-zA-Z]*)?Element))$/.test(e.unescapeLeadingUnderscores(n.symbol.escapedName))}))&&bg(n)}function PS(n,t){var r=t.symbol&&_u(ws(t.symbol),n);return void 0!==r&&!!r.valueDeclaration&&e.hasSyntacticModifier(r.valueDeclaration,32)}function MS(n){for(var t=zr(n),r=e.getScriptTargetFeatures(),a=e.getOwnKeys(r),i=0,o=a;i<o.length;i++){var s=o[i],c=e.getOwnKeys(r[s]);if(void 0!==c&&e.contains(c,t))return s}}function FS(n,t){var r=au(t).symbol;if(r)for(var a=e.getScriptTargetFeatures(),i=e.getOwnKeys(a),o=0,s=i;o<s.length;o++){var c=s[o],l=a[c],u=l[e.symbolName(r)];if(void 0!==u&&e.contains(u,n))return c}}function GS(n,t){var r=wl(t);if("string"!==typeof n){var a=n.parent;e.isPropertyAccessExpression(a)&&(r=e.filter(r,(function(e){return YS(a,t,e)}))),n=e.idText(n)}return zS(n,r,111551)}function BS(n,t){var r=e.isString(n)?n:e.idText(n),a=wl(t),i="for"===r?e.find(a,(function(n){return"htmlFor"===e.symbolName(n)})):"class"===r?e.find(a,(function(n){return"className"===e.symbolName(n)})):void 0;return null!==i&&void 0!==i?i:zS(r,a,111551)}function US(n,t){var r=GS(n,t);return r&&e.symbolName(r)}function VS(n,t,r){e.Debug.assert(void 0!==t,"outername should always be defined");var a=jr(n,t,r,void 0,t,!1,!1,(function(n,r,a){e.Debug.assertEqual(t,r,"name should equal outerName");var i=Fr(n,r,a);return i||zS(e.unescapeLeadingUnderscores(r),e.arrayFrom(n.values()),a)}));return a}function jS(n,t,r){var a=VS(n,t,r);return a&&e.symbolName(a)}function KS(n,t){return t.exports&&zS(e.idText(n),si(t),2623475)}function HS(n,t){var r=KS(n,t);return r&&e.symbolName(r)}function WS(n,t,r){function a(e){var t=Rl(n,e);if(t){var a=mx(ws(t));return!!a&&UL(a)>=1&&W_(r,ML(a,0))}return!1}var i=e.isAssignmentTarget(t)?"set":"get";if(a(i)){var o=e.tryGetPropertyAccessOrIdentifierToString(t.expression);return void 0===o?o=i:o+="."+i,o}}function zS(n,t,r){return e.getSpellingSuggestion(n,t,a);function a(n){var t=e.symbolName(n);if(!e.startsWith(t,'"')){if(n.flags&r)return t;if(2097152&n.flags){var a=Ga(n);if(a&&a.flags&r)return t}}}}function qS(n,t,r){var a=n&&106500&n.flags&&n.valueDeclaration;if(a){var i=e.hasEffectiveModifier(a,8),o=n.valueDeclaration&&e.isNamedDeclaration(n.valueDeclaration)&&e.isPrivateIdentifier(n.valueDeclaration.name);if((i||o)&&(!t||!e.isWriteOnlyAccess(t)||65536&n.flags)){if(r){var s=e.findAncestor(t,e.isFunctionLikeDeclaration);if(s&&s.symbol===n)return}(1&e.getCheckFlags(n)?wr(n).target:n).isReferenced=67108863}}}function JS(n,t){return 107===n.kind||!!t&&e.isEntityNameExpression(n)&&t===rv(e.getFirstIdentifier(n))}function XS(e,n){switch(e.kind){case 202:return QS(e,105===e.expression.kind,n,sh(TA(e.expression)));case 158:return QS(e,!1,n,sh(TA(e.left)));case 196:return QS(e,!1,n,zm(e))}}function YS(e,n,t){return QS(e,202===e.kind&&105===e.expression.kind,t.escapedName,n)}function QS(n,t,r,a){if(a===Ae||ko(a))return!0;var i=_u(a,r);if(i){if(i.valueDeclaration&&e.isPrivateIdentifierClassElementDeclaration(i.valueDeclaration)){var o=e.getContainingClass(i.valueDeclaration);return!e.isOptionalChain(n)&&!!e.findAncestor(n,(function(e){return e===o}))}return cS(n,t,!1,a,i,!1)}return e.isInJSFile(n)&&0!==(1048576&a.flags)&&a.types.some((function(e){return QS(n,t,r,e)}))}function ZS(n){var t=n.initializer;if(251===t.kind){var r=t.declarations[0];if(r&&!e.isBindingPattern(r.name))return yi(r)}else if(78===t.kind)return rv(t)}function $S(e){return Eu(e,1)&&!Eu(e,0)}function ex(n){var t=e.skipParentheses(n);if(78===t.kind){var r=rv(t);if(3&r.flags){var a=n,i=n.parent;while(i){if(239===i.kind&&a===i.statement&&ZS(i)===r&&$S(vA(i.expression)))return!0;a=i,i=i.parent}}}return!1}function nx(e,n){return 32&e.flags?tx(e,n):rx(e,dS(e.expression),n)}function tx(e,n){var t=TA(e.expression),r=Xy(t,e.expression);return Jy(rx(e,yS(r,e.expression),n),e,r!==t)}function rx(n,t,r){var a=0!==e.getAssignmentTargetKind(n)||TS(n)?sh(t):t,i=n.argumentExpression,o=TA(i);if(a===Ae||a===qe)return a;if(ND(a)&&!e.isStringLiteralLike(i))return gr(i,e.Diagnostics.A_const_enum_member_can_only_be_accessed_using_a_string_literal),Ae;var s=ex(i)?Fe:o,c=e.isAssignmentTarget(n)?2|(Jf(a)&&!Yf(a)?1:0):0,l=sm(a,s,void 0,n,16|c)||Ae;return $A(CS(n,Pr(n).resolvedSymbol,l,i,r),n)}function ax(n){return e.isCallOrNewExpression(n)||e.isTaggedTemplateExpression(n)||e.isJsxOpeningLikeElement(n)}function ix(n){return ax(n)&&e.forEach(n.typeArguments,pk),206===n.kind?TA(n.template):e.isJsxOpeningLikeElement(n)?TA(n.attributes):162!==n.kind&&e.forEach(n.arguments,(function(e){TA(e)})),pt}function ox(e){return ix(e),ft}function sx(n,t,r){var a,i,o,s,c=0,l=-1;e.Debug.assert(!t.length);for(var u=0,d=n;u<d.length;u++){var p=d[u],f=p.declaration&&yi(p.declaration),m=p.declaration&&p.declaration.parent;i&&f!==i?(o=c=t.length,a=m):a&&m===a?o+=1:(a=m,o=c),i=f,K(p)?(l++,s=l,c++):s=o,t.splice(s,0,r?Hc(p,r):p)}}function cx(e){return!!e&&(221===e.kind||228===e.kind&&e.isSpread)}function lx(n){return e.findIndex(n,cx)}function ux(e){return!!(16384&e.flags)}function dx(e){return!!(49155&e.flags)}function px(n,t,r,a){var i;void 0===a&&(a=!1);var o=!1,s=BL(r),c=UL(r);if(206===n.kind)if(i=t.length,219===n.template.kind){var l=e.last(n.template.templateSpans);o=e.nodeIsMissing(l.literal)||!!l.literal.isUnterminated}else{var u=n.template;e.Debug.assert(14===u.kind),o=!!u.isUnterminated}else if(162===n.kind)i=kx(n,r);else if(e.isJsxOpeningLikeElement(n)){if(o=n.attributes.end===n.end,o)return!0;i=0===c?t.length:1,s=0===t.length?s:1,c=Math.min(c,1)}else{if(!n.arguments)return e.Debug.assert(205===n.kind),0===UL(r);i=a?t.length+1:t.length,o=n.arguments.end===n.end;var d=lx(t);if(d>=0)return d>=UL(r)&&(VL(r)||d<BL(r))}if(!VL(r)&&i>s)return!1;if(o||i>=c)return!0;for(var p=i;p<c;p++){var f=ML(r,p);if(131072&nb(f,e.isInJSFile(n)&&!z?dx:ux).flags)return!1}return!0}function fx(n,t){var r=e.length(n.typeParameters),a=ku(n.typeParameters);return!e.some(t)||t.length>=a&&t.length<=r}function mx(e){return gx(e,0,!1)}function _x(e){return gx(e,0,!1)||gx(e,1,!1)}function gx(e,n,t){if(524288&e.flags){var r=Nl(e);if(t||0===r.properties.length&&!r.stringIndexInfo&&!r.numberIndexInfo){if(0===n&&1===r.callSignatures.length&&0===r.constructSignatures.length)return r.callSignatures[0];if(1===n&&1===r.constructSignatures.length&&0===r.callSignatures.length)return r.constructSignatures[0]}}}function yx(n,t,r,a){var i=mh(n.typeParameters,n,0,a),o=jL(t),s=r&&(o&&262144&o.flags?r.nonFixingMapper:r.mapper),c=s?p_(t,s):t;return ph(c,n,(function(e,n){Hh(i.inferences,e,n)})),r||fh(t,n,(function(e,n){Hh(i.inferences,e,n,128)})),Xu(n,nv(i),e.isInJSFile(t.declaration))}function hx(e,n,t,r){var a=QE(n,e),i=ZD(e.attributes,a,r,t);return Hh(r.inferences,i,a),nv(r)}function vx(n){if(!n)return We;var t=TA(n);return e.isOptionalChainRoot(n.parent)?Hy(t):e.isOptionalChain(n.parent)?qy(t):t}function bx(n,t,r,a,i){if(e.isJsxOpeningLikeElement(n))return hx(n,t,a,i);if(162!==n.kind){var o=JE(n,e.every(t.typeParameters,(function(e){return!!$l(e)}))?8:0);if(o){var s=XE(n),c=Th(_h(s,1)),l=A_(o,c),u=mx(l),d=u&&u.typeParameters?ad(Yu(u,u.typeParameters)):l,p=Hu(t);Hh(i.inferences,d,p,128);var f=mh(t.typeParameters,t,i.flags),m=A_(o,s&&s.returnMapper);Hh(f.inferences,m,p),i.returnMapper=e.some(f.inferences,dA)?Th(Eh(f)):void 0}}var _=KL(t),g=_?Math.min(BL(t)-1,r.length):r.length;if(_&&262144&_.flags){var y=e.find(i.inferences,(function(e){return e.typeParameter===_}));y&&(y.impliedArity=e.findIndex(r,cx,g)<0?r.length-g:void 0)}var h=Uu(t);if(h){var v=Ax(n);Hh(i.inferences,vx(v),h)}for(var b=0;b<g;b++){var E=r[b];if(223!==E.kind){var T=ML(t,b),S=ZD(E,T,i,a);Hh(i.inferences,S,T)}}if(_){var x=Tx(r,g,r.length,_,i,a);Hh(i.inferences,x,_)}return nv(i)}function Ex(e){return 1048576&e.flags?rb(e,Ex):1&e.flags||ly(ql(e)||e)?e:Cy(e)?Np(Td(e),e.target.elementFlags,!1,e.target.labeledElementDeclarations):Np([e],[8])}function Tx(n,t,r,a,i,o){if(t>=r-1){var s=n[r-1];if(cx(s))return Ex(228===s.kind?s.type:ZD(s.expression,a,i,o))}for(var c=[],l=[],u=[],d=t;d<r;d++){s=n[d];if(cx(s)){var p=228===s.kind?s.type:TA(s.expression);dy(p)?(c.push(p),l.push(8)):(c.push(NI(33,p,ke,221===s.kind?s.expression:s)),l.push(4))}else{var f=im(a,Fm(d-t)),m=ZD(s,f,i,o),_=AD(f,406978556);c.push(_?Pm(m):Sy(m)),l.push(1)}228===s.kind&&s.tupleNameSource&&u.push(s.tupleNameSource)}return Np(c,l,!1,e.length(u)===e.length(c)?u:void 0)}function Sx(n,t,r,a){for(var i,o=e.isInJSFile(n.declaration),s=n.typeParameters,c=Ru(e.map(t,zm),s,ku(s),o),l=0;l<t.length;l++){e.Debug.assert(void 0!==s[l],"Should not call checkTypeArguments with too many type arguments");var u=Gl(s[l]);if(u){var d=r&&a?function(){return e.chainDiagnosticMessages(void 0,e.Diagnostics.Type_0_does_not_satisfy_the_constraint_1)}:void 0,p=a||e.Diagnostics.Type_0_does_not_satisfy_the_constraint_1;i||(i=Qm(s,c));var f=c[l];if(!X_(f,Fc(A_(u,i),f),r?t[l]:void 0,p,d))return}}return c}function xx(n){if(OT(n.tagName))return 2;var t=au(TA(n.tagName));return e.length(yu(t,1))?0:e.length(yu(t,0))?1:2}function Lx(n,t,r,a,i,o,s){var c=QE(t,n),l=ZD(n.attributes,c,void 0,a);return u()&&Q_(l,c,r,i?n.tagName:void 0,n.attributes,void 0,o,s);function u(){var t;if(VT(n))return!0;var r=e.isJsxOpeningElement(n)||e.isJsxSelfClosingElement(n)&&!OT(n.tagName)?TA(n.tagName):void 0;if(!r)return!0;var a=yu(r,0);if(!e.length(a))return!0;var o=FR(n);if(!o)return!0;var c=qa(o,111551,!0,!1,n);if(!c)return!0;var l=ws(c),u=yu(l,0);if(!e.length(u))return!0;for(var d=!1,p=0,f=0,m=u;f<m.length;f++){var _=m[f],g=ML(_,0),y=yu(g,0);if(e.length(y))for(var h=0,v=y;h<v.length;h++){var b=v[h];if(d=!0,VL(b))return!0;var E=BL(b);E>p&&(p=E)}}if(!d)return!0;for(var T=1/0,S=0,x=a;S<x.length;S++){var L=x[S],D=UL(L);D<T&&(T=D)}if(T<=p)return!0;if(i){var A=e.createDiagnosticForNode(n.tagName,e.Diagnostics.Tag_0_expects_at_least_1_arguments_but_the_JSX_factory_2_provides_at_most_3,e.entityNameToString(n.tagName),T,e.entityNameToString(o),p),C=null===(t=jk(n.tagName))||void 0===t?void 0:t.valueDeclaration;C&&e.addRelatedInfo(A,e.createDiagnosticForNode(C,e.Diagnostics._0_is_declared_here,e.entityNameToString(n.tagName))),s&&s.skipLogging&&(s.errors||(s.errors=[])).push(A),s.skipLogging||nr.add(A)}return!1}}function Dx(n,t,r,a,i,o,s){var c={errors:void 0,skipLogging:!0};if(e.isJsxOpeningLikeElement(n))return Lx(n,r,a,i,o,s,c)?void 0:(e.Debug.assert(!o||!!c.errors,"jsx should have errors when reporting errors"),c.errors||e.emptyArray);var l=Uu(r);if(l&&l!==We&&205!==n.kind){var u=Ax(n),d=vx(u),p=o?u||n:void 0,f=e.Diagnostics.The_this_context_of_type_0_is_not_assignable_to_method_s_this_of_type_1;if(!Cg(d,l,a,p,f,s,c))return e.Debug.assert(!o||!!c.errors,"this parameter should have errors when reporting errors"),c.errors||e.emptyArray}for(var m=e.Diagnostics.Argument_of_type_0_is_not_assignable_to_parameter_of_type_1,_=KL(r),g=_?Math.min(BL(r)-1,t.length):t.length,y=0;y<g;y++){var h=t[y];if(223!==h.kind){var v=ML(r,y),b=ZD(h,v,void 0,i),E=4&i?eh(b):b;if(!Q_(E,v,a,o?h:void 0,h,m,s,c))return e.Debug.assert(!o||!!c.errors,"parameter should have errors when reporting errors"),x(h,E,v),c.errors||e.emptyArray}}if(_){var T=Tx(t,g,t.length,_,void 0,i),S=t.length-g;p=o?0===S?n:1===S?t[g]:e.setTextRangePosEnd(Cx(n,T),t[g].pos,t[t.length-1].end):void 0;if(!Cg(T,_,a,p,m,void 0,c))return e.Debug.assert(!o||!!c.errors,"rest parameter should have errors when reporting errors"),x(p,T,_),c.errors||e.emptyArray}return;function x(n,t,r){if(n&&o&&c.errors&&c.errors.length){if(fC(r))return;var i=fC(t);i&&Lg(i,r,a)&&e.addRelatedInfo(c.errors[0],e.createDiagnosticForNode(n,e.Diagnostics.Did_you_forget_to_use_await))}}}function Ax(n){if(204===n.kind){var t=e.skipOuterExpressions(n.expression);if(e.isAccessExpression(t))return t.expression}}function Cx(n,t,r,a){var i=e.parseNodeFactory.createSyntheticExpression(t,r,a);return e.setTextRange(i,n),e.setParent(i,n),i}function Ix(n){if(206===n.kind){var t=n.template,r=[Cx(t,Xd())];return 219===t.kind&&e.forEach(t.templateSpans,(function(e){r.push(e.expression)})),r}if(162===n.kind)return Nx(n);if(e.isJsxOpeningLikeElement(n))return n.attributes.properties.length>0||e.isJsxOpeningElement(n)&&n.parent.children.length>0?[n.attributes]:e.emptyArray;var a=n.arguments||e.emptyArray,i=lx(a);if(i>=0){for(var o=a.slice(0,i),s=function(n){var t=a[n],r=221===t.kind&&(Ct?TA(t.expression):$D(t.expression));r&&Cy(r)?e.forEach(Td(r),(function(e,n){var a,i=r.target.elementFlags[n],s=Cx(t,4&i?Ep(e):e,!!(12&i),null===(a=r.target.labeledElementDeclarations)||void 0===a?void 0:a[n]);o.push(s)})):o.push(t)},c=i;c<a.length;c++)s(c);return o}return a}function Nx(n){var t=n.parent,r=n.expression;switch(t.kind){case 253:case 222:return[Cx(r,ws(yi(t)))];case 161:var a=t.parent;return[Cx(r,167===t.parent.kind?ws(yi(a)):Ae),Cx(r,xe),Cx(r,Fe)];case 164:case 166:case 168:case 169:var i=164!==t.kind&&0!==F;return[Cx(r,Xk(t)),Cx(r,Yk(t)),Cx(r,i?vp(Wk(t)):xe)]}return e.Debug.fail()}function kx(n,t){switch(n.parent.kind){case 253:case 222:return 1;case 164:return 2;case 166:case 168:case 169:return 0===F||t.parameters.length<=2?2:3;case 161:return 3;default:return e.Debug.fail()}}function Rx(n,t){var r,a,i=e.getSourceFileOfNode(n);if(e.isPropertyAccessExpression(n.expression)){var o=e.getErrorSpanForNode(i,n.expression.name);r=o.start,a=t?o.length:n.end-r}else{var s=e.getErrorSpanForNode(i,n.expression);r=s.start,a=t?s.length:n.end-r}return{start:r,length:a,sourceFile:i}}function Ox(n,t,r,a,i,o){if(e.isCallExpression(n)){var s=Rx(n),c=s.sourceFile,l=s.start,u=s.length;return e.createFileDiagnostic(c,l,u,t,r,a,i,o)}return e.createDiagnosticForNode(n,t,r,a,i,o)}function wx(n){if(!e.isCallExpression(n)||!e.isIdentifier(n.expression))return!1;var t=Vr(n.expression,n.expression.escapedText,111551,void 0,void 0,!1),r=null===t||void 0===t?void 0:t.valueDeclaration;if(!r||!e.isParameter(r)||!lT(r.parent)||!e.isNewExpression(r.parent.parent)||!e.isIdentifier(r.parent.parent.expression))return!1;var a=tp(!1);if(!a)return!1;var i=jk(r.parent.parent.expression,!0);return i===a}function Px(n,t,r){var a,i=lx(r);if(i>-1)return e.createDiagnosticForNode(r[i],e.Diagnostics.A_spread_argument_must_either_have_a_tuple_type_or_be_passed_to_a_rest_parameter);for(var o,s=Number.POSITIVE_INFINITY,c=Number.NEGATIVE_INFINITY,l=Number.NEGATIVE_INFINITY,u=Number.POSITIVE_INFINITY,d=0,p=t;d<p.length;d++){var f=p[d],m=UL(f),_=BL(f);m<s&&(s=m,o=f),c=Math.max(c,_),m<r.length&&m>l&&(l=m),r.length<_&&_<u&&(u=_)}var g=e.some(t,VL),y=g?s:s<c?s+"-"+c:s,h=g?e.Diagnostics.Expected_at_least_0_arguments_but_got_1:1===y&&0===r.length&&wx(n)?e.Diagnostics.Expected_0_arguments_but_got_1_Did_you_forget_to_include_void_in_your_type_argument_to_Promise:e.Diagnostics.Expected_0_arguments_but_got_1;if(s<r.length&&r.length<c)return Ox(n,e.Diagnostics.No_overload_expects_0_arguments_but_overloads_do_exist_that_expect_either_1_or_2_arguments,r.length,l,u);if(r.length<s){var v=Ox(n,h,y,r.length),b=null===(a=null===o||void 0===o?void 0:o.declaration)||void 0===a?void 0:a.parameters[o.thisParameter?r.length+1:r.length];if(b){var E=e.createDiagnosticForNode(b,e.isBindingPattern(b.name)?e.Diagnostics.An_argument_matching_this_binding_pattern_was_not_provided:e.isRestParameter(b)?e.Diagnostics.Arguments_for_the_rest_parameter_0_were_not_provided:e.Diagnostics.An_argument_for_0_was_not_provided,b.name?e.isBindingPattern(b.name)?void 0:e.idText(e.getFirstIdentifier(b.name)):r.length);return e.addRelatedInfo(v,E)}return v}var T=e.factory.createNodeArray(r.slice(c)),S=e.first(T).pos,x=e.last(T).end;return x===S&&x++,e.setTextRangePosEnd(T,S,x),e.createDiagnosticForNodeArray(e.getSourceFileOfNode(n),T,h,y,r.length)}function Mx(n,t,r){var a=r.length;if(1===t.length){var i=t[0],o=ku(i.typeParameters),s=e.length(i.typeParameters);return e.createDiagnosticForNodeArray(e.getSourceFileOfNode(n),r,e.Diagnostics.Expected_0_type_arguments_but_got_1,o<s?o+"-"+s:o,a)}for(var c=-1/0,l=1/0,u=0,d=t;u<d.length;u++){i=d[u];var p=ku(i.typeParameters);s=e.length(i.typeParameters);p>a?l=Math.min(l,p):s<a&&(c=Math.max(c,s))}return c!==-1/0&&l!==1/0?e.createDiagnosticForNodeArray(e.getSourceFileOfNode(n),r,e.Diagnostics.No_overload_expects_0_type_arguments_but_overloads_do_exist_that_expect_either_1_or_2_type_arguments,a,c,l):e.createDiagnosticForNodeArray(e.getSourceFileOfNode(n),r,e.Diagnostics.Expected_0_type_arguments_but_got_1,c===-1/0?l:c,a)}function Fx(n,r,a,o,s,c){var l,u=206===n.kind,d=162===n.kind,p=e.isJsxOpeningLikeElement(n),f=!a&&t;d||(l=n.typeArguments,(u||p||105!==n.expression.kind)&&e.forEach(l,pk));var m=a||[];if(sx(r,m,s),!m.length)return f&&nr.add(Ox(n,e.Diagnostics.Call_target_does_not_contain_any_signatures)),ox(n);var _,g,y,h,v=Ix(n),b=1===m.length&&!m[0].typeParameters,E=d||b||!e.some(v,w_)?0:4,T=!!(16&o)&&204===n.kind&&n.arguments.hasTrailingComma;if(m.length>1&&(h=J(m,ir,b,T)),h||(h=J(m,sr,b,T)),h)return h;if(f)if(_)if(1===_.length||_.length>3){var S,x=_[_.length-1];_.length>3&&(S=e.chainDiagnosticMessages(S,e.Diagnostics.The_last_overload_gave_the_following_error),S=e.chainDiagnosticMessages(S,e.Diagnostics.No_overload_matches_this_call));var L=Dx(n,v,x,sr,0,!0,(function(){return S}));if(L)for(var D=0,A=L;D<A.length;D++){var C=A[D];x.declaration&&_.length>3&&e.addRelatedInfo(C,e.createDiagnosticForNode(x.declaration,e.Diagnostics.The_last_overload_is_declared_here)),q(x,C),nr.add(C)}else e.Debug.fail("No error for last overload signature")}else{for(var I=[],N=0,k=Number.MAX_VALUE,R=0,O=0,w=function(t){var r=function(){return e.chainDiagnosticMessages(void 0,e.Diagnostics.Overload_0_of_1_2_gave_the_following_error,O+1,m.length,ao(t))},a=Dx(n,v,t,sr,0,!0,r);a?(a.length<=k&&(k=a.length,R=O),N=Math.max(N,a.length),I.push(a)):e.Debug.fail("No error for 3 or fewer overload signatures"),O++},P=0,M=_;P<M.length;P++){var F=M[P];w(F)}var G=N>1?I[R]:e.flatten(I);e.Debug.assert(G.length>0,"No errors reported for 3 or fewer overload signatures");var B=e.chainDiagnosticMessages(e.map(G,(function(e){return"string"===typeof e.messageText?e:e.messageText})),e.Diagnostics.No_overload_matches_this_call),U=i([],e.flatMap(G,(function(e){return e.relatedInformation}))),V=void 0;if(e.every(G,(function(e){return e.start===G[0].start&&e.length===G[0].length&&e.file===G[0].file}))){var j=G[0],K=j.file,H=j.start,W=j.length;V={file:K,start:H,length:W,code:B.code,category:B.category,messageText:B,relatedInformation:U}}else V=e.createDiagnosticForNodeFromMessageChain(n,B,U);q(_[0],V),nr.add(V)}else if(g)nr.add(Px(n,[g],v));else if(y)Sx(y,n.typeArguments,!0,c);else{var z=e.filter(r,(function(e){return fx(e,l)}));0===z.length?nr.add(Mx(n,r,l)):d?c&&nr.add(Ox(n,c)):nr.add(Px(n,z,v))}return Gx(n,m,v,!!a);function q(n,t){var r,a,i=_,o=g,s=y,c=(null===(a=null===(r=n.declaration)||void 0===r?void 0:r.symbol)||void 0===a?void 0:a.declarations)||e.emptyArray,l=c.length>1,u=l?e.find(c,(function(n){return e.isFunctionLikeDeclaration(n)&&e.nodeIsPresent(n.body)})):void 0;if(u){var d=Ou(u),p=!d.typeParameters;J([d],sr,p)&&e.addRelatedInfo(t,e.createDiagnosticForNode(u,e.Diagnostics.The_call_would_have_succeeded_against_this_implementation_but_implementation_signatures_of_overloads_are_not_externally_visible))}_=i,g=o,y=s}function J(t,r,a,i){if(void 0===i&&(i=!1),_=void 0,g=void 0,y=void 0,a){var o=t[0];if(e.some(l)||!px(n,v,o,i))return;return Dx(n,v,o,r,0,!1,void 0)?void(_=[o]):o}for(var s=0;s<t.length;s++){o=t[s];if(fx(o,l)&&px(n,v,o,i)){var c=void 0,u=void 0;if(o.typeParameters){var d=void 0;if(e.some(l)){if(d=Sx(o,l,!1),!d){y=o;continue}}else u=mh(o.typeParameters,o,e.isInJSFile(n)?2:0),d=bx(n,o,v,8|E,u),E|=4&u.flags?8:0;if(c=Xu(o,d,e.isInJSFile(o.declaration),u&&u.inferredTypeParameters),KL(o)&&!px(n,v,c,i)){g=c;continue}}else c=o;if(!Dx(n,v,c,r,E,!1,void 0)){if(E){if(E=0,u){d=bx(n,o,v,E,u);if(c=Xu(o,d,e.isInJSFile(o.declaration),u&&u.inferredTypeParameters),KL(o)&&!px(n,v,c,i)){g=c;continue}}if(Dx(n,v,c,r,E,!1,void 0)){(_||(_=[])).push(c);continue}}return t[s]=c,c}(_||(_=[])).push(c)}}}}function Gx(n,t,r,a){return e.Debug.assert(t.length>0),yk(n),a||1===t.length||t.some((function(e){return!!e.typeParameters}))?Kx(n,t,r):Bx(t)}function Bx(n){var t,r=e.mapDefined(n,(function(e){return e.thisParameter}));r.length&&(t=Vx(r,r.map(kL)));for(var a=e.minAndMax(n,Ux),i=a.min,o=a.max,s=[],c=function(t){var r=e.mapDefined(n,(function(n){return j(n)?t<n.parameters.length-1?n.parameters[t]:e.last(n.parameters):t<n.parameters.length?n.parameters[t]:void 0}));e.Debug.assert(0!==r.length),s.push(Vx(r,e.mapDefined(n,(function(e){return FL(e,t)}))))},l=0;l<o;l++)c(l);var u=e.mapDefined(n,(function(n){return j(n)?e.last(n.parameters):void 0})),d=0;if(0!==u.length){var p=Ep(Qp(e.mapDefined(n,Ju),2));s.push(jx(u,p)),d|=1}return n.some(K)&&(d|=2),Vc(n[0].declaration,void 0,t,s,pf(n.map(Hu)),void 0,i,d)}function Ux(e){var n=e.parameters.length;return j(e)?n-1:n}function Vx(e,n){return jx(e,Qp(n,2))}function jx(n,t){return Zy(e.first(n),t)}function Kx(n,t,r){var a=zx(t,void 0===oe?r.length:oe),i=t[a],o=i.typeParameters;if(!o)return i;var s=ax(n)?n.typeArguments:void 0,c=s?Qu(i,Hx(s,o,e.isInJSFile(n))):Wx(n,o,i,r);return t[a]=c,c}function Hx(e,n,t){var r=e.map(Wk);while(r.length>n.length)r.pop();while(r.length<n.length)r.push(Gl(n[r.length])||ev(t));return r}function Wx(n,t,r,a){var i=mh(t,r,e.isInJSFile(n)?2:0),o=bx(n,r,a,12,i);return Qu(r,o)}function zx(e,n){for(var t=-1,r=-1,a=0;a<e.length;a++){var i=e[a],o=BL(i);if(VL(i)||o>=n)return a;o>r&&(r=o,t=a)}return t}function qx(n,t,r){if(105===n.expression.kind){var a=lE(n.expression);if(ko(a)){for(var i=0,o=n.arguments;i<o.length;i++){var s=o[i];TA(s)}return pt}if(a!==Ae){var c=e.getEffectiveBaseTypeNode(e.getContainingClass(n));if(c){var l=qs(a,c.typeArguments,c);return Fx(n,l,t,r,0)}}return ix(n)}var u,d=TA(n.expression);if(e.isCallChain(n)){var p=Xy(d,n.expression);u=p===d?0:e.isOutermostOptionalChain(n)?16:8,d=p}else u=0;if(d=gS(d,n.expression,_S),d===qe)return _t;var f=au(d);if(f===Ae)return ox(n);var m=yu(f,0),_=yu(f,1).length;if(Xx(d,f,m.length,_))return d!==Ae&&n.typeArguments&&gr(n,e.Diagnostics.Untyped_function_calls_may_not_accept_type_arguments),ix(n);if(!m.length){if(_)gr(n,e.Diagnostics.Value_of_type_0_is_not_callable_Did_you_mean_to_include_new,io(d));else{var g=void 0;if(1===n.arguments.length){var y=e.getSourceFileOfNode(n).text;e.isLineBreak(y.charCodeAt(e.skipTrivia(y,n.expression.end,!0)-1))&&(g=e.createDiagnosticForNode(n.expression,e.Diagnostics.Are_you_missing_a_semicolon))}eL(n.expression,f,0,g)}return ox(n)}return 8&r&&!n.typeArguments&&m.some(Jx)?(uA(n,r),mt):m.some((function(n){return e.isInJSFile(n.declaration)&&!!e.getJSDocClassTag(n.declaration)}))?(gr(n,e.Diagnostics.Value_of_type_0_is_not_callable_Did_you_mean_to_include_new,io(d)),ox(n)):Fx(n,m,t,r,u)}function Jx(e){return!(!e.typeParameters||!DR(Hu(e)))}function Xx(e,n,t,r){return ko(e)||ko(n)&&!!(262144&e.flags)||!t&&!r&&!(1048576&n.flags)&&!(131072&lu(n).flags)&&W_(e,En)}function Yx(n,t,r){if(n.arguments&&F<1){var a=lx(n.arguments);a>=0&&gr(n.arguments[a],e.Diagnostics.Spread_operator_in_new_expressions_is_only_available_when_targeting_ECMAScript_5_and_higher)}var i=dS(n.expression);if(i===qe)return _t;if(i=au(i),i===Ae)return ox(n);if(ko(i))return n.typeArguments&&gr(n,e.Diagnostics.Untyped_function_calls_may_not_accept_type_arguments),ix(n);var o=yu(i,1);if(o.length){if(!Zx(n,o[0]))return ox(n);if(o.some((function(e){return 4&e.flags})))return gr(n,e.Diagnostics.Cannot_create_an_instance_of_an_abstract_class),ox(n);var s=i.symbol&&e.getClassLikeDeclarationOfSymbol(i.symbol);return s&&e.hasSyntacticModifier(s,128)?(gr(n,e.Diagnostics.Cannot_create_an_instance_of_an_abstract_class),ox(n)):Fx(n,o,t,r,0)}var c=yu(i,0);if(c.length){var l=Fx(n,c,t,r,0);return Y||(l.declaration&&!uL(l.declaration)&&Hu(l)!==We&&gr(n,e.Diagnostics.Only_a_void_function_can_be_called_with_the_new_keyword),Uu(l)===We&&gr(n,e.Diagnostics.A_function_that_is_called_with_the_new_keyword_cannot_have_a_this_type_that_is_void)),l}return eL(n.expression,i,1),ox(n)}function Qx(n,t){var r=Qs(t);if(!e.length(r))return!1;var a=r[0];if(2097152&a.flags){for(var i=a.types,o=ol(i),s=0,c=0,l=a.types;c<l.length;c++){var u=l[c];if(!o[s]&&3&e.getObjectFlags(u)){if(u.symbol===n)return!0;if(Qx(n,u))return!0}s++}return!1}return a.symbol===n||Qx(n,a)}function Zx(n,t){if(!t||!t.declaration)return!0;var r=t.declaration,a=e.getSelectedEffectiveModifierFlags(r,24);if(!a||167!==r.kind)return!0;var i=e.getClassLikeDeclarationOfSymbol(r.parent.symbol),o=mc(r.parent.symbol);if(!Mk(n,i)){var s=e.getContainingClass(n);if(s&&16&a){var c=Wk(s);if(Qx(r.parent.symbol,c))return!0}return 8&a&&gr(n,e.Diagnostics.Constructor_of_class_0_is_private_and_only_accessible_within_the_class_declaration,io(o)),16&a&&gr(n,e.Diagnostics.Constructor_of_class_0_is_protected_and_only_accessible_within_the_class_declaration,io(o)),!1}return!0}function $x(n,t,r){var a,i=0===r,o=yC(t),s=o&&yu(o,r).length>0;if(1048576&t.flags){for(var c=t.types,l=!1,u=0,d=c;u<d.length;u++){var p=d[u],f=yu(p,r);if(0!==f.length){if(l=!0,a)break}else if(a||(a=e.chainDiagnosticMessages(a,i?e.Diagnostics.Type_0_has_no_call_signatures:e.Diagnostics.Type_0_has_no_construct_signatures,io(p)),a=e.chainDiagnosticMessages(a,i?e.Diagnostics.Not_all_constituents_of_type_0_are_callable:e.Diagnostics.Not_all_constituents_of_type_0_are_constructable,io(t))),l)break}l||(a=e.chainDiagnosticMessages(void 0,i?e.Diagnostics.No_constituent_of_type_0_is_callable:e.Diagnostics.No_constituent_of_type_0_is_constructable,io(t))),a||(a=e.chainDiagnosticMessages(a,i?e.Diagnostics.Each_member_of_the_union_type_0_has_signatures_but_none_of_those_signatures_are_compatible_with_each_other:e.Diagnostics.Each_member_of_the_union_type_0_has_construct_signatures_but_none_of_those_signatures_are_compatible_with_each_other,io(t)))}else a=e.chainDiagnosticMessages(a,i?e.Diagnostics.Type_0_has_no_call_signatures:e.Diagnostics.Type_0_has_no_construct_signatures,io(t));var m=i?e.Diagnostics.This_expression_is_not_callable:e.Diagnostics.This_expression_is_not_constructable;if(e.isCallExpression(n.parent)&&0===n.parent.arguments.length){var _=Pr(n).resolvedSymbol;_&&32768&_.flags&&(m=e.Diagnostics.This_expression_is_not_callable_because_it_is_a_get_accessor_Did_you_mean_to_use_it_without)}return{messageChain:e.chainDiagnosticMessages(a,m),relatedMessage:s?e.Diagnostics.Did_you_forget_to_use_await:void 0}}function eL(n,t,r,a){var i=$x(n,t,r),o=i.messageChain,s=i.relatedMessage,c=e.createDiagnosticForNodeFromMessageChain(n,o);if(s&&e.addRelatedInfo(c,e.createDiagnosticForNode(n,s)),e.isCallExpression(n.parent)){var l=Rx(n.parent,!0),u=l.start,d=l.length;c.start=u,c.length=d}nr.add(c),nL(t,r,a?e.addRelatedInfo(c,a):c)}function nL(n,t,r){if(n.symbol){var a=wr(n.symbol).originatingImport;if(a&&!e.isImportCall(a)){var i=yu(ws(wr(n.symbol).target),t);if(!i||!i.length)return;e.addRelatedInfo(r,e.createDiagnosticForNode(a,e.Diagnostics.Type_originates_at_this_import_A_namespace_style_import_cannot_be_called_or_constructed_and_will_cause_a_failure_at_runtime_Consider_using_a_default_import_or_import_require_here_instead))}}}function tL(n,t,r){var a=TA(n.tag),i=au(a);if(i===Ae)return ox(n);var o=yu(i,0),s=yu(i,1).length;if(Xx(a,i,o.length,s))return ix(n);if(!o.length){if(e.isArrayLiteralExpression(n.parent)){var c=e.createDiagnosticForNode(n.tag,e.Diagnostics.It_is_likely_that_you_are_missing_a_comma_to_separate_these_two_template_expressions_They_form_a_tagged_template_expression_which_cannot_be_invoked);return nr.add(c),ox(n)}return eL(n.tag,i,0),ox(n)}return Fx(n,o,t,r,0)}function rL(n){switch(n.parent.kind){case 253:case 222:return e.Diagnostics.Unable_to_resolve_signature_of_class_decorator_when_called_as_an_expression;case 161:return e.Diagnostics.Unable_to_resolve_signature_of_parameter_decorator_when_called_as_an_expression;case 164:return e.Diagnostics.Unable_to_resolve_signature_of_property_decorator_when_called_as_an_expression;case 166:case 168:case 169:return e.Diagnostics.Unable_to_resolve_signature_of_method_decorator_when_called_as_an_expression;default:return e.Debug.fail()}}function aL(n,t,r){var a=TA(n.expression),i=au(a);if(i===Ae)return ox(n);var o=yu(i,0),s=yu(i,1).length;if(Xx(a,i,o.length,s))return ix(n);if(sL(n,o)){var c=e.getTextOfNode(n.expression,!1);return gr(n,e.Diagnostics._0_accepts_too_few_arguments_to_be_used_as_a_decorator_here_Did_you_mean_to_call_it_first_and_write_0,c),ox(n)}var l=rL(n);if(!o.length){var u=$x(n.expression,i,0),d=e.chainDiagnosticMessages(u.messageChain,l),p=e.createDiagnosticForNodeFromMessageChain(n.expression,d);return u.relatedMessage&&e.addRelatedInfo(p,e.createDiagnosticForNode(n.expression,u.relatedMessage)),nr.add(p),nL(i,0,p),ox(n)}return Fx(n,o,t,r,0,l)}function iL(n,t){var r=jT(n),a=r&&pi(r),i=a&&Fr(a,N.Element,788968),o=i&&te.symbolToEntityName(i,788968,n),s=e.factory.createFunctionTypeNode(void 0,[e.factory.createParameterDeclaration(void 0,void 0,void 0,"props",void 0,te.typeToTypeNode(t,n))],o?e.factory.createTypeReferenceNode(o,void 0):e.factory.createKeywordTypeNode(128)),c=Sr(1,"props");return c.type=t,Vc(s,void 0,void 0,[c],i?mc(i):Ae,void 0,1,0)}function oL(n,t,r){if(OT(n.tagName)){var a=YT(n),i=iL(n,a);return Y_(ZD(n.attributes,QE(i,n),void 0,0),a,n.tagName,n.attributes),e.length(n.typeArguments)&&(e.forEach(n.typeArguments,pk),nr.add(e.createDiagnosticForNodeArray(e.getSourceFileOfNode(n),n.typeArguments,e.Diagnostics.Expected_0_type_arguments_but_got_1,0,e.length(n.typeArguments)))),i}var o=TA(n.tagName),s=au(o);if(s===Ae)return ox(n);var c=qT(o,n);return Xx(o,s,c.length,0)?ix(n):0===c.length?(gr(n.tagName,e.Diagnostics.JSX_element_type_0_does_not_have_any_construct_or_call_signatures,e.getTextOfNode(n.tagName)),ox(n)):Fx(n,c,t,r,0)}function sL(n,t){return t.length&&e.every(t,(function(e){return 0===e.minArgumentCount&&!j(e)&&e.parameters.length<kx(n,e)}))}function cL(n,t,r){switch(n.kind){case 204:return qx(n,t,r);case 205:return Yx(n,t,r);case 206:return tL(n,t,r);case 162:return aL(n,t,r);case 276:case 275:return oL(n,t,r)}throw e.Debug.assertNever(n,"Branch in 'resolveSignature' should be unreachable.")}function lL(e,n,t){var r=Pr(e),a=r.resolvedSignature;if(a&&a!==mt&&!n)return a;r.resolvedSignature=mt;var i=cL(e,n,t||0);return i!==mt&&(r.resolvedSignature=At===Ct?i:a),i}function uL(n){var t;if(!n||!e.isInJSFile(n))return!1;var r=e.isFunctionDeclaration(n)||e.isFunctionExpression(n)?n:e.isVariableDeclaration(n)&&n.initializer&&e.isFunctionExpression(n.initializer)?n.initializer:void 0;if(r){if(e.getJSDocClassTag(n))return!0;var a=yi(r);return!!(null===(t=null===a||void 0===a?void 0:a.members)||void 0===t?void 0:t.size)}return!1}function dL(n,t){var r,a;if(t){var i=wr(t);if(!i.inferredClassSymbol||!i.inferredClassSymbol.has(P(n))){var o=e.isTransientSymbol(n)?n:Dr(n);return o.exports=o.exports||e.createSymbolTable(),o.members=o.members||e.createSymbolTable(),o.flags|=32&t.flags,(null===(r=t.exports)||void 0===r?void 0:r.size)&&kr(o.exports,t.exports),(null===(a=t.members)||void 0===a?void 0:a.size)&&kr(o.members,t.members),(i.inferredClassSymbol||(i.inferredClassSymbol=new e.Map)).set(P(o),o),o}return i.inferredClassSymbol.get(P(n))}}function pL(e){var n,t=e&&fL(e,!0),r=null===(n=null===t||void 0===t?void 0:t.exports)||void 0===n?void 0:n.get("prototype"),a=(null===r||void 0===r?void 0:r.valueDeclaration)&&mL(r.valueDeclaration);return a?yi(a):void 0}function fL(n,t){if(n.parent){var r,a;if(e.isVariableDeclaration(n.parent)&&n.parent.initializer===n){if(!e.isInJSFile(n)&&(!e.isVarConst(n.parent)||!e.isFunctionLikeDeclaration(n)))return;r=n.parent.name,a=n.parent}else if(e.isBinaryExpression(n.parent)){var i=n.parent,o=n.parent.operatorToken.kind;if(62!==o||!t&&i.right!==n){if((56===o||60===o)&&(e.isVariableDeclaration(i.parent)&&i.parent.initializer===i?(r=i.parent.name,a=i.parent):e.isBinaryExpression(i.parent)&&62===i.parent.operatorToken.kind&&(t||i.parent.right===i)&&(r=i.parent.left,a=r),!r||!e.isBindableStaticNameExpression(r)||!e.isSameEntityName(r,i.left)))return}else r=i.left,a=r}else t&&e.isFunctionDeclaration(n)&&(r=n.name,a=n);if(a&&r&&(t||e.getExpandoInitializer(n,e.isPrototypeAccess(r))))return yi(a)}}function mL(n){if(!n.parent)return!1;var t=n.parent;while(t&&202===t.kind)t=t.parent;if(t&&e.isBinaryExpression(t)&&e.isPrototypeAccess(t.left)&&62===t.operatorToken.kind){var r=e.getInitializerOfBinaryExpression(t);return e.isObjectLiteralExpression(r)&&r}}function _L(n,t){var r;lO(n,n.typeArguments)||pO(n.arguments);var a=lL(n,void 0,t);if(a===mt)return Je;if(gL(a,n),105===n.expression.kind)return We;if(205===n.kind){var i=a.declaration;if(i&&167!==i.kind&&171!==i.kind&&176!==i.kind&&!e.isJSDocConstructSignature(i)&&!uL(i))return Y&&gr(n,e.Diagnostics.new_expression_whose_target_lacks_a_construct_signature_implicitly_has_an_any_type),xe}if(e.isInJSFile(n)&&EL(n))return Bu(n.arguments[0]);var o=Hu(a);if(12288&o.flags&&hL(n))return Um(e.walkUpParenthesizedExpressions(n.parent));if(204===n.kind&&!n.questionDotToken&&234===n.parent.kind&&16384&o.flags&&Vu(a))if(e.isDottedName(n.expression)){if(!Sb(n)){var s=gr(n.expression,e.Diagnostics.Assertions_require_every_name_in_the_call_target_to_be_declared_with_an_explicit_type_annotation);Tb(n.expression,s)}}else gr(n.expression,e.Diagnostics.Assertions_require_the_call_target_to_be_an_identifier_or_qualified_name);if(e.isInJSFile(n)){var c=fL(n,!1);if(null===(r=null===c||void 0===c?void 0:c.exports)||void 0===r?void 0:r.size){var l=Bi(c,c.exports,e.emptyArray,e.emptyArray,void 0,void 0);return l.objectFlags|=8192,pf([o,l])}}return o}function gL(n,t){if(n.declaration&&134217728&n.declaration.flags){var r=yL(t),a=e.tryGetPropertyAccessOrIdentifierToString(e.getInvokedExpression(t));Tr(r,n.declaration,a,ao(n))}}function yL(n){switch(n=e.skipParentheses(n),n.kind){case 204:case 162:case 205:return yL(n.expression);case 206:return yL(n.tag);case 276:case 275:return yL(n.tagName);case 203:return n.argumentExpression;case 202:return n.name;case 174:var t=n;return e.isQualifiedName(t.typeName)?t.typeName.right:t;default:return n}}function hL(n){if(!e.isCallExpression(n))return!1;var t=n.expression;if(e.isPropertyAccessExpression(t)&&"for"===t.name.escapedText&&(t=t.expression),!e.isIdentifier(t)||"Symbol"!==t.escapedText)return!1;var r=Qd(!1);return!!r&&r===Vr(t,"Symbol",111551,void 0,void 0,!1)}function vL(n){if(pO(n.arguments)||lw(n),0===n.arguments.length)return $L(n,xe);for(var t=n.arguments[0],r=$D(t),a=1;a<n.arguments.length;++a)$D(n.arguments[a]);(32768&r.flags||65536&r.flags||!W_(r,Me))&&gr(t,e.Diagnostics.Dynamic_import_s_specifier_must_be_of_type_string_but_here_has_type_0,io(r));var i=Za(n,t);if(i){var o=ii(i,t,!0,!1);if(o)return $L(n,bL(ws(o),o,i))}return $L(n,xe)}function bL(n,t,r){var a;if(W&&n&&n!==Ae){var i=n;if(!i.syntheticType){var o=null===(a=r.declarations)||void 0===a?void 0:a.find(e.isSourceFile),s=_a(o,r,!1);if(s){var c=e.createSymbolTable(),l=Sr(2097152,"default");l.parent=r,l.nameType=Fm("default"),l.target=Ma(t),c.set("default",l);var u=Sr(2048,"__type"),d=Bi(u,c,e.emptyArray,e.emptyArray,void 0,void 0);u.type=d,i.syntheticType=DT(n)?Im(n,d,u,0,!1):d}else i.syntheticType=n}return i.syntheticType}return n}function EL(n){if(!e.isRequireCall(n,!0))return!1;if(!e.isIdentifier(n.expression))return e.Debug.fail();var t=Vr(n.expression,n.expression.escapedText,111551,void 0,void 0,!0);if(t===ce)return!0;if(2097152&t.flags)return!1;var r=16&t.flags?252:3&t.flags?250:0;if(0!==r){var a=e.getDeclarationOfKind(t,r);return!!a&&!!(8388608&a.flags)}return!1}function TL(e){uO(e)||lO(e,e.typeArguments),F<2&&jR(e,262144);var n=lL(e);return gL(n,e),Hu(n)}function SL(e){return LL(e,e.type,e.expression)}function xL(n){switch(n.kind){case 10:case 14:case 8:case 9:case 109:case 94:case 200:case 201:case 219:return!0;case 208:return xL(n.expression);case 215:var t=n.operator,r=n.operand;return 40===t&&(8===r.kind||9===r.kind)||39===t&&8===r.kind;case 202:case 203:var a=n.expression;if(e.isIdentifier(a)){var i=jk(a);return i&&2097152&i.flags&&(i=Fa(i)),!!(i&&384&i.flags&&1===cc(i))}}return!1}function LL(n,r,a,i){var o=TA(a,i);if(e.isConstTypeReference(r))return xL(a)||gr(a,e.Diagnostics.A_const_assertions_can_only_be_applied_to_references_to_enum_members_or_string_number_boolean_array_or_object_literals),Pm(o);pk(r),o=eh(Ty(o));var s=zm(r);if(t&&s!==Ae){var c=sh(o);q_(s,c)||fg(o,s,n,e.Diagnostics.Conversion_of_type_0_to_type_1_may_be_a_mistake_because_neither_type_sufficiently_overlaps_with_the_other_If_this_was_intentional_convert_the_expression_to_unknown_first)}return s}function DL(e){var n=TA(e.expression),t=Xy(n,e.expression);return Jy(Hy(t),e,t!==n)}function AL(e){return 32&e.flags?DL(e):Hy(TA(e.expression))}function CL(n){return HO(n),102===n.keywordToken?IL(n):99===n.keywordToken?NL(n):e.Debug.assertNever(n.keywordToken)}function IL(n){var t=e.getNewTargetContainer(n);if(t){if(167===t.kind){var r=yi(t.parent);return ws(r)}r=yi(t);return ws(r)}return gr(n,e.Diagnostics.Meta_property_0_is_only_allowed_in_the_body_of_a_function_declaration_function_expression_or_constructor,"new.target"),Ae}function NL(n){G!==e.ModuleKind.ES2020&&G!==e.ModuleKind.ESNext&&G!==e.ModuleKind.System&&gr(n,e.Diagnostics.The_import_meta_meta_property_is_only_allowed_when_the_module_option_is_es2020_esnext_or_system);var t=e.getSourceFileOfNode(n);return e.Debug.assert(!!(2097152&t.flags),"Containing file is missing import meta node flag."),e.Debug.assert(!!t.externalModuleIndicator,"Containing file should be a module."),"meta"===n.name.escapedText?Yd():Ae}function kL(n){var t=ws(n);if(z){var r=n.valueDeclaration;if(r&&e.hasInitializer(r))return jy(t)}return t}function RL(n){return e.Debug.assert(e.isIdentifier(n.name)),n.name.escapedText}function OL(e,n,t){var r=e.parameters.length-(j(e)?1:0);if(n<r)return e.parameters[n].escapedName;var a=e.parameters[r]||Te,i=t||ws(a);if(Cy(i)){var o=i.target.labeledElementDeclarations,s=n-r;return o&&RL(o[s])||a.escapedName+"_"+s}return a.escapedName}function wL(n){return 193===n.kind||e.isParameter(n)&&n.name&&e.isIdentifier(n.name)}function PL(e,n){var t=e.parameters.length-(j(e)?1:0);if(n<t){var r=e.parameters[n].valueDeclaration;return r&&wL(r)?r:void 0}var a=e.parameters[t]||Te,i=ws(a);if(Cy(i)){var o=i.target.labeledElementDeclarations,s=n-t;return o&&o[s]}return a.valueDeclaration&&wL(a.valueDeclaration)?a.valueDeclaration:void 0}function ML(e,n){return FL(e,n)||xe}function FL(e,n){var t=e.parameters.length-(j(e)?1:0);if(n<t)return kL(e.parameters[n]);if(j(e)){var r=ws(e.parameters[t]),a=n-t;if(!Cy(r)||r.target.hasRestElement||a<r.target.fixedLength)return im(r,Fm(a))}}function GL(n,t){var r=BL(n),a=UL(n),i=jL(n);if(i&&t>=r-1)return t===r-1?i:Ep(im(i,Fe));for(var o=[],s=[],c=[],l=t;l<r;l++){!i||l<r-1?(o.push(ML(n,l)),s.push(l<a?1:2)):(o.push(i),s.push(8));var u=PL(n,l);u&&c.push(u)}return Np(o,s,!1,e.length(c)===e.length(o)?c:void 0)}function BL(e){var n=e.parameters.length;if(j(e)){var t=ws(e.parameters[n-1]);if(Cy(t))return n+t.target.fixedLength-(t.target.hasRestElement?0:1)}return n}function UL(n,t){var r=1&t,a=2&t;if(a||void 0===n.resolvedMinArgumentCount){var i=void 0;if(j(n)){var o=ws(n.parameters[n.parameters.length-1]);if(Cy(o)){var s=e.findIndex(o.target.elementFlags,(function(e){return!(1&e)})),c=s<0?o.target.fixedLength:s;c>0&&(i=n.parameters.length-1+c)}}if(void 0===i){if(!r&&32&n.flags)return 0;i=n.minArgumentCount}if(a)return i;for(var l=i-1;l>=0;l--){var u=ML(n,l);if(131072&nb(u,ux).flags)break;i=l}n.resolvedMinArgumentCount=i}return n.resolvedMinArgumentCount}function VL(e){if(j(e)){var n=ws(e.parameters[e.parameters.length-1]);return!Cy(n)||n.target.hasRestElement}return!1}function jL(e){if(j(e)){var n=ws(e.parameters[e.parameters.length-1]);if(!Cy(n))return n;if(n.target.hasRestElement)return Pp(n,n.target.fixedLength)}}function KL(e){var n=jL(e);return!n||sy(n)||ko(n)||0!==(131072&lu(n).flags)?void 0:n}function HL(e){return WL(e,ze)}function WL(e,n){return e.parameters.length>0?ML(e,0):n}function zL(n,t,r){for(var a=n.parameters.length-(j(n)?1:0),i=0;i<a;i++){var o=n.parameters[i].valueDeclaration;if(o.type){var s=e.getEffectiveTypeAnnotationNode(o);s&&Hh(r.inferences,zm(s),ML(t,i))}}var c=jL(t);if(c&&262144&c.flags){var l=p_(t,r.nonFixingMapper);qL(n,l);var u=BL(t)-1;Hh(r.inferences,GL(n,u),c)}}function qL(n,t){if(t.typeParameters){if(n.typeParameters)return;n.typeParameters=t.typeParameters}if(t.thisParameter){var r=n.thisParameter;(!r||r.valueDeclaration&&!r.valueDeclaration.type)&&(r||(n.thisParameter=Zy(t.thisParameter,void 0)),XL(n.thisParameter,ws(t.thisParameter)))}for(var a=n.parameters.length-(j(n)?1:0),i=0;i<a;i++){r=n.parameters[i];if(!e.getEffectiveTypeAnnotationNode(r.valueDeclaration)){var o=FL(t,i);XL(r,o)}}if(j(n)){r=e.last(n.parameters);if(e.isTransientSymbol(r)||!e.getEffectiveTypeAnnotationNode(r.valueDeclaration)){o=GL(t,a);XL(r,o)}}}function JL(e){e.thisParameter&&XL(e.thisParameter);for(var n=0,t=e.parameters;n<t.length;n++){var r=t[n];XL(r)}}function XL(e,n){var t=wr(e);if(!t.type){var r=e.valueDeclaration;t.type=n||us(r,!0),78!==r.name.kind&&(t.type===Ne&&(t.type=ls(r.name)),YL(r.name))}}function YL(n){for(var t=0,r=n.elements;t<r.length;t++){var a=r[t];e.isOmittedExpression(a)||(78===a.name.kind?wr(yi(a)).type=Vo(a):YL(a.name))}}function QL(e){var n=ep(!0);return n!==ln?(e=yC(e)||Ne,vd(n,[e])):Ne}function ZL(e){var n=np(!0);return n!==ln?(e=yC(e)||Ne,vd(n,[e])):Ne}function $L(n,t){var r=QL(t);return r===Ne?(gr(n,e.isImportCall(n)?e.Diagnostics.A_dynamic_import_call_returns_a_Promise_Make_sure_you_have_a_declaration_for_Promise_or_include_ES2015_in_your_lib_option:e.Diagnostics.An_async_function_or_method_must_return_a_Promise_Make_sure_you_have_a_declaration_for_Promise_or_include_ES2015_in_your_lib_option),Ae):(tp(!0)||gr(n,e.isImportCall(n)?e.Diagnostics.A_dynamic_import_call_in_ES5_SlashES3_requires_the_Promise_constructor_Make_sure_you_have_a_declaration_for_the_Promise_constructor_or_include_ES2015_in_your_lib_option:e.Diagnostics.An_async_function_or_method_in_ES5_SlashES3_requires_the_Promise_constructor_Make_sure_you_have_a_declaration_for_the_Promise_constructor_or_include_ES2015_in_your_lib_option),r)}function eD(n,t){if(!n.body)return Ae;var r,a,i,o=e.getFunctionFlags(n),s=0!==(2&o),c=0!==(1&o),l=We;if(231!==n.body.kind)r=$D(n.body,t&&-9&t),s&&(r=_C(r,n,e.Diagnostics.The_return_type_of_an_async_function_must_either_be_a_valid_promise_or_must_not_contain_a_callable_then_member));else if(c){var u=cD(n,t);u?u.length>0&&(r=Qp(u,2)):l=ze;var d=tD(n,t),p=d.yieldTypes,f=d.nextTypes;a=e.some(p)?Qp(p,2):void 0,i=e.some(f)?pf(f):void 0}else{var m=cD(n,t);if(!m)return 2&o?$L(n,ze):ze;if(0===m.length)return 2&o?$L(n,We):We;r=Qp(m,2)}if(r||a||i){if(a&&dh(n,a,3),r&&dh(n,r,1),i&&dh(n,i,2),r&&hy(r)||a&&hy(a)||i&&hy(i)){var _=uT(n),g=_?_===Ou(n)?c?void 0:r:zE(Hu(_),n):void 0;c?(a=Ay(a,g,0,s),r=Ay(r,g,1,s),i=Ay(i,g,2,s)):r=Dy(r,g,s)}a&&(a=sh(a)),r&&(r=sh(r)),i&&(i=sh(i))}return c?nD(a||ze,r||l,i||SE(2,n)||Ne,s):s?QL(r||l):r||l}function nD(e,n,t,r){var a=r?Tt:St,i=a.getGlobalGeneratorType(!1);if(e=a.resolveIterationType(e,void 0)||Ne,n=a.resolveIterationType(n,void 0)||Ne,t=a.resolveIterationType(t,void 0)||Ne,i===ln){var o=a.getGlobalIterableIteratorType(!1),s=o!==ln?jI(o,a):void 0,c=s?s.returnType:xe,l=s?s.nextType:ke;return W_(n,c)&&W_(l,t)?o!==ln?hp(o,[e]):(a.getGlobalIterableIteratorType(!0),an):(a.getGlobalGeneratorType(!0),an)}return hp(i,[e,n,t])}function tD(n,t){var r=[],a=[],i=0!==(2&e.getFunctionFlags(n));return e.forEachYieldExpression(n.body,(function(n){var o,s=n.expression?TA(n.expression,t):Re;if(e.pushIfUnique(r,rD(n,s,xe,i)),n.asteriskToken){var c=GI(s,i?19:17,n.expression);o=c&&c.nextType}else o=JE(n);o&&e.pushIfUnique(a,o)})),{yieldTypes:r,nextTypes:a}}function rD(n,t,r,a){var i=n.expression||n,o=n.asteriskToken?NI(a?19:17,t,r,i):t;return a?yC(o,i,n.asteriskToken?e.Diagnostics.Type_of_iterated_elements_of_a_yield_Asterisk_operand_must_either_be_a_valid_promise_or_must_not_contain_a_callable_then_member:e.Diagnostics.Type_of_yield_operand_in_an_async_generator_must_either_be_a_valid_promise_or_must_not_contain_a_callable_then_member):o}function aD(e,n,t,r){var a=0;if(r){for(var i=n;i<t.length;i++)a|=x.get(t[i])||32768;for(i=e;i<n;i++)a&=~(x.get(t[i])||0);for(i=0;i<e;i++)a|=x.get(t[i])||32768}else{for(i=e;i<n;i++)a|=S.get(t[i])||128;for(i=0;i<e;i++)a&=~(S.get(t[i])||0)}return a}function iD(e){var n=Pr(e);return void 0!==n.isExhaustive?n.isExhaustive:n.isExhaustive=oD(e)}function oD(n){if(212===n.expression.kind){var t=vA(n.expression.expression),r=qv(n,!1),a=aD(0,0,r,!0),i=ql(t)||t;return 3&i.flags?556800===(556800&a):!!(131072&nb(i,(function(e){return(xv(e)&a)===a})).flags)}var o=vA(n.expression);if(!Ey(o))return!1;var s=zv(n);return!(!s.length||e.some(s,yy))&&Jv(rb(o,Pm),s)}function sD(e){return e.endFlowNode&&Ab(e.endFlowNode)}function cD(n,t){var r=e.getFunctionFlags(n),a=[],i=sD(n),o=!1;if(e.forEachReturnStatement(n.body,(function(s){var c=s.expression;if(c){var l=$D(c,t&&-9&t);2&r&&(l=_C(l,n,e.Diagnostics.The_return_type_of_an_async_function_must_either_be_a_valid_promise_or_must_not_contain_a_callable_then_member)),131072&l.flags&&(o=!0),e.pushIfUnique(a,l)}else i=!0})),0!==a.length||i||!o&&!lD(n))return!(z&&a.length&&i)||uL(n)&&a.some((function(e){return e.symbol===n.symbol}))||e.pushIfUnique(a,ke),a}function lD(e){switch(e.kind){case 209:case 210:return!0;case 166:return 201===e.parent.kind;default:return!1}}function uD(n,r){if(t){var a=e.getFunctionFlags(n),i=r&&iN(r,a);if((!i||!AD(i,16385))&&165!==n.kind&&!e.nodeIsMissing(n.body)&&231===n.body.kind&&sD(n)){var o=512&n.flags,s=e.getEffectiveReturnTypeNode(n)||n;if(i&&131072&i.flags)gr(s,e.Diagnostics.A_function_returning_never_cannot_have_a_reachable_end_point);else if(i&&!o)gr(s,e.Diagnostics.A_function_whose_declared_type_is_neither_void_nor_any_must_return_a_value);else if(i&&z&&!W_(ke,i))gr(s,e.Diagnostics.Function_lacks_ending_return_statement_and_return_type_does_not_include_undefined);else if(C.noImplicitReturns){if(!i){if(!o)return;var c=Hu(Ou(n));if(oN(n,c))return}gr(s,e.Diagnostics.Not_all_code_paths_return_a_value)}}}}function dD(n,t){if(e.Debug.assert(166!==n.kind||e.isObjectLiteralMethod(n)),yk(n),t&&4&t&&w_(n)){if(!e.getEffectiveReturnTypeNode(n)&&!M_(n)){var r=dT(n);if(r&&Sh(Hu(r))){var a=Pr(n);if(a.contextFreeType)return a.contextFreeType;var i=eD(n,t),o=Vc(void 0,void 0,void 0,e.emptyArray,i,void 0,0,0),s=Bi(n.symbol,D,[o],e.emptyArray,void 0,void 0);return s.objectFlags|=524288,a.contextFreeType=s}}return un}var c=rO(n);return c||209!==n.kind||hO(n),pD(n,t),ws(yi(n))}function pD(n,t){var r=Pr(n);if(!(1024&r.flags)){var a=dT(n);if(!(1024&r.flags)){r.flags|=1024;var i=e.firstOrUndefined(yu(ws(yi(n)),0));if(!i)return;if(w_(n))if(a){var o=XE(n);t&&2&t&&zL(i,a,o);var s=o?p_(a,o.mapper):a;qL(i,s)}else JL(i);if(a&&!Wu(n)&&!i.resolvedReturnType){var c=eD(n,t);i.resolvedReturnType||(i.resolvedReturnType=c)}kA(n)}}}function fD(n){e.Debug.assert(166!==n.kind||e.isObjectLiteralMethod(n));var t=e.getFunctionFlags(n),r=Wu(n);if(uD(n,r),n.body)if(e.getEffectiveReturnTypeNode(n)||Hu(Ou(n)),231===n.body.kind)pk(n.body);else{var a=TA(n.body),i=r&&iN(r,t);if(i)if(2===(3&t)){var o=_C(a,n.body,e.Diagnostics.The_return_type_of_an_async_function_must_either_be_a_valid_promise_or_must_not_contain_a_callable_then_member);Y_(o,i,n.body,n.body)}else Y_(a,i,n.body,n.body)}}function mD(e,n,t,r){if(void 0===r&&(r=!1),!W_(n,en)){var a=r&&fC(n);return vr(e,!!a&&W_(a,en),t),!1}return!0}function _D(n){if(!e.isCallExpression(n))return!1;if(!e.isBindableObjectDefinePropertyCall(n))return!1;var t=$D(n.arguments[2]),r=Io(t,"value");if(r){var a=_u(t,"writable"),i=a&&ws(a);if(!i||i===Be||i===Ue)return!0;if(a&&a.valueDeclaration&&e.isPropertyAssignment(a.valueDeclaration)){var o=a.valueDeclaration.initializer,s=TA(o);if(s===Be||s===Ue)return!0}return!1}var c=_u(t,"set");return!c}function gD(n){return!!(8&e.getCheckFlags(n)||4&n.flags&&64&e.getDeclarationModifierFlagsFromSymbol(n)||3&n.flags&&2&oS(n)||98304&n.flags&&!(65536&n.flags)||8&n.flags||e.some(n.declarations,_D))}function yD(n,t,r){var a,i;if(0===r)return!1;if(gD(t)){if(4&t.flags&&e.isAccessExpression(n)&&107===n.expression.kind){var o=e.getContainingFunction(n);if(!o||167!==o.kind&&!uL(o))return!0;if(t.valueDeclaration){var s=e.isBinaryExpression(t.valueDeclaration),c=o.parent===t.valueDeclaration.parent,l=o===t.valueDeclaration.parent,u=s&&(null===(a=t.parent)||void 0===a?void 0:a.valueDeclaration)===o.parent,d=s&&(null===(i=t.parent)||void 0===i?void 0:i.valueDeclaration)===o,p=c||l||u||d;return!p}}return!0}if(e.isAccessExpression(n)){var f=e.skipParentheses(n.expression);if(78===f.kind){var m=Pr(f).resolvedSymbol;if(2097152&m.flags){var _=ca(m);return!!_&&264===_.kind}}}return!1}function hD(n,t,r){var a=e.skipOuterExpressions(n,7);return 78===a.kind||e.isAccessExpression(a)?!(32&a.flags)||(gr(n,r),!1):(gr(n,t),!1)}function vD(n){TA(n.expression);var t=e.skipParentheses(n.expression);if(!e.isAccessExpression(t))return gr(t,e.Diagnostics.The_operand_of_a_delete_operator_must_be_a_property_reference),Ke;e.isPropertyAccessExpression(t)&&e.isPrivateIdentifier(t.name)&&gr(t,e.Diagnostics.The_operand_of_a_delete_operator_cannot_be_a_private_identifier);var r=Pr(t),a=Li(r.resolvedSymbol);return a&&(gD(a)&&gr(t,e.Diagnostics.The_operand_of_a_delete_operator_cannot_be_a_read_only_property),bD(t,ws(a))),Ke}function bD(n,t){var r=131075;!z||t.flags&r||32768&Fy(t)||gr(n,e.Diagnostics.The_operand_of_a_delete_operator_must_be_optional)}function ED(e){return TA(e.expression),ar}function TD(e){return TA(e.expression),Re}function SD(n){if(t){if(!(32768&n.flags))if(e.isInTopLevelContext(n)){var r=e.getSourceFileOfNode(n);if(!WO(r)){var a=void 0;if(!e.isEffectiveExternalModule(r,C)){a||(a=e.getSpanOfTokenAtPosition(r,n.pos));var i=e.createFileDiagnostic(r,a.start,a.length,e.Diagnostics.await_expressions_are_only_allowed_at_the_top_level_of_a_file_when_that_file_is_a_module_but_this_file_has_no_imports_or_exports_Consider_adding_an_empty_export_to_make_this_file_a_module);nr.add(i)}if(G!==e.ModuleKind.ESNext&&G!==e.ModuleKind.System||F<4){a=e.getSpanOfTokenAtPosition(r,n.pos);i=e.createFileDiagnostic(r,a.start,a.length,e.Diagnostics.Top_level_await_expressions_are_only_allowed_when_the_module_option_is_set_to_esnext_or_system_and_the_target_option_is_set_to_es2017_or_higher);nr.add(i)}}}else{r=e.getSourceFileOfNode(n);if(!WO(r)){a=e.getSpanOfTokenAtPosition(r,n.pos),i=e.createFileDiagnostic(r,a.start,a.length,e.Diagnostics.await_expressions_are_only_allowed_within_async_functions_and_at_the_top_levels_of_modules);var o=e.getContainingFunction(n);if(o&&167!==o.kind&&0===(2&e.getFunctionFlags(o))){var s=e.createDiagnosticForNode(o,e.Diagnostics.Did_you_mean_to_mark_this_function_as_async);e.addRelatedInfo(i,s)}nr.add(i)}}TE(n)&&gr(n,e.Diagnostics.await_expressions_cannot_be_used_in_a_parameter_initializer)}var c=TA(n.expression),l=_C(c,n,e.Diagnostics.Type_of_await_operand_must_either_be_a_valid_promise_or_must_not_contain_a_callable_then_member);return l!==c||l===Ae||3&c.flags||yr(!1,e.createDiagnosticForNode(n,e.Diagnostics.await_has_no_effect_on_the_type_of_this_expression)),l}function xD(n){var t=TA(n.operand);if(t===qe)return qe;switch(n.operand.kind){case 8:switch(n.operator){case 40:return wm(Fm(-n.operand.text));case 39:return wm(Fm(+n.operand.text))}break;case 9:if(40===n.operator)return wm(Fm({negative:!0,base10Value:e.parsePseudoBigInt(n.operand.text)}))}switch(n.operator){case 39:case 40:case 54:return yS(t,n.operand),AD(t,12288)&&gr(n.operand,e.Diagnostics.The_0_operator_cannot_be_applied_to_type_symbol,e.tokenToString(n.operator)),39===n.operator?(AD(t,2112)&&gr(n.operand,e.Diagnostics.Operator_0_cannot_be_applied_to_type_1,e.tokenToString(n.operator),io(Ty(t))),Fe):DD(t);case 53:xI(n.operand);var r=12582912&xv(t);return 4194304===r?Be:8388608===r?Ve:Ke;case 45:case 46:var a=mD(n.operand,yS(t,n.operand),e.Diagnostics.An_arithmetic_operand_must_be_of_type_any_number_bigint_or_an_enum_type);return a&&hD(n.operand,e.Diagnostics.The_operand_of_an_increment_or_decrement_operator_must_be_a_variable_or_a_property_access,e.Diagnostics.The_operand_of_an_increment_or_decrement_operator_may_not_be_an_optional_property_access),DD(t)}return Ae}function LD(n){var t=TA(n.operand);if(t===qe)return qe;var r=mD(n.operand,yS(t,n.operand),e.Diagnostics.An_arithmetic_operand_must_be_of_type_any_number_bigint_or_an_enum_type);return r&&hD(n.operand,e.Diagnostics.The_operand_of_an_increment_or_decrement_operator_must_be_a_variable_or_a_property_access,e.Diagnostics.The_operand_of_an_increment_or_decrement_operator_may_not_be_an_optional_property_access),DD(t)}function DD(e){return AD(e,2112)?CD(e,3)||AD(e,296)?en:Ge:Fe}function AD(e,n){if(e.flags&n)return!0;if(3145728&e.flags)for(var t=e.types,r=0,a=t;r<a.length;r++){var i=a[r];if(AD(i,n))return!0}return!1}function CD(e,n,t){return!!(e.flags&n)||!(t&&114691&e.flags)&&(!!(296&n)&&W_(e,Fe)||!!(2112&n)&&W_(e,Ge)||!!(402653316&n)&&W_(e,Me)||!!(528&n)&&W_(e,Ke)||!!(16384&n)&&W_(e,We)||!!(131072&n)&&W_(e,ze)||!!(65536&n)&&W_(e,we)||!!(32768&n)&&W_(e,ke)||!!(4096&n)&&W_(e,He)||!!(67108864&n)&&W_(e,Qe))}function ID(n,t,r){return 1048576&n.flags?e.every(n.types,(function(e){return ID(e,t,r)})):CD(n,t,r)}function ND(n){return!!(16&e.getObjectFlags(n))&&!!n.symbol&&kD(n.symbol)}function kD(e){return 0!==(128&e.flags)}function RD(n,t,r,a){return r===qe||a===qe?qe:(!ko(r)&&ID(r,131068)&&gr(n,e.Diagnostics.The_left_hand_side_of_an_instanceof_expression_must_be_of_type_any_an_object_type_or_a_type_parameter),ko(a)||Zk(a)||H_(a,En)||gr(t,e.Diagnostics.The_right_hand_side_of_an_instanceof_expression_must_be_of_type_any_or_of_a_type_assignable_to_the_Function_interface_type),Ke)}function OD(n,t,r,a){if(r===qe||a===qe)return qe;r=yS(r,n),a=yS(a,t),ID(r,402665900)||CD(r,407109632)||gr(n,e.Diagnostics.The_left_hand_side_of_an_in_expression_must_be_of_type_any_string_number_or_symbol);var i=Fl(a);return(!ID(a,126091264)||i&&(CD(a,3145728)&&!ID(i,126091264)||!AD(i,126615552)))&&gr(t,e.Diagnostics.The_right_hand_side_of_an_in_expression_must_not_be_a_primitive),Ke}function wD(e,n,t){var r=e.properties;if(z&&0===r.length)return yS(n,e);for(var a=0;a<r.length;a++)PD(e,n,a,r,t);return n}function PD(n,t,r,a,i){void 0===i&&(i=!1);var o=n.properties,s=o[r];if(289===s.kind||290===s.kind){var c=s.name,l=Sf(c);if(Lc(l)){var u=kc(l),d=_u(t,u);d&&(qS(d,s,i),cS(s,!1,!0,t,d))}var p=im(t,l,void 0,c,void 0,void 0,16),f=Mo(s,p);return GD(290===s.kind?s:s.initializer,f)}if(291===s.kind){if(!(r<o.length-1)){F<99&&jR(s,4);var m=[];if(a)for(var _=0,g=a;_<g.length;_++){var y=g[_];e.isSpreadAssignment(y)||m.push(y.name)}f=Oo(t,m,t.symbol);return ZR(a,e.Diagnostics.A_rest_parameter_or_binding_pattern_may_not_have_a_trailing_comma),GD(s.expression,f)}gr(s,e.Diagnostics.A_rest_element_must_be_last_in_a_destructuring_pattern)}else gr(s,e.Diagnostics.Property_assignment_expected)}function MD(e,n,t){var r=e.elements;F<2&&C.downlevelIteration&&jR(e,512);for(var a=NI(193,n,ke,e)||Ae,i=C.noUncheckedIndexedAccess?void 0:a,o=0;o<r.length;o++){var s=a;221===e.elements[o].kind&&(s=i=null!==i&&void 0!==i?i:NI(65,n,ke,e)||Ae),FD(e,n,o,s,t)}return n}function FD(n,t,r,a,i){var o=n.elements,s=o[r];if(223!==s.kind){if(221!==s.kind){var c=Fm(r);if(dy(t)){var l=16|(mT(s)?8:0),u=sm(t,c,void 0,Cx(s,c),l)||Ae,d=mT(s)?Lv(u,524288):u,p=Mo(s,d);return GD(s,p,i)}return GD(s,a,i)}if(r<o.length-1)gr(s,e.Diagnostics.A_rest_element_must_be_last_in_a_destructuring_pattern);else{var f=s.expression;if(217!==f.kind||62!==f.operatorToken.kind){ZR(n.elements,e.Diagnostics.A_rest_parameter_or_binding_pattern_may_not_have_a_trailing_comma);p=$v(t,Cy)?rb(t,(function(e){return Pp(e,r)})):Ep(a);return GD(f,p,i)}gr(f.operatorToken,e.Diagnostics.A_rest_element_cannot_have_an_initializer)}}}function GD(e,n,t,r){var a;if(290===e.kind){var i=e;i.objectAssignmentInitializer&&(!z||32768&Fy(TA(i.objectAssignmentInitializer))||(n=Lv(n,524288)),HD(i.name,i.equalsToken,i.objectAssignmentInitializer,t)),a=e.name}else a=e;return 217===a.kind&&62===a.operatorToken.kind&&(ee(a,t),a=a.left),201===a.kind?wD(a,n,r):200===a.kind?MD(a,n,t):BD(a,n,t)}function BD(n,t,r){var a=TA(n,r),i=291===n.parent.kind?e.Diagnostics.The_target_of_an_object_rest_assignment_must_be_a_variable_or_a_property_access:e.Diagnostics.The_left_hand_side_of_an_assignment_expression_must_be_a_variable_or_a_property_access,o=291===n.parent.kind?e.Diagnostics.The_target_of_an_object_rest_assignment_may_not_be_an_optional_property_access:e.Diagnostics.The_left_hand_side_of_an_assignment_expression_may_not_be_an_optional_property_access;return hD(n,i,o)&&Y_(t,a,n,n),e.isPrivateIdentifierPropertyAccessExpression(n)&&jR(n.parent,1048576),t}function UD(n){switch(n=e.skipParentheses(n),n.kind){case 78:case 10:case 13:case 206:case 219:case 14:case 8:case 9:case 109:case 94:case 103:case 150:case 209:case 222:case 210:case 200:case 201:case 212:case 226:case 275:case 274:return!0;case 218:return UD(n.whenTrue)&&UD(n.whenFalse);case 217:return!e.isAssignmentOperator(n.operatorToken.kind)&&(UD(n.left)&&UD(n.right));case 215:case 216:switch(n.operator){case 53:case 39:case 40:case 54:return!0}return!1;case 213:case 207:case 225:default:return!1}}function VD(e,n){return 0!==(98304&n.flags)||q_(e,n)}function jD(){var n=e.createBinaryExpressionTrampoline(t,r,a,i,o,s);return function(t,r){var a=n(t,r);return e.Debug.assertIsDefined(a),a};function t(n,t,r){if(t?(t.stackIndex++,t.skip=!1,u(t,void 0),p(t,void 0)):t={checkMode:r,skip:!1,stackIndex:0,typeStack:[void 0,void 0]},e.isInJSFile(n)&&e.getAssignedExpandoInitializer(n))return t.skip=!0,p(t,TA(n.right,r)),t;KD(n);var a=n.operatorToken.kind;return 62!==a||201!==n.left.kind&&200!==n.left.kind||(t.skip=!0,p(t,GD(n.left,TA(n.right,r),r,107===n.right.kind))),t}function r(e,n,t){if(!n.skip)return c(n,e)}function a(n,t,r){if(!t.skip){var a=d(t);e.Debug.assertIsDefined(a),u(t,a),p(t,void 0);var i=n.kind;if(55===i||56===i||60===i){if(55===i){var o=e.walkUpParenthesizedExpressions(r.parent);hI(r.left,a,e.isIfStatement(o)?o.thenStatement:void 0)}SI(a,r.left)}}}function i(e,n,t){if(!n.skip)return c(n,e)}function o(n,t){var r;if(t.skip)r=d(t);else{var a=l(t);e.Debug.assertIsDefined(a);var i=d(t);e.Debug.assertIsDefined(i),r=WD(n.left,n.operatorToken,n.right,a,i,n)}return t.skip=!1,u(t,void 0),p(t,void 0),t.stackIndex--,r}function s(e,n,t){return p(e,n),e}function c(n,t){if(e.isBinaryExpression(t))return t;p(n,TA(t,n.checkMode))}function l(e){return e.typeStack[e.stackIndex]}function u(e,n){e.typeStack[e.stackIndex]=n}function d(e){return e.typeStack[e.stackIndex+1]}function p(e,n){e.typeStack[e.stackIndex+1]=n}}function KD(n){var t=n.left,r=n.operatorToken,a=n.right;60===r.kind&&(!e.isBinaryExpression(t)||56!==t.operatorToken.kind&&55!==t.operatorToken.kind||XO(t,e.Diagnostics._0_and_1_operations_cannot_be_mixed_without_parentheses,e.tokenToString(t.operatorToken.kind),e.tokenToString(r.kind)),!e.isBinaryExpression(a)||56!==a.operatorToken.kind&&55!==a.operatorToken.kind||XO(a,e.Diagnostics._0_and_1_operations_cannot_be_mixed_without_parentheses,e.tokenToString(a.operatorToken.kind),e.tokenToString(r.kind)))}function HD(e,n,t,r,a){var i,o=n.kind;if(62===o&&(201===e.kind||200===e.kind))return GD(e,TA(t,r),r,107===t.kind);i=55===o||56===o||60===o?xI(e,r):TA(e,r);var s=TA(t,r);return WD(e,n,t,i,s,a)}function WD(n,r,a,i,o,s){var c=r.kind;switch(c){case 41:case 42:case 65:case 66:case 43:case 67:case 44:case 68:case 40:case 64:case 47:case 69:case 48:case 70:case 49:case 71:case 51:case 73:case 52:case 77:case 50:case 72:if(i===qe||o===qe)return qe;i=yS(i,n),o=yS(o,a);var l=void 0;if(528&i.flags&&528&o.flags&&void 0!==(l=A(r.kind)))return gr(s||r,e.Diagnostics.The_0_operator_is_not_allowed_for_boolean_types_Consider_using_1_instead,e.tokenToString(r.kind),e.tokenToString(l)),Fe;var u,d=mD(n,i,e.Diagnostics.The_left_hand_side_of_an_arithmetic_operation_must_be_of_type_any_number_bigint_or_an_enum_type,!0),p=mD(a,o,e.Diagnostics.The_right_hand_side_of_an_arithmetic_operation_must_be_of_type_any_number_bigint_or_an_enum_type,!0);if(CD(i,3)&&CD(o,3)||!AD(i,2112)&&!AD(o,2112))u=Fe;else if(S(i,o)){switch(c){case 49:case 71:R();break;case 42:case 66:F<3&&gr(s,e.Diagnostics.Exponentiation_cannot_be_performed_on_bigint_values_unless_the_target_option_is_set_to_es2016_or_later)}u=Ge}else R(S),u=Ae;return d&&p&&I(u),u;case 39:case 63:if(i===qe||o===qe)return qe;CD(i,402653316)||CD(o,402653316)||(i=yS(i,n),o=yS(o,a));var f=void 0;if(CD(i,296,!0)&&CD(o,296,!0)?f=Fe:CD(i,2112,!0)&&CD(o,2112,!0)?f=Ge:CD(i,402653316,!0)||CD(o,402653316,!0)?f=Me:(ko(i)||ko(o))&&(f=i===Ae||o===Ae?Ae:xe),f&&!D(c))return f;if(!f){var m=402655727;return R((function(e,n){return CD(e,m)&&CD(n,m)})),xe}return 63===c&&I(f),f;case 29:case 31:case 32:case 33:return D(c)&&(i=Ty(yS(i,n)),o=Ty(yS(o,a)),k((function(e,n){return q_(e,n)||q_(n,e)||W_(e,en)&&W_(n,en)}))),Ke;case 34:case 35:case 36:case 37:return k((function(e,n){return VD(e,n)||VD(n,e)})),Ke;case 101:return RD(n,a,i,o);case 100:return OD(n,a,i,o);case 55:case 75:var _=4194304&xv(i)?Qp([By(z?i:Ty(o)),o]):i;return 75===c&&I(o),_;case 56:case 74:var g=8388608&xv(i)?Qp([Gy(i),o],2):i;return 74===c&&I(o),g;case 60:case 76:var y=262144&xv(i)?Qp([Hy(i),o],2):i;return 76===c&&I(o),y;case 62:var h=e.isBinaryExpression(n.parent)?e.getAssignmentDeclarationKind(n.parent):0;return x(h,o),N(h)?(524288&o.flags&&(2===h||6===h||bg(o)||Sv(o)||1&e.getObjectFlags(o))||I(o),i):(I(o),eh(o));case 27:if(!C.allowUnreachableCode&&UD(n)&&!L(a)){var v=e.getSourceFileOfNode(n),b=v.text,E=e.skipTrivia(b,n.pos),T=v.parseDiagnostics.some((function(n){return n.code===e.Diagnostics.JSX_expressions_must_have_one_parent_element.code&&e.textSpanContainsPosition(n,E)}));T||gr(n,e.Diagnostics.Left_side_of_comma_operator_is_unused_and_has_no_side_effects)}return o;default:return e.Debug.fail()}function S(e,n){return CD(e,2112)&&CD(n,2112)}function x(n,t){if(2===n)for(var r=0,a=kl(t);r<a.length;r++){var i=a[r],o=ws(i);if(o.symbol&&32&o.symbol.flags){var s=i.escapedName,c=Vr(i.valueDeclaration,s,788968,void 0,s,!1);(null===c||void 0===c?void 0:c.declarations)&&c.declarations.some(e.isJSDocTypedefTag)&&(Cr(c,e.Diagnostics.Duplicate_identifier_0,e.unescapeLeadingUnderscores(s),i),Cr(i,e.Diagnostics.Duplicate_identifier_0,e.unescapeLeadingUnderscores(s),c))}}}function L(e){return 78===e.kind&&"eval"===e.escapedText}function D(t){var r=AD(i,12288)?n:AD(o,12288)?a:void 0;return!r||(gr(r,e.Diagnostics.The_0_operator_cannot_be_applied_to_type_symbol,e.tokenToString(t)),!1)}function A(e){switch(e){case 51:case 73:return 56;case 52:case 77:return 37;case 50:case 72:return 55;default:return}}function I(r){t&&e.isAssignmentOperator(c)&&(!hD(n,e.Diagnostics.The_left_hand_side_of_an_assignment_expression_must_be_a_variable_or_a_property_access,e.Diagnostics.The_left_hand_side_of_an_assignment_expression_may_not_be_an_optional_property_access)||e.isIdentifier(n)&&"exports"===e.unescapeLeadingUnderscores(n.escapedText)||Y_(r,i,n,a))}function N(t){var r;switch(t){case 2:return!0;case 1:case 5:case 6:case 3:case 4:var i=yi(n),o=e.getAssignedExpandoInitializer(a);return!!o&&e.isObjectLiteralExpression(o)&&!!(null===(r=null===i||void 0===i?void 0:i.exports)||void 0===r?void 0:r.size);default:return!1}}function k(e){return!e(i,o)&&(R(e),!0)}function R(n){var t,a=!1,c=s||r;if(n){var l=yC(i),u=yC(o);a=!(l===i&&u===o)&&!(!l||!u)&&n(l,u)}var d=i,p=o;!a&&n&&(t=zD(i,o,n),d=t[0],p=t[1]);var f=oo(d,p),m=f[0],_=f[1];O(c,a,m,_)||vr(c,a,e.Diagnostics.Operator_0_cannot_be_applied_to_types_1_and_2,e.tokenToString(r.kind),m,_)}function O(n,t,a,i){var o;switch(r.kind){case 36:case 34:o="false";break;case 37:case 35:o="true"}if(o)return vr(n,t,e.Diagnostics.This_condition_will_always_return_0_since_the_types_1_and_2_have_no_overlap,o,a,i)}}function zD(e,n,t){var r=e,a=n,i=Ty(e),o=Ty(n);return t(i,o)||(r=i,a=o),[r,a]}function qD(n){t&&(8192&n.flags||zO(n,e.Diagnostics.A_yield_expression_is_only_allowed_in_a_generator_body),TE(n)&&gr(n,e.Diagnostics.yield_expressions_cannot_be_used_in_a_parameter_initializer));var r=e.getContainingFunction(n);if(!r)return xe;var a=e.getFunctionFlags(r);if(!(1&a))return xe;var i=0!==(2&a);n.asteriskToken&&(i&&F<99&&jR(n,26624),!i&&F<2&&C.downlevelIteration&&jR(n,256));var o=Wu(r),s=o&&rN(o,i),c=s&&s.yieldType||xe,l=s&&s.nextType||xe,u=i?yC(l)||xe:l,d=n.expression?TA(n.expression):Re,p=rD(n,d,u,i);if(o&&p&&Y_(p,c,n.expression||n,n.expression),n.asteriskToken){var f=i?19:17;return OI(f,1,d,n.expression)||xe}if(o)return tN(2,o,i)||xe;var m=SE(2,r);if(!m&&(m=xe,t&&Y&&!e.expressionResultIsUnused(n))){var _=JE(n);_&&!ko(_)||gr(n,e.Diagnostics.yield_expression_implicitly_results_in_an_any_type_because_its_containing_generator_lacks_a_return_type_annotation)}return m}function JD(e,n){var t=xI(e.condition);hI(e.condition,t,e.whenTrue);var r=TA(e.whenTrue,n),a=TA(e.whenFalse,n);return Qp([r,a],2)}function XD(n){for(var t=[n.head.text],r=[],a=0,i=n.templateSpans;a<i.length;a++){var o=i[a],s=TA(o.expression);AD(s,12288)&&gr(o.expression,e.Diagnostics.Implicit_conversion_of_a_symbol_to_a_string_will_fail_at_runtime_Consider_wrapping_this_expression_in_String),t.push(o.literal.text),r.push(W_(s,nn)?s:Me)}return iA(n)||Zv(JE(n)||Ne,YD)?Of(t,r):Me}function YD(e){return!!(134217856&e.flags||58982400&e.flags&&AD(ql(e)||Ne,402653316))}function QD(n){return 282!==n.kind||e.isJsxSelfClosingElement(n.parent)?n:n.parent.parent}function ZD(e,n,t,r){var a=QD(e),i=a.contextualType,o=a.inferenceContext;try{a.contextualType=n,a.inferenceContext=t;var s=TA(e,1|r|(t?2:0)),c=AD(s,2944)&&aA(s,zE(n,e))?Pm(s):s;return c}finally{a.contextualType=i,a.inferenceContext=o}}function $D(e,n){var t=Pr(e);if(!t.resolvedType){if(n&&0!==n)return TA(e,n);var r=At,a=ot;At=Ct,ot=void 0,t.resolvedType=TA(e,n),ot=a,At=r}return t.resolvedType}function eA(n){return n=e.skipParentheses(n),207===n.kind||225===n.kind}function nA(n,t){var r=e.getEffectiveInitializer(n),a=bA(r)||(t?ZD(r,t,void 0,0):$D(r));return e.isParameter(n)&&198===n.name.kind&&Cy(a)&&!a.target.hasRestElement&&Sd(a)<n.name.elements.length?tA(a,n.name):a}function tA(n,t){for(var r=t.elements,a=Td(n).slice(),i=n.target.elementFlags.slice(),o=Sd(n);o<r.length;o++){var s=r[o];(o<r.length-1||199!==s.kind||!s.dotDotDotToken)&&(a.push(!e.isOmittedExpression(s)&&mT(s)?os(s,!1,!1):xe),i.push(2),e.isOmittedExpression(s)||mT(s)||uh(s,xe))}return Np(a,i,n.target.readonly)}function rA(n,t){var r=2&e.getCombinedNodeFlags(n)||e.isDeclarationReadonly(n)?t:Sy(t);if(e.isInJSFile(n)){if(98304&r.flags)return uh(n,xe),xe;if(fy(r))return uh(n,kn),kn}return r}function aA(n,t){if(t){if(3145728&t.flags){var r=t.types;return e.some(r,(function(e){return aA(n,e)}))}if(58982400&t.flags){var a=ql(t)||Ne;return AD(a,4)&&AD(n,128)||AD(a,8)&&AD(n,256)||AD(a,64)&&AD(n,2048)||AD(a,4096)&&AD(n,8192)||aA(n,a)}return!!(406847616&t.flags&&AD(n,128)||256&t.flags&&AD(n,256)||2048&t.flags&&AD(n,2048)||512&t.flags&&AD(n,512)||8192&t.flags&&AD(n,8192))}return!1}function iA(n){var t=n.parent;return e.isAssertionExpression(t)&&e.isConstTypeReference(t.type)||(e.isParenthesizedExpression(t)||e.isArrayLiteralExpression(t)||e.isSpreadElement(t))&&iA(t)||(e.isPropertyAssignment(t)||e.isShorthandPropertyAssignment(t)||e.isTemplateSpan(t))&&iA(t.parent)}function oA(e,n,t,r){var a=TA(e,n,r);return iA(e)?Pm(a):eA(e)?a:Ly(a,zE(2===arguments.length?JE(e):t,e))}function sA(e,n){return 159===e.name.kind&&ET(e.name),oA(e.initializer,n)}function cA(e,n){kO(e),159===e.name.kind&&ET(e.name);var t=dD(e,n);return lA(e,t,n)}function lA(n,t,r){if(r&&10&r){var a=gx(t,0,!0),i=gx(t,1,!0),o=a||i;if(o&&o.typeParameters){var s=WE(n,2);if(s){var c=gx(Hy(s),a?0:1,!1);if(c&&!c.typeParameters){if(8&r)return uA(n,r),un;var l=XE(n),u=l.signature&&Hu(l.signature),d=u&&_x(u);if(d&&!d.typeParameters&&!e.every(l.inferences,dA)){var p=mA(l,o.typeParameters),f=Yu(o,p),m=e.map(l.inferences,(function(e){return vh(e.typeParameter)}));if(ph(f,c,(function(e,n){Hh(m,e,n,0,!0)})),e.some(m,dA)&&(fh(f,c,(function(e,n){Hh(m,e,n)})),!pA(l.inferences,m)))return fA(l.inferences,m),l.inferredTypeParameters=e.concatenate(l.inferredTypeParameters,p),ad(f)}return ad(yx(o,c,l))}}}}return t}function uA(e,n){if(2&n){var t=XE(e);t.flags|=4}}function dA(e){return!(!e.candidates&&!e.contraCandidates)}function pA(e,n){for(var t=0;t<e.length;t++)if(dA(e[t])&&dA(n[t]))return!0;return!1}function fA(e,n){for(var t=0;t<e.length;t++)!dA(e[t])&&dA(n[t])&&(e[t]=n[t])}function mA(n,t){for(var r,a,i=[],o=0,s=t;o<s.length;o++){var c=s[o],l=c.symbol.escapedName;if(_A(n.inferredTypeParameters,l)||_A(i,l)){var u=gA(e.concatenate(n.inferredTypeParameters,i),l),d=Sr(262144,u),p=wi(d);p.target=c,r=e.append(r,c),a=e.append(a,p),i.push(p)}else i.push(c)}if(a)for(var f=Qm(r,a),m=0,_=a;m<_.length;m++){c=_[m];c.mapper=f}return i}function _A(n,t){return e.some(n,(function(e){return e.symbol.escapedName===t}))}function gA(e,n){var t=n.length;while(t>1&&n.charCodeAt(t-1)>=48&&n.charCodeAt(t-1)<=57)t--;for(var r=n.slice(0,t),a=1;1;a++){var i=r+a;if(!_A(e,i))return i}}function yA(e){var n=mx(e);if(n&&!n.typeParameters)return Hu(n)}function hA(e){var n=TA(e.expression),t=Xy(n,e.expression),r=yA(n);return r&&Jy(r,e,t!==n)}function vA(n){var t=bA(n);if(t)return t;if(67108864&n.flags&&ot){var r=ot[w(n)];if(r)return r}var a=kt,i=TA(n);if(kt!==a){var o=ot||(ot=[]);o[w(n)]=i,e.setNodeFlags(n,67108864|n.flags)}return i}function bA(n){var t=e.skipParentheses(n);if(!e.isCallExpression(t)||105===t.expression.kind||e.isRequireCall(t,!0)||hL(t)){if(e.isAssertionExpression(t)&&!e.isConstTypeReference(t.type))return zm(t.type);if(8===n.kind||10===n.kind||109===n.kind||94===n.kind)return TA(n)}else{var r=e.isCallChain(t)?hA(t):yA(dS(t.expression));if(r)return r}}function EA(e){var n=Pr(e);if(n.contextFreeType)return n.contextFreeType;var t=e.contextualType;e.contextualType=xe;try{var r=n.contextFreeType=TA(e,4);return r}finally{e.contextualType=t}}function TA(n,t,r){null===e.tracing||void 0===e.tracing||e.tracing.push("check","checkExpression",{kind:n.kind,pos:n.pos,end:n.end});var a=d;d=n,T=0;var i=LA(n,t,r),o=lA(n,i,t);return ND(o)&&SA(n,o),d=a,null===e.tracing||void 0===e.tracing||e.tracing.pop(),o}function SA(n,t){var r=202===n.parent.kind&&n.parent.expression===n||203===n.parent.kind&&n.parent.expression===n||(78===n.kind||158===n.kind)&&Gk(n)||177===n.parent.kind&&n.parent.exprName===n||271===n.parent.kind;if(r||gr(n,e.Diagnostics.const_enums_can_only_be_used_in_property_or_index_access_expressions_or_the_right_hand_side_of_an_import_declaration_or_export_assignment_or_type_query),C.isolatedModules){e.Debug.assert(!!(128&t.symbol.flags));var a=t.symbol.valueDeclaration;8388608&a.flags&&gr(n,e.Diagnostics.Cannot_access_ambient_const_enums_when_the_isolatedModules_flag_is_provided)}}function xA(n,t){var r=e.isInJSFile(n)?e.getJSDocTypeTag(n):void 0;return r?LL(r,r.typeExpression.type,n.expression,t):TA(n.expression,t)}function LA(n,t,a){var i=n.kind;if(r)switch(i){case 222:case 209:case 210:r.throwIfCancellationRequested()}switch(i){case 78:return zb(n,t);case 107:return rE(n);case 105:return lE(n);case 103:return Pe;case 14:case 10:return wm(Fm(n.text));case 8:return rw(n),wm(Fm(+n.text));case 9:return iw(n),wm(xf(n));case 109:return Ve;case 94:return Be;case 219:return XD(n);case 13:return In;case 200:return _T(n,t,a);case 201:return LT(n,t);case 202:return vS(n,t);case 158:return ES(n,t);case 203:return nx(n,t);case 204:if(99===n.expression.kind)return vL(n);case 205:return _L(n,t);case 206:return TL(n);case 208:return xA(n,t);case 222:return bN(n);case 209:case 210:return dD(n,t);case 212:return ED(n);case 207:case 225:return SL(n);case 226:return AL(n);case 227:return CL(n);case 211:return vD(n);case 213:return TD(n);case 214:return SD(n);case 215:return xD(n);case 216:return LD(n);case 217:return ee(n,t);case 218:return JD(n,t);case 221:return pT(n,t);case 223:return Re;case 220:return qD(n);case 228:return fT(n);case 284:return iS(n,t);case 274:return NT(n,t);case 275:return CT(n,t);case 278:return kT(n);case 282:return GT(n,t);case 276:e.Debug.fail("Shouldn't ever directly check a JsxOpeningElement")}return Ae}function DA(n){n.expression&&zO(n.expression,e.Diagnostics.Type_expected),pk(n.constraint),pk(n.default);var r=pc(yi(n));ql(r),eu(r)||gr(n.default,e.Diagnostics.Type_parameter_0_has_a_circular_default,io(r));var a=Gl(r),i=$l(r);a&&i&&X_(i,Fc(A_(a,$m(r,i)),i),n.default,e.Diagnostics.Type_0_does_not_satisfy_the_constraint_1),t&&mN(n.name,e.Diagnostics.Type_parameter_name_cannot_be_0)}function AA(n){WR(n),uI(n);var t=e.getContainingFunction(n);e.hasSyntacticModifier(n,16476)&&(167===t.kind&&e.nodeIsPresent(t.body)||gr(n,e.Diagnostics.A_parameter_property_is_only_allowed_in_a_constructor_implementation),167===t.kind&&e.isIdentifier(n.name)&&"constructor"===n.name.escapedText&&gr(n.name,e.Diagnostics.constructor_cannot_be_used_as_a_parameter_property_name)),n.questionToken&&e.isBindingPattern(n.name)&&t.body&&gr(n,e.Diagnostics.A_binding_pattern_parameter_cannot_be_optional_in_an_implementation_signature),n.name&&e.isIdentifier(n.name)&&("this"===n.name.escapedText||"new"===n.name.escapedText)&&(0!==t.parameters.indexOf(n)&&gr(n,e.Diagnostics.A_0_parameter_must_be_the_first_parameter,n.name.escapedText),167!==t.kind&&171!==t.kind&&176!==t.kind||gr(n,e.Diagnostics.A_constructor_cannot_have_a_this_parameter),210===t.kind&&gr(n,e.Diagnostics.An_arrow_function_cannot_have_a_this_parameter),168!==t.kind&&169!==t.kind||gr(n,e.Diagnostics.get_and_set_accessors_cannot_declare_this_parameters)),!n.dotDotDotToken||e.isBindingPattern(n.name)||W_(lu(ws(n.symbol)),On)||gr(n,e.Diagnostics.A_rest_parameter_must_be_of_an_array_type)}function CA(n){var t=IA(n);if(t){var r=Ou(t),a=Vu(r);if(a){pk(n.type);var i=n.parameterName;if(0===a.kind||2===a.kind)jm(i);else if(a.parameterIndex>=0){if(j(r)&&a.parameterIndex===r.parameters.length-1)gr(i,e.Diagnostics.A_type_predicate_cannot_reference_a_rest_parameter);else if(a.type){var o=function(){return e.chainDiagnosticMessages(void 0,e.Diagnostics.A_type_predicate_s_type_must_be_assignable_to_its_parameter_s_type)};X_(a.type,ws(r.parameters[a.parameterIndex]),n.type,void 0,o)}}else if(i){for(var s=!1,c=0,l=t.parameters;c<l.length;c++){var u=l[c].name;if(e.isBindingPattern(u)&&NA(u,i,a.parameterName)){s=!0;break}}s||gr(n.parameterName,e.Diagnostics.Cannot_find_parameter_0,a.parameterName)}}}else gr(n,e.Diagnostics.A_type_predicate_is_only_allowed_in_return_type_position_for_functions_and_methods)}function IA(e){switch(e.parent.kind){case 210:case 170:case 252:case 209:case 175:case 166:case 165:var n=e.parent;if(e===n.type)return n}}function NA(n,t,r){for(var a=0,i=n.elements;a<i.length;a++){var o=i[a];if(!e.isOmittedExpression(o)){var s=o.name;if(78===s.kind&&s.escapedText===r)return gr(t,e.Diagnostics.A_type_predicate_cannot_reference_element_0_in_a_binding_pattern,r),!0;if((198===s.kind||197===s.kind)&&NA(s,t,r))return!0}}}function kA(n){172===n.kind?sO(n):175!==n.kind&&252!==n.kind&&176!==n.kind&&170!==n.kind&&167!==n.kind&&171!==n.kind||rO(n);var r=e.getFunctionFlags(n);if(4&r||(3===(3&r)&&F<99&&jR(n,6144),2===(3&r)&&F<4&&jR(n,64),0!==(3&r)&&F<2&&jR(n,128)),gN(n.typeParameters),e.forEach(n.parameters,AA),n.type&&pk(n.type),t){nI(n);var a=e.getEffectiveReturnTypeNode(n);if(Y&&!a)switch(n.kind){case 171:gr(n,e.Diagnostics.Construct_signature_which_lacks_return_type_annotation_implicitly_has_an_any_return_type);break;case 170:gr(n,e.Diagnostics.Call_signature_which_lacks_return_type_annotation_implicitly_has_an_any_return_type);break}if(a){var i=e.getFunctionFlags(n);if(1===(5&i)){var o=zm(a);if(o===We)gr(a,e.Diagnostics.A_generator_cannot_have_a_void_type_annotation);else{var s=tN(0,o,0!==(2&i))||xe,c=tN(1,o,0!==(2&i))||s,l=tN(2,o,0!==(2&i))||Ne,u=nD(s,c,l,!!(2&i));X_(u,o,a)}}else 2===(3&i)&&vC(n,a)}172!==n.kind&&309!==n.kind&&BC(n)}}function RA(n){for(var t=new e.Map,r=new e.Map,a=new e.Map,i=0,o=n.members;i<o.length;i++){var s=o[i];if(167===s.kind)for(var c=0,l=s.parameters;c<l.length;c++){var u=l[c];e.isParameterPropertyDeclaration(u,s)&&!e.isBindingPattern(u.name)&&y(t,u.name,u.name.escapedText,3)}else{var d=e.hasSyntacticModifier(s,32),p=s.name;if(!p)continue;var f=e.isPrivateIdentifier(p),m=f&&d?16:0,_=f?a:d?r:t,g=p&&e.getPropertyNameForPropertyNameNode(p);if(g)switch(s.kind){case 168:y(_,p,g,1|m);break;case 169:y(_,p,g,2|m);break;case 164:y(_,p,g,3|m);break;case 166:y(_,p,g,8|m);break}}}function y(n,t,r,a){var i=n.get(r);if(i)if((16&i)!==(16&a))gr(t,e.Diagnostics.Duplicate_identifier_0_Static_and_instance_elements_cannot_share_the_same_private_name,e.getTextOfNode(t));else{var o=!!(8&i),s=!!(8&a);o||s?o!==s&&gr(t,e.Diagnostics.Duplicate_identifier_0,e.getTextOfNode(t)):i&a&-17?gr(t,e.Diagnostics.Duplicate_identifier_0,e.getTextOfNode(t)):n.set(r,i|a)}else n.set(r,a)}}function OA(n){for(var t=0,r=n.members;t<r.length;t++){var a=r[t],i=a.name,o=e.hasSyntacticModifier(a,32);if(o&&i){var s=e.getPropertyNameForPropertyNameNode(i);switch(s){case"name":case"length":case"caller":case"arguments":case"prototype":var c=e.Diagnostics.Static_property_0_conflicts_with_built_in_property_Function_0_of_constructor_function_1,l=bo(yi(n));gr(i,c,s,l);break}}}}function wA(n){for(var t=new e.Map,r=0,a=n.members;r<a.length;r++){var i=a[r];if(163===i.kind){var o=void 0,s=i.name;switch(s.kind){case 10:case 8:o=s.text;break;case 78:o=e.idText(s);break;default:continue}t.get(o)?(gr(e.getNameOfDeclaration(i.symbol.valueDeclaration),e.Diagnostics.Duplicate_identifier_0,o),gr(i.name,e.Diagnostics.Duplicate_identifier_0,o)):t.set(o,!0)}}}function PA(n){if(254===n.kind){var t=yi(n);if(t.declarations&&t.declarations.length>0&&t.declarations[0]!==n)return}var r=id(yi(n));if(null===r||void 0===r?void 0:r.declarations)for(var a=!1,i=!1,o=0,s=r.declarations;o<s.length;o++){var c=s[o],l=c;if(1===l.parameters.length&&l.parameters[0].type)switch(l.parameters[0].type.kind){case 147:i?gr(l,e.Diagnostics.Duplicate_string_index_signature):i=!0;break;case 144:a?gr(l,e.Diagnostics.Duplicate_number_index_signature):a=!0;break}}}function MA(n){WR(n)||ZO(n)||yO(n.name),uI(n),BA(n),e.isPrivateIdentifier(n.name)&&e.hasStaticModifier(n)&&n.initializer&&99===F&&!C.useDefineForClassFields&&gr(n.initializer,e.Diagnostics.Static_fields_with_private_names_can_t_have_initializers_when_the_useDefineForClassFields_flag_is_not_specified_with_a_target_of_esnext_Consider_adding_the_useDefineForClassFields_flag)}function FA(n){return e.isPrivateIdentifier(n.name)&&gr(n,e.Diagnostics.Private_identifiers_are_not_allowed_outside_class_bodies),MA(n)}function GA(n){kO(n)||yO(n.name),GC(n),e.hasSyntacticModifier(n,128)&&166===n.kind&&n.body&&gr(n,e.Diagnostics.Method_0_cannot_have_an_implementation_because_it_is_marked_abstract,e.declarationNameToString(n.name)),e.isPrivateIdentifier(n.name)&&!e.getContainingClass(n)&&gr(n,e.Diagnostics.Private_identifiers_are_not_allowed_outside_class_bodies),BA(n)}function BA(n){if(e.isPrivateIdentifier(n.name)&&F<99){for(var t=e.getEnclosingBlockScopeContainer(n);t;t=e.getEnclosingBlockScopeContainer(t))Pr(t).flags|=67108864;if(e.isClassExpression(n.parent)){var r=Xb(n.parent);r&&(Pr(n.name).flags|=524288,Pr(r).flags|=65536)}}}function UA(n){kA(n),YO(n)||QO(n),pk(n.body);var r=yi(n),a=e.getDeclarationOfKind(r,n.kind);if(n===a&&dC(r),!e.nodeIsMissing(n.body)&&t){var i=n.parent;if(e.getClassExtendsHeritageElement(i)){$b(n.parent,i);var o=nE(i),s=eE(n.body);if(s){o&&gr(s,e.Diagnostics.A_constructor_cannot_contain_a_super_call_when_its_class_extends_null);var c=(99!==C.target||!H)&&(e.some(n.parent.members,m)||e.some(n.parameters,(function(n){return e.hasSyntacticModifier(n,16476)})));if(c){for(var l=n.body.statements,u=void 0,d=0,p=l;d<p.length;d++){var f=p[d];if(234===f.kind&&e.isSuperCall(f.expression)){u=f;break}if(!e.isPrologueDirective(f))break}u||gr(n,e.Diagnostics.A_super_call_must_be_the_first_statement_in_the_constructor_when_a_class_contains_initialized_properties_parameter_properties_or_private_identifiers)}}else o||gr(n,e.Diagnostics.Constructors_for_derived_classes_must_contain_a_super_call)}}function m(n){return!!e.isPrivateIdentifierClassElementDeclaration(n)||164===n.kind&&!e.hasSyntacticModifier(n,32)&&!!n.initializer}}function VA(n){if(t){if(rO(n)||DO(n)||yO(n.name),AC(n),kA(n),168===n.kind&&!(8388608&n.flags)&&e.nodeIsPresent(n.body)&&256&n.flags&&(512&n.flags||gr(n.name,e.Diagnostics.A_get_accessor_must_return_a_value)),159===n.name.kind&&ET(n.name),Ic(n)){var r=yi(n),a=e.getDeclarationOfKind(r,168),i=e.getDeclarationOfKind(r,169);if(a&&i&&!(1&TR(a))){Pr(a).flags|=1;var o=e.getEffectiveModifierFlags(a),s=e.getEffectiveModifierFlags(i);(128&o)!==(128&s)&&(gr(a.name,e.Diagnostics.Accessors_must_both_be_abstract_or_non_abstract),gr(i.name,e.Diagnostics.Accessors_must_both_be_abstract_or_non_abstract)),(16&o&&!(24&s)||8&o&&!(8&s))&&(gr(a.name,e.Diagnostics.A_get_accessor_must_be_at_least_as_accessible_as_the_setter),gr(i.name,e.Diagnostics.A_get_accessor_must_be_at_least_as_accessible_as_the_setter));var c=hs(a),l=hs(i);c&&l&&X_(c,l,a,e.Diagnostics.The_return_type_of_a_get_accessor_must_be_assignable_to_its_set_accessor_type)}}var u=Es(yi(n));168===n.kind&&uD(n,u)}pk(n.body),BA(n)}function jA(e){AC(e)}function KA(n,t){return Ru(e.map(n.typeArguments,zm),t,ku(t),e.isInJSFile(n))}function HA(n,t){for(var r,a,i=!0,o=0;o<t.length;o++){var s=Gl(t[o]);s&&(r||(r=KA(n,t),a=Qm(t,r)),i=i&&X_(r[o],A_(s,a),n.typeArguments[o],e.Diagnostics.Type_0_does_not_satisfy_the_constraint_1))}return i}function WA(n){var t=Ud(n);if(t!==Ae){var r=Pr(n).resolvedSymbol;if(r)return 524288&r.flags&&wr(r).typeParameters||(4&e.getObjectFlags(t)?t.target.localTypeParameters:void 0)}}function zA(n){lO(n,n.typeArguments),174!==n.kind||void 0===n.typeName.jsdocDotPos||e.isInJSFile(n)||e.isInJSDoc(n)||qO(n,n.typeName.jsdocDotPos,1,e.Diagnostics.JSDoc_types_can_only_be_used_inside_documentation_comments),e.forEach(n.typeArguments,pk);var r=Ud(n);if(r!==Ae){if(n.typeArguments&&t){var a=WA(n);a&&HA(n,a)}var i=Pr(n).resolvedSymbol;i&&(e.some(i.declarations,(function(e){return Nk(e)&&!!(134217728&e.flags)}))&&Er(yL(n),i.declarations,i.escapedName),32&r.flags&&8&i.flags&&gr(n,e.Diagnostics.Enum_type_0_has_members_with_initializers_that_are_not_literals,io(r)))}}function qA(n){var t=e.tryCast(n.parent,e.isTypeReferenceType);if(t){var r=WA(t),a=Gl(r[t.typeArguments.indexOf(n)]);return a&&A_(a,Qm(r,KA(t,r)))}}function JA(e){jd(e)}function XA(n){if(e.forEach(n.members,pk),t){var r=Sm(n);fN(r),PA(n),wA(n)}}function YA(e){pk(e.elementType)}function QA(n){for(var t=n.elements,r=!1,a=!1,i=e.some(t,e.isNamedTupleMember),o=0,s=t;o<s.length;o++){var c=s[o];if(193!==c.kind&&i){XO(c,e.Diagnostics.Tuple_members_must_all_have_names_or_all_not_have_names);break}var l=Tp(c);if(8&l){var u=zm(c.type);if(!dy(u)){gr(c,e.Diagnostics.A_rest_element_type_must_be_an_array_type);break}(sy(u)||Cy(u)&&4&u.target.combinedFlags)&&(a=!0)}else if(4&l){if(a){XO(c,e.Diagnostics.A_rest_element_cannot_follow_another_rest_element);break}a=!0}else if(2&l){if(a){XO(c,e.Diagnostics.An_optional_element_cannot_follow_a_rest_element);break}r=!0}else if(r){XO(c,e.Diagnostics.A_required_element_cannot_follow_an_optional_element);break}}e.forEach(n.elements,pk),zm(n)}function ZA(n){e.forEach(n.types,pk),zm(n)}function $A(n,t){if(!(8388608&n.flags))return n;var r=n.objectType,a=n.indexType;if(W_(a,Cf(r,!1)))return 203===t.kind&&e.isAssignmentTarget(t)&&32&e.getObjectFlags(r)&&1&Ll(r)&&gr(t,e.Diagnostics.Index_signature_in_type_0_only_permits_reading,io(r)),n;var i=au(r);if(bu(i,1)&&CD(a,296))return n;if(Jf(r)){var o=jf(a,t);if(o){var s=Qv(i,(function(e){return _u(e,o)}));if(s&&24&e.getDeclarationModifierFlagsFromSymbol(s))return gr(t,e.Diagnostics.Private_or_protected_member_0_cannot_be_accessed_on_a_type_parameter,e.unescapeLeadingUnderscores(o)),Ae}}return gr(t,e.Diagnostics.Type_0_cannot_be_used_to_index_type_1,io(a),io(r)),Ae}function eC(e){pk(e.objectType),pk(e.indexType),$A(cm(e),e)}function nC(n){pk(n.typeParameter),pk(n.nameType),pk(n.type),n.type||uh(n,xe);var t=lm(n),r=bl(t);if(r)X_(r,$e,n.nameType);else{var a=vl(t);X_(a,$e,e.getEffectiveConstraintOfTypeParameter(n.typeParameter))}}function tC(e){jm(e)}function rC(e){IO(e),pk(e.type)}function aC(n){e.forEachChild(n,pk)}function iC(n){e.findAncestor(n,(function(e){return e.parent&&185===e.parent.kind&&e.parent.extendsType===e}))||XO(n,e.Diagnostics.infer_declarations_are_only_permitted_in_the_extends_clause_of_a_conditional_type),pk(n.typeParameter),BC(n)}function oC(e){for(var n=0,t=e.templateSpans;n<t.length;n++){var r=t[n];pk(r.type);var a=zm(r.type);X_(a,nn,r.type)}zm(e)}function sC(e){pk(e.argument),zm(e)}function cC(n){n.dotDotDotToken&&n.questionToken&&XO(n,e.Diagnostics.A_tuple_member_cannot_be_both_optional_and_rest),181===n.type.kind&&XO(n.type,e.Diagnostics.A_labeled_tuple_element_is_declared_as_optional_with_a_question_mark_after_the_name_and_before_the_colon_rather_than_after_the_type),182===n.type.kind&&XO(n.type,e.Diagnostics.A_labeled_tuple_element_is_declared_as_rest_with_a_before_the_name_rather_than_before_the_type),pk(n.type),zm(n)}function lC(n){return(e.hasEffectiveModifier(n,8)||e.isPrivateIdentifierClassElementDeclaration(n))&&!!(8388608&n.flags)}function uC(n,t){var r=e.getCombinedModifierFlags(n);return 254!==n.parent.kind&&253!==n.parent.kind&&222!==n.parent.kind&&8388608&n.flags&&(2&r||e.isModuleBlock(n.parent)&&e.isModuleDeclaration(n.parent.parent)&&e.isGlobalScopeAugmentation(n.parent.parent)||(r|=1),r|=2),r&t}function dC(n){if(t){var r,a,i,o=155,s=0,c=o,l=!1,u=!0,d=!1,p=n.declarations,f=0!==(16384&n.flags),m=!1,_=!1,g=!1,y=[];if(p)for(var h=0,v=p;h<v.length;h++){var b=v[h],E=b,T=8388608&E.flags,S=E.parent&&(254===E.parent.kind||178===E.parent.kind)||T;if(S&&(i=void 0),253!==E.kind&&222!==E.kind||T||(g=!0),252===E.kind||166===E.kind||165===E.kind||167===E.kind){y.push(E);var x=uC(E,o);s|=x,c&=x,l=l||e.hasQuestionToken(E),u=u&&e.hasQuestionToken(E);var L=e.nodeIsPresent(E.body);L&&r?f?_=!0:m=!0:(null===i||void 0===i?void 0:i.parent)===E.parent&&i.end!==E.pos&&w(i),L?r||(r=E):d=!0,i=E,S||(a=E)}}if(_&&e.forEach(y,(function(n){gr(n,e.Diagnostics.Multiple_constructor_implementations_are_not_allowed)})),m&&e.forEach(y,(function(n){gr(e.getNameOfDeclaration(n)||n,e.Diagnostics.Duplicate_function_implementation)})),g&&!f&&16&n.flags&&e.forEach(p,(function(t){Ir(t,e.Diagnostics.Duplicate_identifier_0,e.symbolName(n),p)})),!a||a.body||e.hasSyntacticModifier(a,128)||a.questionToken||w(a),d&&(p&&(R(p,r,o,s,c),O(p,r,l,u)),r))for(var D=Gu(n),A=Ou(r),C=0,I=D;C<I.length;C++){var N=I[C];if(!hg(A,N)){e.addRelatedInfo(gr(N.declaration,e.Diagnostics.This_overload_signature_is_not_compatible_with_its_implementation_signature),e.createDiagnosticForNode(r,e.Diagnostics.The_implementation_signature_is_declared_here));break}}}function k(e,n){var t=void 0!==n&&n.parent===e[0].parent;return t?n:e[0]}function R(n,t,r,a,i){var o=a^i;if(0!==o){var s=uC(k(n,t),r);e.forEach(n,(function(n){var t=uC(n,r)^s;1&t?gr(e.getNameOfDeclaration(n),e.Diagnostics.Overload_signatures_must_all_be_exported_or_non_exported):2&t?gr(e.getNameOfDeclaration(n),e.Diagnostics.Overload_signatures_must_all_be_ambient_or_non_ambient):24&t?gr(e.getNameOfDeclaration(n)||n,e.Diagnostics.Overload_signatures_must_all_be_public_private_or_protected):128&t&&gr(e.getNameOfDeclaration(n),e.Diagnostics.Overload_signatures_must_all_be_abstract_or_non_abstract)}))}}function O(n,t,r,a){if(r!==a){var i=e.hasQuestionToken(k(n,t));e.forEach(n,(function(n){var t=e.hasQuestionToken(n)!==i;t&&gr(e.getNameOfDeclaration(n),e.Diagnostics.Overload_signatures_must_all_be_optional_or_required)}))}}function w(n){if(!n.name||!e.nodeIsMissing(n.name)){var t=!1,r=e.forEachChild(n.parent,(function(e){if(t)return e;t=e===n}));if(r&&r.pos===n.end&&r.kind===n.kind){var a=r.name||r,i=r.name;if(n.name&&i&&(e.isPrivateIdentifier(n.name)&&e.isPrivateIdentifier(i)&&n.name.escapedText===i.escapedText||e.isComputedPropertyName(n.name)&&e.isComputedPropertyName(i)||e.isPropertyNameLiteral(n.name)&&e.isPropertyNameLiteral(i)&&e.getEscapedTextOfIdentifierOrLiteral(n.name)===e.getEscapedTextOfIdentifierOrLiteral(i))){var o=(166===n.kind||165===n.kind)&&e.hasSyntacticModifier(n,32)!==e.hasSyntacticModifier(r,32);if(o){var s=e.hasSyntacticModifier(n,32)?e.Diagnostics.Function_overload_must_be_static:e.Diagnostics.Function_overload_must_not_be_static;gr(a,s)}return}if(e.nodeIsPresent(r.body))return void gr(a,e.Diagnostics.Function_implementation_name_must_be_0,e.declarationNameToString(n.name))}var c=n.name||n;f?gr(c,e.Diagnostics.Constructor_implementation_is_missing):e.hasSyntacticModifier(n,128)?gr(c,e.Diagnostics.All_declarations_of_an_abstract_method_must_be_consecutive):gr(c,e.Diagnostics.Function_implementation_is_missing_or_not_immediately_following_the_declaration)}}}function pC(n){if(t){var r=n.localSymbol;if((r||(r=yi(n),r.exportSymbol))&&e.getDeclarationOfKind(r,n.kind)===n){for(var a=0,i=0,o=0,s=0,c=r.declarations;s<c.length;s++){var l=c[s],u=h(l),d=uC(l,513);1&d?512&d?o|=u:a|=u:i|=u}var p=a|i,f=a&i,m=o&p;if(f||m)for(var _=0,g=r.declarations;_<g.length;_++){l=g[_],u=h(l);var y=e.getNameOfDeclaration(l);u&m?gr(y,e.Diagnostics.Merged_declaration_0_cannot_include_a_default_export_declaration_Consider_adding_a_separate_export_default_0_declaration_instead,e.declarationNameToString(y)):u&f&&gr(y,e.Diagnostics.Individual_declarations_in_merged_declaration_0_must_be_all_exported_or_all_local,e.declarationNameToString(y))}}}function h(n){var t=n;switch(t.kind){case 254:case 255:case 335:case 328:case 329:return 2;case 257:return e.isAmbientModule(t)||0!==e.getModuleInstanceState(t)?5:4;case 253:case 256:case 292:return 3;case 298:return 7;case 267:case 217:var r=t,a=e.isExportAssignment(r)?r.expression:r.right;if(!e.isEntityNameExpression(a))return 1;t=a;case 261:case 264:case 263:var i=0,o=Fa(yi(t));return e.forEach(o.declarations,(function(e){i|=h(e)})),i;case 250:case 199:case 252:case 266:case 78:return 1;default:return e.Debug.failBadSyntaxKind(t)}}}function fC(e,n,t,r){var a=mC(e,n);return a&&yC(a,n,t,r)}function mC(n,t){if(!ko(n)){var r=n;if(r.promisedTypeOfPromise)return r.promisedTypeOfPromise;if(Ps(n,ep(!1)))return r.promisedTypeOfPromise=Td(n)[0];var a=Io(n,"then");if(!ko(a)){var i=a?yu(a,0):e.emptyArray;if(0!==i.length){var o=Lv(Qp(e.map(i,HL)),2097152);if(!ko(o)){var s=yu(o,0);if(0!==s.length)return r.promisedTypeOfPromise=Qp(e.map(s,HL),2);t&&gr(t,e.Diagnostics.The_first_parameter_of_the_then_method_of_a_promise_must_be_a_callback)}}else t&&gr(t,e.Diagnostics.A_promise_must_have_a_then_method)}}}function _C(e,n,t,r){var a=yC(e,n,t,r);return a||Ae}function gC(e){var n=Io(e,"then");return!!n&&yu(Lv(n,2097152),0).length>0}function yC(e,n,t,r){if(ko(e))return e;var a=e;return a.awaitedTypeOfType?a.awaitedTypeOfType:a.awaitedTypeOfType=rb(e,n?function(e){return hC(e,n,t,r)}:hC)}function hC(n,t,r,a){var i=n;if(i.awaitedTypeOfType)return i.awaitedTypeOfType;var o=mC(n);if(o){if(n.id===o.id||er.lastIndexOf(o.id)>=0)return void(t&&gr(t,e.Diagnostics.Type_is_referenced_directly_or_indirectly_in_the_fulfillment_callback_of_its_own_then_method));er.push(n.id);var s=yC(o,t,r,a);if(er.pop(),!s)return;return i.awaitedTypeOfType=s}if(!gC(n))return i.awaitedTypeOfType=n;if(t){if(!r)return e.Debug.fail();gr(t,r,a)}}function vC(n,t){var r=zm(t);if(F>=2){if(r===Ae)return;var a=ep(!0);if(a!==ln&&!Ps(r,a))return void gr(t,e.Diagnostics.The_return_type_of_an_async_function_or_method_must_be_the_global_Promise_T_type_Did_you_mean_to_write_Promise_0,io(yC(r)||We))}else{if(EC(t),r===Ae)return;var i=e.getEntityNameFromTypeNode(t);if(void 0===i)return void gr(t,e.Diagnostics.Type_0_is_not_a_valid_async_function_return_type_in_ES5_SlashES3_because_it_does_not_refer_to_a_Promise_compatible_constructor_value,io(r));var o=qa(i,111551,!0),s=o?ws(o):Ae;if(s===Ae)return void(78===i.kind&&"Promise"===i.escapedText&&Ms(r)===ep(!1)?gr(t,e.Diagnostics.An_async_function_or_method_in_ES5_SlashES3_requires_the_Promise_constructor_Make_sure_you_have_a_declaration_for_the_Promise_constructor_or_include_ES2015_in_your_lib_option):gr(t,e.Diagnostics.Type_0_is_not_a_valid_async_function_return_type_in_ES5_SlashES3_because_it_does_not_refer_to_a_Promise_compatible_constructor_value,e.entityNameToString(i)));var c=rp(!0);if(c===an)return void gr(t,e.Diagnostics.Type_0_is_not_a_valid_async_function_return_type_in_ES5_SlashES3_because_it_does_not_refer_to_a_Promise_compatible_constructor_value,e.entityNameToString(i));if(!X_(s,c,t,e.Diagnostics.Type_0_is_not_a_valid_async_function_return_type_in_ES5_SlashES3_because_it_does_not_refer_to_a_Promise_compatible_constructor_value))return;var l=i&&e.getFirstIdentifier(i),u=Fr(n.locals,l.escapedText,111551);if(u)return void gr(u.valueDeclaration,e.Diagnostics.Duplicate_identifier_0_Compiler_uses_declaration_1_to_support_async_functions,e.idText(l),e.entityNameToString(i))}_C(r,n,e.Diagnostics.The_return_type_of_an_async_function_must_either_be_a_valid_promise_or_must_not_contain_a_callable_then_member)}function bC(n){var t=lL(n);gL(t,n);var r=Hu(t);if(!(1&r.flags)){var a,i,o=rL(n);switch(n.parent.kind){case 253:var s=yi(n.parent),c=ws(s);a=Qp([c,We]);break;case 161:a=We,i=e.chainDiagnosticMessages(void 0,e.Diagnostics.The_return_type_of_a_parameter_decorator_function_must_be_either_void_or_any);break;case 164:a=We,i=e.chainDiagnosticMessages(void 0,e.Diagnostics.The_return_type_of_a_property_decorator_function_must_be_either_void_or_any);break;case 166:case 168:case 169:var l=Wk(n.parent),u=vp(l);a=Qp([u,We]);break;default:return e.Debug.fail()}X_(r,a,n,o,(function(){return i}))}}function EC(n){TC(n&&e.getEntityNameFromTypeNode(n))}function TC(n){if(n){var t=e.getFirstIdentifier(n),r=2097152|(78===n.kind?788968:1920),a=Vr(t,t.escapedText,r,void 0,void 0,!0);a&&2097152&a.flags&&Di(a)&&!mR(Fa(a))&&!Va(a)&&Ka(a)}}function SC(n){var t=xC(n);t&&e.isEntityName(t)&&TC(t)}function xC(e){if(e)switch(e.kind){case 184:case 183:return LC(e.types);case 185:return LC([e.trueType,e.falseType]);case 187:case 193:return xC(e.type);case 174:return e.typeName}}function LC(n){for(var t,r=0,a=n;r<a.length;r++){var i=a[r];while(187===i.kind||193===i.kind)i=i.type;if(141!==i.kind&&(z||(192!==i.kind||103!==i.literal.kind)&&150!==i.kind)){var o=xC(i);if(!o)return;if(t){if(!e.isIdentifier(t)||!e.isIdentifier(o)||t.escapedText!==o.escapedText)return}else t=o}}return t}function DC(n){var t=e.getEffectiveTypeAnnotationNode(n);return e.isRestParameter(n)?e.getRestParameterElementType(t):t}function AC(n){if(n.decorators&&e.nodeCanBeDecorated(n,n.parent,n.parent.parent)){C.experimentalDecorators||gr(n,e.Diagnostics.Experimental_support_for_decorators_is_a_feature_that_is_subject_to_change_in_a_future_release_Set_the_experimentalDecorators_option_in_your_tsconfig_or_jsconfig_to_remove_this_warning);var t=n.decorators[0];if(jR(t,8),161===n.kind&&jR(t,32),C.emitDecoratorMetadata)switch(jR(t,16),n.kind){case 253:var r=e.getFirstConstructorWithBody(n);if(r)for(var a=0,i=r.parameters;a<i.length;a++){var o=i[a];SC(DC(o))}break;case 168:case 169:var s=168===n.kind?169:168,c=e.getDeclarationOfKind(yi(n),s);SC(ys(n)||c&&ys(c));break;case 166:for(var l=0,u=n.parameters;l<u.length;l++){o=u[l];SC(DC(o))}SC(e.getEffectiveReturnTypeNode(n));break;case 164:SC(e.getEffectiveTypeAnnotationNode(n));break;case 161:SC(DC(n));for(var d=n.parent,p=0,f=d.parameters;p<f.length;p++){o=f[p];SC(DC(o))}break}e.forEach(n.decorators,bC)}}function CC(e){t&&(GC(e),hO(e),oI(e,e.name),sI(e,e.name))}function IC(n){n.typeExpression||gr(n.name,e.Diagnostics.JSDoc_typedef_tag_should_either_have_a_type_annotation_or_be_followed_by_property_or_member_tags),n.name&&mN(n.name,e.Diagnostics.Type_alias_name_cannot_be_0),pk(n.typeExpression)}function NC(e){pk(e.constraint);for(var n=0,t=e.typeParameters;n<t.length;n++){var r=t[n];pk(r)}}function kC(e){pk(e.typeExpression)}function RC(n){if(pk(n.typeExpression),!e.getParameterSymbolFromJSDoc(n)){var t=e.getHostSignatureFromJSDoc(n);if(t){var r=e.getJSDocTags(t).filter(e.isJSDocParameterTag).indexOf(n);if(r>-1&&r<t.parameters.length&&e.isBindingPattern(t.parameters[r].name))return;Fu(t)?e.findLast(e.getJSDocTags(t),e.isJSDocParameterTag)===n&&n.typeExpression&&n.typeExpression.type&&!sy(zm(n.typeExpression.type))&&gr(n.name,e.Diagnostics.JSDoc_param_tag_has_name_0_but_there_is_no_parameter_with_that_name_It_would_match_arguments_if_it_had_an_array_type,e.idText(158===n.name.kind?n.name.right:n.name)):e.isQualifiedName(n.name)?gr(n.name,e.Diagnostics.Qualified_name_0_is_not_allowed_without_a_leading_param_object_1,e.entityNameToString(n.name),e.entityNameToString(n.name.left)):gr(n.name,e.Diagnostics.JSDoc_param_tag_has_name_0_but_there_is_no_parameter_with_that_name,e.idText(n.name))}}}function OC(e){pk(e.typeExpression)}function wC(n){!t||n.type||e.isJSDocConstructSignature(n)||uh(n,xe),kA(n)}function PC(n){var t=e.getEffectiveJSDocHost(n);t&&(e.isClassDeclaration(t)||e.isClassExpression(t))||gr(t,e.Diagnostics.JSDoc_0_is_not_attached_to_a_class,e.idText(n.tagName))}function MC(n){var t=e.getEffectiveJSDocHost(n);if(t&&(e.isClassDeclaration(t)||e.isClassExpression(t))){var r=e.getJSDocTags(t).filter(e.isJSDocAugmentsTag);e.Debug.assert(r.length>0),r.length>1&&gr(r[1],e.Diagnostics.Class_declarations_cannot_have_more_than_one_augments_or_extends_tag);var a=FC(n.class.expression),i=e.getClassExtendsHeritageElement(t);if(i){var o=FC(i.expression);o&&a.escapedText!==o.escapedText&&gr(a,e.Diagnostics.JSDoc_0_1_does_not_match_the_extends_2_clause,e.idText(n.tagName),e.idText(a),e.idText(o))}}else gr(t,e.Diagnostics.JSDoc_0_is_not_attached_to_a_class,e.idText(n.tagName))}function FC(e){switch(e.kind){case 78:return e;case 202:return e.name;default:return}}function GC(n){var r;AC(n),kA(n);var a=e.getFunctionFlags(n);if(n.name&&159===n.name.kind&&ET(n.name),Ic(n)){var i=yi(n),o=n.localSymbol||i,s=null===(r=o.declarations)||void 0===r?void 0:r.find((function(e){return e.kind===n.kind&&!(131072&e.flags)}));n===s&&dC(o),i.parent&&dC(i)}var c=165===n.kind?void 0:n.body;if(pk(c),uD(n,Wu(n)),t&&!e.getEffectiveReturnTypeNode(n)&&(e.nodeIsMissing(c)&&!lC(n)&&uh(n,xe),1&a&&e.nodeIsPresent(c)&&Hu(Ou(n))),e.isInJSFile(n)){var l=e.getJSDocTypeTag(n);l&&l.typeExpression&&!sT(zm(l.typeExpression),n)&&gr(l.typeExpression.type,e.Diagnostics.The_type_of_a_function_declaration_must_match_the_function_s_signature)}}function BC(n){if(t){var r=e.getSourceFileOfNode(n),a=Dt.get(r.path);a||(a=[],Dt.set(r.path,a)),a.push(n)}}function UC(n,t){for(var r=0,a=n;r<a.length;r++){var i=a[r];switch(i.kind){case 253:case 222:KC(i,t),WC(i,t);break;case 298:case 257:case 231:case 259:case 238:case 239:case 240:YC(i,t);break;case 167:case 209:case 252:case 210:case 166:case 168:case 169:i.body&&YC(i,t),WC(i,t);break;case 165:case 170:case 171:case 175:case 176:case 255:case 254:WC(i,t);break;case 186:HC(i,t);break;default:e.Debug.assertNever(i,"Node should not have been registered for unused identifiers check")}}}function VC(n,t,r){var a=e.getNameOfDeclaration(n)||n,i=Nk(n)?e.Diagnostics._0_is_declared_but_never_used:e.Diagnostics._0_is_declared_but_its_value_is_never_read;r(n,0,e.createDiagnosticForNode(a,i,t))}function jC(n){return e.isIdentifier(n)&&95===e.idText(n).charCodeAt(0)}function KC(n,t){for(var r=0,a=n.members;r<a.length;r++){var i=a[r];switch(i.kind){case 166:case 164:case 168:case 169:if(169===i.kind&&32768&i.symbol.flags)break;var o=yi(i);o.isReferenced||!(e.hasEffectiveModifier(i,8)||e.isNamedDeclaration(i)&&e.isPrivateIdentifier(i.name))||8388608&i.flags||t(i,0,e.createDiagnosticForNode(i.name,e.Diagnostics._0_is_declared_but_its_value_is_never_read,ro(o)));break;case 167:for(var s=0,c=i.parameters;s<c.length;s++){var l=c[s];!l.symbol.isReferenced&&e.hasSyntacticModifier(l,8)&&t(l,0,e.createDiagnosticForNode(l.name,e.Diagnostics.Property_0_is_declared_but_its_value_is_never_read,e.symbolName(l.symbol)))}break;case 172:case 230:break;default:e.Debug.fail()}}}function HC(n,t){var r=n.typeParameter;zC(r)&&t(n,1,e.createDiagnosticForNode(n,e.Diagnostics._0_is_declared_but_its_value_is_never_read,e.idText(r.name)))}function WC(n,t){var r=yi(n).declarations;if(r&&e.last(r)===n)for(var a=e.getEffectiveTypeParameterDeclarations(n),i=new e.Set,o=0,s=a;o<s.length;o++){var c=s[o];if(zC(c)){var l=e.idText(c.name),u=c.parent;if(186!==u.kind&&u.typeParameters.every(zC)){if(e.tryAddToSet(i,u)){var d=e.getSourceFileOfNode(u),p=e.isJSDocTemplateTag(u)?e.rangeOfNode(u):e.rangeOfTypeParameters(d,u.typeParameters),f=1===u.typeParameters.length,m=f?e.Diagnostics._0_is_declared_but_its_value_is_never_read:e.Diagnostics.All_type_parameters_are_unused,_=f?l:void 0;t(c,1,e.createFileDiagnostic(d,p.pos,p.end-p.pos,m,_))}}else t(c,1,e.createDiagnosticForNode(c,e.Diagnostics._0_is_declared_but_its_value_is_never_read,l))}}}function zC(e){return!(262144&gi(e.symbol).isReferenced)&&!jC(e.name)}function qC(e,n,t,r){var a=String(r(n)),i=e.get(a);i?i[1].push(t):e.set(a,[n,[t]])}function JC(n){return e.tryCast(e.getRootDeclaration(n),e.isParameter)}function XC(n){return e.isBindingElement(n)?e.isObjectBindingPattern(n.parent)?!(!n.propertyName||!jC(n.name)):jC(n.name):e.isAmbientModule(n)||(e.isVariableDeclaration(n)&&e.isForInOrOfStatement(n.parent.parent)||ZC(n))&&jC(n.name)}function YC(n,t){var r=new e.Map,a=new e.Map,i=new e.Map;n.locals.forEach((function(n){if(!(262144&n.flags?!(3&n.flags)||3&n.isReferenced:n.isReferenced||n.exportSymbol)&&n.declarations)for(var o=0,s=n.declarations;o<s.length;o++){var c=s[o];if(!XC(c))if(ZC(c))qC(r,$C(c),c,w);else if(e.isBindingElement(c)&&e.isObjectBindingPattern(c.parent)){var l=e.last(c.parent.elements);c!==l&&e.last(c.parent.elements).dotDotDotToken||qC(a,c.parent,c,w)}else if(e.isVariableDeclaration(c))qC(i,c.parent,c,w);else{var u=n.valueDeclaration&&JC(n.valueDeclaration),d=n.valueDeclaration&&e.getNameOfDeclaration(n.valueDeclaration);u&&d?e.isParameterPropertyDeclaration(u,u.parent)||e.parameterIsThisKeyword(u)||jC(d)||(e.isBindingElement(c)&&e.isArrayBindingPattern(c.parent)?qC(a,c.parent,c,w):t(u,1,e.createDiagnosticForNode(d,e.Diagnostics._0_is_declared_but_its_value_is_never_read,e.symbolName(n)))):VC(c,e.symbolName(n),t)}}})),r.forEach((function(n){var r=n[0],a=n[1],i=r.parent,o=(r.name?1:0)+(r.namedBindings?264===r.namedBindings.kind?1:r.namedBindings.elements.length:0);if(o===a.length)t(i,0,1===a.length?e.createDiagnosticForNode(i,e.Diagnostics._0_is_declared_but_its_value_is_never_read,e.idText(e.first(a).name)):e.createDiagnosticForNode(i,e.Diagnostics.All_imports_in_import_declaration_are_unused));else for(var s=0,c=a;s<c.length;s++){var l=c[s];VC(l,e.idText(l.name),t)}})),a.forEach((function(n){var r=n[0],a=n[1],o=JC(r.parent)?1:0;if(r.elements.length===a.length)1===a.length&&250===r.parent.kind&&251===r.parent.parent.kind?qC(i,r.parent.parent,r.parent,w):t(r,o,1===a.length?e.createDiagnosticForNode(r,e.Diagnostics._0_is_declared_but_its_value_is_never_read,QC(e.first(a).name)):e.createDiagnosticForNode(r,e.Diagnostics.All_destructured_elements_are_unused));else for(var s=0,c=a;s<c.length;s++){var l=c[s];t(l,o,e.createDiagnosticForNode(l,e.Diagnostics._0_is_declared_but_its_value_is_never_read,QC(l.name)))}})),i.forEach((function(n){var r=n[0],a=n[1];if(r.declarations.length===a.length)t(r,0,1===a.length?e.createDiagnosticForNode(e.first(a).name,e.Diagnostics._0_is_declared_but_its_value_is_never_read,QC(e.first(a).name)):e.createDiagnosticForNode(233===r.parent.kind?r.parent:r,e.Diagnostics.All_variables_are_unused));else for(var i=0,o=a;i<o.length;i++){var s=o[i];t(s,0,e.createDiagnosticForNode(s,e.Diagnostics._0_is_declared_but_its_value_is_never_read,QC(s.name)))}}))}function QC(n){switch(n.kind){case 78:return e.idText(n);case 198:case 197:return QC(e.cast(e.first(n.elements),e.isBindingElement).name);default:return e.Debug.assertNever(n)}}function ZC(e){return 263===e.kind||266===e.kind||264===e.kind}function $C(e){return 263===e.kind?e:264===e.kind?e.parent:e.parent.parent}function eI(n){if(231===n.kind&&tw(n),e.isFunctionOrModuleBlock(n)){var t=Nt;e.forEach(n.statements,pk),Nt=t}else e.forEach(n.statements,pk);n.locals&&BC(n)}function nI(n){F>=2||!e.hasRestParameter(n)||8388608&n.flags||e.nodeIsMissing(n.body)||e.forEach(n.parameters,(function(n){n.name&&!e.isBindingPattern(n.name)&&n.name.escapedText===se.escapedName&&_r("noEmit",n,e.Diagnostics.Duplicate_identifier_arguments_Compiler_uses_arguments_to_initialize_rest_parameters)}))}function tI(n,t,r){if(!t||t.escapedText!==r)return!1;if(164===n.kind||163===n.kind||166===n.kind||165===n.kind||168===n.kind||169===n.kind)return!1;if(8388608&n.flags)return!1;var a=e.getRootDeclaration(n);return 161!==a.kind||!e.nodeIsMissing(a.parent.body)}function rI(n){e.findAncestor(n,(function(t){if(4&TR(t)){var r=78!==n.kind;return r?gr(e.getNameOfDeclaration(n),e.Diagnostics.Duplicate_identifier_this_Compiler_uses_variable_declaration_this_to_capture_this_reference):gr(n,e.Diagnostics.Expression_resolves_to_variable_declaration_this_that_compiler_uses_to_capture_this_reference),!0}return!1}))}function aI(n){e.findAncestor(n,(function(t){if(8&TR(t)){var r=78!==n.kind;return r?gr(e.getNameOfDeclaration(n),e.Diagnostics.Duplicate_identifier_newTarget_Compiler_uses_variable_declaration_newTarget_to_capture_new_target_meta_property_reference):gr(n,e.Diagnostics.Expression_resolves_to_variable_declaration_newTarget_that_compiler_uses_to_capture_new_target_meta_property_reference),!0}return!1}))}function iI(n){var t=e.getEnclosingBlockScopeContainer(n);67108864&TR(t)&&(e.Debug.assert(e.isNamedDeclaration(n)&&e.isIdentifier(n.name)&&"string"===typeof n.name.escapedText,"The target of a WeakMap/WeakSet collision check should be an identifier"),_r("noEmit",n,e.Diagnostics.Compiler_reserves_name_0_when_emitting_private_identifier_downlevel,n.name.escapedText))}function oI(n,t){if(!(G>=e.ModuleKind.ES2015)&&(tI(n,t,"require")||tI(n,t,"exports"))&&(!e.isModuleDeclaration(n)||1===e.getModuleInstanceState(n))){var r=Ao(n);298===r.kind&&e.isExternalOrCommonJsModule(r)&&_r("noEmit",t,e.Diagnostics.Duplicate_identifier_0_Compiler_reserves_name_1_in_top_level_scope_of_a_module,e.declarationNameToString(t),e.declarationNameToString(t))}}function sI(n,t){if(!(F>=4)&&tI(n,t,"Promise")&&(!e.isModuleDeclaration(n)||1===e.getModuleInstanceState(n))){var r=Ao(n);298===r.kind&&e.isExternalOrCommonJsModule(r)&&2048&r.flags&&_r("noEmit",t,e.Diagnostics.Duplicate_identifier_0_Compiler_reserves_name_1_in_top_level_scope_of_a_module_containing_async_functions,e.declarationNameToString(t),e.declarationNameToString(t))}}function cI(n){if(0===(3&e.getCombinedNodeFlags(n))&&!e.isParameterDeclaration(n)&&(250!==n.kind||n.initializer)){var t=yi(n);if(1&t.flags){if(!e.isIdentifier(n.name))return e.Debug.fail();var r=Vr(n,n.name.escapedText,3,void 0,void 0,!1);if(r&&r!==t&&2&r.flags&&3&oS(r)){var a=e.getAncestor(r.valueDeclaration,251),i=233===a.parent.kind&&a.parent.parent?a.parent.parent:void 0,o=i&&(231===i.kind&&e.isFunctionLike(i.parent)||258===i.kind||257===i.kind||298===i.kind);if(!o){var s=ro(r);gr(n,e.Diagnostics.Cannot_initialize_outer_scoped_variable_0_in_the_same_scope_as_block_scoped_declaration_1,s,s)}}}}}function lI(e){return e===Le?xe:e===Rn?kn:e}function uI(n){var t;if(AC(n),e.isBindingElement(n)||pk(n.type),n.name){if(159===n.name.kind&&(ET(n.name),n.initializer&&$D(n.initializer)),e.isBindingElement(n)){e.isObjectBindingPattern(n.parent)&&n.dotDotDotToken&&F<5&&jR(n,4),n.propertyName&&159===n.propertyName.kind&&ET(n.propertyName);var r=n.parent.parent,a=Ro(r),i=n.propertyName||n.name;if(a&&!e.isBindingPattern(i)){var o=Sf(i);if(Lc(o)){var s=kc(o),c=_u(a,s);c&&(qS(c,void 0,!1),cS(n,!!r.initializer&&105===r.initializer.kind,!1,a,c))}}}if(e.isBindingPattern(n.name)&&(198===n.name.kind&&F<2&&C.downlevelIteration&&jR(n,512),e.forEach(n.name.elements,pk)),n.initializer&&e.isParameterDeclaration(n)&&e.nodeIsMissing(e.getContainingFunction(n).body))gr(n,e.Diagnostics.A_parameter_initializer_is_only_allowed_in_a_function_or_constructor_implementation);else if(e.isBindingPattern(n.name)){var l=n.initializer&&239!==n.parent.parent.kind,u=0===n.name.elements.length;if(l||u){var d=us(n);if(l){var p=$D(n.initializer);z&&u?hS(p,n):Y_(p,us(n),n,n.initializer)}u&&(e.isArrayBindingPattern(n.name)?NI(65,d,ke,n):z&&hS(d,n))}}else{var f=yi(n);if(2097152&f.flags&&e.isRequireVariableDeclaration(n))XN(n);else{var m=lI(ws(f));if(n===f.valueDeclaration){var _=e.getEffectiveInitializer(n);if(_){var g=e.isInJSFile(n)&&e.isObjectLiteralExpression(_)&&(0===_.properties.length||e.isPrototypeAccess(n.name))&&!!(null===(t=f.exports)||void 0===t?void 0:t.size);g||239===n.parent.parent.kind||Y_($D(_),m,n,_,void 0)}f.declarations&&f.declarations.length>1&&e.some(f.declarations,(function(t){return t!==n&&e.isVariableLike(t)&&!pI(t,n)}))&&gr(n.name,e.Diagnostics.All_declarations_of_0_must_have_identical_modifiers,e.declarationNameToString(n.name))}else{var y=lI(us(n));m===Ae||y===Ae||U_(m,y)||67108864&f.flags||dI(f.valueDeclaration,m,n,y),n.initializer&&Y_($D(n.initializer),y,n,n.initializer,void 0),f.valueDeclaration&&!pI(n,f.valueDeclaration)&&gr(n.name,e.Diagnostics.All_declarations_of_0_must_have_identical_modifiers,e.declarationNameToString(n.name))}164!==n.kind&&163!==n.kind&&(pC(n),250!==n.kind&&199!==n.kind||cI(n),oI(n,n.name),sI(n,n.name),F<99&&(tI(n,n.name,"WeakMap")||tI(n,n.name,"WeakSet"))&&$t.push(n))}}}}function dI(n,t,r,a){var i=e.getNameOfDeclaration(r),o=164===r.kind||163===r.kind?e.Diagnostics.Subsequent_property_declarations_must_have_the_same_type_Property_0_must_be_of_type_1_but_here_has_type_2:e.Diagnostics.Subsequent_variable_declarations_must_have_the_same_type_Variable_0_must_be_of_type_1_but_here_has_type_2,s=e.declarationNameToString(i),c=gr(i,o,s,io(t),io(a));n&&e.addRelatedInfo(c,e.createDiagnosticForNode(n,e.Diagnostics._0_was_also_declared_here,s))}function pI(n,t){if(161===n.kind&&250===t.kind||250===n.kind&&161===t.kind)return!0;if(e.hasQuestionToken(n)!==e.hasQuestionToken(t))return!1;var r=504;return e.getSelectedEffectiveModifierFlags(n,r)===e.getSelectedEffectiveModifierFlags(t,r)}function fI(n){null===e.tracing||void 0===e.tracing||e.tracing.push("check","checkVariableDeclaration",{kind:n.kind,pos:n.pos,end:n.end}),GO(n),uI(n),null===e.tracing||void 0===e.tracing||e.tracing.pop()}function mI(e){return OO(e),uI(e)}function _I(n){WR(n)||VO(n.declarationList)||KO(n),e.forEach(n.declarationList.declarations,pk)}function gI(e){tw(e),TA(e.expression)}function yI(n){tw(n);var t=xI(n.expression);hI(n.expression,t,n.thenStatement),pk(n.thenStatement),232===n.thenStatement.kind&&gr(n.thenStatement,e.Diagnostics.The_body_of_an_if_statement_cannot_be_the_empty_statement),pk(n.elseStatement)}function hI(n,t,r){if(z&&!Fy(t)){var a=e.isBinaryExpression(n)?n.right:n,i=e.isIdentifier(a)?a:e.isPropertyAccessExpression(a)?a.name:e.isBinaryExpression(a)&&e.isIdentifier(a.right)?a.right:void 0,o=e.isPropertyAccessExpression(a)&&e.isAssertionExpression(e.skipParentheses(a.expression));if(i&&!o){var s=yu(t,0),c=!!fC(t);if(0!==s.length||c){var l=jk(i);if(l){var u=e.isBinaryExpression(n.parent)&&bI(n.parent,l)||r&&vI(n,r,i,l);u||(c?vr(a,!0,e.Diagnostics.This_condition_will_always_return_true_since_this_0_is_always_defined,so(t)):gr(a,e.Diagnostics.This_condition_will_always_return_true_since_this_function_is_always_defined_Did_you_mean_to_call_it_instead))}}}}}function vI(n,t,r,a){return!!e.forEachChild(t,(function t(i){if(e.isIdentifier(i)){var o=jk(i);if(o&&o===a){if(e.isIdentifier(n))return!0;var s=r.parent,c=i.parent;while(s&&c){if(e.isIdentifier(s)&&e.isIdentifier(c)||107===s.kind&&107===c.kind)return jk(s)===jk(c);if(e.isPropertyAccessExpression(s)&&e.isPropertyAccessExpression(c)){if(jk(s.name)!==jk(c.name))return!1;c=c.expression,s=s.expression}else{if(!e.isCallExpression(s)||!e.isCallExpression(c))return!1;c=c.expression,s=s.expression}}}}return e.forEachChild(i,t)}))}function bI(n,t){while(e.isBinaryExpression(n)&&55===n.operatorToken.kind){var r=e.forEachChild(n.right,(function n(r){if(e.isIdentifier(r)){var a=jk(r);if(a&&a===t)return!0}return e.forEachChild(r,n)}));if(r)return!0;n=n.parent}return!1}function EI(e){tw(e),pk(e.statement),xI(e.expression)}function TI(e){tw(e),xI(e.expression),pk(e.statement)}function SI(n,t){return 16384&n.flags&&gr(t,e.Diagnostics.An_expression_of_type_void_cannot_be_tested_for_truthiness),n}function xI(e,n){return SI(TA(e,n),e)}function LI(n){tw(n)||n.initializer&&251===n.initializer.kind&&VO(n.initializer),n.initializer&&(251===n.initializer.kind?e.forEach(n.initializer.declarations,fI):TA(n.initializer)),n.condition&&xI(n.condition),n.incrementor&&TA(n.incrementor),pk(n.statement),n.locals&&BC(n)}function DI(n){if(LO(n),n.awaitModifier){var t=e.getFunctionFlags(e.getContainingFunction(n));2===(6&t)&&F<99&&jR(n,16384)}else C.downlevelIteration&&F<2&&jR(n,256);if(251===n.initializer.kind)CI(n);else{var r=n.initializer,a=II(n);if(200===r.kind||201===r.kind)GD(r,a||Ae);else{var i=TA(r);hD(r,e.Diagnostics.The_left_hand_side_of_a_for_of_statement_must_be_a_variable_or_a_property_access,e.Diagnostics.The_left_hand_side_of_a_for_of_statement_may_not_be_an_optional_property_access),a&&Y_(a,i,r,n.expression)}}pk(n.statement),n.locals&&BC(n)}function AI(n){LO(n);var t=fS(TA(n.expression));if(251===n.initializer.kind){var r=n.initializer.declarations[0];r&&e.isBindingPattern(r.name)&&gr(r.name,e.Diagnostics.The_left_hand_side_of_a_for_in_statement_cannot_be_a_destructuring_pattern),CI(n)}else{var a=n.initializer,i=TA(a);200===a.kind||201===a.kind?gr(a,e.Diagnostics.The_left_hand_side_of_a_for_in_statement_cannot_be_a_destructuring_pattern):W_(Nf(t),i)?hD(a,e.Diagnostics.The_left_hand_side_of_a_for_in_statement_must_be_a_variable_or_a_property_access,e.Diagnostics.The_left_hand_side_of_a_for_in_statement_may_not_be_an_optional_property_access):gr(a,e.Diagnostics.The_left_hand_side_of_a_for_in_statement_must_be_of_type_string_or_any)}t!==ze&&CD(t,126091264)||gr(n.expression,e.Diagnostics.The_right_hand_side_of_a_for_in_statement_must_be_of_type_any_an_object_type_or_a_type_parameter_but_here_has_type_0,io(t)),pk(n.statement),n.locals&&BC(n)}function CI(e){var n=e.initializer;if(n.declarations.length>=1){var t=n.declarations[0];fI(t)}}function II(e){var n=e.awaitModifier?15:13;return NI(n,dS(e.expression),ke,e.expression)}function NI(e,n,t,r){return ko(n)?n:kI(e,n,t,r,!0)||xe}function kI(n,t,r,a,i){var o=0!==(2&n);if(t!==ze){var s=F>=2,c=!s&&C.downlevelIteration,l=C.noUncheckedIndexedAccess&&!!(128&n);if(s||c||o){var u=GI(t,n,s?a:void 0);if(i&&u){var d=8&n?e.Diagnostics.Cannot_iterate_value_because_the_next_method_of_its_iterator_expects_type_1_but_for_of_will_always_send_0:32&n?e.Diagnostics.Cannot_iterate_value_because_the_next_method_of_its_iterator_expects_type_1_but_array_spread_will_always_send_0:64&n?e.Diagnostics.Cannot_iterate_value_because_the_next_method_of_its_iterator_expects_type_1_but_array_destructuring_will_always_send_0:16&n?e.Diagnostics.Cannot_delegate_iteration_to_value_because_the_next_method_of_its_iterator_expects_type_1_but_the_containing_generator_will_always_send_0:void 0;d&&X_(r,u.nextType,a,d)}if(u||s)return l?Iv(u&&u.yieldType):u&&u.yieldType}var p=t,f=!1,m=!1;if(4&n){if(1048576&p.flags){var _=t.types,g=e.filter(_,(function(e){return!(402653316&e.flags)}));g!==_&&(p=Qp(g,2))}else 402653316&p.flags&&(p=ze);if(m=p!==t,m&&(F<1&&a&&(gr(a,e.Diagnostics.Using_a_string_in_a_for_of_statement_is_only_supported_in_ECMAScript_5_and_higher),f=!0),131072&p.flags))return l?Iv(Me):Me}if(!dy(p)){if(a&&!f){var y=!!(4&n)&&!m,h=T(y,c),v=h[0],b=h[1];vr(a,b&&!!fC(p),v,io(p))}return m?l?Iv(Me):Me:void 0}var E=Eu(p,1);return m&&E?402653316&E.flags&&!C.noUncheckedIndexedAccess?Me:Qp(l?[E,Me,ke]:[E,Me],2):128&n?Iv(E):E}function T(r,a){var i;if(a)return r?[e.Diagnostics.Type_0_is_not_an_array_type_or_a_string_type_or_does_not_have_a_Symbol_iterator_method_that_returns_an_iterator,!0]:[e.Diagnostics.Type_0_is_not_an_array_type_or_does_not_have_a_Symbol_iterator_method_that_returns_an_iterator,!0];var o=OI(n,0,t,void 0);return o?[e.Diagnostics.Type_0_is_not_an_array_type_or_a_string_type_Use_compiler_option_downlevelIteration_to_allow_iterating_of_iterators,!1]:RI(null===(i=t.symbol)||void 0===i?void 0:i.escapedName)?[e.Diagnostics.Type_0_can_only_be_iterated_through_when_using_the_downlevelIteration_flag_or_with_a_target_of_es2015_or_higher,!0]:r?[e.Diagnostics.Type_0_is_not_an_array_type_or_a_string_type,!0]:[e.Diagnostics.Type_0_is_not_an_array_type,!0]}zI(a,t,o)}function RI(e){switch(e){case"Float32Array":case"Float64Array":case"Int16Array":case"Int32Array":case"Int8Array":case"NodeList":case"Uint16Array":case"Uint32Array":case"Uint8Array":case"Uint8ClampedArray":return!0}return!1}function OI(e,n,t,r){if(!ko(t)){var a=GI(t,e,r);return a&&a[V(n)]}}function wI(e,n,t){if(void 0===e&&(e=ze),void 0===n&&(n=ze),void 0===t&&(t=Ne),67359327&e.flags&&180227&n.flags&&180227&t.flags){var r=gd([e,n,t]),a=yt.get(r);return a||(a={yieldType:e,returnType:n,nextType:t},yt.set(r,a)),a}return{yieldType:e,returnType:n,nextType:t}}function PI(n){for(var t,r,a,i=0,o=n;i<o.length;i++){var s=o[i];if(void 0!==s&&s!==ht){if(s===vt)return vt;t=e.append(t,s.yieldType),r=e.append(r,s.returnType),a=e.append(a,s.nextType)}}return t||r||a?wI(t&&Qp(t),r&&Qp(r),a&&pf(a)):ht}function MI(e,n){return e[n]}function FI(e,n,t){return e[n]=t}function GI(n,t,r){if(ko(n))return vt;if(!(1048576&n.flags)){var a=UI(n,t,r);return a===ht?void(r&&zI(r,n,!!(2&t))):a}var i,o=2&t?"iterationTypesOfAsyncIterable":"iterationTypesOfIterable",s=MI(n,o);if(s)return s===ht?void 0:s;for(var c=0,l=n.types;c<l.length;c++){var u=l[c],d=UI(u,t,r);if(d===ht)return r&&zI(r,n,!!(2&t)),void FI(n,o,ht);i=e.append(i,d)}var p=i?PI(i):ht;return FI(n,o,p),p===ht?void 0:p}function BI(e,n){if(e===ht)return ht;if(e===vt)return vt;var t=e.yieldType,r=e.returnType,a=e.nextType;return wI(yC(t,n)||xe,yC(r,n)||xe,a)}function UI(e,n,t){if(ko(e))return vt;if(2&n){var r=VI(e,Tt)||KI(e,Tt);if(r)return r}if(1&n){r=VI(e,St)||KI(e,St);if(r){if(!(2&n))return r;if(r!==ht)return FI(e,"iterationTypesOfAsyncIterable",BI(r,t))}}if(2&n){r=WI(e,Tt,t);if(r!==ht)return r}if(1&n){r=WI(e,St,t);if(r!==ht)return 2&n?FI(e,"iterationTypesOfAsyncIterable",r?BI(r,t):ht):r}return ht}function VI(e,n){return MI(e,n.iterableCacheKey)}function jI(e,n){var t=VI(e,n)||WI(e,n,void 0);return t===ht?Et:t}function KI(e,n){var t;if(Ps(e,t=n.getGlobalIterableType(!1))||Ps(e,t=n.getGlobalIterableIteratorType(!1))){var r=Td(e)[0],a=jI(t,n),i=a.returnType,o=a.nextType;return FI(e,n.iterableCacheKey,wI(r,i,o))}if(Ps(e,n.getGlobalGeneratorType(!1))){var s=Td(e);r=s[0],i=s[1],o=s[2];return FI(e,n.iterableCacheKey,wI(r,i,o))}}function HI(n){var t=Qd(!1),r=t&&Io(ws(t),e.escapeLeadingUnderscores(n));return r&&Lc(r)?kc(r):"__@"+n}function WI(n,t,r){var a,i=_u(n,HI(t.iteratorSymbolName)),o=!i||16777216&i.flags?void 0:ws(i);if(ko(o))return FI(n,t.iterableCacheKey,vt);var s=o?yu(o,0):void 0;if(!e.some(s))return FI(n,t.iterableCacheKey,ht);var c=pf(e.map(s,Hu)),l=null!==(a=qI(c,t,r))&&void 0!==a?a:ht;return FI(n,t.iterableCacheKey,l)}function zI(n,t,r){var a=r?e.Diagnostics.Type_0_must_have_a_Symbol_asyncIterator_method_that_returns_an_async_iterator:e.Diagnostics.Type_0_must_have_a_Symbol_iterator_method_that_returns_an_iterator;vr(n,!!fC(t),a,io(t))}function qI(e,n,t){if(ko(e))return vt;var r=JI(e,n)||XI(e,n)||nN(e,n,t);return r===ht?void 0:r}function JI(e,n){return MI(e,n.iteratorCacheKey)}function XI(e,n){var t=n.getGlobalIterableIteratorType(!1);if(Ps(e,t)){var r=Td(e)[0],a=JI(t,n)||nN(t,n,void 0),i=a===ht?Et:a,o=i.returnType,s=i.nextType;return FI(e,n.iteratorCacheKey,wI(r,o,s))}if(Ps(e,n.getGlobalIteratorType(!1))||Ps(e,n.getGlobalGeneratorType(!1))){var c=Td(e);r=c[0],o=c[1],s=c[2];return FI(e,n.iteratorCacheKey,wI(r,o,s))}}function YI(e,n){var t=Io(e,"done")||Be;return W_(0===n?Be:Ve,t)}function QI(e){return YI(e,0)}function ZI(e){return YI(e,1)}function $I(e){if(ko(e))return vt;var n=MI(e,"iterationTypesOfIteratorResult");if(n)return n;if(Ps(e,pp(!1))){var t=Td(e)[0];return FI(e,"iterationTypesOfIteratorResult",wI(t,void 0,void 0))}if(Ps(e,fp(!1))){var r=Td(e)[0];return FI(e,"iterationTypesOfIteratorResult",wI(void 0,r,void 0))}var a=nb(e,QI),i=a!==ze?Io(a,"value"):void 0,o=nb(e,ZI),s=o!==ze?Io(o,"value"):void 0;return FI(e,"iterationTypesOfIteratorResult",i||s?wI(i,s||We,void 0):ht)}function eN(n,t,r,a){var i,o,s,c,l=_u(n,r);if(l||"next"===r){var u=!l||"next"===r&&16777216&l.flags?void 0:"next"===r?ws(l):Lv(ws(l),2097152);if(ko(u))return"next"===r?vt:bt;var d,p,f,m,_,g=u?yu(u,0):e.emptyArray;if(0===g.length){if(a){var y="next"===r?t.mustHaveANextMethodDiagnostic:t.mustBeAMethodDiagnostic;gr(a,y,r)}return"next"===r?vt:void 0}if((null===u||void 0===u?void 0:u.symbol)&&1===g.length){var h=t.getGlobalGeneratorType(!1),v=t.getGlobalIteratorType(!1),b=(null===(o=null===(i=h.symbol)||void 0===i?void 0:i.members)||void 0===o?void 0:o.get(r))===u.symbol,E=!b&&(null===(c=null===(s=v.symbol)||void 0===s?void 0:s.members)||void 0===c?void 0:c.get(r))===u.symbol;if(b||E){var T=b?h:v,S=u.mapper;return wI(Zm(T.typeParameters[0],S),Zm(T.typeParameters[1],S),"next"===r?Zm(T.typeParameters[2],S):void 0)}}for(var x=0,L=g;x<L.length;x++){var D=L[x];"throw"!==r&&e.some(D.parameters)&&(d=e.append(d,ML(D,0))),p=e.append(p,Hu(D))}if("throw"!==r){var A=d?Qp(d):Ne;if("next"===r)m=A;else if("return"===r){var C=t.resolveIterationType(A,a)||xe;f=e.append(f,C)}}var I=p?pf(p):ze,N=t.resolveIterationType(I,a)||xe,k=$I(N);return k===ht?(a&&gr(a,t.mustHaveAValueDiagnostic,r),_=xe,f=e.append(f,xe)):(_=k.yieldType,f=e.append(f,k.returnType)),wI(_,Qp(f),m)}}function nN(e,n,t){var r=PI([eN(e,n,"next",t),eN(e,n,"return",t),eN(e,n,"throw",t)]);return FI(e,n.iteratorCacheKey,r)}function tN(e,n,t){if(!ko(n)){var r=rN(n,t);return r&&r[V(e)]}}function rN(e,n){if(ko(e))return vt;var t=n?2:1,r=n?Tt:St;return GI(e,t,void 0)||qI(e,r,void 0)}function aN(e){tw(e)||RO(e)}function iN(e,n){var t,r,a=!!(1&n),i=!!(2&n);return a?null!==(t=tN(1,e,i))&&void 0!==t?t:Ae:i?null!==(r=yC(e))&&void 0!==r?r:Ae:e}function oN(n,t){var r=iN(t,e.getFunctionFlags(n));return!!r&&AD(r,16387)}function sN(n){var t;if(!tw(n)){var r=e.getContainingFunction(n);if(r){var a=Ou(r),i=Hu(a),o=e.getFunctionFlags(r);if(z||n.expression||131072&i.flags){var s=n.expression?$D(n.expression):ke;if(169===r.kind)n.expression&&gr(n,e.Diagnostics.Setters_cannot_return_a_value);else if(167===r.kind)n.expression&&!Y_(s,i,n,n.expression)&&gr(n,e.Diagnostics.Return_type_of_constructor_signature_must_be_assignable_to_the_instance_type_of_the_class);else if(Wu(r)){var c=null!==(t=iN(i,o))&&void 0!==t?t:i,l=2&o?_C(s,n,e.Diagnostics.The_return_type_of_an_async_function_must_either_be_a_valid_promise_or_must_not_contain_a_callable_then_member):s;c&&Y_(l,c,n,n.expression)}}else 167!==r.kind&&C.noImplicitReturns&&!oN(r,i)&&gr(n,e.Diagnostics.Not_all_code_paths_return_a_value)}else zO(n,e.Diagnostics.A_return_statement_can_only_be_used_within_a_function_body)}}function cN(n){tw(n)||32768&n.flags&&zO(n,e.Diagnostics.with_statements_are_not_allowed_in_an_async_function_block),TA(n.expression);var t=e.getSourceFileOfNode(n);if(!WO(t)){var r=e.getSpanOfTokenAtPosition(t,n.pos).start,a=n.statement.pos;qO(t,r,a-r,e.Diagnostics.The_with_statement_is_not_supported_All_symbols_in_a_with_block_will_have_type_any)}}function lN(n){var r;tw(n);var a=!1,i=TA(n.expression),o=Ey(i);e.forEach(n.caseBlock.clauses,(function(n){if(286!==n.kind||a||(void 0===r?r=n:(XO(n,e.Diagnostics.A_default_clause_cannot_appear_more_than_once_in_a_switch_statement),a=!0)),t&&285===n.kind){var s=TA(n.expression),c=Ey(s),l=i;c&&o||(s=c?Ty(s):s,l=Ty(i)),VD(l,s)||fg(s,l,n.expression,void 0)}e.forEach(n.statements,pk),C.noFallthroughCasesInSwitch&&n.fallthroughFlowNode&&Ab(n.fallthroughFlowNode)&&gr(n,e.Diagnostics.Fallthrough_case_in_switch)})),n.caseBlock.locals&&BC(n.caseBlock)}function uN(n){tw(n)||e.findAncestor(n.parent,(function(t){return e.isFunctionLike(t)?"quit":246===t.kind&&t.label.escapedText===n.label.escapedText&&(XO(n.label,e.Diagnostics.Duplicate_label_0,e.getTextOfNode(n.label)),!0)})),pk(n.statement)}function dN(n){tw(n)||e.isIdentifier(n.expression)&&!n.expression.escapedText&&ow(n,e.Diagnostics.Line_break_not_permitted_here),n.expression&&TA(n.expression)}function pN(n){tw(n),eI(n.tryBlock);var t=n.catchClause;if(t){if(t.variableDeclaration){var r=t.variableDeclaration,a=e.getEffectiveTypeAnnotationNode(e.getRootDeclaration(r));if(a){var i=zo(r,!1);!i||3&i.flags||zO(a,e.Diagnostics.Catch_clause_variable_type_annotation_must_be_any_or_unknown_if_specified)}else if(r.initializer)zO(r.initializer,e.Diagnostics.Catch_clause_variable_cannot_have_an_initializer);else{var o=t.block.locals;o&&e.forEachKey(t.locals,(function(n){var t=o.get(n);(null===t||void 0===t?void 0:t.valueDeclaration)&&0!==(2&t.flags)&&XO(t.valueDeclaration,e.Diagnostics.Cannot_redeclare_identifier_0_in_catch_clause,n)}))}}eI(t.block)}n.finallyBlock&&eI(n.finallyBlock)}function fN(n,t){var r,a,i,o,s,c=cd(t?null===(r=n.symbol)||void 0===r?void 0:r.exports:null===(a=n.symbol)||void 0===a?void 0:a.members,1),l=cd(t?null===(i=n.symbol)||void 0===i?void 0:i.exports:null===(o=n.symbol)||void 0===o?void 0:o.members,0),u=Eu(n,0),d=Eu(n,1);if(u||d){e.forEach(kl(n),(function(e){if(!(t&&4194304&e.flags)){var r=ws(e);v(e,r,n,l,u,0),v(e,r,n,c,d,1)}}));var p=n.symbol.valueDeclaration;if(1&e.getObjectFlags(n)&&p&&e.isClassLike(p))for(var f=0,m=p.members;f<m.length;f++){var _=m[f];if(!e.hasSyntacticModifier(_,32)&&!Ic(_)){var g=yi(_),y=ws(g);v(g,y,n,l,u,0),v(g,y,n,c,d,1)}}}if(u&&d&&(s=c||l,!s&&2&e.getObjectFlags(n))){var h=e.forEach(Qs(n),(function(e){return Eu(e,0)&&Eu(e,1)}));s=h||!n.symbol.declarations?void 0:n.symbol.declarations[0]}function v(n,t,r,a,i,o){if(i&&!e.isKnownSymbol(n)){var s=n.valueDeclaration,c=s&&e.getNameOfDeclaration(s);if((!c||!e.isPrivateIdentifier(c))&&(1!==o||(c?yT(c):bT(n.escapedName)))){var l;if(s&&c&&(217===s.kind||159===c.kind||n.parent===r.symbol))l=s;else if(a)l=a;else if(2&e.getObjectFlags(r)){var u=e.forEach(Qs(r),(function(e){return Rl(e,n.escapedName)&&Eu(e,o)}));l=u||!r.symbol.declarations?void 0:r.symbol.declarations[0]}if(l&&!W_(t,i)){var d=0===o?e.Diagnostics.Property_0_of_type_1_is_not_assignable_to_string_index_type_2:e.Diagnostics.Property_0_of_type_1_is_not_assignable_to_numeric_index_type_2;gr(l,d,ro(n),io(t),io(i))}}}}s&&!W_(d,u)&&gr(s,e.Diagnostics.Numeric_index_type_0_is_not_assignable_to_string_index_type_1,io(d),io(u))}function mN(e,n){switch(e.escapedText){case"any":case"unknown":case"never":case"number":case"bigint":case"boolean":case"string":case"symbol":case"void":case"object":gr(e,n,e.escapedText)}}function _N(n){1===F&&"Object"===n.escapedText&&G<e.ModuleKind.ES2015&&gr(n,e.Diagnostics.Class_name_cannot_be_Object_when_targeting_ES5_with_module_0,e.ModuleKind[G])}function gN(n){if(n)for(var r=!1,a=0;a<n.length;a++){var i=n[a];if(DA(i),t){i.default?(r=!0,yN(i.default,n,a)):r&&gr(i,e.Diagnostics.Required_type_parameters_may_not_follow_optional_type_parameters);for(var o=0;o<a;o++)n[o].symbol===i.symbol&&gr(i.name,e.Diagnostics.Duplicate_identifier_0,e.declarationNameToString(i.name))}}}function yN(n,t,r){function a(n){if(174===n.kind){var i=Ud(n);if(262144&i.flags)for(var o=r;o<t.length;o++)i.symbol===yi(t[o])&&gr(n,e.Diagnostics.Type_parameter_defaults_can_only_reference_previously_declared_type_parameters)}e.forEachChild(n,a)}a(n)}function hN(n){if(!n.declarations||1!==n.declarations.length){var t=wr(n);if(!t.typeParametersChecked){t.typeParametersChecked=!0;var r=CN(n);if(!r||r.length<=1)return;var a=mc(n);if(!vN(r,a.localTypeParameters))for(var i=ro(n),o=0,s=r;o<s.length;o++){var c=s[o];gr(c.name,e.Diagnostics.All_declarations_of_0_must_have_identical_type_parameters,i)}}}}function vN(n,t){for(var r=e.length(t),a=ku(t),i=0,o=n;i<o.length;i++){var s=o[i],c=e.getEffectiveTypeParameterDeclarations(s),l=c.length;if(l<a||l>r)return!1;for(var u=0;u<l;u++){var d=c[u],p=t[u];if(d.name.escapedText!==p.symbol.escapedName)return!1;var f=e.getEffectiveConstraintOfTypeParameter(d),m=f&&zm(f),_=Gl(p);if(m&&_&&!U_(m,_))return!1;var g=d.default&&zm(d.default),y=$l(p);if(g&&y&&!U_(g,y))return!1}}return!0}function bN(e){return SN(e),yk(e),ws(yi(e))}function EN(n){e.forEach(n.members,pk),BC(n)}function TN(n){e.some(n.decorators)&&e.some(n.members,(function(n){return e.hasStaticModifier(n)&&e.isPrivateIdentifierClassElementDeclaration(n)}))&&XO(n.decorators[0],e.Diagnostics.Class_decorators_can_t_be_used_with_static_private_identifier_Consider_removing_the_experimental_decorator),n.name||e.hasSyntacticModifier(n,512)||zO(n,e.Diagnostics.A_class_declaration_without_the_default_modifier_must_have_a_name),SN(n),e.forEach(n.members,pk),BC(n)}function SN(n){aO(n),AC(n),n.name&&(mN(n.name,e.Diagnostics.Class_name_cannot_be_0),oI(n,n.name),sI(n,n.name),8388608&n.flags||_N(n.name)),gN(e.getEffectiveTypeParameterDeclarations(n)),pC(n);var r=yi(n),a=mc(r),i=Fc(a),o=ws(r);hN(r),dC(r),RA(n);var s=!!(8388608&n.flags);s||OA(n);var c=e.getEffectiveBaseTypeNode(n);if(c){e.forEach(c.typeArguments,pk),F<2&&jR(c.parent,1);var l=e.getClassExtendsHeritageElement(n);l&&l!==c&&TA(l.expression);var u=Qs(a);if(u.length&&t){var d=u[0],p=Js(a),f=au(p);if(DN(f,c),pk(c.expression),e.some(c.typeArguments)){e.forEach(c.typeArguments,pk);for(var m=0,_=zs(f,c.typeArguments,c);m<_.length;m++){var g=_[m];if(!HA(c,g.typeParameters))break}}var y=Fc(d,a.thisType);if(X_(i,y,void 0)?X_(o,B_(f),n.name||n,e.Diagnostics.Class_static_side_0_incorrectly_extends_base_class_static_side_1):LN(n,i,y,e.Diagnostics.Class_0_incorrectly_extends_base_class_1),8650752&p.flags)if(Ks(o)){var h=yu(p,1);h.some((function(e){return 4&e.flags}))&&!e.hasSyntacticModifier(n,128)&&gr(n.name||n,e.Diagnostics.A_mixin_class_that_extends_from_a_type_variable_containing_an_abstract_construct_signature_must_also_be_declared_abstract)}else gr(n.name||n,e.Diagnostics.A_mixin_class_must_have_a_constructor_with_a_single_rest_parameter_of_type_any);if(!(f.symbol&&32&f.symbol.flags)&&!(8650752&p.flags)){var v=qs(f,c.typeArguments,c);e.forEach(v,(function(e){return!uL(e.declaration)&&!U_(Hu(e),d)}))&&gr(c.expression,e.Diagnostics.Base_constructors_must_all_have_the_same_return_type)}IN(a,d)}}xN(n,a,i,o);var b=e.getEffectiveImplementsTypeNodes(n);if(b)for(var E=0,T=b;E<T.length;E++){var S=T[E];if(e.isEntityNameExpression(S.expression)&&!e.isOptionalChain(S.expression)||gr(S.expression,e.Diagnostics.A_class_can_only_implement_an_identifier_Slashqualified_name_with_optional_type_arguments),zA(S),t){var x=lu(zm(S));if(x!==Ae)if(nc(x)){var L=x.symbol&&32&x.symbol.flags?e.Diagnostics.Class_0_incorrectly_implements_class_1_Did_you_mean_to_extend_1_and_inherit_its_members_as_a_subclass:e.Diagnostics.Class_0_incorrectly_implements_interface_1;y=Fc(x,a.thisType);X_(i,y,void 0)||LN(n,i,y,L)}else gr(S,e.Diagnostics.A_class_can_only_implement_an_object_type_or_intersection_of_object_types_with_statically_known_members)}}t&&(fN(a),fN(o,!0),PA(n),RN(n))}function xN(n,t,r,a){for(var i=!!(8388608&n.flags),o=e.getEffectiveBaseTypeNode(n),s=o&&Qs(t),c=(null===s||void 0===s?void 0:s.length)?Fc(e.first(s),t.thisType):void 0,l=Js(t),u=function(n){if(e.hasAmbientModifier(n))return"continue";e.isConstructorDeclaration(n)&&e.forEach(n.parameters,(function(t){e.isParameterPropertyDeclaration(t,n)&&m(t,!0)})),m(n)},d=0,p=n.members;d<p.length;d++){var f=p[d];u(f)}function m(n,o){var s=e.hasOverrideModifier(n),u=e.hasStaticModifier(n);if(c&&(s||C.noImplicitOverride)){var d=n.name&&jk(n.name)||jk(n);if(!d)return;var p=u?a:r,f=u?l:c,m=_u(p,d.escapedName),_=_u(f,d.escapedName),g=io(c);if(m&&!_&&s)gr(n,e.Diagnostics.This_member_cannot_have_an_override_modifier_because_it_is_not_declared_in_the_base_class_0,g);else if(m&&(null===_||void 0===_?void 0:_.valueDeclaration)&&C.noImplicitOverride&&!i){var y=e.hasAbstractModifier(_.valueDeclaration);if(s)return;if(y)e.hasAbstractModifier(n)&&y&&gr(n,e.Diagnostics.This_member_must_have_an_override_modifier_because_it_overrides_an_abstract_method_that_is_declared_in_the_base_class_0,g);else{var h=o?e.Diagnostics.This_parameter_property_must_have_an_override_modifier_because_it_overrides_a_member_in_base_class_0:e.Diagnostics.This_member_must_have_an_override_modifier_because_it_overrides_a_member_in_the_base_class_0;gr(n,h,g)}}}else if(s){var v=io(t);gr(n,e.Diagnostics.This_member_cannot_have_an_override_modifier_because_its_containing_class_0_does_not_extend_another_class,v)}}}function LN(n,t,r,a){for(var i=!1,o=function(n){if(e.hasStaticModifier(n))return"continue";var a=n.name&&jk(n.name)||jk(n);if(a){var o=_u(t,a.escapedName),s=_u(r,a.escapedName);if(o&&s){var c=function(){return e.chainDiagnosticMessages(void 0,e.Diagnostics.Property_0_in_type_1_is_not_assignable_to_the_same_property_in_base_type_2,ro(a),io(t),io(r))};X_(ws(o),ws(s),n.name||n,void 0,c)||(i=!0)}}},s=0,c=n.members;s<c.length;s++){var l=c[s];o(l)}i||X_(t,r,n.name||n,a)}function DN(n,t){var r=yu(n,1);if(r.length){var a=r[0].declaration;if(a&&e.hasEffectiveModifier(a,8)){var i=e.getClassLikeDeclarationOfSymbol(n.symbol);Mk(t,i)||gr(t,e.Diagnostics.Cannot_extend_a_class_0_Class_constructor_is_marked_as_private,za(n.symbol))}}}function AN(n){return 1&e.getCheckFlags(n)?n.target:n}function CN(n){return e.filter(n.declarations,(function(e){return 253===e.kind||254===e.kind}))}function IN(n,t){var r,a,i=wl(t);e:for(var o=0,s=i;o<s.length;o++){var c=s[o],l=AN(c);if(!(4194304&l.flags)){var u=Rl(n,l.escapedName);if(u){var d=AN(u),p=e.getDeclarationModifierFlagsFromSymbol(l);if(e.Debug.assert(!!d,"derived should point to something, even if it is the base class' declaration."),d===l){var f=e.getClassLikeDeclarationOfSymbol(n.symbol);if(128&p&&(!f||!e.hasSyntacticModifier(f,128))){for(var m=0,_=Qs(n);m<_.length;m++){var g=_[m];if(g!==t){var y=Rl(g,l.escapedName),h=y&&AN(y);if(h&&h!==l)continue e}}222===f.kind?gr(f,e.Diagnostics.Non_abstract_class_expression_does_not_implement_inherited_abstract_member_0_from_class_1,ro(c),io(t)):gr(f,e.Diagnostics.Non_abstract_class_0_does_not_implement_inherited_abstract_member_1_from_class_2,io(n),ro(c),io(t))}}else{var v=e.getDeclarationModifierFlagsFromSymbol(d);if(8&p||8&v)continue;var b=void 0,E=98308&l.flags,T=98308&d.flags;if(E&&T){if(128&p&&!(l.valueDeclaration&&e.isPropertyDeclaration(l.valueDeclaration)&&l.valueDeclaration.initializer)||l.valueDeclaration&&254===l.valueDeclaration.parent.kind||d.valueDeclaration&&e.isBinaryExpression(d.valueDeclaration))continue;var S=4!==E&&4===T,x=4===E&&4!==T;if(S||x){var L=S?e.Diagnostics._0_is_defined_as_an_accessor_in_class_1_but_is_overridden_here_in_2_as_an_instance_property:e.Diagnostics._0_is_defined_as_a_property_in_class_1_but_is_overridden_here_in_2_as_an_accessor;gr(e.getNameOfDeclaration(d.valueDeclaration)||d.valueDeclaration,L,ro(l),io(t),io(n))}else if(H){var D=null===(r=d.declarations)||void 0===r?void 0:r.find((function(e){return 164===e.kind&&!e.initializer}));if(D&&!(33554432&d.flags)&&!(128&p)&&!(128&v)&&!(null===(a=d.declarations)||void 0===a?void 0:a.some((function(e){return!!(8388608&e.flags)})))){var A=Ai(e.getClassLikeDeclarationOfSymbol(n.symbol)),C=D.name;if(D.exclamationToken||!A||!e.isIdentifier(C)||!z||!wN(C,n,A)){var I=e.Diagnostics.Property_0_will_overwrite_the_base_property_in_1_If_this_is_intentional_add_an_initializer_Otherwise_add_a_declare_modifier_or_remove_the_redundant_declaration;gr(e.getNameOfDeclaration(d.valueDeclaration)||d.valueDeclaration,I,ro(l),io(t))}}}continue}if(sS(l)){if(sS(d)||4&d.flags)continue;e.Debug.assert(!!(98304&d.flags)),b=e.Diagnostics.Class_0_defines_instance_member_function_1_but_extended_class_2_defines_it_as_instance_member_accessor}else b=98304&l.flags?e.Diagnostics.Class_0_defines_instance_member_accessor_1_but_extended_class_2_defines_it_as_instance_member_function:e.Diagnostics.Class_0_defines_instance_member_property_1_but_extended_class_2_defines_it_as_instance_member_function;gr(e.getNameOfDeclaration(d.valueDeclaration)||d.valueDeclaration,b,io(t),ro(l),io(n))}}}}}function NN(n,t,r){if(!e.length(t))return r;var a=new e.Map;e.forEach(r,(function(e){a.set(e.escapedName,e)}));for(var i=0,o=t;i<o.length;i++)for(var s=o[i],c=wl(Fc(s,n.thisType)),l=0,u=c;l<u.length;l++){var d=u[l],p=a.get(d.escapedName);p&&!Zg(p,d)&&a.delete(d.escapedName)}return e.arrayFrom(a.values())}function kN(n,t){var r=Qs(n);if(r.length<2)return!0;var a=new e.Map;e.forEach(xc(n).declaredProperties,(function(e){a.set(e.escapedName,{prop:e,containingType:n})}));for(var i=!0,o=0,s=r;o<s.length;o++)for(var c=s[o],l=wl(Fc(c,n.thisType)),u=0,d=l;u<d.length;u++){var p=d[u],f=a.get(p.escapedName);if(f){var m=f.containingType!==n;if(m&&!Zg(f.prop,p)){i=!1;var _=io(f.containingType),g=io(c),y=e.chainDiagnosticMessages(void 0,e.Diagnostics.Named_property_0_of_types_1_and_2_are_not_identical,ro(p),_,g);y=e.chainDiagnosticMessages(y,e.Diagnostics.Interface_0_cannot_simultaneously_extend_types_1_and_2,io(n),_,g),nr.add(e.createDiagnosticForNodeFromMessageChain(t,y))}}else a.set(p.escapedName,{prop:p,containingType:c})}return i}function RN(n){if(z&&X&&!(8388608&n.flags))for(var t=Ai(n),r=0,a=n.members;r<a.length;r++){var i=a[r];if(!(2&e.getEffectiveModifierFlags(i))&&ON(i)){var o=i.name;if(e.isIdentifier(o)||e.isPrivateIdentifier(o)){var s=ws(yi(i));3&s.flags||32768&Fy(s)||t&&wN(o,s,t)||gr(i.name,e.Diagnostics.Property_0_has_no_initializer_and_is_not_definitely_assigned_in_the_constructor,e.declarationNameToString(o))}}}}function ON(n){return 164===n.kind&&!e.hasSyntacticModifier(n,160)&&!n.exclamationToken&&!n.initializer}function wN(n,t,r){var a=e.factory.createPropertyAccessExpression(e.factory.createThis(),n);e.setParent(a.expression,a),e.setParent(a,r),a.flowNode=r.returnFlowNode;var i=kb(a,t,jy(t));return!(32768&Fy(i))}function PN(n){if(WR(n)||gO(n),gN(n.typeParameters),t){mN(n.name,e.Diagnostics.Interface_name_cannot_be_0),pC(n);var r=yi(n);hN(r);var a=e.getDeclarationOfKind(r,254);if(n===a){var i=mc(r),o=Fc(i);if(kN(i,n.name)){for(var s=0,c=Qs(i);s<c.length;s++){var l=c[s];X_(o,Fc(l,i.thisType),n.name,e.Diagnostics.Interface_0_incorrectly_extends_interface_1)}fN(i)}}wA(n)}e.forEach(e.getInterfaceBaseTypeNodes(n),(function(n){e.isEntityNameExpression(n.expression)&&!e.isOptionalChain(n.expression)||gr(n.expression,e.Diagnostics.An_interface_can_only_extend_an_identifier_Slashqualified_name_with_optional_type_arguments),zA(n)})),e.forEach(n.members,pk),t&&(PA(n),BC(n))}function MN(n){WR(n),mN(n.name,e.Diagnostics.Type_alias_name_cannot_be_0),pC(n),gN(n.typeParameters),136===n.type.kind?k.has(n.name.escapedText)&&1===e.length(n.typeParameters)||gr(n.type,e.Diagnostics.The_intrinsic_keyword_can_only_be_used_to_declare_compiler_provided_intrinsic_types):(pk(n.type),BC(n))}function FN(e){var n=Pr(e);if(!(16384&n.flags)){n.flags|=16384;for(var t=0,r=0,a=e.members;r<a.length;r++){var i=a[r],o=GN(i,t);Pr(i).enumMemberValue=o,t="number"===typeof o?o+1:void 0}}}function GN(n,t){if(e.isComputedNonLiteralName(n.name))gr(n.name,e.Diagnostics.Computed_property_names_are_not_allowed_in_enums);else{var r=e.getTextOfPropertyName(n.name);bT(r)&&!vT(r)&&gr(n.name,e.Diagnostics.An_enum_member_cannot_have_a_numeric_name)}return n.initializer?BN(n):8388608&n.parent.flags&&!e.isEnumConst(n.parent)&&0===cc(yi(n.parent))?void 0:void 0!==t?t:void gr(n.name,e.Diagnostics.Enum_member_must_have_initializer)}function BN(n){var t=cc(yi(n.parent)),r=e.isEnumConst(n.parent),a=n.initializer,i=1!==t||sc(n)?s(a):void 0;if(void 0!==i)r&&"number"===typeof i&&!isFinite(i)&&gr(a,isNaN(i)?e.Diagnostics.const_enum_member_initializer_was_evaluated_to_disallowed_value_NaN:e.Diagnostics.const_enum_member_initializer_was_evaluated_to_a_non_finite_value);else{if(1===t)return gr(a,e.Diagnostics.Computed_values_are_not_permitted_in_an_enum_with_string_valued_members),0;if(r)gr(a,e.Diagnostics.const_enum_member_initializers_can_only_contain_literal_values_and_other_computed_enum_values);else if(8388608&n.parent.flags)gr(a,e.Diagnostics.In_ambient_enum_declarations_member_initializer_must_be_constant_expression);else{var o=TA(a);CD(o,296)?X_(o,mc(yi(n.parent)),a,void 0):gr(a,e.Diagnostics.Only_numeric_enums_can_have_computed_members_but_this_expression_has_type_0_If_you_do_not_need_exhaustiveness_checks_consider_using_an_object_literal_instead,io(o))}}return i;function s(t){switch(t.kind){case 215:var r=s(t.operand);if("number"===typeof r)switch(t.operator){case 39:return r;case 40:return-r;case 54:return~r}break;case 217:var a=s(t.left),i=s(t.right);if("number"===typeof a&&"number"===typeof i)switch(t.operatorToken.kind){case 51:return a|i;case 50:return a&i;case 48:return a>>i;case 49:return a>>>i;case 47:return a<<i;case 52:return a^i;case 41:return a*i;case 43:return a/i;case 39:return a+i;case 40:return a-i;case 44:return a%i;case 42:return Math.pow(a,i)}else if("string"===typeof a&&"string"===typeof i&&39===t.operatorToken.kind)return a+i;break;case 10:case 14:return t.text;case 8:return rw(t),+t.text;case 208:return s(t.expression);case 78:var o=t;return vT(o.escapedText)?+o.escapedText:e.nodeIsMissing(t)?0:c(t,yi(n.parent),o.escapedText);case 203:case 202:var l=t;if(UN(l)){var u=vA(l.expression);if(u.symbol&&384&u.symbol.flags){var d=void 0;return d=202===l.kind?l.name.escapedText:e.escapeLeadingUnderscores(e.cast(l.argumentExpression,e.isLiteralExpression).text),c(t,u.symbol,d)}}break}}function c(t,r,a){var i=r.exports.get(a);if(i){var o=i.valueDeclaration;if(o!==n)return o&&Br(o,n)?SR(o):(gr(t,e.Diagnostics.A_member_initializer_in_a_enum_declaration_cannot_reference_members_declared_after_it_including_members_defined_in_other_enums),0);gr(t,e.Diagnostics.Property_0_is_used_before_being_assigned,ro(i))}}}function UN(n){return 78===n.kind||202===n.kind&&UN(n.expression)||203===n.kind&&UN(n.expression)&&e.isStringLiteralLike(n.argumentExpression)}function VN(n){if(t){WR(n),mN(n.name,e.Diagnostics.Enum_name_cannot_be_0),oI(n,n.name),sI(n,n.name),pC(n),n.members.forEach(jN),FN(n);var r=yi(n),a=e.getDeclarationOfKind(r,n.kind);if(n===a){if(r.declarations&&r.declarations.length>1){var i=e.isEnumConst(n);e.forEach(r.declarations,(function(n){e.isEnumDeclaration(n)&&e.isEnumConst(n)!==i&&gr(e.getNameOfDeclaration(n),e.Diagnostics.Enum_declarations_must_all_be_const_or_non_const)}))}var o=!1;e.forEach(r.declarations,(function(n){if(256!==n.kind)return!1;var t=n;if(!t.members.length)return!1;var r=t.members[0];r.initializer||(o?gr(r.name,e.Diagnostics.In_an_enum_with_multiple_declarations_only_one_declaration_can_omit_an_initializer_for_its_first_enum_element):o=!0)}))}}}function jN(n){e.isPrivateIdentifier(n.name)&&gr(n,e.Diagnostics.An_enum_member_cannot_be_named_with_a_private_identifier)}function KN(n){var t=n.declarations;if(t)for(var r=0,a=t;r<a.length;r++){var i=a[r];if((253===i.kind||252===i.kind&&e.nodeIsPresent(i.body))&&!(8388608&i.flags))return i}}function HN(n,t){var r=e.getEnclosingBlockScopeContainer(n),a=e.getEnclosingBlockScopeContainer(t);return Mr(r)?Mr(a):!Mr(a)&&r===a}function WN(n){if(t){var r=e.isGlobalScopeAugmentation(n),a=8388608&n.flags;r&&!a&&gr(n.name,e.Diagnostics.Augmentations_for_the_global_scope_should_have_declare_modifier_unless_they_appear_in_already_ambient_context);var i=e.isAmbientModule(n),o=i?e.Diagnostics.An_ambient_module_declaration_is_only_allowed_at_the_top_level_in_a_file:e.Diagnostics.A_namespace_declaration_is_only_allowed_in_a_namespace_or_module;if(nk(n,o))return;WR(n)||a||10!==n.name.kind||XO(n.name,e.Diagnostics.Only_ambient_modules_can_use_quoted_names),e.isIdentifier(n.name)&&(oI(n,n.name),sI(n,n.name)),pC(n);var s=yi(n);if(512&s.flags&&!a&&s.declarations&&s.declarations.length>1&&M(n,e.shouldPreserveConstEnums(C))){var c=KN(s);c&&(e.getSourceFileOfNode(n)!==e.getSourceFileOfNode(c)?gr(n.name,e.Diagnostics.A_namespace_declaration_cannot_be_in_a_different_file_from_a_class_or_function_with_which_it_is_merged):n.pos<c.pos&&gr(n.name,e.Diagnostics.A_namespace_declaration_cannot_be_located_prior_to_a_class_or_function_with_which_it_is_merged));var l=e.getDeclarationOfKind(s,253);l&&HN(n,l)&&(Pr(n).flags|=32768)}if(i)if(e.isExternalModuleAugmentation(n)){var u=r||33554432&yi(n).flags;if(u&&n.body)for(var d=0,p=n.body.statements;d<p.length;d++){var f=p[d];zN(f,r)}}else Mr(n.parent)?r?gr(n.name,e.Diagnostics.Augmentations_for_the_global_scope_can_only_be_directly_nested_in_external_modules_or_ambient_module_declarations):e.isExternalModuleNameRelative(e.getTextOfIdentifierOrLiteral(n.name))&&gr(n.name,e.Diagnostics.Ambient_module_declaration_cannot_specify_relative_module_name):gr(n.name,r?e.Diagnostics.Augmentations_for_the_global_scope_can_only_be_directly_nested_in_external_modules_or_ambient_module_declarations:e.Diagnostics.Ambient_modules_cannot_be_nested_in_other_modules_or_namespaces)}n.body&&(pk(n.body),e.isGlobalScopeAugmentation(n)||BC(n))}function zN(n,t){var r;switch(n.kind){case 233:for(var a=0,i=n.declarationList.declarations;a<i.length;a++){var o=i[a];zN(o,t)}break;case 267:case 268:zO(n,e.Diagnostics.Exports_and_export_assignments_are_not_permitted_in_module_augmentations);break;case 261:case 262:zO(n,e.Diagnostics.Imports_are_not_permitted_in_module_augmentations_Consider_moving_them_to_the_enclosing_external_module);break;case 199:case 250:var s=n.name;if(e.isBindingPattern(s)){for(var c=0,l=s.elements;c<l.length;c++){var u=l[c];zN(u,t)}break}case 253:case 256:case 252:case 254:case 257:case 255:if(t)return;var d=yi(n);if(d){var p=!(33554432&d.flags);p||(p=!!(null===(r=d.parent)||void 0===r?void 0:r.declarations)&&e.isExternalModuleAugmentation(d.parent.declarations[0]))}break}}function qN(n){switch(n.kind){case 78:return n;case 158:do{n=n.left}while(78!==n.kind);return n;case 202:do{if(e.isModuleExportsAccessExpression(n.expression)&&!e.isPrivateIdentifier(n.name))return n.name;n=n.expression}while(78!==n.kind);return n}}function JN(n){var t=e.getExternalModuleName(n);if(!t||e.nodeIsMissing(t))return!1;if(!e.isStringLiteral(t))return gr(t,e.Diagnostics.String_literal_expected),!1;var r=258===n.parent.kind&&e.isAmbientModule(n.parent.parent);return 298===n.parent.kind||r?!(r&&e.isExternalModuleNameRelative(t.text)&&!yo(n))||(gr(n,e.Diagnostics.Import_or_export_declaration_in_an_ambient_module_declaration_cannot_reference_module_through_relative_module_name),!1):(gr(t,268===n.kind?e.Diagnostics.Export_declarations_are_not_permitted_in_a_namespace:e.Diagnostics.Import_declarations_in_a_namespace_cannot_reference_a_module),!1)}function XN(n){var t,r=yi(n),a=Fa(r);if(a!==Te){r=gi(r.exportSymbol||r);var i=(1160127&r.flags?111551:0)|(788968&r.flags?788968:0)|(1920&r.flags?1920:0);if(a.flags&i){var o=271===n.kind?e.Diagnostics.Export_declaration_conflicts_with_exported_declaration_of_0:e.Diagnostics.Import_declaration_conflicts_with_local_declaration_of_0;gr(n,o,ro(r))}!C.isolatedModules||271!==n.kind||n.parent.parent.isTypeOnly||111551&a.flags||8388608&n.flags||gr(n,e.Diagnostics.Re_exporting_a_type_when_the_isolatedModules_flag_is_provided_requires_using_export_type),e.isImportSpecifier(n)&&(null===(t=a.declarations)||void 0===t?void 0:t.every((function(n){return!!(134217728&e.getCombinedNodeFlags(n))})))&&Er(n.name,a.declarations,r.escapedName)}}function YN(n){oI(n,n.name),sI(n,n.name),XN(n),266===n.kind&&"default"===e.idText(n.propertyName||n.name)&&C.esModuleInterop&&G!==e.ModuleKind.System&&G<e.ModuleKind.ES2015&&jR(n,131072)}function QN(n){if(!nk(n,e.Diagnostics.An_import_declaration_can_only_be_used_in_a_namespace_or_module)&&(!WR(n)&&e.hasEffectiveModifiers(n)&&zO(n,e.Diagnostics.An_import_declaration_cannot_have_modifiers),JN(n))){var t=n.importClause;if(t&&!cw(t)&&(t.name&&YN(t),t.namedBindings))if(264===t.namedBindings.kind)YN(t.namedBindings),G!==e.ModuleKind.System&&G<e.ModuleKind.ES2015&&C.esModuleInterop&&jR(n,65536);else{var r=Za(n,n.moduleSpecifier);r&&e.forEach(t.namedBindings.elements,YN)}}}function ZN(n){if(!nk(n,e.Diagnostics.An_import_declaration_can_only_be_used_in_a_namespace_or_module)&&(WR(n),e.isInternalModuleImportEqualsDeclaration(n)||JN(n)))if(YN(n),e.hasSyntacticModifier(n,1)&&ja(n),273!==n.moduleReference.kind){var t=Fa(yi(n));if(t!==Te){if(111551&t.flags){var r=e.getFirstIdentifier(n.moduleReference);1920&qa(r,112575).flags||gr(r,e.Diagnostics.Module_0_is_hidden_by_a_local_declaration_with_the_same_name,e.declarationNameToString(r))}788968&t.flags&&mN(n.name,e.Diagnostics.Import_name_cannot_be_0)}n.isTypeOnly&&XO(n,e.Diagnostics.An_import_alias_cannot_use_import_type)}else!(G>=e.ModuleKind.ES2015)||n.isTypeOnly||8388608&n.flags||XO(n,e.Diagnostics.Import_assignment_cannot_be_used_when_targeting_ECMAScript_modules_Consider_using_import_Asterisk_as_ns_from_mod_import_a_from_mod_import_d_from_mod_or_another_module_format_instead)}function $N(n){if(!nk(n,e.Diagnostics.An_export_declaration_can_only_be_used_in_a_module)&&(!WR(n)&&e.hasEffectiveModifiers(n)&&zO(n,e.Diagnostics.An_export_declaration_cannot_have_modifiers),n.moduleSpecifier&&n.exportClause&&e.isNamedExports(n.exportClause)&&e.length(n.exportClause.elements)&&0===F&&jR(n,2097152),ek(n),!n.moduleSpecifier||JN(n)))if(n.exportClause&&!e.isNamespaceExport(n.exportClause)){e.forEach(n.exportClause.elements,sk);var t=258===n.parent.kind&&e.isAmbientModule(n.parent.parent),r=!t&&258===n.parent.kind&&!n.moduleSpecifier&&8388608&n.flags;298===n.parent.kind||t||r||gr(n,e.Diagnostics.Export_declarations_are_not_permitted_in_a_namespace)}else{var a=Za(n,n.moduleSpecifier);a&&oi(a)?gr(n.moduleSpecifier,e.Diagnostics.Module_0_uses_export_and_cannot_be_used_with_export_Asterisk,ro(a)):n.exportClause&&XN(n.exportClause),G!==e.ModuleKind.System&&G<e.ModuleKind.ES2015&&(n.exportClause?C.esModuleInterop&&jR(n,65536):jR(n,32768))}}function ek(n){var t,r=n.isTypeOnly&&269!==(null===(t=n.exportClause)||void 0===t?void 0:t.kind);return r&&XO(n,e.Diagnostics.Only_named_exports_may_use_export_type),!r}function nk(e,n){var t=298===e.parent.kind||258===e.parent.kind||257===e.parent.kind;return t||zO(e,n),!t}function tk(n){return e.forEachImportClauseDeclaration(n,(function(e){return!!yi(e).isReferenced}))}function rk(n){return e.forEachImportClauseDeclaration(n,(function(e){return!!wr(yi(e)).constEnumReferenced}))}function ak(n){return e.isImportDeclaration(n)&&n.importClause&&!n.importClause.isTypeOnly&&tk(n.importClause)&&!_R(n.importClause,!0)&&!rk(n.importClause)}function ik(n){return e.isImportEqualsDeclaration(n)&&e.isExternalModuleReference(n.moduleReference)&&!n.isTypeOnly&&yi(n).isReferenced&&!_R(n,!1)&&!wr(yi(n)).constEnumReferenced}function ok(n){for(var t=0,r=n.statements;t<r.length;t++){var a=r[t];(ak(a)||ik(a))&&gr(a,e.Diagnostics.This_import_is_never_used_as_a_value_and_must_use_import_type_because_importsNotUsedAsValues_is_set_to_error)}}function sk(n){if(XN(n),e.getEmitDeclarations(C)&&To(n.propertyName||n.name,!0),n.parent.parent.moduleSpecifier)C.esModuleInterop&&G!==e.ModuleKind.System&&G<e.ModuleKind.ES2015&&"default"===e.idText(n.propertyName||n.name)&&jR(n,131072);else{var t=n.propertyName||n.name,r=Vr(t,t.escapedText,2998271,void 0,void 0,!0);if(r&&(r===ae||r===ie||r.declarations&&Mr(Ao(r.declarations[0]))))gr(t,e.Diagnostics.Cannot_export_0_Only_local_declarations_can_be_exported_from_a_module,e.idText(t));else{ja(n);var a=r&&(2097152&r.flags?Fa(r):r);(!a||a===Te||111551&a.flags)&&$D(n.propertyName||n.name)}}}function ck(n){var t=n.isExportEquals?e.Diagnostics.An_export_assignment_must_be_at_the_top_level_of_a_file_or_module_declaration:e.Diagnostics.A_default_export_must_be_at_the_top_level_of_a_file_or_module_declaration;if(!nk(n,t)){var r=298===n.parent.kind?n.parent:n.parent.parent;if(257!==r.kind||e.isAmbientModule(r)){if(!WR(n)&&e.hasEffectiveModifiers(n)&&zO(n,e.Diagnostics.An_export_assignment_cannot_have_modifiers),78===n.expression.kind){var a=n.expression,i=qa(a,67108863,!0,!0,n);if(i){Wb(i,a);var o=2097152&i.flags?Fa(i):i;(o===Te||111551&o.flags)&&$D(n.expression)}else $D(n.expression);e.getEmitDeclarations(C)&&To(n.expression,!0)}else $D(n.expression);uk(r),8388608&n.flags&&!e.isEntityNameExpression(n.expression)&&XO(n.expression,e.Diagnostics.The_expression_of_an_export_assignment_must_be_an_identifier_or_qualified_name_in_an_ambient_context),!n.isExportEquals||8388608&n.flags||(G>=e.ModuleKind.ES2015?XO(n,e.Diagnostics.Export_assignment_cannot_be_used_when_targeting_ECMAScript_modules_Consider_using_export_default_or_another_module_format_instead):G===e.ModuleKind.System&&XO(n,e.Diagnostics.Export_assignment_is_not_supported_when_module_flag_is_system))}else n.isExportEquals?gr(n,e.Diagnostics.An_export_assignment_cannot_be_used_in_a_namespace):gr(n,e.Diagnostics.A_default_export_can_only_be_used_in_an_ECMAScript_style_module)}}function lk(n){return e.forEachEntry(n.exports,(function(e,n){return"export="!==n}))}function uk(n){var t=yi(n),r=wr(t);if(!r.exportsChecked){var a=t.exports.get("export=");if(a&&lk(t)){var i=ca(a)||a.valueDeclaration;!i||yo(i)||e.isInJSFile(i)||gr(i,e.Diagnostics.An_export_assignment_cannot_be_used_in_a_module_with_other_exported_elements)}var o=fi(t);o&&o.forEach((function(n,t){var r=n.declarations,a=n.flags;if("__export"!==t&&!(1984&a)){var i=e.countWhere(r,I);if(!(524288&a&&i<=2)&&i>1&&!dk(r))for(var o=0,s=r;o<s.length;o++){var c=s[o];B(c)&&nr.add(e.createDiagnosticForNode(c,e.Diagnostics.Cannot_redeclare_exported_variable_0,e.unescapeLeadingUnderscores(t)))}}})),r.exportsChecked=!0}}function dk(n){return n&&n.length>1&&n.every((function(n){return e.isInJSFile(n)&&e.isAccessExpression(n)&&(e.isExportsIdentifier(n.expression)||e.isModuleExportsAccessExpression(n.expression))}))}function pk(e){if(e){var n=d;d=e,T=0,fk(e),d=n}}function fk(n){e.isInJSFile(n)&&e.forEach(n.jsDoc,(function(n){var t=n.tags;return e.forEach(t,pk)}));var t=n.kind;if(r)switch(t){case 257:case 253:case 254:case 252:r.throwIfCancellationRequested()}switch(t>=233&&t<=249&&n.flowNode&&!Ab(n.flowNode)&&hr(!1===C.allowUnreachableCode,n,e.Diagnostics.Unreachable_code_detected),t){case 160:return DA(n);case 161:return AA(n);case 164:return MA(n);case 163:return FA(n);case 176:case 175:case 170:case 171:case 172:return kA(n);case 166:case 165:return GA(n);case 167:return UA(n);case 168:case 169:return VA(n);case 174:return zA(n);case 173:return CA(n);case 177:return JA(n);case 178:return XA(n);case 179:return YA(n);case 180:return QA(n);case 183:case 184:return ZA(n);case 187:case 181:case 182:return pk(n.type);case 188:return tC(n);case 189:return rC(n);case 185:return aC(n);case 186:return iC(n);case 194:return oC(n);case 196:return sC(n);case 193:return cC(n);case 318:return MC(n);case 319:return PC(n);case 335:case 328:case 329:return IC(n);case 334:return NC(n);case 333:return kC(n);case 330:return RC(n);case 337:return OC(n);case 309:wC(n);case 307:case 306:case 304:case 305:case 314:return mk(n),void e.forEachChild(n,pk);case 310:return void _k(n);case 302:return pk(n.type);case 190:return eC(n);case 191:return nC(n);case 252:return CC(n);case 231:case 258:return eI(n);case 233:return _I(n);case 234:return gI(n);case 235:return yI(n);case 236:return EI(n);case 237:return TI(n);case 238:return LI(n);case 239:return AI(n);case 240:return DI(n);case 241:case 242:return aN(n);case 243:return sN(n);case 244:return cN(n);case 245:return lN(n);case 246:return uN(n);case 247:return dN(n);case 248:return pN(n);case 250:return fI(n);case 199:return mI(n);case 253:return TN(n);case 254:return PN(n);case 255:return MN(n);case 256:return VN(n);case 257:return WN(n);case 262:return QN(n);case 261:return ZN(n);case 268:return $N(n);case 267:return ck(n);case 232:case 249:return void tw(n);case 272:return jA(n)}}function mk(n){e.isInJSFile(n)||XO(n,e.Diagnostics.JSDoc_types_can_only_be_used_inside_documentation_comments)}function _k(n){mk(n),pk(n.type);var t=n.parent;if(e.isParameter(t)&&e.isJSDocFunctionType(t.parent))e.last(t.parent.parameters)!==t&&gr(n,e.Diagnostics.A_rest_parameter_must_be_last_in_a_parameter_list);else{e.isJSDocTypeExpression(t)||gr(n,e.Diagnostics.JSDoc_may_only_appear_in_the_last_parameter_of_a_signature);var r=n.parent.parent;if(e.isJSDocParameterTag(r)){var a=e.getParameterSymbolFromJSDoc(r);if(a){var i=e.getHostSignatureFromJSDoc(r);i&&e.last(i.parameters).symbol===a||gr(n,e.Diagnostics.A_rest_parameter_must_be_last_in_a_parameter_list)}}else gr(n,e.Diagnostics.JSDoc_may_only_appear_in_the_last_parameter_of_a_signature)}}function gk(n){var t=zm(n.type),r=n.parent,a=n.parent.parent;if(e.isJSDocTypeExpression(n.parent)&&e.isJSDocParameterTag(a)){var i=e.getHostSignatureFromJSDoc(a),o=e.isJSDocCallbackTag(a.parent.parent);if(i||o){var s=o?e.lastOrUndefined(a.parent.parent.typeExpression.parameters):e.lastOrUndefined(i.parameters),c=e.getParameterSymbolFromJSDoc(a);if(!s||c&&s.symbol===c&&e.isRestParameter(s))return Ep(t)}}return e.isParameter(r)&&e.isJSDocFunctionType(r.parent)?Ep(t):Wo(t)}function yk(n){var t=e.getSourceFileOfNode(n),r=Pr(t);if(!(1&r.flags)){r.deferredNodes=r.deferredNodes||new e.Map;var a=w(n);r.deferredNodes.set(a,n)}}function hk(e){var n=Pr(e);n.deferredNodes&&n.deferredNodes.forEach(vk)}function vk(n){null===e.tracing||void 0===e.tracing||e.tracing.push("check","checkDeferredNode",{kind:n.kind,pos:n.pos,end:n.end});var t=d;switch(d=n,T=0,n.kind){case 204:case 205:case 206:case 162:case 276:ix(n);break;case 209:case 210:case 166:case 165:fD(n);break;case 168:case 169:VA(n);break;case 222:EN(n);break;case 275:AT(n);break;case 274:IT(n);break}d=t,null===e.tracing||void 0===e.tracing||e.tracing.pop()}function bk(n){null===e.tracing||void 0===e.tracing||e.tracing.push("check","checkSourceFile",{path:n.path},!0),e.performance.mark("beforeCheck"),Sk(n),e.performance.mark("afterCheck"),e.performance.measure("Check","beforeCheck","afterCheck"),null===e.tracing||void 0===e.tracing||e.tracing.pop()}function Ek(n,t){if(t)return!1;switch(n){case 0:return!!C.noUnusedLocals;case 1:return!!C.noUnusedParameters;default:return e.Debug.assertNever(n)}}function Tk(n){return Dt.get(n.path)||e.emptyArray}function Sk(t){var r=Pr(t);if(!(1&r.flags)){if(e.skipTypeChecking(t,C,n))return;nw(t),e.clear(Qt),e.clear(Zt),e.clear($t),e.forEach(t.statements,pk),pk(t.endOfFileToken),hk(t),e.isExternalOrCommonJsModule(t)&&BC(t),t.isDeclarationFile||!C.noUnusedLocals&&!C.noUnusedParameters||UC(Tk(t),(function(n,t,r){!e.containsParseError(n)&&Ek(t,!!(8388608&n.flags))&&nr.add(r)})),2===C.importsNotUsedAsValues&&!t.isDeclarationFile&&e.isExternalModule(t)&&ok(t),e.isExternalOrCommonJsModule(t)&&uk(t),Qt.length&&(e.forEach(Qt,rI),e.clear(Qt)),Zt.length&&(e.forEach(Zt,aI),e.clear(Zt)),$t.length&&(e.forEach($t,iI),e.clear($t)),r.flags|=1}}function xk(e,n){try{return r=n,Lk(e)}finally{r=void 0}}function Lk(t){if(Ak(),t){var r=nr.getGlobalDiagnostics(),a=r.length;bk(t);var i=nr.getDiagnostics(t.fileName),o=nr.getGlobalDiagnostics();if(o!==r){var s=e.relativeComplement(r,o,e.compareDiagnostics);return e.concatenate(s,i)}return 0===a&&o.length>0?e.concatenate(o,i):i}return e.forEach(n.getSourceFiles(),bk),nr.getDiagnostics()}function Dk(){return Ak(),nr.getGlobalDiagnostics()}function Ak(){if(!t)throw new Error("Trying to get diagnostics from a type checker that does not produce them.")}function Ck(n,t){if(16777216&n.flags)return[];var r=e.createSymbolTable(),a=!1;return i(),r.delete("this"),xu(r);function i(){while(n){switch(n.locals&&!Mr(n)&&s(n.locals,t),n.kind){case 298:if(!e.isExternalModule(n))break;case 257:c(yi(n).exports,2623475&t);break;case 256:s(yi(n).exports,8&t);break;case 222:var r=n.name;r&&o(n.symbol,t);case 253:case 254:a||s(Pc(yi(n)),788968&t);break;case 209:var i=n.name;i&&o(n.symbol,t);break}e.introducesArgumentsExoticObject(n)&&o(se,t),a=e.hasSyntacticModifier(n,32),n=n.parent}s(re,t)}function o(n,t){if(e.getCombinedLocalAndExportSymbolFlags(n)&t){var a=n.escapedName;r.has(a)||r.set(a,n)}}function s(e,n){n&&e.forEach((function(e){o(e,n)}))}function c(n,t){t&&n.forEach((function(n){e.getDeclarationOfKind(n,271)||e.getDeclarationOfKind(n,270)||o(n,t)}))}}function Ik(n){return 78===n.kind&&Nk(n.parent)&&e.getNameOfDeclaration(n.parent)===n}function Nk(e){switch(e.kind){case 160:case 253:case 254:case 255:case 256:case 335:case 328:case 329:return!0;case 263:return e.isTypeOnly;case 266:case 271:return e.parent.parent.isTypeOnly;default:return!1}}function kk(e){while(158===e.parent.kind)e=e.parent;return 174===e.parent.kind}function Rk(e){while(202===e.parent.kind)e=e.parent;return 224===e.parent.kind}function Ok(n){while(158===n.parent.kind)n=n.parent;while(202===n.parent.kind)n=n.parent;return e.isJSDocNameReference(n.parent)?n.parent:void 0}function wk(n,t){var r;while(1){if(n=e.getContainingClass(n),!n)break;if(r=t(n))break}return r}function Pk(n){return!!e.findAncestor(n,(function(n){return!!(e.isConstructorDeclaration(n)&&e.nodeIsPresent(n.body)||e.isPropertyDeclaration(n))||!(!e.isClassLike(n)&&!e.isFunctionLikeDeclaration(n))&&"quit"}))}function Mk(e,n){return!!wk(e,(function(e){return e===n}))}function Fk(e){while(158===e.parent.kind)e=e.parent;return 261===e.parent.kind?e.parent.moduleReference===e?e.parent:void 0:267===e.parent.kind&&e.parent.expression===e?e.parent:void 0}function Gk(e){return void 0!==Fk(e)}function Bk(n){var t=e.getAssignmentDeclarationKind(n.parent.parent);switch(t){case 1:case 3:return yi(n.parent);case 4:case 2:case 5:return yi(n.parent.parent)}}function Uk(n){var t=n.parent;while(e.isQualifiedName(t))n=t,t=t.parent;if(t&&196===t.kind&&t.qualifier===n)return t}function Vk(n){if(e.isDeclarationName(n))return yi(n.parent);if(e.isInJSFile(n)&&202===n.parent.kind&&n.parent===n.parent.parent.left&&!e.isPrivateIdentifier(n)){var t=Bk(n);if(t)return t}if(267===n.parent.kind&&e.isEntityNameExpression(n)){var r=qa(n,2998271,!0);if(r&&r!==Te)return r}else if(!e.isPropertyAccessExpression(n)&&!e.isPrivateIdentifier(n)&&Gk(n)){var a=e.getAncestor(n,261);return e.Debug.assert(void 0!==a),Wa(n,!0)}if(!e.isPropertyAccessExpression(n)&&!e.isPrivateIdentifier(n)){var i=Uk(n);if(i){zm(i);var o=Pr(n).resolvedSymbol;return o===Te?void 0:o}}while(e.isRightSideOfQualifiedNameOrPropertyAccess(n))n=n.parent;if(Rk(n)){var s=0;224===n.parent.kind?(s=788968,e.isExpressionWithTypeArgumentsInClassExtendsClause(n.parent)&&(s|=111551)):s=1920,s|=2097152;var c=e.isEntityNameExpression(n)?qa(n,s):void 0;if(c)return c}if(330===n.parent.kind)return e.getParameterSymbolFromJSDoc(n.parent);if(160===n.parent.kind&&334===n.parent.parent.kind){e.Debug.assert(!e.isInJSFile(n));var l=e.getTypeParameterFromJsDoc(n.parent);return l&&l.symbol}if(e.isExpressionNode(n)){if(e.nodeIsMissing(n))return;if(78===n.kind){if(e.isJSXTagName(n)&&OT(n)){var u=UT(n.parent);return u===Te?void 0:u}return qa(n,111551,!1,!0)}if(202===n.kind||158===n.kind){var d=Pr(n);return d.resolvedSymbol||(202===n.kind?vS(n,0):ES(n,0)),d.resolvedSymbol}}else if(kk(n)){s=174===n.parent.kind?788968:1920;return qa(n,s,!1,!0)}var p=Ok(n);if(p||e.isJSDocLink(n.parent)){s=901119,u=qa(n,s,!1,!1,e.getHostSignatureFromJSDoc(n));if(u)return u;if(e.isQualifiedName(n)&&e.isIdentifier(n.left)){d=Pr(n);if(d.resolvedSymbol)return d.resolvedSymbol;if(ES(n,0),d.resolvedSymbol)return d.resolvedSymbol;var f=qa(n.left,s,!1);if(f){var m=mc(f);return _u(m,n.right.escapedText)}}}return 173===n.parent.kind?qa(n,1):void 0}function jk(n,t){if(298===n.kind)return e.isExternalModule(n)?gi(n.symbol):void 0;var r=n.parent,a=r.parent;if(!(16777216&n.flags)){if(U(n)){var i=yi(r);return e.isImportOrExportSpecifier(n.parent)&&n.parent.propertyName===n?xT(i):i}if(e.isLiteralComputedPropertyDeclarationName(n))return yi(r.parent);if(78===n.kind){if(Gk(n))return Vk(n);if(199===r.kind&&197===a.kind&&n===r.propertyName){var o=Wk(a),s=_u(o,n.escapedText);if(s)return s}}switch(n.kind){case 78:case 79:case 202:case 158:return Vk(n);case 107:var c=e.getThisContainer(n,!1);if(e.isFunctionLike(c)){var l=Ou(c);if(l.thisParameter)return l.thisParameter}if(e.isInExpressionContext(n))return TA(n).symbol;case 188:return jm(n).symbol;case 105:return TA(n).symbol;case 132:var u=n.parent;return u&&167===u.kind?u.parent.symbol:void 0;case 10:case 14:if(e.isExternalModuleImportEqualsDeclaration(n.parent.parent)&&e.getExternalModuleImportEqualsDeclarationExpression(n.parent.parent)===n||(262===n.parent.kind||268===n.parent.kind)&&n.parent.moduleSpecifier===n||e.isInJSFile(n)&&e.isRequireCall(n.parent,!1)||e.isImportCall(n.parent)||e.isLiteralTypeNode(n.parent)&&e.isLiteralImportTypeNode(n.parent.parent)&&n.parent.parent.argument===n.parent)return Za(n,n,t);if(e.isCallExpression(r)&&e.isBindableObjectDefinePropertyCall(r)&&r.arguments[1]===n)return yi(r);case 8:var d=e.isElementAccessExpression(r)?r.argumentExpression===n?vA(r.expression):void 0:e.isLiteralTypeNode(r)&&e.isIndexedAccessTypeNode(a)?zm(a.objectType):void 0;return d&&_u(d,e.escapeLeadingUnderscores(n.text));case 87:case 97:case 38:case 83:return yi(n.parent);case 196:return e.isLiteralImportTypeNode(n)?jk(n.argument.literal,t):void 0;case 92:return e.isExportAssignment(n.parent)?e.Debug.checkDefined(n.parent.symbol):void 0;default:return}}}function Kk(e){if(e&&290===e.kind)return qa(e.name,2208703)}function Hk(n){return e.isExportSpecifier(n)?n.parent.parent.moduleSpecifier?Sa(n.parent.parent,n):qa(n.propertyName||n.name,2998271):qa(n,2998271)}function Wk(n){if(e.isSourceFile(n)&&!e.isExternalModule(n))return Ae;if(16777216&n.flags)return Ae;var t=e.tryGetClassImplementingOrExtendingExpressionWithTypeArguments(n),r=t&&ac(yi(t.class));if(e.isPartOfTypeNode(n)){var a=zm(n);return r?Fc(a,r.thisType):a}if(e.isExpressionNode(n))return Jk(n);if(r&&!t.isImplements){var i=e.firstOrUndefined(Qs(r));return i?Fc(i,r.thisType):Ae}if(Nk(n)){var o=yi(n);return mc(o)}if(Ik(n)){o=jk(n);return o?mc(o):Ae}if(e.isDeclaration(n)){o=yi(n);return ws(o)}if(U(n)){o=jk(n);return o?ws(o):Ae}if(e.isBindingPattern(n))return zo(n.parent,!0)||Ae;if(Gk(n)){o=jk(n);if(o){var s=mc(o);return s!==Ae?s:ws(o)}}return Ae}function zk(n){if(e.Debug.assert(201===n.kind||200===n.kind),240===n.parent.kind){var t=II(n.parent);return GD(n,t||Ae)}if(217===n.parent.kind){t=vA(n.parent.right);return GD(n,t||Ae)}if(289===n.parent.kind){var r=e.cast(n.parent.parent,e.isObjectLiteralExpression),a=zk(r)||Ae,i=e.indexOfNode(r.properties,n.parent);return PD(r,a,i)}var o=e.cast(n.parent,e.isArrayLiteralExpression),s=zk(o)||Ae,c=NI(65,s,ke,n.parent)||Ae;return FD(o,s,o.elements.indexOf(n),c)}function qk(n){var t=zk(e.cast(n.parent.parent,e.isAssignmentPattern));return t&&_u(t,n.escapedText)}function Jk(n){return e.isRightSideOfQualifiedNameOrPropertyAccess(n)&&(n=n.parent),Pm(vA(n))}function Xk(n){var t=yi(n.parent);return e.hasSyntacticModifier(n,32)?ws(t):mc(t)}function Yk(n){var t=n.name;switch(t.kind){case 78:return Fm(e.idText(t));case 8:case 10:return Fm(t.text);case 159:var r=ET(t);return CD(r,12288)?r:Me;default:return e.Debug.fail("Unsupported property name.")}}function Qk(n){n=au(n);var t=e.createSymbolTable(wl(n)),r=yu(n,0).length?Tn:yu(n,1).length?Sn:void 0;return r&&e.forEach(wl(r),(function(e){t.has(e.escapedName)||t.set(e.escapedName,e)})),Mi(t)}function Zk(n){return e.typeHasCallOrConstructSignatures(n,le)}function $k(n){var t=eR(n);return t?e.flatMap(t,$k):[n]}function eR(n){if(6&e.getCheckFlags(n))return e.mapDefined(wr(n).containingType.types,(function(e){return _u(e,n.escapedName)}));if(33554432&n.flags){var t=n,r=t.leftSpread,a=t.rightSpread,i=t.syntheticOrigin;return r?[r,a]:i?[i]:e.singleElementArray(nR(n))}}function nR(e){var n,t=e;while(t=wr(t).target)n=t;return n}function tR(n){if(e.isGeneratedIdentifier(n))return!1;var t=e.getParseTreeNode(n,e.isIdentifier);if(!t)return!1;var r=t.parent;if(!r)return!1;var a=(e.isPropertyAccessExpression(r)||e.isPropertyAssignment(r))&&r.name===t;return!a&&RR(t)===se}function rR(n){var t=Za(n.parent,n);if(!t||e.isShorthandAmbientModuleSymbol(t))return!0;var r=oi(t);t=ri(t);var a=wr(t);return void 0===a.exportsSomeValue&&(a.exportsSomeValue=r?!!(111551&t.flags):e.forEachEntry(fi(t),i)),a.exportsSomeValue;function i(e){return e=Ma(e),e&&!!(111551&e.flags)}}function aR(n){return e.isModuleOrEnumDeclaration(n.parent)&&n===n.parent.name}function iR(n,t){var r,a=e.getParseTreeNode(n,e.isIdentifier);if(a){var i=RR(a,aR(a));if(i){if(1048576&i.flags){var o=gi(i.exportSymbol);if(!t&&944&o.flags&&!(3&o.flags))return;i=o}var s=hi(i);if(s){if(512&s.flags&&298===(null===(r=s.valueDeclaration)||void 0===r?void 0:r.kind)){var c=s.valueDeclaration,l=e.getSourceFileOfNode(a),u=c!==l;return u?void 0:c}return e.findAncestor(a.parent,(function(n){return e.isModuleOrEnumDeclaration(n)&&yi(n)===s}))}}}}function oR(n){if(n.generatedImportReference)return n.generatedImportReference;var t=e.getParseTreeNode(n,e.isIdentifier);if(t){var r=RR(t);if(Pa(r,111551)&&!Va(r))return ca(r)}}function sR(n){return n.valueDeclaration&&e.isBindingElement(n.valueDeclaration)&&288===e.walkUpBindingElementsAndPatterns(n.valueDeclaration).parent.kind}function cR(n){if(418&n.flags&&n.valueDeclaration&&!e.isSourceFile(n.valueDeclaration)){var t=wr(n);if(void 0===t.isDeclarationWithCollidingName){var r=e.getEnclosingBlockScopeContainer(n.valueDeclaration);if(e.isStatementWithLocals(r)||sR(n)){var a=Pr(n.valueDeclaration);if(Vr(r.parent,n.escapedName,111551,void 0,void 0,!1))t.isDeclarationWithCollidingName=!0;else if(262144&a.flags){var i=524288&a.flags,o=e.isIterationStatement(r,!1),s=231===r.kind&&e.isIterationStatement(r.parent,!1);t.isDeclarationWithCollidingName=!e.isBlockScopedContainerTopLevel(r)&&(!i||!o&&!s)}else t.isDeclarationWithCollidingName=!1}}return t.isDeclarationWithCollidingName}return!1}function lR(n){if(!e.isGeneratedIdentifier(n)){var t=e.getParseTreeNode(n,e.isIdentifier);if(t){var r=RR(t);if(r&&cR(r))return r.valueDeclaration}}}function uR(n){var t=e.getParseTreeNode(n,e.isDeclaration);if(t){var r=yi(t);if(r)return cR(r)}return!1}function dR(n){switch(n.kind){case 261:return fR(yi(n)||Te);case 263:case 264:case 266:case 271:var t=yi(n)||Te;return fR(t)&&!Va(t);case 268:var r=n.exportClause;return!!r&&(e.isNamespaceExport(r)||e.some(r.elements,dR));case 267:return!n.expression||78!==n.expression.kind||fR(yi(n)||Te)}return!1}function pR(n){var t=e.getParseTreeNode(n,e.isImportEqualsDeclaration);if(void 0===t||298!==t.parent.kind||!e.isInternalModuleImportEqualsDeclaration(t))return!1;var r=fR(yi(t));return r&&t.moduleReference&&!e.nodeIsMissing(t.moduleReference)}function fR(n){var t=Fa(n);return t===Te||!!(111551&t.flags)&&(e.shouldPreserveConstEnums(C)||!mR(t))}function mR(e){return kD(e)||!!e.constEnumOnlyModule}function _R(n,t){if(la(n)){var r=yi(n),a=r&&wr(r);if(null===a||void 0===a?void 0:a.referenced)return!0;var i=wr(r).target;if(i&&1&e.getEffectiveModifierFlags(n)&&111551&i.flags&&(e.shouldPreserveConstEnums(C)||!mR(i)))return!0}return!!t&&!!e.forEachChild(n,(function(e){return _R(e,t)}))}function gR(n){if(e.nodeIsPresent(n.body)){if(e.isGetAccessor(n)||e.isSetAccessor(n))return!1;var t=yi(n),r=Gu(t);return r.length>1||1===r.length&&r[0].declaration!==n}return!1}function yR(n){return!!z&&!Au(n)&&!e.isJSDocParameterTag(n)&&!!n.initializer&&!e.hasSyntacticModifier(n,16476)}function hR(n){return z&&Au(n)&&!n.initializer&&e.hasSyntacticModifier(n,16476)}function vR(e){return!!z&&Au(e)&&!e.initializer}function bR(n){var t=e.getParseTreeNode(n,e.isFunctionDeclaration);if(!t)return!1;var r=yi(t);return!!(r&&16&r.flags)&&!!e.forEachEntry(pi(r),(function(n){return 111551&n.flags&&n.valueDeclaration&&e.isPropertyAccessExpression(n.valueDeclaration)}))}function ER(n){var t=e.getParseTreeNode(n,e.isFunctionDeclaration);if(!t)return e.emptyArray;var r=yi(t);return r&&wl(ws(r))||e.emptyArray}function TR(e){return Pr(e).flags||0}function SR(e){return FN(e.parent),Pr(e).enumMemberValue}function xR(e){switch(e.kind){case 292:case 202:case 203:return!0}return!1}function LR(n){if(292===n.kind)return SR(n);var t=Pr(n).resolvedSymbol;if(t&&8&t.flags){var r=t.valueDeclaration;if(e.isEnumConst(r.parent))return SR(r)}}function DR(e){return!!(524288&e.flags)&&yu(e,0).length>0}function AR(n,t){var r,a=e.getParseTreeNode(n,e.isEntityName);if(!a)return e.TypeReferenceSerializationKind.Unknown;if(t&&(t=e.getParseTreeNode(t),!t))return e.TypeReferenceSerializationKind.Unknown;var i=qa(a,111551,!0,!0,t),o=(null===(r=null===i||void 0===i?void 0:i.declarations)||void 0===r?void 0:r.every(e.isTypeOnlyImportOrExportDeclaration))||!1,s=i&&2097152&i.flags?Fa(i):i,c=qa(a,788968,!0,!1,t);if(s&&s===c){var l=tp(!1);if(l&&s===l)return e.TypeReferenceSerializationKind.Promise;var u=ws(s);if(u&&Hs(u))return o?e.TypeReferenceSerializationKind.TypeWithCallSignature:e.TypeReferenceSerializationKind.TypeWithConstructSignatureAndValue}if(!c)return o?e.TypeReferenceSerializationKind.ObjectType:e.TypeReferenceSerializationKind.Unknown;var d=mc(c);return d===Ae?o?e.TypeReferenceSerializationKind.ObjectType:e.TypeReferenceSerializationKind.Unknown:3&d.flags?e.TypeReferenceSerializationKind.ObjectType:CD(d,245760)?e.TypeReferenceSerializationKind.VoidNullableOrNeverType:CD(d,528)?e.TypeReferenceSerializationKind.BooleanType:CD(d,296)?e.TypeReferenceSerializationKind.NumberLikeType:CD(d,2112)?e.TypeReferenceSerializationKind.BigIntLikeType:CD(d,402653316)?e.TypeReferenceSerializationKind.StringLikeType:Cy(d)?e.TypeReferenceSerializationKind.ArrayLikeType:CD(d,12288)?e.TypeReferenceSerializationKind.ESSymbolType:DR(d)?e.TypeReferenceSerializationKind.TypeWithCallSignature:sy(d)?e.TypeReferenceSerializationKind.ArrayLikeType:e.TypeReferenceSerializationKind.ObjectType}function CR(n,t,r,a,i){var o=e.getParseTreeNode(n,e.isVariableLikeOrAccessor);if(!o)return e.factory.createToken(128);var s=yi(o),c=!s||133120&s.flags?Ae:Sy(ws(s));return 8192&c.flags&&c.symbol===s&&(r|=1048576),i&&(c=jy(c)),te.typeToTypeNode(c,t,1024|r,a)}function IR(n,t,r,a){var i=e.getParseTreeNode(n,e.isFunctionLike);if(!i)return e.factory.createToken(128);var o=Ou(i);return te.typeToTypeNode(Hu(o),t,1024|r,a)}function NR(n,t,r,a){var i=e.getParseTreeNode(n,e.isExpression);if(!i)return e.factory.createToken(128);var o=sh(Jk(i));return te.typeToTypeNode(o,t,1024|r,a)}function kR(n){return re.has(e.escapeLeadingUnderscores(n))}function RR(n,t){var r=Pr(n).resolvedSymbol;if(r)return r;var a=n;if(t){var i=n.parent;e.isDeclaration(i)&&n===i.name&&(a=Ao(i))}return Vr(a,n.escapedText,3257279,void 0,void 0,!0)}function OR(n){if(!e.isGeneratedIdentifier(n)){var t=e.getParseTreeNode(n,e.isIdentifier);if(t){var r=RR(t);if(r)return Li(r).valueDeclaration}}}function wR(n){return!!(e.isDeclarationReadonly(n)||e.isVariableDeclaration(n)&&e.isVarConst(n))&&Mm(ws(yi(n)))}function PR(n,t,r){var a=1024&n.flags?te.symbolToExpression(n.symbol,111551,t,void 0,r):n===Ve?e.factory.createTrue():n===Be&&e.factory.createFalse();if(a)return a;var i=n.value;return"object"===typeof i?e.factory.createBigIntLiteral(i):"number"===typeof i?e.factory.createNumericLiteral(i):e.factory.createStringLiteral(i)}function MR(e,n){var t=ws(yi(e));return PR(t,e,n)}function FR(n){return n?(pr(n),e.getSourceFileOfNode(n).localJsxFactory||ct):ct}function GR(n){if(n){var t=e.getSourceFileOfNode(n);if(t){if(t.localJsxFragmentFactory)return t.localJsxFragmentFactory;var r=t.pragmas.get("jsxfrag"),a=e.isArray(r)?r[0]:r;if(a)return t.localJsxFragmentFactory=e.parseIsolatedEntityName(a.arguments.factory,F),t.localJsxFragmentFactory}}if(C.jsxFragmentFactory)return e.parseIsolatedEntityName(C.jsxFragmentFactory,F)}function BR(){var t,r=n.getResolvedTypeReferenceDirectives();return r&&(t=new e.Map,r.forEach((function(e,t){if(e&&e.resolvedFileName){var r=n.getSourceFile(e.resolvedFileName);r&&l(r,t)}}))),{getReferencedExportContainer:iR,getReferencedImportDeclaration:oR,getReferencedDeclarationWithCollidingName:lR,isDeclarationWithCollidingName:uR,isValueAliasDeclaration:function(n){var t=e.getParseTreeNode(n);return!t||dR(t)},hasGlobalName:kR,isReferencedAliasDeclaration:function(n,t){var r=e.getParseTreeNode(n);return!r||_R(r,t)},getNodeCheckFlags:function(n){var t=e.getParseTreeNode(n);return t?TR(t):0},isTopLevelValueImportEqualsWithEntityName:pR,isDeclarationVisible:Eo,isImplementationOfOverload:gR,isRequiredInitializedParameter:yR,isOptionalUninitializedParameterProperty:hR,isExpandoFunctionDeclaration:bR,getPropertiesOfContainerFunction:ER,createTypeOfDeclaration:CR,createReturnTypeOfSignatureDeclaration:IR,createTypeOfExpression:NR,createLiteralConstValue:MR,isSymbolAccessible:Yi,isEntityNameVisible:to,getConstantValue:function(n){var t=e.getParseTreeNode(n,xR);return t?LR(t):void 0},collectLinkedAliases:To,getReferencedValueDeclaration:OR,getTypeReferenceSerializationKind:AR,isOptionalParameter:Au,moduleExportsSomeValue:rR,isArgumentsLocalBinding:tR,getExternalModuleFileFromDeclaration:function(n){var t=e.getParseTreeNode(n,e.hasPossibleExternalModuleReference);return t&&UR(t)},getTypeReferenceDirectivesForEntityName:o,getTypeReferenceDirectivesForSymbol:s,isLiteralConstDeclaration:wR,isLateBound:function(n){var t=e.getParseTreeNode(n,e.isDeclaration),r=t&&yi(t);return!!(r&&4096&e.getCheckFlags(r))},getJsxFactoryEntity:FR,getJsxFragmentFactoryEntity:GR,getAllAccessorDeclarations:function(n){n=e.getParseTreeNode(n,e.isGetOrSetAccessorDeclaration);var t=169===n.kind?168:169,r=e.getDeclarationOfKind(yi(n),t),a=r&&r.pos<n.pos?r:n,i=r&&r.pos<n.pos?n:r,o=169===n.kind?n:r,s=168===n.kind?n:r;return{firstAccessor:a,secondAccessor:i,setAccessor:o,getAccessor:s}},getSymbolOfExternalModuleSpecifier:function(e){return $a(e,e,void 0)},isBindingCapturedByNode:function(n,t){var r=e.getParseTreeNode(n),a=e.getParseTreeNode(t);return!!r&&!!a&&(e.isVariableDeclaration(a)||e.isBindingElement(a))&&Qb(r,a)},getDeclarationStatementsForSourceFile:function(n,t,r,a){var i=e.getParseTreeNode(n);e.Debug.assert(i&&298===i.kind,"Non-sourcefile node passed into getDeclarationsForSourceFile");var o=yi(n);return o?o.exports?te.symbolTableToDeclarationStatements(o.exports,n,t,r,a):[]:n.locals?te.symbolTableToDeclarationStatements(n.locals,n,t,r,a):[]},isImportRequiredByAugmentation:a};function a(n){var t=e.getSourceFileOfNode(n);if(!t.symbol)return!1;var r=UR(n);if(!r)return!1;if(r===t)return!1;for(var a=fi(t.symbol),i=0,o=e.arrayFrom(a.values());i<o.length;i++){var s=o[i];if(s.mergeId){var c=gi(s);if(c.declarations)for(var l=0,u=c.declarations;l<u.length;l++){var d=u[l],p=e.getSourceFileOfNode(d);if(p===r)return!0}}}return!1}function i(e){return e.parent&&224===e.parent.kind&&e.parent.parent&&287===e.parent.parent.kind}function o(e){if(t){var n=790504;(78===e.kind&&av(e)||202===e.kind&&!i(e))&&(n=1160127);var r=qa(e,n,!0);return r&&r!==Te?s(r,n):void 0}}function s(n,r){if(t&&c(n)){for(var a,i=0,o=n.declarations;i<o.length;i++){var s=o[i];if(s.symbol&&s.symbol.flags&r){var l=e.getSourceFileOfNode(s),u=t.get(l.path);if(!u)return;(a||(a=[])).push(u)}}return a}}function c(n){if(!n.declarations)return!1;var r=n;while(1){var a=hi(r);if(!a)break;r=a}if(r.valueDeclaration&&298===r.valueDeclaration.kind&&512&r.flags)return!1;for(var i=0,o=n.declarations;i<o.length;i++){var s=o[i],c=e.getSourceFileOfNode(s);if(t.has(c.path))return!0}return!1}function l(r,a){if(!t.has(r.path)){t.set(r.path,a);for(var i=0,o=r.referencedFiles;i<o.length;i++){var s=o[i].fileName,c=e.resolveTripleslashReference(s,r.fileName),u=n.getSourceFile(c);u&&l(u,a)}}}}function UR(n){var t=257===n.kind?e.tryCast(n.name,e.isStringLiteral):e.getExternalModuleName(n),r=$a(t,t,void 0);if(r)return e.getDeclarationOfKind(r,298)}function VR(){for(var t=0,r=n.getSourceFiles();t<r.length;t++){var a=r[t];e.bindSourceFile(a,C)}var i;gn=new e.Map;for(var o=0,s=n.getSourceFiles();o<s.length;o++){a=s[o];if(!a.redirectInfo){if(!e.isExternalOrCommonJsModule(a)){var c=a.locals.get("globalThis");if(null===c||void 0===c?void 0:c.declarations)for(var l=0,u=c.declarations;l<u.length;l++){var d=u[l];nr.add(e.createDiagnosticForNode(d,e.Diagnostics.Declaration_name_conflicts_with_built_in_global_identifier_0,"globalThis"))}kr(re,a.locals)}if(a.jsGlobalAugmentations&&kr(re,a.jsGlobalAugmentations),a.patternAmbientModules&&a.patternAmbientModules.length&&(hn=e.concatenate(hn,a.patternAmbientModules)),a.moduleAugmentations.length&&(i||(i=[])).push(a.moduleAugmentations),a.symbol&&a.symbol.globalExports){var p=a.symbol.globalExports;p.forEach((function(e,n){re.has(n)||re.set(n,e)}))}}}if(i)for(var f=0,m=i;f<m.length;f++)for(var _=m[f],g=0,y=_;g<y.length;g++){var h=y[g];e.isGlobalScopeAugmentation(h.parent)&&Rr(h)}if(Or(re,dr,e.Diagnostics.Declaration_name_conflicts_with_built_in_global_identifier_0),wr(ae).type=Re,wr(se).type=qd("IArguments",0,!0),wr(Te).type=Ae,wr(ie).type=Ri(16,ie),xn=qd("Array",1,!0),bn=qd("Object",0,!0),En=qd("Function",0,!0),Tn=J&&qd("CallableFunction",0,!0)||En,Sn=J&&qd("NewableFunction",0,!0)||En,Dn=qd("String",0,!0),An=qd("Number",0,!0),Cn=qd("Boolean",0,!0),In=qd("RegExp",0,!0),kn=Ep(xe),Rn=Ep(Le),Rn===an&&(Rn=Bi(void 0,D,e.emptyArray,e.emptyArray,void 0,void 0)),Ln=mp("ReadonlyArray",1)||xn,On=Ln?hp(Ln,[xe]):kn,Nn=mp("ThisType",1),i)for(var v=0,b=i;v<b.length;v++){_=b[v];for(var E=0,T=_;E<T.length;E++){h=T[E];e.isGlobalScopeAugmentation(h.parent)||Rr(h)}}gn.forEach((function(n){var t=n.firstFile,r=n.secondFile,a=n.conflictingSymbols;if(a.size<8)a.forEach((function(n,t){for(var r=n.isBlockScoped,a=n.firstFileLocations,i=n.secondFileLocations,o=r?e.Diagnostics.Cannot_redeclare_block_scoped_variable_0:e.Diagnostics.Duplicate_identifier_0,s=0,c=a;s<c.length;s++){var l=c[s];Ir(l,o,t,i)}for(var u=0,d=i;u<d.length;u++){l=d[u];Ir(l,o,t,a)}}));else{var i=e.arrayFrom(a.keys()).join(", ");nr.add(e.addRelatedInfo(e.createDiagnosticForNode(t,e.Diagnostics.Definitions_of_the_following_identifiers_conflict_with_those_in_another_file_Colon_0,i),e.createDiagnosticForNode(r,e.Diagnostics.Conflicts_are_in_this_file))),nr.add(e.addRelatedInfo(e.createDiagnosticForNode(r,e.Diagnostics.Definitions_of_the_following_identifiers_conflict_with_those_in_another_file_Colon_0,i),e.createDiagnosticForNode(t,e.Diagnostics.Conflicts_are_in_this_file)))}})),gn=void 0}function jR(n,t){if((a&t)!==t&&C.importHelpers){var r=e.getSourceFileOfNode(n);if(e.isEffectiveExternalModule(r,C)&&!(8388608&n.flags)){var i=HR(r,n);if(i!==Te)for(var o=t&~a,s=1;s<=2097152;s<<=1)if(o&s){var c=KR(s),l=Fr(i.exports,e.escapeLeadingUnderscores(c),111551);l?524288&s?e.some(Gu(l),(function(e){return BL(e)>3}))||gr(n,e.Diagnostics.This_syntax_requires_an_imported_helper_named_1_with_2_parameters_which_is_not_compatible_with_the_one_in_0_Consider_upgrading_your_version_of_0,e.externalHelpersModuleNameText,c,4):1048576&s&&(e.some(Gu(l),(function(e){return BL(e)>4}))||gr(n,e.Diagnostics.This_syntax_requires_an_imported_helper_named_1_with_2_parameters_which_is_not_compatible_with_the_one_in_0_Consider_upgrading_your_version_of_0,e.externalHelpersModuleNameText,c,5)):gr(n,e.Diagnostics.This_syntax_requires_an_imported_helper_named_1_which_does_not_exist_in_0_Consider_upgrading_your_version_of_0,e.externalHelpersModuleNameText,c)}a|=t}}}function KR(n){switch(n){case 1:return"__extends";case 2:return"__assign";case 4:return"__rest";case 8:return"__decorate";case 16:return"__metadata";case 32:return"__param";case 64:return"__awaiter";case 128:return"__generator";case 256:return"__values";case 512:return"__read";case 1024:return"__spreadArray";case 2048:return"__await";case 4096:return"__asyncGenerator";case 8192:return"__asyncDelegator";case 16384:return"__asyncValues";case 32768:return"__exportStar";case 65536:return"__importStar";case 131072:return"__importDefault";case 262144:return"__makeTemplateObject";case 524288:return"__classPrivateFieldGet";case 1048576:return"__classPrivateFieldSet";case 2097152:return"__createBinding";default:return e.Debug.fail("Unrecognized helper")}}function HR(n,t){return u||(u=ei(n,e.externalHelpersModuleNameText,e.Diagnostics.This_syntax_requires_an_imported_helper_but_module_0_cannot_be_found,t)||Te),u}function WR(e){return zR(e)||qR(e)}function zR(n){if(!n.decorators)return!1;if(!e.nodeCanBeDecorated(n,n.parent,n.parent.parent))return 166!==n.kind||e.nodeIsPresent(n.body)?zO(n,e.Diagnostics.Decorators_are_not_valid_here):zO(n,e.Diagnostics.A_decorator_can_only_decorate_a_method_implementation_not_an_overload);if(168===n.kind||169===n.kind){var t=e.getAllAccessorDeclarations(n.parent.members,n);if(t.firstAccessor.decorators&&n===t.secondAccessor)return zO(n,e.Diagnostics.Decorators_cannot_be_applied_to_multiple_get_Slashset_accessors_of_the_same_name)}return!1}function qR(n){var t,r,a,i,o,s=JR(n);if(void 0!==s)return s;for(var c=0,l=0,u=n.modifiers;l<u.length;l++){var d=u[l];if(142!==d.kind){if(163===n.kind||165===n.kind)return XO(d,e.Diagnostics._0_modifier_cannot_appear_on_a_type_member,e.tokenToString(d.kind));if(172===n.kind&&(123!==d.kind||!e.isClassLike(n.parent)))return XO(d,e.Diagnostics._0_modifier_cannot_appear_on_an_index_signature,e.tokenToString(d.kind))}switch(d.kind){case 84:if(256!==n.kind)return XO(n,e.Diagnostics.A_class_member_cannot_have_the_0_keyword,e.tokenToString(84));break;case 156:if(16384&c)return XO(d,e.Diagnostics._0_modifier_already_seen,"override");if(2&c)return XO(d,e.Diagnostics._0_modifier_cannot_be_used_with_1_modifier,"override","declare");if(64&c)return XO(d,e.Diagnostics._0_modifier_must_precede_1_modifier,"override","readonly");if(256&c)return XO(d,e.Diagnostics._0_modifier_must_precede_1_modifier,"override","async");c|=16384,o=d;break;case 122:case 121:case 120:var p=_o(e.modifierToFlag(d.kind));if(28&c)return XO(d,e.Diagnostics.Accessibility_modifier_already_seen);if(16384&c)return XO(d,e.Diagnostics._0_modifier_must_precede_1_modifier,p,"override");if(32&c)return XO(d,e.Diagnostics._0_modifier_must_precede_1_modifier,p,"static");if(64&c)return XO(d,e.Diagnostics._0_modifier_must_precede_1_modifier,p,"readonly");if(256&c)return XO(d,e.Diagnostics._0_modifier_must_precede_1_modifier,p,"async");if(258===n.parent.kind||298===n.parent.kind)return XO(d,e.Diagnostics._0_modifier_cannot_appear_on_a_module_or_namespace_element,p);if(128&c)return 120===d.kind?XO(d,e.Diagnostics._0_modifier_cannot_be_used_with_1_modifier,p,"abstract"):XO(d,e.Diagnostics._0_modifier_must_precede_1_modifier,p,"abstract");if(e.isPrivateIdentifierClassElementDeclaration(n))return XO(d,e.Diagnostics.An_accessibility_modifier_cannot_be_used_with_a_private_identifier);c|=e.modifierToFlag(d.kind);break;case 123:if(32&c)return XO(d,e.Diagnostics._0_modifier_already_seen,"static");if(64&c)return XO(d,e.Diagnostics._0_modifier_must_precede_1_modifier,"static","readonly");if(256&c)return XO(d,e.Diagnostics._0_modifier_must_precede_1_modifier,"static","async");if(258===n.parent.kind||298===n.parent.kind)return XO(d,e.Diagnostics._0_modifier_cannot_appear_on_a_module_or_namespace_element,"static");if(161===n.kind)return XO(d,e.Diagnostics._0_modifier_cannot_appear_on_a_parameter,"static");if(128&c)return XO(d,e.Diagnostics._0_modifier_cannot_be_used_with_1_modifier,"static","abstract");if(16384&c)return XO(d,e.Diagnostics._0_modifier_must_precede_1_modifier,"static","override");c|=32,t=d;break;case 142:if(64&c)return XO(d,e.Diagnostics._0_modifier_already_seen,"readonly");if(164!==n.kind&&163!==n.kind&&172!==n.kind&&161!==n.kind)return XO(d,e.Diagnostics.readonly_modifier_can_only_appear_on_a_property_declaration_or_index_signature);c|=64,i=d;break;case 92:if(1&c)return XO(d,e.Diagnostics._0_modifier_already_seen,"export");if(2&c)return XO(d,e.Diagnostics._0_modifier_must_precede_1_modifier,"export","declare");if(128&c)return XO(d,e.Diagnostics._0_modifier_must_precede_1_modifier,"export","abstract");if(256&c)return XO(d,e.Diagnostics._0_modifier_must_precede_1_modifier,"export","async");if(e.isClassLike(n.parent))return XO(d,e.Diagnostics._0_modifier_cannot_appear_on_class_elements_of_this_kind,"export");if(161===n.kind)return XO(d,e.Diagnostics._0_modifier_cannot_appear_on_a_parameter,"export");c|=1;break;case 87:var f=298===n.parent.kind?n.parent:n.parent.parent;if(257===f.kind&&!e.isAmbientModule(f))return XO(d,e.Diagnostics.A_default_export_can_only_be_used_in_an_ECMAScript_style_module);c|=512;break;case 133:if(2&c)return XO(d,e.Diagnostics._0_modifier_already_seen,"declare");if(256&c)return XO(d,e.Diagnostics._0_modifier_cannot_be_used_in_an_ambient_context,"async");if(16384&c)return XO(d,e.Diagnostics._0_modifier_cannot_be_used_in_an_ambient_context,"override");if(e.isClassLike(n.parent)&&!e.isPropertyDeclaration(n))return XO(d,e.Diagnostics._0_modifier_cannot_appear_on_class_elements_of_this_kind,"declare");if(161===n.kind)return XO(d,e.Diagnostics._0_modifier_cannot_appear_on_a_parameter,"declare");if(8388608&n.parent.flags&&258===n.parent.kind)return XO(d,e.Diagnostics.A_declare_modifier_cannot_be_used_in_an_already_ambient_context);if(e.isPrivateIdentifierClassElementDeclaration(n))return XO(d,e.Diagnostics._0_modifier_cannot_be_used_with_a_private_identifier,"declare");c|=2,r=d;break;case 125:if(128&c)return XO(d,e.Diagnostics._0_modifier_already_seen,"abstract");if(253!==n.kind&&176!==n.kind){if(166!==n.kind&&164!==n.kind&&168!==n.kind&&169!==n.kind)return XO(d,e.Diagnostics.abstract_modifier_can_only_appear_on_a_class_method_or_property_declaration);if(253!==n.parent.kind||!e.hasSyntacticModifier(n.parent,128))return XO(d,e.Diagnostics.Abstract_methods_can_only_appear_within_an_abstract_class);if(32&c)return XO(d,e.Diagnostics._0_modifier_cannot_be_used_with_1_modifier,"static","abstract");if(8&c)return XO(d,e.Diagnostics._0_modifier_cannot_be_used_with_1_modifier,"private","abstract");if(256&c&&a)return XO(a,e.Diagnostics._0_modifier_cannot_be_used_with_1_modifier,"async","abstract");if(16384&c)return XO(d,e.Diagnostics._0_modifier_must_precede_1_modifier,"abstract","override")}if(e.isNamedDeclaration(n)&&79===n.name.kind)return XO(d,e.Diagnostics._0_modifier_cannot_be_used_with_a_private_identifier,"abstract");c|=128;break;case 129:if(256&c)return XO(d,e.Diagnostics._0_modifier_already_seen,"async");if(2&c||8388608&n.parent.flags)return XO(d,e.Diagnostics._0_modifier_cannot_be_used_in_an_ambient_context,"async");if(161===n.kind)return XO(d,e.Diagnostics._0_modifier_cannot_appear_on_a_parameter,"async");if(128&c)return XO(d,e.Diagnostics._0_modifier_cannot_be_used_with_1_modifier,"async","abstract");c|=256,a=d;break}}return 167===n.kind?32&c?XO(t,e.Diagnostics._0_modifier_cannot_appear_on_a_constructor_declaration,"static"):128&c?XO(t,e.Diagnostics._0_modifier_cannot_appear_on_a_constructor_declaration,"abstract"):16384&c?XO(o,e.Diagnostics._0_modifier_cannot_appear_on_a_constructor_declaration,"override"):256&c?XO(a,e.Diagnostics._0_modifier_cannot_appear_on_a_constructor_declaration,"async"):!!(64&c)&&XO(i,e.Diagnostics._0_modifier_cannot_appear_on_a_constructor_declaration,"readonly"):(262===n.kind||261===n.kind)&&2&c?XO(r,e.Diagnostics.A_0_modifier_cannot_be_used_with_an_import_declaration,"declare"):161===n.kind&&16476&c&&e.isBindingPattern(n.name)?XO(n,e.Diagnostics.A_parameter_property_may_not_be_declared_using_a_binding_pattern):161===n.kind&&16476&c&&n.dotDotDotToken?XO(n,e.Diagnostics.A_parameter_property_cannot_be_declared_using_a_rest_parameter):!!(256&c)&&QR(n,a)}function JR(n){return!!n.modifiers&&(XR(n)?zO(n,e.Diagnostics.Modifiers_cannot_appear_here):void 0)}function XR(n){switch(n.kind){case 168:case 169:case 167:case 164:case 163:case 166:case 165:case 172:case 257:case 262:case 261:case 268:case 267:case 209:case 210:case 161:return!1;default:if(258===n.parent.kind||298===n.parent.kind)return!1;switch(n.kind){case 252:return YR(n,129);case 253:case 176:return YR(n,125);case 254:case 233:case 255:return!0;case 256:return YR(n,84);default:e.Debug.fail()}}}function YR(e,n){return e.modifiers.length>1||e.modifiers[0].kind!==n}function QR(n,t){switch(n.kind){case 166:case 252:case 209:case 210:return!1}return XO(t,e.Diagnostics._0_modifier_cannot_be_used_here,"async")}function ZR(n,t){return void 0===t&&(t=e.Diagnostics.Trailing_comma_not_allowed),!(!n||!n.hasTrailingComma)&&qO(n[0],n.end-",".length,",".length,t)}function $R(n,t){if(n&&0===n.length){var r=n.pos-"<".length,a=e.skipTrivia(t.text,n.end)+">".length;return qO(t,r,a-r,e.Diagnostics.Type_parameter_list_cannot_be_empty)}return!1}function eO(n){for(var t=!1,r=n.length,a=0;a<r;a++){var i=n[a];if(i.dotDotDotToken){if(a!==r-1)return XO(i.dotDotDotToken,e.Diagnostics.A_rest_parameter_must_be_last_in_a_parameter_list);if(8388608&i.flags||ZR(n,e.Diagnostics.A_rest_parameter_or_binding_pattern_may_not_have_a_trailing_comma),i.questionToken)return XO(i.questionToken,e.Diagnostics.A_rest_parameter_cannot_be_optional);if(i.initializer)return XO(i.name,e.Diagnostics.A_rest_parameter_cannot_have_an_initializer)}else if(Au(i)){if(t=!0,i.questionToken&&i.initializer)return XO(i.name,e.Diagnostics.Parameter_cannot_have_question_mark_and_initializer)}else if(t&&!i.initializer)return XO(i.name,e.Diagnostics.A_required_parameter_cannot_follow_an_optional_parameter)}}function nO(n){return e.filter(n,(function(n){return!!n.initializer||e.isBindingPattern(n.name)||e.isRestParameter(n)}))}function tO(n){if(F>=3){var t=n.body&&e.isBlock(n.body)&&e.findUseStrictPrologue(n.body.statements);if(t){var r=nO(n.parameters);if(e.length(r)){e.forEach(r,(function(n){e.addRelatedInfo(gr(n,e.Diagnostics.This_parameter_is_not_allowed_with_use_strict_directive),e.createDiagnosticForNode(t,e.Diagnostics.use_strict_directive_used_here))}));var a=r.map((function(n,t){return 0===t?e.createDiagnosticForNode(n,e.Diagnostics.Non_simple_parameter_declared_here):e.createDiagnosticForNode(n,e.Diagnostics.and_here)}));return e.addRelatedInfo.apply(void 0,i([gr(t,e.Diagnostics.use_strict_directive_cannot_be_used_with_non_simple_parameter_list)],a)),!0}}}return!1}function rO(n){var t=e.getSourceFileOfNode(n);return WR(n)||$R(n.typeParameters,t)||eO(n.parameters)||iO(n,t)||e.isFunctionLikeDeclaration(n)&&tO(n)}function aO(n){var t=e.getSourceFileOfNode(n);return _O(n)||$R(n.typeParameters,t)}function iO(n,t){if(!e.isArrowFunction(n))return!1;var r=n.equalsGreaterThanToken,a=e.getLineAndCharacterOfPosition(t,r.pos).line,i=e.getLineAndCharacterOfPosition(t,r.end).line;return a!==i&&XO(r,e.Diagnostics.Line_terminator_not_permitted_before_arrow)}function oO(n){var t=n.parameters[0];if(1!==n.parameters.length)return XO(t?t.name:n,e.Diagnostics.An_index_signature_must_have_exactly_one_parameter);if(ZR(n.parameters,e.Diagnostics.An_index_signature_cannot_have_a_trailing_comma),t.dotDotDotToken)return XO(t.dotDotDotToken,e.Diagnostics.An_index_signature_cannot_have_a_rest_parameter);if(e.hasEffectiveModifiers(t))return XO(t.name,e.Diagnostics.An_index_signature_parameter_cannot_have_an_accessibility_modifier);if(t.questionToken)return XO(t.questionToken,e.Diagnostics.An_index_signature_parameter_cannot_have_a_question_mark);if(t.initializer)return XO(t.name,e.Diagnostics.An_index_signature_parameter_cannot_have_an_initializer);if(!t.type)return XO(t.name,e.Diagnostics.An_index_signature_parameter_must_have_a_type_annotation);if(147!==t.type.kind&&144!==t.type.kind){var r=zm(t.type);return 4&r.flags||8&r.flags?XO(t.name,e.Diagnostics.An_index_signature_parameter_type_cannot_be_a_type_alias_Consider_writing_0_Colon_1_Colon_2_instead,e.getTextOfNode(t.name),io(r),io(n.type?zm(n.type):xe)):1048576&r.flags&&ID(r,384,!0)?XO(t.name,e.Diagnostics.An_index_signature_parameter_type_cannot_be_a_union_type_Consider_using_a_mapped_object_type_instead):XO(t.name,e.Diagnostics.An_index_signature_parameter_type_must_be_either_string_or_number)}return!n.type&&XO(n,e.Diagnostics.An_index_signature_must_have_a_type_annotation)}function sO(e){return WR(e)||oO(e)}function cO(n,t){if(t&&0===t.length){var r=e.getSourceFileOfNode(n),a=t.pos-"<".length,i=e.skipTrivia(r.text,t.end)+">".length;return qO(r,a,i-a,e.Diagnostics.Type_argument_list_cannot_be_empty)}return!1}function lO(e,n){return ZR(n)||cO(e,n)}function uO(n){return!!(n.questionDotToken||32&n.flags)&&XO(n.template,e.Diagnostics.Tagged_template_expressions_are_not_permitted_in_an_optional_chain)}function dO(n){if(n)for(var t=0,r=n;t<r.length;t++){var a=r[t];if(223===a.kind)return qO(a,a.pos,0,e.Diagnostics.Argument_expression_expected)}return!1}function pO(e){return dO(e)}function fO(n){var t=n.types;if(ZR(t))return!0;if(t&&0===t.length){var r=e.tokenToString(n.token);return qO(n,t.pos,0,e.Diagnostics._0_list_cannot_be_empty,r)}return e.some(t,mO)}function mO(e){return lO(e,e.typeArguments)}function _O(n){var t=!1,r=!1;if(!WR(n)&&n.heritageClauses)for(var a=0,i=n.heritageClauses;a<i.length;a++){var o=i[a];if(93===o.token){if(t)return zO(o,e.Diagnostics.extends_clause_already_seen);if(r)return zO(o,e.Diagnostics.extends_clause_must_precede_implements_clause);if(o.types.length>1)return zO(o.types[1],e.Diagnostics.Classes_can_only_extend_a_single_class);t=!0}else{if(e.Debug.assert(116===o.token),r)return zO(o,e.Diagnostics.implements_clause_already_seen);r=!0}fO(o)}}function gO(n){var t=!1;if(n.heritageClauses)for(var r=0,a=n.heritageClauses;r<a.length;r++){var i=a[r];if(93!==i.token)return e.Debug.assert(116===i.token),zO(i,e.Diagnostics.Interface_declaration_cannot_have_implements_clause);if(t)return zO(i,e.Diagnostics.extends_clause_already_seen);t=!0,fO(i)}return!1}function yO(n){if(159!==n.kind)return!1;var t=n;return 217===t.expression.kind&&27===t.expression.operatorToken.kind&&XO(t.expression,e.Diagnostics.A_comma_expression_is_not_allowed_in_a_computed_property_name)}function hO(n){if(n.asteriskToken){if(e.Debug.assert(252===n.kind||209===n.kind||166===n.kind),8388608&n.flags)return XO(n.asteriskToken,e.Diagnostics.Generators_are_not_allowed_in_an_ambient_context);if(!n.body)return XO(n.asteriskToken,e.Diagnostics.An_overload_signature_cannot_be_declared_as_a_generator)}}function vO(e,n){return!!e&&XO(e,n)}function bO(e,n){return!!e&&XO(e,n)}function EO(n,t){for(var r=new e.Map,a=0,i=n.properties;a<i.length;a++){var o=i[a];if(291!==o.kind){var s=o.name;if(159===s.kind&&yO(s),290===o.kind&&!t&&o.objectAssignmentInitializer)return XO(o.equalsToken,e.Diagnostics.Did_you_mean_to_use_a_Colon_An_can_only_follow_a_property_name_when_the_containing_object_literal_is_part_of_a_destructuring_pattern);if(79===s.kind&&XO(s,e.Diagnostics.Private_identifiers_are_not_allowed_outside_class_bodies),o.modifiers)for(var c=0,l=o.modifiers;c<l.length;c++){var u=l[c];129===u.kind&&166===o.kind||XO(u,e.Diagnostics._0_modifier_cannot_be_used_here,e.getTextOfNode(u))}var d=void 0;switch(o.kind){case 290:bO(o.exclamationToken,e.Diagnostics.A_definite_assignment_assertion_is_not_permitted_in_this_context);case 289:vO(o.questionToken,e.Diagnostics.An_object_member_cannot_be_declared_optional),8===s.kind&&rw(s),d=4;break;case 166:d=8;break;case 168:d=1;break;case 169:d=2;break;default:throw e.Debug.assertNever(o,"Unexpected syntax kind:"+o.kind)}if(!t){var p=e.getPropertyNameForPropertyNameNode(s);if(void 0===p)continue;var f=r.get(p);if(f)if(12&d&&12&f)XO(s,e.Diagnostics.Duplicate_identifier_0,e.getTextOfNode(s));else{if(!(3&d&&3&f))return XO(s,e.Diagnostics.An_object_literal_cannot_have_property_and_accessor_with_the_same_name);if(3===f||d===f)return XO(s,e.Diagnostics.An_object_literal_cannot_have_multiple_get_Slashset_accessors_with_the_same_name);r.set(p,d|f)}else r.set(p,d)}}else if(t){var m=e.skipParentheses(o.expression);if(e.isArrayLiteralExpression(m)||e.isObjectLiteralExpression(m))return XO(o.expression,e.Diagnostics.A_rest_element_cannot_contain_a_binding_pattern)}}}function TO(n){SO(n.tagName),lO(n,n.typeArguments);for(var t=new e.Map,r=0,a=n.attributes.properties;r<a.length;r++){var i=a[r];if(283!==i.kind){var o=i.name,s=i.initializer;if(t.get(o.escapedText))return XO(o,e.Diagnostics.JSX_elements_cannot_have_multiple_attributes_with_the_same_name);if(t.set(o.escapedText,!0),s&&284===s.kind&&!s.expression)return XO(s,e.Diagnostics.JSX_attributes_must_only_be_assigned_a_non_empty_expression)}}}function SO(n){if(e.isPropertyAccessExpression(n)){var t=n;do{var r=i(t.name);if(r)return r;t=t.expression}while(e.isPropertyAccessExpression(t));var a=i(t);if(a)return a}function i(n){if(e.isIdentifier(n)&&-1!==e.idText(n).indexOf(":"))return XO(n,e.Diagnostics.JSX_property_access_expressions_cannot_include_JSX_namespace_names)}}function xO(n){if(n.expression&&e.isCommaSequence(n.expression))return XO(n.expression,e.Diagnostics.JSX_expressions_may_not_use_the_comma_operator_Did_you_mean_to_write_an_array)}function LO(n){if(tw(n))return!0;if(240===n.kind&&n.awaitModifier&&!(32768&n.flags)){var t=e.getSourceFileOfNode(n);if(e.isInTopLevelContext(n))WO(t)||(e.isEffectiveExternalModule(t,C)||nr.add(e.createDiagnosticForNode(n.awaitModifier,e.Diagnostics.for_await_loops_are_only_allowed_at_the_top_level_of_a_file_when_that_file_is_a_module_but_this_file_has_no_imports_or_exports_Consider_adding_an_empty_export_to_make_this_file_a_module)),(G!==e.ModuleKind.ESNext&&G!==e.ModuleKind.System||F<4)&&nr.add(e.createDiagnosticForNode(n.awaitModifier,e.Diagnostics.Top_level_for_await_loops_are_only_allowed_when_the_module_option_is_set_to_esnext_or_system_and_the_target_option_is_set_to_es2017_or_higher)));else if(!WO(t)){var r=e.createDiagnosticForNode(n.awaitModifier,e.Diagnostics.for_await_loops_are_only_allowed_within_async_functions_and_at_the_top_levels_of_modules),a=e.getContainingFunction(n);if(a&&167!==a.kind){e.Debug.assert(0===(2&e.getFunctionFlags(a)),"Enclosing function should never be an async function.");var i=e.createDiagnosticForNode(a,e.Diagnostics.Did_you_mean_to_mark_this_function_as_async);e.addRelatedInfo(r,i)}return nr.add(r),!0}return!1}if(251===n.initializer.kind){var o=n.initializer;if(!VO(o)){var s=o.declarations;if(!s.length)return!1;if(s.length>1){r=239===n.kind?e.Diagnostics.Only_a_single_variable_declaration_is_allowed_in_a_for_in_statement:e.Diagnostics.Only_a_single_variable_declaration_is_allowed_in_a_for_of_statement;return zO(o.declarations[1],r)}var c=s[0];if(c.initializer){r=239===n.kind?e.Diagnostics.The_variable_declaration_of_a_for_in_statement_cannot_have_an_initializer:e.Diagnostics.The_variable_declaration_of_a_for_of_statement_cannot_have_an_initializer;return XO(c.name,r)}if(c.type){r=239===n.kind?e.Diagnostics.The_left_hand_side_of_a_for_in_statement_cannot_use_a_type_annotation:e.Diagnostics.The_left_hand_side_of_a_for_of_statement_cannot_use_a_type_annotation;return XO(c,r)}}}return!1}function DO(n){if(!(8388608&n.flags)&&178!==n.parent.kind&&254!==n.parent.kind){if(F<1)return XO(n.name,e.Diagnostics.Accessors_are_only_available_when_targeting_ECMAScript_5_and_higher);if(F<2&&e.isPrivateIdentifier(n.name))return XO(n.name,e.Diagnostics.Private_identifiers_are_only_available_when_targeting_ECMAScript_2015_and_higher);if(void 0===n.body&&!e.hasSyntacticModifier(n,128))return qO(n,n.end-1,";".length,e.Diagnostics._0_expected,"{")}if(n.body){if(e.hasSyntacticModifier(n,128))return XO(n,e.Diagnostics.An_abstract_accessor_cannot_have_an_implementation);if(178===n.parent.kind||254===n.parent.kind)return XO(n.body,e.Diagnostics.An_implementation_cannot_be_declared_in_ambient_contexts)}if(n.typeParameters)return XO(n.name,e.Diagnostics.An_accessor_cannot_have_type_parameters);if(!AO(n))return XO(n.name,168===n.kind?e.Diagnostics.A_get_accessor_cannot_have_parameters:e.Diagnostics.A_set_accessor_must_have_exactly_one_parameter);if(169===n.kind){if(n.type)return XO(n.name,e.Diagnostics.A_set_accessor_cannot_have_a_return_type_annotation);var t=e.Debug.checkDefined(e.getSetAccessorValueParameter(n),"Return value does not match parameter count assertion.");if(t.dotDotDotToken)return XO(t.dotDotDotToken,e.Diagnostics.A_set_accessor_cannot_have_rest_parameter);if(t.questionToken)return XO(t.questionToken,e.Diagnostics.A_set_accessor_cannot_have_an_optional_parameter);if(t.initializer)return XO(n.name,e.Diagnostics.A_set_accessor_parameter_cannot_have_an_initializer)}return!1}function AO(e){return CO(e)||e.parameters.length===(168===e.kind?0:1)}function CO(n){if(n.parameters.length===(168===n.kind?1:2))return e.getThisParameter(n)}function IO(n){if(151===n.operator){if(148!==n.type.kind)return XO(n.type,e.Diagnostics._0_expected,e.tokenToString(148));var t=e.walkUpParenthesizedTypes(n.parent);switch(e.isInJSFile(t)&&e.isJSDocTypeExpression(t)&&(t=t.parent,e.isJSDocTypeTag(t)&&(t=t.parent.parent)),t.kind){case 250:var r=t;if(78!==r.name.kind)return XO(n,e.Diagnostics.unique_symbol_types_may_not_be_used_on_a_variable_declaration_with_a_binding_name);if(!e.isVariableDeclarationInVariableStatement(r))return XO(n,e.Diagnostics.unique_symbol_types_are_only_allowed_on_variables_in_a_variable_statement);if(!(2&r.parent.flags))return XO(t.name,e.Diagnostics.A_variable_whose_type_is_a_unique_symbol_type_must_be_const);break;case 164:if(!e.hasSyntacticModifier(t,32)||!e.hasEffectiveModifier(t,64))return XO(t.name,e.Diagnostics.A_property_of_a_class_whose_type_is_a_unique_symbol_type_must_be_both_static_and_readonly);break;case 163:if(!e.hasSyntacticModifier(t,64))return XO(t.name,e.Diagnostics.A_property_of_an_interface_or_type_literal_whose_type_is_a_unique_symbol_type_must_be_readonly);break;default:return XO(n,e.Diagnostics.unique_symbol_types_are_not_allowed_here)}}else if(142===n.operator&&179!==n.type.kind&&180!==n.type.kind)return zO(n,e.Diagnostics.readonly_type_modifier_is_only_permitted_on_array_and_tuple_literal_types,e.tokenToString(148))}function NO(e,n){if(Nc(e))return XO(e,n)}function kO(n){if(rO(n))return!0;if(166===n.kind){if(201===n.parent.kind){if(n.modifiers&&(1!==n.modifiers.length||129!==e.first(n.modifiers).kind))return zO(n,e.Diagnostics.Modifiers_cannot_appear_here);if(vO(n.questionToken,e.Diagnostics.An_object_member_cannot_be_declared_optional))return!0;if(bO(n.exclamationToken,e.Diagnostics.A_definite_assignment_assertion_is_not_permitted_in_this_context))return!0;if(void 0===n.body)return qO(n,n.end-1,";".length,e.Diagnostics._0_expected,"{")}if(hO(n))return!0}if(e.isClassLike(n.parent)){if(F<2&&e.isPrivateIdentifier(n.name))return XO(n.name,e.Diagnostics.Private_identifiers_are_only_available_when_targeting_ECMAScript_2015_and_higher);if(8388608&n.flags)return NO(n.name,e.Diagnostics.A_computed_property_name_in_an_ambient_context_must_refer_to_an_expression_whose_type_is_a_literal_type_or_a_unique_symbol_type);if(166===n.kind&&!n.body)return NO(n.name,e.Diagnostics.A_computed_property_name_in_a_method_overload_must_refer_to_an_expression_whose_type_is_a_literal_type_or_a_unique_symbol_type)}else{if(254===n.parent.kind)return NO(n.name,e.Diagnostics.A_computed_property_name_in_an_interface_must_refer_to_an_expression_whose_type_is_a_literal_type_or_a_unique_symbol_type);if(178===n.parent.kind)return NO(n.name,e.Diagnostics.A_computed_property_name_in_a_type_literal_must_refer_to_an_expression_whose_type_is_a_literal_type_or_a_unique_symbol_type)}}function RO(n){var t=n;while(t){if(e.isFunctionLike(t))return XO(n,e.Diagnostics.Jump_target_cannot_cross_function_boundary);switch(t.kind){case 246:if(n.label&&t.label.escapedText===n.label.escapedText){var r=241===n.kind&&!e.isIterationStatement(t.statement,!0);return!!r&&XO(n,e.Diagnostics.A_continue_statement_can_only_jump_to_a_label_of_an_enclosing_iteration_statement)}break;case 245:if(242===n.kind&&!n.label)return!1;break;default:if(e.isIterationStatement(t,!1)&&!n.label)return!1;break}t=t.parent}if(n.label){var a=242===n.kind?e.Diagnostics.A_break_statement_can_only_jump_to_a_label_of_an_enclosing_statement:e.Diagnostics.A_continue_statement_can_only_jump_to_a_label_of_an_enclosing_iteration_statement;return XO(n,a)}a=242===n.kind?e.Diagnostics.A_break_statement_can_only_be_used_within_an_enclosing_iteration_or_switch_statement:e.Diagnostics.A_continue_statement_can_only_be_used_within_an_enclosing_iteration_statement;return XO(n,a)}function OO(n){if(n.dotDotDotToken){var t=n.parent.elements;if(n!==e.last(t))return XO(n,e.Diagnostics.A_rest_element_must_be_last_in_a_destructuring_pattern);if(ZR(t,e.Diagnostics.A_rest_parameter_or_binding_pattern_may_not_have_a_trailing_comma),n.propertyName)return XO(n.name,e.Diagnostics.A_rest_element_cannot_have_a_property_name)}if(n.dotDotDotToken&&n.initializer)return qO(n,n.initializer.pos-1,1,e.Diagnostics.A_rest_element_cannot_have_an_initializer)}function wO(n){return e.isStringOrNumericLiteralLike(n)||215===n.kind&&40===n.operator&&8===n.operand.kind}function PO(e){return 9===e.kind||215===e.kind&&40===e.operator&&9===e.operand.kind}function MO(n){if((e.isPropertyAccessExpression(n)||e.isElementAccessExpression(n)&&wO(n.argumentExpression))&&e.isEntityNameExpression(n.expression))return!!(1024&$D(n).flags)}function FO(n){var t=n.initializer;if(t){var r=!(wO(t)||MO(t)||109===t.kind||94===t.kind||PO(t)),a=e.isDeclarationReadonly(n)||e.isVariableDeclaration(n)&&e.isVarConst(n);if(!a||n.type)return XO(t,e.Diagnostics.Initializers_are_not_allowed_in_ambient_contexts);if(r)return XO(t,e.Diagnostics.A_const_initializer_in_an_ambient_context_must_be_a_string_or_numeric_literal_or_literal_enum_reference);if(!a||r)return XO(t,e.Diagnostics.Initializers_are_not_allowed_in_ambient_contexts)}}function GO(n){if(239!==n.parent.parent.kind&&240!==n.parent.parent.kind)if(8388608&n.flags)FO(n);else if(!n.initializer){if(e.isBindingPattern(n.name)&&!e.isBindingPattern(n.parent))return XO(n,e.Diagnostics.A_destructuring_declaration_must_have_an_initializer);if(e.isVarConst(n))return XO(n,e.Diagnostics.const_declarations_must_be_initialized)}if(n.exclamationToken&&(233!==n.parent.parent.kind||!n.type||n.initializer||8388608&n.flags)){var t=n.initializer?e.Diagnostics.Declarations_with_initializers_cannot_also_have_definite_assignment_assertions:n.type?e.Diagnostics.A_definite_assignment_assertion_is_not_permitted_in_this_context:e.Diagnostics.Declarations_with_definite_assignment_assertions_must_also_have_type_annotations;return XO(n.exclamationToken,t)}var r=e.getEmitModuleKind(C);r<e.ModuleKind.ES2015&&r!==e.ModuleKind.System&&!(8388608&n.parent.parent.flags)&&e.hasSyntacticModifier(n.parent.parent,1)&&BO(n.name);var a=e.isLet(n)||e.isVarConst(n);return a&&UO(n.name)}function BO(n){if(78===n.kind){if("__esModule"===e.idText(n))return JO("noEmit",n,e.Diagnostics.Identifier_expected_esModule_is_reserved_as_an_exported_marker_when_transforming_ECMAScript_modules)}else for(var t=n.elements,r=0,a=t;r<a.length;r++){var i=a[r];if(!e.isOmittedExpression(i))return BO(i.name)}return!1}function UO(n){if(78===n.kind){if(118===n.originalKeywordKind)return XO(n,e.Diagnostics.let_is_not_allowed_to_be_used_as_a_name_in_let_or_const_declarations)}else for(var t=n.elements,r=0,a=t;r<a.length;r++){var i=a[r];e.isOmittedExpression(i)||UO(i.name)}return!1}function VO(n){var t=n.declarations;return!!ZR(n.declarations)||!n.declarations.length&&qO(n,t.pos,t.end-t.pos,e.Diagnostics.Variable_declaration_list_cannot_be_empty)}function jO(e){switch(e.kind){case 235:case 236:case 237:case 244:case 238:case 239:case 240:return!1;case 246:return jO(e.parent)}return!0}function KO(n){if(!jO(n.parent)){if(e.isLet(n.declarationList))return XO(n,e.Diagnostics.let_declarations_can_only_be_declared_inside_a_block);if(e.isVarConst(n.declarationList))return XO(n,e.Diagnostics.const_declarations_can_only_be_declared_inside_a_block)}}function HO(n){var t=n.name.escapedText;switch(n.keywordToken){case 102:if("target"!==t)return XO(n.name,e.Diagnostics._0_is_not_a_valid_meta_property_for_keyword_1_Did_you_mean_2,n.name.escapedText,e.tokenToString(n.keywordToken),"target");break;case 99:if("meta"!==t)return XO(n.name,e.Diagnostics._0_is_not_a_valid_meta_property_for_keyword_1_Did_you_mean_2,n.name.escapedText,e.tokenToString(n.keywordToken),"meta");break}}function WO(e){return e.parseDiagnostics.length>0}function zO(n,t,r,a,i){var o=e.getSourceFileOfNode(n);if(!WO(o)){var s=e.getSpanOfTokenAtPosition(o,n.pos);return nr.add(e.createFileDiagnostic(o,s.start,s.length,t,r,a,i)),!0}return!1}function qO(n,t,r,a,i,o,s){var c=e.getSourceFileOfNode(n);return!WO(c)&&(nr.add(e.createFileDiagnostic(c,t,r,a,i,o,s)),!0)}function JO(n,t,r,a,i,o){var s=e.getSourceFileOfNode(t);return!WO(s)&&(_r(n,t,r,a,i,o),!0)}function XO(n,t,r,a,i){var o=e.getSourceFileOfNode(n);return!WO(o)&&(nr.add(e.createDiagnosticForNode(n,t,r,a,i)),!0)}function YO(n){var t=e.isInJSFile(n)?e.getJSDocTypeParameterDeclarations(n):void 0,r=n.typeParameters||t&&e.firstOrUndefined(t);if(r){var a=r.pos===r.end?r.pos:e.skipTrivia(e.getSourceFileOfNode(n).text,r.pos);return qO(n,a,r.end-a,e.Diagnostics.Type_parameters_cannot_appear_on_a_constructor_declaration)}}function QO(n){var t=e.getEffectiveReturnTypeNode(n);if(t)return XO(t,e.Diagnostics.Type_annotation_cannot_appear_on_a_constructor_declaration)}function ZO(n){if(e.isClassLike(n.parent)){if(e.isStringLiteral(n.name)&&"constructor"===n.name.text)return XO(n.name,e.Diagnostics.Classes_may_not_have_a_field_named_constructor);if(NO(n.name,e.Diagnostics.A_computed_property_name_in_a_class_property_declaration_must_have_a_simple_literal_type_or_a_unique_symbol_type))return!0;if(F<2&&e.isPrivateIdentifier(n.name))return XO(n.name,e.Diagnostics.Private_identifiers_are_only_available_when_targeting_ECMAScript_2015_and_higher)}else if(254===n.parent.kind){if(NO(n.name,e.Diagnostics.A_computed_property_name_in_an_interface_must_refer_to_an_expression_whose_type_is_a_literal_type_or_a_unique_symbol_type))return!0;if(n.initializer)return XO(n.initializer,e.Diagnostics.An_interface_property_cannot_have_an_initializer)}else if(178===n.parent.kind){if(NO(n.name,e.Diagnostics.A_computed_property_name_in_a_type_literal_must_refer_to_an_expression_whose_type_is_a_literal_type_or_a_unique_symbol_type))return!0;if(n.initializer)return XO(n.initializer,e.Diagnostics.A_type_literal_property_cannot_have_an_initializer)}if(8388608&n.flags&&FO(n),e.isPropertyDeclaration(n)&&n.exclamationToken&&(!e.isClassLike(n.parent)||!n.type||n.initializer||8388608&n.flags||e.hasSyntacticModifier(n,160))){var t=n.initializer?e.Diagnostics.Declarations_with_initializers_cannot_also_have_definite_assignment_assertions:n.type?e.Diagnostics.A_definite_assignment_assertion_is_not_permitted_in_this_context:e.Diagnostics.Declarations_with_definite_assignment_assertions_must_also_have_type_annotations;return XO(n.exclamationToken,t)}}function $O(n){return 254!==n.kind&&255!==n.kind&&262!==n.kind&&261!==n.kind&&268!==n.kind&&267!==n.kind&&260!==n.kind&&!e.hasSyntacticModifier(n,515)&&zO(n,e.Diagnostics.Top_level_declarations_in_d_ts_files_must_start_with_either_a_declare_or_export_modifier)}function ew(n){for(var t=0,r=n.statements;t<r.length;t++){var a=r[t];if((e.isDeclaration(a)||233===a.kind)&&$O(a))return!0}return!1}function nw(e){return!!(8388608&e.flags)&&ew(e)}function tw(n){if(8388608&n.flags){var t=Pr(n);if(!t.hasReportedStatementInAmbientContext&&(e.isFunctionLike(n.parent)||e.isAccessor(n.parent)))return Pr(n).hasReportedStatementInAmbientContext=zO(n,e.Diagnostics.An_implementation_cannot_be_declared_in_ambient_contexts);if(231===n.parent.kind||258===n.parent.kind||298===n.parent.kind){var r=Pr(n.parent);if(!r.hasReportedStatementInAmbientContext)return r.hasReportedStatementInAmbientContext=zO(n,e.Diagnostics.Statements_are_not_allowed_in_ambient_contexts)}}return!1}function rw(n){if(32&n.numericLiteralFlags){var t=void 0;if(F>=1?t=e.Diagnostics.Octal_literals_are_not_available_when_targeting_ECMAScript_5_and_higher_Use_the_syntax_0:e.isChildOfNodeWithKind(n,192)?t=e.Diagnostics.Octal_literal_types_must_use_ES2015_syntax_Use_the_syntax_0:e.isChildOfNodeWithKind(n,292)&&(t=e.Diagnostics.Octal_literals_are_not_allowed_in_enums_members_initializer_Use_the_syntax_0),t){var r=e.isPrefixUnaryExpression(n.parent)&&40===n.parent.operator,a=(r?"-":"")+"0o"+n.text;return XO(r?n.parent:n,t,a)}}return aw(n),!1}function aw(n){if(!(16&n.numericLiteralFlags||n.text.length<=15||-1!==n.text.indexOf("."))){var t=+e.getTextOfNode(n);t<=Math.pow(2,53)-1&&t+1>t||yr(!1,e.createDiagnosticForNode(n,e.Diagnostics.Numeric_literals_with_absolute_values_equal_to_2_53_or_greater_are_too_large_to_be_represented_accurately_as_integers))}}function iw(n){var t=e.isLiteralTypeNode(n.parent)||e.isPrefixUnaryExpression(n.parent)&&e.isLiteralTypeNode(n.parent.parent);return!!(!t&&F<7&&XO(n,e.Diagnostics.BigInt_literals_are_not_available_when_targeting_lower_than_ES2020))}function ow(n,t,r,a,i){var o=e.getSourceFileOfNode(n);if(!WO(o)){var s=e.getSpanOfTokenAtPosition(o,n.pos);return nr.add(e.createFileDiagnostic(o,e.textSpanEnd(s),0,t,r,a,i)),!0}return!1}function sw(){return yn||(yn=[],re.forEach((function(e,n){s.test(n)&&yn.push(e)}))),yn}function cw(n){return!!(n.isTypeOnly&&n.name&&n.namedBindings)&&XO(n,e.Diagnostics.A_type_only_import_can_specify_a_default_import_or_named_bindings_but_not_both)}function lw(n){if(G===e.ModuleKind.ES2015)return XO(n,e.Diagnostics.Dynamic_imports_are_only_supported_when_the_module_flag_is_set_to_es2020_esnext_commonjs_amd_system_or_umd);if(n.typeArguments)return XO(n,e.Diagnostics.Dynamic_import_cannot_have_type_arguments);var t=n.arguments;return 1!==t.length?XO(n,e.Diagnostics.Dynamic_import_must_have_one_specifier_as_an_argument):(ZR(t),!!e.isSpreadElement(t[0])&&XO(t[0],e.Diagnostics.Specifier_of_dynamic_import_cannot_be_spread_element))}function uw(n,t){var r=e.getObjectFlags(n);if(20&r&&1048576&t.flags)return e.find(t.types,(function(t){if(524288&t.flags){var a=r&e.getObjectFlags(t);if(4&a)return n.target===t.target;if(16&a)return!!n.aliasSymbol&&n.aliasSymbol===t.aliasSymbol}return!1}))}function dw(n,t){if(128&e.getObjectFlags(n)&&Zv(t,dy))return e.find(t.types,(function(e){return!dy(e)}))}function pw(n,t){var r=0,a=yu(n,r).length>0||(r=1,yu(n,r).length>0);if(a)return e.find(t.types,(function(e){return yu(e,r).length>0}))}function fw(n,t){for(var r,a=0,i=0,o=t.types;i<o.length;i++){var s=o[i],c=pf([Cf(n),Cf(s)]);if(4194304&c.flags)r=s,a=1/0;else if(1048576&c.flags){var l=e.length(e.filter(c.types,hy));l>=a&&(r=s,a=l)}else hy(c)&&1>=a&&(r=s,a=1)}return r}function mw(e){if(AD(e,67108864)){var n=nb(e,(function(e){return!(131068&e.flags)}));if(!(131072&n.flags))return n}return e}function _w(n,t,r,a){if(1048576&t.flags&&2621440&n.flags){var i=gv(t,n);if(i)return i;var o=wl(n);if(o){var s=pv(o,t);if(s)return kg(t,e.map(s,(function(e){return[function(){return ws(e)},e.escapedName]})),r,void 0,a)}}}}function G(n){return!e.isAccessor(n)}function B(e){return 252!==e.kind&&166!==e.kind||!!e.body}function U(n){switch(n.parent.kind){case 266:case 271:return e.isIdentifier(n);default:return e.isDeclarationName(n)}}function V(e){switch(e){case 0:return"yieldType";case 1:return"returnType";case 2:return"nextType"}}function j(e){return!!(1&e.flags)}function K(e){return!!(2&e.flags)}e.getNodeId=w,e.getSymbolId=P,e.isInstantiatedModule=M,e.createTypeChecker=F,function(e){e.JSX="JSX",e.IntrinsicElements="IntrinsicElements",e.ElementClass="ElementClass",e.ElementAttributesPropertyNameContainer="ElementAttributesProperty",e.ElementChildrenAttributeNameContainer="ElementChildrenAttribute",e.Element="Element",e.IntrinsicAttributes="IntrinsicAttributes",e.IntrinsicClassAttributes="IntrinsicClassAttributes",e.LibraryManagedAttributes="LibraryManagedAttributes"}(N||(N={})),e.signatureHasRestParameter=j,e.signatureHasLiteralTypes=K}(d||(d={})),function(e){function n(n,t,r,a){if(void 0===n||void 0===t)return n;var i,o=t(n);return o===n?n:void 0!==o?(i=e.isArray(o)?(a||p)(o):o,e.Debug.assertNode(i,r),i):void 0}function t(n,t,r,a,i){if(void 0===n||void 0===t)return n;var o,s,c=n.length;(void 0===a||a<0)&&(a=0),(void 0===i||i>c-a)&&(i=c-a);var l=-1,u=-1;(a>0||i<c)&&(o=[],s=n.hasTrailingComma&&a+i===c);for(var d=0;d<i;d++){var p=n[d+a],f=void 0!==p?t(p):void 0;if((void 0!==o||void 0===f||f!==p)&&(void 0===o&&(o=n.slice(0,d),s=n.hasTrailingComma,l=n.pos,u=n.end),f))if(e.isArray(f))for(var m=0,_=f;m<_.length;m++){var g=_[m];e.Debug.assertNode(g,r),o.push(g)}else e.Debug.assertNode(f,r),o.push(f)}if(o){var y=e.factory.createNodeArray(o,s);return e.setTextRangePosEnd(y,l,u),y}return n}function r(n,r,a,i,o,s){return void 0===s&&(s=t),a.startLexicalEnvironment(),n=s(n,r,e.isStatement,i),o&&(n=a.factory.ensureUseStrict(n)),e.factory.mergeLexicalEnvironment(n,a.endLexicalEnvironment())}function a(n,r,a,o){var s;return void 0===o&&(o=t),a.startLexicalEnvironment(),n&&(a.setLexicalEnvironmentFlags(1,!0),s=o(n,r,e.isParameterDeclaration),2&a.getLexicalEnvironmentFlags()&&e.getEmitScriptTarget(a.getCompilerOptions())>=2&&(s=i(s,a)),a.setLexicalEnvironmentFlags(1,!1)),a.suspendLexicalEnvironment(),s}function i(n,t){for(var r,a=0;a<n.length;a++){var i=n[a],s=o(i,t);(r||s!==i)&&(r||(r=n.slice(0,a)),r[a]=s)}return r?e.setTextRange(t.factory.createNodeArray(r,n.hasTrailingComma),n):n}function o(n,t){return n.dotDotDotToken?n:e.isBindingPattern(n.name)?s(n,t):n.initializer?c(n,n.name,n.initializer,t):n}function s(e,n){var t=n.factory;return n.addInitializationStatement(t.createVariableStatement(void 0,t.createVariableDeclarationList([t.createVariableDeclaration(e.name,void 0,e.type,e.initializer?t.createConditionalExpression(t.createStrictEquality(t.getGeneratedNameForNode(e),t.createVoidZero()),void 0,e.initializer,void 0,t.getGeneratedNameForNode(e)):t.getGeneratedNameForNode(e))]))),t.updateParameterDeclaration(e,e.decorators,e.modifiers,e.dotDotDotToken,t.getGeneratedNameForNode(e),e.questionToken,e.type,void 0)}function c(n,t,r,a){var i=a.factory;return a.addInitializationStatement(i.createIfStatement(i.createTypeCheck(i.cloneNode(t),"undefined"),e.setEmitFlags(e.setTextRange(i.createBlock([i.createExpressionStatement(e.setEmitFlags(e.setTextRange(i.createAssignment(e.setEmitFlags(i.cloneNode(t),48),e.setEmitFlags(r,1584|e.getEmitFlags(r))),n),1536))]),n),1953))),i.updateParameterDeclaration(n,n.decorators,n.modifiers,n.dotDotDotToken,n.name,n.questionToken,n.type,void 0)}function l(t,r,a,i){void 0===i&&(i=n),a.resumeLexicalEnvironment();var o=i(t,r,e.isConciseBody),s=a.endLexicalEnvironment();if(e.some(s)){if(!o)return a.factory.createBlock(s);var c=a.factory.converters.convertToFunctionBlock(o),l=e.factory.mergeLexicalEnvironment(c.statements,s);return a.factory.updateBlock(c,l)}return o}function u(t,r,a){a.startBlockScope();var i=n(t,r,e.isStatement,a.factory.liftToBlock),o=a.endBlockScope();return e.some(o)?e.isBlock(i)?(o.push.apply(o,i.statements),a.factory.updateBlock(i,o)):(o.push(i),a.factory.createBlock(o)):i}function d(i,o,s,c,d,p){if(void 0===c&&(c=t),void 0===p&&(p=n),void 0!==i){var f=i.kind;if(f>0&&f<=157||188===f)return i;var m=s.factory;switch(f){case 78:return e.Debug.type(i),m.updateIdentifier(i,c(i.typeArguments,o,e.isTypeNodeOrTypeParameterDeclaration));case 158:return e.Debug.type(i),m.updateQualifiedName(i,p(i.left,o,e.isEntityName),p(i.right,o,e.isIdentifier));case 159:return e.Debug.type(i),m.updateComputedPropertyName(i,p(i.expression,o,e.isExpression));case 160:return e.Debug.type(i),m.updateTypeParameterDeclaration(i,p(i.name,o,e.isIdentifier),p(i.constraint,o,e.isTypeNode),p(i.default,o,e.isTypeNode));case 161:return e.Debug.type(i),m.updateParameterDeclaration(i,c(i.decorators,o,e.isDecorator),c(i.modifiers,o,e.isModifier),p(i.dotDotDotToken,d,e.isDotDotDotToken),p(i.name,o,e.isBindingName),p(i.questionToken,d,e.isQuestionToken),p(i.type,o,e.isTypeNode),p(i.initializer,o,e.isExpression));case 162:return e.Debug.type(i),m.updateDecorator(i,p(i.expression,o,e.isExpression));case 163:return e.Debug.type(i),m.updatePropertySignature(i,c(i.modifiers,o,e.isModifier),p(i.name,o,e.isPropertyName),p(i.questionToken,d,e.isToken),p(i.type,o,e.isTypeNode));case 164:return e.Debug.type(i),m.updatePropertyDeclaration(i,c(i.decorators,o,e.isDecorator),c(i.modifiers,o,e.isModifier),p(i.name,o,e.isPropertyName),p(i.questionToken||i.exclamationToken,d,e.isQuestionOrExclamationToken),p(i.type,o,e.isTypeNode),p(i.initializer,o,e.isExpression));case 165:return e.Debug.type(i),m.updateMethodSignature(i,c(i.modifiers,o,e.isModifier),p(i.name,o,e.isPropertyName),p(i.questionToken,d,e.isQuestionToken),c(i.typeParameters,o,e.isTypeParameterDeclaration),c(i.parameters,o,e.isParameterDeclaration),p(i.type,o,e.isTypeNode));case 166:return e.Debug.type(i),m.updateMethodDeclaration(i,c(i.decorators,o,e.isDecorator),c(i.modifiers,o,e.isModifier),p(i.asteriskToken,d,e.isAsteriskToken),p(i.name,o,e.isPropertyName),p(i.questionToken,d,e.isQuestionToken),c(i.typeParameters,o,e.isTypeParameterDeclaration),a(i.parameters,o,s,c),p(i.type,o,e.isTypeNode),l(i.body,o,s,p));case 167:return e.Debug.type(i),m.updateConstructorDeclaration(i,c(i.decorators,o,e.isDecorator),c(i.modifiers,o,e.isModifier),a(i.parameters,o,s,c),l(i.body,o,s,p));case 168:return e.Debug.type(i),m.updateGetAccessorDeclaration(i,c(i.decorators,o,e.isDecorator),c(i.modifiers,o,e.isModifier),p(i.name,o,e.isPropertyName),a(i.parameters,o,s,c),p(i.type,o,e.isTypeNode),l(i.body,o,s,p));case 169:return e.Debug.type(i),m.updateSetAccessorDeclaration(i,c(i.decorators,o,e.isDecorator),c(i.modifiers,o,e.isModifier),p(i.name,o,e.isPropertyName),a(i.parameters,o,s,c),l(i.body,o,s,p));case 170:return e.Debug.type(i),m.updateCallSignature(i,c(i.typeParameters,o,e.isTypeParameterDeclaration),c(i.parameters,o,e.isParameterDeclaration),p(i.type,o,e.isTypeNode));case 171:return e.Debug.type(i),m.updateConstructSignature(i,c(i.typeParameters,o,e.isTypeParameterDeclaration),c(i.parameters,o,e.isParameterDeclaration),p(i.type,o,e.isTypeNode));case 172:return e.Debug.type(i),m.updateIndexSignature(i,c(i.decorators,o,e.isDecorator),c(i.modifiers,o,e.isModifier),c(i.parameters,o,e.isParameterDeclaration),p(i.type,o,e.isTypeNode));case 173:return e.Debug.type(i),m.updateTypePredicateNode(i,p(i.assertsModifier,o,e.isAssertsKeyword),p(i.parameterName,o,e.isIdentifierOrThisTypeNode),p(i.type,o,e.isTypeNode));case 174:return e.Debug.type(i),m.updateTypeReferenceNode(i,p(i.typeName,o,e.isEntityName),c(i.typeArguments,o,e.isTypeNode));case 175:return e.Debug.type(i),m.updateFunctionTypeNode(i,c(i.typeParameters,o,e.isTypeParameterDeclaration),c(i.parameters,o,e.isParameterDeclaration),p(i.type,o,e.isTypeNode));case 176:return e.Debug.type(i),m.updateConstructorTypeNode(i,c(i.modifiers,o,e.isModifier),c(i.typeParameters,o,e.isTypeParameterDeclaration),c(i.parameters,o,e.isParameterDeclaration),p(i.type,o,e.isTypeNode));case 177:return e.Debug.type(i),m.updateTypeQueryNode(i,p(i.exprName,o,e.isEntityName));case 178:return e.Debug.type(i),m.updateTypeLiteralNode(i,c(i.members,o,e.isTypeElement));case 179:return e.Debug.type(i),m.updateArrayTypeNode(i,p(i.elementType,o,e.isTypeNode));case 180:return e.Debug.type(i),m.updateTupleTypeNode(i,c(i.elements,o,e.isTypeNode));case 181:return e.Debug.type(i),m.updateOptionalTypeNode(i,p(i.type,o,e.isTypeNode));case 182:return e.Debug.type(i),m.updateRestTypeNode(i,p(i.type,o,e.isTypeNode));case 183:return e.Debug.type(i),m.updateUnionTypeNode(i,c(i.types,o,e.isTypeNode));case 184:return e.Debug.type(i),m.updateIntersectionTypeNode(i,c(i.types,o,e.isTypeNode));case 185:return e.Debug.type(i),m.updateConditionalTypeNode(i,p(i.checkType,o,e.isTypeNode),p(i.extendsType,o,e.isTypeNode),p(i.trueType,o,e.isTypeNode),p(i.falseType,o,e.isTypeNode));case 186:return e.Debug.type(i),m.updateInferTypeNode(i,p(i.typeParameter,o,e.isTypeParameterDeclaration));case 196:return e.Debug.type(i),m.updateImportTypeNode(i,p(i.argument,o,e.isTypeNode),p(i.qualifier,o,e.isEntityName),t(i.typeArguments,o,e.isTypeNode),i.isTypeOf);case 193:return e.Debug.type(i),m.updateNamedTupleMember(i,n(i.dotDotDotToken,o,e.isDotDotDotToken),n(i.name,o,e.isIdentifier),n(i.questionToken,o,e.isQuestionToken),n(i.type,o,e.isTypeNode));case 187:return e.Debug.type(i),m.updateParenthesizedType(i,p(i.type,o,e.isTypeNode));case 189:return e.Debug.type(i),m.updateTypeOperatorNode(i,p(i.type,o,e.isTypeNode));case 190:return e.Debug.type(i),m.updateIndexedAccessTypeNode(i,p(i.objectType,o,e.isTypeNode),p(i.indexType,o,e.isTypeNode));case 191:return e.Debug.type(i),m.updateMappedTypeNode(i,p(i.readonlyToken,d,e.isReadonlyKeywordOrPlusOrMinusToken),p(i.typeParameter,o,e.isTypeParameterDeclaration),p(i.nameType,o,e.isTypeNode),p(i.questionToken,d,e.isQuestionOrPlusOrMinusToken),p(i.type,o,e.isTypeNode));case 192:return e.Debug.type(i),m.updateLiteralTypeNode(i,p(i.literal,o,e.isExpression));case 194:return e.Debug.type(i),m.updateTemplateLiteralType(i,p(i.head,o,e.isTemplateHead),c(i.templateSpans,o,e.isTemplateLiteralTypeSpan));case 195:return e.Debug.type(i),m.updateTemplateLiteralTypeSpan(i,p(i.type,o,e.isTypeNode),p(i.literal,o,e.isTemplateMiddleOrTemplateTail));case 197:return e.Debug.type(i),m.updateObjectBindingPattern(i,c(i.elements,o,e.isBindingElement));case 198:return e.Debug.type(i),m.updateArrayBindingPattern(i,c(i.elements,o,e.isArrayBindingElement));case 199:return e.Debug.type(i),m.updateBindingElement(i,p(i.dotDotDotToken,d,e.isDotDotDotToken),p(i.propertyName,o,e.isPropertyName),p(i.name,o,e.isBindingName),p(i.initializer,o,e.isExpression));case 200:return e.Debug.type(i),m.updateArrayLiteralExpression(i,c(i.elements,o,e.isExpression));case 201:return e.Debug.type(i),m.updateObjectLiteralExpression(i,c(i.properties,o,e.isObjectLiteralElementLike));case 202:return 32&i.flags?(e.Debug.type(i),m.updatePropertyAccessChain(i,p(i.expression,o,e.isExpression),p(i.questionDotToken,d,e.isQuestionDotToken),p(i.name,o,e.isMemberName))):(e.Debug.type(i),m.updatePropertyAccessExpression(i,p(i.expression,o,e.isExpression),p(i.name,o,e.isMemberName)));case 203:return 32&i.flags?(e.Debug.type(i),m.updateElementAccessChain(i,p(i.expression,o,e.isExpression),p(i.questionDotToken,d,e.isQuestionDotToken),p(i.argumentExpression,o,e.isExpression))):(e.Debug.type(i),m.updateElementAccessExpression(i,p(i.expression,o,e.isExpression),p(i.argumentExpression,o,e.isExpression)));case 204:return 32&i.flags?(e.Debug.type(i),m.updateCallChain(i,p(i.expression,o,e.isExpression),p(i.questionDotToken,d,e.isQuestionDotToken),c(i.typeArguments,o,e.isTypeNode),c(i.arguments,o,e.isExpression))):(e.Debug.type(i),m.updateCallExpression(i,p(i.expression,o,e.isExpression),c(i.typeArguments,o,e.isTypeNode),c(i.arguments,o,e.isExpression)));case 205:return e.Debug.type(i),m.updateNewExpression(i,p(i.expression,o,e.isExpression),c(i.typeArguments,o,e.isTypeNode),c(i.arguments,o,e.isExpression));case 206:return e.Debug.type(i),m.updateTaggedTemplateExpression(i,p(i.tag,o,e.isExpression),t(i.typeArguments,o,e.isTypeNode),p(i.template,o,e.isTemplateLiteral));case 207:return e.Debug.type(i),m.updateTypeAssertion(i,p(i.type,o,e.isTypeNode),p(i.expression,o,e.isExpression));case 208:return e.Debug.type(i),m.updateParenthesizedExpression(i,p(i.expression,o,e.isExpression));case 209:return e.Debug.type(i),m.updateFunctionExpression(i,c(i.modifiers,o,e.isModifier),p(i.asteriskToken,d,e.isAsteriskToken),p(i.name,o,e.isIdentifier),c(i.typeParameters,o,e.isTypeParameterDeclaration),a(i.parameters,o,s,c),p(i.type,o,e.isTypeNode),l(i.body,o,s,p));case 210:return e.Debug.type(i),m.updateArrowFunction(i,c(i.modifiers,o,e.isModifier),c(i.typeParameters,o,e.isTypeParameterDeclaration),a(i.parameters,o,s,c),p(i.type,o,e.isTypeNode),p(i.equalsGreaterThanToken,d,e.isEqualsGreaterThanToken),l(i.body,o,s,p));case 211:return e.Debug.type(i),m.updateDeleteExpression(i,p(i.expression,o,e.isExpression));case 212:return e.Debug.type(i),m.updateTypeOfExpression(i,p(i.expression,o,e.isExpression));case 213:return e.Debug.type(i),m.updateVoidExpression(i,p(i.expression,o,e.isExpression));case 214:return e.Debug.type(i),m.updateAwaitExpression(i,p(i.expression,o,e.isExpression));case 215:return e.Debug.type(i),m.updatePrefixUnaryExpression(i,p(i.operand,o,e.isExpression));case 216:return e.Debug.type(i),m.updatePostfixUnaryExpression(i,p(i.operand,o,e.isExpression));case 217:return e.Debug.type(i),m.updateBinaryExpression(i,p(i.left,o,e.isExpression),p(i.operatorToken,d,e.isBinaryOperatorToken),p(i.right,o,e.isExpression));case 218:return e.Debug.type(i),m.updateConditionalExpression(i,p(i.condition,o,e.isExpression),p(i.questionToken,d,e.isQuestionToken),p(i.whenTrue,o,e.isExpression),p(i.colonToken,d,e.isColonToken),p(i.whenFalse,o,e.isExpression));case 219:return e.Debug.type(i),m.updateTemplateExpression(i,p(i.head,o,e.isTemplateHead),c(i.templateSpans,o,e.isTemplateSpan));case 220:return e.Debug.type(i),m.updateYieldExpression(i,p(i.asteriskToken,d,e.isAsteriskToken),p(i.expression,o,e.isExpression));case 221:return e.Debug.type(i),m.updateSpreadElement(i,p(i.expression,o,e.isExpression));case 222:return e.Debug.type(i),m.updateClassExpression(i,c(i.decorators,o,e.isDecorator),c(i.modifiers,o,e.isModifier),p(i.name,o,e.isIdentifier),c(i.typeParameters,o,e.isTypeParameterDeclaration),c(i.heritageClauses,o,e.isHeritageClause),c(i.members,o,e.isClassElement));case 224:return e.Debug.type(i),m.updateExpressionWithTypeArguments(i,p(i.expression,o,e.isExpression),c(i.typeArguments,o,e.isTypeNode));case 225:return e.Debug.type(i),m.updateAsExpression(i,p(i.expression,o,e.isExpression),p(i.type,o,e.isTypeNode));case 226:return 32&i.flags?(e.Debug.type(i),m.updateNonNullChain(i,p(i.expression,o,e.isExpression))):(e.Debug.type(i),m.updateNonNullExpression(i,p(i.expression,o,e.isExpression)));case 227:return e.Debug.type(i),m.updateMetaProperty(i,p(i.name,o,e.isIdentifier));case 229:return e.Debug.type(i),m.updateTemplateSpan(i,p(i.expression,o,e.isExpression),p(i.literal,o,e.isTemplateMiddleOrTemplateTail));case 231:return e.Debug.type(i),m.updateBlock(i,c(i.statements,o,e.isStatement));case 233:return e.Debug.type(i),m.updateVariableStatement(i,c(i.modifiers,o,e.isModifier),p(i.declarationList,o,e.isVariableDeclarationList));case 234:return e.Debug.type(i),m.updateExpressionStatement(i,p(i.expression,o,e.isExpression));case 235:return e.Debug.type(i),m.updateIfStatement(i,p(i.expression,o,e.isExpression),p(i.thenStatement,o,e.isStatement,m.liftToBlock),p(i.elseStatement,o,e.isStatement,m.liftToBlock));case 236:return e.Debug.type(i),m.updateDoStatement(i,u(i.statement,o,s),p(i.expression,o,e.isExpression));case 237:return e.Debug.type(i),m.updateWhileStatement(i,p(i.expression,o,e.isExpression),u(i.statement,o,s));case 238:return e.Debug.type(i),m.updateForStatement(i,p(i.initializer,o,e.isForInitializer),p(i.condition,o,e.isExpression),p(i.incrementor,o,e.isExpression),u(i.statement,o,s));case 239:return e.Debug.type(i),m.updateForInStatement(i,p(i.initializer,o,e.isForInitializer),p(i.expression,o,e.isExpression),u(i.statement,o,s));case 240:return e.Debug.type(i),m.updateForOfStatement(i,p(i.awaitModifier,d,e.isAwaitKeyword),p(i.initializer,o,e.isForInitializer),p(i.expression,o,e.isExpression),u(i.statement,o,s));case 241:return e.Debug.type(i),m.updateContinueStatement(i,p(i.label,o,e.isIdentifier));case 242:return e.Debug.type(i),m.updateBreakStatement(i,p(i.label,o,e.isIdentifier));case 243:return e.Debug.type(i),m.updateReturnStatement(i,p(i.expression,o,e.isExpression));case 244:return e.Debug.type(i),m.updateWithStatement(i,p(i.expression,o,e.isExpression),p(i.statement,o,e.isStatement,m.liftToBlock));case 245:return e.Debug.type(i),m.updateSwitchStatement(i,p(i.expression,o,e.isExpression),p(i.caseBlock,o,e.isCaseBlock));case 246:return e.Debug.type(i),m.updateLabeledStatement(i,p(i.label,o,e.isIdentifier),p(i.statement,o,e.isStatement,m.liftToBlock));case 247:return e.Debug.type(i),m.updateThrowStatement(i,p(i.expression,o,e.isExpression));case 248:return e.Debug.type(i),m.updateTryStatement(i,p(i.tryBlock,o,e.isBlock),p(i.catchClause,o,e.isCatchClause),p(i.finallyBlock,o,e.isBlock));case 250:return e.Debug.type(i),m.updateVariableDeclaration(i,p(i.name,o,e.isBindingName),p(i.exclamationToken,d,e.isExclamationToken),p(i.type,o,e.isTypeNode),p(i.initializer,o,e.isExpression));case 251:return e.Debug.type(i),m.updateVariableDeclarationList(i,c(i.declarations,o,e.isVariableDeclaration));case 252:return e.Debug.type(i),m.updateFunctionDeclaration(i,c(i.decorators,o,e.isDecorator),c(i.modifiers,o,e.isModifier),p(i.asteriskToken,d,e.isAsteriskToken),p(i.name,o,e.isIdentifier),c(i.typeParameters,o,e.isTypeParameterDeclaration),a(i.parameters,o,s,c),p(i.type,o,e.isTypeNode),l(i.body,o,s,p));case 253:return e.Debug.type(i),m.updateClassDeclaration(i,c(i.decorators,o,e.isDecorator),c(i.modifiers,o,e.isModifier),p(i.name,o,e.isIdentifier),c(i.typeParameters,o,e.isTypeParameterDeclaration),c(i.heritageClauses,o,e.isHeritageClause),c(i.members,o,e.isClassElement));case 254:return e.Debug.type(i),m.updateInterfaceDeclaration(i,c(i.decorators,o,e.isDecorator),c(i.modifiers,o,e.isModifier),p(i.name,o,e.isIdentifier),c(i.typeParameters,o,e.isTypeParameterDeclaration),c(i.heritageClauses,o,e.isHeritageClause),c(i.members,o,e.isTypeElement));case 255:return e.Debug.type(i),m.updateTypeAliasDeclaration(i,c(i.decorators,o,e.isDecorator),c(i.modifiers,o,e.isModifier),p(i.name,o,e.isIdentifier),c(i.typeParameters,o,e.isTypeParameterDeclaration),p(i.type,o,e.isTypeNode));case 256:return e.Debug.type(i),m.updateEnumDeclaration(i,c(i.decorators,o,e.isDecorator),c(i.modifiers,o,e.isModifier),p(i.name,o,e.isIdentifier),c(i.members,o,e.isEnumMember));case 257:return e.Debug.type(i),m.updateModuleDeclaration(i,c(i.decorators,o,e.isDecorator),c(i.modifiers,o,e.isModifier),p(i.name,o,e.isModuleName),p(i.body,o,e.isModuleBody));case 258:return e.Debug.type(i),m.updateModuleBlock(i,c(i.statements,o,e.isStatement));case 259:return e.Debug.type(i),m.updateCaseBlock(i,c(i.clauses,o,e.isCaseOrDefaultClause));case 260:return e.Debug.type(i),m.updateNamespaceExportDeclaration(i,p(i.name,o,e.isIdentifier));case 261:return e.Debug.type(i),m.updateImportEqualsDeclaration(i,c(i.decorators,o,e.isDecorator),c(i.modifiers,o,e.isModifier),i.isTypeOnly,p(i.name,o,e.isIdentifier),p(i.moduleReference,o,e.isModuleReference));case 262:return e.Debug.type(i),m.updateImportDeclaration(i,c(i.decorators,o,e.isDecorator),c(i.modifiers,o,e.isModifier),p(i.importClause,o,e.isImportClause),p(i.moduleSpecifier,o,e.isExpression));case 263:return e.Debug.type(i),m.updateImportClause(i,i.isTypeOnly,p(i.name,o,e.isIdentifier),p(i.namedBindings,o,e.isNamedImportBindings));case 264:return e.Debug.type(i),m.updateNamespaceImport(i,p(i.name,o,e.isIdentifier));case 270:return e.Debug.type(i),m.updateNamespaceExport(i,p(i.name,o,e.isIdentifier));case 265:return e.Debug.type(i),m.updateNamedImports(i,c(i.elements,o,e.isImportSpecifier));case 266:return e.Debug.type(i),m.updateImportSpecifier(i,p(i.propertyName,o,e.isIdentifier),p(i.name,o,e.isIdentifier));case 267:return e.Debug.type(i),m.updateExportAssignment(i,c(i.decorators,o,e.isDecorator),c(i.modifiers,o,e.isModifier),p(i.expression,o,e.isExpression));case 268:return e.Debug.type(i),m.updateExportDeclaration(i,c(i.decorators,o,e.isDecorator),c(i.modifiers,o,e.isModifier),i.isTypeOnly,p(i.exportClause,o,e.isNamedExportBindings),p(i.moduleSpecifier,o,e.isExpression));case 269:return e.Debug.type(i),m.updateNamedExports(i,c(i.elements,o,e.isExportSpecifier));case 271:return e.Debug.type(i),m.updateExportSpecifier(i,p(i.propertyName,o,e.isIdentifier),p(i.name,o,e.isIdentifier));case 273:return e.Debug.type(i),m.updateExternalModuleReference(i,p(i.expression,o,e.isExpression));case 274:return e.Debug.type(i),m.updateJsxElement(i,p(i.openingElement,o,e.isJsxOpeningElement),c(i.children,o,e.isJsxChild),p(i.closingElement,o,e.isJsxClosingElement));case 275:return e.Debug.type(i),m.updateJsxSelfClosingElement(i,p(i.tagName,o,e.isJsxTagNameExpression),c(i.typeArguments,o,e.isTypeNode),p(i.attributes,o,e.isJsxAttributes));case 276:return e.Debug.type(i),m.updateJsxOpeningElement(i,p(i.tagName,o,e.isJsxTagNameExpression),c(i.typeArguments,o,e.isTypeNode),p(i.attributes,o,e.isJsxAttributes));case 277:return e.Debug.type(i),m.updateJsxClosingElement(i,p(i.tagName,o,e.isJsxTagNameExpression));case 278:return e.Debug.type(i),m.updateJsxFragment(i,p(i.openingFragment,o,e.isJsxOpeningFragment),c(i.children,o,e.isJsxChild),p(i.closingFragment,o,e.isJsxClosingFragment));case 281:return e.Debug.type(i),m.updateJsxAttribute(i,p(i.name,o,e.isIdentifier),p(i.initializer,o,e.isStringLiteralOrJsxExpression));case 282:return e.Debug.type(i),m.updateJsxAttributes(i,c(i.properties,o,e.isJsxAttributeLike));case 283:return e.Debug.type(i),m.updateJsxSpreadAttribute(i,p(i.expression,o,e.isExpression));case 284:return e.Debug.type(i),m.updateJsxExpression(i,p(i.expression,o,e.isExpression));case 285:return e.Debug.type(i),m.updateCaseClause(i,p(i.expression,o,e.isExpression),c(i.statements,o,e.isStatement));case 286:return e.Debug.type(i),m.updateDefaultClause(i,c(i.statements,o,e.isStatement));case 287:return e.Debug.type(i),m.updateHeritageClause(i,c(i.types,o,e.isExpressionWithTypeArguments));case 288:return e.Debug.type(i),m.updateCatchClause(i,p(i.variableDeclaration,o,e.isVariableDeclaration),p(i.block,o,e.isBlock));case 289:return e.Debug.type(i),m.updatePropertyAssignment(i,p(i.name,o,e.isPropertyName),p(i.initializer,o,e.isExpression));case 290:return e.Debug.type(i),m.updateShorthandPropertyAssignment(i,p(i.name,o,e.isIdentifier),p(i.objectAssignmentInitializer,o,e.isExpression));case 291:return e.Debug.type(i),m.updateSpreadAssignment(i,p(i.expression,o,e.isExpression));case 292:return e.Debug.type(i),m.updateEnumMember(i,p(i.name,o,e.isPropertyName),p(i.initializer,o,e.isExpression));case 298:return e.Debug.type(i),m.updateSourceFile(i,r(i.statements,o,s));case 340:return e.Debug.type(i),m.updatePartiallyEmittedExpression(i,p(i.expression,o,e.isExpression));case 341:return e.Debug.type(i),m.updateCommaListExpression(i,c(i.elements,o,e.isExpression));default:return i}}}function p(n){return e.Debug.assert(n.length<=1,"Too many nodes written to output."),e.singleOrUndefined(n)}e.visitNode=n,e.visitNodes=t,e.visitLexicalEnvironment=r,e.visitParameterList=a,e.visitFunctionBody=l,e.visitIterationBody=u,e.visitEachChild=d}(d||(d={})),function(e){function n(n,t,r,a,i){var o,s,c=i.extendedDiagnostics?e.performance.createTimer("Source Map","beforeSourcemap","afterSourcemap"):e.performance.nullTimer,u=c.enter,d=c.exit,p=[],f=[],_=new e.Map,g=[],y="",h=0,v=0,b=0,E=0,T=0,S=0,x=!1,L=0,D=0,A=0,C=0,I=0,N=0,k=!1,R=!1,O=!1;return{getSources:function(){return p},addSource:w,setSourceContent:P,addName:M,addMapping:B,appendSourceMap:U,toJSON:K,toString:function(){return JSON.stringify(K())}};function w(t){u();var r=e.getRelativePathToDirectoryOrUrl(a,t,n.getCurrentDirectory(),n.getCanonicalFileName,!0),i=_.get(r);return void 0===i&&(i=f.length,f.push(r),p.push(t),_.set(r,i)),d(),i}function P(e,n){if(u(),null!==n){o||(o=[]);while(o.length<e)o.push(null);o[e]=n}d()}function M(n){u(),s||(s=new e.Map);var t=s.get(n);return void 0===t&&(t=g.length,g.push(n),s.set(n,t)),d(),t}function F(e,n){return!k||L!==e||D!==n}function G(e,n,t){return void 0!==e&&void 0!==n&&void 0!==t&&A===e&&(C>n||C===n&&I>t)}function B(n,t,r,a,i,o){e.Debug.assert(n>=L,"generatedLine cannot backtrack"),e.Debug.assert(t>=0,"generatedCharacter cannot be negative"),e.Debug.assert(void 0===r||r>=0,"sourceIndex cannot be negative"),e.Debug.assert(void 0===a||a>=0,"sourceLine cannot be negative"),e.Debug.assert(void 0===i||i>=0,"sourceCharacter cannot be negative"),u(),(F(n,t)||G(r,a,i))&&(j(),L=n,D=t,R=!1,O=!1,k=!0),void 0!==r&&void 0!==a&&void 0!==i&&(A=r,C=a,I=i,R=!0,void 0!==o&&(N=o,O=!0)),d()}function U(n,t,r,a,i,o){e.Debug.assert(n>=L,"generatedLine cannot backtrack"),e.Debug.assert(t>=0,"generatedCharacter cannot be negative"),u();for(var s,c=[],p=l(r.mappings),f=p.next();!f.done;f=p.next()){var m=f.value;if(o&&(m.generatedLine>o.line||m.generatedLine===o.line&&m.generatedCharacter>o.character))break;if(!i||!(m.generatedLine<i.line||i.line===m.generatedLine&&m.generatedCharacter<i.character)){var _=void 0,g=void 0,y=void 0,h=void 0;if(void 0!==m.sourceIndex){if(_=c[m.sourceIndex],void 0===_){var v=r.sources[m.sourceIndex],b=r.sourceRoot?e.combinePaths(r.sourceRoot,v):v,E=e.combinePaths(e.getDirectoryPath(a),b);c[m.sourceIndex]=_=w(E),r.sourcesContent&&"string"===typeof r.sourcesContent[m.sourceIndex]&&P(_,r.sourcesContent[m.sourceIndex])}g=m.sourceLine,y=m.sourceCharacter,r.names&&void 0!==m.nameIndex&&(s||(s=[]),h=s[m.nameIndex],void 0===h&&(s[m.nameIndex]=h=M(r.names[m.nameIndex])))}var T=m.generatedLine-(i?i.line:0),S=T+n,x=i&&i.line===m.generatedLine?m.generatedCharacter-i.character:m.generatedCharacter,D=0===T?x+t:x;B(S,D,_,g,y,h)}}d()}function V(){return!x||h!==L||v!==D||b!==A||E!==C||T!==I||S!==N}function j(){if(k&&V()){if(u(),h<L)do{y+=";",h++,v=0}while(h<L);else e.Debug.assertEqual(h,L,"generatedLine cannot backtrack"),x&&(y+=",");y+=m(D-v),v=D,R&&(y+=m(A-b),b=A,y+=m(C-E),E=C,y+=m(I-T),T=I,O&&(y+=m(N-S),S=N)),x=!0,d()}}function K(){return j(),{version:3,file:t,sourceRoot:r,sources:f,names:g,mappings:y,sourcesContent:o}}}e.createSourceMapGenerator=n;var t=/^\/\/[@#] source[M]appingURL=(.+)\s*$/,r=/^\s*(\/\/[@#] .*)?$/;function a(e,n){return{getLineCount:function(){return n.length},getLineText:function(t){return e.substring(n[t],n[t+1])}}}function i(e){for(var n=e.getLineCount()-1;n>=0;n--){var a=e.getLineText(n),i=t.exec(a);if(i)return i[1];if(!a.match(r))break}}function o(e){return"string"===typeof e||null===e}function s(n){return null!==n&&"object"===typeof n&&3===n.version&&"string"===typeof n.file&&"string"===typeof n.mappings&&e.isArray(n.sources)&&e.every(n.sources,e.isString)&&(void 0===n.sourceRoot||null===n.sourceRoot||"string"===typeof n.sourceRoot)&&(void 0===n.sourcesContent||null===n.sourcesContent||e.isArray(n.sourcesContent)&&e.every(n.sourcesContent,o))&&(void 0===n.names||null===n.names||e.isArray(n.names)&&e.every(n.names,e.isString))}function c(e){try{var n=JSON.parse(e);if(s(n))return n}catch(t){}}function l(e){var n,t=!1,r=0,a=0,i=0,o=0,s=0,c=0,l=0;return{get pos(){return r},get error(){return n},get state(){return u(!0,!0)},next:function(){while(!t&&r<e.length){var n=e.charCodeAt(r);if(59!==n){if(44!==n){var p=!1,f=!1;if(i+=y(),_())return d();if(i<0)return m("Invalid generatedCharacter found");if(!g()){if(p=!0,o+=y(),_())return d();if(o<0)return m("Invalid sourceIndex found");if(g())return m("Unsupported Format: No entries after sourceIndex");if(s+=y(),_())return d();if(s<0)return m("Invalid sourceLine found");if(g())return m("Unsupported Format: No entries after sourceLine");if(c+=y(),_())return d();if(c<0)return m("Invalid sourceCharacter found");if(!g()){if(f=!0,l+=y(),_())return d();if(l<0)return m("Invalid nameIndex found");if(!g())return m("Unsupported Error Format: Entries after nameIndex")}}return{value:u(p,f),done:t}}r++}else a++,i=0,r++}return d()}};function u(e,n){return{generatedLine:a,generatedCharacter:i,sourceIndex:e?o:void 0,sourceLine:e?s:void 0,sourceCharacter:e?c:void 0,nameIndex:n?l:void 0}}function d(){return t=!0,{value:void 0,done:!0}}function p(e){void 0===n&&(n=e)}function m(e){return p(e),d()}function _(){return void 0!==n}function g(){return r===e.length||44===e.charCodeAt(r)||59===e.charCodeAt(r)}function y(){for(var n=!0,t=0,a=0;n;r++){if(r>=e.length)return p("Error in decoding base64VLQFormatDecode, past the mapping string"),-1;var i=f(e.charCodeAt(r));if(-1===i)return p("Invalid character in VLQ"),-1;n=0!==(32&i),a|=(31&i)<<t,t+=5}return 0===(1&a)?a>>=1:(a>>=1,a=-a),a}}function u(e,n){return e===n||e.generatedLine===n.generatedLine&&e.generatedCharacter===n.generatedCharacter&&e.sourceIndex===n.sourceIndex&&e.sourceLine===n.sourceLine&&e.sourceCharacter===n.sourceCharacter&&e.nameIndex===n.nameIndex}function d(e){return void 0!==e.sourceIndex&&void 0!==e.sourceLine&&void 0!==e.sourceCharacter}function p(n){return n>=0&&n<26?65+n:n>=26&&n<52?97+n-26:n>=52&&n<62?48+n-52:62===n?43:63===n?47:e.Debug.fail(n+": not a base64 value")}function f(e){return e>=65&&e<=90?e-65:e>=97&&e<=122?e-97+26:e>=48&&e<=57?e-48+52:43===e?62:47===e?63:-1}function m(e){e<0?e=1+(-e<<1):e<<=1;var n="";do{var t=31&e;e>>=5,e>0&&(t|=32),n+=String.fromCharCode(p(t))}while(e>0);return n}function _(e){return void 0!==e.sourceIndex&&void 0!==e.sourcePosition}function g(e,n){return e.generatedPosition===n.generatedPosition&&e.sourceIndex===n.sourceIndex&&e.sourcePosition===n.sourcePosition}function y(n,t){return e.Debug.assert(n.sourceIndex===t.sourceIndex),e.compareValues(n.sourcePosition,t.sourcePosition)}function h(n,t){return e.compareValues(n.generatedPosition,t.generatedPosition)}function v(e){return e.sourcePosition}function b(e){return e.generatedPosition}function E(n,t,r){var a,i,o,s=e.getDirectoryPath(r),c=t.sourceRoot?e.getNormalizedAbsolutePath(t.sourceRoot,s):s,u=e.getNormalizedAbsolutePath(t.file,s),p=n.getSourceFileLike(u),f=t.sources.map((function(n){return e.getNormalizedAbsolutePath(n,c)})),m=new e.Map(f.map((function(e,t){return[n.getCanonicalFileName(e),t]})));return{getSourcePosition:D,getGeneratedPosition:L};function E(r){var a,i,o=void 0!==p?e.getPositionOfLineAndCharacter(p,r.generatedLine,r.generatedCharacter,!0):-1;if(d(r)){var s=n.getSourceFileLike(f[r.sourceIndex]);a=t.sources[r.sourceIndex],i=void 0!==s?e.getPositionOfLineAndCharacter(s,r.sourceLine,r.sourceCharacter,!0):-1}return{generatedPosition:o,source:a,sourceIndex:r.sourceIndex,sourcePosition:i,nameIndex:r.nameIndex}}function T(){if(void 0===a){var r=l(t.mappings),i=e.arrayFrom(r,E);void 0!==r.error?(n.log&&n.log("Encountered error while decoding sourcemap: "+r.error),a=e.emptyArray):a=i}return a}function S(n){if(void 0===o){for(var t=[],r=0,a=T();r<a.length;r++){var i=a[r];if(_(i)){var s=t[i.sourceIndex];s||(t[i.sourceIndex]=s=[]),s.push(i)}}o=t.map((function(n){return e.sortAndDeduplicate(n,y,g)}))}return o[n]}function x(){if(void 0===i){for(var n=[],t=0,r=T();t<r.length;t++){var a=r[t];n.push(a)}i=e.sortAndDeduplicate(n,h,g)}return i}function L(t){var r=m.get(n.getCanonicalFileName(t.fileName));if(void 0===r)return t;var a=S(r);if(!e.some(a))return t;var i=e.binarySearchKey(a,t.pos,v,e.compareValues);i<0&&(i=~i);var o=a[i];return void 0===o||o.sourceIndex!==r?t:{fileName:u,pos:o.generatedPosition}}function D(n){var t=x();if(!e.some(t))return n;var r=e.binarySearchKey(t,n.pos,b,e.compareValues);r<0&&(r=~r);var a=t[r];return void 0!==a&&_(a)?{fileName:f[a.sourceIndex],pos:a.sourcePosition}:n}}e.getLineInfo=a,e.tryGetSourceMappingURL=i,e.isRawSourceMap=s,e.tryParseRawSourceMap=c,e.decodeMappings=l,e.sameMapping=u,e.isSourceMapping=d,e.createDocumentPositionMapper=E,e.identitySourceMapConsumer={getSourcePosition:e.identity,getGeneratedPosition:e.identity}}(d||(d={})),function(e){function n(n){return n=e.getOriginalNode(n),n?e.getNodeId(n):0}function t(n){return!!n&&(!!e.isNamedImports(n)&&e.some(n.elements,r))}function r(e){return void 0!==e.propertyName&&"default"===e.propertyName.escapedText}function a(n,t){return r;function r(e){return 298===e.kind?t(e):a(e)}function a(r){return n.factory.createBundle(e.map(r.sourceFiles,t),r.prepends)}}function i(n){return!!e.getNamespaceDeclarationNode(n)}function o(n){if(e.getNamespaceDeclarationNode(n))return!0;var t=n.importClause&&n.importClause.namedBindings;if(!t)return!1;if(!e.isNamedImports(t))return!1;for(var a=0,i=0,o=t.elements;i<o.length;i++){var s=o[i];r(s)&&a++}return a>0&&a!==t.elements.length||!!(t.elements.length-a)&&e.isDefaultImport(n)}function s(n){return!o(n)&&(e.isDefaultImport(n)||!!n.importClause&&e.isNamedImports(n.importClause.namedBindings)&&t(n.importClause.namedBindings))}function c(t,r,a,i){for(var c,d,p=[],f=e.createMultiMap(),m=[],_=new e.Map,g=!1,y=!1,h=!1,v=!1,b=0,E=r.statements;b<E.length;b++){var T=E[b];switch(T.kind){case 262:p.push(T),!h&&o(T)&&(h=!0),!v&&s(T)&&(v=!0);break;case 261:273===T.moduleReference.kind&&p.push(T);break;case 268:if(T.moduleSpecifier)if(T.exportClause)if(p.push(T),e.isNamedExports(T.exportClause))C(T);else{var S=T.exportClause.name;_.get(e.idText(S))||(u(m,n(T),S),_.set(e.idText(S),!0),c=e.append(c,S)),h=!0}else p.push(T),y=!0;else C(T);break;case 267:T.isExportEquals&&!d&&(d=T);break;case 233:if(e.hasSyntacticModifier(T,1))for(var x=0,L=T.declarationList.declarations;x<L.length;x++){var D=L[x];c=l(D,_,c)}break;case 252:if(e.hasSyntacticModifier(T,1))if(e.hasSyntacticModifier(T,512))g||(u(m,n(T),t.factory.getDeclarationName(T)),g=!0);else{S=T.name;_.get(e.idText(S))||(u(m,n(T),S),_.set(e.idText(S),!0),c=e.append(c,S))}break;case 253:if(e.hasSyntacticModifier(T,1))if(e.hasSyntacticModifier(T,512))g||(u(m,n(T),t.factory.getDeclarationName(T)),g=!0);else{S=T.name;S&&!_.get(e.idText(S))&&(u(m,n(T),S),_.set(e.idText(S),!0),c=e.append(c,S))}break}}var A=e.createExternalHelpersImportDeclarationIfNeeded(t.factory,t.getEmitHelperFactory(),r,i,y,h,v);return A&&p.unshift(A),{externalImports:p,exportSpecifiers:f,exportEquals:d,hasExportStarsToExportValues:y,exportedBindings:m,exportedNames:c,externalHelpersImportDeclaration:A};function C(t){for(var r=0,i=e.cast(t.exportClause,e.isNamedExports).elements;r<i.length;r++){var o=i[r];if(!_.get(e.idText(o.name))){var s=o.propertyName||o.name;t.moduleSpecifier||f.add(e.idText(s),o);var l=a.getReferencedImportDeclaration(s)||a.getReferencedValueDeclaration(s);l&&u(m,n(l),o.name),_.set(e.idText(o.name),!0),c=e.append(c,o.name)}}}}function l(n,t,r){if(e.isBindingPattern(n.name))for(var a=0,i=n.name.elements;a<i.length;a++){var o=i[a];e.isOmittedExpression(o)||(r=l(o,t,r))}else if(!e.isGeneratedIdentifier(n.name)){var s=e.idText(n.name);t.get(s)||(t.set(s,!0),r=e.append(r,n.name))}return r}function u(e,n,t){var r=e[n];return r?r.push(t):e[n]=r=[t],r}function d(n){return e.isStringLiteralLike(n)||8===n.kind||e.isKeyword(n.kind)||e.isIdentifier(n)}function p(n){return!e.isIdentifier(n)&&d(n)}function f(e){return e>=63&&e<=77}function m(e){switch(e){case 63:return 39;case 64:return 40;case 65:return 41;case 66:return 42;case 67:return 43;case 68:return 44;case 69:return 47;case 70:return 48;case 71:return 49;case 72:return 50;case 73:return 51;case 77:return 52;case 74:return 56;case 75:return 55;case 76:return 60}}function _(n,t,r,a){if(t.body){var i=t.body.statements,o=n.copyPrologue(i,r,!1,a);if(o===i.length)return o;var s=e.findIndex(i,(function(n){return e.isExpressionStatement(n)&&e.isSuperCall(n.expression)}),o);if(s>-1){for(var c=o;c<=s;c++)r.push(e.visitNode(i[c],a,e.isStatement));return s+1}return o}return 0}function g(n,t,r){return e.filter(n.members,(function(e){return y(e,t,r)}))}function y(n,t,r){return e.isPropertyDeclaration(n)&&(!!n.initializer||!t)&&e.hasStaticModifier(n)===r}function h(e){return 164===e.kind&&void 0!==e.initializer}function v(n){return!e.hasStaticModifier(n)&&e.isMethodOrAccessor(n)&&e.isPrivateIdentifier(n.name)}e.getOriginalNodeId=n,e.chainBundle=a,e.getExportNeedsImportStarHelper=i,e.getImportNeedsImportStarHelper=o,e.getImportNeedsImportDefaultHelper=s,e.collectExternalModuleInfo=c,e.isSimpleCopiableExpression=d,e.isSimpleInlineableExpression=p,e.isCompoundAssignment=f,e.getNonAssignmentOperatorForCompoundAssignment=m,e.addPrologueDirectivesAndInitialSuperCall=_,e.getProperties=g,e.isInitializedProperty=h,e.isNonStaticMethodOrAccessorWithPrivateName=v}(d||(d={})),function(e){function n(n,r,i,o,c,l){var u,d,p=n;if(e.isDestructuringAssignment(n)){u=n.right;while(e.isEmptyArrayLiteral(n.left)||e.isEmptyObjectLiteral(n.left)){if(!e.isDestructuringAssignment(u))return e.visitNode(u,r,e.isExpression);p=n=u,u=n.right}}var m={context:i,level:o,downlevelIteration:!!i.getCompilerOptions().downlevelIteration,hoistTempVariables:!0,emitExpression:g,emitBindingOrAssignment:h,createArrayBindingOrAssignmentPattern:function(e){return _(i.factory,e)},createObjectBindingOrAssignmentPattern:function(e){return y(i.factory,e)},createArrayBindingOrAssignmentElement:v,visitor:r};if(u&&(u=e.visitNode(u,r,e.isExpression),e.isIdentifier(u)&&t(n,u.escapedText)||a(n)?u=f(m,u,!1,p):c?u=f(m,u,!0,p):e.nodeIsSynthesized(n)&&(p=u)),s(m,n,u,p,e.isDestructuringAssignment(n)),u&&c){if(!e.some(d))return u;d.push(u)}return i.factory.inlineExpressions(d)||i.factory.createOmittedExpression();function g(n){d=e.append(d,n)}function h(n,t,a,o){e.Debug.assertNode(n,l?e.isIdentifier:e.isExpression);var s=l?l(n,t,a):e.setTextRange(i.factory.createAssignment(e.visitNode(n,r,e.isExpression),t),a);s.original=o,g(s)}}function t(n,t){var a=e.getTargetOfBindingOrAssignmentElement(n);return e.isBindingOrAssignmentPattern(a)?r(a,t):!!e.isIdentifier(a)&&a.escapedText===t}function r(n,r){for(var a=e.getElementsOfBindingOrAssignmentPattern(n),i=0,o=a;i<o.length;i++){var s=o[i];if(t(s,r))return!0}return!1}function a(n){var t=e.tryGetPropertyNameOfBindingOrAssignmentElement(n);if(t&&e.isComputedPropertyName(t)&&!e.isLiteralExpression(t.expression))return!0;var r=e.getTargetOfBindingOrAssignmentElement(n);return!!r&&e.isBindingOrAssignmentPattern(r)&&i(r)}function i(n){return!!e.forEach(e.getElementsOfBindingOrAssignmentPattern(n),a)}function o(n,r,i,o,c,l,u){var d;void 0===l&&(l=!1);var p=[],_=[],y={context:i,level:o,downlevelIteration:!!i.getCompilerOptions().downlevelIteration,hoistTempVariables:l,emitExpression:k,emitBindingOrAssignment:R,createArrayBindingOrAssignmentPattern:function(e){return m(i.factory,e)},createObjectBindingOrAssignmentPattern:function(e){return g(i.factory,e)},createArrayBindingOrAssignmentElement:function(e){return h(i.factory,e)},visitor:r};if(e.isVariableDeclaration(n)){var v=e.getInitializerOfBindingOrAssignmentElement(n);v&&(e.isIdentifier(v)&&t(n,v.escapedText)||a(n))&&(v=f(y,e.visitNode(v,y.visitor),!1,v),n=i.factory.updateVariableDeclaration(n,n.name,void 0,void 0,v))}if(s(y,n,c,n,u),d){var b=i.factory.createTempVariable(void 0);if(l){var E=i.factory.inlineExpressions(d);d=void 0,R(b,E,void 0,void 0)}else{i.hoistVariableDeclaration(b);var T=e.last(p);T.pendingExpressions=e.append(T.pendingExpressions,i.factory.createAssignment(b,T.value)),e.addRange(T.pendingExpressions,d),T.value=b}}for(var S=0,x=p;S<x.length;S++){var L=x[S],D=L.pendingExpressions,A=L.name,C=(E=L.value,L.location),I=L.original,N=i.factory.createVariableDeclaration(A,void 0,void 0,D?i.factory.inlineExpressions(e.append(D,E)):E);N.original=I,e.setTextRange(N,C),_.push(N)}return _;function k(n){d=e.append(d,n)}function R(n,t,r,a){e.Debug.assertNode(n,e.isBindingName),d&&(t=i.factory.inlineExpressions(e.append(d,t)),d=void 0),p.push({pendingExpressions:d,name:n,value:t,location:r,original:a})}}function s(n,t,r,a,i){var o=e.getTargetOfBindingOrAssignmentElement(t);if(!i){var s=e.visitNode(e.getInitializerOfBindingOrAssignmentElement(t),n.visitor,e.isExpression);s?r?(r=d(n,r,s,a),!e.isSimpleInlineableExpression(s)&&e.isBindingOrAssignmentPattern(o)&&(r=f(n,r,!0,a))):r=s:r||(r=n.context.factory.createVoidZero())}e.isObjectBindingOrAssignmentPattern(o)?c(n,t,o,r,a):e.isArrayBindingOrAssignmentPattern(o)?l(n,t,o,r,a):n.emitBindingOrAssignment(o,r,a,t)}function c(n,t,r,a,i){var o,c,l=e.getElementsOfBindingOrAssignmentPattern(r),u=l.length;if(1!==u){var d=!e.isDeclarationBindingElement(t)||0!==u;a=f(n,a,d,i)}for(var m=0;m<u;m++){var _=l[m];if(e.getRestIndicatorOfBindingOrAssignmentElement(_)){if(m===u-1){o&&(n.emitBindingOrAssignment(n.createObjectBindingOrAssignmentPattern(o),a,i,r),o=void 0);y=n.context.getEmitHelperFactory().createRestHelper(a,l,c,r);s(n,_,y,_)}}else{var g=e.getPropertyNameOfBindingOrAssignmentElement(_);if(!(n.level>=1)||49152&_.transformFlags||49152&e.getTargetOfBindingOrAssignmentElement(_).transformFlags||e.isComputedPropertyName(g)){o&&(n.emitBindingOrAssignment(n.createObjectBindingOrAssignmentPattern(o),a,i,r),o=void 0);var y=p(n,a,g);e.isComputedPropertyName(g)&&(c=e.append(c,y.argumentExpression)),s(n,_,y,_)}else o=e.append(o,e.visitNode(_,n.visitor))}}o&&n.emitBindingOrAssignment(n.createObjectBindingOrAssignmentPattern(o),a,i,r)}function l(n,t,r,a,i){var o,c,l=e.getElementsOfBindingOrAssignmentPattern(r),d=l.length;if(n.level<1&&n.downlevelIteration)a=f(n,e.setTextRange(n.context.getEmitHelperFactory().createReadHelper(a,d>0&&e.getRestIndicatorOfBindingOrAssignmentElement(l[d-1])?void 0:d),i),!1,i);else if(1!==d&&(n.level<1||0===d)||e.every(l,e.isOmittedExpression)){var p=!e.isDeclarationBindingElement(t)||0!==d;a=f(n,a,p,i)}for(var m=0;m<d;m++){var _=l[m];if(n.level>=1)if(32768&_.transformFlags||n.hasTransformedPriorElement&&!u(_)){n.hasTransformedPriorElement=!0;var g=n.context.factory.createTempVariable(void 0);n.hoistTempVariables&&n.context.hoistVariableDeclaration(g),c=e.append(c,[g,_]),o=e.append(o,n.createArrayBindingOrAssignmentElement(g))}else o=e.append(o,_);else{if(e.isOmittedExpression(_))continue;if(e.getRestIndicatorOfBindingOrAssignmentElement(_)){if(m===d-1){y=n.context.factory.createArraySliceCall(a,m);s(n,_,y,_)}}else{var y=n.context.factory.createElementAccessExpression(a,m);s(n,_,y,_)}}}if(o&&n.emitBindingOrAssignment(n.createArrayBindingOrAssignmentPattern(o),a,i,r),c)for(var h=0,v=c;h<v.length;h++){var b=v[h],E=b[0];_=b[1];s(n,_,E,_)}}function u(n){var t=e.getTargetOfBindingOrAssignmentElement(n);if(!t||e.isOmittedExpression(t))return!0;var r=e.tryGetPropertyNameOfBindingOrAssignmentElement(n);if(r&&!e.isPropertyNameLiteral(r))return!1;var a=e.getInitializerOfBindingOrAssignmentElement(n);return!(a&&!e.isSimpleInlineableExpression(a))&&(e.isBindingOrAssignmentPattern(t)?e.every(e.getElementsOfBindingOrAssignmentPattern(t),u):e.isIdentifier(t))}function d(e,n,t,r){return n=f(e,n,!0,r),e.context.factory.createConditionalExpression(e.context.factory.createTypeCheck(n,"undefined"),void 0,t,void 0,n)}function p(n,t,r){if(e.isComputedPropertyName(r)){var a=f(n,e.visitNode(r.expression,n.visitor),!1,r);return n.context.factory.createElementAccessExpression(t,a)}if(e.isStringOrNumericLiteralLike(r)){a=e.factory.cloneNode(r);return n.context.factory.createElementAccessExpression(t,a)}var i=n.context.factory.createIdentifier(e.idText(r));return n.context.factory.createPropertyAccessExpression(t,i)}function f(n,t,r,a){if(e.isIdentifier(t)&&r)return t;var i=n.context.factory.createTempVariable(void 0);return n.hoistTempVariables?(n.context.hoistVariableDeclaration(i),n.emitExpression(e.setTextRange(n.context.factory.createAssignment(i,t),a))):n.emitBindingOrAssignment(i,t,a,void 0),i}function m(n,t){return e.Debug.assertEachNode(t,e.isArrayBindingElement),n.createArrayBindingPattern(t)}function _(n,t){return n.createArrayLiteralExpression(e.map(t,n.converters.convertToArrayAssignmentElement))}function g(n,t){return e.Debug.assertEachNode(t,e.isBindingElement),n.createObjectBindingPattern(t)}function y(n,t){return n.createObjectLiteralExpression(e.map(t,n.converters.convertToObjectAssignmentElement))}function h(e,n){return e.createBindingElement(void 0,void 0,n)}function v(e){return e}(function(e){e[e["All"]=0]="All",e[e["ObjectRest"]=1]="ObjectRest"})(e.FlattenLevel||(e.FlattenLevel={})),e.flattenDestructuringAssignment=n,e.flattenDestructuringBinding=o}(d||(d={})),function(e){var n;function t(t,i,o,s,c,l){var u=e.visitNode(i.tag,o,e.isExpression),d=[void 0],p=[],f=[],m=i.template;if(l===n.LiftRestriction&&!e.hasInvalidEscape(m))return e.visitEachChild(i,o,t);if(e.isNoSubstitutionTemplateLiteral(m))p.push(r(m)),f.push(a(m,s));else{p.push(r(m.head)),f.push(a(m.head,s));for(var _=0,g=m.templateSpans;_<g.length;_++){var y=g[_];p.push(r(y.literal)),f.push(a(y.literal,s)),d.push(e.visitNode(y.expression,o,e.isExpression))}}var h=t.getEmitHelperFactory().createTemplateObjectHelper(e.factory.createArrayLiteralExpression(p),e.factory.createArrayLiteralExpression(f));if(e.isExternalModule(s)){var v=e.factory.createUniqueName("templateObject");c(v),d[0]=e.factory.createLogicalOr(v,e.factory.createAssignment(v,h))}else d[0]=h;return e.factory.createCallExpression(u,void 0,d)}function r(n){return n.templateFlags?e.factory.createVoidZero():e.factory.createStringLiteral(n.text)}function a(n,t){var r=n.rawText;if(void 0===r){r=e.getSourceTextOfNodeFromSourceFile(t,n);var a=14===n.kind||17===n.kind;r=r.substring(1,r.length-(a?1:2))}return r=r.replace(/\r\n?/g,"\n"),e.setTextRange(e.factory.createStringLiteral(r),n)}(function(e){e[e["LiftRestriction"]=0]="LiftRestriction",e[e["All"]=1]="All"})(n=e.ProcessLevel||(e.ProcessLevel={})),e.processTaggedTemplateExpression=t}(d||(d={})),function(e){var n,t,r=!1;function a(n){var t,a,i,o,s,c,l,u,d,p,f=n.factory,m=n.getEmitHelperFactory,_=n.startLexicalEnvironment,g=n.resumeLexicalEnvironment,y=n.endLexicalEnvironment,h=n.hoistVariableDeclaration,v=n.getEmitResolver(),b=n.getCompilerOptions(),E=e.getStrictOptionValue(b,"strictNullChecks"),T=e.getEmitScriptTarget(b),S=e.getEmitModuleKind(b),x=n.onEmitNode,L=n.onSubstituteNode;return n.onEmitNode=rt,n.onSubstituteNode=at,n.enableSubstitution(202),n.enableSubstitution(203),D;function D(e){return 299===e.kind?A(e):C(e)}function A(n){return f.createBundle(n.sourceFiles.map(C),e.mapDefined(n.prepends,(function(n){return 301===n.kind?e.createUnparsedSourceFile(n,"js"):n})))}function C(r){if(r.isDeclarationFile)return r;t=r;var a=I(r,j);return e.addEmitHelpers(a,n.readEmitHelpers()),t=void 0,a}function I(e,n){var t=o,r=s,a=c,i=l;N(e);var u=n(e);return o!==t&&(c=a),o=t,s=r,l=i,u}function N(n){switch(n.kind){case 298:case 259:case 258:case 231:o=n,s=void 0,c=void 0;break;case 253:case 252:if(e.hasSyntacticModifier(n,2))break;n.name?vn(n):e.Debug.assert(253===n.kind||e.hasSyntacticModifier(n,512)),e.isClassDeclaration(n)&&(s=n);break}}function k(e){return I(e,R)}function R(e){return 1&e.transformFlags?V(e):e}function O(e){return I(e,w)}function w(e){switch(e.kind){case 262:case 261:case 267:case 268:return P(e);default:return R(e)}}function P(t){var r=e.getParseTreeNode(t);if(r!==t)return 1&t.transformFlags?e.visitEachChild(t,k,n):t;switch(t.kind){case 262:return Dn(t);case 261:return Fn(t);case 267:return Nn(t);case 268:return kn(t);default:e.Debug.fail("Unhandled ellided statement")}}function M(e){return I(e,F)}function F(n){if(268!==n.kind&&262!==n.kind&&263!==n.kind&&(261!==n.kind||273!==n.moduleReference.kind))return 1&n.transformFlags||e.hasSyntacticModifier(n,1)?V(n):n}function G(e){return I(e,B)}function B(n){switch(n.kind){case 167:return Ke(n);case 164:return je(n);case 172:case 168:case 169:case 166:return R(n);case 230:return n;default:return e.Debug.failBadSyntaxKind(n)}}function U(n){if(!(18654&e.modifierToFlag(n.kind))&&(!a||92!==n.kind))return n}function V(t){if(e.isStatement(t)&&e.hasSyntacticModifier(t,2))return f.createNotEmittedStatement(t);switch(t.kind){case 92:case 87:return a?void 0:t;case 122:case 120:case 121:case 125:case 84:case 133:case 142:case 179:case 180:case 181:case 182:case 178:case 173:case 160:case 128:case 152:case 131:case 147:case 144:case 141:case 113:case 148:case 176:case 175:case 177:case 174:case 183:case 184:case 185:case 187:case 188:case 189:case 190:case 191:case 192:case 172:case 162:case 255:return;case 164:return je(t);case 260:return;case 167:return Ke(t);case 254:return f.createNotEmittedStatement(t);case 253:return J(t);case 222:return Q(t);case 287:return Be(t);case 224:return Ue(t);case 166:return ze(t);case 168:return Je(t);case 169:return Xe(t);case 252:return Ye(t);case 209:return Qe(t);case 210:return Ze(t);case 161:return $e(t);case 208:return rn(t);case 207:case 225:return an(t);case 204:return sn(t);case 205:return cn(t);case 206:return ln(t);case 226:return on(t);case 256:return fn(t);case 233:return en(t);case 250:return tn(t);case 257:return Sn(t);case 261:return Fn(t);case 275:return un(t);case 276:return dn(t);default:return e.visitEachChild(t,k,n)}}function j(t){var r=e.getStrictOptionValue(b,"alwaysStrict")&&!(e.isExternalModule(t)&&S>=e.ModuleKind.ES2015)&&!e.isJsonSourceFile(t);return f.updateSourceFile(t,e.visitLexicalEnvironment(t.statements,O,n,0,r))}function K(n){if(n.decorators&&n.decorators.length>0)return!0;var t=e.getFirstConstructorWithBody(n);return!!t&&e.forEach(t.parameters,H)}function H(e){return void 0!==e.decorators&&e.decorators.length>0}function W(n,t){var r=0;e.some(t)&&(r|=1);var a=e.getEffectiveBaseTypeNode(n);return a&&103!==e.skipOuterExpressions(a.expression).kind&&(r|=64),K(n)&&(r|=2),e.childIsDecorated(n)&&(r|=4),Gn(n)?r|=8:Vn(n)?r|=32:Un(n)&&(r|=16),T<=1&&7&r&&(r|=128),r}function z(e){return!!(4096&e.transformFlags)}function q(n){return e.some(n.decorators)||e.some(n.typeParameters)||e.some(n.heritageClauses,z)||e.some(n.members,z)}function J(r){if(!q(r)&&(!a||!e.hasSyntacticModifier(r,1)))return e.visitEachChild(r,k,n);var i=e.getProperties(r,!0,!0),o=W(r,i);128&o&&n.startLexicalEnvironment();var s=r.name||(5&o?f.getGeneratedNameForNode(r):void 0),c=2&o?Y(r,s):X(r,s,o),l=[c];if(ue(l,r,!1),ue(l,r,!0),fe(l,r),128&o){var u=e.createTokenRange(e.skipTrivia(t.text,r.members.end),19),d=f.getInternalName(r),p=f.createPartiallyEmittedExpression(d);e.setTextRangeEnd(p,u.end),e.setEmitFlags(p,1536);var m=f.createReturnStatement(p);e.setTextRangePos(m,u.pos),e.setEmitFlags(m,1920),l.push(m),e.insertStatementsAfterStandardPrologue(l,n.endLexicalEnvironment());var _=f.createImmediatelyInvokedArrowFunction(l);e.setEmitFlags(_,33554432);var g=f.createVariableStatement(void 0,f.createVariableDeclarationList([f.createVariableDeclaration(f.getLocalName(r,!1,!1),void 0,void 0,_)]));e.setOriginalNode(g,r),e.setCommentRange(g,r),e.setSourceMapRange(g,e.moveRangePastDecorators(r)),e.startOnNewLine(g),l=[g]}return 8&o?Kn(l,r):(128&o||2&o)&&(32&o?l.push(f.createExportDefault(f.getLocalName(r,!1,!0))):16&o&&l.push(f.createExternalModuleExport(f.getLocalName(r,!1,!0)))),l.length>1&&(l.push(f.createEndOfDeclarationMarker(r)),e.setEmitFlags(c,4194304|e.getEmitFlags(c))),e.singleOrMany(l)}function X(n,t,r){var a=128&r?void 0:e.visitNodes(n.modifiers,U,e.isModifier),i=f.createClassDeclaration(void 0,a,t,void 0,e.visitNodes(n.heritageClauses,k,e.isHeritageClause),Z(n)),o=e.getEmitFlags(n);return 1&r&&(o|=32),e.setTextRange(i,n),e.setOriginalNode(i,n),e.setEmitFlags(i,o),i}function Y(n,t){var r=e.moveRangePastDecorators(n),a=Xn(n),i=f.getLocalName(n,!1,!0),o=e.visitNodes(n.heritageClauses,k,e.isHeritageClause),s=Z(n),c=f.createClassExpression(void 0,void 0,t,void 0,o,s);e.setOriginalNode(c,n),e.setTextRange(c,r);var l=f.createVariableStatement(void 0,f.createVariableDeclarationList([f.createVariableDeclaration(i,void 0,void 0,a?f.createAssignment(a,c):c)],1));return e.setOriginalNode(l,n),e.setTextRange(l,r),e.setCommentRange(l,n),l}function Q(t){if(!q(t))return e.visitEachChild(t,k,n);var r=f.createClassExpression(void 0,void 0,t.name,void 0,e.visitNodes(t.heritageClauses,k,e.isHeritageClause),Z(t));return e.setOriginalNode(r,t),e.setTextRange(r,t),r}function Z(n){var t=[],r=e.getFirstConstructorWithBody(n),a=r&&e.filter(r.parameters,(function(n){return e.isParameterPropertyDeclaration(n,r)}));if(a)for(var i=0,o=a;i<o.length;i++){var s=o[i];e.isIdentifier(s.name)&&t.push(e.setOriginalNode(f.createPropertyDeclaration(void 0,void 0,s.name,void 0,void 0,void 0),s))}return e.addRange(t,e.visitNodes(n.members,G,e.isClassElement)),e.setTextRange(f.createNodeArray(t),n.members)}function $(n,t){return e.filter(n.members,t?function(e){return ee(e,n)}:function(e){return ne(e,n)})}function ee(e,n){return te(e,!0,n)}function ne(e,n){return te(e,!1,n)}function te(n,t,r){return e.nodeOrChildIsDecorated(n,r)&&t===e.hasSyntacticModifier(n,32)}function re(n){var t;if(n)for(var r=n.parameters,a=r.length>0&&e.parameterIsThisKeyword(r[0]),i=a?1:0,o=a?r.length-1:r.length,s=0;s<o;s++){var c=r[s+i];(t||c.decorators)&&(t||(t=new Array(o)),t[s]=c.decorators)}return t}function ae(n){var t=n.decorators,r=re(e.getFirstConstructorWithBody(n));if(t||r)return{decorators:t,parameters:r}}function ie(e,n){switch(n.kind){case 168:case 169:return oe(e,n);case 166:return se(n);case 164:return ce(n);default:return}}function oe(n,t){if(t.body){var r=e.getAllAccessorDeclarations(n.members,t),a=r.firstAccessor,i=r.secondAccessor,o=r.setAccessor,s=a.decorators?a:i&&i.decorators?i:void 0;if(s&&t===s){var c=s.decorators,l=re(o);if(c||l)return{decorators:c,parameters:l}}}}function se(e){if(e.body){var n=e.decorators,t=re(e);if(n||t)return{decorators:n,parameters:t}}}function ce(e){var n=e.decorators;if(n)return{decorators:n}}function le(n,t,r){if(r){var a=[];return e.addRange(a,e.map(r.decorators,_e)),e.addRange(a,e.flatMap(r.parameters,ge)),ye(n,t,a),a}}function ue(n,t,r){e.addRange(n,e.map(de(t,r),jn))}function de(e,n){for(var t,r=$(e,n),a=0,i=r;a<i.length;a++){var o=i[a],s=pe(e,o);s&&(t?t.push(s):t=[s])}return t}function pe(n,t){var r=ie(n,t),a=le(t,n,r);if(a){var i=Qn(n,t),o=Fe(t,!0),s=T>0?164===t.kind?f.createVoidZero():f.createNull():void 0,c=m().createDecorateHelper(a,i,o,s);return e.setTextRange(c,e.moveRangePastDecorators(t)),e.setEmitFlags(c,1536),c}}function fe(n,t){var r=me(t);r&&n.push(e.setOriginalNode(f.createExpressionStatement(r),t))}function me(n){var t=ae(n),r=le(n,n,t);if(r){var a=d&&d[e.getOriginalNodeId(n)],i=f.getLocalName(n,!1,!0),o=m().createDecorateHelper(r,i),s=f.createAssignment(i,a?f.createAssignment(a,o):o);return e.setEmitFlags(s,1536),e.setSourceMapRange(s,e.moveRangePastDecorators(n)),s}}function _e(n){return e.visitNode(n.expression,k,e.isExpression)}function ge(n,t){var r;if(n){r=[];for(var a=0,i=n;a<i.length;a++){var o=i[a],s=m().createParamHelper(_e(o),t);e.setTextRange(s,o.expression),e.setEmitFlags(s,1536),r.push(s)}}return r}function ye(e,n,t){r?ve(e,n,t):he(e,n,t)}function he(e,n,t){b.emitDecoratorMetadata&&(be(e)&&t.push(m().createMetadataHelper("design:type",xe(e))),Te(e)&&t.push(m().createMetadataHelper("design:paramtypes",Le(e,n))),Ee(e)&&t.push(m().createMetadataHelper("design:returntype",Ae(e))))}function ve(e,n,t){if(b.emitDecoratorMetadata){var r=void 0;be(e)&&(r||(r=[])).push(f.createPropertyAssignment("type",f.createArrowFunction(void 0,void 0,[],void 0,f.createToken(38),xe(e)))),Te(e)&&(r||(r=[])).push(f.createPropertyAssignment("paramTypes",f.createArrowFunction(void 0,void 0,[],void 0,f.createToken(38),Le(e,n)))),Ee(e)&&(r||(r=[])).push(f.createPropertyAssignment("returnType",f.createArrowFunction(void 0,void 0,[],void 0,f.createToken(38),Ae(e)))),r&&t.push(m().createMetadataHelper("design:typeinfo",f.createObjectLiteralExpression(r,!0)))}}function be(e){var n=e.kind;return 166===n||168===n||169===n||164===n}function Ee(e){return 166===e.kind}function Te(n){switch(n.kind){case 253:case 222:return void 0!==e.getFirstConstructorWithBody(n);case 166:case 168:case 169:return!0}return!1}function Se(n){var t=v.getAllAccessorDeclarations(n);return t.setAccessor&&e.getSetAccessorTypeAnnotationNode(t.setAccessor)||t.getAccessor&&e.getEffectiveReturnTypeNode(t.getAccessor)}function xe(e){switch(e.kind){case 164:case 161:return Ce(e.type);case 169:case 168:return Ce(Se(e));case 253:case 222:case 166:return f.createIdentifier("Function");default:return f.createVoidZero()}}function Le(n,t){var r=e.isClassLike(n)?e.getFirstConstructorWithBody(n):e.isFunctionLike(n)&&e.nodeIsPresent(n.body)?n:void 0,a=[];if(r)for(var i=De(r,t),o=i.length,s=0;s<o;s++){var c=i[s];0===s&&e.isIdentifier(c.name)&&"this"===c.name.escapedText||(c.dotDotDotToken?a.push(Ce(e.getRestParameterElementType(c.type))):a.push(xe(c)))}return f.createArrayLiteralExpression(a)}function De(n,t){if(t&&168===n.kind){var r=e.getAllAccessorDeclarations(t.members,n).setAccessor;if(r)return r.parameters}return n.parameters}function Ae(n){return e.isFunctionLike(n)&&n.type?Ce(n.type):e.isAsyncFunction(n)?f.createIdentifier("Promise"):f.createVoidZero()}function Ce(n){if(void 0===n)return f.createIdentifier("Object");switch(n.kind){case 113:case 150:case 141:return f.createVoidZero();case 187:return Ce(n.type);case 175:case 176:return f.createIdentifier("Function");case 179:case 180:return f.createIdentifier("Array");case 173:case 131:return f.createIdentifier("Boolean");case 147:return f.createIdentifier("String");case 145:return f.createIdentifier("Object");case 192:switch(n.literal.kind){case 10:case 14:return f.createIdentifier("String");case 215:case 8:return f.createIdentifier("Number");case 9:return Me();case 109:case 94:return f.createIdentifier("Boolean");case 103:return f.createVoidZero();default:return e.Debug.failBadSyntaxKind(n.literal)}case 144:return f.createIdentifier("Number");case 155:return Me();case 148:return T<2?Pe():f.createIdentifier("Symbol");case 174:return Ne(n);case 184:case 183:return Ie(n.types);case 185:return Ie([n.trueType,n.falseType]);case 189:if(142===n.operator)return Ce(n.type);break;case 177:case 190:case 191:case 178:case 128:case 152:case 188:case 196:break;case 304:case 305:case 309:case 310:case 311:break;case 306:case 307:case 308:return Ce(n.type);default:return e.Debug.failBadSyntaxKind(n)}return f.createIdentifier("Object")}function Ie(n){for(var t,r=0,a=n;r<a.length;r++){var i=a[r];while(187===i.kind)i=i.type;if(141!==i.kind&&(E||(192!==i.kind||103!==i.literal.kind)&&150!==i.kind)){var o=Ce(i);if(e.isIdentifier(o)&&"Object"===o.escapedText)return o;if(t){if(!e.isIdentifier(t)||!e.isIdentifier(o)||t.escapedText!==o.escapedText)return f.createIdentifier("Object")}else t=o}}return t||f.createVoidZero()}function Ne(n){var t=v.getTypeReferenceSerializationKind(n.typeName,s||o);switch(t){case e.TypeReferenceSerializationKind.Unknown:if(e.findAncestor(n,(function(n){return n.parent&&e.isConditionalTypeNode(n.parent)&&(n.parent.trueType===n||n.parent.falseType===n)})))return f.createIdentifier("Object");var r=Re(n.typeName),a=f.createTempVariable(h);return f.createConditionalExpression(f.createTypeCheck(f.createAssignment(a,r),"function"),void 0,a,void 0,f.createIdentifier("Object"));case e.TypeReferenceSerializationKind.TypeWithConstructSignatureAndValue:return Oe(n.typeName);case e.TypeReferenceSerializationKind.VoidNullableOrNeverType:return f.createVoidZero();case e.TypeReferenceSerializationKind.BigIntLikeType:return Me();case e.TypeReferenceSerializationKind.BooleanType:return f.createIdentifier("Boolean");case e.TypeReferenceSerializationKind.NumberLikeType:return f.createIdentifier("Number");case e.TypeReferenceSerializationKind.StringLikeType:return f.createIdentifier("String");case e.TypeReferenceSerializationKind.ArrayLikeType:return f.createIdentifier("Array");case e.TypeReferenceSerializationKind.ESSymbolType:return T<2?Pe():f.createIdentifier("Symbol");case e.TypeReferenceSerializationKind.TypeWithCallSignature:return f.createIdentifier("Function");case e.TypeReferenceSerializationKind.Promise:return f.createIdentifier("Promise");case e.TypeReferenceSerializationKind.ObjectType:return f.createIdentifier("Object");default:return e.Debug.assertNever(t)}}function ke(e,n){return f.createLogicalAnd(f.createStrictInequality(f.createTypeOfExpression(e),f.createStringLiteral("undefined")),n)}function Re(e){if(78===e.kind){var n=Oe(e);return ke(n,n)}if(78===e.left.kind)return ke(Oe(e.left),Oe(e));var t=Re(e.left),r=f.createTempVariable(h);return f.createLogicalAnd(f.createLogicalAnd(t.left,f.createStrictInequality(f.createAssignment(r,t.right),f.createVoidZero())),f.createPropertyAccessExpression(r,e.right))}function Oe(n){switch(n.kind){case 78:var t=e.setParent(e.setTextRange(e.parseNodeFactory.cloneNode(n),n),n.parent);return t.original=void 0,e.setParent(t,e.getParseTreeNode(o)),t;case 158:return we(n)}}function we(e){return f.createPropertyAccessExpression(Oe(e.left),e.right)}function Pe(){return f.createConditionalExpression(f.createTypeCheck(f.createIdentifier("Symbol"),"function"),void 0,f.createIdentifier("Symbol"),void 0,f.createIdentifier("Object"))}function Me(){return T<99?f.createConditionalExpression(f.createTypeCheck(f.createIdentifier("BigInt"),"function"),void 0,f.createIdentifier("BigInt"),void 0,f.createIdentifier("Object")):f.createIdentifier("BigInt")}function Fe(n,t){var r=n.name;return e.isPrivateIdentifier(r)?f.createIdentifier(""):e.isComputedPropertyName(r)?t&&!e.isSimpleInlineableExpression(r.expression)?f.getGeneratedNameForNode(r):r.expression:e.isIdentifier(r)?f.createStringLiteral(e.idText(r)):f.cloneNode(r)}function Ge(n){var t=n.name;if(e.isComputedPropertyName(t)&&(!e.hasStaticModifier(n)&&l||e.some(n.decorators))){var r=e.visitNode(t.expression,k,e.isExpression),a=e.skipPartiallyEmittedExpressions(r);if(!e.isSimpleInlineableExpression(a)){var i=f.getGeneratedNameForNode(t);return h(i),f.updateComputedPropertyName(t,f.createAssignment(i,r))}}return e.visitNode(t,k,e.isPropertyName)}function Be(t){if(116!==t.token)return e.visitEachChild(t,k,n)}function Ue(n){return f.updateExpressionWithTypeArguments(n,e.visitNode(n.expression,k,e.isLeftHandSideExpression),void 0)}function Ve(n){return!e.nodeIsMissing(n.body)}function je(n){if(!(8388608&n.flags||e.hasSyntacticModifier(n,128))){var t=f.updatePropertyDeclaration(n,void 0,e.visitNodes(n.modifiers,k,e.isModifier),Ge(n),void 0,void 0,e.visitNode(n.initializer,k));return t!==n&&(e.setCommentRange(t,n),e.setSourceMapRange(t,e.moveRangePastDecorators(n))),t}}function Ke(t){if(Ve(t))return f.updateConstructorDeclaration(t,void 0,void 0,e.visitParameterList(t.parameters,k,n),He(t.body,t))}function He(t,r){var a=r&&e.filter(r.parameters,(function(n){return e.isParameterPropertyDeclaration(n,r)}));if(!e.some(a))return e.visitFunctionBody(t,k,n);var i=[],o=0;g(),o=e.addPrologueDirectivesAndInitialSuperCall(f,r,i,k),e.addRange(i,e.map(a,We)),e.addRange(i,e.visitNodes(t.statements,k,e.isStatement,o)),i=f.mergeLexicalEnvironment(i,y());var s=f.createBlock(e.setTextRange(f.createNodeArray(i),t.statements),!0);return e.setTextRange(s,t),e.setOriginalNode(s,t),s}function We(n){var t=n.name;if(e.isIdentifier(t)){var r=e.setParent(e.setTextRange(f.cloneNode(t),t),t.parent);e.setEmitFlags(r,1584);var a=e.setParent(e.setTextRange(f.cloneNode(t),t),t.parent);return e.setEmitFlags(a,1536),e.startOnNewLine(e.removeAllComments(e.setTextRange(e.setOriginalNode(f.createExpressionStatement(f.createAssignment(e.setTextRange(f.createPropertyAccessExpression(f.createThis(),r),n.name),a)),n),e.moveRangePos(n,-1))))}}function ze(t){if(Ve(t)){var r=f.updateMethodDeclaration(t,void 0,e.visitNodes(t.modifiers,U,e.isModifier),t.asteriskToken,Ge(t),void 0,void 0,e.visitParameterList(t.parameters,k,n),void 0,e.visitFunctionBody(t.body,k,n));return r!==t&&(e.setCommentRange(r,t),e.setSourceMapRange(r,e.moveRangePastDecorators(t))),r}}function qe(n){return!(e.nodeIsMissing(n.body)&&e.hasSyntacticModifier(n,128))}function Je(t){if(qe(t)){var r=f.updateGetAccessorDeclaration(t,void 0,e.visitNodes(t.modifiers,U,e.isModifier),Ge(t),e.visitParameterList(t.parameters,k,n),void 0,e.visitFunctionBody(t.body,k,n)||f.createBlock([]));return r!==t&&(e.setCommentRange(r,t),e.setSourceMapRange(r,e.moveRangePastDecorators(t))),r}}function Xe(t){if(qe(t)){var r=f.updateSetAccessorDeclaration(t,void 0,e.visitNodes(t.modifiers,U,e.isModifier),Ge(t),e.visitParameterList(t.parameters,k,n),e.visitFunctionBody(t.body,k,n)||f.createBlock([]));return r!==t&&(e.setCommentRange(r,t),e.setSourceMapRange(r,e.moveRangePastDecorators(t))),r}}function Ye(t){if(!Ve(t))return f.createNotEmittedStatement(t);var r=f.updateFunctionDeclaration(t,void 0,e.visitNodes(t.modifiers,U,e.isModifier),t.asteriskToken,t.name,void 0,e.visitParameterList(t.parameters,k,n),void 0,e.visitFunctionBody(t.body,k,n)||f.createBlock([]));if(Gn(t)){var a=[r];return Kn(a,t),a}return r}function Qe(t){if(!Ve(t))return f.createOmittedExpression();var r=f.updateFunctionExpression(t,e.visitNodes(t.modifiers,U,e.isModifier),t.asteriskToken,t.name,void 0,e.visitParameterList(t.parameters,k,n),void 0,e.visitFunctionBody(t.body,k,n)||f.createBlock([]));return r}function Ze(t){var r=f.updateArrowFunction(t,e.visitNodes(t.modifiers,U,e.isModifier),void 0,e.visitParameterList(t.parameters,k,n),void 0,t.equalsGreaterThanToken,e.visitFunctionBody(t.body,k,n));return r}function $e(n){if(!e.parameterIsThisKeyword(n)){var t=f.updateParameterDeclaration(n,void 0,void 0,n.dotDotDotToken,e.visitNode(n.name,k,e.isBindingName),void 0,void 0,e.visitNode(n.initializer,k,e.isExpression));return t!==n&&(e.setCommentRange(t,n),e.setTextRange(t,e.moveRangePastModifiers(n)),e.setSourceMapRange(t,e.moveRangePastModifiers(n)),e.setEmitFlags(t.name,32)),t}}function en(t){if(Gn(t)){var r=e.getInitializedVariables(t.declarationList);if(0===r.length)return;return e.setTextRange(f.createExpressionStatement(f.inlineExpressions(e.map(r,nn))),t)}return e.visitEachChild(t,k,n)}function nn(t){var r=t.name;return e.isBindingPattern(r)?e.flattenDestructuringAssignment(t,k,n,0,!1,Wn):e.setTextRange(f.createAssignment(zn(r),e.visitNode(t.initializer,k,e.isExpression)),t)}function tn(n){return f.updateVariableDeclaration(n,e.visitNode(n.name,k,e.isBindingName),void 0,void 0,e.visitNode(n.initializer,k,e.isExpression))}function rn(r){var a=e.skipOuterExpressions(r.expression,-7);if(e.isAssertionExpression(a)){var i=e.visitNode(r.expression,k,e.isExpression);return e.length(e.getLeadingCommentRangesOfNode(i,t))?f.updateParenthesizedExpression(r,i):f.createPartiallyEmittedExpression(i,r)}return e.visitEachChild(r,k,n)}function an(n){var t=e.visitNode(n.expression,k,e.isExpression);return f.createPartiallyEmittedExpression(t,n)}function on(n){var t=e.visitNode(n.expression,k,e.isLeftHandSideExpression);return f.createPartiallyEmittedExpression(t,n)}function sn(n){return f.updateCallExpression(n,e.visitNode(n.expression,k,e.isExpression),void 0,e.visitNodes(n.arguments,k,e.isExpression))}function cn(n){return f.updateNewExpression(n,e.visitNode(n.expression,k,e.isExpression),void 0,e.visitNodes(n.arguments,k,e.isExpression))}function ln(n){return f.updateTaggedTemplateExpression(n,e.visitNode(n.tag,k,e.isExpression),void 0,e.visitNode(n.template,k,e.isExpression))}function un(n){return f.updateJsxSelfClosingElement(n,e.visitNode(n.tagName,k,e.isJsxTagNameExpression),void 0,e.visitNode(n.attributes,k,e.isJsxAttributes))}function dn(n){return f.updateJsxOpeningElement(n,e.visitNode(n.tagName,k,e.isJsxTagNameExpression),void 0,e.visitNode(n.attributes,k,e.isJsxAttributes))}function pn(n){return!e.isEnumConst(n)||e.shouldPreserveConstEnums(b)}function fn(n){if(!pn(n))return f.createNotEmittedStatement(n);var r=[],a=2,s=Tn(r,n);s&&(S===e.ModuleKind.System&&o===t||(a|=512));var c=qn(n),l=Jn(n),u=e.hasSyntacticModifier(n,1)?f.getExternalModuleOrNamespaceExportName(i,n,!1,!0):f.getLocalName(n,!1,!0),d=f.createLogicalOr(u,f.createAssignment(u,f.createObjectLiteralExpression()));if(hn(n)){var p=f.getLocalName(n,!1,!0);d=f.createAssignment(p,d)}var m=f.createExpressionStatement(f.createCallExpression(f.createFunctionExpression(void 0,void 0,void 0,void 0,[f.createParameterDeclaration(void 0,void 0,void 0,c)],void 0,mn(n,l)),void 0,[d]));return e.setOriginalNode(m,n),s&&(e.setSyntheticLeadingComments(m,void 0),e.setSyntheticTrailingComments(m,void 0)),e.setTextRange(m,n),e.addEmitFlags(m,a),r.push(m),r.push(f.createEndOfDeclarationMarker(n)),r}function mn(n,t){var r=i;i=t;var a=[];_();var o=e.map(n.members,_n);return e.insertStatementsAfterStandardPrologue(a,y()),e.addRange(a,o),i=r,f.createBlock(e.setTextRange(f.createNodeArray(a),n.members),!0)}function _n(n){var t=Fe(n,!1),r=gn(n),a=f.createAssignment(f.createElementAccessExpression(i,t),r),o=10===r.kind?a:f.createAssignment(f.createElementAccessExpression(i,a),t);return e.setTextRange(f.createExpressionStatement(e.setTextRange(o,n)),n)}function gn(n){var t=v.getConstantValue(n);return void 0!==t?"string"===typeof t?f.createStringLiteral(t):f.createNumericLiteral(t):(Zn(),n.initializer?e.visitNode(n.initializer,k,e.isExpression):f.createVoidZero())}function yn(n){var t=e.getParseTreeNode(n,e.isModuleDeclaration);return!t||e.isInstantiatedModule(t,e.shouldPreserveConstEnums(b))}function hn(n){return Gn(n)||Bn(n)&&S!==e.ModuleKind.ES2015&&S!==e.ModuleKind.ES2020&&S!==e.ModuleKind.ESNext&&S!==e.ModuleKind.System}function vn(n){c||(c=new e.Map);var t=En(n);c.has(t)||c.set(t,n)}function bn(e){if(c){var n=En(e);return c.get(n)===e}return!0}function En(n){return e.Debug.assertNode(n.name,e.isIdentifier),n.name.escapedText}function Tn(n,t){var r=f.createVariableStatement(e.visitNodes(t.modifiers,U,e.isModifier),f.createVariableDeclarationList([f.createVariableDeclaration(f.getLocalName(t,!1,!0))],298===o.kind?0:1));if(e.setOriginalNode(r,t),vn(t),bn(t))return 256===t.kind?e.setSourceMapRange(r.declarationList,t):e.setSourceMapRange(r,t),e.setCommentRange(r,t),e.addEmitFlags(r,4195328),n.push(r),!0;var a=f.createMergeDeclarationMarker(r);return e.setEmitFlags(a,4195840),n.push(a),!1}function Sn(n){if(!yn(n))return f.createNotEmittedStatement(n);e.Debug.assertNode(n.name,e.isIdentifier,"A TypeScript namespace should have an Identifier name."),et();var r=[],a=2,s=Tn(r,n);s&&(S===e.ModuleKind.System&&o===t||(a|=512));var c=qn(n),l=Jn(n),u=e.hasSyntacticModifier(n,1)?f.getExternalModuleOrNamespaceExportName(i,n,!1,!0):f.getLocalName(n,!1,!0),d=f.createLogicalOr(u,f.createAssignment(u,f.createObjectLiteralExpression()));if(hn(n)){var p=f.getLocalName(n,!1,!0);d=f.createAssignment(p,d)}var m=f.createExpressionStatement(f.createCallExpression(f.createFunctionExpression(void 0,void 0,void 0,void 0,[f.createParameterDeclaration(void 0,void 0,void 0,c)],void 0,xn(n,l)),void 0,[d]));return e.setOriginalNode(m,n),s&&(e.setSyntheticLeadingComments(m,void 0),e.setSyntheticTrailingComments(m,void 0)),e.setTextRange(m,n),e.addEmitFlags(m,a),r.push(m),r.push(f.createEndOfDeclarationMarker(n)),r}function xn(n,t){var r=i,o=a,s=c;i=t,a=n,c=void 0;var l,u,d=[];if(_(),n.body)if(258===n.body.kind)I(n.body,(function(n){return e.addRange(d,e.visitNodes(n.statements,M,e.isStatement))})),l=n.body.statements,u=n.body;else{var p=Sn(n.body);p&&(e.isArray(p)?e.addRange(d,p):d.push(p));var m=Ln(n).body;l=e.moveRangePos(m.statements,-1)}e.insertStatementsAfterStandardPrologue(d,y()),i=r,a=o,c=s;var g=f.createBlock(e.setTextRange(f.createNodeArray(d),l),!0);return e.setTextRange(g,u),n.body&&258===n.body.kind||e.setEmitFlags(g,1536|e.getEmitFlags(g)),g}function Ln(e){if(257===e.body.kind){var n=Ln(e.body);return n||e.body}}function Dn(n){if(!n.importClause)return n;if(!n.importClause.isTypeOnly){var t=e.visitNode(n.importClause,An,e.isImportClause);return t||1===b.importsNotUsedAsValues||2===b.importsNotUsedAsValues?f.updateImportDeclaration(n,void 0,void 0,t,n.moduleSpecifier):void 0}}function An(n){if(!n.isTypeOnly){var t=v.isReferencedAliasDeclaration(n)?n.name:void 0,r=e.visitNode(n.namedBindings,Cn,e.isNamedImportBindings);return t||r?f.updateImportClause(n,!1,t,r):void 0}}function Cn(n){if(264===n.kind)return v.isReferencedAliasDeclaration(n)?n:void 0;var t=e.visitNodes(n.elements,In,e.isImportSpecifier);return e.some(t)?f.updateNamedImports(n,t):void 0}function In(e){return v.isReferencedAliasDeclaration(e)?e:void 0}function Nn(t){return v.isValueAliasDeclaration(t)?e.visitEachChild(t,k,n):void 0}function kn(n){if(!n.isTypeOnly){if(!n.exportClause||e.isNamespaceExport(n.exportClause))return n;if(v.isValueAliasDeclaration(n)){var t=e.visitNode(n.exportClause,wn,e.isNamedExportBindings);return t?f.updateExportDeclaration(n,void 0,void 0,n.isTypeOnly,t,n.moduleSpecifier):void 0}}}function Rn(n){var t=e.visitNodes(n.elements,Pn,e.isExportSpecifier);return e.some(t)?f.updateNamedExports(n,t):void 0}function On(n){return f.updateNamespaceExport(n,e.visitNode(n.name,k,e.isIdentifier))}function wn(n){return e.isNamespaceExport(n)?On(n):Rn(n)}function Pn(e){return v.isValueAliasDeclaration(e)?e:void 0}function Mn(n){return v.isReferencedAliasDeclaration(n)||!e.isExternalModule(t)&&v.isTopLevelValueImportEqualsWithEntityName(n)}function Fn(t){if(!t.isTypeOnly){if(e.isExternalModuleImportEqualsDeclaration(t)){var r=v.isReferencedAliasDeclaration(t);return r||1!==b.importsNotUsedAsValues?r?e.visitEachChild(t,k,n):void 0:e.setOriginalNode(e.setTextRange(f.createImportDeclaration(void 0,void 0,void 0,t.moduleReference.expression),t),t)}if(Mn(t)){var a=e.createExpressionFromEntityName(f,t.moduleReference);return e.setEmitFlags(a,3584),Un(t)||!Gn(t)?e.setOriginalNode(e.setTextRange(f.createVariableStatement(e.visitNodes(t.modifiers,U,e.isModifier),f.createVariableDeclarationList([e.setOriginalNode(f.createVariableDeclaration(t.name,void 0,void 0,a),t)])),t),t):e.setOriginalNode(Hn(t.name,a,t),t)}}}function Gn(n){return void 0!==a&&e.hasSyntacticModifier(n,1)}function Bn(n){return void 0===a&&e.hasSyntacticModifier(n,1)}function Un(n){return Bn(n)&&!e.hasSyntacticModifier(n,512)}function Vn(n){return Bn(n)&&e.hasSyntacticModifier(n,512)}function jn(e){return f.createExpressionStatement(e)}function Kn(n,t){var r=f.createAssignment(f.getExternalModuleOrNamespaceExportName(i,t,!1,!0),f.getLocalName(t));e.setSourceMapRange(r,e.createRange(t.name?t.name.pos:t.pos,t.end));var a=f.createExpressionStatement(r);e.setSourceMapRange(a,e.createRange(-1,t.end)),n.push(a)}function Hn(n,t,r){return e.setTextRange(f.createExpressionStatement(f.createAssignment(f.getNamespaceMemberName(i,n,!1,!0),t)),r)}function Wn(n,t,r){return e.setTextRange(f.createAssignment(zn(n),t),r)}function zn(e){return f.getNamespaceMemberName(i,e,!1,!0)}function qn(n){var t=f.getGeneratedNameForNode(n);return e.setSourceMapRange(t,n.name),t}function Jn(e){return f.getGeneratedNameForNode(e)}function Xn(n){if(16777216&v.getNodeCheckFlags(n)){$n();var t=f.createUniqueName(n.name&&!e.isGeneratedIdentifier(n.name)?e.idText(n.name):"default");return d[e.getOriginalNodeId(n)]=t,h(t),t}}function Yn(e){return f.createPropertyAccessExpression(f.getDeclarationName(e),"prototype")}function Qn(n,t){return e.hasSyntacticModifier(t,32)?f.getDeclarationName(n):Yn(n)}function Zn(){0===(8&u)&&(u|=8,n.enableSubstitution(78))}function $n(){0===(1&u)&&(u|=1,n.enableSubstitution(78),d=[])}function et(){0===(2&u)&&(u|=2,n.enableSubstitution(78),n.enableSubstitution(290),n.enableEmitNotification(257))}function nt(n){return 257===e.getOriginalNode(n).kind}function tt(n){return 256===e.getOriginalNode(n).kind}function rt(n,r,a){var i=p,o=t;e.isSourceFile(r)&&(t=r),2&u&&nt(r)&&(p|=2),8&u&&tt(r)&&(p|=8),x(n,r,a),p=i,t=o}function at(n,t){return t=L(n,t),1===n?ot(t):e.isShorthandPropertyAssignment(t)?it(t):t}function it(n){if(2&u){var t=n.name,r=lt(t);if(r){if(n.objectAssignmentInitializer){var a=f.createAssignment(r,n.objectAssignmentInitializer);return e.setTextRange(f.createPropertyAssignment(t,a),n)}return e.setTextRange(f.createPropertyAssignment(t,r),n)}}return n}function ot(e){switch(e.kind){case 78:return st(e);case 202:return ut(e);case 203:return dt(e)}return e}function st(e){return ct(e)||lt(e)||e}function ct(n){if(1&u&&33554432&v.getNodeCheckFlags(n)){var t=v.getReferencedValueDeclaration(n);if(t){var r=d[t.id];if(r){var a=f.cloneNode(r);return e.setSourceMapRange(a,n),e.setCommentRange(a,n),a}}}}function lt(n){if(u&p&&!e.isGeneratedIdentifier(n)&&!e.isLocalName(n)){var t=v.getReferencedExportContainer(n,!1);if(t&&298!==t.kind){var r=2&p&&257===t.kind||8&p&&256===t.kind;if(r)return e.setTextRange(f.createPropertyAccessExpression(f.getGeneratedNameForNode(t),n),n)}}}function ut(e){return pt(e)}function dt(e){return pt(e)}function pt(n){var t=ft(n);if(void 0!==t){e.setConstantValue(n,t);var r="string"===typeof t?f.createStringLiteral(t):f.createNumericLiteral(t);if(!b.removeComments){var a=e.getOriginalNode(n,e.isAccessExpression),i=e.isPropertyAccessExpression(a)?e.declarationNameToString(a.name):e.getTextOfNode(a.argumentExpression);e.addSyntheticTrailingComment(r,3," "+i+" ")}return r}return n}function ft(n){if(!b.isolatedModules)return e.isPropertyAccessExpression(n)||e.isElementAccessExpression(n)?v.getConstantValue(n):void 0}}(function(e){e[e["ClassAliases"]=1]="ClassAliases",e[e["NamespaceExports"]=2]="NamespaceExports",e[e["NonQualifiedEnumMembers"]=8]="NonQualifiedEnumMembers"})(n||(n={})),function(e){e[e["None"]=0]="None",e[e["HasStaticInitializedProperties"]=1]="HasStaticInitializedProperties",e[e["HasConstructorDecorators"]=2]="HasConstructorDecorators",e[e["HasMemberDecorators"]=4]="HasMemberDecorators",e[e["IsExportOfNamespace"]=8]="IsExportOfNamespace",e[e["IsNamedExternalExport"]=16]="IsNamedExternalExport",e[e["IsDefaultExternalExport"]=32]="IsDefaultExternalExport",e[e["IsDerivedClass"]=64]="IsDerivedClass",e[e["UseImmediatelyInvokedFunctionExpression"]=128]="UseImmediatelyInvokedFunctionExpression",e[e["HasAnyDecorators"]=6]="HasAnyDecorators",e[e["NeedsName"]=5]="NeedsName",e[e["MayNeedImmediatelyInvokedFunctionExpression"]=7]="MayNeedImmediatelyInvokedFunctionExpression",e[e["IsExported"]=56]="IsExported"}(t||(t={})),e.transformTypeScript=a}(d||(d={})),function(e){var n;function t(n){var t,c,l,u,d=n.factory,p=n.hoistVariableDeclaration,f=n.endLexicalEnvironment,m=n.resumeLexicalEnvironment,_=n.addBlockScopedVariable,g=n.getEmitResolver(),y=n.getCompilerOptions(),h=e.getEmitScriptTarget(y),v=e.getUseDefineForClassFields(y),b=h<99,E=n.onSubstituteNode;n.onSubstituteNode=se;var T,S=[];return e.chainBundle(n,x);function x(t){var r=n.getCompilerOptions();if(t.isDeclarationFile||v&&99===r.target)return t;var a=e.visitEachChild(t,L,n);return e.addEmitHelpers(a,n.readEmitHelpers()),a}function L(t){if(!(8388608&t.transformFlags))return t;switch(t.kind){case 222:case 253:return z(t);case 164:return O(t);case 233:return I(t);case 202:return M(t);case 215:return F(t);case 216:return G(t,!1);case 204:return j(t);case 217:return H(t);case 79:return A(t);case 234:return U(t);case 238:return B(t);case 206:return K(t)}return e.visitEachChild(t,L,n)}function D(e){switch(e.kind){case 201:case 200:return Se(e);default:return L(e)}}function A(n){return b?e.setOriginalNode(d.createIdentifier(""),n):n}function C(e){switch(e.kind){case 167:return;case 168:case 169:case 166:return k(e);case 164:return O(e);case 159:return N(e);case 230:return e;default:return L(e)}}function I(t){var r=u;u=[];var a=e.visitEachChild(t,L,n),o=e.some(u)?i([a],u):a;return u=r,o}function N(t){var r=e.visitEachChild(t,L,n);if(e.some(l)){var a=l;a.push(r.expression),l=[],r=d.updateComputedPropertyName(r,d.inlineExpressions(a))}return r}function k(t){if(e.Debug.assert(!e.some(t.decorators)),!b||!e.isPrivateIdentifier(t.name))return e.visitEachChild(t,C,n);var r=ve(t.name);if(e.Debug.assert(r,"Undeclared private name for property declaration."),!r.isValid)return t;var a=R(t);a&&_e().push(d.createAssignment(a,d.createFunctionExpression(e.filter(t.modifiers,(function(n){return!e.isStaticModifier(n)})),t.asteriskToken,a,void 0,e.visitParameterList(t.parameters,C,n),void 0,e.visitFunctionBody(t.body,C,n))))}function R(n){e.Debug.assert(e.isPrivateIdentifier(n.name));var t=ve(n.name);if(e.Debug.assert(t,"Undeclared private name for property declaration."),"m"===t.kind)return t.methodName;if("a"===t.kind){if(e.isGetAccessor(n))return t.getterName;if(e.isSetAccessor(n))return t.setterName}}function O(n){if(e.Debug.assert(!e.some(n.decorators)),e.isPrivateIdentifier(n.name)){if(!b)return d.updatePropertyDeclaration(n,void 0,e.visitNodes(n.modifiers,L,e.isModifier),n.name,void 0,void 0,void 0);var t=ve(n.name);if(e.Debug.assert(t,"Undeclared private name for property declaration."),!t.isValid)return n}var r=de(n.name,!!n.initializer||v);r&&!e.isSimpleInlineableExpression(r)&&_e().push(r)}function w(n,t){return P(n,e.visitNode(t,L,e.isExpression))}function P(t,r){switch(e.setCommentRange(r,e.moveRangePos(r,-1)),t.kind){case"a":return n.getEmitHelperFactory().createClassPrivateFieldGetHelper(r,t.brandCheckIdentifier,t.kind,t.getterName);case"m":return n.getEmitHelperFactory().createClassPrivateFieldGetHelper(r,t.brandCheckIdentifier,t.kind,t.methodName);case"f":return n.getEmitHelperFactory().createClassPrivateFieldGetHelper(r,t.brandCheckIdentifier,t.kind,t.variableName);default:e.Debug.assertNever(t,"Unknown private element type")}}function M(t){if(b&&e.isPrivateIdentifier(t.name)){var r=ve(t.name);if(r)return e.setTextRange(e.setOriginalNode(w(r,t.expression),t),t)}return e.visitEachChild(t,L,n)}function F(t){if(b&&e.isPrivateIdentifierPropertyAccessExpression(t.operand)){var r=45===t.operator?39:46===t.operator?40:void 0,a=void 0;if(r&&(a=ve(t.operand.name))){var i=e.visitNode(t.operand.expression,L,e.isExpression),o=V(i),s=o.readExpression,c=o.initializeExpression,l=d.createPrefixUnaryExpression(39,w(a,s));return e.setOriginalNode(W(a,c||s,d.createBinaryExpression(l,r,d.createNumericLiteral(1)),62),t)}}return e.visitEachChild(t,L,n)}function G(t,r){if(b&&e.isPrivateIdentifierPropertyAccessExpression(t.operand)){var a=45===t.operator?39:46===t.operator?40:void 0,i=void 0;if(a&&(i=ve(t.operand.name))){var o=e.visitNode(t.operand.expression,L,e.isExpression),s=V(o),c=s.readExpression,l=s.initializeExpression,u=d.createPrefixUnaryExpression(39,w(i,c)),f=r?void 0:d.createTempVariable(p);return e.setOriginalNode(d.inlineExpressions(e.compact([W(i,l||c,d.createBinaryExpression(f?d.createAssignment(f,u):u,a,d.createNumericLiteral(1)),62),f])),t)}}return e.visitEachChild(t,L,n)}function B(t){return t.incrementor&&e.isPostfixUnaryExpression(t.incrementor)?d.updateForStatement(t,e.visitNode(t.initializer,L,e.isForInitializer),e.visitNode(t.condition,L,e.isExpression),G(t.incrementor,!0),e.visitIterationBody(t.statement,L,n)):e.visitEachChild(t,L,n)}function U(t){return e.isPostfixUnaryExpression(t.expression)?d.updateExpressionStatement(t,G(t.expression,!0)):e.visitEachChild(t,L,n)}function V(n){var t=e.nodeIsSynthesized(n)?n:d.cloneNode(n);if(e.isSimpleInlineableExpression(n))return{readExpression:t,initializeExpression:void 0};var r=d.createTempVariable(p),a=d.createAssignment(r,t);return{readExpression:r,initializeExpression:a}}function j(t){if(b&&e.isPrivateIdentifierPropertyAccessExpression(t.expression)){var r=d.createCallBinding(t.expression,p,h),a=r.thisArg,o=r.target;return e.isCallChain(t)?d.updateCallChain(t,d.createPropertyAccessChain(e.visitNode(o,L),t.questionDotToken,"call"),void 0,void 0,i([e.visitNode(a,L,e.isExpression)],e.visitNodes(t.arguments,L,e.isExpression))):d.updateCallExpression(t,d.createPropertyAccessExpression(e.visitNode(o,L),"call"),void 0,i([e.visitNode(a,L,e.isExpression)],e.visitNodes(t.arguments,L,e.isExpression)))}return e.visitEachChild(t,L,n)}function K(t){if(b&&e.isPrivateIdentifierPropertyAccessExpression(t.tag)){var r=d.createCallBinding(t.tag,p,h),a=r.thisArg,i=r.target;return d.updateTaggedTemplateExpression(t,d.createCallExpression(d.createPropertyAccessExpression(e.visitNode(i,L),"bind"),void 0,[e.visitNode(a,L,e.isExpression)]),void 0,e.visitNode(t.template,L,e.isTemplateLiteral))}return e.visitEachChild(t,L,n)}function H(t){if(b){if(e.isDestructuringAssignment(t)){var r=l;l=void 0,t=d.updateBinaryExpression(t,e.visitNode(t.left,D),t.operatorToken,e.visitNode(t.right,L));var a=e.some(l)?d.inlineExpressions(e.compact(i(i([],l),[t]))):t;return l=r,a}if(e.isAssignmentExpression(t)&&e.isPrivateIdentifierPropertyAccessExpression(t.left)){var o=ve(t.left.name);if(o)return e.setTextRange(e.setOriginalNode(W(o,t.left.expression,t.right,t.operatorToken.kind),t),t)}}return e.visitEachChild(t,L,n)}function W(t,r,a,i){if(r=e.visitNode(r,L,e.isExpression),a=e.visitNode(a,L,e.isExpression),e.isCompoundAssignment(i)){var o=V(r),s=o.readExpression,c=o.initializeExpression;r=c||s,a=d.createBinaryExpression(P(t,s),e.getNonAssignmentOperatorForCompoundAssignment(i),a)}switch(e.setCommentRange(r,e.moveRangePos(r,-1)),t.kind){case"a":return n.getEmitHelperFactory().createClassPrivateFieldSetHelper(r,t.brandCheckIdentifier,a,t.kind,t.setterName);case"m":return n.getEmitHelperFactory().createClassPrivateFieldSetHelper(r,t.brandCheckIdentifier,a,t.kind,void 0);case"f":return n.getEmitHelperFactory().createClassPrivateFieldSetHelper(r,t.brandCheckIdentifier,a,t.kind,t.variableName);default:e.Debug.assertNever(t,"Unknown private element type")}}function z(n){var t=l;if(l=void 0,b){pe();var r=e.getNameOfDeclaration(n);r&&e.isIdentifier(r)&&(me().className=e.idText(r));var a=J(n);e.some(a)&&(me().weakSetName=ye("instances",a[0].name))}var i=e.isClassDeclaration(n)?X(n):Y(n);return b&&fe(),l=t,i}function q(n){return e.isPropertyDeclaration(n)||b&&n.name&&e.isPrivateIdentifier(n.name)}function J(n){return e.filter(n.members,e.isNonStaticMethodOrAccessorWithPrivateName)}function X(t){if(!e.forEach(t.members,q))return e.visitEachChild(t,L,n);var r,a=e.getProperties(t,!1,!0);if(b&&e.some(t.members,(function(n){return e.hasStaticModifier(n)&&!!n.name&&e.isPrivateIdentifier(n.name)}))){var i=d.createTempVariable(p,!0);me().classConstructor=d.cloneNode(i),r=d.createAssignment(i,d.getInternalName(t))}var o=e.getEffectiveBaseTypeNode(t),s=!(!o||103===e.skipOuterExpressions(o.expression).kind),c=[d.updateClassDeclaration(t,void 0,t.modifiers,t.name,void 0,e.visitNodes(t.heritageClauses,L,e.isHeritageClause),Q(t,s))];return r&&_e().unshift(r),e.some(l)&&c.push(d.createExpressionStatement(d.inlineExpressions(l))),e.some(a)&&te(c,a,d.getInternalName(t)),c}function Y(t){if(!e.forEach(t.members,q))return e.visitEachChild(t,L,n);var r,a=e.isClassDeclaration(e.getOriginalNode(t)),i=e.getProperties(t,!1,!0),o=e.getEffectiveBaseTypeNode(t),s=!(!o||103===e.skipOuterExpressions(o.expression).kind),f=16777216&g.getNodeCheckFlags(t);function m(){var e=g.getNodeCheckFlags(t),n=16777216&e,r=524288&e;return d.createTempVariable(r?_:p,!!n)}b&&e.some(t.members,(function(n){return e.hasStaticModifier(n)&&!!n.name&&e.isPrivateIdentifier(n.name)}))&&(r=m(),me().classConstructor=d.cloneNode(r));var y=d.updateClassExpression(t,e.visitNodes(t.decorators,L,e.isDecorator),t.modifiers,t.name,void 0,e.visitNodes(t.heritageClauses,L,e.isHeritageClause),Q(t,s)),h=e.some(i,(function(n){return!!n.initializer||b&&e.isPrivateIdentifier(n.name)}));if(h||e.some(l)){if(a)return e.Debug.assertIsDefined(u,"Decorated classes transformed by TypeScript are expected to be within a variable declaration."),u&&l&&e.some(l)&&u.push(d.createExpressionStatement(d.inlineExpressions(l))),u&&e.some(i)&&te(u,i,d.getInternalName(t)),r?d.inlineExpressions([d.createAssignment(r,y),r]):y;var v=[];if(r||(r=m()),f){ie();var E=d.cloneNode(r);E.autoGenerateFlags&=-9,c[e.getOriginalNodeId(t)]=E}return e.setEmitFlags(y,65536|e.getEmitFlags(y)),v.push(e.startOnNewLine(d.createAssignment(r,y))),e.addRange(v,e.map(l,e.startOnNewLine)),e.addRange(v,re(i,r)),v.push(e.startOnNewLine(r)),d.inlineExpressions(v)}return y}function Q(n,t){if(b){for(var r=0,a=n.members;r<a.length;r++){var i=a[r];e.isPrivateIdentifierClassElementDeclaration(i)&&ge(i)}e.some(J(n))&&Z()}var o=[],s=ee(n,t);return s&&o.push(s),e.addRange(o,e.visitNodes(n.members,C,e.isClassElement)),e.setTextRange(d.createNodeArray(o),n.members)}function Z(){var n=me().weakSetName;e.Debug.assert(n,"weakSetName should be set in private identifier environment"),_e().push(d.createAssignment(n,d.createNewExpression(d.createIdentifier("WeakSet"),void 0,[])))}function $(n){return!e.hasStaticModifier(n)&&!e.hasSyntacticModifier(e.getOriginalNode(n),128)&&(v?h<99:e.isInitializedProperty(n)||b&&e.isPrivateIdentifierClassElementDeclaration(n))}function ee(t,r){var a=e.visitNode(e.getFirstConstructorWithBody(t),L,e.isConstructorDeclaration),i=t.members.filter($);if(!e.some(i))return a;var o=e.visitParameterList(a?a.parameters:void 0,L,n),s=ne(t,a,r);return s?e.startOnNewLine(e.setOriginalNode(e.setTextRange(d.createConstructorDeclaration(void 0,void 0,null!==o&&void 0!==o?o:[],s),a||t),a)):void 0}function ne(t,r,a){var i=e.getProperties(t,!1,!1);v||(i=e.filter(i,(function(n){return!!n.initializer||e.isPrivateIdentifier(n.name)})));var o=J(t),s=e.some(i)||e.some(o);if(!r&&!s)return e.visitFunctionBody(void 0,L,n);m();var c=0,l=[];if(!r&&a&&l.push(d.createExpressionStatement(d.createCallExpression(d.createSuper(),void 0,[d.createSpreadElement(d.createIdentifier("arguments"))]))),r&&(c=e.addPrologueDirectivesAndInitialSuperCall(d,r,l,L)),null===r||void 0===r?void 0:r.body){var u=e.findIndex(r.body.statements,(function(n){return!e.isParameterPropertyDeclaration(e.getOriginalNode(n),r)}),c);-1===u&&(u=r.body.statements.length),u>c&&(v||e.addRange(l,e.visitNodes(r.body.statements,L,e.isStatement,c,u-c)),c=u)}var p=d.createThis();return oe(l,o,p),te(l,i,p),r&&e.addRange(l,e.visitNodes(r.body.statements,L,e.isStatement,c)),l=d.mergeLexicalEnvironment(l,f()),e.setTextRange(d.createBlock(e.setTextRange(d.createNodeArray(l),r?r.body.statements:t.members),!0),r?r.body:void 0)}function te(n,t,r){for(var a=0,i=t;a<i.length;a++){var o=i[a],s=ae(o,r);if(s){var c=d.createExpressionStatement(s);e.setSourceMapRange(c,e.moveRangePastModifiers(o)),e.setCommentRange(c,o),e.setOriginalNode(c,o),n.push(c)}}}function re(n,t){for(var r=[],a=0,i=n;a<i.length;a++){var o=i[a],s=ae(o,t);s&&(e.startOnNewLine(s),e.setSourceMapRange(s,e.moveRangePastModifiers(o)),e.setCommentRange(s,o),e.setOriginalNode(s,o),r.push(s))}return r}function ae(n,t){var i,o=!v,s=e.isComputedPropertyName(n.name)&&!e.isSimpleInlineableExpression(n.name.expression)?d.updateComputedPropertyName(n.name,d.getGeneratedNameForNode(n.name)):n.name;if(b&&e.isPrivateIdentifier(s)){var c=ve(s);if(c)return"f"===c.kind?c.isStatic?r(c.variableName,e.visitNode(n.initializer,L,e.isExpression)):a(t,e.visitNode(n.initializer,L,e.isExpression),c.brandCheckIdentifier):void 0;e.Debug.fail("Undeclared private name for property declaration.")}if(!e.isPrivateIdentifier(s)&&!e.hasStaticModifier(n)||n.initializer){var l=e.getOriginalNode(n);if(!e.hasSyntacticModifier(l,128)){var u=n.initializer||o?null!==(i=e.visitNode(n.initializer,L,e.isExpression))&&void 0!==i?i:d.createVoidZero():e.isParameterPropertyDeclaration(l,l.parent)&&e.isIdentifier(s)?s:d.createVoidZero();if(o||e.isPrivateIdentifier(s)){var p=e.createMemberAccessForPropertyName(d,t,s,s);return d.createAssignment(p,u)}var f=e.isComputedPropertyName(s)?s.expression:e.isIdentifier(s)?d.createStringLiteral(e.unescapeLeadingUnderscores(s.escapedText)):s,m=d.createPropertyDescriptor({value:u,configurable:!0,writable:!0,enumerable:!0});return d.createObjectDefinePropertyCall(t,f,m)}}}function ie(){0===(1&t)&&(t|=1,n.enableSubstitution(78),c=[])}function oe(n,t,r){if(b&&e.some(t)){var a=me().weakSetName;e.Debug.assert(a,"weakSetName should be set in private identifier environment"),n.push(d.createExpressionStatement(o(r,a)))}}function se(e,n){return n=E(e,n),1===e?ce(n):n}function ce(e){switch(e.kind){case 78:return le(e)}return e}function le(e){return ue(e)||e}function ue(n){if(1&t&&33554432&g.getNodeCheckFlags(n)){var r=g.getReferencedValueDeclaration(n);if(r){var a=c[r.id];if(a){var i=d.cloneNode(a);return e.setSourceMapRange(i,n),e.setCommentRange(i,n),i}}}}function de(n,t){if(e.isComputedPropertyName(n)){var r=e.visitNode(n.expression,L,e.isExpression),a=e.skipPartiallyEmittedExpressions(r),i=e.isSimpleInlineableExpression(a),o=e.isAssignmentExpression(a)&&e.isGeneratedIdentifier(a.left);if(!o&&!i&&t){var s=d.getGeneratedNameForNode(n);return 524288&g.getNodeCheckFlags(n)?_(s):p(s),d.createAssignment(s,r)}return i||e.isIdentifier(a)?void 0:r}}function pe(){S.push(T),T=void 0}function fe(){T=S.pop()}function me(){return T||(T={className:"",identifiers:new e.Map}),T}function _e(){return l||(l=[])}function ge(n){var t,r=e.getTextOfPropertyName(n.name),a=me(),i=a.weakSetName,o=a.classConstructor,c=[],l=n.name.escapedText,u=a.identifiers.get(l),p=!s(n.name)&&void 0===u;if(e.hasStaticModifier(n))if(e.Debug.assert(o,"weakSetName should be set in private identifier environment"),e.isPropertyDeclaration(n)){var f=he(r,n);a.identifiers.set(l,{kind:"f",variableName:f,brandCheckIdentifier:o,isStatic:!0,isValid:p})}else if(e.isMethodDeclaration(n)){var m=he(r,n);a.identifiers.set(l,{kind:"m",methodName:m,brandCheckIdentifier:o,isStatic:!0,isValid:p})}else if(e.isGetAccessorDeclaration(n)){var _=he(r+"_get",n);"a"===(null===u||void 0===u?void 0:u.kind)&&u.isStatic&&!u.getterName?u.getterName=_:a.identifiers.set(l,{kind:"a",getterName:_,setterName:void 0,brandCheckIdentifier:o,isStatic:!0,isValid:p})}else if(e.isSetAccessorDeclaration(n)){var g=he(r+"_set",n);"a"===(null===u||void 0===u?void 0:u.kind)&&u.isStatic&&!u.setterName?u.setterName=g:a.identifiers.set(l,{kind:"a",getterName:void 0,setterName:g,brandCheckIdentifier:o,isStatic:!0,isValid:p})}else e.Debug.assertNever(n,"Unknown class element type.");else if(e.isPropertyDeclaration(n)){var y=he(r,n);a.identifiers.set(l,{kind:"f",brandCheckIdentifier:y,isStatic:!1,variableName:void 0,isValid:p}),c.push(d.createAssignment(y,d.createNewExpression(d.createIdentifier("WeakMap"),void 0,[])))}else if(e.isMethodDeclaration(n))e.Debug.assert(i,"weakSetName should be set in private identifier environment"),a.identifiers.set(l,{kind:"m",methodName:he(r,n),brandCheckIdentifier:i,isStatic:!1,isValid:p});else if(e.isAccessor(n))if(e.Debug.assert(i,"weakSetName should be set in private identifier environment"),e.isGetAccessor(n)){_=he(r+"_get",n);"a"!==(null===u||void 0===u?void 0:u.kind)||u.isStatic||u.getterName?a.identifiers.set(l,{kind:"a",getterName:_,setterName:void 0,brandCheckIdentifier:i,isStatic:!1,isValid:p}):u.getterName=_}else{g=he(r+"_set",n);"a"!==(null===u||void 0===u?void 0:u.kind)||u.isStatic||u.setterName?a.identifiers.set(l,{kind:"a",getterName:void 0,setterName:g,brandCheckIdentifier:i,isStatic:!1,isValid:p}):u.setterName=g}else e.Debug.assertNever(n,"Unknown class element type.");(t=_e()).push.apply(t,c)}function ye(e,n){var t=me().className,r=t?"_"+t:"",a=d.createUniqueName(r+"_"+e,16);return 524288&g.getNodeCheckFlags(n)?_(a):p(a),a}function he(e,n){return ye(e.substring(1),n.name)}function ve(e){if(T){var n=T.identifiers.get(e.escapedText);if(n)return n}for(var t=S.length-1;t>=0;--t){var r=S[t];if(r){n=r.identifiers.get(e.escapedText);if(n)return n}}}function be(t){var r=d.getGeneratedNameForNode(t),a=ve(t.name);if(!a)return e.visitEachChild(t,L,n);var i=t.expression;return(e.isThisProperty(t)||e.isSuperProperty(t)||!e.isSimpleCopiableExpression(t.expression))&&(i=d.createTempVariable(p,!0),_e().push(d.createBinaryExpression(i,62,t.expression))),d.createPropertyAccessExpression(d.createParenthesizedExpression(d.createObjectLiteralExpression([d.createSetAccessorDeclaration(void 0,void 0,"value",[d.createParameterDeclaration(void 0,void 0,void 0,r,void 0,void 0,void 0)],d.createBlock([d.createExpressionStatement(W(a,i,r,62))]))])),"value")}function Ee(n){var t=e.getTargetOfBindingOrAssignmentElement(n);if(t&&e.isPrivateIdentifierPropertyAccessExpression(t)){var r=be(t);return e.isAssignmentExpression(n)?d.updateBinaryExpression(n,r,n.operatorToken,e.visitNode(n.right,L,e.isExpression)):e.isSpreadElement(n)?d.updateSpreadElement(n,r):r}return e.visitNode(n,D)}function Te(n){if(e.isPropertyAssignment(n)){var t=e.getTargetOfBindingOrAssignmentElement(n);if(t&&e.isPrivateIdentifierPropertyAccessExpression(t)){var r=e.getInitializerOfBindingOrAssignmentElement(n),a=be(t);return d.updatePropertyAssignment(n,e.visitNode(n.name,L),r?d.createAssignment(a,e.visitNode(r,L)):a)}return d.updatePropertyAssignment(n,e.visitNode(n.name,L),e.visitNode(n.initializer,D))}return e.visitNode(n,L)}function Se(n){return e.isArrayLiteralExpression(n)?d.updateArrayLiteralExpression(n,e.visitNodes(n.elements,Ee,e.isExpression)):d.updateObjectLiteralExpression(n,e.visitNodes(n.properties,Te,e.isObjectLiteralElementLike))}}function r(n,t){return e.factory.createAssignment(n,e.factory.createObjectLiteralExpression([e.factory.createPropertyAssignment("value",t||e.factory.createVoidZero())]))}function a(n,t,r){return e.factory.createCallExpression(e.factory.createPropertyAccessExpression(r,"set"),void 0,[n,t||e.factory.createVoidZero()])}function o(n,t){return e.factory.createCallExpression(e.factory.createPropertyAccessExpression(t,"add"),void 0,[n])}function s(e){return"#constructor"===e.escapedText}(function(e){e[e["ClassAliases"]=1]="ClassAliases"})(n||(n={})),function(e){e["Field"]="f",e["Method"]="m",e["Accessor"]="a"}(e.PrivateIdentifierKind||(e.PrivateIdentifierKind={})),e.transformClassFields=t}(d||(d={})),function(e){var n,t;function r(n){var t,r,o,s,c=n.factory,l=n.getEmitHelperFactory,u=n.resumeLexicalEnvironment,d=n.endLexicalEnvironment,p=n.hoistVariableDeclaration,f=n.getEmitResolver(),m=n.getCompilerOptions(),_=e.getEmitScriptTarget(m),g=0,y=[],h=0,v=n.onEmitNode,b=n.onSubstituteNode;return n.onEmitNode=Q,n.onSubstituteNode=Z,e.chainBundle(n,E);function E(t){if(t.isDeclarationFile)return t;T(1,!1),T(2,!e.isEffectiveStrictModeSourceFile(t,m));var r=e.visitEachChild(t,C,n);return e.addEmitHelpers(r,n.readEmitHelpers()),r}function T(e,n){h=n?h|e:h&~e}function S(e){return 0!==(h&e)}function x(){return!S(1)}function L(){return S(2)}function D(e,n,t){var r=e&~h;if(r){T(r,!0);var a=n(t);return T(r,!1),a}return n(t)}function A(t){return e.visitEachChild(t,C,n)}function C(t){if(0===(128&t.transformFlags))return t;switch(t.kind){case 129:return;case 214:return P(t);case 166:return D(3,M,t);case 252:return D(3,F,t);case 209:return D(3,G,t);case 210:return D(1,B,t);case 202:return o&&e.isPropertyAccessExpression(t)&&105===t.expression.kind&&o.add(t.name.escapedText),e.visitEachChild(t,C,n);case 203:return o&&105===t.expression.kind&&(s=!0),e.visitEachChild(t,C,n);case 168:case 169:case 167:case 253:case 222:return D(3,A,t);default:return e.visitEachChild(t,C,n)}}function I(t){if(e.isNodeWithPossibleHoistedDeclaration(t))switch(t.kind){case 233:return k(t);case 238:return w(t);case 239:return R(t);case 240:return O(t);case 288:return N(t);case 231:case 245:case 259:case 285:case 286:case 248:case 236:case 237:case 235:case 244:case 246:return e.visitEachChild(t,I,n);default:return e.Debug.assertNever(t,"Unhandled node.")}return C(t)}function N(t){var a,i=new e.Set;if(U(t.variableDeclaration,i),i.forEach((function(n,t){r.has(t)&&(a||(a=new e.Set(r)),a.delete(t))})),a){var o=r;r=a;var s=e.visitEachChild(t,I,n);return r=o,s}return e.visitEachChild(t,I,n)}function k(t){if(V(t.declarationList)){var r=j(t.declarationList,!1);return r?c.createExpressionStatement(r):void 0}return e.visitEachChild(t,C,n)}function R(t){return c.updateForInStatement(t,V(t.initializer)?j(t.initializer,!0):e.visitNode(t.initializer,C,e.isForInitializer),e.visitNode(t.expression,C,e.isExpression),e.visitIterationBody(t.statement,I,n))}function O(t){return c.updateForOfStatement(t,e.visitNode(t.awaitModifier,C,e.isToken),V(t.initializer)?j(t.initializer,!0):e.visitNode(t.initializer,C,e.isForInitializer),e.visitNode(t.expression,C,e.isExpression),e.visitIterationBody(t.statement,I,n))}function w(t){var r=t.initializer;return c.updateForStatement(t,V(r)?j(r,!1):e.visitNode(t.initializer,C,e.isForInitializer),e.visitNode(t.condition,C,e.isExpression),e.visitNode(t.incrementor,C,e.isExpression),e.visitIterationBody(t.statement,I,n))}function P(t){return x()?e.visitEachChild(t,C,n):e.setOriginalNode(e.setTextRange(c.createYieldExpression(void 0,e.visitNode(t.expression,C,e.isExpression)),t),t)}function M(t){return c.updateMethodDeclaration(t,void 0,e.visitNodes(t.modifiers,C,e.isModifier),t.asteriskToken,t.name,void 0,void 0,e.visitParameterList(t.parameters,C,n),void 0,2&e.getFunctionFlags(t)?q(t):e.visitFunctionBody(t.body,C,n))}function F(t){return c.updateFunctionDeclaration(t,void 0,e.visitNodes(t.modifiers,C,e.isModifier),t.asteriskToken,t.name,void 0,e.visitParameterList(t.parameters,C,n),void 0,2&e.getFunctionFlags(t)?q(t):e.visitFunctionBody(t.body,C,n))}function G(t){return c.updateFunctionExpression(t,e.visitNodes(t.modifiers,C,e.isModifier),t.asteriskToken,t.name,void 0,e.visitParameterList(t.parameters,C,n),void 0,2&e.getFunctionFlags(t)?q(t):e.visitFunctionBody(t.body,C,n))}function B(t){return c.updateArrowFunction(t,e.visitNodes(t.modifiers,C,e.isModifier),void 0,e.visitParameterList(t.parameters,C,n),void 0,t.equalsGreaterThanToken,2&e.getFunctionFlags(t)?q(t):e.visitFunctionBody(t.body,C,n))}function U(n,t){var r=n.name;if(e.isIdentifier(r))t.add(r.escapedText);else for(var a=0,i=r.elements;a<i.length;a++){var o=i[a];e.isOmittedExpression(o)||U(o,t)}}function V(n){return!!n&&e.isVariableDeclarationList(n)&&!(3&n.flags)&&n.declarations.some(z)}function j(n,t){K(n);var r=e.getInitializedVariables(n);return 0===r.length?t?e.visitNode(c.converters.convertToAssignmentElementTarget(n.declarations[0].name),C,e.isExpression):void 0:c.inlineExpressions(e.map(r,W))}function K(n){e.forEach(n.declarations,H)}function H(n){var t=n.name;if(e.isIdentifier(t))p(t);else for(var r=0,a=t.elements;r<a.length;r++){var i=a[r];e.isOmittedExpression(i)||H(i)}}function W(n){var t=e.setSourceMapRange(c.createAssignment(c.converters.convertToAssignmentElementTarget(n.name),n.initializer),n);return e.visitNode(t,C,e.isExpression)}function z(n){var t=n.name;if(e.isIdentifier(t))return r.has(t.escapedText);for(var a=0,i=t.elements;a<i.length;a++){var o=i[a];if(!e.isOmittedExpression(o)&&z(o))return!0}return!1}function q(n){u();var t=e.getOriginalNode(n,e.isFunctionLike),i=t.type,p=_<2?X(i):void 0,m=210===n.kind,g=0!==(8192&f.getNodeCheckFlags(n)),h=r;r=new e.Set;for(var v=0,b=n.parameters;v<b.length;v++){var E=b[v];U(E,r)}var T,S=o,x=s;if(m||(o=new e.Set,s=!1),m){var D=l().createAwaiterHelper(L(),g,p,J(n.body)),A=d();if(e.some(A)){O=c.converters.convertToFunctionBlock(D);T=c.updateBlock(O,e.setTextRange(c.createNodeArray(e.concatenate(A,O.statements)),O.statements))}else T=D}else{var I=[],N=c.copyPrologue(n.body.statements,I,!1,C);I.push(c.createReturnStatement(l().createAwaiterHelper(L(),g,p,J(n.body,N)))),e.insertStatementsAfterStandardPrologue(I,d());var k=_>=2&&6144&f.getNodeCheckFlags(n);if(k&&(Y(),o.size)){var R=a(c,f,n,o);y[e.getNodeId(R)]=!0,e.insertStatementsAfterStandardPrologue(I,[R])}var O=c.createBlock(I,!0);e.setTextRange(O,n.body),k&&s&&(4096&f.getNodeCheckFlags(n)?e.addEmitHelper(O,e.advancedAsyncSuperHelper):2048&f.getNodeCheckFlags(n)&&e.addEmitHelper(O,e.asyncSuperHelper)),T=O}return r=h,m||(o=S,s=x),T}function J(n,t){return e.isBlock(n)?c.updateBlock(n,e.visitNodes(n.statements,I,e.isStatement,t)):c.converters.convertToFunctionBlock(e.visitNode(n,I,e.isConciseBody))}function X(n){var t=n&&e.getEntityNameFromTypeNode(n);if(t&&e.isEntityName(t)){var r=f.getTypeReferenceSerializationKind(t);if(r===e.TypeReferenceSerializationKind.TypeWithConstructSignatureAndValue||r===e.TypeReferenceSerializationKind.Unknown)return t}}function Y(){0===(1&t)&&(t|=1,n.enableSubstitution(204),n.enableSubstitution(202),n.enableSubstitution(203),n.enableEmitNotification(253),n.enableEmitNotification(166),n.enableEmitNotification(168),n.enableEmitNotification(169),n.enableEmitNotification(167),n.enableEmitNotification(233))}function Q(n,r,a){if(1&t&&re(r)){var i=6144&f.getNodeCheckFlags(r);if(i!==g){var o=g;return g=i,v(n,r,a),void(g=o)}}else if(t&&y[e.getNodeId(r)]){o=g;return g=0,v(n,r,a),void(g=o)}v(n,r,a)}function Z(e,n){return n=b(e,n),1===e&&g?$(n):n}function $(e){switch(e.kind){case 202:return ee(e);case 203:return ne(e);case 204:return te(e)}return e}function ee(n){return 105===n.expression.kind?e.setTextRange(c.createPropertyAccessExpression(c.createUniqueName("_super",48),n.name),n):n}function ne(e){return 105===e.expression.kind?ae(e.argumentExpression,e):e}function te(n){var t=n.expression;if(e.isSuperProperty(t)){var r=e.isPropertyAccessExpression(t)?ee(t):ne(t);return c.createCallExpression(c.createPropertyAccessExpression(r,"call"),void 0,i([c.createThis()],n.arguments))}return n}function re(e){var n=e.kind;return 253===n||167===n||166===n||168===n||169===n}function ae(n,t){return 4096&g?e.setTextRange(c.createPropertyAccessExpression(c.createCallExpression(c.createUniqueName("_superIndex",48),void 0,[n]),"value"),t):e.setTextRange(c.createCallExpression(c.createUniqueName("_superIndex",48),void 0,[n]),t)}}function a(n,t,r,a){var i=0!==(4096&t.getNodeCheckFlags(r)),o=[];return a.forEach((function(t,r){var a=e.unescapeLeadingUnderscores(r),s=[];s.push(n.createPropertyAssignment("get",n.createArrowFunction(void 0,void 0,[],void 0,void 0,e.setEmitFlags(n.createPropertyAccessExpression(e.setEmitFlags(n.createSuper(),4),a),4)))),i&&s.push(n.createPropertyAssignment("set",n.createArrowFunction(void 0,void 0,[n.createParameterDeclaration(void 0,void 0,void 0,"v",void 0,void 0,void 0)],void 0,void 0,n.createAssignment(e.setEmitFlags(n.createPropertyAccessExpression(e.setEmitFlags(n.createSuper(),4),a),4),n.createIdentifier("v"))))),o.push(n.createPropertyAssignment(a,n.createObjectLiteralExpression(s)))})),n.createVariableStatement(void 0,n.createVariableDeclarationList([n.createVariableDeclaration(n.createUniqueName("_super",48),void 0,void 0,n.createCallExpression(n.createPropertyAccessExpression(n.createIdentifier("Object"),"create"),void 0,[n.createNull(),n.createObjectLiteralExpression(o,!0)]))],2))}(function(e){e[e["AsyncMethodsWithSuper"]=1]="AsyncMethodsWithSuper"})(n||(n={})),function(e){e[e["NonTopLevel"]=1]="NonTopLevel",e[e["HasLexicalThis"]=2]="HasLexicalThis"}(t||(t={})),e.transformES2017=r,e.createSuperAccessVariableStatement=a}(d||(d={})),function(e){var n,t;function r(n){var t=n.factory,r=n.getEmitHelperFactory,a=n.resumeLexicalEnvironment,o=n.endLexicalEnvironment,s=n.hoistVariableDeclaration,c=n.getEmitResolver(),l=n.getCompilerOptions(),u=e.getEmitScriptTarget(l),d=n.onEmitNode;n.onEmitNode=_e;var p=n.onSubstituteNode;n.onSubstituteNode=ge;var f,m,_,g,y,h,v=!1,b=0,E=0,T=[];return e.chainBundle(n,A);function S(e,n){return E!==(E&~e|n)}function x(e,n){var t=E;return E=3&(E&~e|n),t}function L(e){E=e}function D(n){g=e.append(g,t.createVariableDeclaration(n))}function A(t){if(t.isDeclarationFile)return t;_=t;var r=j(t);return e.addEmitHelpers(r,n.readEmitHelpers()),_=void 0,g=void 0,r}function C(e){return O(e,!1)}function I(e){return O(e,!0)}function N(e){if(129!==e.kind)return e}function k(e,n,t,r){if(S(t,r)){var a=x(t,r),i=e(n);return L(a),i}return e(n)}function R(t){return e.visitEachChild(t,C,n)}function O(t,r){if(0===(64&t.transformFlags))return t;switch(t.kind){case 214:return w(t);case 220:return P(t);case 243:return M(t);case 246:return F(t);case 201:return B(t);case 217:return H(t,r);case 341:return W(t,r);case 288:return z(t);case 233:return q(t);case 250:return J(t);case 236:case 237:case 239:return k(R,t,0,2);case 240:return Z(t,void 0);case 238:return k(Y,t,0,2);case 213:return Q(t);case 167:return k(ae,t,2,1);case 166:return k(se,t,2,1);case 168:return k(ie,t,2,1);case 169:return k(oe,t,2,1);case 252:return k(ce,t,2,1);case 209:return k(ue,t,2,1);case 210:return k(le,t,2,0);case 161:return re(t);case 234:return U(t);case 208:return V(t,r);case 206:return K(t);case 202:return y&&e.isPropertyAccessExpression(t)&&105===t.expression.kind&&y.add(t.name.escapedText),e.visitEachChild(t,C,n);case 203:return y&&105===t.expression.kind&&(h=!0),e.visitEachChild(t,C,n);case 253:case 222:return k(R,t,2,1);default:return e.visitEachChild(t,C,n)}}function w(a){return 2&m&&1&m?e.setOriginalNode(e.setTextRange(t.createYieldExpression(void 0,r().createAwaitHelper(e.visitNode(a.expression,C,e.isExpression))),a),a):e.visitEachChild(a,C,n)}function P(a){if(2&m&&1&m){if(a.asteriskToken){var i=e.visitNode(e.Debug.assertDefined(a.expression),C,e.isExpression);return e.setOriginalNode(e.setTextRange(t.createYieldExpression(void 0,r().createAwaitHelper(t.updateYieldExpression(a,a.asteriskToken,e.setTextRange(r().createAsyncDelegatorHelper(e.setTextRange(r().createAsyncValuesHelper(i),i)),i)))),a),a)}return e.setOriginalNode(e.setTextRange(t.createYieldExpression(void 0,ne(a.expression?e.visitNode(a.expression,C,e.isExpression):t.createVoidZero())),a),a)}return e.visitEachChild(a,C,n)}function M(r){return 2&m&&1&m?t.updateReturnStatement(r,ne(r.expression?e.visitNode(r.expression,C,e.isExpression):t.createVoidZero())):e.visitEachChild(r,C,n)}function F(r){if(2&m){var a=e.unwrapInnermostStatementOfLabel(r);return 240===a.kind&&a.awaitModifier?Z(a,r):t.restoreEnclosingLabel(e.visitNode(a,C,e.isStatement,t.liftToBlock),r)}return e.visitEachChild(r,C,n)}function G(n){for(var r,a=[],i=0,o=n;i<o.length;i++){var s=o[i];if(291===s.kind){r&&(a.push(t.createObjectLiteralExpression(r)),r=void 0);var c=s.expression;a.push(e.visitNode(c,C,e.isExpression))}else r=e.append(r,289===s.kind?t.createPropertyAssignment(s.name,e.visitNode(s.initializer,C,e.isExpression)):e.visitNode(s,C,e.isObjectLiteralElementLike))}return r&&a.push(t.createObjectLiteralExpression(r)),a}function B(a){if(32768&a.transformFlags){var i=G(a.properties);i.length&&201!==i[0].kind&&i.unshift(t.createObjectLiteralExpression());var o=i[0];if(i.length>1){for(var s=1;s<i.length;s++)o=r().createAssignHelper([o,i[s]]);return o}return r().createAssignHelper(i)}return e.visitEachChild(a,C,n)}function U(t){return e.visitEachChild(t,I,n)}function V(t,r){return e.visitEachChild(t,r?I:C,n)}function j(r){var a=x(2,e.isEffectiveStrictModeSourceFile(r,l)?0:1);v=!1;var i=e.visitEachChild(r,C,n),o=e.concatenate(i.statements,g&&[t.createVariableStatement(void 0,t.createVariableDeclarationList(g))]),s=t.updateSourceFile(i,e.setTextRange(t.createNodeArray(o),r.statements));return L(a),s}function K(t){return e.processTaggedTemplateExpression(n,t,C,_,D,e.ProcessLevel.LiftRestriction)}function H(r,a){return e.isDestructuringAssignment(r)&&32768&r.left.transformFlags?e.flattenDestructuringAssignment(r,C,n,1,!a):27===r.operatorToken.kind?t.updateBinaryExpression(r,e.visitNode(r.left,I,e.isExpression),r.operatorToken,e.visitNode(r.right,a?I:C,e.isExpression)):e.visitEachChild(r,C,n)}function W(r,a){if(a)return e.visitEachChild(r,I,n);for(var i,o=0;o<r.elements.length;o++){var s=r.elements[o],c=e.visitNode(s,o<r.elements.length-1?I:C,e.isExpression);(i||c!==s)&&(i||(i=r.elements.slice(0,o)),i.push(c))}var l=i?e.setTextRange(t.createNodeArray(i),r.elements):r.elements;return t.updateCommaListExpression(r,l)}function z(r){if(r.variableDeclaration&&e.isBindingPattern(r.variableDeclaration.name)&&32768&r.variableDeclaration.name.transformFlags){var a=t.getGeneratedNameForNode(r.variableDeclaration.name),o=t.updateVariableDeclaration(r.variableDeclaration,r.variableDeclaration.name,void 0,void 0,a),s=e.flattenDestructuringBinding(o,C,n,1),c=e.visitNode(r.block,C,e.isBlock);return e.some(s)&&(c=t.updateBlock(c,i([t.createVariableStatement(void 0,s)],c.statements))),t.updateCatchClause(r,t.updateVariableDeclaration(r.variableDeclaration,a,void 0,void 0,void 0),c)}return e.visitEachChild(r,C,n)}function q(t){if(e.hasSyntacticModifier(t,1)){var r=v;v=!0;var a=e.visitEachChild(t,C,n);return v=r,a}return e.visitEachChild(t,C,n)}function J(e){if(v){var n=v;v=!1;var t=X(e,!0);return v=n,t}return X(e,!1)}function X(t,r){return e.isBindingPattern(t.name)&&32768&t.name.transformFlags?e.flattenDestructuringBinding(t,C,n,1,void 0,r):e.visitEachChild(t,C,n)}function Y(r){return t.updateForStatement(r,e.visitNode(r.initializer,I,e.isForInitializer),e.visitNode(r.condition,C,e.isExpression),e.visitNode(r.incrementor,I,e.isExpression),e.visitIterationBody(r.statement,C,n))}function Q(t){return e.visitEachChild(t,I,n)}function Z(r,a){var i=x(0,2);32768&r.initializer.transformFlags&&(r=$(r));var o=r.awaitModifier?te(r,a,i):t.restoreEnclosingLabel(e.visitEachChild(r,C,n),a);return L(i),o}function $(n){var r=e.skipParentheses(n.initializer);if(e.isVariableDeclarationList(r)||e.isAssignmentPattern(r)){var a=void 0,i=void 0,o=t.createTempVariable(void 0),s=[e.createForOfBindingStatement(t,r,o)];return e.isBlock(n.statement)?(e.addRange(s,n.statement.statements),a=n.statement,i=n.statement.statements):n.statement&&(e.append(s,n.statement),a=n.statement,i=n.statement),t.updateForOfStatement(n,n.awaitModifier,e.setTextRange(t.createVariableDeclarationList([e.setTextRange(t.createVariableDeclaration(o),n.initializer)],1),n.initializer),n.expression,e.setTextRange(t.createBlock(e.setTextRange(t.createNodeArray(s),i),!0),a))}return n}function ee(r,a){var i,o,s=e.createForOfBindingStatement(t,r.initializer,a),c=[e.visitNode(s,C,e.isStatement)],l=e.visitIterationBody(r.statement,C,n);return e.isBlock(l)?(e.addRange(c,l.statements),i=l,o=l.statements):c.push(l),e.setEmitFlags(e.setTextRange(t.createBlock(e.setTextRange(t.createNodeArray(c),o),!0),i),432)}function ne(e){return 1&m?t.createYieldExpression(void 0,r().createAwaitHelper(e)):t.createAwaitExpression(e)}function te(n,a,i){var o=e.visitNode(n.expression,C,e.isExpression),c=e.isIdentifier(o)?t.getGeneratedNameForNode(o):t.createTempVariable(void 0),l=e.isIdentifier(o)?t.getGeneratedNameForNode(c):t.createTempVariable(void 0),u=t.createUniqueName("e"),d=t.getGeneratedNameForNode(u),p=t.createTempVariable(void 0),f=e.setTextRange(r().createAsyncValuesHelper(o),n.expression),m=t.createCallExpression(t.createPropertyAccessExpression(c,"next"),void 0,[]),_=t.createPropertyAccessExpression(l,"done"),g=t.createPropertyAccessExpression(l,"value"),y=t.createFunctionCallCall(p,c,[]);s(u),s(p);var h=2&i?t.inlineExpressions([t.createAssignment(u,t.createVoidZero()),f]):f,v=e.setEmitFlags(e.setTextRange(t.createForStatement(e.setEmitFlags(e.setTextRange(t.createVariableDeclarationList([e.setTextRange(t.createVariableDeclaration(c,void 0,void 0,h),n.expression),t.createVariableDeclaration(l)]),n.expression),2097152),t.createComma(t.createAssignment(l,ne(m)),t.createLogicalNot(_)),void 0,ee(n,g)),n),256);return t.createTryStatement(t.createBlock([t.restoreEnclosingLabel(v,a)]),t.createCatchClause(t.createVariableDeclaration(d),e.setEmitFlags(t.createBlock([t.createExpressionStatement(t.createAssignment(u,t.createObjectLiteralExpression([t.createPropertyAssignment("error",d)])))]),1)),t.createBlock([t.createTryStatement(t.createBlock([e.setEmitFlags(t.createIfStatement(t.createLogicalAnd(t.createLogicalAnd(l,t.createLogicalNot(_)),t.createAssignment(p,t.createPropertyAccessExpression(c,"return"))),t.createExpressionStatement(ne(y))),1)]),void 0,e.setEmitFlags(t.createBlock([e.setEmitFlags(t.createIfStatement(u,t.createThrowStatement(t.createPropertyAccessExpression(u,"error"))),1)]),1))]))}function re(r){return 32768&r.transformFlags?t.updateParameterDeclaration(r,void 0,void 0,r.dotDotDotToken,t.getGeneratedNameForNode(r),void 0,void 0,e.visitNode(r.initializer,C,e.isExpression)):e.visitEachChild(r,C,n)}function ae(r){var a=m;m=0;var i=t.updateConstructorDeclaration(r,void 0,r.modifiers,e.visitParameterList(r.parameters,C,n),pe(r));return m=a,i}function ie(r){var a=m;m=0;var i=t.updateGetAccessorDeclaration(r,void 0,r.modifiers,e.visitNode(r.name,C,e.isPropertyName),e.visitParameterList(r.parameters,C,n),void 0,pe(r));return m=a,i}function oe(r){var a=m;m=0;var i=t.updateSetAccessorDeclaration(r,void 0,r.modifiers,e.visitNode(r.name,C,e.isPropertyName),e.visitParameterList(r.parameters,C,n),pe(r));return m=a,i}function se(r){var a=m;m=e.getFunctionFlags(r);var i=t.updateMethodDeclaration(r,void 0,1&m?e.visitNodes(r.modifiers,N,e.isModifier):r.modifiers,2&m?void 0:r.asteriskToken,e.visitNode(r.name,C,e.isPropertyName),e.visitNode(void 0,C,e.isToken),void 0,e.visitParameterList(r.parameters,C,n),void 0,2&m&&1&m?de(r):pe(r));return m=a,i}function ce(r){var a=m;m=e.getFunctionFlags(r);var i=t.updateFunctionDeclaration(r,void 0,1&m?e.visitNodes(r.modifiers,N,e.isModifier):r.modifiers,2&m?void 0:r.asteriskToken,r.name,void 0,e.visitParameterList(r.parameters,C,n),void 0,2&m&&1&m?de(r):pe(r));return m=a,i}function le(r){var a=m;m=e.getFunctionFlags(r);var i=t.updateArrowFunction(r,r.modifiers,void 0,e.visitParameterList(r.parameters,C,n),void 0,r.equalsGreaterThanToken,pe(r));return m=a,i}function ue(r){var a=m;m=e.getFunctionFlags(r);var i=t.updateFunctionExpression(r,1&m?e.visitNodes(r.modifiers,N,e.isModifier):r.modifiers,2&m?void 0:r.asteriskToken,r.name,void 0,e.visitParameterList(r.parameters,C,n),void 0,2&m&&1&m?de(r):pe(r));return m=a,i}function de(i){a();var s=[],l=t.copyPrologue(i.body.statements,s,!1,C);fe(s,i);var d=y,p=h;y=new e.Set,h=!1;var f=t.createReturnStatement(r().createAsyncGeneratorHelper(t.createFunctionExpression(void 0,t.createToken(41),i.name&&t.getGeneratedNameForNode(i.name),void 0,[],void 0,t.updateBlock(i.body,e.visitLexicalEnvironment(i.body.statements,C,n,l))),!!(1&E))),m=u>=2&&6144&c.getNodeCheckFlags(i);if(m){me();var _=e.createSuperAccessVariableStatement(t,c,i,y);T[e.getNodeId(_)]=!0,e.insertStatementsAfterStandardPrologue(s,[_])}s.push(f),e.insertStatementsAfterStandardPrologue(s,o());var g=t.updateBlock(i.body,s);return m&&h&&(4096&c.getNodeCheckFlags(i)?e.addEmitHelper(g,e.advancedAsyncSuperHelper):2048&c.getNodeCheckFlags(i)&&e.addEmitHelper(g,e.asyncSuperHelper)),y=d,h=p,g}function pe(n){var r;a();var i=0,s=[],c=null!==(r=e.visitNode(n.body,C,e.isConciseBody))&&void 0!==r?r:t.createBlock([]);e.isBlock(c)&&(i=t.copyPrologue(c.statements,s,!1,C)),e.addRange(s,fe(void 0,n));var l=o();if(i>0||e.some(s)||e.some(l)){var u=t.converters.convertToFunctionBlock(c,!0);return e.insertStatementsAfterStandardPrologue(s,l),e.addRange(s,u.statements.slice(i)),t.updateBlock(u,e.setTextRange(t.createNodeArray(s),u.statements))}return c}function fe(r,a){for(var i=0,o=a.parameters;i<o.length;i++){var s=o[i];if(32768&s.transformFlags){var c=t.getGeneratedNameForNode(s),l=e.flattenDestructuringBinding(s,C,n,1,c,!1,!0);if(e.some(l)){var u=t.createVariableStatement(void 0,t.createVariableDeclarationList(l));e.setEmitFlags(u,1048576),r=e.append(r,u)}}}return r}function me(){0===(1&f)&&(f|=1,n.enableSubstitution(204),n.enableSubstitution(202),n.enableSubstitution(203),n.enableEmitNotification(253),n.enableEmitNotification(166),n.enableEmitNotification(168),n.enableEmitNotification(169),n.enableEmitNotification(167),n.enableEmitNotification(233))}function _e(n,t,r){if(1&f&&Ee(t)){var a=6144&c.getNodeCheckFlags(t);if(a!==b){var i=b;return b=a,d(n,t,r),void(b=i)}}else if(f&&T[e.getNodeId(t)]){i=b;return b=0,d(n,t,r),void(b=i)}d(n,t,r)}function ge(e,n){return n=p(e,n),1===e&&b?ye(n):n}function ye(e){switch(e.kind){case 202:return he(e);case 203:return ve(e);case 204:return be(e)}return e}function he(n){return 105===n.expression.kind?e.setTextRange(t.createPropertyAccessExpression(t.createUniqueName("_super",48),n.name),n):n}function ve(e){return 105===e.expression.kind?Te(e.argumentExpression,e):e}function be(n){var r=n.expression;if(e.isSuperProperty(r)){var a=e.isPropertyAccessExpression(r)?he(r):ve(r);return t.createCallExpression(t.createPropertyAccessExpression(a,"call"),void 0,i([t.createThis()],n.arguments))}return n}function Ee(e){var n=e.kind;return 253===n||167===n||166===n||168===n||169===n}function Te(n,r){return 4096&b?e.setTextRange(t.createPropertyAccessExpression(t.createCallExpression(t.createIdentifier("_superIndex"),void 0,[n]),"value"),r):e.setTextRange(t.createCallExpression(t.createIdentifier("_superIndex"),void 0,[n]),r)}}(function(e){e[e["AsyncMethodsWithSuper"]=1]="AsyncMethodsWithSuper"})(n||(n={})),function(e){e[e["None"]=0]="None",e[e["HasLexicalThis"]=1]="HasLexicalThis",e[e["IterationContainer"]=2]="IterationContainer",e[e["AncestorFactsMask"]=3]="AncestorFactsMask",e[e["SourceFileIncludes"]=1]="SourceFileIncludes",e[e["SourceFileExcludes"]=2]="SourceFileExcludes",e[e["StrictModeSourceFileIncludes"]=0]="StrictModeSourceFileIncludes",e[e["ClassOrFunctionIncludes"]=1]="ClassOrFunctionIncludes",e[e["ClassOrFunctionExcludes"]=2]="ClassOrFunctionExcludes",e[e["ArrowFunctionIncludes"]=0]="ArrowFunctionIncludes",e[e["ArrowFunctionExcludes"]=2]="ArrowFunctionExcludes",e[e["IterationStatementIncludes"]=2]="IterationStatementIncludes",e[e["IterationStatementExcludes"]=0]="IterationStatementExcludes"}(t||(t={})),e.transformES2018=r}(d||(d={})),function(e){function n(n){var t=n.factory;return e.chainBundle(n,r);function r(t){return t.isDeclarationFile?t:e.visitEachChild(t,a,n)}function a(t){if(0===(32&t.transformFlags))return t;switch(t.kind){case 288:return i(t);default:return e.visitEachChild(t,a,n)}}function i(r){return r.variableDeclaration?e.visitEachChild(r,a,n):t.updateCatchClause(r,t.createVariableDeclaration(t.createTempVariable(void 0)),e.visitNode(r.block,a,e.isBlock))}}e.transformES2019=n}(d||(d={})),function(e){function n(n){var t=n.factory,r=n.hoistVariableDeclaration;return e.chainBundle(n,a);function a(t){return t.isDeclarationFile?t:e.visitEachChild(t,i,n)}function i(t){if(0===(16&t.transformFlags))return t;switch(t.kind){case 204:var r=l(t,!1);return e.Debug.assertNotNode(r,e.isSyntheticReference),r;case 202:case 203:if(e.isOptionalChain(t)){r=d(t,!1,!1);return e.Debug.assertNotNode(r,e.isSyntheticReference),r}return e.visitEachChild(t,i,n);case 217:return 60===t.operatorToken.kind?f(t):e.visitEachChild(t,i,n);case 211:return m(t);default:return e.visitEachChild(t,i,n)}}function o(n){e.Debug.assertNotNode(n,e.isNonNullChain);var t=[n];while(!n.questionDotToken&&!e.isTaggedTemplateExpression(n))n=e.cast(e.skipPartiallyEmittedExpressions(n.expression),e.isOptionalChain),e.Debug.assertNotNode(n,e.isNonNullChain),t.unshift(n);return{expression:n.expression,chain:t}}function s(n,r,a){var i=u(n.expression,r,a);return e.isSyntheticReference(i)?t.createSyntheticReferenceExpression(t.updateParenthesizedExpression(n,i.expression),i.thisArg):t.updateParenthesizedExpression(n,i)}function c(n,a,o){if(e.isOptionalChain(n))return d(n,a,o);var s,c=e.visitNode(n.expression,i,e.isExpression);return e.Debug.assertNotNode(c,e.isSyntheticReference),a&&(e.isSimpleCopiableExpression(c)?s=c:(s=t.createTempVariable(r),c=t.createAssignment(s,c))),c=202===n.kind?t.updatePropertyAccessExpression(n,c,e.visitNode(n.name,i,e.isIdentifier)):t.updateElementAccessExpression(n,c,e.visitNode(n.argumentExpression,i,e.isExpression)),s?t.createSyntheticReferenceExpression(c,s):c}function l(r,a){if(e.isOptionalChain(r))return d(r,a,!1);if(e.isParenthesizedExpression(r.expression)&&e.isOptionalChain(e.skipParentheses(r.expression))){var o=s(r.expression,!0,!1),c=e.visitNodes(r.arguments,i,e.isExpression);return e.isSyntheticReference(o)?e.setTextRange(t.createFunctionCallCall(o.expression,o.thisArg,c),r):t.updateCallExpression(r,o,void 0,c)}return e.visitEachChild(r,i,n)}function u(n,t,r){switch(n.kind){case 208:return s(n,t,r);case 202:case 203:return c(n,t,r);case 204:return l(n,t);default:return e.visitNode(n,i,e.isExpression)}}function d(n,a,s){var c=o(n),l=c.expression,d=c.chain,f=u(l,e.isCallChain(d[0]),!1),m=e.isSyntheticReference(f)?f.thisArg:void 0,_=e.isSyntheticReference(f)?f.expression:f,g=_;e.isSimpleCopiableExpression(_)||(g=t.createTempVariable(r),_=t.createAssignment(g,_));for(var y,h=g,v=0;v<d.length;v++){var b=d[v];switch(b.kind){case 202:case 203:v===d.length-1&&a&&(e.isSimpleCopiableExpression(h)?y=h:(y=t.createTempVariable(r),h=t.createAssignment(y,h))),h=202===b.kind?t.createPropertyAccessExpression(h,e.visitNode(b.name,i,e.isIdentifier)):t.createElementAccessExpression(h,e.visitNode(b.argumentExpression,i,e.isExpression));break;case 204:h=0===v&&m?t.createFunctionCallCall(h,105===m.kind?t.createThis():m,e.visitNodes(b.arguments,i,e.isExpression)):t.createCallExpression(h,void 0,e.visitNodes(b.arguments,i,e.isExpression));break}e.setOriginalNode(h,b)}var E=s?t.createConditionalExpression(p(_,g,!0),void 0,t.createTrue(),void 0,t.createDeleteExpression(h)):t.createConditionalExpression(p(_,g,!0),void 0,t.createVoidZero(),void 0,h);return e.setTextRange(E,n),y?t.createSyntheticReferenceExpression(E,y):E}function p(e,n,r){return t.createBinaryExpression(t.createBinaryExpression(e,t.createToken(r?36:37),t.createNull()),t.createToken(r?56:55),t.createBinaryExpression(n,t.createToken(r?36:37),t.createVoidZero()))}function f(n){var a=e.visitNode(n.left,i,e.isExpression),o=a;return e.isSimpleCopiableExpression(a)||(o=t.createTempVariable(r),a=t.createAssignment(o,a)),e.setTextRange(t.createConditionalExpression(p(a,o),void 0,o,void 0,e.visitNode(n.right,i,e.isExpression)),n)}function m(n){return e.isOptionalChain(e.skipParentheses(n.expression))?e.setOriginalNode(u(n.expression,!1,!0),n):t.updateDeleteExpression(n,e.visitNode(n.expression,i,e.isExpression))}}e.transformES2020=n}(d||(d={})),function(e){function n(n){var t=n.hoistVariableDeclaration,r=n.factory;return e.chainBundle(n,a);function a(t){return t.isDeclarationFile?t:e.visitEachChild(t,i,n)}function i(t){if(0===(8&t.transformFlags))return t;switch(t.kind){case 217:var r=t;if(e.isLogicalOrCoalescingAssignmentExpression(r))return o(r);default:return e.visitEachChild(t,i,n)}}function o(n){var a=n.operatorToken,o=e.getNonAssignmentOperatorForCompoundAssignment(a.kind),s=e.skipParentheses(e.visitNode(n.left,i,e.isLeftHandSideExpression)),c=s,l=e.skipParentheses(e.visitNode(n.right,i,e.isExpression));if(e.isAccessExpression(s)){var u=e.isSimpleCopiableExpression(s.expression),d=u?s.expression:r.createTempVariable(t),p=u?s.expression:r.createAssignment(d,s.expression);if(e.isPropertyAccessExpression(s))c=r.createPropertyAccessExpression(d,s.name),s=r.createPropertyAccessExpression(p,s.name);else{var f=e.isSimpleCopiableExpression(s.argumentExpression),m=f?s.argumentExpression:r.createTempVariable(t);c=r.createElementAccessExpression(d,m),s=r.createElementAccessExpression(p,f?s.argumentExpression:r.createAssignment(m,s.argumentExpression))}}return r.createBinaryExpression(s,o,r.createParenthesizedExpression(r.createAssignment(c,l)))}}e.transformES2021=n}(d||(d={})),function(e){function n(n){return e.chainBundle(n,t);function t(t){return t.isDeclarationFile?t:e.visitEachChild(t,r,n)}function r(t){if(0===(4&t.transformFlags))return t;switch(t.kind){default:return e.visitEachChild(t,r,n)}}}e.transformESNext=n}(d||(d={})),function(e){function n(n){var r,a,i=n.factory,o=n.getEmitHelperFactory,s=n.getCompilerOptions();return e.chainBundle(n,f);function c(){if(a.filenameDeclaration)return a.filenameDeclaration.name;var e=i.createVariableDeclaration(i.createUniqueName("_jsxFileName",48),void 0,void 0,i.createStringLiteral(r.fileName));return a.filenameDeclaration=e,a.filenameDeclaration.name}function l(e){return 5===s.jsx?"jsxDEV":e>1?"jsxs":"jsx"}function u(e){var n=l(e);return p(n)}function d(){return p("Fragment")}function p(n){var t,r,o="createElement"===n?a.importSpecifier:e.getJSXRuntimeImport(a.importSpecifier,s),c=null===(r=null===(t=a.utilizedImplicitRuntimeImports)||void 0===t?void 0:t.get(o))||void 0===r?void 0:r.get(n);if(c)return c.name;a.utilizedImplicitRuntimeImports||(a.utilizedImplicitRuntimeImports=e.createMap());var l=a.utilizedImplicitRuntimeImports.get(o);l||(l=e.createMap(),a.utilizedImplicitRuntimeImports.set(o,l));var u=i.createUniqueName("_"+n,112),d=i.createImportSpecifier(i.createIdentifier(n),u);return u.generatedImportReference=d,l.set(n,d),u}function f(t){if(t.isDeclarationFile)return t;r=t,a={},a.importSpecifier=e.getJSXImplicitImportBase(s,t);var o=e.visitEachChild(t,m,n);e.addEmitHelpers(o,n.readEmitHelpers());var c=o.statements;if(a.filenameDeclaration&&(c=e.insertStatementAfterCustomPrologue(c.slice(),i.createVariableStatement(void 0,i.createVariableDeclarationList([a.filenameDeclaration],2)))),a.utilizedImplicitRuntimeImports)for(var l=0,u=e.arrayFrom(a.utilizedImplicitRuntimeImports.entries());l<u.length;l++){var d=u[l],p=d[0],f=d[1];if(e.isExternalModule(t)){var _=i.createImportDeclaration(void 0,void 0,i.createImportClause(!1,void 0,i.createNamedImports(e.arrayFrom(f.values()))),i.createStringLiteral(p));e.setParentRecursive(_,!1),c=e.insertStatementAfterCustomPrologue(c.slice(),_)}else if(e.isExternalOrCommonJsModule(t)){var g=i.createVariableStatement(void 0,i.createVariableDeclarationList([i.createVariableDeclaration(i.createObjectBindingPattern(e.map(e.arrayFrom(f.values()),(function(e){return i.createBindingElement(void 0,e.propertyName,e.name)}))),void 0,void 0,i.createCallExpression(i.createIdentifier("require"),void 0,[i.createStringLiteral(p)]))],2));e.setParentRecursive(g,!1),c=e.insertStatementAfterCustomPrologue(c.slice(),g)}}return c!==o.statements&&(o=i.updateSourceFile(o,c)),a=void 0,o}function m(e){return 2&e.transformFlags?_(e):e}function _(t){switch(t.kind){case 274:return v(t,!1);case 275:return b(t,!1);case 278:return E(t,!1);case 284:return B(t);default:return e.visitEachChild(t,m,n)}}function g(n){switch(n.kind){case 11:return R(n);case 284:return B(n);case 274:return v(n,!0);case 275:return b(n,!0);case 278:return E(n,!0);default:return e.Debug.failBadSyntaxKind(n)}}function y(n){for(var t=!1,r=0,a=n.attributes.properties;r<a.length;r++){var i=a[r];if(e.isJsxSpreadAttribute(i))t=!0;else if(t&&e.isJsxAttribute(i)&&"key"===i.name.escapedText)return!0}return!1}function h(e){return void 0===a.importSpecifier||y(e)}function v(e,n){var t=h(e.openingElement)?L:S;return t(e.openingElement,e.children,n,e)}function b(e,n){var t=h(e)?L:S;return t(e,void 0,n,e)}function E(e,n){var t=void 0===a.importSpecifier?A:D;return t(e.openingFragment,e.children,n,e)}function T(n){var t=e.getSemanticJsxChildren(n);if(1===e.length(t)){var r=g(t[0]);return r&&i.createObjectLiteralExpression([i.createPropertyAssignment("children",r)])}var a=e.mapDefined(n,g);return a.length?i.createObjectLiteralExpression([i.createPropertyAssignment("children",i.createArrayLiteralExpression(a))]):void 0}function S(n,t,r,a){var s,c=F(n),l=e.find(n.attributes.properties,(function(n){return!!n.name&&e.isIdentifier(n.name)&&"key"===n.name.escapedText})),u=l?e.filter(n.attributes.properties,(function(e){return e!==l})):n.attributes.properties,d=[];if(u.length&&(d=e.flatten(e.spanMap(u,e.isJsxSpreadAttribute,(function(n,t){return t?e.map(n,I):i.createObjectLiteralExpression(e.map(n,N))}))),e.isJsxSpreadAttribute(u[0])&&d.unshift(i.createObjectLiteralExpression())),t&&t.length){var p=T(t);p&&d.push(p)}return s=0===d.length?i.createObjectLiteralExpression([]):e.singleOrUndefined(d)||o().createAssignHelper(d),x(c,s,l,e.length(e.getSemanticJsxChildren(t||e.emptyArray)),r,a)}function x(n,t,a,o,l,d){var p=[n,t,a?k(a.initializer):i.createVoidZero()];if(5===s.jsx){var f=e.getOriginalNode(r);if(f&&e.isSourceFile(f)){p.push(o>1?i.createTrue():i.createFalse());var m=e.getLineAndCharacterOfPosition(f,d.pos);p.push(i.createObjectLiteralExpression([i.createPropertyAssignment("fileName",c()),i.createPropertyAssignment("lineNumber",i.createNumericLiteral(m.line+1)),i.createPropertyAssignment("columnNumber",i.createNumericLiteral(m.character+1))])),p.push(i.createThis())}}var _=e.setTextRange(i.createCallExpression(u(o),void 0,p),d);return l&&e.startOnNewLine(_),_}function L(t,c,l,u){var d,f=F(t),m=t.attributes.properties;if(0===m.length)d=i.createNull();else{var _=s.target;if(_&&_>=5)d=i.createObjectLiteralExpression(e.flatten(e.spanMap(m,e.isJsxSpreadAttribute,(function(n,t){return t?e.map(n,C):e.map(n,N)}))));else{var y=e.flatten(e.spanMap(m,e.isJsxSpreadAttribute,(function(n,t){return t?e.map(n,I):i.createObjectLiteralExpression(e.map(n,N))})));e.isJsxSpreadAttribute(m[0])&&y.unshift(i.createObjectLiteralExpression()),d=e.singleOrUndefined(y),d||(d=o().createAssignHelper(y))}}var h=void 0===a.importSpecifier?e.createJsxFactoryExpression(i,n.getEmitResolver().getJsxFactoryEntity(r),s.reactNamespace,t):p("createElement"),v=e.createExpressionForJsxElement(i,h,f,d,e.mapDefined(c,g),u);return l&&e.startOnNewLine(v),v}function D(n,t,r,a){var o;if(t&&t.length){var s=T(t);s&&(o=s)}return x(d(),o||i.createObjectLiteralExpression([]),void 0,e.length(e.getSemanticJsxChildren(t)),r,a)}function A(t,a,o,c){var l=e.createExpressionForJsxFragment(i,n.getEmitResolver().getJsxFactoryEntity(r),n.getEmitResolver().getJsxFragmentFactoryEntity(r),s.reactNamespace,e.mapDefined(a,g),t,c);return o&&e.startOnNewLine(l),l}function C(n){return i.createSpreadAssignment(e.visitNode(n.expression,m,e.isExpression))}function I(n){return e.visitNode(n.expression,m,e.isExpression)}function N(e){var n=G(e),t=k(e.initializer);return i.createPropertyAssignment(n,t)}function k(n){if(void 0===n)return i.createTrue();if(10===n.kind){var t=void 0!==n.singleQuote?n.singleQuote:!e.isStringDoubleQuoted(n,r),a=i.createStringLiteral(M(n.text)||n.text,t);return e.setTextRange(a,n)}return 284===n.kind?void 0===n.expression?i.createTrue():e.visitNode(n.expression,m,e.isExpression):e.Debug.failBadSyntaxKind(n)}function R(e){var n=O(e.text);return void 0===n?void 0:i.createStringLiteral(n)}function O(n){for(var t,r=0,a=-1,i=0;i<n.length;i++){var o=n.charCodeAt(i);e.isLineBreak(o)?(-1!==r&&-1!==a&&(t=w(t,n.substr(r,a-r+1))),r=-1):e.isWhiteSpaceSingleLine(o)||(a=i,-1===r&&(r=i))}return-1!==r?w(t,n.substr(r)):t}function w(e,n){var t=P(n);return void 0===e?t:e+" "+t}function P(n){return n.replace(/&((#((\d+)|x([\da-fA-F]+)))|(\w+));/g,(function(n,r,a,i,o,s,c){if(o)return e.utf16EncodeAsString(parseInt(o,10));if(s)return e.utf16EncodeAsString(parseInt(s,16));var l=t.get(c);return l?e.utf16EncodeAsString(l):n}))}function M(e){var n=P(e);return n===e?void 0:n}function F(n){if(274===n.kind)return F(n.openingElement);var t=n.tagName;return e.isIdentifier(t)&&e.isIntrinsicJsxName(t.escapedText)?i.createStringLiteral(e.idText(t)):e.createExpressionFromEntityName(i,t)}function G(n){var t=n.name,r=e.idText(t);return/^[A-Za-z_]\w*$/.test(r)?t:i.createStringLiteral(r)}function B(n){return e.visitNode(n.expression,m,e.isExpression)}}e.transformJsx=n;var t=new e.Map(e.getEntries({quot:34,amp:38,apos:39,lt:60,gt:62,nbsp:160,iexcl:161,cent:162,pound:163,curren:164,yen:165,brvbar:166,sect:167,uml:168,copy:169,ordf:170,laquo:171,not:172,shy:173,reg:174,macr:175,deg:176,plusmn:177,sup2:178,sup3:179,acute:180,micro:181,para:182,middot:183,cedil:184,sup1:185,ordm:186,raquo:187,frac14:188,frac12:189,frac34:190,iquest:191,Agrave:192,Aacute:193,Acirc:194,Atilde:195,Auml:196,Aring:197,AElig:198,Ccedil:199,Egrave:200,Eacute:201,Ecirc:202,Euml:203,Igrave:204,Iacute:205,Icirc:206,Iuml:207,ETH:208,Ntilde:209,Ograve:210,Oacute:211,Ocirc:212,Otilde:213,Ouml:214,times:215,Oslash:216,Ugrave:217,Uacute:218,Ucirc:219,Uuml:220,Yacute:221,THORN:222,szlig:223,agrave:224,aacute:225,acirc:226,atilde:227,auml:228,aring:229,aelig:230,ccedil:231,egrave:232,eacute:233,ecirc:234,euml:235,igrave:236,iacute:237,icirc:238,iuml:239,eth:240,ntilde:241,ograve:242,oacute:243,ocirc:244,otilde:245,ouml:246,divide:247,oslash:248,ugrave:249,uacute:250,ucirc:251,uuml:252,yacute:253,thorn:254,yuml:255,OElig:338,oelig:339,Scaron:352,scaron:353,Yuml:376,fnof:402,circ:710,tilde:732,Alpha:913,Beta:914,Gamma:915,Delta:916,Epsilon:917,Zeta:918,Eta:919,Theta:920,Iota:921,Kappa:922,Lambda:923,Mu:924,Nu:925,Xi:926,Omicron:927,Pi:928,Rho:929,Sigma:931,Tau:932,Upsilon:933,Phi:934,Chi:935,Psi:936,Omega:937,alpha:945,beta:946,gamma:947,delta:948,epsilon:949,zeta:950,eta:951,theta:952,iota:953,kappa:954,lambda:955,mu:956,nu:957,xi:958,omicron:959,pi:960,rho:961,sigmaf:962,sigma:963,tau:964,upsilon:965,phi:966,chi:967,psi:968,omega:969,thetasym:977,upsih:978,piv:982,ensp:8194,emsp:8195,thinsp:8201,zwnj:8204,zwj:8205,lrm:8206,rlm:8207,ndash:8211,mdash:8212,lsquo:8216,rsquo:8217,sbquo:8218,ldquo:8220,rdquo:8221,bdquo:8222,dagger:8224,Dagger:8225,bull:8226,hellip:8230,permil:8240,prime:8242,Prime:8243,lsaquo:8249,rsaquo:8250,oline:8254,frasl:8260,euro:8364,image:8465,weierp:8472,real:8476,trade:8482,alefsym:8501,larr:8592,uarr:8593,rarr:8594,darr:8595,harr:8596,crarr:8629,lArr:8656,uArr:8657,rArr:8658,dArr:8659,hArr:8660,forall:8704,part:8706,exist:8707,empty:8709,nabla:8711,isin:8712,notin:8713,ni:8715,prod:8719,sum:8721,minus:8722,lowast:8727,radic:8730,prop:8733,infin:8734,ang:8736,and:8743,or:8744,cap:8745,cup:8746,int:8747,there4:8756,sim:8764,cong:8773,asymp:8776,ne:8800,equiv:8801,le:8804,ge:8805,sub:8834,sup:8835,nsub:8836,sube:8838,supe:8839,oplus:8853,otimes:8855,perp:8869,sdot:8901,lceil:8968,rceil:8969,lfloor:8970,rfloor:8971,lang:9001,rang:9002,loz:9674,spades:9824,clubs:9827,hearts:9829,diams:9830}))}(d||(d={})),function(e){function n(n){var t=n.factory,r=n.hoistVariableDeclaration;return e.chainBundle(n,a);function a(t){return t.isDeclarationFile?t:e.visitEachChild(t,i,n)}function i(t){if(0===(256&t.transformFlags))return t;switch(t.kind){case 217:return o(t);default:return e.visitEachChild(t,i,n)}}function o(t){switch(t.operatorToken.kind){case 66:return s(t);case 42:return c(t);default:return e.visitEachChild(t,i,n)}}function s(n){var a,o,s=e.visitNode(n.left,i,e.isExpression),c=e.visitNode(n.right,i,e.isExpression);if(e.isElementAccessExpression(s)){var l=t.createTempVariable(r),u=t.createTempVariable(r);a=e.setTextRange(t.createElementAccessExpression(e.setTextRange(t.createAssignment(l,s.expression),s.expression),e.setTextRange(t.createAssignment(u,s.argumentExpression),s.argumentExpression)),s),o=e.setTextRange(t.createElementAccessExpression(l,u),s)}else if(e.isPropertyAccessExpression(s)){l=t.createTempVariable(r);a=e.setTextRange(t.createPropertyAccessExpression(e.setTextRange(t.createAssignment(l,s.expression),s.expression),s.name),s),o=e.setTextRange(t.createPropertyAccessExpression(l,s.name),s)}else a=s,o=s;return e.setTextRange(t.createAssignment(a,e.setTextRange(t.createGlobalMethodCall("Math","pow",[o,c]),n)),n)}function c(n){var r=e.visitNode(n.left,i,e.isExpression),a=e.visitNode(n.right,i,e.isExpression);return e.setTextRange(t.createGlobalMethodCall("Math","pow",[r,a]),n)}}e.transformES2016=n}(d||(d={})),function(e){var n,t,r,a,o;function s(n){var t,r,a,o,s,c,l=n.factory,u=n.getEmitHelperFactory,d=n.startLexicalEnvironment,p=n.resumeLexicalEnvironment,f=n.endLexicalEnvironment,m=n.hoistVariableDeclaration,_=n.getCompilerOptions(),g=n.getEmitResolver(),y=n.onSubstituteNode,h=n.onEmitNode;function v(n){o=e.append(o,l.createVariableDeclaration(n))}return n.onEmitNode=Yn,n.onSubstituteNode=$n,e.chainBundle(n,b);function b(i){if(i.isDeclarationFile)return i;t=i,r=i.text;var s=N(i);return e.addEmitHelpers(s,n.readEmitHelpers()),t=void 0,r=void 0,o=void 0,a=0,s}function E(e,n){var t=a;return a=16383&(a&~e|n),t}function T(e,n,t){a=-16384&(a&~n|t)|e}function S(e){return 0!==(8192&a)&&243===e.kind&&!e.expression}function x(n){return 2097152&n.transformFlags&&(e.isReturnStatement(n)||e.isIfStatement(n)||e.isWithStatement(n)||e.isSwitchStatement(n)||e.isCaseBlock(n)||e.isCaseClause(n)||e.isDefaultClause(n)||e.isTryStatement(n)||e.isCatchClause(n)||e.isLabeledStatement(n)||e.isIterationStatement(n,!1)||e.isBlock(n))}function L(n){return 0!==(512&n.transformFlags)||void 0!==s||8192&a&&x(n)||e.isIterationStatement(n,!1)&&Je(n)||0!==(33554432&e.getEmitFlags(n))}function D(e){return L(e)?I(e,!1):e}function A(e){return L(e)?I(e,!0):e}function C(e){return 105===e.kind?Jn(!0):D(e)}function I(t,r){switch(t.kind){case 123:return;case 253:return B(t);case 222:return U(t);case 161:return Q(t);case 252:return me(t);case 210:return pe(t);case 209:return fe(t);case 250:return Ce(t);case 78:return F(t);case 251:return xe(t);case 245:return k(t);case 259:return R(t);case 231:return ye(t,!1);case 242:case 241:return G(t);case 246:return ke(t);case 236:case 237:return we(t,void 0);case 238:return Pe(t,void 0);case 239:return Fe(t,void 0);case 240:return Ge(t,void 0);case 234:return he(t);case 201:return Ke(t);case 288:return En(t);case 290:return Ln(t);case 159:return Dn(t);case 200:return Cn(t);case 204:return In(t);case 205:return On(t);case 208:return ve(t,r);case 217:return be(t,r);case 341:return Ee(t,r);case 14:case 15:case 16:case 17:return Un(t);case 10:return Vn(t);case 8:return jn(t);case 206:return Kn(t);case 219:return Hn(t);case 220:return An(t);case 221:return Gn(t);case 105:return Jn(!1);case 107:return P(t);case 227:return Xn(t);case 166:return Sn(t);case 168:case 169:return xn(t);case 233:return Se(t);case 243:return w(t);case 213:return M(t);default:return e.visitEachChild(t,D,n)}}function N(n){var t=E(8064,64),r=[],a=[];d();var i=l.copyPrologue(n.statements,r,!1,D);return e.addRange(a,e.visitNodes(n.statements,D,e.isStatement,i)),o&&a.push(l.createVariableStatement(void 0,l.createVariableDeclarationList(o))),l.mergeLexicalEnvironment(r,f()),ae(r,n),T(t,0,0),l.updateSourceFile(n,e.setTextRange(l.createNodeArray(e.concatenate(r,a)),n.statements))}function k(t){if(void 0!==s){var r=s.allowedNonLabeledJumps;s.allowedNonLabeledJumps|=2;var a=e.visitEachChild(t,D,n);return s.allowedNonLabeledJumps=r,a}return e.visitEachChild(t,D,n)}function R(t){var r=E(7104,0),a=e.visitEachChild(t,D,n);return T(r,0,0),a}function O(n){return e.setOriginalNode(l.createReturnStatement(l.createUniqueName("_this",48)),n)}function w(t){return s?(s.nonLocalJumps|=8,S(t)&&(t=O(t)),l.createReturnStatement(l.createObjectLiteralExpression([l.createPropertyAssignment(l.createIdentifier("value"),t.expression?e.visitNode(t.expression,D,e.isExpression):l.createVoidZero())]))):S(t)?O(t):e.visitEachChild(t,D,n)}function P(e){return 2&a&&(a|=32768),s?2&a?(s.containsLexicalThis=!0,e):s.thisName||(s.thisName=l.createUniqueName("this")):e}function M(t){return e.visitEachChild(t,A,n)}function F(e){return s&&g.isArgumentsLocalBinding(e)?s.argumentsName||(s.argumentsName=l.createUniqueName("arguments")):e}function G(t){if(s){var r=242===t.kind?2:4,a=t.label&&s.labels&&s.labels.get(e.idText(t.label))||!t.label&&s.allowedNonLabeledJumps&r;if(!a){var i=void 0,o=t.label;o?242===t.kind?(i="break-"+o.escapedText,mn(s,!0,e.idText(o),i)):(i="continue-"+o.escapedText,mn(s,!1,e.idText(o),i)):242===t.kind?(s.nonLocalJumps|=2,i="break"):(s.nonLocalJumps|=4,i="continue");var c=l.createStringLiteral(i);if(s.loopOutParameters.length){for(var u=s.loopOutParameters,d=void 0,p=0;p<u.length;p++){var f=un(u[p],1);d=0===p?f:l.createBinaryExpression(d,27,f)}c=l.createBinaryExpression(d,27,c)}return l.createReturnStatement(c)}}return e.visitEachChild(t,D,n)}function B(n){var t=l.createVariableDeclaration(l.getLocalName(n,!0),void 0,void 0,V(n));e.setOriginalNode(t,n);var r=[],a=l.createVariableStatement(void 0,l.createVariableDeclarationList([t]));if(e.setOriginalNode(a,n),e.setTextRange(a,n),e.startOnNewLine(a),r.push(a),e.hasSyntacticModifier(n,1)){var i=e.hasSyntacticModifier(n,512)?l.createExportDefault(l.getLocalName(n)):l.createExternalModuleExport(l.getLocalName(n));e.setOriginalNode(i,a),r.push(i)}var o=e.getEmitFlags(n);return 0===(4194304&o)&&(r.push(l.createEndOfDeclarationMarker(n)),e.setEmitFlags(a,4194304|o)),e.singleOrMany(r)}function U(e){return V(e)}function V(n){n.name&&Qn();var t=e.getClassExtendsHeritageElement(n),a=l.createFunctionExpression(void 0,void 0,void 0,void 0,t?[l.createParameterDeclaration(void 0,void 0,void 0,l.createUniqueName("_super",48))]:[],void 0,j(n,t));e.setEmitFlags(a,65536&e.getEmitFlags(n)|524288);var i=l.createPartiallyEmittedExpression(a);e.setTextRangeEnd(i,n.end),e.setEmitFlags(i,1536);var o=l.createPartiallyEmittedExpression(i);e.setTextRangeEnd(o,e.skipTrivia(r,n.pos)),e.setEmitFlags(o,1536);var s=l.createParenthesizedExpression(l.createCallExpression(o,void 0,t?[e.visitNode(t.expression,D,e.isExpression)]:[]));return e.addSyntheticLeadingComment(s,3,"* @class "),s}function j(n,t){var a=[],i=l.getInternalName(n),o=e.isIdentifierANonContextualKeyword(i)?l.getGeneratedNameForNode(i):i;d(),K(a,n,t),H(a,n,o,t),se(a,n);var s=e.createTokenRange(e.skipTrivia(r,n.members.end),19),c=l.createPartiallyEmittedExpression(o);e.setTextRangeEnd(c,s.end),e.setEmitFlags(c,1536);var u=l.createReturnStatement(c);e.setTextRangePos(u,s.pos),e.setEmitFlags(u,1920),a.push(u),e.insertStatementsAfterStandardPrologue(a,f());var p=l.createBlock(e.setTextRange(l.createNodeArray(a),n.members),!0);return e.setEmitFlags(p,1536),p}function K(n,t,r){r&&n.push(e.setTextRange(l.createExpressionStatement(u().createExtendsHelper(l.getInternalName(t))),r))}function H(n,t,r,a){var i=s;s=void 0;var o=E(16278,73),c=e.getFirstConstructorWithBody(t),u=st(c,void 0!==a),d=l.createFunctionDeclaration(void 0,void 0,void 0,r,void 0,W(c,u),void 0,q(c,t,a,u));e.setTextRange(d,c||t),a&&e.setEmitFlags(d,8),n.push(d),T(o,49152,0),s=i}function W(t,r){return e.visitParameterList(t&&!r?t.parameters:void 0,D,n)||[]}function z(n,t){var r=[];p(),l.mergeLexicalEnvironment(r,f()),t&&r.push(l.createReturnStatement(Y()));var a=l.createNodeArray(r);e.setTextRange(a,n.members);var i=l.createBlock(a,!0);return e.setTextRange(i,n),e.setEmitFlags(i,1536),i}function q(n,t,r,i){var o=!!r&&103!==e.skipOuterExpressions(r.expression).kind;if(!n)return z(t,o);var s=[],c=[];p();var u,d=0;if(i||(d=l.copyStandardPrologue(n.body.statements,s,!1)),$(c,n),re(c,n,i),i||(d=l.copyCustomPrologue(n.body.statements,c,d,D)),i)u=Y();else if(o&&d<n.body.statements.length){var m=n.body.statements[d];e.isExpressionStatement(m)&&e.isSuperCall(m.expression)&&(u=kn(m.expression))}if(u&&(a|=8192,d++),e.addRange(c,e.visitNodes(n.body.statements,D,e.isStatement,d)),l.mergeLexicalEnvironment(s,f()),oe(s,n,!1),o)if(!u||d!==n.body.statements.length||8192&n.body.transformFlags)ie(c,n,u||X()),J(n.body)||c.push(l.createReturnStatement(l.createUniqueName("_this",48)));else{var _=e.cast(e.cast(u,e.isBinaryExpression).left,e.isCallExpression),g=l.createReturnStatement(u);e.setCommentRange(g,e.getCommentRange(_)),e.setEmitFlags(_,1536),c.push(g)}else ae(s,n);var y=l.createBlock(e.setTextRange(l.createNodeArray(e.concatenate(s,c)),n.body.statements),!0);return e.setTextRange(y,n.body),y}function J(n){if(243===n.kind)return!0;if(235===n.kind){var t=n;if(t.elseStatement)return J(t.thenStatement)&&J(t.elseStatement)}else if(231===n.kind){var r=e.lastOrUndefined(n.statements);if(r&&J(r))return!0}return!1}function X(){return e.setEmitFlags(l.createThis(),4)}function Y(){return l.createLogicalOr(l.createLogicalAnd(l.createStrictInequality(l.createUniqueName("_super",48),l.createNull()),l.createFunctionApplyCall(l.createUniqueName("_super",48),X(),l.createIdentifier("arguments"))),X())}function Q(n){return n.dotDotDotToken?void 0:e.isBindingPattern(n.name)?e.setOriginalNode(e.setTextRange(l.createParameterDeclaration(void 0,void 0,void 0,l.getGeneratedNameForNode(n),void 0,void 0,void 0),n),n):n.initializer?e.setOriginalNode(e.setTextRange(l.createParameterDeclaration(void 0,void 0,void 0,n.name,void 0,void 0,void 0),n),n):n}function Z(n){return void 0!==n.initializer||e.isBindingPattern(n.name)}function $(n,t){if(!e.some(t.parameters,Z))return!1;for(var r=!1,a=0,i=t.parameters;a<i.length;a++){var o=i[a],s=o.name,c=o.initializer,l=o.dotDotDotToken;l||(e.isBindingPattern(s)?r=ee(n,o,s,c)||r:c&&(ne(n,o,s,c),r=!0))}return r}function ee(t,r,a,i){return a.elements.length>0?(e.insertStatementAfterCustomPrologue(t,e.setEmitFlags(l.createVariableStatement(void 0,l.createVariableDeclarationList(e.flattenDestructuringBinding(r,D,n,0,l.getGeneratedNameForNode(r)))),1048576)),!0):!!i&&(e.insertStatementAfterCustomPrologue(t,e.setEmitFlags(l.createExpressionStatement(l.createAssignment(l.getGeneratedNameForNode(r),e.visitNode(i,D,e.isExpression))),1048576)),!0)}function ne(n,t,r,a){a=e.visitNode(a,D,e.isExpression);var i=l.createIfStatement(l.createTypeCheck(l.cloneNode(r),"undefined"),e.setEmitFlags(e.setTextRange(l.createBlock([l.createExpressionStatement(e.setEmitFlags(e.setTextRange(l.createAssignment(e.setEmitFlags(e.setParent(e.setTextRange(l.cloneNode(r),r),r.parent),48),e.setEmitFlags(a,1584|e.getEmitFlags(a))),t),1536))]),t),1953));e.startOnNewLine(i),e.setTextRange(i,t),e.setEmitFlags(i,1050528),e.insertStatementAfterCustomPrologue(n,i)}function te(e,n){return!(!e||!e.dotDotDotToken||n)}function re(t,r,a){var i=[],o=e.lastOrUndefined(r.parameters);if(!te(o,a))return!1;var s=78===o.name.kind?e.setParent(e.setTextRange(l.cloneNode(o.name),o.name),o.name.parent):l.createTempVariable(void 0);e.setEmitFlags(s,48);var c=78===o.name.kind?l.cloneNode(o.name):s,u=r.parameters.length-1,d=l.createLoopVariable();i.push(e.setEmitFlags(e.setTextRange(l.createVariableStatement(void 0,l.createVariableDeclarationList([l.createVariableDeclaration(s,void 0,void 0,l.createArrayLiteralExpression([]))])),o),1048576));var p=l.createForStatement(e.setTextRange(l.createVariableDeclarationList([l.createVariableDeclaration(d,void 0,void 0,l.createNumericLiteral(u))]),o),e.setTextRange(l.createLessThan(d,l.createPropertyAccessExpression(l.createIdentifier("arguments"),"length")),o),e.setTextRange(l.createPostfixIncrement(d),o),l.createBlock([e.startOnNewLine(e.setTextRange(l.createExpressionStatement(l.createAssignment(l.createElementAccessExpression(c,0===u?d:l.createSubtract(d,l.createNumericLiteral(u))),l.createElementAccessExpression(l.createIdentifier("arguments"),d))),o))]));return e.setEmitFlags(p,1048576),e.startOnNewLine(p),i.push(p),78!==o.name.kind&&i.push(e.setEmitFlags(e.setTextRange(l.createVariableStatement(void 0,l.createVariableDeclarationList(e.flattenDestructuringBinding(o,D,n,0,c))),o),1048576)),e.insertStatementsAfterCustomPrologue(t,i),!0}function ae(e,n){return!!(32768&a&&210!==n.kind)&&(ie(e,n,l.createThis()),!0)}function ie(n,t,r){Zn();var a=l.createVariableStatement(void 0,l.createVariableDeclarationList([l.createVariableDeclaration(l.createUniqueName("_this",48),void 0,void 0,r)]));e.setEmitFlags(a,1050112),e.setSourceMapRange(a,t),e.insertStatementAfterCustomPrologue(n,a)}function oe(n,t,r){if(16384&a){var i=void 0;switch(t.kind){case 210:return n;case 166:case 168:case 169:i=l.createVoidZero();break;case 167:i=l.createPropertyAccessExpression(e.setEmitFlags(l.createThis(),4),"constructor");break;case 252:case 209:i=l.createConditionalExpression(l.createLogicalAnd(e.setEmitFlags(l.createThis(),4),l.createBinaryExpression(e.setEmitFlags(l.createThis(),4),101,l.getLocalName(t))),void 0,l.createPropertyAccessExpression(e.setEmitFlags(l.createThis(),4),"constructor"),void 0,l.createVoidZero());break;default:return e.Debug.failBadSyntaxKind(t)}var o=l.createVariableStatement(void 0,l.createVariableDeclarationList([l.createVariableDeclaration(l.createUniqueName("_newTarget",48),void 0,void 0,i)]));e.setEmitFlags(o,1050112),r&&(n=n.slice()),e.insertStatementAfterCustomPrologue(n,o)}return n}function se(n,r){for(var a=0,i=r.members;a<i.length;a++){var o=i[a];switch(o.kind){case 230:n.push(ce(o));break;case 166:n.push(le(ot(r,o),o,r));break;case 168:case 169:var s=e.getAllAccessorDeclarations(r.members,o);o===s.firstAccessor&&n.push(ue(ot(r,o),s,r));break;case 167:break;default:e.Debug.failBadSyntaxKind(o,t&&t.fileName);break}}}function ce(n){return e.setTextRange(l.createEmptyStatement(),n)}function le(t,r,a){var i,o=e.getCommentRange(r),s=e.getSourceMapRange(r),c=_e(r,r,void 0,a),u=e.visitNode(r.name,D,e.isPropertyName);if(!e.isPrivateIdentifier(u)&&e.getUseDefineForClassFields(n.getCompilerOptions())){var d=e.isComputedPropertyName(u)?u.expression:e.isIdentifier(u)?l.createStringLiteral(e.unescapeLeadingUnderscores(u.escapedText)):u;i=l.createObjectDefinePropertyCall(t,d,l.createPropertyDescriptor({value:c,enumerable:!1,writable:!0,configurable:!0}))}else{var p=e.createMemberAccessForPropertyName(l,t,u,r.name);i=l.createAssignment(p,c)}e.setEmitFlags(c,1536),e.setSourceMapRange(c,s);var f=e.setTextRange(l.createExpressionStatement(i),r);return e.setOriginalNode(f,r),e.setCommentRange(f,o),e.setEmitFlags(f,48),f}function ue(n,t,r){var a=l.createExpressionStatement(de(n,t,r,!1));return e.setEmitFlags(a,1536),e.setSourceMapRange(a,e.getSourceMapRange(t.firstAccessor)),a}function de(n,t,r,a){var i=t.firstAccessor,o=t.getAccessor,s=t.setAccessor,c=e.setParent(e.setTextRange(l.cloneNode(n),n),n.parent);e.setEmitFlags(c,1568),e.setSourceMapRange(c,i.name);var u=e.visitNode(i.name,D,e.isPropertyName);if(e.isPrivateIdentifier(u))return e.Debug.failBadSyntaxKind(u,"Encountered unhandled private identifier while transforming ES2015.");var d=e.createExpressionForPropertyName(l,u);e.setEmitFlags(d,1552),e.setSourceMapRange(d,i.name);var p=[];if(o){var f=_e(o,void 0,void 0,r);e.setSourceMapRange(f,e.getSourceMapRange(o)),e.setEmitFlags(f,512);var m=l.createPropertyAssignment("get",f);e.setCommentRange(m,e.getCommentRange(o)),p.push(m)}if(s){var _=_e(s,void 0,void 0,r);e.setSourceMapRange(_,e.getSourceMapRange(s)),e.setEmitFlags(_,512);var g=l.createPropertyAssignment("set",_);e.setCommentRange(g,e.getCommentRange(s)),p.push(g)}p.push(l.createPropertyAssignment("enumerable",o||s?l.createFalse():l.createTrue()),l.createPropertyAssignment("configurable",l.createTrue()));var y=l.createCallExpression(l.createPropertyAccessExpression(l.createIdentifier("Object"),"defineProperty"),void 0,[c,d,l.createObjectLiteralExpression(p,!0)]);return a&&e.startOnNewLine(y),y}function pe(t){8192&t.transformFlags&&(a|=32768);var r=s;s=void 0;var i=E(15232,66),o=l.createFunctionExpression(void 0,void 0,void 0,void 0,e.visitParameterList(t.parameters,D,n),void 0,ge(t));return e.setTextRange(o,t),e.setOriginalNode(o,t),e.setEmitFlags(o,8),32768&a&&Zn(),T(i,0,0),s=r,o}function fe(t){var r=262144&e.getEmitFlags(t)?E(16278,69):E(16286,65),i=s;s=void 0;var o=e.visitParameterList(t.parameters,D,n),c=ge(t),u=16384&a?l.getLocalName(t):t.name;return T(r,49152,0),s=i,l.updateFunctionExpression(t,void 0,t.asteriskToken,u,void 0,o,void 0,c)}function me(t){var r=s;s=void 0;var i=E(16286,65),o=e.visitParameterList(t.parameters,D,n),c=ge(t),u=16384&a?l.getLocalName(t):t.name;return T(i,49152,0),s=r,l.updateFunctionDeclaration(t,void 0,e.visitNodes(t.modifiers,D,e.isModifier),t.asteriskToken,u,void 0,o,void 0,c)}function _e(t,r,i,o){var c=s;s=void 0;var u=o&&e.isClassLike(o)&&!e.hasSyntacticModifier(t,32)?E(16286,73):E(16286,65),d=e.visitParameterList(t.parameters,D,n),p=ge(t);return 16384&a&&!i&&(252===t.kind||209===t.kind)&&(i=l.getGeneratedNameForNode(t)),T(u,49152,0),s=c,e.setOriginalNode(e.setTextRange(l.createFunctionExpression(void 0,t.asteriskToken,i,void 0,d,void 0,p),r),t)}function ge(n){var r,a,i,o=!1,s=!1,c=[],u=[],d=n.body;if(p(),e.isBlock(d)&&(i=l.copyStandardPrologue(d.statements,c,!1),i=l.copyCustomPrologue(d.statements,u,i,D,e.isHoistedFunction),i=l.copyCustomPrologue(d.statements,u,i,D,e.isHoistedVariableStatement)),o=$(u,n)||o,o=re(u,n,!1)||o,e.isBlock(d))i=l.copyCustomPrologue(d.statements,u,i,D),r=d.statements,e.addRange(u,e.visitNodes(d.statements,D,e.isStatement,i)),!o&&d.multiLine&&(o=!0);else{e.Debug.assert(210===n.kind),r=e.moveRangeEnd(d,-1);var m=n.equalsGreaterThanToken;e.nodeIsSynthesized(m)||e.nodeIsSynthesized(d)||(e.rangeEndIsOnSameLineAsRangeStart(m,d,t)?s=!0:o=!0);var _=e.visitNode(d,D,e.isExpression),g=l.createReturnStatement(_);e.setTextRange(g,d),e.moveSyntheticComments(g,d),e.setEmitFlags(g,1440),u.push(g),a=d}if(l.mergeLexicalEnvironment(c,f()),oe(c,n,!1),ae(c,n),e.some(c)&&(o=!0),u.unshift.apply(u,c),e.isBlock(d)&&e.arrayIsEqualTo(u,d.statements))return d;var y=l.createBlock(e.setTextRange(l.createNodeArray(u),r),o);return e.setTextRange(y,n.body),!o&&s&&e.setEmitFlags(y,1),a&&e.setTokenSourceMapRange(y,19,a),e.setOriginalNode(y,n.body),y}function ye(t,r){if(r)return e.visitEachChild(t,D,n);var i=256&a?E(7104,512):E(6976,128),o=e.visitEachChild(t,D,n);return T(i,0,0),o}function he(t){return e.visitEachChild(t,A,n)}function ve(t,r){return e.visitEachChild(t,r?A:D,n)}function be(t,r){return e.isDestructuringAssignment(t)?e.flattenDestructuringAssignment(t,D,n,0,!r):27===t.operatorToken.kind?l.updateBinaryExpression(t,e.visitNode(t.left,A,e.isExpression),t.operatorToken,e.visitNode(t.right,r?A:D,e.isExpression)):e.visitEachChild(t,D,n)}function Ee(t,r){if(r)return e.visitEachChild(t,A,n);for(var a,i=0;i<t.elements.length;i++){var o=t.elements[i],s=e.visitNode(o,i<t.elements.length-1?A:D,e.isExpression);(a||s!==o)&&(a||(a=t.elements.slice(0,i)),a.push(s))}var c=a?e.setTextRange(l.createNodeArray(a),t.elements):t.elements;return l.updateCommaListExpression(t,c)}function Te(n){return 1===n.declarationList.declarations.length&&!!n.declarationList.declarations[0].initializer&&!!(33554432&e.getEmitFlags(n.declarationList.declarations[0].initializer))}function Se(t){var r,a=E(0,e.hasSyntacticModifier(t,1)?32:0);if(s&&0===(3&t.declarationList.flags)&&!Te(t)){for(var i=void 0,o=0,c=t.declarationList.declarations;o<c.length;o++){var u=c[o];if(Ye(s,u),u.initializer){var d=void 0;e.isBindingPattern(u.name)?d=e.flattenDestructuringAssignment(u,D,n,0):(d=l.createBinaryExpression(u.name,62,e.visitNode(u.initializer,D,e.isExpression)),e.setTextRange(d,u)),i=e.append(i,d)}}r=i?e.setTextRange(l.createExpressionStatement(l.inlineExpressions(i)),t):void 0}else r=e.visitEachChild(t,D,n);return T(a,0,0),r}function xe(t){if(3&t.flags||262144&t.transformFlags){3&t.flags&&Qn();var r=e.flatMap(t.declarations,1&t.flags?Ae:Ce),a=l.createVariableDeclarationList(r);return e.setOriginalNode(a,t),e.setTextRange(a,t),e.setCommentRange(a,t),262144&t.transformFlags&&(e.isBindingPattern(t.declarations[0].name)||e.isBindingPattern(e.last(t.declarations).name))&&e.setSourceMapRange(a,Le(r)),a}return e.visitEachChild(t,D,n)}function Le(n){for(var t=-1,r=-1,a=0,i=n;a<i.length;a++){var o=i[a];t=-1===t?o.pos:-1===o.pos?t:Math.min(t,o.pos),r=Math.max(r,o.end)}return e.createRange(t,r)}function De(e){var n=g.getNodeCheckFlags(e),t=262144&n,r=524288&n,i=0!==(64&a)||t&&r&&0!==(512&a),o=!i&&0===(4096&a)&&(!g.isDeclarationWithCollidingName(e)||r&&!t&&0===(6144&a));return o}function Ae(t){var r=t.name;return e.isBindingPattern(r)?Ce(t):!t.initializer&&De(t)?l.updateVariableDeclaration(t,t.name,void 0,void 0,l.createVoidZero()):e.visitEachChild(t,D,n)}function Ce(t){var r,a=E(32,0);return r=e.isBindingPattern(t.name)?e.flattenDestructuringBinding(t,D,n,0,void 0,0!==(32&a)):e.visitEachChild(t,D,n),T(a,0,0),r}function Ie(n){s.labels.set(e.idText(n.label),!0)}function Ne(n){s.labels.set(e.idText(n.label),!1)}function ke(n){s&&!s.labels&&(s.labels=new e.Map);var t=e.unwrapInnermostStatementOfLabel(n,s&&Ie);return e.isIterationStatement(t,!1)?Re(t,n):l.restoreEnclosingLabel(e.visitNode(t,D,e.isStatement,l.liftToBlock),n,s&&Ne)}function Re(e,n){switch(e.kind){case 236:case 237:return we(e,n);case 238:return Pe(e,n);case 239:return Fe(e,n);case 240:return Ge(e,n)}}function Oe(e,n,t,r,a){var i=E(e,n),o=Qe(t,r,i,a);return T(i,0,0),o}function we(e,n){return Oe(0,1280,e,n)}function Pe(e,n){return Oe(5056,3328,e,n)}function Me(n){return l.updateForStatement(n,e.visitNode(n.initializer,A,e.isForInitializer),e.visitNode(n.condition,D,e.isExpression),e.visitNode(n.incrementor,A,e.isExpression),e.visitNode(n.statement,D,e.isStatement,l.liftToBlock))}function Fe(e,n){return Oe(3008,5376,e,n)}function Ge(e,n){return Oe(3008,5376,e,n,_.downlevelIteration?je:Ve)}function Be(t,r,a){var i=[],o=t.initializer;if(e.isVariableDeclarationList(o)){3&t.initializer.flags&&Qn();var s=e.firstOrUndefined(o.declarations);if(s&&e.isBindingPattern(s.name)){var c=e.flattenDestructuringBinding(s,D,n,0,r),u=e.setTextRange(l.createVariableDeclarationList(c),t.initializer);e.setOriginalNode(u,t.initializer),e.setSourceMapRange(u,e.createRange(c[0].pos,e.last(c).end)),i.push(l.createVariableStatement(void 0,u))}else i.push(e.setTextRange(l.createVariableStatement(void 0,e.setOriginalNode(e.setTextRange(l.createVariableDeclarationList([l.createVariableDeclaration(s?s.name:l.createTempVariable(void 0),void 0,void 0,r)]),e.moveRangePos(o,-1)),o)),e.moveRangeEnd(o,-1)))}else{var d=l.createAssignment(o,r);e.isDestructuringAssignment(d)?i.push(l.createExpressionStatement(be(d,!0))):(e.setTextRangeEnd(d,o.end),i.push(e.setTextRange(l.createExpressionStatement(e.visitNode(d,D,e.isExpression)),e.moveRangeEnd(o,-1))))}if(a)return Ue(e.addRange(i,a));var p=e.visitNode(t.statement,D,e.isStatement,l.liftToBlock);return e.isBlock(p)?l.updateBlock(p,e.setTextRange(l.createNodeArray(e.concatenate(i,p.statements)),p.statements)):(i.push(p),Ue(i))}function Ue(n){return e.setEmitFlags(l.createBlock(l.createNodeArray(n),!0),432)}function Ve(n,t,r){var a=e.visitNode(n.expression,D,e.isExpression),i=l.createLoopVariable(),o=e.isIdentifier(a)?l.getGeneratedNameForNode(a):l.createTempVariable(void 0);e.setEmitFlags(a,48|e.getEmitFlags(a));var c=e.setTextRange(l.createForStatement(e.setEmitFlags(e.setTextRange(l.createVariableDeclarationList([e.setTextRange(l.createVariableDeclaration(i,void 0,void 0,l.createNumericLiteral(0)),e.moveRangePos(n.expression,-1)),e.setTextRange(l.createVariableDeclaration(o,void 0,void 0,a),n.expression)]),n.expression),2097152),e.setTextRange(l.createLessThan(i,l.createPropertyAccessExpression(o,"length")),n.expression),e.setTextRange(l.createPostfixIncrement(i),n.expression),Be(n,l.createElementAccessExpression(o,i),r)),n);return e.setEmitFlags(c,256),e.setTextRange(c,n),l.restoreEnclosingLabel(c,t,s&&Ne)}function je(n,t,r,a){var i=e.visitNode(n.expression,D,e.isExpression),o=e.isIdentifier(i)?l.getGeneratedNameForNode(i):l.createTempVariable(void 0),c=e.isIdentifier(i)?l.getGeneratedNameForNode(o):l.createTempVariable(void 0),d=l.createUniqueName("e"),p=l.getGeneratedNameForNode(d),f=l.createTempVariable(void 0),_=e.setTextRange(u().createValuesHelper(i),n.expression),g=l.createCallExpression(l.createPropertyAccessExpression(o,"next"),void 0,[]);m(d),m(f);var y=1024&a?l.inlineExpressions([l.createAssignment(d,l.createVoidZero()),_]):_,h=e.setEmitFlags(e.setTextRange(l.createForStatement(e.setEmitFlags(e.setTextRange(l.createVariableDeclarationList([e.setTextRange(l.createVariableDeclaration(o,void 0,void 0,y),n.expression),l.createVariableDeclaration(c,void 0,void 0,g)]),n.expression),2097152),l.createLogicalNot(l.createPropertyAccessExpression(c,"done")),l.createAssignment(c,g),Be(n,l.createPropertyAccessExpression(c,"value"),r)),n),256);return l.createTryStatement(l.createBlock([l.restoreEnclosingLabel(h,t,s&&Ne)]),l.createCatchClause(l.createVariableDeclaration(p),e.setEmitFlags(l.createBlock([l.createExpressionStatement(l.createAssignment(d,l.createObjectLiteralExpression([l.createPropertyAssignment("error",p)])))]),1)),l.createBlock([l.createTryStatement(l.createBlock([e.setEmitFlags(l.createIfStatement(l.createLogicalAnd(l.createLogicalAnd(c,l.createLogicalNot(l.createPropertyAccessExpression(c,"done"))),l.createAssignment(f,l.createPropertyAccessExpression(o,"return"))),l.createExpressionStatement(l.createFunctionCallCall(f,o,[]))),1)]),void 0,e.setEmitFlags(l.createBlock([e.setEmitFlags(l.createIfStatement(d,l.createThrowStatement(l.createPropertyAccessExpression(d,"error"))),1)]),1))]))}function Ke(t){for(var r=t.properties,i=-1,o=!1,s=0;s<r.length;s++){var c=r[s];if(524288&c.transformFlags&&4&a||(o=159===e.Debug.checkDefined(c.name).kind)){i=s;break}}if(i<0)return e.visitEachChild(t,D,n);var u=l.createTempVariable(m),d=[],p=l.createAssignment(u,e.setEmitFlags(l.createObjectLiteralExpression(e.visitNodes(r,D,e.isObjectLiteralElementLike,0,i),t.multiLine),o?65536:0));return t.multiLine&&e.startOnNewLine(p),d.push(p),yn(d,t,u,i),d.push(t.multiLine?e.startOnNewLine(e.setParent(e.setTextRange(l.cloneNode(u),u),u.parent)):u),l.inlineExpressions(d)}function He(e){return 0!==(131072&g.getNodeCheckFlags(e))}function We(n){return e.isForStatement(n)&&!!n.initializer&&He(n.initializer)}function ze(n){return e.isForStatement(n)&&!!n.condition&&He(n.condition)}function qe(n){return e.isForStatement(n)&&!!n.incrementor&&He(n.incrementor)}function Je(e){return Xe(e)||We(e)}function Xe(e){return 0!==(65536&g.getNodeCheckFlags(e))}function Ye(n,t){function r(t){if(78===t.kind)n.hoistedLocalVariables.push(t);else for(var a=0,i=t.elements;a<i.length;a++){var o=i[a];e.isOmittedExpression(o)||r(o.name)}}n.hoistedLocalVariables||(n.hoistedLocalVariables=[]),r(t.name)}function Qe(t,r,a,i){if(!Je(t)){var o=void 0;s&&(o=s.allowedNonLabeledJumps,s.allowedNonLabeledJumps=6);var c=i?i(t,r,void 0,a):l.restoreEnclosingLabel(e.isForStatement(t)?Me(t):e.visitEachChild(t,D,n),r,s&&Ne);return s&&(s.allowedNonLabeledJumps=o),c}var u=an(t),d=[],p=s;s=u;var f,m=We(t)?cn(t,u):void 0,_=Xe(t)?ln(t,u,p):void 0;if(s=p,m&&d.push(m.functionDeclaration),_&&d.push(_.functionDeclaration),on(d,u,p),m&&d.push(pn(m.functionName,m.containsYield)),_)if(i)f=i(t,r,_.part,a);else{var g=Ze(t,m,l.createBlock(_.part,!0));f=l.restoreEnclosingLabel(g,r,s&&Ne)}else{var y=Ze(t,m,e.visitNode(t.statement,D,e.isStatement,l.liftToBlock));f=l.restoreEnclosingLabel(y,r,s&&Ne)}return d.push(f),d}function Ze(n,t,r){switch(n.kind){case 238:return $e(n,t,r);case 239:return nn(n,r);case 240:return en(n,r);case 236:return tn(n,r);case 237:return rn(n,r);default:return e.Debug.failBadSyntaxKind(n,"IterationStatement expected")}}function $e(n,t,r){var a=n.condition&&He(n.condition),i=a||n.incrementor&&He(n.incrementor);return l.updateForStatement(n,e.visitNode(t?t.part:n.initializer,A,e.isForInitializer),e.visitNode(a?void 0:n.condition,D,e.isExpression),e.visitNode(i?void 0:n.incrementor,A,e.isExpression),r)}function en(n,t){return l.updateForOfStatement(n,void 0,e.visitNode(n.initializer,D,e.isForInitializer),e.visitNode(n.expression,D,e.isExpression),t)}function nn(n,t){return l.updateForInStatement(n,e.visitNode(n.initializer,D,e.isForInitializer),e.visitNode(n.expression,D,e.isExpression),t)}function tn(n,t){return l.updateDoStatement(n,t,e.visitNode(n.expression,D,e.isExpression))}function rn(n,t){return l.updateWhileStatement(n,e.visitNode(n.expression,D,e.isExpression),t)}function an(n){var t;switch(n.kind){case 238:case 239:case 240:var r=n.initializer;r&&251===r.kind&&(t=r);break}var a=[],i=[];if(t&&3&e.getCombinedNodeFlags(t))for(var o=We(n),c=0,l=t.declarations;c<l.length;c++){var u=l[c];gn(n,u,a,i,o)}var d={loopParameters:a,loopOutParameters:i};return s&&(s.argumentsName&&(d.argumentsName=s.argumentsName),s.thisName&&(d.thisName=s.thisName),s.hoistedLocalVariables&&(d.hoistedLocalVariables=s.hoistedLocalVariables)),d}function on(e,n,t){var r;if(n.argumentsName&&(t?t.argumentsName=n.argumentsName:(r||(r=[])).push(l.createVariableDeclaration(n.argumentsName,void 0,void 0,l.createIdentifier("arguments")))),n.thisName&&(t?t.thisName=n.thisName:(r||(r=[])).push(l.createVariableDeclaration(n.thisName,void 0,void 0,l.createIdentifier("this")))),n.hoistedLocalVariables)if(t)t.hoistedLocalVariables=n.hoistedLocalVariables;else{r||(r=[]);for(var a=0,i=n.hoistedLocalVariables;a<i.length;a++){var o=i[a];r.push(l.createVariableDeclaration(o))}}if(n.loopOutParameters.length){r||(r=[]);for(var s=0,c=n.loopOutParameters;s<c.length;s++){var u=c[s];r.push(l.createVariableDeclaration(u.outParamName))}}n.conditionVariable&&(r||(r=[]),r.push(l.createVariableDeclaration(n.conditionVariable,void 0,void 0,l.createFalse()))),r&&e.push(l.createVariableStatement(void 0,l.createVariableDeclarationList(r)))}function sn(e){return l.createVariableDeclaration(e.originalName,void 0,void 0,e.outParamName)}function cn(n,t){var r=l.createUniqueName("_loop_init"),i=0!==(524288&n.initializer.transformFlags),o=0;t.containsLexicalThis&&(o|=8),i&&4&a&&(o|=262144);var s=[];s.push(l.createVariableStatement(void 0,n.initializer)),dn(t.loopOutParameters,2,1,s);var c=l.createVariableStatement(void 0,e.setEmitFlags(l.createVariableDeclarationList([l.createVariableDeclaration(r,void 0,void 0,e.setEmitFlags(l.createFunctionExpression(void 0,i?l.createToken(41):void 0,void 0,void 0,void 0,void 0,e.visitNode(l.createBlock(s,!0),D,e.isBlock)),o))]),2097152)),u=l.createVariableDeclarationList(e.map(t.loopOutParameters,sn));return{functionName:r,containsYield:i,functionDeclaration:c,part:u}}function ln(n,t,r){var i=l.createUniqueName("_loop");d();var o=e.visitNode(n.statement,D,e.isStatement,l.liftToBlock),s=f(),c=[];(ze(n)||qe(n))&&(t.conditionVariable=l.createUniqueName("inc"),n.incrementor?c.push(l.createIfStatement(t.conditionVariable,l.createExpressionStatement(e.visitNode(n.incrementor,D,e.isExpression)),l.createExpressionStatement(l.createAssignment(t.conditionVariable,l.createTrue())))):c.push(l.createIfStatement(l.createLogicalNot(t.conditionVariable),l.createExpressionStatement(l.createAssignment(t.conditionVariable,l.createTrue())))),ze(n)&&c.push(l.createIfStatement(l.createPrefixUnaryExpression(53,e.visitNode(n.condition,D,e.isExpression)),e.visitNode(l.createBreakStatement(),D,e.isStatement)))),e.isBlock(o)?e.addRange(c,o.statements):c.push(o),dn(t.loopOutParameters,1,1,c),e.insertStatementsAfterStandardPrologue(c,s);var u=l.createBlock(c,!0);e.isBlock(o)&&e.setOriginalNode(u,o);var p=0!==(524288&n.statement.transformFlags),m=524288;t.containsLexicalThis&&(m|=8),p&&0!==(4&a)&&(m|=262144);var _=l.createVariableStatement(void 0,e.setEmitFlags(l.createVariableDeclarationList([l.createVariableDeclaration(i,void 0,void 0,e.setEmitFlags(l.createFunctionExpression(void 0,p?l.createToken(41):void 0,void 0,void 0,t.loopParameters,void 0,u),m))]),2097152)),g=fn(i,t,r,p);return{functionName:i,containsYield:p,functionDeclaration:_,part:g}}function un(e,n){var t=0===n?e.outParamName:e.originalName,r=0===n?e.originalName:e.outParamName;return l.createBinaryExpression(r,62,t)}function dn(e,n,t,r){for(var a=0,i=e;a<i.length;a++){var o=i[a];o.flags&n&&r.push(l.createExpressionStatement(un(o,t)))}}function pn(n,t){var r=l.createCallExpression(n,void 0,[]),a=t?l.createYieldExpression(l.createToken(41),e.setEmitFlags(r,8388608)):r;return l.createExpressionStatement(a)}function fn(n,t,r,a){var i=[],o=!(-5&t.nonLocalJumps)&&!t.labeledNonLocalBreaks&&!t.labeledNonLocalContinues,s=l.createCallExpression(n,void 0,e.map(t.loopParameters,(function(e){return e.name}))),c=a?l.createYieldExpression(l.createToken(41),e.setEmitFlags(s,8388608)):s;if(o)i.push(l.createExpressionStatement(c)),dn(t.loopOutParameters,1,0,i);else{var u=l.createUniqueName("state"),d=l.createVariableStatement(void 0,l.createVariableDeclarationList([l.createVariableDeclaration(u,void 0,void 0,c)]));if(i.push(d),dn(t.loopOutParameters,1,0,i),8&t.nonLocalJumps){var p=void 0;r?(r.nonLocalJumps|=8,p=l.createReturnStatement(u)):p=l.createReturnStatement(l.createPropertyAccessExpression(u,"value")),i.push(l.createIfStatement(l.createTypeCheck(u,"object"),p))}if(2&t.nonLocalJumps&&i.push(l.createIfStatement(l.createStrictEquality(u,l.createStringLiteral("break")),l.createBreakStatement())),t.labeledNonLocalBreaks||t.labeledNonLocalContinues){var f=[];_n(t.labeledNonLocalBreaks,!0,u,r,f),_n(t.labeledNonLocalContinues,!1,u,r,f),i.push(l.createSwitchStatement(u,l.createCaseBlock(f)))}}return i}function mn(n,t,r,a){t?(n.labeledNonLocalBreaks||(n.labeledNonLocalBreaks=new e.Map),n.labeledNonLocalBreaks.set(r,a)):(n.labeledNonLocalContinues||(n.labeledNonLocalContinues=new e.Map),n.labeledNonLocalContinues.set(r,a))}function _n(e,n,t,r,a){e&&e.forEach((function(e,i){var o=[];if(!r||r.labels&&r.labels.get(i)){var s=l.createIdentifier(i);o.push(n?l.createBreakStatement(s):l.createContinueStatement(s))}else mn(r,n,i,e),o.push(l.createReturnStatement(t));a.push(l.createCaseClause(l.createStringLiteral(e),o))}))}function gn(n,t,r,a,i){var o=t.name;if(e.isBindingPattern(o))for(var s=0,c=o.elements;s<c.length;s++){var u=c[s];e.isOmittedExpression(u)||gn(n,u,r,a,i)}else{r.push(l.createParameterDeclaration(void 0,void 0,void 0,o));var d=g.getNodeCheckFlags(t);if(4194304&d||i){var p=l.createUniqueName("out_"+e.idText(o)),f=0;4194304&d&&(f|=1),e.isForStatement(n)&&n.initializer&&g.isBindingCapturedByNode(n.initializer,t)&&(f|=2),a.push({flags:f,originalName:o,outParamName:p})}}}function yn(n,t,r,a){for(var i=t.properties,o=i.length,s=a;s<o;s++){var c=i[s];switch(c.kind){case 168:case 169:var l=e.getAllAccessorDeclarations(t.properties,c);c===l.firstAccessor&&n.push(de(r,l,t,!!t.multiLine));break;case 166:n.push(bn(c,r,t,t.multiLine));break;case 289:n.push(hn(c,r,t.multiLine));break;case 290:n.push(vn(c,r,t.multiLine));break;default:e.Debug.failBadSyntaxKind(t);break}}}function hn(n,t,r){var a=l.createAssignment(e.createMemberAccessForPropertyName(l,t,e.visitNode(n.name,D,e.isPropertyName)),e.visitNode(n.initializer,D,e.isExpression));return e.setTextRange(a,n),r&&e.startOnNewLine(a),a}function vn(n,t,r){var a=l.createAssignment(e.createMemberAccessForPropertyName(l,t,e.visitNode(n.name,D,e.isPropertyName)),l.cloneNode(n.name));return e.setTextRange(a,n),r&&e.startOnNewLine(a),a}function bn(n,t,r,a){var i=l.createAssignment(e.createMemberAccessForPropertyName(l,t,e.visitNode(n.name,D,e.isPropertyName)),_e(n,n,void 0,r));return e.setTextRange(i,n),a&&e.startOnNewLine(i),i}function En(t){var r,a=E(7104,0);if(e.Debug.assert(!!t.variableDeclaration,"Catch clause variable should always be present when downleveling ES2015."),e.isBindingPattern(t.variableDeclaration.name)){var i=l.createTempVariable(void 0),o=l.createVariableDeclaration(i);e.setTextRange(o,t.variableDeclaration);var s=e.flattenDestructuringBinding(t.variableDeclaration,D,n,0,i),c=l.createVariableDeclarationList(s);e.setTextRange(c,t.variableDeclaration);var u=l.createVariableStatement(void 0,c);r=l.updateCatchClause(t,o,Tn(t.block,u))}else r=e.visitEachChild(t,D,n);return T(a,0,0),r}function Tn(n,t){var r=e.visitNodes(n.statements,D,e.isStatement);return l.updateBlock(n,i([t],r))}function Sn(n){e.Debug.assert(!e.isComputedPropertyName(n.name));var t=_e(n,e.moveRangePos(n,-1),void 0,void 0);return e.setEmitFlags(t,512|e.getEmitFlags(t)),e.setTextRange(l.createPropertyAssignment(n.name,t),n)}function xn(t){e.Debug.assert(!e.isComputedPropertyName(t.name));var r=s;s=void 0;var a,i=E(16286,65),o=e.visitParameterList(t.parameters,D,n),c=ge(t);return a=168===t.kind?l.updateGetAccessorDeclaration(t,t.decorators,t.modifiers,t.name,o,t.type,c):l.updateSetAccessorDeclaration(t,t.decorators,t.modifiers,t.name,o,c),T(i,49152,0),s=r,a}function Ln(n){return e.setTextRange(l.createPropertyAssignment(n.name,F(l.cloneNode(n.name))),n)}function Dn(t){return e.visitEachChild(t,D,n)}function An(t){return e.visitEachChild(t,D,n)}function Cn(t){return e.some(t.elements,e.isSpreadElement)?wn(t.elements,!0,!!t.multiLine,!!t.elements.hasTrailingComma):e.visitEachChild(t,D,n)}function In(n){if(33554432&e.getEmitFlags(n))return Nn(n);var t=e.skipOuterExpressions(n.expression);return 105===t.kind||e.isSuperProperty(t)||e.some(n.arguments,e.isSpreadElement)?Rn(n,!0):l.updateCallExpression(n,e.visitNode(n.expression,C,e.isExpression),void 0,e.visitNodes(n.arguments,D,e.isExpression))}function Nn(n){var t=e.cast(e.cast(e.skipOuterExpressions(n.expression),e.isArrowFunction).body,e.isBlock),r=function(n){return e.isVariableStatement(n)&&!!e.first(n.declarationList.declarations).initializer},a=s;s=void 0;var i=e.visitNodes(t.statements,D,e.isStatement);s=a;var o=e.filter(i,r),c=e.filter(i,(function(e){return!r(e)})),u=e.cast(e.first(o),e.isVariableStatement),d=u.declarationList.declarations[0],p=e.skipOuterExpressions(d.initializer),f=e.tryCast(p,e.isAssignmentExpression),m=e.cast(f?e.skipOuterExpressions(f.right):p,e.isCallExpression),_=e.cast(e.skipOuterExpressions(m.expression),e.isFunctionExpression),g=_.body.statements,y=0,h=-1,v=[];if(f){var b=e.tryCast(g[y],e.isExpressionStatement);b&&(v.push(b),y++),v.push(g[y]),y++,v.push(l.createExpressionStatement(l.createAssignment(f.left,e.cast(d.name,e.isIdentifier))))}while(!e.isReturnStatement(e.elementAt(g,h)))h--;return e.addRange(v,g,y,h),h<-1&&e.addRange(v,g,h+1),e.addRange(v,c),e.addRange(v,o,1),l.restoreOuterExpressions(n.expression,l.restoreOuterExpressions(d.initializer,l.restoreOuterExpressions(f&&f.right,l.updateCallExpression(m,l.restoreOuterExpressions(m.expression,l.updateFunctionExpression(_,void 0,void 0,void 0,void 0,_.parameters,void 0,l.updateBlock(_.body,v))),void 0,m.arguments))))}function kn(e){return Rn(e,!1)}function Rn(t,r){if(16384&t.transformFlags||105===t.expression.kind||e.isSuperProperty(e.skipOuterExpressions(t.expression))){var a=l.createCallBinding(t.expression,m),i=a.target,o=a.thisArg;105===t.expression.kind&&e.setEmitFlags(o,4);var s=void 0;if(s=16384&t.transformFlags?l.createFunctionApplyCall(e.visitNode(i,C,e.isExpression),105===t.expression.kind?o:e.visitNode(o,D,e.isExpression),wn(t.arguments,!1,!1,!1)):e.setTextRange(l.createFunctionCallCall(e.visitNode(i,C,e.isExpression),105===t.expression.kind?o:e.visitNode(o,D,e.isExpression),e.visitNodes(t.arguments,D,e.isExpression)),t),105===t.expression.kind){var c=l.createLogicalOr(s,X());s=r?l.createAssignment(l.createUniqueName("_this",48),c):c}return e.setOriginalNode(s,t)}return e.visitEachChild(t,D,n)}function On(t){if(e.some(t.arguments,e.isSpreadElement)){var r=l.createCallBinding(l.createPropertyAccessExpression(t.expression,"bind"),m),a=r.target,o=r.thisArg;return l.createNewExpression(l.createFunctionApplyCall(e.visitNode(a,D,e.isExpression),o,wn(l.createNodeArray(i([l.createVoidZero()],t.arguments)),!1,!1,!1)),void 0,[])}return e.visitEachChild(t,D,n)}function wn(n,t,r,a){var i=n.length,o=e.flatten(e.spanMap(n,Pn,(function(e,n,t,o){return n(e,r,a&&o===i)})));if(1===o.length){var s=o[0];if(!t&&!_.downlevelIteration||e.isPackedArrayLiteral(s)||e.isCallToHelper(s,"___spreadArray"))return o[0]}for(var c=u(),d=e.isSpreadElement(n[0]),p=d?l.createArrayLiteralExpression():o[0],f=d?0:1;f<o.length;f++)p=c.createSpreadArrayHelper(p,_.downlevelIteration&&!e.isPackedArrayLiteral(o[f])?c.createReadHelper(o[f],void 0):o[f]);return p}function Pn(n){return e.isSpreadElement(n)?Mn:Fn}function Mn(n){return e.map(n,Bn)}function Fn(n,t,r){return l.createArrayLiteralExpression(e.visitNodes(l.createNodeArray(n,r),D,e.isExpression),t)}function Gn(n){return e.visitNode(n.expression,D,e.isExpression)}function Bn(n){return e.visitNode(n.expression,D,e.isExpression)}function Un(n){return e.setTextRange(l.createStringLiteral(n.text),n)}function Vn(n){return n.hasExtendedUnicodeEscape?e.setTextRange(l.createStringLiteral(n.text),n):n}function jn(n){return 384&n.numericLiteralFlags?e.setTextRange(l.createNumericLiteral(n.text),n):n}function Kn(r){return e.processTaggedTemplateExpression(n,r,D,t,v,e.ProcessLevel.All)}function Hn(n){var t=[];zn(t,n),qn(t,n);var r=e.reduceLeft(t,l.createAdd);return e.nodeIsSynthesized(r)&&e.setTextRange(r,n),r}function Wn(n){return e.Debug.assert(0!==n.templateSpans.length),0!==n.head.text.length||0===n.templateSpans[0].literal.text.length}function zn(e,n){Wn(n)&&e.push(l.createStringLiteral(n.head.text))}function qn(n,t){for(var r=0,a=t.templateSpans;r<a.length;r++){var i=a[r];n.push(e.visitNode(i.expression,D,e.isExpression)),0!==i.literal.text.length&&n.push(l.createStringLiteral(i.literal.text))}}function Jn(e){return 8&a&&!e?l.createPropertyAccessExpression(l.createUniqueName("_super",48),"prototype"):l.createUniqueName("_super",48)}function Xn(e){return 102===e.keywordToken&&"target"===e.name.escapedText?(a|=16384,l.createUniqueName("_newTarget",48)):e}function Yn(n,t,r){if(1&c&&e.isFunctionLike(t)){var a=E(16286,8&e.getEmitFlags(t)?81:65);return h(n,t,r),void T(a,0,0)}h(n,t,r)}function Qn(){0===(2&c)&&(c|=2,n.enableSubstitution(78))}function Zn(){0===(1&c)&&(c|=1,n.enableSubstitution(107),n.enableEmitNotification(167),n.enableEmitNotification(166),n.enableEmitNotification(168),n.enableEmitNotification(169),n.enableEmitNotification(210),n.enableEmitNotification(209),n.enableEmitNotification(252))}function $n(n,t){return t=y(n,t),1===n?tt(t):e.isIdentifier(t)?et(t):t}function et(n){if(2&c&&!e.isInternalName(n)){var t=e.getParseTreeNode(n,e.isIdentifier);if(t&&nt(t))return e.setTextRange(l.getGeneratedNameForNode(t),n)}return n}function nt(e){switch(e.parent.kind){case 199:case 253:case 256:case 250:return e.parent.name===e&&g.isDeclarationWithCollidingName(e.parent)}return!1}function tt(e){switch(e.kind){case 78:return rt(e);case 107:return it(e)}return e}function rt(n){if(2&c&&!e.isInternalName(n)){var t=g.getReferencedDeclarationWithCollidingName(n);if(t&&(!e.isClassLike(t)||!at(t,n)))return e.setTextRange(l.getGeneratedNameForNode(e.getNameOfDeclaration(t)),n)}return n}function at(n,t){var r=e.getParseTreeNode(t);if(!r||r===n||r.end<=n.pos||r.pos>=n.end)return!1;var a=e.getEnclosingBlockScopeContainer(n);while(r){if(r===a||r===n)return!1;if(e.isClassElement(r)&&r.parent===n)return!0;r=r.parent}return!1}function it(n){return 1&c&&16&a?e.setTextRange(l.createUniqueName("_this",48),n):n}function ot(n,t){return e.hasSyntacticModifier(t,32)?l.getInternalName(n):l.createPropertyAccessExpression(l.getInternalName(n),"prototype")}function st(n,t){if(!n||!t)return!1;if(e.some(n.parameters))return!1;var r=e.firstOrUndefined(n.body.statements);if(!r||!e.nodeIsSynthesized(r)||234!==r.kind)return!1;var a=r.expression;if(!e.nodeIsSynthesized(a)||204!==a.kind)return!1;var i=a.expression;if(!e.nodeIsSynthesized(i)||105!==i.kind)return!1;var o=e.singleOrUndefined(a.arguments);if(!o||!e.nodeIsSynthesized(o)||221!==o.kind)return!1;var s=o.expression;return e.isIdentifier(s)&&"arguments"===s.escapedText}}(function(e){e[e["CapturedThis"]=1]="CapturedThis",e[e["BlockScopedBindings"]=2]="BlockScopedBindings"})(n||(n={})),function(e){e[e["Body"]=1]="Body",e[e["Initializer"]=2]="Initializer"}(t||(t={})),function(e){e[e["ToOriginal"]=0]="ToOriginal",e[e["ToOutParameter"]=1]="ToOutParameter"}(r||(r={})),function(e){e[e["Break"]=2]="Break",e[e["Continue"]=4]="Continue",e[e["Return"]=8]="Return"}(a||(a={})),function(e){e[e["None"]=0]="None",e[e["Function"]=1]="Function",e[e["ArrowFunction"]=2]="ArrowFunction",e[e["AsyncFunctionBody"]=4]="AsyncFunctionBody",e[e["NonStaticClassElement"]=8]="NonStaticClassElement",e[e["CapturesThis"]=16]="CapturesThis",e[e["ExportedVariableStatement"]=32]="ExportedVariableStatement",e[e["TopLevel"]=64]="TopLevel",e[e["Block"]=128]="Block",e[e["IterationStatement"]=256]="IterationStatement",e[e["IterationStatementBlock"]=512]="IterationStatementBlock",e[e["IterationContainer"]=1024]="IterationContainer",e[e["ForStatement"]=2048]="ForStatement",e[e["ForInOrForOfStatement"]=4096]="ForInOrForOfStatement",e[e["ConstructorWithCapturedSuper"]=8192]="ConstructorWithCapturedSuper",e[e["AncestorFactsMask"]=16383]="AncestorFactsMask",e[e["BlockScopeIncludes"]=0]="BlockScopeIncludes",e[e["BlockScopeExcludes"]=7104]="BlockScopeExcludes",e[e["SourceFileIncludes"]=64]="SourceFileIncludes",e[e["SourceFileExcludes"]=8064]="SourceFileExcludes",e[e["FunctionIncludes"]=65]="FunctionIncludes",e[e["FunctionExcludes"]=16286]="FunctionExcludes",e[e["AsyncFunctionBodyIncludes"]=69]="AsyncFunctionBodyIncludes",e[e["AsyncFunctionBodyExcludes"]=16278]="AsyncFunctionBodyExcludes",e[e["ArrowFunctionIncludes"]=66]="ArrowFunctionIncludes",e[e["ArrowFunctionExcludes"]=15232]="ArrowFunctionExcludes",e[e["ConstructorIncludes"]=73]="ConstructorIncludes",e[e["ConstructorExcludes"]=16278]="ConstructorExcludes",e[e["DoOrWhileStatementIncludes"]=1280]="DoOrWhileStatementIncludes",e[e["DoOrWhileStatementExcludes"]=0]="DoOrWhileStatementExcludes",e[e["ForStatementIncludes"]=3328]="ForStatementIncludes",e[e["ForStatementExcludes"]=5056]="ForStatementExcludes",e[e["ForInOrForOfStatementIncludes"]=5376]="ForInOrForOfStatementIncludes",e[e["ForInOrForOfStatementExcludes"]=3008]="ForInOrForOfStatementExcludes",e[e["BlockIncludes"]=128]="BlockIncludes",e[e["BlockExcludes"]=6976]="BlockExcludes",e[e["IterationStatementBlockIncludes"]=512]="IterationStatementBlockIncludes",e[e["IterationStatementBlockExcludes"]=7104]="IterationStatementBlockExcludes",e[e["NewTarget"]=16384]="NewTarget",e[e["CapturedLexicalThis"]=32768]="CapturedLexicalThis",e[e["SubtreeFactsMask"]=-16384]="SubtreeFactsMask",e[e["ArrowFunctionSubtreeExcludes"]=0]="ArrowFunctionSubtreeExcludes",e[e["FunctionSubtreeExcludes"]=49152]="FunctionSubtreeExcludes"}(o||(o={})),e.transformES2015=s}(d||(d={})),function(e){function n(n){var t,r,a=n.factory,i=n.getCompilerOptions();1!==i.jsx&&3!==i.jsx||(t=n.onEmitNode,n.onEmitNode=c,n.enableEmitNotification(276),n.enableEmitNotification(277),n.enableEmitNotification(275),r=[]);var o=n.onSubstituteNode;return n.onSubstituteNode=l,n.enableSubstitution(202),n.enableSubstitution(289),e.chainBundle(n,s);function s(e){return e}function c(n,a,i){switch(a.kind){case 276:case 277:case 275:var o=a.tagName;r[e.getOriginalNodeId(o)]=!0;break}t(n,a,i)}function l(n,t){return t.id&&r&&r[t.id]?o(n,t):(t=o(n,t),e.isPropertyAccessExpression(t)?u(t):e.isPropertyAssignment(t)?d(t):t)}function u(n){if(e.isPrivateIdentifier(n.name))return n;var t=p(n.name);return t?e.setTextRange(a.createElementAccessExpression(n.expression,t),n):n}function d(n){var t=e.isIdentifier(n.name)&&p(n.name);return t?a.updatePropertyAssignment(n,t,n.initializer):n}function p(n){var t=n.originalKeywordKind||(e.nodeIsSynthesized(n)?e.stringToToken(e.idText(n)):void 0);if(void 0!==t&&t>=80&&t<=115)return e.setTextRange(a.createStringLiteralFromNode(n),n)}}e.transformES5=n}(d||(d={})),function(e){var n,t,r,a,o;function s(e){switch(e){case 2:return"return";case 3:return"break";case 4:return"yield";case 5:return"yield*";case 7:return"endfinally";default:return}}function c(n){var t,r,a,o,c,l,u,d,p,f,m=n.factory,_=n.getEmitHelperFactory,g=n.resumeLexicalEnvironment,y=n.endLexicalEnvironment,h=n.hoistFunctionDeclaration,v=n.hoistVariableDeclaration,b=n.getCompilerOptions(),E=e.getEmitScriptTarget(b),T=n.getEmitResolver(),S=n.onSubstituteNode;n.onSubstituteNode=je;var x,L,D,A,C,I,N,k,R,O,w,P,M=1,F=0,G=0;return e.chainBundle(n,B);function B(t){if(t.isDeclarationFile||0===(1024&t.transformFlags))return t;var r=e.visitEachChild(t,U,n);return e.addEmitHelpers(r,n.readEmitHelpers()),r}function U(t){var r=t.transformFlags;return o?V(t):a?j(t):e.isFunctionLikeDeclaration(t)&&t.asteriskToken?H(t):1024&r?e.visitEachChild(t,U,n):t}function V(e){switch(e.kind){case 236:return be(e);case 237:return Te(e);case 245:return Pe(e);case 246:return Fe(e);default:return j(e)}}function j(t){switch(t.kind){case 252:return W(t);case 209:return z(t);case 168:case 169:return q(t);case 233:return X(t);case 238:return xe(t);case 239:return De(t);case 242:return Ne(t);case 241:return Ce(t);case 243:return Re(t);default:return 524288&t.transformFlags?K(t):2098176&t.transformFlags?e.visitEachChild(t,U,n):t}}function K(t){switch(t.kind){case 217:return Y(t);case 341:return ee(t);case 218:return te(t);case 220:return re(t);case 200:return ae(t);case 201:return oe(t);case 203:return se(t);case 204:return ce(t);case 205:return le(t);default:return e.visitEachChild(t,U,n)}}function H(n){switch(n.kind){case 252:return W(n);case 209:return z(n);default:return e.Debug.failBadSyntaxKind(n)}}function W(t){if(t.asteriskToken)t=e.setOriginalNode(e.setTextRange(m.createFunctionDeclaration(void 0,t.modifiers,void 0,t.name,void 0,e.visitParameterList(t.parameters,U,n),void 0,J(t.body)),t),t);else{var r=a,i=o;a=!1,o=!1,t=e.visitEachChild(t,U,n),a=r,o=i}return a?void h(t):t}function z(t){if(t.asteriskToken)t=e.setOriginalNode(e.setTextRange(m.createFunctionExpression(void 0,void 0,t.name,void 0,e.visitParameterList(t.parameters,U,n),void 0,J(t.body)),t),t);else{var r=a,i=o;a=!1,o=!1,t=e.visitEachChild(t,U,n),a=r,o=i}return t}function q(t){var r=a,i=o;return a=!1,o=!1,t=e.visitEachChild(t,U,n),a=r,o=i,t}function J(n){var t=[],r=a,i=o,s=c,_=l,h=u,v=d,b=p,E=f,T=M,S=x,C=L,I=D,N=A;a=!0,o=!1,c=void 0,l=void 0,u=void 0,d=void 0,p=void 0,f=void 0,M=1,x=void 0,L=void 0,D=void 0,A=m.createTempVariable(void 0),g();var k=m.copyPrologue(n.statements,t,!1,U);ue(n.statements,k);var R=Gn();return e.insertStatementsAfterStandardPrologue(t,y()),t.push(m.createReturnStatement(R)),a=r,o=i,c=s,l=_,u=h,d=v,p=b,f=E,M=T,x=S,L=C,D=I,A=N,e.setTextRange(m.createBlock(t,n.multiLine),n)}function X(n){if(524288&n.transformFlags)ge(n.declarationList);else{if(1048576&e.getEmitFlags(n))return n;for(var t=0,r=n.declarationList.declarations;t<r.length;t++){var a=r[t];v(a.name)}var i=e.getInitializedVariables(n.declarationList);if(0!==i.length)return e.setSourceMapRange(m.createExpressionStatement(m.inlineExpressions(e.map(i,ye))),n)}}function Y(n){var t=e.getExpressionAssociativity(n);switch(t){case 0:return Z(n);case 1:return Q(n);default:return e.Debug.assertNever(t)}}function Q(t){var r=t.left,a=t.right;if(Ue(a)){var i=void 0;switch(r.kind){case 202:i=m.updatePropertyAccessExpression(r,We(e.visitNode(r.expression,U,e.isLeftHandSideExpression)),r.name);break;case 203:i=m.updateElementAccessExpression(r,We(e.visitNode(r.expression,U,e.isLeftHandSideExpression)),We(e.visitNode(r.argumentExpression,U,e.isExpression)));break;default:i=e.visitNode(r,U,e.isExpression);break}var o=t.operatorToken.kind;return e.isCompoundAssignment(o)?e.setTextRange(m.createAssignment(i,e.setTextRange(m.createBinaryExpression(We(i),e.getNonAssignmentOperatorForCompoundAssignment(o),e.visitNode(a,U,e.isExpression)),t)),t):m.updateBinaryExpression(t,i,t.operatorToken,e.visitNode(a,U,e.isExpression))}return e.visitEachChild(t,U,n)}function Z(t){return Ue(t.right)?e.isLogicalOperator(t.operatorToken.kind)?ne(t):27===t.operatorToken.kind?$(t):m.updateBinaryExpression(t,We(e.visitNode(t.left,U,e.isExpression)),t.operatorToken,e.visitNode(t.right,U,e.isExpression)):e.visitEachChild(t,U,n)}function $(n){var t=[];return r(n.left),r(n.right),m.inlineExpressions(t);function r(n){e.isBinaryExpression(n)&&27===n.operatorToken.kind?(r(n.left),r(n.right)):(Ue(n)&&t.length>0&&(Fn(1,[m.createExpressionStatement(m.inlineExpressions(t))]),t=[]),t.push(e.visitNode(n,U,e.isExpression)))}}function ee(n){for(var t=[],r=0,a=n.elements;r<a.length;r++){var i=a[r];e.isBinaryExpression(i)&&27===i.operatorToken.kind?t.push($(i)):(Ue(i)&&t.length>0&&(Fn(1,[m.createExpressionStatement(m.inlineExpressions(t))]),t=[]),t.push(e.visitNode(i,U,e.isExpression)))}return m.inlineExpressions(t)}function ne(n){var t=qe(),r=ze();return Cn(r,e.visitNode(n.left,U,e.isExpression),n.left),55===n.operatorToken.kind?kn(t,r,n.left):Nn(t,r,n.left),Cn(r,e.visitNode(n.right,U,e.isExpression),n.right),Je(t),r}function te(t){if(Ue(t.whenTrue)||Ue(t.whenFalse)){var r=qe(),a=qe(),i=ze();return kn(r,e.visitNode(t.condition,U,e.isExpression),t.condition),Cn(i,e.visitNode(t.whenTrue,U,e.isExpression),t.whenTrue),In(a),Je(r),Cn(i,e.visitNode(t.whenFalse,U,e.isExpression),t.whenFalse),Je(a),i}return e.visitEachChild(t,U,n)}function re(n){var t=qe(),r=e.visitNode(n.expression,U,e.isExpression);if(n.asteriskToken){var a=0===(8388608&e.getEmitFlags(n.expression))?e.setTextRange(_().createValuesHelper(r),n):r;Rn(a,n)}else On(r,n);return Je(t),Ln(n)}function ae(e){return ie(e.elements,void 0,void 0,e.multiLine)}function ie(n,t,r,a){var o,s=Ve(n);if(s>0){o=ze();var c=e.visitNodes(n,U,e.isExpression,0,s);Cn(o,m.createArrayLiteralExpression(t?i([t],c):c)),t=void 0}var l=e.reduceLeft(n,u,[],s);return o?m.createArrayConcatCall(o,[m.createArrayLiteralExpression(l,a)]):e.setTextRange(m.createArrayLiteralExpression(t?i([t],l):l,a),r);function u(n,r){if(Ue(r)&&n.length>0){var s=void 0!==o;o||(o=ze()),Cn(o,s?m.createArrayConcatCall(o,[m.createArrayLiteralExpression(n,a)]):m.createArrayLiteralExpression(t?i([t],n):n,a)),t=void 0,n=[]}return n.push(e.visitNode(r,U,e.isExpression)),n}}function oe(n){var t=n.properties,r=n.multiLine,a=Ve(t),i=ze();Cn(i,m.createObjectLiteralExpression(e.visitNodes(t,U,e.isObjectLiteralElementLike,0,a),r));var o=e.reduceLeft(t,s,[],a);return o.push(r?e.startOnNewLine(e.setParent(e.setTextRange(m.cloneNode(i),i),i.parent)):i),m.inlineExpressions(o);function s(t,a){Ue(a)&&t.length>0&&(An(m.createExpressionStatement(m.inlineExpressions(t))),t=[]);var o=e.createExpressionForObjectLiteralElementLike(m,n,a,i),s=e.visitNode(o,U,e.isExpression);return s&&(r&&e.startOnNewLine(s),t.push(s)),t}}function se(t){return Ue(t.argumentExpression)?m.updateElementAccessExpression(t,We(e.visitNode(t.expression,U,e.isLeftHandSideExpression)),e.visitNode(t.argumentExpression,U,e.isExpression)):e.visitEachChild(t,U,n)}function ce(t){if(!e.isImportCall(t)&&e.forEach(t.arguments,Ue)){var r=m.createCallBinding(t.expression,v,E,!0),a=r.target,i=r.thisArg;return e.setOriginalNode(e.setTextRange(m.createFunctionApplyCall(We(e.visitNode(a,U,e.isLeftHandSideExpression)),i,ie(t.arguments)),t),t)}return e.visitEachChild(t,U,n)}function le(t){if(e.forEach(t.arguments,Ue)){var r=m.createCallBinding(m.createPropertyAccessExpression(t.expression,"bind"),v),a=r.target,i=r.thisArg;return e.setOriginalNode(e.setTextRange(m.createNewExpression(m.createFunctionApplyCall(We(e.visitNode(a,U,e.isExpression)),i,ie(t.arguments,m.createVoidZero())),void 0,[]),t),t)}return e.visitEachChild(t,U,n)}function ue(e,n){void 0===n&&(n=0);for(var t=e.length,r=n;r<t;r++)pe(e[r])}function de(n){e.isBlock(n)?ue(n.statements):pe(n)}function pe(e){var n=o;o||(o=Ue(e)),fe(e),o=n}function fe(n){switch(n.kind){case 231:return me(n);case 234:return _e(n);case 235:return he(n);case 236:return ve(n);case 237:return Ee(n);case 238:return Se(n);case 239:return Le(n);case 241:return Ae(n);case 242:return Ie(n);case 243:return ke(n);case 244:return Oe(n);case 245:return we(n);case 246:return Me(n);case 247:return Ge(n);case 248:return Be(n);default:return An(e.visitNode(n,U,e.isStatement))}}function me(n){Ue(n)?ue(n.statements):An(e.visitNode(n,U,e.isStatement))}function _e(n){An(e.visitNode(n,U,e.isStatement))}function ge(n){for(var t=0,r=n.declarations;t<r.length;t++){var a=r[t],i=m.cloneNode(a.name);e.setCommentRange(i,a.name),v(i)}var o=e.getInitializedVariables(n),s=o.length,c=0,l=[];while(c<s){for(var u=c;u<s;u++){a=o[u];if(Ue(a.initializer)&&l.length>0)break;l.push(ye(a))}l.length&&(An(m.createExpressionStatement(m.inlineExpressions(l))),c+=l.length,l=[])}}function ye(n){return e.setSourceMapRange(m.createAssignment(e.setSourceMapRange(m.cloneNode(n.name),n.name),e.visitNode(n.initializer,U,e.isExpression)),n)}function he(n){if(Ue(n))if(Ue(n.thenStatement)||Ue(n.elseStatement)){var t=qe(),r=n.elseStatement?qe():void 0;kn(n.elseStatement?r:t,e.visitNode(n.expression,U,e.isExpression),n.expression),de(n.thenStatement),n.elseStatement&&(In(t),Je(r),de(n.elseStatement)),Je(t)}else An(e.visitNode(n,U,e.isStatement));else An(e.visitNode(n,U,e.isStatement))}function ve(n){if(Ue(n)){var t=qe(),r=qe();sn(t),Je(r),de(n.statement),Je(t),Nn(r,e.visitNode(n.expression,U,e.isExpression)),cn()}else An(e.visitNode(n,U,e.isStatement))}function be(t){return o?(on(),t=e.visitEachChild(t,U,n),cn(),t):e.visitEachChild(t,U,n)}function Ee(n){if(Ue(n)){var t=qe(),r=sn(t);Je(t),kn(r,e.visitNode(n.expression,U,e.isExpression)),de(n.statement),In(t),cn()}else An(e.visitNode(n,U,e.isStatement))}function Te(t){return o?(on(),t=e.visitEachChild(t,U,n),cn(),t):e.visitEachChild(t,U,n)}function Se(n){if(Ue(n)){var t=qe(),r=qe(),a=sn(r);if(n.initializer){var i=n.initializer;e.isVariableDeclarationList(i)?ge(i):An(e.setTextRange(m.createExpressionStatement(e.visitNode(i,U,e.isExpression)),i))}Je(t),n.condition&&kn(a,e.visitNode(n.condition,U,e.isExpression)),de(n.statement),Je(r),n.incrementor&&An(e.setTextRange(m.createExpressionStatement(e.visitNode(n.incrementor,U,e.isExpression)),n.incrementor)),In(t),cn()}else An(e.visitNode(n,U,e.isStatement))}function xe(t){o&&on();var r=t.initializer;if(r&&e.isVariableDeclarationList(r)){for(var a=0,i=r.declarations;a<i.length;a++){var s=i[a];v(s.name)}var c=e.getInitializedVariables(r);t=m.updateForStatement(t,c.length>0?m.inlineExpressions(e.map(c,ye)):void 0,e.visitNode(t.condition,U,e.isExpression),e.visitNode(t.incrementor,U,e.isExpression),e.visitIterationBody(t.statement,U,n))}else t=e.visitEachChild(t,U,n);return o&&cn(),t}function Le(n){if(Ue(n)){var t=ze(),r=ze(),a=m.createLoopVariable(),i=n.initializer;v(a),Cn(t,m.createArrayLiteralExpression()),An(m.createForInStatement(r,e.visitNode(n.expression,U,e.isExpression),m.createExpressionStatement(m.createCallExpression(m.createPropertyAccessExpression(t,"push"),void 0,[r])))),Cn(a,m.createNumericLiteral(0));var o=qe(),s=qe(),c=sn(s);Je(o),kn(c,m.createLessThan(a,m.createPropertyAccessExpression(t,"length")));var l=void 0;if(e.isVariableDeclarationList(i)){for(var u=0,d=i.declarations;u<d.length;u++){var p=d[u];v(p.name)}l=m.cloneNode(i.declarations[0].name)}else l=e.visitNode(i,U,e.isExpression),e.Debug.assert(e.isLeftHandSideExpression(l));Cn(l,m.createElementAccessExpression(t,a)),de(n.statement),Je(s),An(m.createExpressionStatement(m.createPostfixIncrement(a))),In(o),cn()}else An(e.visitNode(n,U,e.isStatement))}function De(t){o&&on();var r=t.initializer;if(e.isVariableDeclarationList(r)){for(var a=0,i=r.declarations;a<i.length;a++){var s=i[a];v(s.name)}t=m.updateForInStatement(t,r.declarations[0].name,e.visitNode(t.expression,U,e.isExpression),e.visitNode(t.statement,U,e.isStatement,m.liftToBlock))}else t=e.visitEachChild(t,U,n);return o&&cn(),t}function Ae(n){var t=bn(n.label?e.idText(n.label):void 0);t>0?In(t,n):An(n)}function Ce(t){if(o){var r=bn(t.label&&e.idText(t.label));if(r>0)return Sn(r,t)}return e.visitEachChild(t,U,n)}function Ie(n){var t=vn(n.label?e.idText(n.label):void 0);t>0?In(t,n):An(n)}function Ne(t){if(o){var r=vn(t.label&&e.idText(t.label));if(r>0)return Sn(r,t)}return e.visitEachChild(t,U,n)}function ke(n){wn(e.visitNode(n.expression,U,e.isExpression),n)}function Re(n){return xn(e.visitNode(n.expression,U,e.isExpression),n)}function Oe(n){Ue(n)?($e(We(e.visitNode(n.expression,U,e.isExpression))),de(n.statement),en()):An(e.visitNode(n,U,e.isStatement))}function we(n){if(Ue(n.caseBlock)){for(var t=n.caseBlock,r=t.clauses.length,a=un(),i=We(e.visitNode(n.expression,U,e.isExpression)),o=[],s=-1,c=0;c<r;c++){var l=t.clauses[c];o.push(qe()),286===l.kind&&-1===s&&(s=c)}var u=0,d=[];while(u<r){var p=0;for(c=u;c<r;c++){l=t.clauses[c];if(285===l.kind){if(Ue(l.expression)&&d.length>0)break;d.push(m.createCaseClause(e.visitNode(l.expression,U,e.isExpression),[Sn(o[c],l.expression)]))}else p++}d.length&&(An(m.createSwitchStatement(i,m.createCaseBlock(d))),u+=d.length,d=[]),p>0&&(u+=p,p=0)}In(s>=0?o[s]:a);for(c=0;c<r;c++)Je(o[c]),ue(t.clauses[c].statements);dn()}else An(e.visitNode(n,U,e.isStatement))}function Pe(t){return o&&ln(),t=e.visitEachChild(t,U,n),o&&dn(),t}function Me(n){Ue(n)?(fn(e.idText(n.label)),de(n.statement),mn()):An(e.visitNode(n,U,e.isStatement))}function Fe(t){return o&&pn(e.idText(t.label)),t=e.visitEachChild(t,U,n),o&&mn(),t}function Ge(n){var t;Pn(e.visitNode(null!==(t=n.expression)&&void 0!==t?t:m.createVoidZero(),U,e.isExpression),n)}function Be(t){Ue(t)?(nn(),de(t.tryBlock),t.catchClause&&(tn(t.catchClause.variableDeclaration),de(t.catchClause.block)),t.finallyBlock&&(rn(),de(t.finallyBlock)),an()):An(e.visitEachChild(t,U,n))}function Ue(e){return!!e&&0!==(524288&e.transformFlags)}function Ve(e){for(var n=e.length,t=0;t<n;t++)if(Ue(e[t]))return t;return-1}function je(e,n){return n=S(e,n),1===e?Ke(n):n}function Ke(n){return e.isIdentifier(n)?He(n):n}function He(n){if(!e.isGeneratedIdentifier(n)&&t&&t.has(e.idText(n))){var a=e.getOriginalNode(n);if(e.isIdentifier(a)&&a.parent){var i=T.getReferencedValueDeclaration(a);if(i){var o=r[e.getOriginalNodeId(i)];if(o){var s=e.setParent(e.setTextRange(m.cloneNode(o),o),o.parent);return e.setSourceMapRange(s,n),e.setCommentRange(s,n),s}}}}return n}function We(n){if(e.isGeneratedIdentifier(n)||4096&e.getEmitFlags(n))return n;var t=m.createTempVariable(v);return Cn(t,n,n),t}function ze(e){var n=e?m.createUniqueName(e):m.createTempVariable(void 0);return v(n),n}function qe(){p||(p=[]);var e=M;return M++,p[e]=-1,e}function Je(n){e.Debug.assert(void 0!==p,"No labels were defined."),p[n]=x?x.length:0}function Xe(e){c||(c=[],u=[],l=[],d=[]);var n=u.length;return u[n]=0,l[n]=x?x.length:0,c[n]=e,d.push(e),n}function Ye(){var n=Qe();if(void 0===n)return e.Debug.fail("beginBlock was never called.");var t=u.length;return u[t]=1,l[t]=x?x.length:0,c[t]=n,d.pop(),n}function Qe(){return e.lastOrUndefined(d)}function Ze(){var e=Qe();return e&&e.kind}function $e(e){var n=qe(),t=qe();Je(n),Xe({kind:1,expression:e,startLabel:n,endLabel:t})}function en(){e.Debug.assert(1===Ze());var n=Ye();Je(n.endLabel)}function nn(){var e=qe(),n=qe();return Je(e),Xe({kind:0,state:0,startLabel:e,endLabel:n}),Dn(),n}function tn(a){var i;if(e.Debug.assert(0===Ze()),e.isGeneratedIdentifier(a.name))i=a.name,v(a.name);else{var o=e.idText(a.name);i=ze(o),t||(t=new e.Map,r=[],n.enableSubstitution(78)),t.set(o,!0),r[e.getOriginalNodeId(a)]=i}var s=Qe();e.Debug.assert(s.state<1);var c=s.endLabel;In(c);var l=qe();Je(l),s.state=1,s.catchVariable=i,s.catchLabel=l,Cn(i,m.createCallExpression(m.createPropertyAccessExpression(A,"sent"),void 0,[])),Dn()}function rn(){e.Debug.assert(0===Ze());var n=Qe();e.Debug.assert(n.state<2);var t=n.endLabel;In(t);var r=qe();Je(r),n.state=2,n.finallyLabel=r}function an(){e.Debug.assert(0===Ze());var n=Ye(),t=n.state;t<2?In(n.endLabel):Mn(),Je(n.endLabel),Dn(),n.state=3}function on(){Xe({kind:3,isScript:!0,breakLabel:-1,continueLabel:-1})}function sn(e){var n=qe();return Xe({kind:3,isScript:!1,breakLabel:n,continueLabel:e}),n}function cn(){e.Debug.assert(3===Ze());var n=Ye(),t=n.breakLabel;n.isScript||Je(t)}function ln(){Xe({kind:2,isScript:!0,breakLabel:-1})}function un(){var e=qe();return Xe({kind:2,isScript:!1,breakLabel:e}),e}function dn(){e.Debug.assert(2===Ze());var n=Ye(),t=n.breakLabel;n.isScript||Je(t)}function pn(e){Xe({kind:4,isScript:!0,labelText:e,breakLabel:-1})}function fn(e){var n=qe();Xe({kind:4,isScript:!1,labelText:e,breakLabel:n})}function mn(){e.Debug.assert(4===Ze());var n=Ye();n.isScript||Je(n.breakLabel)}function _n(e){return 2===e.kind||3===e.kind}function gn(e){return 4===e.kind}function yn(e){return 3===e.kind}function hn(e,n){for(var t=n;t>=0;t--){var r=d[t];if(!gn(r))break;if(r.labelText===e)return!0}return!1}function vn(e){if(d)if(e)for(var n=d.length-1;n>=0;n--){var t=d[n];if(gn(t)&&t.labelText===e)return t.breakLabel;if(_n(t)&&hn(e,n-1))return t.breakLabel}else for(n=d.length-1;n>=0;n--){t=d[n];if(_n(t))return t.breakLabel}return 0}function bn(e){if(d)if(e)for(var n=d.length-1;n>=0;n--){var t=d[n];if(yn(t)&&hn(e,n-1))return t.continueLabel}else for(n=d.length-1;n>=0;n--){t=d[n];if(yn(t))return t.continueLabel}return 0}function En(e){if(void 0!==e&&e>0){void 0===f&&(f=[]);var n=m.createNumericLiteral(-1);return void 0===f[e]?f[e]=[n]:f[e].push(n),n}return m.createOmittedExpression()}function Tn(n){var t=m.createNumericLiteral(n);return e.addSyntheticTrailingComment(t,3,s(n)),t}function Sn(n,t){return e.Debug.assertLessThan(0,n,"Invalid label"),e.setTextRange(m.createReturnStatement(m.createArrayLiteralExpression([Tn(3),En(n)])),t)}function xn(n,t){return e.setTextRange(m.createReturnStatement(m.createArrayLiteralExpression(n?[Tn(2),n]:[Tn(2)])),t)}function Ln(n){return e.setTextRange(m.createCallExpression(m.createPropertyAccessExpression(A,"sent"),void 0,[]),n)}function Dn(){Fn(0)}function An(e){e?Fn(1,[e]):Dn()}function Cn(e,n,t){Fn(2,[e,n],t)}function In(e,n){Fn(3,[e],n)}function Nn(e,n,t){Fn(4,[e,n],t)}function kn(e,n,t){Fn(5,[e,n],t)}function Rn(e,n){Fn(7,[e],n)}function On(e,n){Fn(6,[e],n)}function wn(e,n){Fn(8,[e],n)}function Pn(e,n){Fn(9,[e],n)}function Mn(){Fn(10)}function Fn(e,n,t){void 0===x&&(x=[],L=[],D=[]),void 0===p&&Je(qe());var r=x.length;x[r]=e,L[r]=n,D[r]=t}function Gn(){F=0,G=0,C=void 0,I=!1,N=!1,k=void 0,R=void 0,O=void 0,w=void 0,P=void 0;var n=Bn();return _().createGeneratorHelper(e.setEmitFlags(m.createFunctionExpression(void 0,void 0,void 0,void 0,[m.createParameterDeclaration(void 0,void 0,void 0,A)],void 0,m.createBlock(n,n.length>0)),524288))}function Bn(){if(x){for(var n=0;n<x.length;n++)qn(n);Vn(x.length)}else Vn(0);if(k){var t=m.createPropertyAccessExpression(A,"label"),r=m.createSwitchStatement(t,m.createCaseBlock(k));return[e.startOnNewLine(r)]}return R||[]}function Un(){R&&(Kn(!I),I=!1,N=!1,G++)}function Vn(e){jn(e)&&(Hn(e),P=void 0,Qn(void 0,void 0)),R&&k&&Kn(!1),Wn()}function jn(e){if(!N)return!0;if(!p||!f)return!1;for(var n=0;n<p.length;n++)if(p[n]===e&&f[n])return!0;return!1}function Kn(e){if(k||(k=[]),R){if(P)for(var n=P.length-1;n>=0;n--){var t=P[n];R=[m.createWithStatement(t.expression,m.createBlock(R))]}if(w){var r=w.startLabel,a=w.catchLabel,i=w.finallyLabel,o=w.endLabel;R.unshift(m.createExpressionStatement(m.createCallExpression(m.createPropertyAccessExpression(m.createPropertyAccessExpression(A,"trys"),"push"),void 0,[m.createArrayLiteralExpression([En(r),En(a),En(i),En(o)])]))),w=void 0}e&&R.push(m.createExpressionStatement(m.createAssignment(m.createPropertyAccessExpression(A,"label"),m.createNumericLiteral(G+1))))}k.push(m.createCaseClause(m.createNumericLiteral(G),R||[])),R=void 0}function Hn(e){if(p)for(var n=0;n<p.length;n++)p[n]===e&&(Un(),void 0===C&&(C=[]),void 0===C[G]?C[G]=[n]:C[G].push(n))}function Wn(){if(void 0!==f&&void 0!==C)for(var e=0;e<C.length;e++){var n=C[e];if(void 0!==n)for(var t=0,r=n;t<r.length;t++){var a=r[t],i=f[a];if(void 0!==i)for(var o=0,s=i;o<s.length;o++){var c=s[o];c.text=String(e)}}}}function zn(e){if(c)for(;F<u.length&&l[F]<=e;F++){var n=c[F],t=u[F];switch(n.kind){case 0:0===t?(O||(O=[]),R||(R=[]),O.push(w),w=n):1===t&&(w=O.pop());break;case 1:0===t?(P||(P=[]),P.push(n)):1===t&&P.pop();break}}}function qn(e){if(Hn(e),zn(e),!I){I=!1,N=!1;var n=x[e];if(0!==n){if(10===n)return rt();var t=L[e];if(1===n)return Jn(t[0]);var r=D[e];switch(n){case 2:return Xn(t[0],t[1],r);case 3:return Zn(t[0],r);case 4:return $n(t[0],t[1],r);case 5:return et(t[0],t[1],r);case 6:return nt(t[0],r);case 7:return tt(t[0],r);case 8:return Qn(t[0],r);case 9:return Yn(t[0],r)}}}}function Jn(e){e&&(R?R.push(e):R=[e])}function Xn(n,t,r){Jn(e.setTextRange(m.createExpressionStatement(m.createAssignment(n,t)),r))}function Yn(n,t){I=!0,N=!0,Jn(e.setTextRange(m.createThrowStatement(n),t))}function Qn(n,t){I=!0,N=!0,Jn(e.setEmitFlags(e.setTextRange(m.createReturnStatement(m.createArrayLiteralExpression(n?[Tn(2),n]:[Tn(2)])),t),384))}function Zn(n,t){I=!0,Jn(e.setEmitFlags(e.setTextRange(m.createReturnStatement(m.createArrayLiteralExpression([Tn(3),En(n)])),t),384))}function $n(n,t,r){Jn(e.setEmitFlags(m.createIfStatement(t,e.setEmitFlags(e.setTextRange(m.createReturnStatement(m.createArrayLiteralExpression([Tn(3),En(n)])),r),384)),1))}function et(n,t,r){Jn(e.setEmitFlags(m.createIfStatement(m.createLogicalNot(t),e.setEmitFlags(e.setTextRange(m.createReturnStatement(m.createArrayLiteralExpression([Tn(3),En(n)])),r),384)),1))}function nt(n,t){I=!0,Jn(e.setEmitFlags(e.setTextRange(m.createReturnStatement(m.createArrayLiteralExpression(n?[Tn(4),n]:[Tn(4)])),t),384))}function tt(n,t){I=!0,Jn(e.setEmitFlags(e.setTextRange(m.createReturnStatement(m.createArrayLiteralExpression([Tn(5),n])),t),384))}function rt(){I=!0,Jn(m.createReturnStatement(m.createArrayLiteralExpression([Tn(7)])))}}(function(e){e[e["Nop"]=0]="Nop",e[e["Statement"]=1]="Statement",e[e["Assign"]=2]="Assign",e[e["Break"]=3]="Break",e[e["BreakWhenTrue"]=4]="BreakWhenTrue",e[e["BreakWhenFalse"]=5]="BreakWhenFalse",e[e["Yield"]=6]="Yield",e[e["YieldStar"]=7]="YieldStar",e[e["Return"]=8]="Return",e[e["Throw"]=9]="Throw",e[e["Endfinally"]=10]="Endfinally"})(n||(n={})),function(e){e[e["Open"]=0]="Open",e[e["Close"]=1]="Close"}(t||(t={})),function(e){e[e["Exception"]=0]="Exception",e[e["With"]=1]="With",e[e["Switch"]=2]="Switch",e[e["Loop"]=3]="Loop",e[e["Labeled"]=4]="Labeled"}(r||(r={})),function(e){e[e["Try"]=0]="Try",e[e["Catch"]=1]="Catch",e[e["Finally"]=2]="Finally",e[e["Done"]=3]="Done"}(a||(a={})),function(e){e[e["Next"]=0]="Next",e[e["Throw"]=1]="Throw",e[e["Return"]=2]="Return",e[e["Break"]=3]="Break",e[e["Yield"]=4]="Yield",e[e["YieldStar"]=5]="YieldStar",e[e["Catch"]=6]="Catch",e[e["Endfinally"]=7]="Endfinally"}(o||(o={})),e.transformGenerators=c}(d||(d={})),function(e){function n(n){function r(n){switch(n){case e.ModuleKind.AMD:return D;case e.ModuleKind.UMD:return A;default:return L}}var a=n.factory,o=n.getEmitHelperFactory,s=n.startLexicalEnvironment,c=n.endLexicalEnvironment,l=n.hoistVariableDeclaration,u=n.getCompilerOptions(),d=n.getEmitResolver(),p=n.getEmitHost(),f=e.getEmitScriptTarget(u),m=e.getEmitModuleKind(u),_=n.onSubstituteNode,g=n.onEmitNode;n.onSubstituteNode=fe,n.onEmitNode=pe,n.enableSubstitution(78),n.enableSubstitution(217),n.enableSubstitution(215),n.enableSubstitution(216),n.enableSubstitution(290),n.enableEmitNotification(298);var y,h,v,b,E=[],T=[];return e.chainBundle(n,S);function S(t){if(t.isDeclarationFile||!(e.isEffectiveExternalModule(t,u)||4194304&t.transformFlags||e.isJsonSourceFile(t)&&e.hasJsonModuleEmitEnabled(u)&&e.outFile(u)))return t;y=t,h=e.collectExternalModuleInfo(n,t,d,u),E[e.getOriginalNodeId(t)]=h;var a=r(m),i=a(t);return y=void 0,h=void 0,b=!1,i}function x(){return!(h.exportEquals||!e.isExternalModule(y))}function L(t){s();var r=[],i=e.getStrictOptionValue(u,"alwaysStrict")||!u.noImplicitUseStrict&&e.isExternalModule(y),o=a.copyPrologue(t.statements,r,i&&!e.isJsonSourceFile(t),R);if(x()&&e.append(r,ce()),e.length(h.exportedNames))for(var l=50,d=0;d<h.exportedNames.length;d+=l)e.append(r,a.createExpressionStatement(e.reduceLeft(h.exportedNames.slice(d,d+l),(function(n,t){return a.createAssignment(a.createPropertyAccessExpression(a.createIdentifier("exports"),a.createIdentifier(e.idText(t))),n)}),a.createVoidZero())));e.append(r,e.visitNode(h.externalHelpersImportDeclaration,R,e.isStatement)),e.addRange(r,e.visitNodes(t.statements,R,e.isStatement,o)),k(r,!1),e.insertStatementsAfterStandardPrologue(r,c());var p=a.updateSourceFile(t,e.setTextRange(a.createNodeArray(r),t.statements));return e.addEmitHelpers(p,n.readEmitHelpers()),p}function D(t){var r=a.createIdentifier("define"),o=e.tryGetModuleNameFromFile(a,t,p,u),s=e.isJsonSourceFile(t)&&t,c=C(t,!0),l=c.aliasedModuleNames,d=c.unaliasedModuleNames,f=c.importAliasNames,m=a.updateSourceFile(t,e.setTextRange(a.createNodeArray([a.createExpressionStatement(a.createCallExpression(r,void 0,i(i([],o?[o]:[]),[a.createArrayLiteralExpression(s?e.emptyArray:i(i([a.createStringLiteral("require"),a.createStringLiteral("exports")],l),d)),s?s.statements.length?s.statements[0].expression:a.createObjectLiteralExpression():a.createFunctionExpression(void 0,void 0,void 0,void 0,i([a.createParameterDeclaration(void 0,void 0,void 0,"require"),a.createParameterDeclaration(void 0,void 0,void 0,"exports")],f),void 0,N(t))])))]),t.statements));return e.addEmitHelpers(m,n.readEmitHelpers()),m}function A(t){var r=C(t,!1),o=r.aliasedModuleNames,s=r.unaliasedModuleNames,c=r.importAliasNames,l=e.tryGetModuleNameFromFile(a,t,p,u),d=a.createFunctionExpression(void 0,void 0,void 0,void 0,[a.createParameterDeclaration(void 0,void 0,void 0,"factory")],void 0,e.setTextRange(a.createBlock([a.createIfStatement(a.createLogicalAnd(a.createTypeCheck(a.createIdentifier("module"),"object"),a.createTypeCheck(a.createPropertyAccessExpression(a.createIdentifier("module"),"exports"),"object")),a.createBlock([a.createVariableStatement(void 0,[a.createVariableDeclaration("v",void 0,void 0,a.createCallExpression(a.createIdentifier("factory"),void 0,[a.createIdentifier("require"),a.createIdentifier("exports")]))]),e.setEmitFlags(a.createIfStatement(a.createStrictInequality(a.createIdentifier("v"),a.createIdentifier("undefined")),a.createExpressionStatement(a.createAssignment(a.createPropertyAccessExpression(a.createIdentifier("module"),"exports"),a.createIdentifier("v")))),1)]),a.createIfStatement(a.createLogicalAnd(a.createTypeCheck(a.createIdentifier("define"),"function"),a.createPropertyAccessExpression(a.createIdentifier("define"),"amd")),a.createBlock([a.createExpressionStatement(a.createCallExpression(a.createIdentifier("define"),void 0,i(i([],l?[l]:[]),[a.createArrayLiteralExpression(i(i([a.createStringLiteral("require"),a.createStringLiteral("exports")],o),s)),a.createIdentifier("factory")])))])))],!0),void 0)),f=a.updateSourceFile(t,e.setTextRange(a.createNodeArray([a.createExpressionStatement(a.createCallExpression(d,void 0,[a.createFunctionExpression(void 0,void 0,void 0,void 0,i([a.createParameterDeclaration(void 0,void 0,void 0,"require"),a.createParameterDeclaration(void 0,void 0,void 0,"exports")],c),void 0,N(t))]))]),t.statements));return e.addEmitHelpers(f,n.readEmitHelpers()),f}function C(n,t){for(var r=[],i=[],o=[],s=0,c=n.amdDependencies;s<c.length;s++){var l=c[s];l.name?(r.push(a.createStringLiteral(l.path)),o.push(a.createParameterDeclaration(void 0,void 0,void 0,l.name))):i.push(a.createStringLiteral(l.path))}for(var f=0,m=h.externalImports;f<m.length;f++){var _=m[f],g=e.getExternalModuleNameLiteral(a,_,y,p,d,u),v=e.getLocalNameForExternalImport(a,_,y);g&&(t&&v?(e.setEmitFlags(v,4),r.push(g),o.push(a.createParameterDeclaration(void 0,void 0,void 0,v))):i.push(g))}return{aliasedModuleNames:r,unaliasedModuleNames:i,importAliasNames:o}}function I(n){if(!e.isImportEqualsDeclaration(n)&&!e.isExportDeclaration(n)&&e.getExternalModuleNameLiteral(a,n,y,p,d,u)){var t=e.getLocalNameForExternalImport(a,n,y),r=V(n,t);if(r!==t)return a.createExpressionStatement(a.createAssignment(t,r))}}function N(n){s();var r=[],i=a.copyPrologue(n.statements,r,!u.noImplicitUseStrict,R);x()&&e.append(r,ce()),e.length(h.exportedNames)&&e.append(r,a.createExpressionStatement(e.reduceLeft(h.exportedNames,(function(n,t){return a.createAssignment(a.createPropertyAccessExpression(a.createIdentifier("exports"),a.createIdentifier(e.idText(t))),n)}),a.createVoidZero()))),e.append(r,e.visitNode(h.externalHelpersImportDeclaration,R,e.isStatement)),m===e.ModuleKind.AMD&&e.addRange(r,e.mapDefined(h.externalImports,I)),e.addRange(r,e.visitNodes(n.statements,R,e.isStatement,i)),k(r,!0),e.insertStatementsAfterStandardPrologue(r,c());var o=a.createBlock(r,!0);return b&&e.addEmitHelper(o,t),o}function k(n,t){if(h.exportEquals){var r=e.visitNode(h.exportEquals.expression,O);if(r)if(t){var i=a.createReturnStatement(r);e.setTextRange(i,h.exportEquals),e.setEmitFlags(i,1920),n.push(i)}else{i=a.createExpressionStatement(a.createAssignment(a.createPropertyAccessExpression(a.createIdentifier("module"),"exports"),r));e.setTextRange(i,h.exportEquals),e.setEmitFlags(i,1536),n.push(i)}}}function R(t){switch(t.kind){case 262:return j(t);case 261:return H(t);case 268:return W(t);case 267:return z(t);case 233:return X(t);case 252:return q(t);case 253:return J(t);case 342:return Z(t);case 343:return ee(t);default:return e.visitEachChild(t,O,n)}}function O(t){return 4194304&t.transformFlags||2048&t.transformFlags?e.isImportCall(t)?M(t):e.isDestructuringAssignment(t)?P(t):e.visitEachChild(t,O,n):t}function w(n){if(e.isObjectLiteralExpression(n))for(var t=0,r=n.properties;t<r.length;t++){var a=r[t];switch(a.kind){case 289:if(w(a.initializer))return!0;break;case 290:if(w(a.name))return!0;break;case 291:if(w(a.expression))return!0;break;case 166:case 168:case 169:return!1;default:e.Debug.assertNever(a,"Unhandled object member kind")}}else if(e.isArrayLiteralExpression(n))for(var i=0,o=n.elements;i<o.length;i++){a=o[i];if(e.isSpreadElement(a)){if(w(a.expression))return!0}else if(w(a))return!0}else if(e.isIdentifier(n))return e.length(ve(n))>(e.isExportName(n)?1:0);return!1}function P(t){return w(t.left)?e.flattenDestructuringAssignment(t,O,n,0,!1,Y):e.visitEachChild(t,O,n)}function M(n){var t=e.getExternalModuleNameLiteral(a,n,y,p,d,u),r=e.visitNode(e.firstOrUndefined(n.arguments),O),i=!t||r&&e.isStringLiteral(r)&&r.text===t.text?r:t,o=!!(8192&n.transformFlags);switch(u.module){case e.ModuleKind.AMD:return G(i,o);case e.ModuleKind.UMD:return F(null!==i&&void 0!==i?i:a.createVoidZero(),o);case e.ModuleKind.CommonJS:default:return B(i,o)}}function F(n,t){if(b=!0,e.isSimpleCopiableExpression(n)){var r=e.isGeneratedIdentifier(n)?n:e.isStringLiteral(n)?a.createStringLiteralFromNode(n):e.setEmitFlags(e.setTextRange(a.cloneNode(n),n),1536);return a.createConditionalExpression(a.createIdentifier("__syncRequire"),void 0,B(n,t),void 0,G(r,t))}var i=a.createTempVariable(l);return a.createComma(a.createAssignment(i,n),a.createConditionalExpression(a.createIdentifier("__syncRequire"),void 0,B(i,t),void 0,G(i,t)))}function G(n,t){var r,i=a.createUniqueName("resolve"),s=a.createUniqueName("reject"),c=[a.createParameterDeclaration(void 0,void 0,void 0,i),a.createParameterDeclaration(void 0,void 0,void 0,s)],l=a.createBlock([a.createExpressionStatement(a.createCallExpression(a.createIdentifier("require"),void 0,[a.createArrayLiteralExpression([n||a.createOmittedExpression()]),i,s]))]);f>=2?r=a.createArrowFunction(void 0,void 0,c,void 0,void 0,l):(r=a.createFunctionExpression(void 0,void 0,void 0,void 0,c,void 0,l),t&&e.setEmitFlags(r,8));var d=a.createNewExpression(a.createIdentifier("Promise"),void 0,[r]);return u.esModuleInterop?a.createCallExpression(a.createPropertyAccessExpression(d,a.createIdentifier("then")),void 0,[o().createImportStarCallbackHelper()]):d}function B(n,t){var r,i=a.createCallExpression(a.createPropertyAccessExpression(a.createIdentifier("Promise"),"resolve"),void 0,[]),s=a.createCallExpression(a.createIdentifier("require"),void 0,n?[n]:[]);return u.esModuleInterop&&(s=o().createImportStarHelper(s)),f>=2?r=a.createArrowFunction(void 0,void 0,[],void 0,void 0,s):(r=a.createFunctionExpression(void 0,void 0,void 0,void 0,[],void 0,a.createBlock([a.createReturnStatement(s)])),t&&e.setEmitFlags(r,8)),a.createCallExpression(a.createPropertyAccessExpression(i,"then"),void 0,[r])}function U(n,t){return!u.esModuleInterop||67108864&e.getEmitFlags(n)?t:e.getExportNeedsImportStarHelper(n)?o().createImportStarHelper(t):t}function V(n,t){return!u.esModuleInterop||67108864&e.getEmitFlags(n)?t:e.getImportNeedsImportStarHelper(n)?o().createImportStarHelper(t):e.getImportNeedsImportDefaultHelper(n)?o().createImportDefaultHelper(t):t}function j(n){var t,r=e.getNamespaceDeclarationNode(n);if(m!==e.ModuleKind.AMD){if(!n.importClause)return e.setOriginalNode(e.setTextRange(a.createExpressionStatement(K(n)),n),n);var i=[];r&&!e.isDefaultImport(n)?i.push(a.createVariableDeclaration(a.cloneNode(r.name),void 0,void 0,V(n,K(n)))):(i.push(a.createVariableDeclaration(a.getGeneratedNameForNode(n),void 0,void 0,V(n,K(n)))),r&&e.isDefaultImport(n)&&i.push(a.createVariableDeclaration(a.cloneNode(r.name),void 0,void 0,a.getGeneratedNameForNode(n)))),t=e.append(t,e.setOriginalNode(e.setTextRange(a.createVariableStatement(void 0,a.createVariableDeclarationList(i,f>=2?2:0)),n),n))}else r&&e.isDefaultImport(n)&&(t=e.append(t,a.createVariableStatement(void 0,a.createVariableDeclarationList([e.setOriginalNode(e.setTextRange(a.createVariableDeclaration(a.cloneNode(r.name),void 0,void 0,a.getGeneratedNameForNode(n)),n),n)],f>=2?2:0))));if($(n)){var o=e.getOriginalNodeId(n);T[o]=ne(T[o],n)}else t=ne(t,n);return e.singleOrMany(t)}function K(n){var t=e.getExternalModuleNameLiteral(a,n,y,p,d,u),r=[];return t&&r.push(t),a.createCallExpression(a.createIdentifier("require"),void 0,r)}function H(n){var t;if(e.Debug.assert(e.isExternalModuleImportEqualsDeclaration(n),"import= for internal module references should be handled in an earlier transformer."),m!==e.ModuleKind.AMD?t=e.hasSyntacticModifier(n,1)?e.append(t,e.setOriginalNode(e.setTextRange(a.createExpressionStatement(ue(n.name,K(n))),n),n)):e.append(t,e.setOriginalNode(e.setTextRange(a.createVariableStatement(void 0,a.createVariableDeclarationList([a.createVariableDeclaration(a.cloneNode(n.name),void 0,void 0,K(n))],f>=2?2:0)),n),n)):e.hasSyntacticModifier(n,1)&&(t=e.append(t,e.setOriginalNode(e.setTextRange(a.createExpressionStatement(ue(a.getExportName(n),a.getLocalName(n))),n),n))),$(n)){var r=e.getOriginalNodeId(n);T[r]=te(T[r],n)}else t=te(t,n);return e.singleOrMany(t)}function W(n){if(n.moduleSpecifier){var t=a.getGeneratedNameForNode(n);if(n.exportClause&&e.isNamedExports(n.exportClause)){var r=[];m!==e.ModuleKind.AMD&&r.push(e.setOriginalNode(e.setTextRange(a.createVariableStatement(void 0,a.createVariableDeclarationList([a.createVariableDeclaration(t,void 0,void 0,K(n))])),n),n));for(var i=0,s=n.exportClause.elements;i<s.length;i++){var c=s[i];if(0===f)r.push(e.setOriginalNode(e.setTextRange(a.createExpressionStatement(o().createCreateBindingHelper(t,a.createStringLiteralFromNode(c.propertyName||c.name),c.propertyName?a.createStringLiteralFromNode(c.name):void 0)),c),c));else{var l=!!u.esModuleInterop&&!(67108864&e.getEmitFlags(n))&&"default"===e.idText(c.propertyName||c.name),d=a.createPropertyAccessExpression(l?o().createImportDefaultHelper(t):t,c.propertyName||c.name);r.push(e.setOriginalNode(e.setTextRange(a.createExpressionStatement(ue(a.getExportName(c),d,void 0,!0)),c),c))}}return e.singleOrMany(r)}if(n.exportClause){r=[];return r.push(e.setOriginalNode(e.setTextRange(a.createExpressionStatement(ue(a.cloneNode(n.exportClause.name),U(n,m!==e.ModuleKind.AMD?K(n):e.isExportNamespaceAsDefaultDeclaration(n)?t:a.createIdentifier(e.idText(n.exportClause.name))))),n),n)),e.singleOrMany(r)}return e.setOriginalNode(e.setTextRange(a.createExpressionStatement(o().createExportStarHelper(m!==e.ModuleKind.AMD?K(n):t)),n),n)}}function z(n){if(!n.isExportEquals){var t,r=n.original;if(r&&$(r)){var i=e.getOriginalNodeId(n);T[i]=se(T[i],a.createIdentifier("default"),e.visitNode(n.expression,O),n,!0)}else t=se(t,a.createIdentifier("default"),e.visitNode(n.expression,O),n,!0);return e.singleOrMany(t)}}function q(t){var r;if(r=e.hasSyntacticModifier(t,1)?e.append(r,e.setOriginalNode(e.setTextRange(a.createFunctionDeclaration(void 0,e.visitNodes(t.modifiers,de,e.isModifier),t.asteriskToken,a.getDeclarationName(t,!0,!0),void 0,e.visitNodes(t.parameters,O),void 0,e.visitEachChild(t.body,O,n)),t),t)):e.append(r,e.visitEachChild(t,O,n)),$(t)){var i=e.getOriginalNodeId(t);T[i]=ie(T[i],t)}else r=ie(r,t);return e.singleOrMany(r)}function J(t){var r;if(r=e.hasSyntacticModifier(t,1)?e.append(r,e.setOriginalNode(e.setTextRange(a.createClassDeclaration(void 0,e.visitNodes(t.modifiers,de,e.isModifier),a.getDeclarationName(t,!0,!0),void 0,e.visitNodes(t.heritageClauses,O),e.visitNodes(t.members,O)),t),t)):e.append(r,e.visitEachChild(t,O,n)),$(t)){var i=e.getOriginalNodeId(t);T[i]=ie(T[i],t)}else r=ie(r,t);return e.singleOrMany(r)}function X(t){var r,i,o;if(e.hasSyntacticModifier(t,1)){for(var s=void 0,c=!1,l=0,u=t.declarationList.declarations;l<u.length;l++){var d=u[l];if(e.isIdentifier(d.name)&&e.isLocalName(d.name))s||(s=e.visitNodes(t.modifiers,de,e.isModifier)),i=e.append(i,d);else if(d.initializer)if(!e.isBindingPattern(d.name)&&(e.isArrowFunction(d.initializer)||e.isFunctionExpression(d.initializer)||e.isClassExpression(d.initializer))){var p=a.createAssignment(e.setTextRange(a.createPropertyAccessExpression(a.createIdentifier("exports"),d.name),d.name),a.createIdentifier(e.getTextOfIdentifierOrLiteral(d.name))),f=a.createVariableDeclaration(d.name,d.exclamationToken,d.type,e.visitNode(d.initializer,O));i=e.append(i,f),o=e.append(o,p),c=!0}else o=e.append(o,Q(d))}if(i&&(r=e.append(r,a.updateVariableStatement(t,s,a.updateVariableDeclarationList(t.declarationList,i)))),o){var m=e.setOriginalNode(e.setTextRange(a.createExpressionStatement(a.inlineExpressions(o)),t),t);c&&e.removeAllComments(m),r=e.append(r,m)}}else r=e.append(r,e.visitEachChild(t,O,n));if($(t)){var _=e.getOriginalNodeId(t);T[_]=re(T[_],t)}else r=re(r,t);return e.singleOrMany(r)}function Y(n,t,r){var i=ve(n);if(i){for(var o=e.isExportName(n)?t:a.createAssignment(n,t),s=0,c=i;s<c.length;s++){var l=c[s];e.setEmitFlags(o,4),o=ue(l,o,r)}return o}return a.createAssignment(n,t)}function Q(t){return e.isBindingPattern(t.name)?e.flattenDestructuringAssignment(e.visitNode(t,O),void 0,n,0,!1,Y):a.createAssignment(e.setTextRange(a.createPropertyAccessExpression(a.createIdentifier("exports"),t.name),t.name),t.initializer?e.visitNode(t.initializer,O):a.createVoidZero())}function Z(n){if($(n)&&233===n.original.kind){var t=e.getOriginalNodeId(n);T[t]=re(T[t],n.original)}return n}function $(n){return 0!==(4194304&e.getEmitFlags(n))}function ee(n){var t=e.getOriginalNodeId(n),r=T[t];return r?(delete T[t],e.append(r,n)):n}function ne(e,n){if(h.exportEquals)return e;var t=n.importClause;if(!t)return e;t.name&&(e=oe(e,t));var r=t.namedBindings;if(r)switch(r.kind){case 264:e=oe(e,r);break;case 265:for(var a=0,i=r.elements;a<i.length;a++){var o=i[a];e=oe(e,o,!0)}break}return e}function te(e,n){return h.exportEquals?e:oe(e,n)}function re(e,n){if(h.exportEquals)return e;for(var t=0,r=n.declarationList.declarations;t<r.length;t++){var a=r[t];e=ae(e,a)}return e}function ae(n,t){if(h.exportEquals)return n;if(e.isBindingPattern(t.name))for(var r=0,a=t.name.elements;r<a.length;r++){var i=a[r];e.isOmittedExpression(i)||(n=ae(n,i))}else e.isGeneratedIdentifier(t.name)||(n=oe(n,t));return n}function ie(n,t){if(h.exportEquals)return n;if(e.hasSyntacticModifier(t,1)){var r=e.hasSyntacticModifier(t,512)?a.createIdentifier("default"):a.getDeclarationName(t);n=se(n,r,a.getLocalName(t),t)}return t.name&&(n=oe(n,t)),n}function oe(n,t,r){var i=a.getDeclarationName(t),o=h.exportSpecifiers.get(e.idText(i));if(o)for(var s=0,c=o;s<c.length;s++){var l=c[s];n=se(n,l.name,i,l.name,void 0,r)}return n}function se(n,t,r,a,i,o){return n=e.append(n,le(t,r,a,i,o)),n}function ce(){var n;return n=0===f?a.createExpressionStatement(ue(a.createIdentifier("__esModule"),a.createTrue())):a.createExpressionStatement(a.createCallExpression(a.createPropertyAccessExpression(a.createIdentifier("Object"),"defineProperty"),void 0,[a.createIdentifier("exports"),a.createStringLiteral("__esModule"),a.createObjectLiteralExpression([a.createPropertyAssignment("value",a.createTrue())])])),e.setEmitFlags(n,1048576),n}function le(n,t,r,i,o){var s=e.setTextRange(a.createExpressionStatement(ue(n,t,void 0,o)),r);return e.startOnNewLine(s),i||e.setEmitFlags(s,1536),s}function ue(n,t,r,i){return e.setTextRange(i&&0!==f?a.createCallExpression(a.createPropertyAccessExpression(a.createIdentifier("Object"),"defineProperty"),void 0,[a.createIdentifier("exports"),a.createStringLiteralFromNode(n),a.createObjectLiteralExpression([a.createPropertyAssignment("enumerable",a.createTrue()),a.createPropertyAssignment("get",a.createFunctionExpression(void 0,void 0,void 0,void 0,[],void 0,a.createBlock([a.createReturnStatement(t)])))])]):a.createAssignment(a.createPropertyAccessExpression(a.createIdentifier("exports"),a.cloneNode(n)),t),r)}function de(e){switch(e.kind){case 92:case 87:return}return e}function pe(n,t,r){298===t.kind?(y=t,h=E[e.getOriginalNodeId(y)],v=[],g(n,t,r),y=void 0,h=void 0,v=void 0):g(n,t,r)}function fe(n,t){return t=_(n,t),t.id&&v[t.id]?t:1===n?_e(t):e.isShorthandPropertyAssignment(t)?me(t):t}function me(n){var t=n.name,r=ge(t);if(r!==t){if(n.objectAssignmentInitializer){var i=a.createAssignment(r,n.objectAssignmentInitializer);return e.setTextRange(a.createPropertyAssignment(t,i),n)}return e.setTextRange(a.createPropertyAssignment(t,r),n)}return n}function _e(e){switch(e.kind){case 78:return ge(e);case 217:return ye(e);case 216:case 215:return he(e)}return e}function ge(n){var t,r;if(4096&e.getEmitFlags(n)){var i=e.getExternalHelpersModuleName(y);return i?a.createPropertyAccessExpression(i,n):n}if((!e.isGeneratedIdentifier(n)||64&n.autoGenerateFlags)&&!e.isLocalName(n)){var o=d.getReferencedExportContainer(n,e.isExportName(n));if(o&&298===o.kind)return e.setTextRange(a.createPropertyAccessExpression(a.createIdentifier("exports"),a.cloneNode(n)),n);var s=d.getReferencedImportDeclaration(n);if(s){if(e.isImportClause(s))return e.setTextRange(a.createPropertyAccessExpression(a.getGeneratedNameForNode(s.parent),a.createIdentifier("default")),n);if(e.isImportSpecifier(s)){var c=s.propertyName||s.name;return e.setTextRange(a.createPropertyAccessExpression(a.getGeneratedNameForNode((null===(r=null===(t=s.parent)||void 0===t?void 0:t.parent)||void 0===r?void 0:r.parent)||s),a.cloneNode(c)),n)}}}return n}function ye(n){if(e.isAssignmentOperator(n.operatorToken.kind)&&e.isIdentifier(n.left)&&!e.isGeneratedIdentifier(n.left)&&!e.isLocalName(n.left)&&!e.isDeclarationNameOfEnumOrNamespace(n.left)){var t=ve(n.left);if(t){for(var r=n,a=0,i=t;a<i.length;a++){var o=i[a];v[e.getNodeId(r)]=!0,r=ue(o,r,n)}return r}}return n}function he(n){if((45===n.operator||46===n.operator)&&e.isIdentifier(n.operand)&&!e.isGeneratedIdentifier(n.operand)&&!e.isLocalName(n.operand)&&!e.isDeclarationNameOfEnumOrNamespace(n.operand)){var t=ve(n.operand);if(t){for(var r=216===n.kind?e.setTextRange(a.createPrefixUnaryExpression(n.operator,n.operand),n):n,i=0,o=t;i<o.length;i++){var s=o[i];v[e.getNodeId(r)]=!0,r=ue(s,r)}return 216===n.kind&&(v[e.getNodeId(r)]=!0,r=45===n.operator?a.createSubtract(r,a.createNumericLiteral(1)):a.createAdd(r,a.createNumericLiteral(1))),r}}return n}function ve(n){if(!e.isGeneratedIdentifier(n)){var t=d.getReferencedImportDeclaration(n)||d.getReferencedValueDeclaration(n);if(t)return h&&h.exportedBindings[e.getOriginalNodeId(t)]}}}e.transformModule=n;var t={name:"typescript:dynamicimport-sync-require",scoped:!0,text:'\n            var __syncRequire = typeof module === "object" && typeof module.exports === "object";'}}(d||(d={})),function(e){function n(n){var t=n.factory,r=n.startLexicalEnvironment,a=n.endLexicalEnvironment,i=n.hoistVariableDeclaration,o=n.getCompilerOptions(),s=n.getEmitResolver(),c=n.getEmitHost(),l=n.onSubstituteNode,u=n.onEmitNode;n.onSubstituteNode=xe,n.onEmitNode=Se,n.enableSubstitution(78),n.enableSubstitution(290),n.enableSubstitution(217),n.enableSubstitution(215),n.enableSubstitution(216),n.enableSubstitution(227),n.enableEmitNotification(298);var d,p,f,m,_,g,y,h=[],v=[],b=[],E=[],T=[];return e.chainBundle(n,S);function S(r){if(r.isDeclarationFile||!(e.isEffectiveExternalModule(r,o)||4194304&r.transformFlags))return r;var a=e.getOriginalNodeId(r);d=r,g=r,p=h[a]=e.collectExternalModuleInfo(n,r,s,o),f=t.createUniqueName("exports"),b[a]=f,m=T[a]=t.createUniqueName("context");var i=x(p.externalImports),l=L(r,i),u=t.createFunctionExpression(void 0,void 0,void 0,void 0,[t.createParameterDeclaration(void 0,void 0,void 0,f),t.createParameterDeclaration(void 0,void 0,void 0,m)],void 0,l),v=e.tryGetModuleNameFromFile(t,r,c,o),S=t.createArrayLiteralExpression(e.map(i,(function(e){return e.name}))),D=e.setEmitFlags(t.updateSourceFile(r,e.setTextRange(t.createNodeArray([t.createExpressionStatement(t.createCallExpression(t.createPropertyAccessExpression(t.createIdentifier("System"),"register"),void 0,v?[v,S,u]:[S,u]))]),r.statements)),1024);return e.outFile(o)||e.moveEmitHelpers(D,l,(function(e){return!e.scoped})),y&&(E[a]=y,y=void 0),d=void 0,p=void 0,f=void 0,m=void 0,_=void 0,g=void 0,D}function x(n){for(var r=new e.Map,a=[],i=0,l=n;i<l.length;i++){var u=l[i],p=e.getExternalModuleNameLiteral(t,u,d,c,s,o);if(p){var f=p.text,m=r.get(f);void 0!==m?a[m].externalImports.push(u):(r.set(f,a.length),a.push({name:p,externalImports:[u]}))}}return a}function L(n,i){var s=[];r();var c=e.getStrictOptionValue(o,"alwaysStrict")||!o.noImplicitUseStrict&&e.isExternalModule(d),l=t.copyPrologue(n.statements,s,c,I);s.push(t.createVariableStatement(void 0,t.createVariableDeclarationList([t.createVariableDeclaration("__moduleName",void 0,void 0,t.createLogicalAnd(m,t.createPropertyAccessExpression(m,"id")))]))),e.visitNode(p.externalHelpersImportDeclaration,I,e.isStatement);var u=e.visitNodes(n.statements,I,e.isStatement,l);e.addRange(s,_),e.insertStatementsAfterStandardPrologue(s,a());var f=D(s),g=1048576&n.transformFlags?t.createModifiersFromModifierFlags(256):void 0,y=t.createObjectLiteralExpression([t.createPropertyAssignment("setters",C(f,i)),t.createPropertyAssignment("execute",t.createFunctionExpression(g,void 0,void 0,void 0,[],void 0,t.createBlock(u,!0)))],!0);return s.push(t.createReturnStatement(y)),t.createBlock(s,!0)}function D(e){if(p.hasExportStarsToExportValues){if(!p.exportedNames&&0===p.exportSpecifiers.size){for(var n=!1,r=0,a=p.externalImports;r<a.length;r++){var i=a[r];if(268===i.kind&&i.exportClause){n=!0;break}}if(!n){var o=A(void 0);return e.push(o),o.name}}var s=[];if(p.exportedNames)for(var c=0,l=p.exportedNames;c<l.length;c++){var u=l[c];"default"!==u.escapedText&&s.push(t.createPropertyAssignment(t.createStringLiteralFromNode(u),t.createTrue()))}var d=t.createUniqueName("exportedNames");e.push(t.createVariableStatement(void 0,t.createVariableDeclarationList([t.createVariableDeclaration(d,void 0,void 0,t.createObjectLiteralExpression(s,!0))])));var f=A(d);return e.push(f),f.name}}function A(n){var r=t.createUniqueName("exportStar"),a=t.createIdentifier("m"),i=t.createIdentifier("n"),o=t.createIdentifier("exports"),s=t.createStrictInequality(i,t.createStringLiteral("default"));return n&&(s=t.createLogicalAnd(s,t.createLogicalNot(t.createCallExpression(t.createPropertyAccessExpression(n,"hasOwnProperty"),void 0,[i])))),t.createFunctionDeclaration(void 0,void 0,void 0,r,void 0,[t.createParameterDeclaration(void 0,void 0,void 0,a)],void 0,t.createBlock([t.createVariableStatement(void 0,t.createVariableDeclarationList([t.createVariableDeclaration(o,void 0,void 0,t.createObjectLiteralExpression([]))])),t.createForInStatement(t.createVariableDeclarationList([t.createVariableDeclaration(i)]),a,t.createBlock([e.setEmitFlags(t.createIfStatement(s,t.createExpressionStatement(t.createAssignment(t.createElementAccessExpression(o,i),t.createElementAccessExpression(a,i)))),1)])),t.createExpressionStatement(t.createCallExpression(f,void 0,[o]))],!0))}function C(n,r){for(var a=[],i=0,o=r;i<o.length;i++){for(var s=o[i],c=e.forEach(s.externalImports,(function(n){return e.getLocalNameForExternalImport(t,n,d)})),l=c?t.getGeneratedNameForNode(c):t.createUniqueName(""),u=[],p=0,m=s.externalImports;p<m.length;p++){var _=m[p],g=e.getLocalNameForExternalImport(t,_,d);switch(_.kind){case 262:if(!_.importClause)break;case 261:e.Debug.assert(void 0!==g),u.push(t.createExpressionStatement(t.createAssignment(g,l)));break;case 268:if(e.Debug.assert(void 0!==g),_.exportClause)if(e.isNamedExports(_.exportClause)){for(var y=[],h=0,v=_.exportClause.elements;h<v.length;h++){var b=v[h];y.push(t.createPropertyAssignment(t.createStringLiteral(e.idText(b.name)),t.createElementAccessExpression(l,t.createStringLiteral(e.idText(b.propertyName||b.name)))))}u.push(t.createExpressionStatement(t.createCallExpression(f,void 0,[t.createObjectLiteralExpression(y,!0)])))}else u.push(t.createExpressionStatement(t.createCallExpression(f,void 0,[t.createStringLiteral(e.idText(_.exportClause.name)),l])));else u.push(t.createExpressionStatement(t.createCallExpression(n,void 0,[l])));break}}a.push(t.createFunctionExpression(void 0,void 0,void 0,void 0,[t.createParameterDeclaration(void 0,void 0,void 0,l)],void 0,t.createBlock(u,!0)))}return t.createArrayLiteralExpression(a,!0)}function I(e){switch(e.kind){case 262:return N(e);case 261:return R(e);case 268:return k(e);case 267:return O(e);default:return ne(e)}}function N(n){var r;if(n.importClause&&i(e.getLocalNameForExternalImport(t,n,d)),H(n)){var a=e.getOriginalNodeId(n);v[a]=z(v[a],n)}else r=z(r,n);return e.singleOrMany(r)}function k(n){e.Debug.assertIsDefined(n)}function R(n){var r;if(e.Debug.assert(e.isExternalModuleImportEqualsDeclaration(n),"import= for internal module references should be handled in an earlier transformer."),i(e.getLocalNameForExternalImport(t,n,d)),H(n)){var a=e.getOriginalNodeId(n);v[a]=q(v[a],n)}else r=q(r,n);return e.singleOrMany(r)}function O(n){if(!n.isExportEquals){var r=e.visitNode(n.expression,he,e.isExpression),a=n.original;if(!a||!H(a))return $(t.createIdentifier("default"),r,!0);var i=e.getOriginalNodeId(n);v[i]=Z(v[i],t.createIdentifier("default"),r,!0)}}function w(r){if(_=e.hasSyntacticModifier(r,1)?e.append(_,t.updateFunctionDeclaration(r,r.decorators,e.visitNodes(r.modifiers,Te,e.isModifier),r.asteriskToken,t.getDeclarationName(r,!0,!0),void 0,e.visitNodes(r.parameters,he,e.isParameterDeclaration),void 0,e.visitNode(r.body,he,e.isBlock))):e.append(_,e.visitEachChild(r,he,n)),H(r)){var a=e.getOriginalNodeId(r);v[a]=Y(v[a],r)}else _=Y(_,r)}function P(n){var r,a=t.getLocalName(n);if(i(a),r=e.append(r,e.setTextRange(t.createExpressionStatement(t.createAssignment(a,e.setTextRange(t.createClassExpression(e.visitNodes(n.decorators,he,e.isDecorator),void 0,n.name,void 0,e.visitNodes(n.heritageClauses,he,e.isHeritageClause),e.visitNodes(n.members,he,e.isClassElement)),n))),n)),H(n)){var o=e.getOriginalNodeId(n);v[o]=Y(v[o],n)}else r=Y(r,n);return e.singleOrMany(r)}function M(n){if(!G(n.declarationList))return e.visitNode(n,he,e.isStatement);for(var r,a,i=e.hasSyntacticModifier(n,1),o=H(n),s=0,c=n.declarationList.declarations;s<c.length;s++){var l=c[s];l.initializer?r=e.append(r,B(l,i&&!o)):F(l)}if(r&&(a=e.append(a,e.setTextRange(t.createExpressionStatement(t.inlineExpressions(r)),n))),o){var u=e.getOriginalNodeId(n);v[u]=J(v[u],n,i)}else a=J(a,n,!1);return e.singleOrMany(a)}function F(n){if(e.isBindingPattern(n.name))for(var r=0,a=n.name.elements;r<a.length;r++){var o=a[r];e.isOmittedExpression(o)||F(o)}else i(t.cloneNode(n.name))}function G(n){return 0===(2097152&e.getEmitFlags(n))&&(298===g.kind||0===(3&e.getOriginalNode(n).flags))}function B(t,r){var a=r?U:V;return e.isBindingPattern(t.name)?e.flattenDestructuringAssignment(t,he,n,0,!1,a):t.initializer?a(t.name,e.visitNode(t.initializer,he,e.isExpression)):t.name}function U(e,n,t){return j(e,n,t,!0)}function V(e,n,t){return j(e,n,t,!1)}function j(n,r,a,o){return i(t.cloneNode(n)),o?ee(n,Oe(e.setTextRange(t.createAssignment(n,r),a))):Oe(e.setTextRange(t.createAssignment(n,r),a))}function K(n){if(H(n)&&233===n.original.kind){var t=e.getOriginalNodeId(n),r=e.hasSyntacticModifier(n.original,1);v[t]=J(v[t],n.original,r)}return n}function H(n){return 0!==(4194304&e.getEmitFlags(n))}function W(n){var t=e.getOriginalNodeId(n),r=v[t];if(r)return delete v[t],e.append(r,n);var a=e.getOriginalNode(n);return e.isModuleOrEnumDeclaration(a)?e.append(Q(r,a),n):n}function z(e,n){if(p.exportEquals)return e;var t=n.importClause;if(!t)return e;t.name&&(e=Q(e,t));var r=t.namedBindings;if(r)switch(r.kind){case 264:e=Q(e,r);break;case 265:for(var a=0,i=r.elements;a<i.length;a++){var o=i[a];e=Q(e,o)}break}return e}function q(e,n){return p.exportEquals?e:Q(e,n)}function J(e,n,t){if(p.exportEquals)return e;for(var r=0,a=n.declarationList.declarations;r<a.length;r++){var i=a[r];(i.initializer||t)&&(e=X(e,i,t))}return e}function X(n,r,a){if(p.exportEquals)return n;if(e.isBindingPattern(r.name))for(var i=0,o=r.name.elements;i<o.length;i++){var s=o[i];e.isOmittedExpression(s)||(n=X(n,s,a))}else if(!e.isGeneratedIdentifier(r.name)){var c=void 0;a&&(n=Z(n,r.name,t.getLocalName(r)),c=e.idText(r.name)),n=Q(n,r,c)}return n}function Y(n,r){if(p.exportEquals)return n;var a;if(e.hasSyntacticModifier(r,1)){var i=e.hasSyntacticModifier(r,512)?t.createStringLiteral("default"):r.name;n=Z(n,i,t.getLocalName(r)),a=e.getTextOfIdentifierOrLiteral(i)}return r.name&&(n=Q(n,r,a)),n}function Q(n,r,a){if(p.exportEquals)return n;var i=t.getDeclarationName(r),o=p.exportSpecifiers.get(e.idText(i));if(o)for(var s=0,c=o;s<c.length;s++){var l=c[s];l.name.escapedText!==a&&(n=Z(n,l.name,i))}return n}function Z(n,t,r,a){return n=e.append(n,$(t,r,a)),n}function $(n,r,a){var i=t.createExpressionStatement(ee(n,r));return e.startOnNewLine(i),a||e.setEmitFlags(i,1536),i}function ee(n,r){var a=e.isIdentifier(n)?t.createStringLiteralFromNode(n):n;return e.setEmitFlags(r,1536|e.getEmitFlags(r)),e.setCommentRange(t.createCallExpression(f,void 0,[a,r]),r)}function ne(e){switch(e.kind){case 233:return M(e);case 252:return w(e);case 253:return P(e);case 238:return te(e);case 239:return re(e);case 240:return ae(e);case 236:return se(e);case 237:return ce(e);case 246:return le(e);case 244:return ue(e);case 245:return de(e);case 259:return pe(e);case 285:return fe(e);case 286:return me(e);case 248:return _e(e);case 288:return ge(e);case 231:return ye(e);case 342:return K(e);case 343:return W(e);default:return he(e)}}function te(r){var a=g;return g=r,r=t.updateForStatement(r,r.initializer&&oe(r.initializer),e.visitNode(r.condition,he,e.isExpression),e.visitNode(r.incrementor,he,e.isExpression),e.visitIterationBody(r.statement,ne,n)),g=a,r}function re(r){var a=g;return g=r,r=t.updateForInStatement(r,oe(r.initializer),e.visitNode(r.expression,he,e.isExpression),e.visitIterationBody(r.statement,ne,n)),g=a,r}function ae(r){var a=g;return g=r,r=t.updateForOfStatement(r,r.awaitModifier,oe(r.initializer),e.visitNode(r.expression,he,e.isExpression),e.visitIterationBody(r.statement,ne,n)),g=a,r}function ie(n){return e.isVariableDeclarationList(n)&&G(n)}function oe(r){if(ie(r)){for(var a=void 0,i=0,o=r.declarations;i<o.length;i++){var s=o[i];a=e.append(a,B(s,!1)),s.initializer||F(s)}return a?t.inlineExpressions(a):t.createOmittedExpression()}return e.visitEachChild(r,ne,n)}function se(r){return t.updateDoStatement(r,e.visitIterationBody(r.statement,ne,n),e.visitNode(r.expression,he,e.isExpression))}function ce(r){return t.updateWhileStatement(r,e.visitNode(r.expression,he,e.isExpression),e.visitIterationBody(r.statement,ne,n))}function le(n){return t.updateLabeledStatement(n,n.label,e.visitNode(n.statement,ne,e.isStatement,t.liftToBlock))}function ue(n){return t.updateWithStatement(n,e.visitNode(n.expression,he,e.isExpression),e.visitNode(n.statement,ne,e.isStatement,t.liftToBlock))}function de(n){return t.updateSwitchStatement(n,e.visitNode(n.expression,he,e.isExpression),e.visitNode(n.caseBlock,ne,e.isCaseBlock))}function pe(n){var r=g;return g=n,n=t.updateCaseBlock(n,e.visitNodes(n.clauses,ne,e.isCaseOrDefaultClause)),g=r,n}function fe(n){return t.updateCaseClause(n,e.visitNode(n.expression,he,e.isExpression),e.visitNodes(n.statements,ne,e.isStatement))}function me(t){return e.visitEachChild(t,ne,n)}function _e(t){return e.visitEachChild(t,ne,n)}function ge(n){var r=g;return g=n,n=t.updateCatchClause(n,n.variableDeclaration,e.visitNode(n.block,ne,e.isBlock)),g=r,n}function ye(t){var r=g;return g=t,t=e.visitEachChild(t,ne,n),g=r,t}function he(t){return e.isDestructuringAssignment(t)?be(t):e.isImportCall(t)?ve(t):2048&t.transformFlags||4194304&t.transformFlags?e.visitEachChild(t,he,n):t}function ve(n){var r=e.getExternalModuleNameLiteral(t,n,d,c,s,o),a=e.visitNode(e.firstOrUndefined(n.arguments),he),i=!r||a&&e.isStringLiteral(a)&&a.text===r.text?a:r;return t.createCallExpression(t.createPropertyAccessExpression(m,t.createIdentifier("import")),void 0,i?[i]:[])}function be(t){return Ee(t.left)?e.flattenDestructuringAssignment(t,he,n,0,!0):e.visitEachChild(t,he,n)}function Ee(n){if(e.isAssignmentExpression(n,!0))return Ee(n.left);if(e.isSpreadElement(n))return Ee(n.expression);if(e.isObjectLiteralExpression(n))return e.some(n.properties,Ee);if(e.isArrayLiteralExpression(n))return e.some(n.elements,Ee);if(e.isShorthandPropertyAssignment(n))return Ee(n.name);if(e.isPropertyAssignment(n))return Ee(n.initializer);if(e.isIdentifier(n)){var t=s.getReferencedExportContainer(n);return void 0!==t&&298===t.kind}return!1}function Te(e){switch(e.kind){case 92:case 87:return}return e}function Se(n,t,r){if(298===t.kind){var a=e.getOriginalNodeId(t);d=t,p=h[a],f=b[a],y=E[a],m=T[a],y&&delete E[a],u(n,t,r),d=void 0,p=void 0,f=void 0,m=void 0,y=void 0}else u(n,t,r)}function xe(e,n){return n=l(e,n),we(n)?n:1===e?Ae(n):4===e?Le(n):n}function Le(e){switch(e.kind){case 290:return De(e)}return e}function De(n){var r,a,i=n.name;if(!e.isGeneratedIdentifier(i)&&!e.isLocalName(i)){var o=s.getReferencedImportDeclaration(i);if(o){if(e.isImportClause(o))return e.setTextRange(t.createPropertyAssignment(t.cloneNode(i),t.createPropertyAccessExpression(t.getGeneratedNameForNode(o.parent),t.createIdentifier("default"))),n);if(e.isImportSpecifier(o))return e.setTextRange(t.createPropertyAssignment(t.cloneNode(i),t.createPropertyAccessExpression(t.getGeneratedNameForNode((null===(a=null===(r=o.parent)||void 0===r?void 0:r.parent)||void 0===a?void 0:a.parent)||o),t.cloneNode(o.propertyName||o.name))),n)}}return n}function Ae(e){switch(e.kind){case 78:return Ce(e);case 217:return Ie(e);case 215:case 216:return Ne(e);case 227:return ke(e)}return e}function Ce(n){var r,a;if(4096&e.getEmitFlags(n)){var i=e.getExternalHelpersModuleName(d);return i?t.createPropertyAccessExpression(i,n):n}if(!e.isGeneratedIdentifier(n)&&!e.isLocalName(n)){var o=s.getReferencedImportDeclaration(n);if(o){if(e.isImportClause(o))return e.setTextRange(t.createPropertyAccessExpression(t.getGeneratedNameForNode(o.parent),t.createIdentifier("default")),n);if(e.isImportSpecifier(o))return e.setTextRange(t.createPropertyAccessExpression(t.getGeneratedNameForNode((null===(a=null===(r=o.parent)||void 0===r?void 0:r.parent)||void 0===a?void 0:a.parent)||o),t.cloneNode(o.propertyName||o.name)),n)}}return n}function Ie(n){if(e.isAssignmentOperator(n.operatorToken.kind)&&e.isIdentifier(n.left)&&!e.isGeneratedIdentifier(n.left)&&!e.isLocalName(n.left)&&!e.isDeclarationNameOfEnumOrNamespace(n.left)){var t=Re(n.left);if(t){for(var r=n,a=0,i=t;a<i.length;a++){var o=i[a];r=ee(o,Oe(r))}return r}}return n}function Ne(n){if((45===n.operator||46===n.operator)&&e.isIdentifier(n.operand)&&!e.isGeneratedIdentifier(n.operand)&&!e.isLocalName(n.operand)&&!e.isDeclarationNameOfEnumOrNamespace(n.operand)){var r=Re(n.operand);if(r){for(var a=216===n.kind?e.setTextRange(t.createPrefixUnaryExpression(n.operator,n.operand),n):n,i=0,o=r;i<o.length;i++){var s=o[i];a=ee(s,Oe(a))}return 216===n.kind&&(a=45===n.operator?t.createSubtract(Oe(a),t.createNumericLiteral(1)):t.createAdd(Oe(a),t.createNumericLiteral(1))),a}}return n}function ke(n){return e.isImportMeta(n)?t.createPropertyAccessExpression(m,t.createIdentifier("meta")):n}function Re(n){var r;if(!e.isGeneratedIdentifier(n)){var a=s.getReferencedImportDeclaration(n)||s.getReferencedValueDeclaration(n);if(a){var i=s.getReferencedExportContainer(n,!1);i&&298===i.kind&&(r=e.append(r,t.getDeclarationName(a))),r=e.addRange(r,p&&p.exportedBindings[e.getOriginalNodeId(a)])}}return r}function Oe(n){return void 0===y&&(y=[]),y[e.getNodeId(n)]=!0,n}function we(e){return y&&e.id&&y[e.id]}}e.transformSystemModule=n}(d||(d={})),function(e){function n(n){var t,r=n.factory,a=n.getEmitHelperFactory,o=n.getCompilerOptions(),s=n.onEmitNode,c=n.onSubstituteNode;return n.onEmitNode=m,n.onSubstituteNode=_,n.enableEmitNotification(298),n.enableSubstitution(78),e.chainBundle(n,l);function l(n){if(n.isDeclarationFile)return n;if(e.isExternalModule(n)||o.isolatedModules){var t=u(n);return!e.isExternalModule(n)||e.some(t.statements,e.isExternalModuleIndicator)?t:r.updateSourceFile(t,e.setTextRange(r.createNodeArray(i(i([],t.statements),[e.createEmptyExports(r)])),t.statements))}return n}function u(t){var i=e.createExternalHelpersImportDeclarationIfNeeded(r,a(),t,o);if(i){var s=[],c=r.copyPrologue(t.statements,s);return e.append(s,i),e.addRange(s,e.visitNodes(t.statements,d,e.isStatement,c)),r.updateSourceFile(t,e.setTextRange(r.createNodeArray(s),t.statements))}return e.visitEachChild(t,d,n)}function d(e){switch(e.kind){case 261:return;case 267:return p(e);case 268:var n=e;return f(n)}return e}function p(e){return e.isExportEquals?void 0:e}function f(n){if(void 0!==o.module&&o.module>e.ModuleKind.ES2015)return n;if(!n.exportClause||!e.isNamespaceExport(n.exportClause)||!n.moduleSpecifier)return n;var t=n.exportClause.name,a=r.getGeneratedNameForNode(t),i=r.createImportDeclaration(void 0,void 0,r.createImportClause(!1,void 0,r.createNamespaceImport(a)),n.moduleSpecifier);e.setOriginalNode(i,n.exportClause);var s=e.isExportNamespaceAsDefaultDeclaration(n)?r.createExportDefault(a):r.createExportDeclaration(void 0,void 0,!1,r.createNamedExports([r.createExportSpecifier(a,t)]));return e.setOriginalNode(s,n),[i,s]}function m(n,r,a){e.isSourceFile(r)?((e.isExternalModule(r)||o.isolatedModules)&&o.importHelpers&&(t=new e.Map),s(n,r,a),t=void 0):s(n,r,a)}function _(n,r){return r=c(n,r),t&&e.isIdentifier(r)&&4096&e.getEmitFlags(r)?g(r):r}function g(n){var a=e.idText(n),i=t.get(a);return i||t.set(a,i=r.createUniqueName(a,48)),i}}e.transformECMAScriptModule=n}(d||(d={})),function(e){function n(n){return e.isVariableDeclaration(n)||e.isPropertyDeclaration(n)||e.isPropertySignature(n)||e.isBindingElement(n)||e.isSetAccessor(n)||e.isGetAccessor(n)||e.isConstructSignatureDeclaration(n)||e.isCallSignatureDeclaration(n)||e.isMethodDeclaration(n)||e.isMethodSignature(n)||e.isFunctionDeclaration(n)||e.isParameter(n)||e.isTypeParameterDeclaration(n)||e.isExpressionWithTypeArguments(n)||e.isImportEqualsDeclaration(n)||e.isTypeAliasDeclaration(n)||e.isConstructorDeclaration(n)||e.isIndexSignatureDeclaration(n)||e.isPropertyAccessExpression(n)||e.isJSDocTypeAlias(n)}function t(n){return e.isSetAccessor(n)||e.isGetAccessor(n)?t:e.isMethodSignature(n)||e.isMethodDeclaration(n)?i:r(n);function t(e){var t=a(e);return void 0!==t?{diagnosticMessage:t,errorNode:n,typeName:n.name}:void 0}function a(t){return e.hasSyntacticModifier(n,32)?t.errorModuleName?2===t.accessibility?e.Diagnostics.Public_static_property_0_of_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named:e.Diagnostics.Public_static_property_0_of_exported_class_has_or_is_using_name_1_from_private_module_2:e.Diagnostics.Public_static_property_0_of_exported_class_has_or_is_using_private_name_1:253===n.parent.kind?t.errorModuleName?2===t.accessibility?e.Diagnostics.Public_property_0_of_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named:e.Diagnostics.Public_property_0_of_exported_class_has_or_is_using_name_1_from_private_module_2:e.Diagnostics.Public_property_0_of_exported_class_has_or_is_using_private_name_1:t.errorModuleName?e.Diagnostics.Property_0_of_exported_interface_has_or_is_using_name_1_from_private_module_2:e.Diagnostics.Property_0_of_exported_interface_has_or_is_using_private_name_1}function i(e){var t=o(e);return void 0!==t?{diagnosticMessage:t,errorNode:n,typeName:n.name}:void 0}function o(t){return e.hasSyntacticModifier(n,32)?t.errorModuleName?2===t.accessibility?e.Diagnostics.Public_static_method_0_of_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named:e.Diagnostics.Public_static_method_0_of_exported_class_has_or_is_using_name_1_from_private_module_2:e.Diagnostics.Public_static_method_0_of_exported_class_has_or_is_using_private_name_1:253===n.parent.kind?t.errorModuleName?2===t.accessibility?e.Diagnostics.Public_method_0_of_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named:e.Diagnostics.Public_method_0_of_exported_class_has_or_is_using_name_1_from_private_module_2:e.Diagnostics.Public_method_0_of_exported_class_has_or_is_using_private_name_1:t.errorModuleName?e.Diagnostics.Method_0_of_exported_interface_has_or_is_using_name_1_from_private_module_2:e.Diagnostics.Method_0_of_exported_interface_has_or_is_using_private_name_1}}function r(n){return e.isVariableDeclaration(n)||e.isPropertyDeclaration(n)||e.isPropertySignature(n)||e.isPropertyAccessExpression(n)||e.isBindingElement(n)||e.isConstructorDeclaration(n)?r:e.isSetAccessor(n)||e.isGetAccessor(n)?a:e.isConstructSignatureDeclaration(n)||e.isCallSignatureDeclaration(n)||e.isMethodDeclaration(n)||e.isMethodSignature(n)||e.isFunctionDeclaration(n)||e.isIndexSignatureDeclaration(n)?i:e.isParameter(n)?e.isParameterPropertyDeclaration(n,n.parent)&&e.hasSyntacticModifier(n.parent,8)?r:o:e.isTypeParameterDeclaration(n)?c:e.isExpressionWithTypeArguments(n)?l:e.isImportEqualsDeclaration(n)?u:e.isTypeAliasDeclaration(n)||e.isJSDocTypeAlias(n)?d:e.Debug.assertNever(n,"Attempted to set a declaration diagnostic context for unhandled node kind: "+e.SyntaxKind[n.kind]);function t(t){return 250===n.kind||199===n.kind?t.errorModuleName?2===t.accessibility?e.Diagnostics.Exported_variable_0_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named:e.Diagnostics.Exported_variable_0_has_or_is_using_name_1_from_private_module_2:e.Diagnostics.Exported_variable_0_has_or_is_using_private_name_1:164===n.kind||202===n.kind||163===n.kind||161===n.kind&&e.hasSyntacticModifier(n.parent,8)?e.hasSyntacticModifier(n,32)?t.errorModuleName?2===t.accessibility?e.Diagnostics.Public_static_property_0_of_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named:e.Diagnostics.Public_static_property_0_of_exported_class_has_or_is_using_name_1_from_private_module_2:e.Diagnostics.Public_static_property_0_of_exported_class_has_or_is_using_private_name_1:253===n.parent.kind||161===n.kind?t.errorModuleName?2===t.accessibility?e.Diagnostics.Public_property_0_of_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named:e.Diagnostics.Public_property_0_of_exported_class_has_or_is_using_name_1_from_private_module_2:e.Diagnostics.Public_property_0_of_exported_class_has_or_is_using_private_name_1:t.errorModuleName?e.Diagnostics.Property_0_of_exported_interface_has_or_is_using_name_1_from_private_module_2:e.Diagnostics.Property_0_of_exported_interface_has_or_is_using_private_name_1:void 0}function r(e){var r=t(e);return void 0!==r?{diagnosticMessage:r,errorNode:n,typeName:n.name}:void 0}function a(t){var r;return r=169===n.kind?e.hasSyntacticModifier(n,32)?t.errorModuleName?e.Diagnostics.Parameter_type_of_public_static_setter_0_from_exported_class_has_or_is_using_name_1_from_private_module_2:e.Diagnostics.Parameter_type_of_public_static_setter_0_from_exported_class_has_or_is_using_private_name_1:t.errorModuleName?e.Diagnostics.Parameter_type_of_public_setter_0_from_exported_class_has_or_is_using_name_1_from_private_module_2:e.Diagnostics.Parameter_type_of_public_setter_0_from_exported_class_has_or_is_using_private_name_1:e.hasSyntacticModifier(n,32)?t.errorModuleName?2===t.accessibility?e.Diagnostics.Return_type_of_public_static_getter_0_from_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named:e.Diagnostics.Return_type_of_public_static_getter_0_from_exported_class_has_or_is_using_name_1_from_private_module_2:e.Diagnostics.Return_type_of_public_static_getter_0_from_exported_class_has_or_is_using_private_name_1:t.errorModuleName?2===t.accessibility?e.Diagnostics.Return_type_of_public_getter_0_from_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named:e.Diagnostics.Return_type_of_public_getter_0_from_exported_class_has_or_is_using_name_1_from_private_module_2:e.Diagnostics.Return_type_of_public_getter_0_from_exported_class_has_or_is_using_private_name_1,{diagnosticMessage:r,errorNode:n.name,typeName:n.name}}function i(t){var r;switch(n.kind){case 171:r=t.errorModuleName?e.Diagnostics.Return_type_of_constructor_signature_from_exported_interface_has_or_is_using_name_0_from_private_module_1:e.Diagnostics.Return_type_of_constructor_signature_from_exported_interface_has_or_is_using_private_name_0;break;case 170:r=t.errorModuleName?e.Diagnostics.Return_type_of_call_signature_from_exported_interface_has_or_is_using_name_0_from_private_module_1:e.Diagnostics.Return_type_of_call_signature_from_exported_interface_has_or_is_using_private_name_0;break;case 172:r=t.errorModuleName?e.Diagnostics.Return_type_of_index_signature_from_exported_interface_has_or_is_using_name_0_from_private_module_1:e.Diagnostics.Return_type_of_index_signature_from_exported_interface_has_or_is_using_private_name_0;break;case 166:case 165:r=e.hasSyntacticModifier(n,32)?t.errorModuleName?2===t.accessibility?e.Diagnostics.Return_type_of_public_static_method_from_exported_class_has_or_is_using_name_0_from_external_module_1_but_cannot_be_named:e.Diagnostics.Return_type_of_public_static_method_from_exported_class_has_or_is_using_name_0_from_private_module_1:e.Diagnostics.Return_type_of_public_static_method_from_exported_class_has_or_is_using_private_name_0:253===n.parent.kind?t.errorModuleName?2===t.accessibility?e.Diagnostics.Return_type_of_public_method_from_exported_class_has_or_is_using_name_0_from_external_module_1_but_cannot_be_named:e.Diagnostics.Return_type_of_public_method_from_exported_class_has_or_is_using_name_0_from_private_module_1:e.Diagnostics.Return_type_of_public_method_from_exported_class_has_or_is_using_private_name_0:t.errorModuleName?e.Diagnostics.Return_type_of_method_from_exported_interface_has_or_is_using_name_0_from_private_module_1:e.Diagnostics.Return_type_of_method_from_exported_interface_has_or_is_using_private_name_0;break;case 252:r=t.errorModuleName?2===t.accessibility?e.Diagnostics.Return_type_of_exported_function_has_or_is_using_name_0_from_external_module_1_but_cannot_be_named:e.Diagnostics.Return_type_of_exported_function_has_or_is_using_name_0_from_private_module_1:e.Diagnostics.Return_type_of_exported_function_has_or_is_using_private_name_0;break;default:return e.Debug.fail("This is unknown kind for signature: "+n.kind)}return{diagnosticMessage:r,errorNode:n.name||n}}function o(e){var t=s(e);return void 0!==t?{diagnosticMessage:t,errorNode:n,typeName:n.name}:void 0}function s(t){switch(n.parent.kind){case 167:return t.errorModuleName?2===t.accessibility?e.Diagnostics.Parameter_0_of_constructor_from_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named:e.Diagnostics.Parameter_0_of_constructor_from_exported_class_has_or_is_using_name_1_from_private_module_2:e.Diagnostics.Parameter_0_of_constructor_from_exported_class_has_or_is_using_private_name_1;case 171:case 176:return t.errorModuleName?e.Diagnostics.Parameter_0_of_constructor_signature_from_exported_interface_has_or_is_using_name_1_from_private_module_2:e.Diagnostics.Parameter_0_of_constructor_signature_from_exported_interface_has_or_is_using_private_name_1;case 170:return t.errorModuleName?e.Diagnostics.Parameter_0_of_call_signature_from_exported_interface_has_or_is_using_name_1_from_private_module_2:e.Diagnostics.Parameter_0_of_call_signature_from_exported_interface_has_or_is_using_private_name_1;case 172:return t.errorModuleName?e.Diagnostics.Parameter_0_of_index_signature_from_exported_interface_has_or_is_using_name_1_from_private_module_2:e.Diagnostics.Parameter_0_of_index_signature_from_exported_interface_has_or_is_using_private_name_1;case 166:case 165:return e.hasSyntacticModifier(n.parent,32)?t.errorModuleName?2===t.accessibility?e.Diagnostics.Parameter_0_of_public_static_method_from_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named:e.Diagnostics.Parameter_0_of_public_static_method_from_exported_class_has_or_is_using_name_1_from_private_module_2:e.Diagnostics.Parameter_0_of_public_static_method_from_exported_class_has_or_is_using_private_name_1:253===n.parent.parent.kind?t.errorModuleName?2===t.accessibility?e.Diagnostics.Parameter_0_of_public_method_from_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named:e.Diagnostics.Parameter_0_of_public_method_from_exported_class_has_or_is_using_name_1_from_private_module_2:e.Diagnostics.Parameter_0_of_public_method_from_exported_class_has_or_is_using_private_name_1:t.errorModuleName?e.Diagnostics.Parameter_0_of_method_from_exported_interface_has_or_is_using_name_1_from_private_module_2:e.Diagnostics.Parameter_0_of_method_from_exported_interface_has_or_is_using_private_name_1;case 252:case 175:return t.errorModuleName?2===t.accessibility?e.Diagnostics.Parameter_0_of_exported_function_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named:e.Diagnostics.Parameter_0_of_exported_function_has_or_is_using_name_1_from_private_module_2:e.Diagnostics.Parameter_0_of_exported_function_has_or_is_using_private_name_1;case 169:case 168:return t.errorModuleName?2===t.accessibility?e.Diagnostics.Parameter_0_of_accessor_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named:e.Diagnostics.Parameter_0_of_accessor_has_or_is_using_name_1_from_private_module_2:e.Diagnostics.Parameter_0_of_accessor_has_or_is_using_private_name_1;default:return e.Debug.fail("Unknown parent for parameter: "+e.SyntaxKind[n.parent.kind])}}function c(){var t;switch(n.parent.kind){case 253:t=e.Diagnostics.Type_parameter_0_of_exported_class_has_or_is_using_private_name_1;break;case 254:t=e.Diagnostics.Type_parameter_0_of_exported_interface_has_or_is_using_private_name_1;break;case 191:t=e.Diagnostics.Type_parameter_0_of_exported_mapped_object_type_is_using_private_name_1;break;case 176:case 171:t=e.Diagnostics.Type_parameter_0_of_constructor_signature_from_exported_interface_has_or_is_using_private_name_1;break;case 170:t=e.Diagnostics.Type_parameter_0_of_call_signature_from_exported_interface_has_or_is_using_private_name_1;break;case 166:case 165:t=e.hasSyntacticModifier(n.parent,32)?e.Diagnostics.Type_parameter_0_of_public_static_method_from_exported_class_has_or_is_using_private_name_1:253===n.parent.parent.kind?e.Diagnostics.Type_parameter_0_of_public_method_from_exported_class_has_or_is_using_private_name_1:e.Diagnostics.Type_parameter_0_of_method_from_exported_interface_has_or_is_using_private_name_1;break;case 175:case 252:t=e.Diagnostics.Type_parameter_0_of_exported_function_has_or_is_using_private_name_1;break;case 255:t=e.Diagnostics.Type_parameter_0_of_exported_type_alias_has_or_is_using_private_name_1;break;default:return e.Debug.fail("This is unknown parent for type parameter: "+n.parent.kind)}return{diagnosticMessage:t,errorNode:n,typeName:n.name}}function l(){var t;return t=e.isClassDeclaration(n.parent.parent)?e.isHeritageClause(n.parent)&&116===n.parent.token?e.Diagnostics.Implements_clause_of_exported_class_0_has_or_is_using_private_name_1:n.parent.parent.name?e.Diagnostics.extends_clause_of_exported_class_0_has_or_is_using_private_name_1:e.Diagnostics.extends_clause_of_exported_class_has_or_is_using_private_name_0:e.Diagnostics.extends_clause_of_exported_interface_0_has_or_is_using_private_name_1,{diagnosticMessage:t,errorNode:n,typeName:e.getNameOfDeclaration(n.parent.parent)}}function u(){return{diagnosticMessage:e.Diagnostics.Import_declaration_0_is_using_private_name_1,errorNode:n,typeName:n.name}}function d(t){return{diagnosticMessage:t.errorModuleName?e.Diagnostics.Exported_type_alias_0_has_or_is_using_private_name_1_from_module_2:e.Diagnostics.Exported_type_alias_0_has_or_is_using_private_name_1,errorNode:e.isJSDocTypeAlias(n)?e.Debug.checkDefined(n.typeExpression):n.type,typeName:e.isJSDocTypeAlias(n)?e.getNameOfDeclaration(n):n.name}}}e.canProduceDiagnostics=n,e.createGetSymbolAccessibilityDiagnosticForNodeName=t,e.createGetSymbolAccessibilityDiagnosticForNode=r}(d||(d={})),function(e){function n(n,t,r){var a=n.getCompilerOptions(),i=e.transformNodes(t,n,e.factory,a,r?[r]:e.filter(n.getSourceFiles(),e.isSourceFileNotJson),[o],!1);return i.diagnostics}function t(n,t){var r=t.text.substring(n.pos,n.end);return e.stringContains(r,"@internal")}function r(n,r){var a=e.getParseTreeNode(n);if(a&&161===a.kind){var i=a.parent.parameters.indexOf(a),o=i>0?a.parent.parameters[i-1]:void 0,s=r.text,c=o?e.concatenate(e.getTrailingCommentRanges(s,e.skipTrivia(s,o.end+1,!1,!0)),e.getLeadingCommentRanges(s,n.pos)):e.getTrailingCommentRanges(s,e.skipTrivia(s,n.pos,!1,!0));return c&&c.length&&t(e.last(c),r)}var l=a&&e.getLeadingCommentRangesOfNode(a,r);return!!e.forEach(l,(function(e){return t(e,r)}))}e.getDeclarationDiagnostics=n,e.isInternalDeclaration=r;var a=531469;function o(n){var t,o,m,_,g,y,h,v,b,E,T,S,x=function(){return e.Debug.fail("Diagnostic emitted without context")},L=x,D=!0,A=!1,C=!1,I=!1,N=!1,k=n.factory,R=n.getEmitHost(),O={trackSymbol:j,reportInaccessibleThisError:z,reportInaccessibleUniqueSymbolError:H,reportCyclicStructureError:W,reportPrivateInBaseOfClassExpression:K,reportLikelyUnsafeImportRequiredError:q,reportTruncationError:J,moduleResolverHost:R,trackReferencedAmbientModule:B,trackExternalModuleSymbolOfImportTypeNode:V,reportNonlocalAugmentation:X},w=n.getEmitResolver(),P=n.getCompilerOptions(),M=P.noResolve,F=P.stripInternal;return Q;function G(n){if(n){o=o||new e.Set;for(var t=0,r=n;t<r.length;t++){var a=r[t];o.add(a)}}}function B(n,t){var r=w.getTypeReferenceDirectivesForSymbol(t,67108863);if(e.length(r))return G(r);var a=e.getSourceFileOfNode(n);E.set(e.getOriginalNodeId(a),a)}function U(t){if(0===t.accessibility){if(t&&t.aliasesToMakeVisible)if(m)for(var r=0,a=t.aliasesToMakeVisible;r<a.length;r++){var i=a[r];e.pushIfUnique(m,i)}else m=t.aliasesToMakeVisible}else{var o=L(t);o&&(o.typeName?n.addDiagnostic(e.createDiagnosticForNode(t.errorNode||o.errorNode,o.diagnosticMessage,e.getTextOfNode(o.typeName),t.errorSymbolName,t.errorModuleName)):n.addDiagnostic(e.createDiagnosticForNode(t.errorNode||o.errorNode,o.diagnosticMessage,t.errorSymbolName,t.errorModuleName)))}}function V(e){A||(y||(y=[])).push(e)}function j(e,n,t){262144&e.flags||(U(w.isSymbolAccessible(e,n,t,!0)),G(w.getTypeReferenceDirectivesForSymbol(e,t)))}function K(t){(h||v)&&n.addDiagnostic(e.createDiagnosticForNode(h||v,e.Diagnostics.Property_0_of_exported_class_expression_may_not_be_private_or_protected,t))}function H(){h&&n.addDiagnostic(e.createDiagnosticForNode(h,e.Diagnostics.The_inferred_type_of_0_references_an_inaccessible_1_type_A_type_annotation_is_necessary,e.declarationNameToString(h),"unique symbol"))}function W(){h&&n.addDiagnostic(e.createDiagnosticForNode(h,e.Diagnostics.The_inferred_type_of_0_references_a_type_with_a_cyclic_structure_which_cannot_be_trivially_serialized_A_type_annotation_is_necessary,e.declarationNameToString(h)))}function z(){h&&n.addDiagnostic(e.createDiagnosticForNode(h,e.Diagnostics.The_inferred_type_of_0_references_an_inaccessible_1_type_A_type_annotation_is_necessary,e.declarationNameToString(h),"this"))}function q(t){h&&n.addDiagnostic(e.createDiagnosticForNode(h,e.Diagnostics.The_inferred_type_of_0_cannot_be_named_without_a_reference_to_1_This_is_likely_not_portable_A_type_annotation_is_necessary,e.declarationNameToString(h),t))}function J(){(h||v)&&n.addDiagnostic(e.createDiagnosticForNode(h||v,e.Diagnostics.The_inferred_type_of_this_node_exceeds_the_maximum_length_the_compiler_will_serialize_An_explicit_type_annotation_is_needed))}function X(t,r,a){var i,o=null===(i=r.declarations)||void 0===i?void 0:i.find((function(n){return e.getSourceFileOfNode(n)===t})),s=e.filter(a.declarations,(function(n){return e.getSourceFileOfNode(n)!==t}));if(s)for(var c=0,l=s;c<l.length;c++){var u=l[c];n.addDiagnostic(e.addRelatedInfo(e.createDiagnosticForNode(u,e.Diagnostics.Declaration_augments_declaration_in_another_file_This_cannot_be_serialized),e.createDiagnosticForNode(o,e.Diagnostics.This_is_the_declaration_being_augmented_Consider_moving_the_augmenting_declaration_into_the_same_file)))}}function Y(n,t){var r=L;L=function(t){return t.errorNode&&e.canProduceDiagnostics(t.errorNode)?e.createGetSymbolAccessibilityDiagnosticForNode(t.errorNode)(t):{diagnosticMessage:t.errorModuleName?e.Diagnostics.Declaration_emit_for_this_file_requires_using_private_name_0_from_module_1_An_explicit_type_annotation_may_unblock_declaration_emit:e.Diagnostics.Declaration_emit_for_this_file_requires_using_private_name_0_An_explicit_type_annotation_may_unblock_declaration_emit,errorNode:t.errorNode||n}};var i=w.getDeclarationStatementsForSourceFile(n,a,O,t);return L=r,i}function Q(r){if(298===r.kind&&r.isDeclarationFile)return r;if(299===r.kind){A=!0,E=new e.Map,T=new e.Map;var a=!1,s=k.createBundle(e.map(r.sourceFiles,(function(r){if(!r.isDeclarationFile){if(a=a||r.hasNoDefaultLib,b=r,t=r,m=void 0,g=!1,_=new e.Map,L=x,I=!1,N=!1,Z(r,E),$(r,T),e.isExternalOrCommonJsModule(r)||e.isJsonSourceFile(r)){C=!1,D=!1;var i=e.isSourceFileJS(r)?k.createNodeArray(Y(r,!0)):e.visitNodes(r.statements,ve),o=k.updateSourceFile(r,[k.createModuleDeclaration([],[k.createModifier(133)],k.createStringLiteral(e.getResolvedExternalModuleName(n.getEmitHost(),r)),k.createModuleBlock(e.setTextRange(k.createNodeArray(ge(i)),r.statements)))],!0,[],[],!1,[]);return o}D=!0;var s=e.isSourceFileJS(r)?k.createNodeArray(Y(r)):e.visitNodes(r.statements,ve);return k.updateSourceFile(r,ge(s),!0,[],[],!1,[])}})),e.mapDefined(r.prepends,(function(n){if(301===n.kind){var t=e.createUnparsedSourceFile(n,"dts",F);return a=a||!!t.hasNoDefaultLib,Z(t,E),G(t.typeReferenceDirectives),$(t,T),t}return n})));s.syntheticFileReferences=[],s.syntheticTypeReferences=w(),s.syntheticLibReferences=O(),s.hasNoDefaultLib=a;var c=e.getDirectoryPath(e.normalizeSlashes(e.getOutputPathsFor(r,R,!0).declarationFilePath)),l=B(s.syntheticFileReferences,c);return E.forEach(l),s}D=!0,I=!1,N=!1,t=r,b=r,L=x,A=!1,C=!1,g=!1,m=void 0,_=new e.Map,o=void 0,E=Z(b,new e.Map),T=$(b,new e.Map);var u,d=[],p=e.getDirectoryPath(e.normalizeSlashes(e.getOutputPathsFor(r,R,!0).declarationFilePath)),f=B(d,p);if(e.isSourceFileJS(b))u=k.createNodeArray(Y(r)),E.forEach(f),S=e.filter(u,e.isAnyImportSyntax);else{var h=e.visitNodes(r.statements,ve);u=e.setTextRange(k.createNodeArray(ge(h)),r.statements),E.forEach(f),S=e.filter(u,e.isAnyImportSyntax),e.isExternalModule(r)&&(!C||I&&!N)&&(u=e.setTextRange(k.createNodeArray(i(i([],u),[e.createEmptyExports(k)])),u))}var v=k.updateSourceFile(r,u,!0,d,w(),r.hasNoDefaultLib,O());return v.exportedModulesFromDeclarationEmit=y,v;function O(){return e.map(e.arrayFrom(T.keys()),(function(e){return{fileName:e,pos:-1,end:-1}}))}function w(){return o?e.mapDefined(e.arrayFrom(o.keys()),M):[]}function M(n){if(S)for(var t=0,r=S;t<r.length;t++){var a=r[t];if(e.isImportEqualsDeclaration(a)&&e.isExternalModuleReference(a.moduleReference)){var i=a.moduleReference.expression;if(e.isStringLiteralLike(i)&&i.text===n)return}else if(e.isImportDeclaration(a)&&e.isStringLiteral(a.moduleSpecifier)&&a.moduleSpecifier.text===n)return}return{fileName:n,pos:-1,end:-1}}function B(n,t){return function(a){var i;if(a.isDeclarationFile)i=a.fileName;else{if(A&&e.contains(r.sourceFiles,a))return;var o=e.getOutputPathsFor(a,R,!0);i=o.declarationFilePath||o.jsFilePath||a.fileName}if(i){var s=e.moduleSpecifiers.getModuleSpecifier(P,b,e.toPath(t,R.getCurrentDirectory(),R.getCanonicalFileName),e.toPath(i,R.getCurrentDirectory(),R.getCanonicalFileName),R,void 0);if(!e.pathIsRelative(s))return void G([s]);var c=e.getRelativePathToDirectoryOrUrl(t,i,R.getCurrentDirectory(),R.getCanonicalFileName,!1);if(e.startsWith(c,"./")&&e.hasExtension(c)&&(c=c.substring(2)),e.startsWith(c,"node_modules/")||e.pathContainsNodeModules(c))return;n.push({pos:-1,end:-1,fileName:c})}}}}function Z(n,t){return M||!e.isUnparsedSource(n)&&e.isSourceFileJS(n)||e.forEach(n.referencedFiles,(function(r){var a=R.getSourceFileFromReference(n,r);a&&t.set(e.getOriginalNodeId(a),a)})),t}function $(n,t){return e.forEach(n.libReferenceDirectives,(function(n){var r=R.getLibFileFromReference(n);r&&t.set(e.toFileNameLowerCase(n.fileName),!0)})),t}function ee(n){return 78===n.kind?n:198===n.kind?k.updateArrayBindingPattern(n,e.visitNodes(n.elements,t)):k.updateObjectBindingPattern(n,e.visitNodes(n.elements,t));function t(e){return 223===e.kind?e:k.updateBindingElement(e,e.dotDotDotToken,e.propertyName,ee(e.name),te(e)?e.initializer:void 0)}}function ne(n,t,r){var a;g||(a=L,L=e.createGetSymbolAccessibilityDiagnosticForNode(n));var i=k.updateParameterDeclaration(n,void 0,c(n,t),n.dotDotDotToken,ee(n.name),w.isOptionalParameter(n)?n.questionToken||k.createToken(57):void 0,ae(n,r||n.type,!0),re(n));return g||(L=a),i}function te(n){return d(n)&&w.isLiteralConstDeclaration(e.getParseTreeNode(n))}function re(n){if(te(n))return w.createLiteralConstValue(e.getParseTreeNode(n),O)}function ae(n,r,i){if((i||!e.hasEffectiveModifier(n,8))&&!te(n)){var o,s=161===n.kind&&(w.isRequiredInitializedParameter(n)||w.isOptionalUninitializedParameterProperty(n));return r&&!s?e.visitNode(r,ye):e.getParseTreeNode(n)?169===n.kind?k.createKeywordTypeNode(128):(h=n.name,g||(o=L,L=e.createGetSymbolAccessibilityDiagnosticForNode(n)),250===n.kind||199===n.kind?c(w.createTypeOfDeclaration(n,t,a,O)):161===n.kind||164===n.kind||163===n.kind?n.initializer?c(w.createTypeOfDeclaration(n,t,a,O,s)||w.createTypeOfExpression(n.initializer,t,a,O)):c(w.createTypeOfDeclaration(n,t,a,O,s)):c(w.createReturnTypeOfSignatureDeclaration(n,t,a,O))):r?e.visitNode(r,ye):k.createKeywordTypeNode(128)}function c(e){return h=void 0,g||(L=o),e||k.createKeywordTypeNode(128)}}function ie(n){switch(n=e.getParseTreeNode(n),n.kind){case 252:case 257:case 254:case 253:case 255:case 256:return!w.isDeclarationVisible(n);case 250:return!oe(n);case 261:case 262:case 268:case 267:return!1}return!1}function oe(n){return!e.isOmittedExpression(n)&&(e.isBindingPattern(n.name)?e.some(n.name.elements,oe):w.isDeclarationVisible(n))}function se(n,t,r){if(!e.hasEffectiveModifier(n,8)){var a=e.map(t,(function(e){return ne(e,r)}));if(a)return k.createNodeArray(a,t.hasTrailingComma)}}function ce(n,t){var r;if(!t){var a=e.getThisParameter(n);a&&(r=[ne(a)])}if(e.isSetAccessorDeclaration(n)){var i=void 0;if(!t){var o=e.getSetAccessorValueParameter(n);if(o){var s=ke(n,w.getAllAccessorDeclarations(n));i=ne(o,void 0,s)}}i||(i=k.createParameterDeclaration(void 0,void 0,void 0,"value")),r=e.append(r,i)}return k.createNodeArray(r||e.emptyArray)}function le(n,t){return e.hasEffectiveModifier(n,8)?void 0:e.visitNodes(t,ye)}function ue(n){return e.isSourceFile(n)||e.isTypeAliasDeclaration(n)||e.isModuleDeclaration(n)||e.isClassDeclaration(n)||e.isInterfaceDeclaration(n)||e.isFunctionLike(n)||e.isIndexSignatureDeclaration(n)||e.isMappedTypeNode(n)}function de(e,n){var t=w.isEntityNameVisible(e,n);U(t),G(w.getTypeReferenceDirectivesForEntityName(e))}function pe(n,t){return e.hasJSDocNodes(n)&&e.hasJSDocNodes(t)&&(n.jsDoc=t.jsDoc),e.setCommentRange(n,e.getCommentRange(t))}function fe(t,r){if(r){if(C=C||257!==t.kind&&196!==t.kind,e.isStringLiteralLike(r))if(A){var a=e.getExternalModuleNameFromDeclaration(n.getEmitHost(),w,t);if(a)return k.createStringLiteral(a)}else{var i=w.getSymbolOfExternalModuleSpecifier(r);i&&(y||(y=[])).push(i)}return r}}function me(n){if(w.isDeclarationVisible(n)){if(273===n.moduleReference.kind){var r=e.getExternalModuleImportEqualsDeclarationExpression(n);return k.updateImportEqualsDeclaration(n,void 0,n.modifiers,n.isTypeOnly,n.name,k.updateExternalModuleReference(n.moduleReference,fe(n,r)))}var a=L;return L=e.createGetSymbolAccessibilityDiagnosticForNode(n),de(n.moduleReference,t),L=a,n}}function _e(n){if(!n.importClause)return k.updateImportDeclaration(n,void 0,n.modifiers,n.importClause,fe(n,n.moduleSpecifier));var t=n.importClause&&n.importClause.name&&w.isDeclarationVisible(n.importClause)?n.importClause.name:void 0;if(!n.importClause.namedBindings)return t&&k.updateImportDeclaration(n,void 0,n.modifiers,k.updateImportClause(n.importClause,n.importClause.isTypeOnly,t,void 0),fe(n,n.moduleSpecifier));if(264===n.importClause.namedBindings.kind){var r=w.isDeclarationVisible(n.importClause.namedBindings)?n.importClause.namedBindings:void 0;return t||r?k.updateImportDeclaration(n,void 0,n.modifiers,k.updateImportClause(n.importClause,n.importClause.isTypeOnly,t,r),fe(n,n.moduleSpecifier)):void 0}var a=e.mapDefined(n.importClause.namedBindings.elements,(function(e){return w.isDeclarationVisible(e)?e:void 0}));return a&&a.length||t?k.updateImportDeclaration(n,void 0,n.modifiers,k.updateImportClause(n.importClause,n.importClause.isTypeOnly,t,a&&a.length?k.updateNamedImports(n.importClause.namedBindings,a):void 0),fe(n,n.moduleSpecifier)):w.isImportRequiredByAugmentation(n)?k.updateImportDeclaration(n,void 0,n.modifiers,void 0,fe(n,n.moduleSpecifier)):void 0}function ge(n){while(e.length(m)){var t=m.shift();if(!e.isLateVisibilityPaintedStatement(t))return e.Debug.fail("Late replaced statement was found which is not handled by the declaration transformer!: "+(e.SyntaxKind?e.SyntaxKind[t.kind]:t.kind));var r=D;D=t.parent&&e.isSourceFile(t.parent)&&!(e.isExternalModule(t.parent)&&A);var a=Ee(t);D=r,_.set(e.getOriginalNodeId(t),a)}return e.visitNodes(n,i);function i(n){if(e.isLateVisibilityPaintedStatement(n)){var t=e.getOriginalNodeId(n);if(_.has(t)){var r=_.get(t);return _.delete(t),r&&((e.isArray(r)?e.some(r,e.needsScopeMarker):e.needsScopeMarker(r))&&(I=!0),e.isSourceFile(n.parent)&&(e.isArray(r)?e.some(r,e.isExternalModuleIndicator):e.isExternalModuleIndicator(r))&&(C=!0)),r}}return n}}function ye(r){if(!De(r)){if(e.isDeclaration(r)){if(ie(r))return;if(e.hasDynamicName(r)&&!w.isLateBound(e.getParseTreeNode(r)))return}if((!e.isFunctionLike(r)||!w.isImplementationOfOverload(r))&&!e.isSemicolonClassElement(r)){var a;ue(r)&&(a=t,t=r);var i=L,o=e.canProduceDiagnostics(r),s=g,c=(178===r.kind||191===r.kind)&&255!==r.parent.kind;if((e.isMethodDeclaration(r)||e.isMethodSignature(r))&&e.hasEffectiveModifier(r,8)){if(r.symbol&&r.symbol.declarations&&r.symbol.declarations[0]!==r)return;return E(k.createPropertyDeclaration(void 0,Ie(r),r.name,void 0,void 0,void 0))}if(o&&!g&&(L=e.createGetSymbolAccessibilityDiagnosticForNode(r)),e.isTypeQueryNode(r)&&de(r.exprName,t),c&&(g=!0),f(r))switch(r.kind){case 224:(e.isEntityName(r.expression)||e.isEntityNameExpression(r.expression))&&de(r.expression,t);var l=e.visitEachChild(r,ye,n);return E(k.updateExpressionWithTypeArguments(l,l.expression,l.typeArguments));case 174:de(r.typeName,t);l=e.visitEachChild(r,ye,n);return E(k.updateTypeReferenceNode(l,l.typeName,l.typeArguments));case 171:return E(k.updateConstructSignature(r,le(r,r.typeParameters),se(r,r.parameters),ae(r,r.type)));case 167:var u=k.createConstructorDeclaration(void 0,Ie(r),se(r,r.parameters,0),void 0);return E(u);case 166:if(e.isPrivateIdentifier(r.name))return E(void 0);var d=k.createMethodDeclaration(void 0,Ie(r),void 0,r.name,r.questionToken,le(r,r.typeParameters),se(r,r.parameters),ae(r,r.type),void 0);return E(d);case 168:if(e.isPrivateIdentifier(r.name))return E(void 0);var p=ke(r,w.getAllAccessorDeclarations(r));return E(k.updateGetAccessorDeclaration(r,void 0,Ie(r),r.name,ce(r,e.hasEffectiveModifier(r,8)),ae(r,p),void 0));case 169:return e.isPrivateIdentifier(r.name)?E(void 0):E(k.updateSetAccessorDeclaration(r,void 0,Ie(r),r.name,ce(r,e.hasEffectiveModifier(r,8)),void 0));case 164:return e.isPrivateIdentifier(r.name)?E(void 0):E(k.updatePropertyDeclaration(r,void 0,Ie(r),r.name,r.questionToken,ae(r,r.type),re(r)));case 163:return e.isPrivateIdentifier(r.name)?E(void 0):E(k.updatePropertySignature(r,Ie(r),r.name,r.questionToken,ae(r,r.type)));case 165:return e.isPrivateIdentifier(r.name)?E(void 0):E(k.updateMethodSignature(r,Ie(r),r.name,r.questionToken,le(r,r.typeParameters),se(r,r.parameters),ae(r,r.type)));case 170:return E(k.updateCallSignature(r,le(r,r.typeParameters),se(r,r.parameters),ae(r,r.type)));case 172:return E(k.updateIndexSignature(r,void 0,Ie(r),se(r,r.parameters),e.visitNode(r.type,ye)||k.createKeywordTypeNode(128)));case 250:return e.isBindingPattern(r.name)?Se(r.name):(c=!0,g=!0,E(k.updateVariableDeclaration(r,r.name,void 0,ae(r,r.type),re(r))));case 160:return he(r)&&(r.default||r.constraint)?E(k.updateTypeParameterDeclaration(r,r.name,void 0,void 0)):E(e.visitEachChild(r,ye,n));case 185:var m=e.visitNode(r.checkType,ye),_=e.visitNode(r.extendsType,ye),y=t;t=r.trueType;var h=e.visitNode(r.trueType,ye);t=y;var v=e.visitNode(r.falseType,ye);return E(k.updateConditionalTypeNode(r,m,_,h,v));case 175:return E(k.updateFunctionTypeNode(r,e.visitNodes(r.typeParameters,ye),se(r,r.parameters),e.visitNode(r.type,ye)));case 176:return E(k.updateConstructorTypeNode(r,Ie(r),e.visitNodes(r.typeParameters,ye),se(r,r.parameters),e.visitNode(r.type,ye)));case 196:return e.isLiteralImportTypeNode(r)?E(k.updateImportTypeNode(r,k.updateLiteralTypeNode(r.argument,fe(r,r.argument.literal)),r.qualifier,e.visitNodes(r.typeArguments,ye,e.isTypeNode),r.isTypeOf)):E(r);default:e.Debug.assertNever(r,"Attempted to process unhandled node kind: "+e.SyntaxKind[r.kind])}return e.isTupleTypeNode(r)&&e.getLineAndCharacterOfPosition(b,r.pos).line===e.getLineAndCharacterOfPosition(b,r.end).line&&e.setEmitFlags(r,1),E(e.visitEachChild(r,ye,n))}}function E(n){return n&&o&&e.hasDynamicName(r)&&Le(r),ue(r)&&(t=a),o&&!g&&(L=i),c&&(g=s),n===r?n:n&&e.setOriginalNode(pe(n,r),r)}}function he(n){return 166===n.parent.kind&&e.hasEffectiveModifier(n.parent,8)}function ve(n){if(p(n)&&!De(n)){switch(n.kind){case 268:return e.isSourceFile(n.parent)&&(C=!0),N=!0,k.updateExportDeclaration(n,void 0,n.modifiers,n.isTypeOnly,n.exportClause,fe(n,n.moduleSpecifier));case 267:if(e.isSourceFile(n.parent)&&(C=!0),N=!0,78===n.expression.kind)return n;var t=k.createUniqueName("_default",16);L=function(){return{diagnosticMessage:e.Diagnostics.Default_export_of_the_module_has_or_is_using_private_name_0,errorNode:n}},v=n;var r=k.createVariableDeclaration(t,void 0,w.createTypeOfExpression(n.expression,n,a,O),void 0);v=void 0;var i=k.createVariableStatement(D?[k.createModifier(133)]:[],k.createVariableDeclarationList([r],2));return[i,k.updateExportAssignment(n,n.decorators,n.modifiers,t)]}var o=Ee(n);return _.set(e.getOriginalNodeId(n),o),n}}function be(n){if(e.isImportEqualsDeclaration(n)||e.hasEffectiveModifier(n,512)||!e.canHaveModifiers(n))return n;var t=k.createModifiersFromModifierFlags(27646&e.getEffectiveModifierFlags(n));return k.updateModifiers(n,t)}function Ee(n){if(!De(n)){switch(n.kind){case 261:return me(n);case 262:return _e(n)}if((!e.isDeclaration(n)||!ie(n))&&(!e.isFunctionLike(n)||!w.isImplementationOfOverload(n))){var r;ue(n)&&(r=t,t=n);var o=e.canProduceDiagnostics(n),s=L;o&&(L=e.createGetSymbolAccessibilityDiagnosticForNode(n));var c=D;switch(n.kind){case 255:return Z(k.updateTypeAliasDeclaration(n,void 0,Ie(n),n.name,e.visitNodes(n.typeParameters,ye,e.isTypeParameterDeclaration),e.visitNode(n.type,ye,e.isTypeNode)));case 254:return Z(k.updateInterfaceDeclaration(n,void 0,Ie(n),n.name,le(n,n.typeParameters),Re(n.heritageClauses),e.visitNodes(n.members,ye)));case 252:var l=Z(k.updateFunctionDeclaration(n,void 0,Ie(n),void 0,n.name,le(n,n.typeParameters),se(n,n.parameters),ae(n,n.type),void 0));if(l&&w.isExpandoFunctionDeclaration(n)){var u=w.getPropertiesOfContainerFunction(n),d=e.parseNodeFactory.createModuleDeclaration(void 0,void 0,l.name||k.createIdentifier("_default"),k.createModuleBlock([]),16);e.setParent(d,t),d.locals=e.createSymbolTable(u),d.symbol=u[0].parent;var p=[],f=e.mapDefined(u,(function(n){if(n.valueDeclaration&&e.isPropertyAccessExpression(n.valueDeclaration)){L=e.createGetSymbolAccessibilityDiagnosticForNode(n.valueDeclaration);var t=w.createTypeOfDeclaration(n.valueDeclaration,d,a,O);L=s;var r=e.unescapeLeadingUnderscores(n.escapedName),i=e.isStringANonContextualKeyword(r),o=i?k.getGeneratedNameForNode(n.valueDeclaration):k.createIdentifier(r);i&&p.push([o,r]);var c=k.createVariableDeclaration(o,void 0,t,void 0);return k.createVariableStatement(i?void 0:[k.createToken(92)],k.createVariableDeclarationList([c]))}}));p.length?f.push(k.createExportDeclaration(void 0,void 0,!1,k.createNamedExports(e.map(p,(function(e){var n=e[0],t=e[1];return k.createExportSpecifier(n,t)}))))):f=e.mapDefined(f,(function(e){return k.updateModifiers(e,0)}));var m=k.createModuleDeclaration(void 0,Ie(n),n.name,k.createModuleBlock(f),16);if(!e.hasEffectiveModifier(l,512))return[l,m];var g=k.createModifiersFromModifierFlags(-514&e.getEffectiveModifierFlags(l)|2),y=k.updateFunctionDeclaration(l,void 0,g,void 0,l.name,l.typeParameters,l.parameters,l.type,void 0),b=k.updateModuleDeclaration(m,void 0,g,m.name,m.body),E=k.createExportAssignment(void 0,void 0,!1,m.name);return e.isSourceFile(n.parent)&&(C=!0),N=!0,[y,b,E]}return l;case 257:D=!1;var T=n.body;if(T&&258===T.kind){var S=I,x=N;N=!1,I=!1;var A=e.visitNodes(T.statements,ve),R=ge(A);8388608&n.flags&&(I=!1),e.isGlobalScopeAugmentation(n)||Ce(R)||N||(R=I?k.createNodeArray(i(i([],R),[e.createEmptyExports(k)])):e.visitNodes(R,be));var P=k.updateModuleBlock(T,R);D=c,I=S,N=x;var M=Ie(n);return Z(k.updateModuleDeclaration(n,void 0,M,e.isExternalModuleAugmentation(n)?fe(n,n.name):n.name,P))}D=c;M=Ie(n);D=!1,e.visitNode(T,ve);var F=e.getOriginalNodeId(T);P=_.get(F);return _.delete(F),Z(k.updateModuleDeclaration(n,void 0,M,n.name,P));case 253:h=n.name,v=n;g=k.createNodeArray(Ie(n));var G=le(n,n.typeParameters),B=e.getFirstConstructorWithBody(n),U=void 0;if(B){var V=L;U=e.compact(e.flatMap(B.parameters,(function(n){if(e.hasSyntacticModifier(n,16476)&&!De(n))return L=e.createGetSymbolAccessibilityDiagnosticForNode(n),78===n.name.kind?pe(k.createPropertyDeclaration(void 0,Ie(n),n.name,n.questionToken,ae(n,n.type),re(n)),n):t(n.name);function t(r){for(var a,i=0,o=r.elements;i<o.length;i++){var s=o[i];e.isOmittedExpression(s)||(e.isBindingPattern(s.name)&&(a=e.concatenate(a,t(s.name))),a=a||[],a.push(k.createPropertyDeclaration(void 0,Ie(n),s.name,void 0,ae(s,void 0),void 0)))}return a}}))),L=V}var j=e.some(n.members,(function(n){return!!n.name&&e.isPrivateIdentifier(n.name)})),K=j?[k.createPropertyDeclaration(void 0,void 0,k.createPrivateIdentifier("#private"),void 0,void 0,void 0)]:void 0,H=e.concatenate(e.concatenate(K,U),e.visitNodes(n.members,ye)),W=k.createNodeArray(H),z=e.getEffectiveBaseTypeNode(n);if(z&&!e.isEntityNameExpression(z.expression)&&103!==z.expression.kind){var q=n.name?e.unescapeLeadingUnderscores(n.name.escapedText):"default",J=k.createUniqueName(q+"_base",16);L=function(){return{diagnosticMessage:e.Diagnostics.extends_clause_of_exported_class_0_has_or_is_using_private_name_1,errorNode:z,typeName:n.name}};var X=k.createVariableDeclaration(J,void 0,w.createTypeOfExpression(z.expression,n,a,O),void 0),Y=k.createVariableStatement(D?[k.createModifier(133)]:[],k.createVariableDeclarationList([X],2)),Q=k.createNodeArray(e.map(n.heritageClauses,(function(n){if(93===n.token){var t=L;L=e.createGetSymbolAccessibilityDiagnosticForNode(n.types[0]);var r=k.updateHeritageClause(n,e.map(n.types,(function(n){return k.updateExpressionWithTypeArguments(n,J,e.visitNodes(n.typeArguments,ye))})));return L=t,r}return k.updateHeritageClause(n,e.visitNodes(k.createNodeArray(e.filter(n.types,(function(n){return e.isEntityNameExpression(n.expression)||103===n.expression.kind}))),ye))})));return[Y,Z(k.updateClassDeclaration(n,void 0,g,n.name,G,Q,W))]}Q=Re(n.heritageClauses);return Z(k.updateClassDeclaration(n,void 0,g,n.name,G,Q,W));case 233:return Z(Te(n));case 256:return Z(k.updateEnumDeclaration(n,void 0,k.createNodeArray(Ie(n)),n.name,k.createNodeArray(e.mapDefined(n.members,(function(e){if(!De(e)){var n=w.getConstantValue(e);return pe(k.updateEnumMember(e,e.name,void 0!==n?"string"===typeof n?k.createStringLiteral(n):k.createNumericLiteral(n):void 0),e)}})))))}return e.Debug.assertNever(n,"Unhandled top-level node in declaration emit: "+e.SyntaxKind[n.kind])}}function Z(a){return ue(n)&&(t=r),o&&(L=s),257===n.kind&&(D=c),a===n?a:(v=void 0,h=void 0,a&&e.setOriginalNode(pe(a,n),n))}}function Te(n){if(e.forEach(n.declarationList.declarations,oe)){var t=e.visitNodes(n.declarationList.declarations,ye);if(e.length(t))return k.updateVariableStatement(n,k.createNodeArray(Ie(n)),k.updateVariableDeclarationList(n.declarationList,t))}}function Se(n){return e.flatten(e.mapDefined(n.elements,(function(e){return xe(e)})))}function xe(n){if(223!==n.kind&&n.name){if(!oe(n))return;return e.isBindingPattern(n.name)?Se(n.name):k.createVariableDeclaration(n.name,void 0,ae(n,void 0),void 0)}}function Le(n){var r;g||(r=L,L=e.createGetSymbolAccessibilityDiagnosticForNodeName(n)),h=n.name,e.Debug.assert(w.isLateBound(e.getParseTreeNode(n)));var a=n,i=a.name.expression;de(i,t),g||(L=r),h=void 0}function De(e){return!!F&&!!e&&r(e,b)}function Ae(n){return e.isExportAssignment(n)||e.isExportDeclaration(n)}function Ce(n){return e.some(n,Ae)}function Ie(n){var t=e.getEffectiveModifierFlags(n),r=Ne(n);return t===r?n.modifiers:k.createModifiersFromModifierFlags(r)}function Ne(n){var t=11003,r=D&&!s(n)?2:0,a=298===n.parent.kind;return(!a||A&&a&&e.isExternalModule(n.parent))&&(t^=2,r=0),l(n,t,r)}function ke(n,t){var r=u(n);return r||n===t.firstAccessor||(r=u(t.firstAccessor),L=e.createGetSymbolAccessibilityDiagnosticForNode(t.firstAccessor)),!r&&t.secondAccessor&&n!==t.secondAccessor&&(r=u(t.secondAccessor),L=e.createGetSymbolAccessibilityDiagnosticForNode(t.secondAccessor)),r}function Re(n){return k.createNodeArray(e.filter(e.map(n,(function(n){return k.updateHeritageClause(n,e.visitNodes(k.createNodeArray(e.filter(n.types,(function(t){return e.isEntityNameExpression(t.expression)||93===n.token&&103===t.expression.kind}))),ye))})),(function(e){return e.types&&!!e.types.length})))}}function s(e){return 254===e.kind}function c(n,t,r){return e.factory.createModifiersFromModifierFlags(l(n,t,r))}function l(n,t,r){void 0===t&&(t=27643),void 0===r&&(r=0);var a=e.getEffectiveModifierFlags(n)&t|r;return 512&a&&!(1&a)&&(a^=1),512&a&&2&a&&(a^=2),a}function u(e){if(e)return 168===e.kind?e.type:e.parameters.length>0?e.parameters[0].type:void 0}function d(n){switch(n.kind){case 164:case 163:return!e.hasEffectiveModifier(n,8);case 161:case 250:return!0}return!1}function p(e){switch(e.kind){case 252:case 257:case 261:case 254:case 253:case 255:case 256:case 233:case 262:case 268:case 267:return!0}return!1}function f(e){switch(e.kind){case 171:case 167:case 166:case 168:case 169:case 164:case 163:case 165:case 170:case 172:case 250:case 160:case 224:case 174:case 185:case 175:case 176:case 196:return!0}return!1}e.transformDeclarations=o}(d||(d={})),function(e){function n(n){switch(n){case e.ModuleKind.ESNext:case e.ModuleKind.ES2020:case e.ModuleKind.ES2015:return e.transformECMAScriptModule;case e.ModuleKind.System:return e.transformSystemModule;default:return e.transformModule}}var t,r;function a(e,n,t){return{scriptTransformers:o(e,n,t),declarationTransformers:s(n)}}function o(t,r,a){if(a)return e.emptyArray;var i=e.getEmitScriptTarget(t),o=e.getEmitModuleKind(t),s=[];return e.addRange(s,r&&e.map(r.before,u)),s.push(e.transformTypeScript),s.push(e.transformClassFields),e.getJSXTransformEnabled(t)&&s.push(e.transformJsx),i<99&&s.push(e.transformESNext),i<8&&s.push(e.transformES2021),i<7&&s.push(e.transformES2020),i<6&&s.push(e.transformES2019),i<5&&s.push(e.transformES2018),i<4&&s.push(e.transformES2017),i<3&&s.push(e.transformES2016),i<2&&(s.push(e.transformES2015),s.push(e.transformGenerators)),s.push(n(o)),i<1&&s.push(e.transformES5),e.addRange(s,r&&e.map(r.after,u)),s}function s(n){var t=[];return t.push(e.transformDeclarations),e.addRange(t,n&&e.map(n.afterDeclarations,d)),t}function c(n){return function(t){return e.isBundle(t)?n.transformBundle(t):n.transformSourceFile(t)}}function l(e,n){return function(t){var r=e(t);return"function"===typeof r?n(t,r):c(r)}}function u(n){return l(n,e.chainBundle)}function d(e){return l(e,(function(e,n){return n}))}function p(e,n){return n}function f(e,n,t){t(e,n)}function m(n,t,r,a,o,s,c){for(var l,u,d,m,_,g=new Array(345),y=0,h=[],v=[],b=[],E=[],T=0,S=!1,x=[],L=0,D=p,A=f,C=0,I=[],N={factory:r,getCompilerOptions:function(){return a},getEmitResolver:function(){return n},getEmitHost:function(){return t},getEmitHelperFactory:e.memoize((function(){return e.createEmitHelperFactory(N)})),startLexicalEnvironment:X,suspendLexicalEnvironment:Y,resumeLexicalEnvironment:Q,endLexicalEnvironment:Z,setLexicalEnvironmentFlags:$,getLexicalEnvironmentFlags:ee,hoistVariableDeclaration:z,hoistFunctionDeclaration:q,addInitializationStatement:J,startBlockScope:ne,endBlockScope:te,addBlockScopedVariable:re,requestEmitHelper:ae,readEmitHelpers:ie,enableSubstitution:U,enableEmitNotification:K,isSubstitutionEnabled:V,isEmitNotificationEnabled:H,get onSubstituteNode(){return D},set onSubstituteNode(n){e.Debug.assert(C<1,"Cannot modify transformation hooks after initialization has completed."),e.Debug.assert(void 0!==n,"Value must not be 'undefined'"),D=n},get onEmitNode(){return A},set onEmitNode(n){e.Debug.assert(C<1,"Cannot modify transformation hooks after initialization has completed."),e.Debug.assert(void 0!==n,"Value must not be 'undefined'"),A=n},addDiagnostic:function(e){I.push(e)}},k=0,R=o;k<R.length;k++){var O=R[k];e.disposeEmitNodes(e.getSourceFileOfNode(e.getParseTreeNode(O)))}e.performance.mark("beforeTransform");var w=s.map((function(e){return e(N)})),P=function(e){for(var n=0,t=w;n<t.length;n++){var r=t[n];e=r(e)}return e};C=1;for(var M=[],F=0,G=o;F<G.length;F++){O=G[F];null===e.tracing||void 0===e.tracing||e.tracing.push("emit","transformNodes",298===O.kind?{path:O.path}:{kind:O.kind,pos:O.pos,end:O.end}),M.push((c?P:B)(O)),null===e.tracing||void 0===e.tracing||e.tracing.pop()}return C=2,e.performance.mark("afterTransform"),e.performance.measure("transformTime","beforeTransform","afterTransform"),{transformed:M,substituteNode:j,emitNodeWithNotification:W,isEmitNotificationEnabled:H,dispose:oe,diagnostics:I};function B(n){return!n||e.isSourceFile(n)&&n.isDeclarationFile?n:P(n)}function U(n){e.Debug.assert(C<2,"Cannot modify the transformation context after transformation has completed."),g[n]|=1}function V(n){return 0!==(1&g[n.kind])&&0===(4&e.getEmitFlags(n))}function j(n,t){return e.Debug.assert(C<3,"Cannot substitute a node after the result is disposed."),t&&V(t)&&D(n,t)||t}function K(n){e.Debug.assert(C<2,"Cannot modify the transformation context after transformation has completed."),g[n]|=2}function H(n){return 0!==(2&g[n.kind])||0!==(2&e.getEmitFlags(n))}function W(n,t,r){e.Debug.assert(C<3,"Cannot invoke TransformationResult callbacks after the result is disposed."),t&&(H(t)?A(n,t,r):r(n,t))}function z(n){e.Debug.assert(C>0,"Cannot modify the lexical environment during initialization."),e.Debug.assert(C<2,"Cannot modify the lexical environment after transformation has completed.");var t=e.setEmitFlags(r.createVariableDeclaration(n),64);l?l.push(t):l=[t],1&y&&(y|=2)}function q(n){e.Debug.assert(C>0,"Cannot modify the lexical environment during initialization."),e.Debug.assert(C<2,"Cannot modify the lexical environment after transformation has completed."),e.setEmitFlags(n,1048576),u?u.push(n):u=[n]}function J(n){e.Debug.assert(C>0,"Cannot modify the lexical environment during initialization."),e.Debug.assert(C<2,"Cannot modify the lexical environment after transformation has completed."),e.setEmitFlags(n,1048576),d?d.push(n):d=[n]}function X(){e.Debug.assert(C>0,"Cannot modify the lexical environment during initialization."),e.Debug.assert(C<2,"Cannot modify the lexical environment after transformation has completed."),e.Debug.assert(!S,"Lexical environment is suspended."),h[T]=l,v[T]=u,b[T]=d,E[T]=y,T++,l=void 0,u=void 0,d=void 0,y=0}function Y(){e.Debug.assert(C>0,"Cannot modify the lexical environment during initialization."),e.Debug.assert(C<2,"Cannot modify the lexical environment after transformation has completed."),e.Debug.assert(!S,"Lexical environment is already suspended."),S=!0}function Q(){e.Debug.assert(C>0,"Cannot modify the lexical environment during initialization."),e.Debug.assert(C<2,"Cannot modify the lexical environment after transformation has completed."),e.Debug.assert(S,"Lexical environment is not suspended."),S=!1}function Z(){var n;if(e.Debug.assert(C>0,"Cannot modify the lexical environment during initialization."),e.Debug.assert(C<2,"Cannot modify the lexical environment after transformation has completed."),e.Debug.assert(!S,"Lexical environment is suspended."),l||u||d){if(u&&(n=i([],u)),l){var t=r.createVariableStatement(void 0,r.createVariableDeclarationList(l));e.setEmitFlags(t,1048576),n?n.push(t):n=[t]}d&&(n=i(n?i([],n):[],d))}return T--,l=h[T],u=v[T],d=b[T],y=E[T],0===T&&(h=[],v=[],b=[],E=[]),n}function $(e,n){y=n?y|e:y&~e}function ee(){return y}function ne(){e.Debug.assert(C>0,"Cannot start a block scope during initialization."),e.Debug.assert(C<2,"Cannot start a block scope after transformation has completed."),x[L]=m,L++,m=void 0}function te(){e.Debug.assert(C>0,"Cannot end a block scope during initialization."),e.Debug.assert(C<2,"Cannot end a block scope after transformation has completed.");var n=e.some(m)?[r.createVariableStatement(void 0,r.createVariableDeclarationList(m.map((function(e){return r.createVariableDeclaration(e)})),1))]:void 0;return L--,m=x[L],0===L&&(x=[]),n}function re(n){e.Debug.assert(L>0,"Cannot add a block scoped variable outside of an iteration body."),(m||(m=[])).push(n)}function ae(n){if(e.Debug.assert(C>0,"Cannot modify the transformation context during initialization."),e.Debug.assert(C<2,"Cannot modify the transformation context after transformation has completed."),e.Debug.assert(!n.scoped,"Cannot request a scoped emit helper."),n.dependencies)for(var t=0,r=n.dependencies;t<r.length;t++){var a=r[t];ae(a)}_=e.append(_,n)}function ie(){e.Debug.assert(C>0,"Cannot modify the transformation context during initialization."),e.Debug.assert(C<2,"Cannot modify the transformation context after transformation has completed.");var n=_;return _=void 0,n}function oe(){if(C<3){for(var n=0,t=o;n<t.length;n++){var r=t[n];e.disposeEmitNodes(e.getSourceFileOfNode(e.getParseTreeNode(r)))}l=void 0,h=void 0,u=void 0,v=void 0,D=void 0,A=void 0,_=void 0,C=3}}}(function(e){e[e["Uninitialized"]=0]="Uninitialized",e[e["Initialized"]=1]="Initialized",e[e["Completed"]=2]="Completed",e[e["Disposed"]=3]="Disposed"})(t||(t={})),function(e){e[e["Substitution"]=1]="Substitution",e[e["EmitNotifications"]=2]="EmitNotifications"}(r||(r={})),e.noTransformers={scriptTransformers:e.emptyArray,declarationTransformers:e.emptyArray},e.getTransformers=a,e.noEmitSubstitution=p,e.noEmitNotification=f,e.transformNodes=m,e.nullTransformationContext={factory:e.factory,getCompilerOptions:function(){return{}},getEmitResolver:e.notImplemented,getEmitHost:e.notImplemented,getEmitHelperFactory:e.notImplemented,startLexicalEnvironment:e.noop,resumeLexicalEnvironment:e.noop,suspendLexicalEnvironment:e.noop,endLexicalEnvironment:e.returnUndefined,setLexicalEnvironmentFlags:e.noop,getLexicalEnvironmentFlags:function(){return 0},hoistVariableDeclaration:e.noop,hoistFunctionDeclaration:e.noop,addInitializationStatement:e.noop,startBlockScope:e.noop,endBlockScope:e.returnUndefined,addBlockScopedVariable:e.noop,requestEmitHelper:e.noop,readEmitHelpers:e.notImplemented,enableSubstitution:e.noop,enableEmitNotification:e.noop,isSubstitutionEnabled:e.notImplemented,isEmitNotificationEnabled:e.notImplemented,onSubstituteNode:p,onEmitNode:f,addDiagnostic:e.noop}}(d||(d={})),function(e){var n,t,r=I();function a(n){return e.fileExtensionIs(n,".tsbuildinfo")}function o(n,t,r,a,i,o){void 0===a&&(a=!1);var c=e.isArray(r)?r:e.getSourceFilesToEmit(n,r,a),u=n.getCompilerOptions();if(e.outFile(u)){var d=n.getPrependNodes();if(c.length||d.length){var p=e.factory.createBundle(c,d),f=t(l(p,n,a),p);if(f)return f}}else{if(!i)for(var m=0,_=c;m<_.length;m++){var g=_[m];f=t(l(g,n,a),g);if(f)return f}if(o){var y=s(u);if(y)return t({buildInfoPath:y},void 0)}}}function s(n){var t=n.configFilePath;if(e.isIncrementalCompilation(n)){if(n.tsBuildInfoFile)return n.tsBuildInfoFile;var r,a=e.outFile(n);if(a)r=e.removeFileExtension(a);else{if(!t)return;var i=e.removeFileExtension(t);r=n.outDir?n.rootDir?e.resolvePath(n.outDir,e.getRelativePathFromDirectory(n.rootDir,i,!0)):e.combinePaths(n.outDir,e.getBaseFileName(i)):i}return r+".tsbuildinfo"}}function c(n,t){var r=e.outFile(n),a=n.emitDeclarationOnly?void 0:r,i=a&&u(a,n),o=t||e.getEmitDeclarations(n)?e.removeFileExtension(r)+".d.ts":void 0,c=o&&e.getAreDeclarationMapsEnabled(n)?o+".map":void 0,l=s(n);return{jsFilePath:a,sourceMapFilePath:i,declarationFilePath:o,declarationMapPath:c,buildInfoPath:l}}function l(n,t,r){var a=t.getCompilerOptions();if(299===n.kind)return c(a,r);var i=e.getOwnEmitOutputFilePath(n.fileName,t,d(n,a)),o=e.isJsonSourceFile(n),s=o&&0===e.comparePaths(n.fileName,i,t.getCurrentDirectory(),!t.useCaseSensitiveFileNames()),l=a.emitDeclarationOnly||s?void 0:i,p=!l||e.isJsonSourceFile(n)?void 0:u(l,a),f=r||e.getEmitDeclarations(a)&&!o?e.getDeclarationEmitOutputFilePath(n.fileName,t):void 0,m=f&&e.getAreDeclarationMapsEnabled(a)?f+".map":void 0;return{jsFilePath:l,sourceMapFilePath:p,declarationFilePath:f,declarationMapPath:m,buildInfoPath:void 0}}function u(e,n){return n.sourceMap&&!n.inlineSourceMap?e+".map":void 0}function d(n,t){if(e.isJsonSourceFile(n))return".json";if(1===t.jsx)if(e.isSourceFileJS(n)){if(e.fileExtensionIs(n.fileName,".jsx"))return".jsx"}else if(1===n.languageVariant)return".jsx";return".js"}function p(n,t,r,a,i){return a?e.resolvePath(a,e.getRelativePathFromDirectory(i?i():v(t,r),n,r)):n}function f(n,t,r,a){return e.Debug.assert(!e.fileExtensionIs(n,".d.ts")&&!e.fileExtensionIs(n,".json")),e.changeExtension(p(n,t,r,t.options.declarationDir||t.options.outDir,a),".d.ts")}function m(n,t,r,a){if(!t.options.emitDeclarationOnly){var i=e.fileExtensionIs(n,".json"),o=e.changeExtension(p(n,t,r,t.options.outDir,a),i?".json":1===t.options.jsx&&(e.fileExtensionIs(n,".tsx")||e.fileExtensionIs(n,".jsx"))?".jsx":".js");return i&&0===e.comparePaths(n,o,e.Debug.checkDefined(t.options.configFilePath),r)?void 0:o}}function _(){var n;return{addOutput:t,getOutputs:r};function t(e){e&&(n||(n=[])).push(e)}function r(){return n||e.emptyArray}}function g(e,n){var t=c(e.options,!1),r=t.jsFilePath,a=t.sourceMapFilePath,i=t.declarationFilePath,o=t.declarationMapPath,s=t.buildInfoPath;n(r),n(a),n(i),n(o),n(s)}function y(n,t,r,a,i){if(!e.fileExtensionIs(t,".d.ts")){var o=m(t,n,r,i);if(a(o),!e.fileExtensionIs(t,".json")&&(o&&n.options.sourceMap&&a(o+".map"),e.getEmitDeclarations(n.options))){var s=f(t,n,r,i);a(s),n.options.declarationMap&&a(s+".map")}}}function h(n,t,r,a,i){var o;return n.rootDir?(o=e.getNormalizedAbsolutePath(n.rootDir,r),null===i||void 0===i||i(n.rootDir)):n.composite&&n.configFilePath?(o=e.getDirectoryPath(e.normalizeSlashes(n.configFilePath)),null===i||void 0===i||i(o)):o=e.computeCommonSourceDirectoryOfFilenames(t(),r,a),o&&o[o.length-1]!==e.directorySeparator&&(o+=e.directorySeparator),o}function v(n,t){var r=n.options,a=n.fileNames;return h(r,(function(){return e.filter(a,(function(n){return!(r.noEmitForJsFiles&&e.fileExtensionIsOneOf(n,e.supportedJSExtensions))&&!e.fileExtensionIs(n,".d.ts")}))}),e.getDirectoryPath(e.normalizeSlashes(e.Debug.checkDefined(r.configFilePath))),e.createGetCanonicalFileName(!t))}function b(n,t){var r=_(),a=r.addOutput,i=r.getOutputs;if(e.outFile(n.options))g(n,a);else{for(var o=e.memoize((function(){return v(n,t)})),c=0,l=n.fileNames;c<l.length;c++){var u=l[c];y(n,u,t,a,o)}a(s(n.options))}return i()}function E(n,t,r){t=e.normalizePath(t),e.Debug.assert(e.contains(n.fileNames,t),"Expected fileName to be present in command line");var a=_(),i=a.addOutput,o=a.getOutputs;return e.outFile(n.options)?g(n,i):y(n,t,r,i),o()}function T(n,t){if(e.outFile(n.options)){var r=c(n.options,!1).jsFilePath;return e.Debug.checkDefined(r,"project "+n.options.configFilePath+" expected to have at least one output")}for(var a=e.memoize((function(){return v(n,t)})),i=0,o=n.fileNames;i<o.length;i++){var l=o[i];if(!e.fileExtensionIs(l,".d.ts")){r=m(l,n,t,a);if(r)return r;if(!e.fileExtensionIs(l,".json")&&e.getEmitDeclarations(n.options))return f(l,n,t,a)}}var u=s(n.options);return u||e.Debug.fail("project "+n.options.configFilePath+" expected to have at least one output")}function S(n,t,r,a,i,s,c){var l,u,d=a.scriptTransformers,p=a.declarationTransformers,f=t.getCompilerOptions(),m=f.sourceMap||f.inlineSourceMap||e.getAreDeclarationMapsEnabled(f)?[]:void 0,_=f.listEmittedFiles?[]:void 0,g=e.createDiagnosticCollection(),y=e.getNewLineCharacter(f,(function(){return t.getNewLine()})),h=e.createTextWriter(y),v=e.performance.createTimer("printTime","beforePrint","afterPrint"),b=v.enter,E=v.exit,T=!1;return b(),o(t,S,e.getSourceFilesToEmit(t,r,c),c,s,!r),E(),{emitSkipped:T,diagnostics:g.getDiagnostics(),emittedFiles:_,sourceMaps:m,exportedModulesFromDeclarationEmit:u};function S(n,r){var a,o=n.jsFilePath,s=n.sourceMapFilePath,c=n.declarationFilePath,u=n.declarationMapPath,d=n.buildInfoPath;function p(n){return e.ensurePathIsNonModuleName(e.getRelativePathFromDirectory(a,n,t.getCanonicalFileName))}d&&r&&e.isBundle(r)&&(a=e.getDirectoryPath(e.getNormalizedAbsolutePath(d,t.getCurrentDirectory())),l={commonSourceDirectory:p(t.getCommonSourceDirectory()),sourceFiles:r.sourceFiles.map((function(n){return p(e.getNormalizedAbsolutePath(n.fileName,t.getCurrentDirectory()))}))}),null===e.tracing||void 0===e.tracing||e.tracing.push("emit","emitJsFileOrBundle",{jsFilePath:o}),D(r,o,s,p),null===e.tracing||void 0===e.tracing||e.tracing.pop(),null===e.tracing||void 0===e.tracing||e.tracing.push("emit","emitDeclarationFileOrBundle",{declarationFilePath:c}),A(r,c,u,p),null===e.tracing||void 0===e.tracing||e.tracing.pop(),null===e.tracing||void 0===e.tracing||e.tracing.push("emit","emitBuildInfo",{buildInfoPath:d}),L(l,d),null===e.tracing||void 0===e.tracing||e.tracing.pop(),!T&&_&&(i||(o&&_.push(o),s&&_.push(s),d&&_.push(d)),c&&_.push(c),u&&_.push(u))}function L(n,a){if(a&&!r&&!T){var i=t.getProgramBuildInfo();if(t.isEmitBlocked(a))T=!0;else{var o=e.version;e.writeFile(t,g,a,x({bundle:n,program:i,version:o}),!1)}}}function D(r,a,o,s){if(r&&!i&&a)if(a&&t.isEmitBlocked(a)||f.noEmit)T=!0;else{var c=e.transformNodes(n,t,e.factory,f,[r],d,!1),u={removeComments:f.removeComments,newLine:f.newLine,noEmitHelpers:f.noEmitHelpers,module:f.module,target:f.target,sourceMap:f.sourceMap,inlineSourceMap:f.inlineSourceMap,inlineSources:f.inlineSources,extendedDiagnostics:f.extendedDiagnostics,writeBundleFileInfo:!!l,relativeToBuildInfo:s},p=C(u,{hasGlobalName:n.hasGlobalName,onEmitNode:c.emitNodeWithNotification,isEmitNotificationEnabled:c.isEmitNotificationEnabled,substituteNode:c.substituteNode});e.Debug.assert(1===c.transformed.length,"Should only see one output from the transform"),N(a,o,c.transformed[0],p,f),c.dispose(),l&&(l.js=p.bundleFileInfo)}}function A(r,a,o,s){if(r)if(a){var d=e.isSourceFile(r)?[r]:r.sourceFiles,m=c?d:e.filter(d,e.isSourceFileNotJson),_=e.outFile(f)?[e.factory.createBundle(m,e.isSourceFile(r)?void 0:r.prepends)]:m;i&&!e.getEmitDeclarations(f)&&m.forEach(I);var y=e.transformNodes(n,t,e.factory,f,_,p,!1);if(e.length(y.diagnostics))for(var h=0,v=y.diagnostics;h<v.length;h++){var b=v[h];g.add(b)}var E={removeComments:f.removeComments,newLine:f.newLine,noEmitHelpers:!0,module:f.module,target:f.target,sourceMap:f.sourceMap,inlineSourceMap:f.inlineSourceMap,extendedDiagnostics:f.extendedDiagnostics,onlyPrintJsDocStyle:!0,writeBundleFileInfo:!!l,recordInternalSection:!!l,relativeToBuildInfo:s},S=C(E,{hasGlobalName:n.hasGlobalName,onEmitNode:y.emitNodeWithNotification,isEmitNotificationEnabled:y.isEmitNotificationEnabled,substituteNode:y.substituteNode}),x=!!y.diagnostics&&!!y.diagnostics.length||!!t.isEmitBlocked(a)||!!f.noEmit;if(T=T||x,(!x||c)&&(e.Debug.assert(1===y.transformed.length,"Should only see one output from the decl transform"),N(a,o,y.transformed[0],S,{sourceMap:!c&&f.declarationMap,sourceRoot:f.sourceRoot,mapRoot:f.mapRoot,extendedDiagnostics:f.extendedDiagnostics}),c&&298===y.transformed[0].kind)){var L=y.transformed[0];u=L.exportedModulesFromDeclarationEmit}y.dispose(),l&&(l.dts=S.bundleFileInfo)}else(i||f.emitDeclarationOnly)&&(T=!0)}function I(t){e.isExportAssignment(t)?78===t.expression.kind&&n.collectLinkedAliases(t.expression,!0):e.isExportSpecifier(t)?n.collectLinkedAliases(t.propertyName||t.name,!0):e.forEachChild(t,I)}function N(n,r,a,i,o){var s,c=299===a.kind?a:void 0,l=298===a.kind?a:void 0,u=c?c.sourceFiles:[l];if(k(o,a)&&(s=e.createSourceMapGenerator(t,e.getBaseFileName(e.normalizeSlashes(n)),R(o),O(o,n,l),o)),c?i.writeBundle(c,h,s):i.writeFile(l,h,s),s){m&&m.push({inputSourceFileNames:s.getSources(),sourceMap:s.toJSON()});var d=w(o,s,n,r,l);if(d&&(h.isAtStartOfLine()||h.rawWrite(y),h.writeComment("//# sourceMappingURL="+d)),r){var p=s.toString();e.writeFile(t,g,r,p,!1,u)}}else h.writeLine();e.writeFile(t,g,n,h.getText(),!!f.emitBOM,u),h.clear()}function k(n,t){return(n.sourceMap||n.inlineSourceMap)&&(298!==t.kind||!e.fileExtensionIs(t.fileName,".json"))}function R(n){var t=e.normalizeSlashes(n.sourceRoot||"");return t?e.ensureTrailingDirectorySeparator(t):t}function O(n,r,a){if(n.sourceRoot)return t.getCommonSourceDirectory();if(n.mapRoot){var i=e.normalizeSlashes(n.mapRoot);return a&&(i=e.getDirectoryPath(e.getSourceFilePathInNewDir(a.fileName,t,i))),0===e.getRootLength(i)&&(i=e.combinePaths(t.getCommonSourceDirectory(),i)),i}return e.getDirectoryPath(e.normalizePath(r))}function w(n,r,a,i,o){if(n.inlineSourceMap){var s=r.toString(),c=e.base64encode(e.sys,s);return"data:application/json;base64,"+c}var l=e.getBaseFileName(e.normalizeSlashes(e.Debug.checkDefined(i)));if(n.mapRoot){var u=e.normalizeSlashes(n.mapRoot);return o&&(u=e.getDirectoryPath(e.getSourceFilePathInNewDir(o.fileName,t,u))),0===e.getRootLength(u)?(u=e.combinePaths(t.getCommonSourceDirectory(),u),encodeURI(e.getRelativePathToDirectoryOrUrl(e.getDirectoryPath(e.normalizePath(a)),e.combinePaths(u,l),t.getCurrentDirectory(),t.getCanonicalFileName,!0))):encodeURI(e.combinePaths(u,l))}return encodeURI(l)}}function x(e){return JSON.stringify(e)}function L(e){return JSON.parse(e)}function D(n,t,r){var a,i=e.Debug.checkDefined(n.js),o=(null===(a=i.sources)||void 0===a?void 0:a.prologues)&&e.arrayToMap(i.sources.prologues,(function(e){return e.file}));return n.sourceFiles.map((function(n,a){var i,s,c=null===o||void 0===o?void 0:o.get(a),l=null===c||void 0===c?void 0:c.directives.map((function(n){var t=e.setTextRange(e.factory.createStringLiteral(n.expression.text),n.expression),r=e.setTextRange(e.factory.createExpressionStatement(t),n);return e.setParent(t,r),r})),u=e.factory.createToken(1),d=e.factory.createSourceFile(null!==l&&void 0!==l?l:[],u,0);return d.fileName=e.getRelativePathFromDirectory(r.getCurrentDirectory(),e.getNormalizedAbsolutePath(n,t),!r.useCaseSensitiveFileNames()),d.text=null!==(i=null===c||void 0===c?void 0:c.text)&&void 0!==i?i:"",e.setTextRangePosWidth(d,0,null!==(s=null===c||void 0===c?void 0:c.text.length)&&void 0!==s?s:0),e.setEachParent(d.statements,d),e.setTextRangePosWidth(u,d.end,0),e.setParent(u,d),d}))}function A(n,t,r,a){var o=c(n.options,!1),s=o.buildInfoPath,l=o.jsFilePath,u=o.sourceMapFilePath,d=o.declarationFilePath,p=o.declarationMapPath,f=t.readFile(e.Debug.checkDefined(s));if(!f)return s;var m=t.readFile(e.Debug.checkDefined(l));if(!m)return l;var _=u&&t.readFile(u);if(u&&!_||n.options.inlineSourceMap)return u||"inline sourcemap decoding";var g=d&&t.readFile(d);if(d&&!g)return d;var y=p&&t.readFile(p);if(p&&!y||n.options.inlineSourceMap)return p||"inline sourcemap decoding";var h=L(f);if(!h.bundle||!h.bundle.js||g&&!h.bundle.dts)return s;var v=e.getDirectoryPath(e.getNormalizedAbsolutePath(s,t.getCurrentDirectory())),b=e.createInputFiles(m,g,u,_,p,y,l,d,s,h,!0),E=[],T=e.createPrependNodes(n.projectReferences,r,(function(e){return t.readFile(e)})),A=D(h.bundle,v,t),C={getPrependNodes:e.memoize((function(){return i(i([],T),[b])})),getCanonicalFileName:t.getCanonicalFileName,getCommonSourceDirectory:function(){return e.getNormalizedAbsolutePath(h.bundle.commonSourceDirectory,v)},getCompilerOptions:function(){return n.options},getCurrentDirectory:function(){return t.getCurrentDirectory()},getNewLine:function(){return t.getNewLine()},getSourceFile:e.returnUndefined,getSourceFileByPath:e.returnUndefined,getSourceFiles:function(){return A},getLibFileFromReference:e.notImplemented,isSourceFileFromExternalLibrary:e.returnFalse,getResolvedProjectReferenceToRedirect:e.returnUndefined,getProjectReferenceRedirect:e.returnUndefined,isSourceOfProjectReferenceRedirect:e.returnFalse,writeFile:function(n,t,r){switch(n){case l:if(m===t)return;break;case u:if(_===t)return;break;case s:var a=L(t);a.program=h.program;var i=h.bundle,o=i.js,c=i.dts,f=i.sourceFiles;return a.bundle.js.sources=o.sources,c&&(a.bundle.dts.sources=c.sources),a.bundle.sourceFiles=f,void E.push({name:n,text:x(a),writeByteOrderMark:r});case d:if(g===t)return;break;case p:if(y===t)return;break;default:e.Debug.fail("Unexpected path: "+n)}E.push({name:n,text:t,writeByteOrderMark:r})},isEmitBlocked:e.returnFalse,readFile:function(e){return t.readFile(e)},fileExists:function(e){return t.fileExists(e)},useCaseSensitiveFileNames:function(){return t.useCaseSensitiveFileNames()},getProgramBuildInfo:e.returnUndefined,getSourceFileFromReference:e.returnUndefined,redirectTargetsMap:e.createMultiMap(),getFileIncludeReasons:e.notImplemented};return S(e.notImplementedResolver,C,void 0,e.getTransformers(n.options,a)),E}function C(n,t){void 0===n&&(n={}),void 0===t&&(t={});var r,a,i,o,s,c,l,u,d,p,f,m,_,g,y,h,v,b,E,T=t.hasGlobalName,S=t.onEmitNode,x=void 0===S?e.noEmitNotification:S,L=t.isEmitNotificationEnabled,D=t.substituteNode,A=void 0===D?e.noEmitSubstitution:D,C=t.onBeforeEmitNode,I=t.onAfterEmitNode,R=t.onBeforeEmitNodeArray,O=t.onAfterEmitNodeArray,w=t.onBeforeEmitToken,P=t.onAfterEmitToken,M=!!n.extendedDiagnostics,F=e.getNewLineCharacter(n),G=e.getEmitModuleKind(n),B=new e.Map,U=n.preserveSourceNewlines,V=qa,j=n.writeBundleFileInfo?{sections:[]}:void 0,K=j?e.Debug.checkDefined(n.relativeToBuildInfo):void 0,H=n.recordInternalSection,W=0,z="text",q=!0,J=-1,X=-1,Y=-1,Q=-1,Z=-1,$=!1,ee=!!n.removeComments,ne=e.performance.createTimerIf(M,"commentTime","beforeComment","afterComment"),te=ne.enter,re=ne.exit,ae=e.factory.parenthesizer,ie=_t();return De(),{printNode:oe,printList:se,printFile:le,printBundle:ce,writeNode:de,writeList:pe,writeFile:be,writeBundle:he,bundleFileInfo:j};function oe(n,t,r){switch(n){case 0:e.Debug.assert(e.isSourceFile(t),"Expected a SourceFile node.");break;case 2:e.Debug.assert(e.isIdentifier(t),"Expected an Identifier node.");break;case 1:e.Debug.assert(e.isExpression(t),"Expected an Expression node.");break}switch(t.kind){case 298:return le(t);case 299:return ce(t);case 300:return ue(t)}return de(n,t,r,Ee()),Te()}function se(e,n,t){return pe(e,n,t,Ee()),Te()}function ce(e){return he(e,Ee(),void 0),Te()}function le(e){return be(e,Ee(),void 0),Te()}function ue(e){return ve(e,Ee()),Te()}function de(e,n,t,r){var a=p;Le(r,void 0),Se(e,n,t),De(),p=a}function pe(e,n,t,r){var a=p;Le(r,void 0),t&&xe(t),ja(void 0,n,e),De(),p=a}function fe(){return p.getTextPosWithWriteLine?p.getTextPosWithWriteLine():p.getTextPos()}function me(n,t,r){var a=e.lastOrUndefined(j.sections);a&&a.kind===r?a.end=t:j.sections.push({pos:n,end:t,kind:r})}function _e(n){if(H&&j&&r&&(e.isDeclaration(n)||e.isVariableStatement(n))&&e.isInternalDeclaration(n,r)&&"internal"!==z){var t=z;return ye(p.getTextPos()),W=fe(),z="internal",t}}function ge(e){e&&(ye(p.getTextPos()),W=fe(),z=e)}function ye(e){return W<e&&(me(W,e,z),!0)}function he(n,t,r){var a;m=!1;var i=p;Le(t,r),xa(n),Ta(n),We(n),ma(n);for(var o=0,s=n.prepends;o<s.length;o++){var c=s[o];ri();var l=p.getTextPos(),u=j&&j.sections;if(u&&(j.sections=[]),Se(4,c,void 0),j){var d=j.sections;j.sections=u,c.oldFileOfCurrentEmit?(a=j.sections).push.apply(a,d):(d.forEach((function(n){return e.Debug.assert(e.isBundleFileTextLike(n))})),j.sections.push({pos:l,end:p.getTextPos(),kind:"prepend",data:K(c.fileName),texts:d}))}}W=fe();for(var f=0,_=n.sourceFiles;f<_.length;f++){var g=_[f];Se(0,g,g)}if(j&&n.sourceFiles.length){var y=p.getTextPos();if(ye(y)){var h=Sa(n);h&&(j.sources||(j.sources={}),j.sources.prologues=h);var v=He(n);v&&(j.sources||(j.sources={}),j.sources.helpers=v)}}De(),p=i}function ve(e,n){var t=p;Le(n,void 0),Se(4,e,void 0),De(),p=t}function be(e,n,t){m=!0;var r=p;Le(n,t),xa(e),Ta(e),Se(0,e,e),De(),p=r}function Ee(){return f||(f=e.createTextWriter(F))}function Te(){var e=f.getText();return f.clear(),e}function Se(e,n,t){t&&xe(t),we(e,n,void 0)}function xe(e){r=e,h=void 0,v=void 0,e&&ko(e)}function Le(t,r){t&&n.omitTrailingSemicolon&&(t=e.getTrailingSemicolonDeferringWriter(t)),p=t,_=r,q=!p||!_}function De(){a=[],i=[],o=new e.Set,s=[],c=0,l=[],r=void 0,h=void 0,v=void 0,Le(void 0,void 0)}function Ae(){return h||(h=e.getLineStarts(r))}function Ce(e,n){if(void 0!==e){var t=_e(e);we(4,e,n),ge(t)}}function Ie(e){void 0!==e&&we(2,e,void 0)}function Ne(e,n){void 0!==e&&we(1,e,n)}function ke(n){we(e.isStringLiteral(n)?6:4,n)}function Re(n){U&&134217728&e.getEmitFlags(n)&&(U=!1)}function Oe(e){U=e}function we(e,n,t){E=t;var r=Fe(0,e,n);r(e,n),E=void 0}function Pe(n){return!ee&&!e.isSourceFile(n)}function Me(n){return!q&&!e.isSourceFile(n)&&!e.isInJsonFile(n)&&!e.isUnparsedSource(n)&&!e.isUnparsedPrepend(n)}function Fe(n,t,r){switch(n){case 0:if(x!==e.noEmitNotification&&(!L||L(r)))return Be;case 1:if(A!==e.noEmitSubstitution&&(b=A(t,r)||r)!==r)return E&&(b=E(b)),Ke;case 2:if(Pe(r))return qi;case 3:if(Me(r))return xo;case 4:return Ue;default:return e.Debug.assertNever(n)}}function Ge(e,n,t){return Fe(e+1,n,t)}function Be(e,n){var t=Ge(0,e,n);x(e,n,t)}function Ue(e,n){if(null===C||void 0===C||C(n),U){var t=U;Re(n),Ve(e,n),Oe(t)}else Ve(e,n);null===I||void 0===I||I(n),E=void 0}function Ve(n,t){if(0===n)return fa(e.cast(t,e.isSourceFile));if(2===n)return $e(e.cast(t,e.isIdentifier));if(6===n)return Je(e.cast(t,e.isStringLiteral),!0);if(3===n)return je(e.cast(t,e.isTypeParameterDeclaration));if(5===n)return e.Debug.assertNode(t,e.isEmptyStatement),It(!0);if(4===n){switch(t.kind){case 15:case 16:case 17:return Je(t,!1);case 78:return $e(t);case 79:return en(t);case 158:return nn(t);case 159:return rn(t);case 160:return an(t);case 161:return on(t);case 162:return sn(t);case 163:return cn(t);case 164:return ln(t);case 165:return un(t);case 166:return dn(t);case 167:return pn(t);case 168:case 169:return fn(t);case 170:return mn(t);case 171:return _n(t);case 172:return gn(t);case 173:return vn(t);case 174:return bn(t);case 175:return En(t);case 176:return Dn(t);case 177:return An(t);case 178:return Cn(t);case 179:return In(t);case 180:return kn(t);case 181:return On(t);case 183:return wn(t);case 184:return Pn(t);case 185:return Mn(t);case 186:return Fn(t);case 187:return Gn(t);case 224:return Et(t);case 188:return Bn();case 189:return Un(t);case 190:return Vn(t);case 191:return jn(t);case 192:return Kn(t);case 193:return Rn(t);case 194:return Hn(t);case 195:return yn(t);case 196:return Wn(t);case 197:return zn(t);case 198:return qn(t);case 199:return Jn(t);case 229:return Lt(t);case 230:return hn();case 231:return Dt(t);case 233:return Ct(t);case 232:return It(!1);case 234:return Nt(t);case 235:return kt(t);case 236:return Ot(t);case 237:return wt(t);case 238:return Pt(t);case 239:return Mt(t);case 240:return Ft(t);case 241:return Bt(t);case 242:return Ut(t);case 243:return jt(t);case 244:return Kt(t);case 245:return Ht(t);case 246:return Wt(t);case 247:return zt(t);case 248:return qt(t);case 249:return Jt(t);case 250:return Xt(t);case 251:return Yt(t);case 252:return Qt(t);case 253:return ir(t);case 254:return sr(t);case 255:return cr(t);case 256:return lr(t);case 257:return ur(t);case 258:return dr(t);case 259:return pr(t);case 260:return Tr(t);case 261:return fr(t);case 262:return _r(t);case 263:return gr(t);case 264:return yr(t);case 270:return Sr(t);case 265:return hr(t);case 266:return vr(t);case 267:return br(t);case 268:return Er(t);case 269:return xr(t);case 271:return Lr(t);case 272:return;case 273:return Cr(t);case 11:return Or(t);case 276:case 279:return Rr(t);case 277:case 280:return wr(t);case 281:return Mr(t);case 282:return Pr(t);case 283:return Fr(t);case 284:return Vr(t);case 285:return Kr(t);case 286:return Hr(t);case 287:return zr(t);case 288:return qr(t);case 289:return Jr(t);case 290:return Xr(t);case 291:return Yr(t);case 292:return Qr(t);case 293:return Ye(t);case 300:case 294:return Xe(t);case 295:case 296:return Qe(t);case 297:return Ze(t);case 298:return fa(t);case 299:return e.Debug.fail("Bundles should be printed using printBundle");case 301:return e.Debug.fail("InputFiles should not be printed");case 302:return pa(t);case 303:return na(t);case 304:return Xa("*");case 305:return Xa("?");case 306:return Sn(t);case 307:return xn(t);case 308:return Ln(t);case 309:return Tn(t);case 182:case 310:return Nn(t);case 311:return;case 312:return Zr(t);case 314:return sa(t);case 315:return ca(t);case 317:case 322:return oa(t);case 318:case 319:return ta(t);case 320:case 321:return;case 323:case 324:case 325:case 326:case 327:return;case 328:return ia(t);case 330:case 337:return la(t);case 329:case 331:case 332:case 333:return $r(t);case 334:return ra(t);case 335:return aa(t);case 336:return ea(t);case 339:case 343:case 342:return}if(e.isExpression(t)&&(n=1,A!==e.noEmitSubstitution)){var r=A(n,t)||t;r!==t&&(t=r,E&&(t=E(t)))}}if(1===n)switch(t.kind){case 8:case 9:return qe(t);case 10:case 13:case 14:return Je(t,!1);case 78:return $e(t);case 200:return Xn(t);case 201:return Yn(t);case 202:return Qn(t);case 203:return $n(t);case 204:return et(t);case 205:return nt(t);case 206:return tt(t);case 207:return rt(t);case 208:return at(t);case 209:return it(t);case 210:return ot(t);case 211:return ct(t);case 212:return lt(t);case 213:return ut(t);case 214:return dt(t);case 215:return pt(t);case 216:return mt(t);case 217:return ie(t);case 218:return gt(t);case 219:return yt(t);case 220:return ht(t);case 221:return vt(t);case 222:return bt(t);case 223:return;case 225:return Tt(t);case 226:return St(t);case 227:return xt(t);case 228:return e.Debug.fail("SyntheticExpression should never be printed.");case 274:return Ir(t);case 275:return Nr(t);case 278:return kr(t);case 338:return e.Debug.fail("SyntaxList should not be printed");case 339:return;case 340:return ha(t);case 341:return va(t);case 342:case 343:return;case 344:return e.Debug.fail("SyntheticReferenceExpression should not be printed")}return e.isKeyword(t.kind)?si(t,Qa):e.isTokenKind(t.kind)?si(t,Xa):void e.Debug.fail("Unhandled SyntaxKind: "+e.Debug.formatSyntaxKind(t.kind)+".")}function je(e){Ce(e.name),ni(),Qa("in"),ni(),Ce(e.constraint)}function Ke(n,t){var r=Ge(1,n,t);e.Debug.assertIsDefined(b),t=b,b=void 0,r(n,t)}function He(t){var r;if(G!==e.ModuleKind.None&&!n.noEmitHelpers){for(var a=new e.Map,i=0,o=t.sourceFiles;i<o.length;i++){var s=o[i],c=void 0!==e.getExternalHelpersModuleName(s),l=ze(s);if(l)for(var u=0,d=l;u<d.length;u++){var p=d[u];p.scoped||c||a.get(p.name)||(a.set(p.name,!0),(r||(r=[])).push(p.name))}}return r}}function We(t){var a=!1,i=299===t.kind?t:void 0;if(!i||G!==e.ModuleKind.None){for(var o=i?i.prepends.length:0,s=i?i.sourceFiles.length+o:1,c=0;c<s;c++){var l=i?c<o?i.prepends[c]:i.sourceFiles[c-o]:t,u=e.isSourceFile(l)?l:e.isUnparsedSource(l)?void 0:r,d=n.noEmitHelpers||!!u&&e.hasRecordedExternalHelpers(u),f=(e.isSourceFile(l)||e.isUnparsedSource(l))&&!m,_=e.isUnparsedSource(l)?l.helpers:ze(l);if(_)for(var g=0,y=_;g<y.length;g++){var h=y[g];if(h.scoped){if(i)continue}else{if(d)continue;if(f){if(B.get(h.name))continue;B.set(h.name,!0)}}var v=fe();"string"===typeof h.text?ui(h.text):ui(h.text(Gi)),j&&j.sections.push({pos:v,end:p.getTextPos(),kind:"emitHelpers",data:h.name}),a=!0}}return a}}function ze(n){var t=e.getEmitHelpers(n);return t&&e.stableSort(t,e.compareEmitHelpers)}function qe(e){Je(e,!1)}function Je(t,r){var a=xi(t,n.neverAsciiEscape,r);!n.sourceMap&&!n.inlineSourceMap||10!==t.kind&&!e.isTemplateLiteralKind(t.kind)?za(a):Wa(a)}function Xe(e){for(var n=0,t=e.texts;n<t.length;n++){var r=t[n];ri(),Ce(r)}}function Ye(e){p.rawWrite(e.parent.text.substring(e.pos,e.end))}function Qe(e){var n=fe();Ye(e),j&&me(n,p.getTextPos(),295===e.kind?"text":"internal")}function Ze(n){var t=fe();if(Ye(n),j){var r=e.clone(n.section);r.pos=t,r.end=p.getTextPos(),j.sections.push(r)}}function $e(e){var n=e.symbol?Ja:V;n(Si(e,!1),e.symbol),ja(e,e.typeArguments,53776)}function en(e){var n=e.symbol?Ja:V;n(Si(e,!1),e.symbol)}function nn(e){tn(e.left),Xa("."),Ce(e.right)}function tn(e){78===e.kind?Ne(e):Ce(e)}function rn(e){Xa("["),Ne(e.expression,ae.parenthesizeExpressionOfComputedPropertyName),Xa("]")}function an(e){Ce(e.name),e.constraint&&(ni(),Qa("extends"),ni(),Ce(e.constraint)),e.default&&(ni(),Za("="),ni(),Ce(e.default))}function on(e){wa(e,e.decorators),Da(e,e.modifiers),Ce(e.dotDotDotToken),La(e.name,$a),Ce(e.questionToken),e.parent&&309===e.parent.kind&&!e.name?Ce(e.type):Aa(e.type),Ca(e.initializer,e.type?e.type.end:e.questionToken?e.questionToken.end:e.name?e.name.end:e.modifiers?e.modifiers.end:e.decorators?e.decorators.end:e.pos,e,ae.parenthesizeExpressionForDisallowedComma)}function sn(e){Xa("@"),Ne(e.expression,ae.parenthesizeLeftSideOfAccess)}function cn(e){wa(e,e.decorators),Da(e,e.modifiers),La(e.name,ti),Ce(e.questionToken),Aa(e.type),Ya()}function ln(e){wa(e,e.decorators),Da(e,e.modifiers),Ce(e.name),Ce(e.questionToken),Ce(e.exclamationToken),Aa(e.type),Ca(e.initializer,e.type?e.type.end:e.questionToken?e.questionToken.end:e.name.end,e),Ya()}function un(e){Li(e),wa(e,e.decorators),Da(e,e.modifiers),Ce(e.name),Ce(e.questionToken),Ma(e,e.typeParameters),Fa(e,e.parameters),Aa(e.type),Ya(),Di(e)}function dn(e){wa(e,e.decorators),Da(e,e.modifiers),Ce(e.asteriskToken),Ce(e.name),Ce(e.questionToken),$t(e,er)}function pn(e){Da(e,e.modifiers),Qa("constructor"),$t(e,er)}function fn(e){wa(e,e.decorators),Da(e,e.modifiers),Qa(168===e.kind?"get":"set"),ni(),Ce(e.name),$t(e,er)}function mn(e){Li(e),wa(e,e.decorators),Da(e,e.modifiers),Ma(e,e.typeParameters),Fa(e,e.parameters),Aa(e.type),Ya(),Di(e)}function _n(e){Li(e),wa(e,e.decorators),Da(e,e.modifiers),Qa("new"),ni(),Ma(e,e.typeParameters),Fa(e,e.parameters),Aa(e.type),Ya(),Di(e)}function gn(e){wa(e,e.decorators),Da(e,e.modifiers),Ua(e,e.parameters),Aa(e.type),Ya()}function yn(e){Ce(e.type),Ce(e.literal)}function hn(){Ya()}function vn(e){e.assertsModifier&&(Ce(e.assertsModifier),ni()),Ce(e.parameterName),e.type&&(ni(),Qa("is"),ni(),Ce(e.type))}function bn(e){Ce(e.typeName),Pa(e,e.typeArguments)}function En(e){Li(e),Ma(e,e.typeParameters),Ba(e,e.parameters),ni(),Xa("=>"),ni(),Ce(e.type),Di(e)}function Tn(e){Qa("function"),Fa(e,e.parameters),Xa(":"),Ce(e.type)}function Sn(e){Xa("?"),Ce(e.type)}function xn(e){Xa("!"),Ce(e.type)}function Ln(e){Ce(e.type),Xa("=")}function Dn(e){Li(e),Da(e,e.modifiers),Qa("new"),ni(),Ma(e,e.typeParameters),Fa(e,e.parameters),ni(),Xa("=>"),ni(),Ce(e.type),Di(e)}function An(e){Qa("typeof"),ni(),Ce(e.exprName)}function Cn(n){Xa("{");var t=1&e.getEmitFlags(n)?768:32897;ja(n,n.members,524288|t),Xa("}")}function In(e){Ce(e.elementType,ae.parenthesizeElementTypeOfArrayType),Xa("["),Xa("]")}function Nn(e){Xa("..."),Ce(e.type)}function kn(n){Vt(22,n.pos,Xa,n);var t=1&e.getEmitFlags(n)?528:657;ja(n,n.elements,524288|t),Vt(23,n.elements.end,Xa,n)}function Rn(e){Ce(e.dotDotDotToken),Ce(e.name),Ce(e.questionToken),Vt(58,e.name.end,Xa,e),ni(),Ce(e.type)}function On(e){Ce(e.type,ae.parenthesizeElementTypeOfArrayType),Xa("?")}function wn(e){ja(e,e.types,516,ae.parenthesizeMemberOfElementType)}function Pn(e){ja(e,e.types,520,ae.parenthesizeMemberOfElementType)}function Mn(e){Ce(e.checkType,ae.parenthesizeMemberOfConditionalType),ni(),Qa("extends"),ni(),Ce(e.extendsType,ae.parenthesizeMemberOfConditionalType),ni(),Xa("?"),ni(),Ce(e.trueType),ni(),Xa(":"),ni(),Ce(e.falseType)}function Fn(e){Qa("infer"),ni(),Ce(e.typeParameter)}function Gn(e){Xa("("),Ce(e.type),Xa(")")}function Bn(){Qa("this")}function Un(e){ci(e.operator,Qa),ni(),Ce(e.type,ae.parenthesizeMemberOfElementType)}function Vn(e){Ce(e.objectType,ae.parenthesizeMemberOfElementType),Xa("["),Ce(e.indexType),Xa("]")}function jn(n){var t=e.getEmitFlags(n);Xa("{"),1&t?ni():(ri(),ai()),n.readonlyToken&&(Ce(n.readonlyToken),142!==n.readonlyToken.kind&&Qa("readonly"),ni()),Xa("["),we(3,n.typeParameter),n.nameType&&(ni(),Qa("as"),ni(),Ce(n.nameType)),Xa("]"),n.questionToken&&(Ce(n.questionToken),57!==n.questionToken.kind&&Xa("?")),Xa(":"),ni(),Ce(n.type),Ya(),1&t?ni():(ri(),ii()),Xa("}")}function Kn(e){Ne(e.literal)}function Hn(e){Ce(e.head),ja(e,e.templateSpans,262144)}function Wn(e){e.isTypeOf&&(Qa("typeof"),ni()),Qa("import"),Xa("("),Ce(e.argument),Xa(")"),e.qualifier&&(Xa("."),Ce(e.qualifier)),Pa(e,e.typeArguments)}function zn(e){Xa("{"),ja(e,e.elements,525136),Xa("}")}function qn(e){Xa("["),ja(e,e.elements,524880),Xa("]")}function Jn(e){Ce(e.dotDotDotToken),e.propertyName&&(Ce(e.propertyName),Xa(":"),ni()),Ce(e.name),Ca(e.initializer,e.name.end,e,ae.parenthesizeExpressionForDisallowedComma)}function Xn(e){var n=e.elements,t=e.multiLine?65536:0;Ka(e,n,8914|t,ae.parenthesizeExpressionForDisallowedComma)}function Yn(n){e.forEach(n.properties,Ii);var t=65536&e.getEmitFlags(n);t&&ai();var a=n.multiLine?65536:0,i=r.languageVersion>=1&&!e.isJsonSourceFile(r)?64:0;ja(n,n.properties,526226|i|a),t&&ii()}function Qn(n){Ne(n.expression,ae.parenthesizeLeftSideOfAccess);var t=n.questionDotToken||e.setTextRangePosEnd(e.factory.createToken(24),n.expression.end,n.name.pos),r=bi(n,n.expression,t),a=bi(n,t,n.name);di(r,!1);var i=28!==t.kind&&Zn(n.expression)&&!p.hasTrailingComment()&&!p.hasTrailingWhitespace();i&&Xa("."),n.questionDotToken?Ce(t):Vt(t.kind,n.expression.end,Xa,n),di(a,!1),Ce(n.name),pi(r,a)}function Zn(n){if(n=e.skipPartiallyEmittedExpressions(n),e.isNumericLiteral(n)){var t=xi(n,!0,!1);return!n.numericLiteralFlags&&!e.stringContains(t,e.tokenToString(24))}if(e.isAccessExpression(n)){var r=e.getConstantValue(n);return"number"===typeof r&&isFinite(r)&&Math.floor(r)===r}}function $n(e){Ne(e.expression,ae.parenthesizeLeftSideOfAccess),Ce(e.questionDotToken),Vt(22,e.expression.end,Xa,e),Ne(e.argumentExpression),Vt(23,e.argumentExpression.end,Xa,e)}function et(e){Ne(e.expression,ae.parenthesizeLeftSideOfAccess),Ce(e.questionDotToken),Pa(e,e.typeArguments),Ka(e,e.arguments,2576,ae.parenthesizeExpressionForDisallowedComma)}function nt(e){Vt(102,e.pos,Qa,e),ni(),Ne(e.expression,ae.parenthesizeExpressionOfNew),Pa(e,e.typeArguments),Ka(e,e.arguments,18960,ae.parenthesizeExpressionForDisallowedComma)}function tt(e){Ne(e.tag,ae.parenthesizeLeftSideOfAccess),Pa(e,e.typeArguments),ni(),Ne(e.template)}function rt(e){Xa("<"),Ce(e.type),Xa(">"),Ne(e.expression,ae.parenthesizeOperandOfPrefixUnary)}function at(e){var n=Vt(20,e.pos,Xa,e),t=yi(e.expression,e);Ne(e.expression,void 0),hi(e.expression,e),pi(t),Vt(21,e.expression?e.expression.end:n,Xa,e)}function it(e){Ni(e.name),Zt(e)}function ot(e){wa(e,e.decorators),Da(e,e.modifiers),$t(e,st)}function st(e){Ma(e,e.typeParameters),Ba(e,e.parameters),Aa(e.type),ni(),Ce(e.equalsGreaterThanToken)}function ct(e){Vt(88,e.pos,Qa,e),ni(),Ne(e.expression,ae.parenthesizeOperandOfPrefixUnary)}function lt(e){Vt(111,e.pos,Qa,e),ni(),Ne(e.expression,ae.parenthesizeOperandOfPrefixUnary)}function ut(e){Vt(113,e.pos,Qa,e),ni(),Ne(e.expression,ae.parenthesizeOperandOfPrefixUnary)}function dt(e){Vt(130,e.pos,Qa,e),ni(),Ne(e.expression,ae.parenthesizeOperandOfPrefixUnary)}function pt(e){ci(e.operator,Za),ft(e)&&ni(),Ne(e.operand,ae.parenthesizeOperandOfPrefixUnary)}function ft(e){var n=e.operand;return 215===n.kind&&(39===e.operator&&(39===n.operator||45===n.operator)||40===e.operator&&(40===n.operator||46===n.operator))}function mt(e){Ne(e.operand,ae.parenthesizeOperandOfPostfixUnary),ci(e.operator,Za)}function _t(){return e.createBinaryExpressionTrampoline(n,t,r,a,i,void 0);function n(e,n){if(n){n.stackIndex++,n.preserveSourceNewlinesStack[n.stackIndex]=U,n.containerPosStack[n.stackIndex]=Y,n.containerEndStack[n.stackIndex]=Q,n.declarationListContainerEndStack[n.stackIndex]=Z;var t=n.shouldEmitCommentsStack[n.stackIndex]=Pe(e),r=n.shouldEmitSourceMapsStack[n.stackIndex]=Me(e);null===C||void 0===C||C(e),t&&Ji(e),r&&Lo(e),Re(e)}else n={stackIndex:0,preserveSourceNewlinesStack:[void 0],containerPosStack:[-1],containerEndStack:[-1],declarationListContainerEndStack:[-1],shouldEmitCommentsStack:[!1],shouldEmitSourceMapsStack:[!1]};return n}function t(e,n,t){return o(e,t,"left")}function r(e,n,t){var r=27!==e.kind,a=bi(t,t.left,e),i=bi(t,e,t.right);di(a,r),lo(e.pos),si(e,100===e.kind?Qa:Za),fo(e.end,!0),di(i,!0)}function a(e,n,t){return o(e,t,"right")}function i(e,n){var t=bi(e,e.left,e.operatorToken),r=bi(e,e.operatorToken,e.right);if(pi(t,r),n.stackIndex>0){var a=n.preserveSourceNewlinesStack[n.stackIndex],i=n.containerPosStack[n.stackIndex],o=n.containerEndStack[n.stackIndex],s=n.declarationListContainerEndStack[n.stackIndex],c=n.shouldEmitCommentsStack[n.stackIndex],l=n.shouldEmitSourceMapsStack[n.stackIndex];Oe(a),l&&Do(e),c&&Xi(e,i,o,s),null===I||void 0===I||I(e),n.stackIndex--}}function o(n,t,r){var a="left"===r?ae.getParenthesizeLeftSideOfBinaryForOperator(t.operatorToken.kind):ae.getParenthesizeRightSideOfBinaryForOperator(t.operatorToken.kind),i=Fe(0,1,n);if(i===Ke&&(e.Debug.assertIsDefined(b),n=a(e.cast(b,e.isExpression)),i=Ge(1,1,n),b=void 0),(i===qi||i===xo||i===Ue)&&e.isBinaryExpression(n))return n;E=a,i(1,n)}}function gt(e){var n=bi(e,e.condition,e.questionToken),t=bi(e,e.questionToken,e.whenTrue),r=bi(e,e.whenTrue,e.colonToken),a=bi(e,e.colonToken,e.whenFalse);Ne(e.condition,ae.parenthesizeConditionOfConditionalExpression),di(n,!0),Ce(e.questionToken),di(t,!0),Ne(e.whenTrue,ae.parenthesizeBranchOfConditionalExpression),pi(n,t),di(r,!0),Ce(e.colonToken),di(a,!0),Ne(e.whenFalse,ae.parenthesizeBranchOfConditionalExpression),pi(r,a)}function yt(e){Ce(e.head),ja(e,e.templateSpans,262144)}function ht(e){Vt(124,e.pos,Qa,e),Ce(e.asteriskToken),ka(e.expression,ae.parenthesizeExpressionForDisallowedComma)}function vt(e){Vt(25,e.pos,Xa,e),Ne(e.expression,ae.parenthesizeExpressionForDisallowedComma)}function bt(e){Ni(e.name),or(e)}function Et(e){Ne(e.expression,ae.parenthesizeLeftSideOfAccess),Pa(e,e.typeArguments)}function Tt(e){Ne(e.expression,void 0),e.type&&(ni(),Qa("as"),ni(),Ce(e.type))}function St(e){Ne(e.expression,ae.parenthesizeLeftSideOfAccess),Za("!")}function xt(e){oi(e.keywordToken,e.pos,Xa),Xa("."),Ce(e.name)}function Lt(e){Ne(e.expression),Ce(e.literal)}function Dt(e){At(e,!e.multiLine&&Ei(e))}function At(n,t){Vt(18,n.pos,Xa,n);var r=t||1&e.getEmitFlags(n)?768:129;ja(n,n.statements,r),Vt(19,n.statements.end,Xa,n,!!(1&r))}function Ct(e){Da(e,e.modifiers),Ce(e.declarationList),Ya()}function It(e){e?Xa(";"):Ya()}function Nt(n){Ne(n.expression,ae.parenthesizeExpressionOfExpressionStatement),e.isJsonSourceFile(r)&&!e.nodeIsSynthesized(n.expression)||Ya()}function kt(e){var n=Vt(98,e.pos,Qa,e);ni(),Vt(20,n,Xa,e),Ne(e.expression),Vt(21,e.expression.end,Xa,e),Oa(e,e.thenStatement),e.elseStatement&&(li(e,e.thenStatement,e.elseStatement),Vt(90,e.thenStatement.end,Qa,e),235===e.elseStatement.kind?(ni(),Ce(e.elseStatement)):Oa(e,e.elseStatement))}function Rt(e,n){var t=Vt(114,n,Qa,e);ni(),Vt(20,t,Xa,e),Ne(e.expression),Vt(21,e.expression.end,Xa,e)}function Ot(n){Vt(89,n.pos,Qa,n),Oa(n,n.statement),e.isBlock(n.statement)&&!U?ni():li(n,n.statement,n.expression),Rt(n,n.statement.end),Ya()}function wt(e){Rt(e,e.pos),Oa(e,e.statement)}function Pt(e){var n=Vt(96,e.pos,Qa,e);ni();var t=Vt(20,n,Xa,e);Gt(e.initializer),t=Vt(26,e.initializer?e.initializer.end:t,Xa,e),ka(e.condition),t=Vt(26,e.condition?e.condition.end:t,Xa,e),ka(e.incrementor),Vt(21,e.incrementor?e.incrementor.end:t,Xa,e),Oa(e,e.statement)}function Mt(e){var n=Vt(96,e.pos,Qa,e);ni(),Vt(20,n,Xa,e),Gt(e.initializer),ni(),Vt(100,e.initializer.end,Qa,e),ni(),Ne(e.expression),Vt(21,e.expression.end,Xa,e),Oa(e,e.statement)}function Ft(e){var n=Vt(96,e.pos,Qa,e);ni(),Ra(e.awaitModifier),Vt(20,n,Xa,e),Gt(e.initializer),ni(),Vt(157,e.initializer.end,Qa,e),ni(),Ne(e.expression),Vt(21,e.expression.end,Xa,e),Oa(e,e.statement)}function Gt(e){void 0!==e&&(251===e.kind?Ce(e):Ne(e))}function Bt(e){Vt(85,e.pos,Qa,e),Na(e.label),Ya()}function Ut(e){Vt(80,e.pos,Qa,e),Na(e.label),Ya()}function Vt(n,t,a,i,o){var s=e.getParseTreeNode(i),c=s&&s.kind===i.kind,l=t;if(c&&r&&(t=e.skipTrivia(r.text,t)),c&&i.pos!==l){var u=o&&r&&!e.positionsAreOnSameLine(l,t,r);u&&ai(),lo(l),u&&ii()}if(t=ci(n,a,t),c&&i.end!==t){var d=284===i.kind;fo(t,!d,d)}return t}function jt(e){Vt(104,e.pos,Qa,e),ka(e.expression),Ya()}function Kt(e){var n=Vt(115,e.pos,Qa,e);ni(),Vt(20,n,Xa,e),Ne(e.expression),Vt(21,e.expression.end,Xa,e),Oa(e,e.statement)}function Ht(e){var n=Vt(106,e.pos,Qa,e);ni(),Vt(20,n,Xa,e),Ne(e.expression),Vt(21,e.expression.end,Xa,e),ni(),Ce(e.caseBlock)}function Wt(e){Ce(e.label),Vt(58,e.label.end,Xa,e),ni(),Ce(e.statement)}function zt(e){Vt(108,e.pos,Qa,e),ka(e.expression),Ya()}function qt(e){Vt(110,e.pos,Qa,e),ni(),Ce(e.tryBlock),e.catchClause&&(li(e,e.tryBlock,e.catchClause),Ce(e.catchClause)),e.finallyBlock&&(li(e,e.catchClause||e.tryBlock,e.finallyBlock),Vt(95,(e.catchClause||e.tryBlock).end,Qa,e),ni(),Ce(e.finallyBlock))}function Jt(e){oi(86,e.pos,Qa),Ya()}function Xt(e){Ce(e.name),Ce(e.exclamationToken),Aa(e.type),Ca(e.initializer,e.type?e.type.end:e.name.end,e,ae.parenthesizeExpressionForDisallowedComma)}function Yt(n){Qa(e.isLet(n)?"let":e.isVarConst(n)?"const":"var"),ni(),ja(n,n.declarations,528)}function Qt(e){Zt(e)}function Zt(e){wa(e,e.decorators),Da(e,e.modifiers),Qa("function"),Ce(e.asteriskToken),ni(),Ie(e.name),$t(e,er)}function $t(n,t){var r=n.body;if(r)if(e.isBlock(r)){var a=65536&e.getEmitFlags(n);a&&ai(),Li(n),e.forEach(n.parameters,Ci),Ci(n.body),t(n),tr(r),Di(n),a&&ii()}else t(n),ni(),Ne(r,ae.parenthesizeConciseBodyOfArrowFunction);else t(n),Ya()}function er(e){Ma(e,e.typeParameters),Fa(e,e.parameters),Aa(e.type)}function nr(n){if(1&e.getEmitFlags(n))return!0;if(n.multiLine)return!1;if(!e.nodeIsSynthesized(n)&&!e.rangeIsOnSingleLine(n,r))return!1;if(fi(n,n.statements,2)||_i(n,n.statements,2))return!1;for(var t,a=0,i=n.statements;a<i.length;a++){var o=i[a];if(mi(t,o,2)>0)return!1;t=o}return!0}function tr(e){null===C||void 0===C||C(e),ni(),Xa("{"),ai();var n=nr(e)?rr:ar;to?to(e,e.statements,n):n(e),ii(),oi(19,e.statements.end,Xa,e),null===I||void 0===I||I(e)}function rr(e){ar(e,!0)}function ar(e,n){var t=ba(e.statements),r=p.getTextPos();We(e),0===t&&r===p.getTextPos()&&n?(ii(),ja(e,e.statements,768),ai()):ja(e,e.statements,1,void 0,t)}function ir(e){or(e)}function or(n){e.forEach(n.members,Ii),wa(n,n.decorators),Da(n,n.modifiers),Qa("class"),n.name&&(ni(),Ie(n.name));var t=65536&e.getEmitFlags(n);t&&ai(),Ma(n,n.typeParameters),ja(n,n.heritageClauses,0),ni(),Xa("{"),ja(n,n.members,129),Xa("}"),t&&ii()}function sr(e){wa(e,e.decorators),Da(e,e.modifiers),Qa("interface"),ni(),Ce(e.name),Ma(e,e.typeParameters),ja(e,e.heritageClauses,512),ni(),Xa("{"),ja(e,e.members,129),Xa("}")}function cr(e){wa(e,e.decorators),Da(e,e.modifiers),Qa("type"),ni(),Ce(e.name),Ma(e,e.typeParameters),ni(),Xa("="),ni(),Ce(e.type),Ya()}function lr(e){Da(e,e.modifiers),Qa("enum"),ni(),Ce(e.name),ni(),Xa("{"),ja(e,e.members,145),Xa("}")}function ur(n){Da(n,n.modifiers),1024&~n.flags&&(Qa(16&n.flags?"namespace":"module"),ni()),Ce(n.name);var t=n.body;if(!t)return Ya();while(t&&e.isModuleDeclaration(t))Xa("."),Ce(t.name),t=t.body;ni(),Ce(t)}function dr(n){Li(n),e.forEach(n.statements,Ci),At(n,Ei(n)),Di(n)}function pr(e){Vt(18,e.pos,Xa,e),ja(e,e.clauses,129),Vt(19,e.clauses.end,Xa,e,!0)}function fr(e){Da(e,e.modifiers),Vt(99,e.modifiers?e.modifiers.end:e.pos,Qa,e),ni(),e.isTypeOnly&&(Vt(149,e.pos,Qa,e),ni()),Ce(e.name),ni(),Vt(62,e.name.end,Xa,e),ni(),mr(e.moduleReference),Ya()}function mr(e){78===e.kind?Ne(e):Ce(e)}function _r(e){Da(e,e.modifiers),Vt(99,e.modifiers?e.modifiers.end:e.pos,Qa,e),ni(),e.importClause&&(Ce(e.importClause),ni(),Vt(153,e.importClause.end,Qa,e),ni()),Ne(e.moduleSpecifier),Ya()}function gr(e){e.isTypeOnly&&(Vt(149,e.pos,Qa,e),ni()),Ce(e.name),e.name&&e.namedBindings&&(Vt(27,e.name.end,Xa,e),ni()),Ce(e.namedBindings)}function yr(e){var n=Vt(41,e.pos,Xa,e);ni(),Vt(126,n,Qa,e),ni(),Ce(e.name)}function hr(e){Dr(e)}function vr(e){Ar(e)}function br(e){var n=Vt(92,e.pos,Qa,e);ni(),e.isExportEquals?Vt(62,n,Za,e):Vt(87,n,Qa,e),ni(),Ne(e.expression,e.isExportEquals?ae.getParenthesizeRightSideOfBinaryForOperator(62):ae.parenthesizeExpressionOfExportDefault),Ya()}function Er(e){var n=Vt(92,e.pos,Qa,e);if(ni(),e.isTypeOnly&&(n=Vt(149,n,Qa,e),ni()),e.exportClause?Ce(e.exportClause):n=Vt(41,n,Xa,e),e.moduleSpecifier){ni();var t=e.exportClause?e.exportClause.end:n;Vt(153,t,Qa,e),ni(),Ne(e.moduleSpecifier)}Ya()}function Tr(e){var n=Vt(92,e.pos,Qa,e);ni(),n=Vt(126,n,Qa,e),ni(),n=Vt(140,n,Qa,e),ni(),Ce(e.name),Ya()}function Sr(e){var n=Vt(41,e.pos,Xa,e);ni(),Vt(126,n,Qa,e),ni(),Ce(e.name)}function xr(e){Dr(e)}function Lr(e){Ar(e)}function Dr(e){Xa("{"),ja(e,e.elements,525136),Xa("}")}function Ar(e){e.propertyName&&(Ce(e.propertyName),ni(),Vt(126,e.propertyName.end,Qa,e),ni()),Ce(e.name)}function Cr(e){Qa("require"),Xa("("),Ne(e.expression),Xa(")")}function Ir(e){Ce(e.openingElement),ja(e,e.children,262144),Ce(e.closingElement)}function Nr(e){Xa("<"),jr(e.tagName),Pa(e,e.typeArguments),ni(),Ce(e.attributes),Xa("/>")}function kr(e){Ce(e.openingFragment),ja(e,e.children,262144),Ce(e.closingFragment)}function Rr(n){if(Xa("<"),e.isJsxOpeningElement(n)){var t=yi(n.tagName,n);jr(n.tagName),Pa(n,n.typeArguments),n.attributes.properties&&n.attributes.properties.length>0&&ni(),Ce(n.attributes),hi(n.attributes,n),pi(t)}Xa(">")}function Or(e){p.writeLiteral(e.text)}function wr(n){Xa("</"),e.isJsxClosingElement(n)&&jr(n.tagName),Xa(">")}function Pr(e){ja(e,e.properties,262656)}function Mr(e){Ce(e.name),Ia("=",Xa,e.initializer,ke)}function Fr(e){Xa("{..."),Ne(e.expression),Xa("}")}function Gr(n){var t=!1;return e.forEachTrailingCommentRange((null===r||void 0===r?void 0:r.text)||"",n+1,(function(){return t=!0})),t}function Br(n){var t=!1;return e.forEachLeadingCommentRange((null===r||void 0===r?void 0:r.text)||"",n+1,(function(){return t=!0})),t}function Ur(e){return Gr(e)||Br(e)}function Vr(n){var t;if(n.expression||!ee&&!e.nodeIsSynthesized(n)&&Ur(n.pos)){var a=r&&!e.nodeIsSynthesized(n)&&e.getLineAndCharacterOfPosition(r,n.pos).line!==e.getLineAndCharacterOfPosition(r,n.end).line;a&&p.increaseIndent();var i=Vt(18,n.pos,Xa,n);Ce(n.dotDotDotToken),Ne(n.expression),Vt(19,(null===(t=n.expression)||void 0===t?void 0:t.end)||i,Xa,n),a&&p.decreaseIndent()}}function jr(e){78===e.kind?Ne(e):Ce(e)}function Kr(e){Vt(81,e.pos,Qa,e),ni(),Ne(e.expression,ae.parenthesizeExpressionForDisallowedComma),Wr(e,e.statements,e.expression.end)}function Hr(e){var n=Vt(87,e.pos,Qa,e);Wr(e,e.statements,n)}function Wr(n,t,a){var i=1===t.length&&(e.nodeIsSynthesized(n)||e.nodeIsSynthesized(t[0])||e.rangeStartPositionsAreOnSameLine(n,t[0],r)),o=163969;i?(oi(58,a,Xa,n),ni(),o&=-130):Vt(58,a,Xa,n),ja(n,t,o)}function zr(e){ni(),ci(e.token,Qa),ni(),ja(e,e.types,528)}function qr(e){var n=Vt(82,e.pos,Qa,e);ni(),e.variableDeclaration&&(Vt(20,n,Xa,e),Ce(e.variableDeclaration),Vt(21,e.variableDeclaration.end,Xa,e),ni()),Ce(e.block)}function Jr(n){Ce(n.name),Xa(":"),ni();var t=n.initializer;if(0===(512&e.getEmitFlags(t))){var r=e.getCommentRange(t);fo(r.pos)}Ne(t,ae.parenthesizeExpressionForDisallowedComma)}function Xr(e){Ce(e.name),e.objectAssignmentInitializer&&(ni(),Xa("="),ni(),Ne(e.objectAssignmentInitializer,ae.parenthesizeExpressionForDisallowedComma))}function Yr(e){e.expression&&(Vt(25,e.pos,Xa,e),Ne(e.expression,ae.parenthesizeExpressionForDisallowedComma))}function Qr(e){Ce(e.name),Ca(e.initializer,e.name.end,e,ae.parenthesizeExpressionForDisallowedComma)}function Zr(n){if(V("/**"),n.comment){var t=e.getTextOfJSDocComment(n.comment);if(t)for(var r=t.split(/\r\n?|\n/g),a=0,i=r;a<i.length;a++){var o=i[a];ri(),ni(),Xa("*"),ni(),V(o)}}n.tags&&(1!==n.tags.length||333!==n.tags[0].kind||n.comment?ja(n,n.tags,33):(ni(),Ce(n.tags[0]))),ni(),V("*/")}function $r(e){ua(e.tagName),pa(e.typeExpression),da(e.comment)}function ea(e){ua(e.tagName),Ce(e.name),da(e.comment)}function na(e){ni(),Xa("{"),Ce(e.name),Xa("}")}function ta(e){ua(e.tagName),ni(),Xa("{"),Ce(e.class),Xa("}"),da(e.comment)}function ra(e){ua(e.tagName),pa(e.constraint),ni(),ja(e,e.typeParameters,528),da(e.comment)}function aa(e){ua(e.tagName),e.typeExpression&&(302===e.typeExpression.kind?pa(e.typeExpression):(ni(),Xa("{"),V("Object"),e.typeExpression.isArrayType&&(Xa("["),Xa("]")),Xa("}"))),e.fullName&&(ni(),Ce(e.fullName)),da(e.comment),e.typeExpression&&314===e.typeExpression.kind&&sa(e.typeExpression)}function ia(e){ua(e.tagName),e.name&&(ni(),Ce(e.name)),da(e.comment),ca(e.typeExpression)}function oa(e){ua(e.tagName),da(e.comment)}function sa(n){ja(n,e.factory.createNodeArray(n.jsDocPropertyTags),33)}function ca(n){n.typeParameters&&ja(n,e.factory.createNodeArray(n.typeParameters),33),n.parameters&&ja(n,e.factory.createNodeArray(n.parameters),33),n.type&&(ri(),ni(),Xa("*"),ni(),Ce(n.type))}function la(e){ua(e.tagName),pa(e.typeExpression),ni(),e.isBracketed&&Xa("["),Ce(e.name),e.isBracketed&&Xa("]"),da(e.comment)}function ua(e){Xa("@"),Ce(e)}function da(n){var t=e.getTextOfJSDocComment(n);t&&(ni(),V(t))}function pa(e){e&&(ni(),Xa("{"),Ce(e.type),Xa("}"))}function fa(n){ri();var t=n.statements;if(to){var r=0===t.length||!e.isPrologueDirective(t[0])||e.nodeIsSynthesized(t[0]);if(r)return void to(n,t,ya)}ya(n)}function ma(n){ga(!!n.hasNoDefaultLib,n.syntheticFileReferences||[],n.syntheticTypeReferences||[],n.syntheticLibReferences||[]);for(var t=0,r=n.prepends;t<r.length;t++){var a=r[t];if(e.isUnparsedSource(a)&&a.syntheticReferences)for(var i=0,o=a.syntheticReferences;i<o.length;i++){var s=o[i];Ce(s),ri()}}}function _a(e){e.isDeclarationFile&&ga(e.hasNoDefaultLib,e.referencedFiles,e.typeReferenceDirectives,e.libReferenceDirectives)}function ga(e,n,t,a){if(e){var i=p.getTextPos();ei('/// <reference no-default-lib="true"/>'),j&&j.sections.push({pos:i,end:p.getTextPos(),kind:"no-default-lib"}),ri()}if(r&&r.moduleName&&(ei('/// <amd-module name="'+r.moduleName+'" />'),ri()),r&&r.amdDependencies)for(var o=0,s=r.amdDependencies;o<s.length;o++){var c=s[o];c.name?ei('/// <amd-dependency name="'+c.name+'" path="'+c.path+'" />'):ei('/// <amd-dependency path="'+c.path+'" />'),ri()}for(var l=0,u=n;l<u.length;l++){var d=u[l];i=p.getTextPos();ei('/// <reference path="'+d.fileName+'" />'),j&&j.sections.push({pos:i,end:p.getTextPos(),kind:"reference",data:d.fileName}),ri()}for(var f=0,m=t;f<m.length;f++){d=m[f],i=p.getTextPos();ei('/// <reference types="'+d.fileName+'" />'),j&&j.sections.push({pos:i,end:p.getTextPos(),kind:"type",data:d.fileName}),ri()}for(var _=0,g=a;_<g.length;_++){d=g[_],i=p.getTextPos();ei('/// <reference lib="'+d.fileName+'" />'),j&&j.sections.push({pos:i,end:p.getTextPos(),kind:"lib",data:d.fileName}),ri()}}function ya(n){var t=n.statements;Li(n),e.forEach(n.statements,Ci),We(n);var r=e.findIndex(t,(function(n){return!e.isPrologueDirective(n)}));_a(n),ja(n,t,1,void 0,-1===r?t.length:r),Di(n)}function ha(e){Ne(e.expression)}function va(e){Ka(e,e.elements,528,void 0)}function ba(n,t,r,a){for(var i=!!t,o=0;o<n.length;o++){var s=n[o];if(!e.isPrologueDirective(s))return o;var c=!r||!r.has(s.expression.text);if(c){i&&(i=!1,xe(t)),ri();var l=p.getTextPos();Ce(s),a&&j&&j.sections.push({pos:l,end:p.getTextPos(),kind:"prologue",data:s.expression.text}),r&&r.add(s.expression.text)}}return n.length}function Ea(e,n){for(var t=0,r=e;t<r.length;t++){var a=r[t];if(!n.has(a.data)){ri();var i=p.getTextPos();Ce(a),j&&j.sections.push({pos:i,end:p.getTextPos(),kind:"prologue",data:a.data}),n&&n.add(a.data)}}}function Ta(n){if(e.isSourceFile(n))ba(n.statements,n);else{for(var t=new e.Set,r=0,a=n.prepends;r<a.length;r++){var i=a[r];Ea(i.prologues,t)}for(var o=0,s=n.sourceFiles;o<s.length;o++){var c=s[o];ba(c.statements,c,t,!0)}xe(void 0)}}function Sa(n){for(var t,r=new e.Set,a=0;a<n.sourceFiles.length;a++){for(var i=n.sourceFiles[a],o=void 0,s=0,c=0,l=i.statements;c<l.length;c++){var u=l[c];if(!e.isPrologueDirective(u))break;r.has(u.expression.text)||(r.add(u.expression.text),(o||(o=[])).push({pos:u.pos,end:u.end,expression:{pos:u.expression.pos,end:u.expression.end,text:u.expression.text}}),s=s<u.end?u.end:s)}o&&(t||(t=[])).push({file:a,text:i.text.substring(0,s),directives:o})}return t}function xa(n){if(e.isSourceFile(n)||e.isUnparsedSource(n)){var t=e.getShebang(n.text);if(t)return ei(t),ri(),!0}else{for(var r=0,a=n.prepends;r<a.length;r++){var i=a[r];if(e.Debug.assertNode(i,e.isUnparsedSource),xa(i))return!0}for(var o=0,s=n.sourceFiles;o<s.length;o++){var c=s[o];if(xa(c))return!0}}}function La(e,n){if(e){var t=V;V=n,Ce(e),V=t}}function Da(e,n){n&&n.length&&(ja(e,n,262656),ni())}function Aa(e){e&&(Xa(":"),ni(),Ce(e))}function Ca(e,n,t,r){e&&(ni(),Vt(62,n,Za,t),ni(),Ne(e,r))}function Ia(e,n,t,r){t&&(n(e),r(t))}function Na(e){e&&(ni(),Ce(e))}function ka(e,n){e&&(ni(),Ne(e,n))}function Ra(e){e&&(Ce(e),ni())}function Oa(n,t){e.isBlock(t)||1&e.getEmitFlags(n)?(ni(),Ce(t)):(ri(),ai(),e.isEmptyStatement(t)?we(5,t):Ce(t),ii())}function wa(e,n){ja(e,n,2146305)}function Pa(e,n){ja(e,n,53776,ae.parenthesizeMemberOfElementType)}function Ma(n,t){if(e.isFunctionLike(n)&&n.typeArguments)return Pa(n,n.typeArguments);ja(n,t,53776)}function Fa(e,n){ja(e,n,2576)}function Ga(n,t){var r=e.singleOrUndefined(t);return r&&r.pos===n.pos&&e.isArrowFunction(n)&&!n.type&&!e.some(n.decorators)&&!e.some(n.modifiers)&&!e.some(n.typeParameters)&&!e.some(r.decorators)&&!e.some(r.modifiers)&&!r.dotDotDotToken&&!r.questionToken&&!r.type&&!r.initializer&&e.isIdentifier(r.name)}function Ba(e,n){Ga(e,n)?ja(e,n,528):Fa(e,n)}function Ua(e,n){ja(e,n,8848)}function Va(e){switch(60&e){case 0:break;case 16:Xa(",");break;case 4:ni(),Xa("|");break;case 32:ni(),Xa("*"),ni();break;case 8:ni(),Xa("&");break}}function ja(e,n,t,r,a,i){Ha(Ce,e,n,t,r,a,i)}function Ka(e,n,t,r,a,i){Ha(Ne,e,n,t,r,a,i)}function Ha(n,t,a,i,o,s,c){void 0===s&&(s=0),void 0===c&&(c=a?a.length-s:0);var l=void 0===a;if(!(l&&16384&i)){var u=void 0===a||s>=a.length||0===c;if(u&&32768&i)return R&&R(a),void(O&&O(a));if(15360&i&&(Xa(N(i)),u&&a&&fo(a.pos,!0)),R&&R(a),u)1&i&&(!U||t&&!e.rangeIsOnSingleLine(t,r))?ri():256&i&&!(524288&i)&&ni();else{e.Debug.type(a);var p=0===(262144&i),f=p,m=fi(t,a,i);m?(ri(m),f=!1):256&i&&ni(),128&i&&ai();for(var _=void 0,g=void 0,y=!1,h=0;h<c;h++){var v=a[s+h];if(32&i)ri(),Va(i);else if(_){60&i&&_.end!==(t?t.end:-1)&&lo(_.end),Va(i),ge(g);var b=mi(_,v,i);b>0?(0===(131&i)&&(ai(),y=!0),ri(b),f=!1):_&&512&i&&ni()}if(g=_e(v),f){if(fo){var E=e.getCommentRange(v);fo(E.pos)}}else f=p;d=v.pos,1===n.length?n(v):n(v,o),y&&(ii(),y=!1),_=v}var T=_?e.getEmitFlags(_):0,S=ee||!!(1024&T),x=(null===a||void 0===a?void 0:a.hasTrailingComma)&&64&i&&16&i;x&&(_&&!S?Vt(27,_.end,Xa,_):Xa(",")),_&&(t?t.end:-1)!==_.end&&60&i&&!S&&lo(x&&(null===a||void 0===a?void 0:a.end)?a.end:_.end),128&i&&ii(),ge(g);var L=_i(t,a,i);L?ri(L):2097408&i&&ni()}O&&O(a),15360&i&&(u&&a&&lo(a.end),Xa(k(i)))}}function Wa(e){p.writeLiteral(e)}function za(e){p.writeStringLiteral(e)}function qa(e){p.write(e)}function Ja(e,n){p.writeSymbol(e,n)}function Xa(e){p.writePunctuation(e)}function Ya(){p.writeTrailingSemicolon(";")}function Qa(e){p.writeKeyword(e)}function Za(e){p.writeOperator(e)}function $a(e){p.writeParameter(e)}function ei(e){p.writeComment(e)}function ni(){p.writeSpace(" ")}function ti(e){p.writeProperty(e)}function ri(e){void 0===e&&(e=1);for(var n=0;n<e;n++)p.writeLine(n>0)}function ai(){p.increaseIndent()}function ii(){p.decreaseIndent()}function oi(e,n,t,r){return q?ci(e,t,n):No(r,e,t,n,ci)}function si(n,t){w&&w(n),t(e.tokenToString(n.kind)),P&&P(n)}function ci(n,t,r){var a=e.tokenToString(n);return t(a),r<0?r:r+a.length}function li(n,t,r){if(1&e.getEmitFlags(n))ni();else if(U){var a=bi(n,t,r);a?ri(a):ni()}else ri()}function ui(n){for(var t=n.split(/\r\n?|\n/g),r=e.guessIndentation(t),a=0,i=t;a<i.length;a++){var o=i[a],s=r?o.slice(r):o;s.length&&(ri(),V(s))}}function di(e,n){e?(ai(),ri(e)):n&&ni()}function pi(e,n){e&&ii(),n&&ii()}function fi(n,t,a){if(2&a||U){if(65536&a)return 1;var i=t[0];if(void 0===i)return!n||e.rangeIsOnSingleLine(n,r)?0:1;if(i.pos===d)return 0;if(11===i.kind)return 0;if(n&&!e.positionIsSynthesized(n.pos)&&!e.nodeIsSynthesized(i)&&(!i.parent||e.getOriginalNode(i.parent)===e.getOriginalNode(n)))return U?gi((function(t){return e.getLinesBetweenPositionAndPrecedingNonWhitespaceCharacter(i.pos,n.pos,r,t)})):e.rangeStartPositionsAreOnSameLine(n,i,r)?0:1;if(vi(i,a))return 1}return 1&a?1:0}function mi(n,t,a){if(2&a||U){if(void 0===n||void 0===t)return 0;if(11===t.kind)return 0;if(U&&ro(n,t))return gi((function(a){return e.getLinesBetweenRangeEndAndRangeStart(n,t,r,a)}));if(!(U||e.nodeIsSynthesized(n)||e.nodeIsSynthesized(t)))return e.rangeEndIsOnSameLineAsRangeStart(n,t,r)?0:1;if(vi(n,a)||vi(t,a))return 1}else if(e.getStartsOnNewLine(t))return 1;return 1&a?1:0}function _i(n,t,a){if(2&a||U){if(65536&a)return 1;var i=e.lastOrUndefined(t);if(void 0===i)return!n||e.rangeIsOnSingleLine(n,r)?0:1;if(n&&!e.positionIsSynthesized(n.pos)&&!e.nodeIsSynthesized(i)&&(!i.parent||i.parent===n)){if(U){var o=e.isNodeArray(t)&&!e.positionIsSynthesized(t.end)?t.end:i.end;return gi((function(t){return e.getLinesBetweenPositionAndNextNonWhitespaceCharacter(o,n.end,r,t)}))}return e.rangeEndPositionsAreOnSameLine(n,i,r)?0:1}if(vi(i,a))return 1}return 1&a&&!(131072&a)?1:0}function gi(n){e.Debug.assert(!!U);var t=n(!0);return 0===t?n(!1):t}function yi(e,n){var t=U&&fi(n,[e],0);return t&&di(t,!1),!!t}function hi(e,n){var t=U&&_i(n,[e],0);t&&ri(t)}function vi(n,t){if(e.nodeIsSynthesized(n)){var r=e.getStartsOnNewLine(n);return void 0===r?0!==(65536&t):r}return 0!==(65536&t)}function bi(n,t,a){return 131072&e.getEmitFlags(n)?0:(n=Ti(n),t=Ti(t),a=Ti(a),e.getStartsOnNewLine(a)?1:e.nodeIsSynthesized(n)||e.nodeIsSynthesized(t)||e.nodeIsSynthesized(a)?0:U?gi((function(n){return e.getLinesBetweenRangeEndAndRangeStart(t,a,r,n)})):e.rangeEndIsOnSameLineAsRangeStart(t,a,r)?0:1)}function Ei(n){return 0===n.statements.length&&e.rangeEndIsOnSameLineAsRangeStart(n,n,r)}function Ti(n){while(208===n.kind&&e.nodeIsSynthesized(n))n=n.expression;return n}function Si(n,t){return e.isGeneratedIdentifier(n)?ki(n):(e.isIdentifier(n)||e.isPrivateIdentifier(n))&&(e.nodeIsSynthesized(n)||!n.parent||!r||n.parent&&r&&e.getSourceFileOfNode(n)!==e.getOriginalNode(r))?e.idText(n):10===n.kind&&n.textSourceNode?Si(n.textSourceNode,t):!e.isLiteralExpression(n)||!e.nodeIsSynthesized(n)&&n.parent?e.getSourceTextOfNodeFromSourceFile(r,n,t):n.text}function xi(t,a,i){if(10===t.kind&&t.textSourceNode){var o=t.textSourceNode;if(e.isIdentifier(o)||e.isNumericLiteral(o)){var s=e.isNumericLiteral(o)?o.text:Si(o);return i?'"'+e.escapeJsxAttributeString(s)+'"':a||16777216&e.getEmitFlags(t)?'"'+e.escapeString(s)+'"':'"'+e.escapeNonAsciiString(s)+'"'}return xi(o,a,i)}var c=(a?1:0)|(i?2:0)|(n.terminateUnterminatedLiterals?4:0)|(n.target&&99===n.target?8:0);return e.getLiteralText(t,r,c)}function Li(n){n&&524288&e.getEmitFlags(n)||(s.push(c),c=0,l.push(u))}function Di(n){n&&524288&e.getEmitFlags(n)||(c=s.pop(),u=l.pop())}function Ai(n){u&&u!==e.lastOrUndefined(l)||(u=new e.Set),u.add(n)}function Ci(n){if(n)switch(n.kind){case 231:e.forEach(n.statements,Ci);break;case 246:case 244:case 236:case 237:Ci(n.statement);break;case 235:Ci(n.thenStatement),Ci(n.elseStatement);break;case 238:case 240:case 239:Ci(n.initializer),Ci(n.statement);break;case 245:Ci(n.caseBlock);break;case 259:e.forEach(n.clauses,Ci);break;case 285:case 286:e.forEach(n.statements,Ci);break;case 248:Ci(n.tryBlock),Ci(n.catchClause),Ci(n.finallyBlock);break;case 288:Ci(n.variableDeclaration),Ci(n.block);break;case 233:Ci(n.declarationList);break;case 251:e.forEach(n.declarations,Ci);break;case 250:case 161:case 199:case 253:Ni(n.name);break;case 252:Ni(n.name),524288&e.getEmitFlags(n)&&(e.forEach(n.parameters,Ci),Ci(n.body));break;case 197:case 198:e.forEach(n.elements,Ci);break;case 262:Ci(n.importClause);break;case 263:Ni(n.name),Ci(n.namedBindings);break;case 264:Ni(n.name);break;case 270:Ni(n.name);break;case 265:e.forEach(n.elements,Ci);break;case 266:Ni(n.propertyName||n.name);break}}function Ii(e){if(e)switch(e.kind){case 289:case 290:case 164:case 166:case 168:case 169:Ni(e.name);break}}function Ni(n){n&&(e.isGeneratedIdentifier(n)?ki(n):e.isBindingPattern(n)&&Ci(n))}function ki(e){if(4===(7&e.autoGenerateFlags))return Ri(zi(e),e.autoGenerateFlags);var n=e.autoGenerateId;return i[n]||(i[n]=Wi(e))}function Ri(n,t){var r=e.getNodeId(n);return a[r]||(a[r]=Hi(n,t))}function Oi(e){return wi(e)&&!o.has(e)&&!(u&&u.has(e))}function wi(n){return!r||e.isFileLevelUniqueName(r,n,T)}function Pi(n,t){for(var r=t;e.isNodeDescendantOf(r,t);r=r.nextContainer)if(r.locals){var a=r.locals.get(e.escapeLeadingUnderscores(n));if(a&&3257279&a.flags)return!1}return!0}function Mi(e,n){if(e&&!(c&e)){var t=268435456===e?"_i":"_n";if(Oi(t))return c|=e,n&&Ai(t),t}while(1){var r=268435455&c;if(c++,8!==r&&13!==r){t=r<26?"_"+String.fromCharCode(97+r):"_"+(r-26);if(Oi(t))return n&&Ai(t),t}}}function Fi(e,n,t,r){if(void 0===n&&(n=Oi),t&&n(e))return r?Ai(e):o.add(e),e;95!==e.charCodeAt(e.length-1)&&(e+="_");var a=1;while(1){var i=e+a;if(n(i))return r?Ai(i):o.add(i),i;a++}}function Gi(e){return Fi(e,wi,!0)}function Bi(e){var n=Si(e.name);return Pi(n,e)?n:Fi(n)}function Ui(n){var t=e.getExternalModuleName(n),r=e.isStringLiteral(t)?e.makeIdentifierFromModuleName(t.text):"module";return Fi(r)}function Vi(){return Fi("default")}function ji(){return Fi("class")}function Ki(n){return e.isIdentifier(n.name)?Ri(n.name):Mi(0)}function Hi(e,n){switch(e.kind){case 78:return Fi(Si(e),Oi,!!(16&n),!!(8&n));case 257:case 256:return Bi(e);case 262:case 268:return Ui(e);case 252:case 253:case 267:return Vi();case 222:return ji();case 166:case 168:case 169:return Ki(e);case 159:return Mi(0,!0);default:return Mi(0)}}function Wi(n){switch(7&n.autoGenerateFlags){case 1:return Mi(0,!!(8&n.autoGenerateFlags));case 2:return Mi(268435456,!!(8&n.autoGenerateFlags));case 3:return Fi(e.idText(n),32&n.autoGenerateFlags?wi:Oi,!!(16&n.autoGenerateFlags),!!(8&n.autoGenerateFlags))}return e.Debug.fail("Unsupported GeneratedIdentifierKind.")}function zi(n){var t=n.autoGenerateId,r=n,a=r.original;while(a){if(r=a,e.isIdentifier(r)&&4&r.autoGenerateFlags&&r.autoGenerateId!==t)break;a=r.original}return r}function qi(e,n){var t=Ge(2,e,n),r=Y,a=Q,i=Z;Ji(n),t(e,n),Xi(n,r,a,i)}function Ji(n){var t=e.getEmitFlags(n),r=e.getCommentRange(n);Yi(n,t,r.pos,r.end),2048&t&&(ee=!0)}function Xi(n,t,r,a){var i=e.getEmitFlags(n),o=e.getCommentRange(n);2048&i&&(ee=!1),Qi(n,i,o.pos,o.end,t,r,a)}function Yi(n,t,r,a){te(),$=!1;var i=r<0||0!==(512&t)||11===n.kind,o=a<0||0!==(1024&t)||11===n.kind;(r>0||a>0)&&r!==a&&(i||ao(r,339!==n.kind),(!i||r>=0&&0!==(512&t))&&(Y=r),(!o||a>=0&&0!==(1024&t))&&(Q=a,251===n.kind&&(Z=a))),e.forEach(e.getSyntheticLeadingComments(n),Zi),re()}function Qi(n,t,r,a,i,o,s){te();var c=a<0||0!==(1024&t)||11===n.kind;e.forEach(e.getSyntheticTrailingComments(n),$i),(r>0||a>0)&&r!==a&&(Y=i,Q=o,Z=s,c||339===n.kind||uo(a)),re()}function Zi(e){(e.hasLeadingNewline||2===e.kind)&&p.writeLine(),eo(e),e.hasTrailingNewLine||2===e.kind?p.writeLine():p.writeSpace(" ")}function $i(e){p.isAtStartOfLine()||p.writeSpace(" "),eo(e),e.hasTrailingNewLine&&p.writeLine()}function eo(n){var t=no(n),r=3===n.kind?e.computeLineStarts(t):void 0;e.writeCommentRange(t,r,p,0,t.length,F)}function no(e){return 3===e.kind?"/*"+e.text+"*/":"//"+e.text}function to(n,t,r){te();var a=t.pos,i=t.end,o=e.getEmitFlags(n),s=a<0||0!==(512&o),c=ee||i<0||0!==(1024&o);s||bo(t),re(),2048&o&&!ee?(ee=!0,r(n),ee=!1):r(n),te(),c||(ao(t.end,!0),$&&!p.isAtStartOfLine()&&p.writeLine()),re()}function ro(n,t){if(e.nodeIsSynthesized(n)||e.nodeIsSynthesized(t))return!1;if(t.pos<n.end)return!1;n=e.getOriginalNode(n),t=e.getOriginalNode(t);var r=n.parent;if(!r||r!==t.parent)return!1;var a=e.getContainingNodeArray(n),i=null===a||void 0===a?void 0:a.indexOf(n);return void 0!==i&&i>-1&&a.indexOf(t)===i+1}function ao(e,n){$=!1,n?0===e&&(null===r||void 0===r?void 0:r.isDeclarationFile)?go(e,oo):go(e,co):0===e&&go(e,io)}function io(e,n,t,r,a){To(e,n)&&co(e,n,t,r,a)}function oo(e,n,t,r,a){To(e,n)||co(e,n,t,r,a)}function so(t,r){return!n.onlyPrintJsDocStyle||(e.isJSDocLikeText(t,r)||e.isPinnedComment(t,r))}function co(n,t,a,i,o){so(r.text,n)&&($||(e.emitNewLineBeforeLeadingCommentOfPosition(Ae(),p,o,n),$=!0),Co(n),e.writeCommentRange(r.text,Ae(),p,n,t,F),Co(t),i?p.writeLine():3===a&&p.writeSpace(" "))}function lo(e){ee||-1===e||ao(e,!0)}function uo(e){yo(e,po)}function po(n,t,a,i){so(r.text,n)&&(p.isAtStartOfLine()||p.writeSpace(" "),Co(n),e.writeCommentRange(r.text,Ae(),p,n,t,F),Co(t),i&&p.writeLine())}function fo(e,n,t){ee||(te(),yo(e,n?po:t?mo:_o),re())}function mo(n,t,a){Co(n),e.writeCommentRange(r.text,Ae(),p,n,t,F),Co(t),2===a&&p.writeLine()}function _o(n,t,a,i){Co(n),e.writeCommentRange(r.text,Ae(),p,n,t,F),Co(t),i?p.writeLine():p.writeSpace(" ")}function go(n,t){!r||-1!==Y&&n===Y||(ho(n)?vo(t):e.forEachLeadingCommentRange(r.text,n,t,n))}function yo(n,t){r&&(-1===Q||n!==Q&&n!==Z)&&e.forEachTrailingCommentRange(r.text,n,t)}function ho(n){return void 0!==v&&e.last(v).nodePos===n}function vo(n){var t=e.last(v).detachedCommentEndPos;v.length-1?v.pop():v=void 0,e.forEachLeadingCommentRange(r.text,t,n,t)}function bo(n){var t=e.emitDetachedComments(r.text,Ae(),p,Eo,n,F,ee);t&&(v?v.push(t):v=[t])}function Eo(n,t,a,i,o,s){so(r.text,i)&&(Co(i),e.writeCommentRange(n,t,a,i,o,s),Co(o))}function To(n,t){return e.isRecognizedTripleSlashComment(r.text,n,t)}function So(n){return void 0===n.parsedSourceMap&&void 0!==n.sourceMapText&&(n.parsedSourceMap=e.tryParseRawSourceMap(n.sourceMapText)||!1),n.parsedSourceMap||void 0}function xo(e,n){var t=Ge(3,e,n);Lo(n),t(e,n),Do(n)}function Lo(n){var t=e.getEmitFlags(n),r=e.getSourceMapRange(n);if(e.isUnparsedNode(n)){e.Debug.assertIsDefined(n.parent,"UnparsedNodes must have parent pointers");var a=So(n.parent);a&&_&&_.appendSourceMap(p.getLine(),p.getColumn(),a,n.parent.sourceMapPath,n.parent.getLineAndCharacterOfPosition(n.pos),n.parent.getLineAndCharacterOfPosition(n.end))}else{var i=r.source||g;339!==n.kind&&0===(16&t)&&r.pos>=0&&Io(r.source||g,Ao(i,r.pos)),64&t&&(q=!0)}}function Do(n){var t=e.getEmitFlags(n),r=e.getSourceMapRange(n);e.isUnparsedNode(n)||(64&t&&(q=!1),339!==n.kind&&0===(32&t)&&r.end>=0&&Io(r.source||g,r.end))}function Ao(n,t){return n.skipTrivia?n.skipTrivia(t):e.skipTrivia(n.text,t)}function Co(n){if(!(q||e.positionIsSynthesized(n)||Oo(g))){var t=e.getLineAndCharacterOfPosition(g,n),r=t.line,a=t.character;_.addMapping(p.getLine(),p.getColumn(),J,r,a,void 0)}}function Io(e,n){if(e!==g){var t=g,r=J;ko(e),Co(n),Ro(t,r)}else Co(n)}function No(n,t,r,a,i){if(q||n&&e.isInJsonFile(n))return i(t,r,a);var o=n&&n.emitNode,s=o&&o.flags||0,c=o&&o.tokenSourceMapRanges&&o.tokenSourceMapRanges[t],l=c&&c.source||g;return a=Ao(l,c?c.pos:a),0===(128&s)&&a>=0&&Io(l,a),a=i(t,r,a),c&&(a=c.end),0===(256&s)&&a>=0&&Io(l,a),a}function ko(e){q||(g=e,e!==y?Oo(e)||(J=_.addSource(e.fileName),n.inlineSources&&_.setSourceContent(J,e.text),y=e,X=J):J=X)}function Ro(e,n){g=e,J=n}function Oo(n){return e.fileExtensionIs(n.fileName,".json")}}function I(){var e=[];return e[1024]=["{","}"],e[2048]=["(",")"],e[4096]=["<",">"],e[8192]=["[","]"],e}function N(e){return r[15360&e][0]}function k(e){return r[15360&e][1]}e.isBuildInfoFile=a,e.forEachEmittedFile=o,e.getTsBuildInfoEmitOutputFilePath=s,e.getOutputPathsForBundle=c,e.getOutputPathsFor=l,e.getOutputExtension=d,e.getOutputDeclarationFileName=f,e.getCommonSourceDirectory=h,e.getCommonSourceDirectoryOfConfig=v,e.getAllProjectOutputs=b,e.getOutputFileNames=E,e.getFirstProjectOutput=T,e.emitFiles=S,e.getBuildInfoText=x,e.getBuildInfo=L,e.notImplementedResolver={hasGlobalName:e.notImplemented,getReferencedExportContainer:e.notImplemented,getReferencedImportDeclaration:e.notImplemented,getReferencedDeclarationWithCollidingName:e.notImplemented,isDeclarationWithCollidingName:e.notImplemented,isValueAliasDeclaration:e.notImplemented,isReferencedAliasDeclaration:e.notImplemented,isTopLevelValueImportEqualsWithEntityName:e.notImplemented,getNodeCheckFlags:e.notImplemented,isDeclarationVisible:e.notImplemented,isLateBound:function(e){return!1},collectLinkedAliases:e.notImplemented,isImplementationOfOverload:e.notImplemented,isRequiredInitializedParameter:e.notImplemented,isOptionalUninitializedParameterProperty:e.notImplemented,isExpandoFunctionDeclaration:e.notImplemented,getPropertiesOfContainerFunction:e.notImplemented,createTypeOfDeclaration:e.notImplemented,createReturnTypeOfSignatureDeclaration:e.notImplemented,createTypeOfExpression:e.notImplemented,createLiteralConstValue:e.notImplemented,isSymbolAccessible:e.notImplemented,isEntityNameVisible:e.notImplemented,getConstantValue:e.notImplemented,getReferencedValueDeclaration:e.notImplemented,getTypeReferenceSerializationKind:e.notImplemented,isOptionalParameter:e.notImplemented,moduleExportsSomeValue:e.notImplemented,isArgumentsLocalBinding:e.notImplemented,getExternalModuleFileFromDeclaration:e.notImplemented,getTypeReferenceDirectivesForEntityName:e.notImplemented,getTypeReferenceDirectivesForSymbol:e.notImplemented,isLiteralConstDeclaration:e.notImplemented,getJsxFactoryEntity:e.notImplemented,getJsxFragmentFactoryEntity:e.notImplemented,getAllAccessorDeclarations:e.notImplemented,getSymbolOfExternalModuleSpecifier:e.notImplemented,isBindingCapturedByNode:e.notImplemented,getDeclarationStatementsForSourceFile:e.notImplemented,isImportRequiredByAugmentation:e.notImplemented},e.emitUsingBuildInfo=A,function(e){e[e["Notification"]=0]="Notification",e[e["Substitution"]=1]="Substitution",e[e["Comments"]=2]="Comments",e[e["SourceMaps"]=3]="SourceMaps",e[e["Emit"]=4]="Emit"}(n||(n={})),e.createPrinter=C,function(e){e[e["Auto"]=0]="Auto",e[e["CountMask"]=268435455]="CountMask",e[e["_i"]=268435456]="_i"}(t||(t={}))}(d||(d={})),function(e){function n(n,t,r){if(n.getDirectories&&n.readDirectory){var a=new e.Map,i=e.createGetCanonicalFileName(r);return{useCaseSensitiveFileNames:r,fileExists:g,readFile:function(e,t){return n.readFile(e,t)},directoryExists:n.directoryExists&&y,getDirectories:v,readDirectory:b,createDirectory:n.createDirectory&&h,writeFile:n.writeFile&&_,addOrDeleteFileOrDirectory:T,addOrDeleteFile:S,clearCache:L,realpath:n.realpath&&E}}function o(n){return e.toPath(n,t,i)}function s(n){return a.get(e.ensureTrailingDirectorySeparator(n))}function c(n){return s(e.getDirectoryPath(n))}function l(n){return e.getBaseFileName(e.normalizePath(n))}function u(t,r){var i;if(!n.realpath||e.ensureTrailingDirectorySeparator(o(n.realpath(t)))===r){var s={files:e.map(n.readDirectory(t,void 0,void 0,["*.*"]),l)||[],directories:n.getDirectories(t)||[]};return a.set(e.ensureTrailingDirectorySeparator(r),s),s}if(null===(i=n.directoryExists)||void 0===i?void 0:i.call(n,t))return a.set(r,!1),!1}function d(n,t){t=e.ensureTrailingDirectorySeparator(t);var r=s(t);if(r)return r;try{return u(n,t)}catch(i){return void e.Debug.assert(!a.has(e.ensureTrailingDirectorySeparator(t)))}}function p(e,n){return i(e)===i(n)}function f(n,t){return e.some(n,(function(e){return p(e,t)}))}function m(n,t,r){if(f(n,t)){if(!r)return e.filterMutate(n,(function(e){return!p(e,t)}))}else if(r)return n.push(t)}function _(e,t,r){var a=o(e),i=c(a);return i&&x(i,l(e),!0),n.writeFile(e,t,r)}function g(e){var t=o(e),r=c(t);return r&&f(r.files,l(e))||n.fileExists(e)}function y(t){var r=o(t);return a.has(e.ensureTrailingDirectorySeparator(r))||n.directoryExists(t)}function h(e){var t=o(e),r=c(t),a=l(e);r&&m(r.directories,a,!0),n.createDirectory(e)}function v(e){var t=o(e),r=d(e,t);return r?r.directories.slice():n.getDirectories(e)}function b(a,i,s,c,u){var p,f=o(a),m=d(a,f);return void 0!==m?e.matchFiles(a,i,s,c,r,t,u,_,E):n.readDirectory(a,i,s,c,u);function _(n){var t=o(n);if(t===f)return m||g(n,t);var r=d(n,t);return void 0!==r?r||g(n,t):e.emptyFileSystemEntries}function g(t,r){if(p&&r===f)return p;var a={files:e.map(n.readDirectory(t,void 0,void 0,["*.*"]),l)||e.emptyArray,directories:n.getDirectories(t)||e.emptyArray};return r===f&&(p=a),a}}function E(e){return n.realpath?n.realpath(e):e}function T(e,t){var r=s(t);if(void 0===r){var a=c(t);if(a){if(n.directoryExists){var i=l(e),o={fileExists:n.fileExists(t),directoryExists:n.directoryExists(t)};return o.directoryExists||f(a.directories,i)?L():x(a,i,o.fileExists),o}L()}}else L()}function S(n,t,r){if(r!==e.FileWatcherEventKind.Changed){var a=c(t);a&&x(a,l(n),r===e.FileWatcherEventKind.Created)}}function x(e,n,t){m(e.files,n,t)}function L(){a.clear()}}var t;function r(n,t,r,a,i){var o,s=e.arrayToMap((null===(o=null===t||void 0===t?void 0:t.configFile)||void 0===o?void 0:o.extendedSourceFiles)||e.emptyArray,i);r.forEach((function(e,t){s.has(t)||(e.projects.delete(n),e.close())})),s.forEach((function(t,i){var o=r.get(i);o?o.projects.add(n):r.set(i,{projects:new e.Set([n]),watcher:a(t,i),close:function(){var e=r.get(i);e&&0===e.projects.size&&(e.watcher.close(),r.delete(i))}})}))}function a(e,n){n.forEach((function(n){n.projects.delete(e)&&n.close()}))}function o(e,n,t){e.delete(n)&&e.forEach((function(r,a){var i,s=r.extendedResult;(null===(i=s.extendedSourceFiles)||void 0===i?void 0:i.some((function(e){return t(e)===n})))&&o(e,a,t)}))}function s(n,t,r){var a=n.getMissingFilePaths(),i=e.arrayToMap(a,e.identity,e.returnTrue);e.mutateMap(t,i,{createNewValue:r,onDeleteValue:e.closeFileWatcher})}function c(n,t,r){function a(e,n){return{watcher:r(e,n),flags:n}}function i(e,t,r){e.flags!==t&&(e.watcher.close(),n.set(r,a(r,t)))}e.mutateMap(n,t,{createNewValue:a,onDeleteValue:m,onExistingValue:i})}function l(n){var t=n.watchedDirPath,r=n.fileOrDirectory,a=n.fileOrDirectoryPath,i=n.configFileName,o=n.options,s=n.program,c=n.extraFileExtensions,l=n.currentDirectory,d=n.useCaseSensitiveFileNames,p=n.writeLog,f=n.toPath,m=e.removeIgnoredPath(a);if(!m)return p("Project: "+i+" Detected ignored path: "+r),!0;if(a=m,a===t)return!1;if(e.hasExtension(a)&&!e.isSupportedSourceFileName(r,o,c))return p("Project: "+i+" Detected file add/remove of non supported extension: "+r),!0;if(e.isExcludedFile(r,o.configFile.configFileSpecs,e.getNormalizedAbsolutePath(e.getDirectoryPath(i),l),d,l))return p("Project: "+i+" Detected excluded file: "+r),!0;if(!s)return!1;if(o.outFile||o.outDir)return!1;if(e.fileExtensionIs(a,".d.ts")){if(o.declarationDir)return!1}else if(!e.fileExtensionIsOneOf(a,e.supportedJSExtensions))return!1;var _=e.removeFileExtension(a),g=e.isArray(s)?void 0:u(s)?s.getProgramOrUndefined():s,y=g||e.isArray(s)?void 0:s;return!(!h(_+".ts")&&!h(_+".tsx"))&&(p("Project: "+i+" Detected output file: "+r),!0);function h(n){return g?!!g.getSourceFileByPath(n):y?y.getState().fileInfos.has(n):!!e.find(s,(function(e){return f(e)===n}))}}function u(e){return!!e.getState}function d(e,n){return!!e&&e.isEmittedFile(n)}function p(n,r,a,o){e.setSysLog(r===t.Verbose?a:e.noop);var s={watchFile:function(e,t,r,a){return n.watchFile(e,t,r,a)},watchDirectory:function(e,t,r,a){return n.watchDirectory(e,t,0!==(1&r),a)}},c=r!==t.None?{watchFile:g("watchFile"),watchDirectory:g("watchDirectory")}:void 0,l=r===t.Verbose?{watchFile:m,watchDirectory:_}:c||s,u=r===t.Verbose?f:e.returnNoopFileWatcher;return{watchFile:d("watchFile"),watchDirectory:d("watchDirectory")};function d(t){return function(r,a,i,o,s,c){var d;return e.matchesExclude(r,"watchFile"===t?null===o||void 0===o?void 0:o.excludeFiles:null===o||void 0===o?void 0:o.excludeDirectories,p(),(null===(d=n.getCurrentDirectory)||void 0===d?void 0:d.call(n))||"")?u(r,i,o,s,c):l[t].call(void 0,r,a,i,o,s,c)}}function p(){return"boolean"===typeof n.useCaseSensitiveFileNames?n.useCaseSensitiveFileNames:n.useCaseSensitiveFileNames()}function f(e,n,t,r,i){return a("ExcludeWatcher:: Added:: "+y(e,n,t,r,i,o)),{close:function(){return a("ExcludeWatcher:: Close:: "+y(e,n,t,r,i,o))}}}function m(e,n,t,r,i,s){a("FileWatcher:: Added:: "+y(e,t,r,i,s,o));var l=c.watchFile(e,n,t,r,i,s);return{close:function(){a("FileWatcher:: Close:: "+y(e,t,r,i,s,o)),l.close()}}}function _(n,t,r,i,s,l){var u="DirectoryWatcher:: Added:: "+y(n,r,i,s,l,o);a(u);var d=e.timestamp(),p=c.watchDirectory(n,t,r,i,s,l),f=e.timestamp()-d;return a("Elapsed:: "+f+"ms "+u),{close:function(){var t="DirectoryWatcher:: Close:: "+y(n,r,i,s,l,o);a(t);var c=e.timestamp();p.close();var u=e.timestamp()-c;a("Elapsed:: "+u+"ms "+t)}}}function g(n){return function(t,r,c,l,u,d){return s[n].call(void 0,t,(function(){for(var s=[],p=0;p<arguments.length;p++)s[p]=arguments[p];var f=("watchFile"===n?"FileWatcher":"DirectoryWatcher")+":: Triggered with "+s[0]+" "+(void 0!==s[1]?s[1]:"")+":: "+y(t,c,l,u,d,o);a(f);var m=e.timestamp();r.call.apply(r,i([void 0],s));var _=e.timestamp()-m;a("Elapsed:: "+_+"ms "+f)}),c,l,u,d)}}function y(e,n,t,r,a,i){return"WatchInfo: "+e+" "+n+" "+JSON.stringify(t)+" "+(i?i(r,a):void 0===a?r:r+" "+a)}}function f(n){var t=null===n||void 0===n?void 0:n.fallbackPolling;return{watchFile:void 0!==t?t:e.WatchFileKind.PriorityPollingInterval}}function m(e){e.watcher.close()}e.createCachedDirectoryStructureHost=n,function(e){e[e["None"]=0]="None",e[e["Partial"]=1]="Partial",e[e["Full"]=2]="Full"}(e.ConfigFileProgramReloadLevel||(e.ConfigFileProgramReloadLevel={})),e.updateSharedExtendedConfigFileWatcher=r,e.clearSharedExtendedConfigFileWatcher=a,e.cleanExtendedConfigCache=o,e.updateMissingFilePathsWatch=s,e.updateWatchingWildcardDirectories=c,e.isIgnoredFileFromWildCardWatching=l,e.isEmittedFileOfProgram=d,function(e){e[e["None"]=0]="None",e[e["TriggerOnly"]=1]="TriggerOnly",e[e["Verbose"]=2]="Verbose"}(t=e.WatchLogLevel||(e.WatchLogLevel={})),e.getWatchFactory=p,e.getFallbackOptions=f,e.closeFileWatcherOf=m}(d||(d={})),function(e){function n(n,t,r){return void 0===r&&(r="tsconfig.json"),e.forEachAncestorDirectory(n,(function(n){var a=e.combinePaths(n,r);return t(a)?a:void 0}))}function t(n,t){var r=e.getDirectoryPath(t),a=e.isRootedDiskPath(n)?n:e.combinePaths(r,n);return e.normalizePath(a)}function r(n,t,r){var a,i=e.forEach(n,(function(n){var i=e.getNormalizedPathComponents(n,t);if(i.pop(),a){for(var o=Math.min(a.length,i.length),s=0;s<o;s++)if(r(a[s])!==r(i[s])){if(0===s)return!0;a.length=s;break}i.length<a.length&&(a.length=i.length)}else a=i}));return i?"":a?e.getPathFromPathComponents(a):t}function a(e,n){return o(e,n)}function o(n,t,r){void 0===r&&(r=e.sys);var a,i=new e.Map,o=e.createGetCanonicalFileName(r.useCaseSensitiveFileNames),s=e.maybeBind(r,r.createHash)||e.generateDjb2Hash;function c(n,r,a){var i;try{e.performance.mark("beforeIORead"),i=_.readFile(n),e.performance.mark("afterIORead"),e.performance.measure("I/O Read","beforeIORead","afterIORead")}catch(o){a&&a(o.message),i=""}return void 0!==i?e.createSourceFile(n,i,r,t):void 0}function l(e){return!!i.has(e)||!!(_.directoryExists||r.directoryExists)(e)&&(i.set(e,!0),!0)}function u(n,t,a,i){try{e.performance.mark("beforeIOWrite"),e.writeFileEnsuringDirectories(n,t,a,(function(e,n,t){return d(e,n,t)}),(function(e){return(_.createDirectory||r.createDirectory)(e)}),(function(e){return l(e)})),e.performance.mark("afterIOWrite"),e.performance.measure("I/O Write","beforeIOWrite","afterIOWrite")}catch(o){i&&i(o.message)}}function d(t,i,o){if(e.isWatchSet(n)&&r.getModifiedTime){a||(a=new e.Map);var c=s(i),l=r.getModifiedTime(t);if(l){var u=a.get(t);if(u&&u.byteOrderMark===o&&u.hash===c&&u.mtime.getTime()===l.getTime())return}r.writeFile(t,i,o);var d=r.getModifiedTime(t)||e.missingFileModifiedTime;a.set(t,{hash:c,byteOrderMark:o,mtime:d})}else r.writeFile(t,i,o)}function p(){return e.getDirectoryPath(e.normalizePath(r.getExecutingFilePath()))}var f=e.getNewLineCharacter(n,(function(){return r.newLine})),m=r.realpath&&function(e){return r.realpath(e)},_={getSourceFile:c,getDefaultLibLocation:p,getDefaultLibFileName:function(n){return e.combinePaths(p(),e.getDefaultLibFileName(n))},writeFile:u,getCurrentDirectory:e.memoize((function(){return r.getCurrentDirectory()})),useCaseSensitiveFileNames:function(){return r.useCaseSensitiveFileNames},getCanonicalFileName:o,getNewLine:function(){return f},fileExists:function(e){return r.fileExists(e)},readFile:function(e){return r.readFile(e)},trace:function(e){return r.write(e+f)},directoryExists:function(e){return r.directoryExists(e)},getEnvironmentVariable:function(e){return r.getEnvironmentVariable?r.getEnvironmentVariable(e):""},getDirectories:function(e){return r.getDirectories(e)},realpath:m,readDirectory:function(e,n,t,a,i){return r.readDirectory(e,n,t,a,i)},createDirectory:function(e){return r.createDirectory(e)},createHash:e.maybeBind(r,r.createHash)};return _}function s(n,t,r){var a=n.readFile,i=n.fileExists,o=n.directoryExists,s=n.createDirectory,c=n.writeFile,l=new e.Map,u=new e.Map,d=new e.Map,p=new e.Map,f=function(e){var n=t(e),r=l.get(n);return void 0!==r?!1!==r?r:void 0:m(n,e)},m=function(e,t){var r=a.call(n,t);return l.set(e,void 0!==r&&r),r};n.readFile=function(r){var i=t(r),o=l.get(i);return void 0!==o?!1!==o?o:void 0:e.fileExtensionIs(r,".json")||e.isBuildInfoFile(r)?m(i,r):a.call(n,r)};var _=r?function(n,a,i,o){var s=t(n),c=p.get(s);if(c)return c;var l=r(n,a,i,o);return l&&(e.isDeclarationFileName(n)||e.fileExtensionIs(n,".json"))&&p.set(s,l),l}:void 0;return n.fileExists=function(e){var r=t(e),a=u.get(r);if(void 0!==a)return a;var o=i.call(n,e);return u.set(r,!!o),o},c&&(n.writeFile=function(e,r,a,i,o){var s=t(e);u.delete(s);var d=l.get(s);if(void 0!==d&&d!==r)l.delete(s),p.delete(s);else if(_){var f=p.get(s);f&&f.text!==r&&p.delete(s)}c.call(n,e,r,a,i,o)}),o&&s&&(n.directoryExists=function(e){var r=t(e),a=d.get(r);if(void 0!==a)return a;var i=o.call(n,e);return d.set(r,!!i),i},n.createDirectory=function(e){var r=t(e);d.delete(r),s.call(n,e)}),{originalReadFile:a,originalFileExists:i,originalDirectoryExists:o,originalCreateDirectory:s,originalWriteFile:c,getSourceFileWithCache:_,readFileWithCache:f}}function c(n,t,r){var a;return a=e.addRange(a,n.getConfigFileParsingDiagnostics()),a=e.addRange(a,n.getOptionsDiagnostics(r)),a=e.addRange(a,n.getSyntacticDiagnostics(t,r)),a=e.addRange(a,n.getGlobalDiagnostics(r)),a=e.addRange(a,n.getSemanticDiagnostics(t,r)),e.getEmitDeclarations(n.getCompilerOptions())&&(a=e.addRange(a,n.getDeclarationDiagnostics(t,r))),e.sortAndDeduplicateDiagnostics(a||e.emptyArray)}function l(e,n){for(var t="",r=0,a=e;r<a.length;r++){var i=a[r];t+=u(i,n)}return t}function u(n,t){var r=e.diagnosticCategoryName(n)+" TS"+n.code+": "+S(n.messageText,t.getNewLine())+t.getNewLine();if(n.file){var a=e.getLineAndCharacterOfPosition(n.file,n.start),i=a.line,o=a.character,s=n.file.fileName,c=e.convertToRelativePath(s,t.getCurrentDirectory(),(function(e){return t.getCanonicalFileName(e)}));return c+"("+(i+1)+","+(o+1)+"): "+r}return r}var d;e.findConfigFile=n,e.resolveTripleslashReference=t,e.computeCommonSourceDirectoryOfFilenames=r,e.createCompilerHost=a,e.createCompilerHostWorker=o,e.changeCompilerHostLikeToUseCache=s,e.getPreEmitDiagnostics=c,e.formatDiagnostics=l,e.formatDiagnostic=u,function(e){e["Grey"]="[90m",e["Red"]="[91m",e["Yellow"]="[93m",e["Blue"]="[94m",e["Cyan"]="[96m"}(d=e.ForegroundColorEscapeSequences||(e.ForegroundColorEscapeSequences={}));var p="[7m",f=" ",m="[0m",_="...",g="  ",y="    ";function h(n){switch(n){case e.DiagnosticCategory.Error:return d.Red;case e.DiagnosticCategory.Warning:return d.Yellow;case e.DiagnosticCategory.Suggestion:return e.Debug.fail("Should never get an Info diagnostic on the command line.");case e.DiagnosticCategory.Message:return d.Blue}}function v(e,n){return n+e+m}function b(n,t,r,a,i,o){var s=e.getLineAndCharacterOfPosition(n,t),c=s.line,l=s.character,u=e.getLineAndCharacterOfPosition(n,t+r),d=u.line,g=u.character,y=e.getLineAndCharacterOfPosition(n,n.text.length).line,h=d-c>=4,b=(d+1+"").length;h&&(b=Math.max(_.length,b));for(var E="",T=c;T<=d;T++){E+=o.getNewLine(),h&&c+1<T&&T<d-1&&(E+=a+v(e.padLeft(_,b),p)+f+o.getNewLine(),T=d-1);var S=e.getPositionOfLineAndCharacter(n,T,0),x=T<y?e.getPositionOfLineAndCharacter(n,T+1,0):n.text.length,L=n.text.slice(S,x);if(L=L.replace(/\s+$/g,""),L=L.replace(/\t/g," "),E+=a+v(e.padLeft(T+1+"",b),p)+f,E+=L+o.getNewLine(),E+=a+v(e.padLeft("",b),p)+f,E+=i,T===c){var D=T===d?g:void 0;E+=L.slice(0,l).replace(/\S/g," "),E+=L.slice(l,D).replace(/./g,"~")}else E+=T===d?L.slice(0,g).replace(/./g,"~"):L.replace(/./g,"~");E+=m}return E}function E(n,t,r,a){void 0===a&&(a=v);var i=e.getLineAndCharacterOfPosition(n,t),o=i.line,s=i.character,c=r?e.convertToRelativePath(n.fileName,r.getCurrentDirectory(),(function(e){return r.getCanonicalFileName(e)})):n.fileName,l="";return l+=a(c,d.Cyan),l+=":",l+=a(""+(o+1),d.Yellow),l+=":",l+=a(""+(s+1),d.Yellow),l}function T(n,t){for(var r="",a=0,i=n;a<i.length;a++){var o=i[a];if(o.file){var s=o.file,c=o.start;r+=E(s,c,t),r+=" - "}if(r+=v(e.diagnosticCategoryName(o),h(o.category)),r+=v(" TS"+o.code+": ",d.Grey),r+=S(o.messageText,t.getNewLine()),o.file&&(r+=t.getNewLine(),r+=b(o.file,o.start,o.length,"",h(o.category),t)),o.relatedInformation){r+=t.getNewLine();for(var l=0,u=o.relatedInformation;l<u.length;l++){var p=u[l],f=(s=p.file,c=p.start,p.length),m=p.messageText;s&&(r+=t.getNewLine(),r+=g+E(s,c,t),r+=b(s,c,f,y,d.Cyan,t)),r+=t.getNewLine(),r+=y+S(m,t.getNewLine())}}r+=t.getNewLine()}return r}function S(n,t,r){if(void 0===r&&(r=0),e.isString(n))return n;if(void 0===n)return"";var a="";if(r){a+=t;for(var i=0;i<r;i++)a+="  "}if(a+=n.messageText,r++,n.next)for(var o=0,s=n.next;o<s.length;o++){var c=s[o];a+=S(c,t,r)}return a}function x(n,t,r,a){if(0===n.length)return[];for(var i=[],o=new e.Map,s=0,c=n;s<c.length;s++){var l=c[s],u=void 0;o.has(l)?u=o.get(l):o.set(l,u=a(l,t,r)),i.push(u)}return i}function L(e,n){return D(void 0,e,(function(e,t){return e&&n(e,t)}))}function D(n,t,r,a){var i;return o(n,t,void 0);function o(n,t,s){if(a){var c=a(n,s);if(c)return c}return e.forEach(t,(function(n,t){if(!n||!(null===i||void 0===i?void 0:i.has(n.sourceFile.path))){var a=r(n,s,t);return a||!n?a:((i||(i=new e.Set)).add(n.sourceFile.path),o(n.commandLine.projectReferences,n.references,n))}}))}}function A(n){switch(null===n||void 0===n?void 0:n.kind){case e.FileIncludeKind.Import:case e.FileIncludeKind.ReferenceFile:case e.FileIncludeKind.TypeReferenceDirective:case e.FileIncludeKind.LibReferenceDirective:return!0;default:return!1}}function C(e){return void 0!==e.pos}function I(n,t){var r,a,i,o,s,c,l,u,d,p,f=e.Debug.checkDefined(n(t.file)),m=t.kind,_=t.index;switch(m){case e.FileIncludeKind.Import:var g=K(f,_);if(p=null===(s=null===(o=f.resolvedModules)||void 0===o?void 0:o.get(g.text))||void 0===s?void 0:s.packageId,-1===g.pos)return{file:f,packageId:p,text:g.text};u=e.skipTrivia(f.text,g.pos),d=g.end;break;case e.FileIncludeKind.ReferenceFile:r=f.referencedFiles[_],u=r.pos,d=r.end;break;case e.FileIncludeKind.TypeReferenceDirective:a=f.typeReferenceDirectives[_],u=a.pos,d=a.end,p=null===(l=null===(c=f.resolvedTypeReferenceDirectiveNames)||void 0===c?void 0:c.get(e.toFileNameLowerCase(f.typeReferenceDirectives[_].fileName)))||void 0===l?void 0:l.packageId;break;case e.FileIncludeKind.LibReferenceDirective:i=f.libReferenceDirectives[_],u=i.pos,d=i.end;break;default:return e.Debug.assertNever(m)}return{file:f,pos:u,end:d,packageId:p}}function N(n,t,r,a,i,o,s,c,l){if(!n||(null===s||void 0===s?void 0:s()))return!1;if(!e.arrayIsEqualTo(n.getRootFileNames(),t))return!1;var u;if(!e.arrayIsEqualTo(n.getProjectReferences(),l,m))return!1;if(n.getSourceFiles().some(p))return!1;if(n.getMissingFilePaths().some(i))return!1;var d=n.getCompilerOptions();return!!e.compareDataObjects(d,r)&&(!d.configFile||!r.configFile||d.configFile.text===r.configFile.text);function p(e){return!f(e)||o(e.path)}function f(e){return e.version===a(e.resolvedPath,e.fileName)}function m(t,r,a){return e.projectReferenceIsEqualTo(t,r)&&_(n.getResolvedProjectReferences()[a],t)}function _(n,t){if(n){if(e.contains(u,n))return!0;var r=U(t),a=c(r);return!!a&&(n.commandLine.options.configFile===a.options.configFile&&(!!e.arrayIsEqualTo(n.commandLine.fileNames,a.fileNames)&&((u||(u=[])).push(n),!e.forEach(n.references,(function(e,t){return!_(e,n.commandLine.projectReferences[t])})))))}var i=U(t);return!c(i)}}function k(e){return e.options.configFile?i(i([],e.options.configFile.parseDiagnostics),e.errors):e.errors}function R(n,t){if(!n)return!1;var r=n.getCompilerOptions();return!!e.sourceFileAffectingCompilerOptions.some((function(n){return!e.isJsonEqual(e.getCompilerOptionValue(r,n),e.getCompilerOptionValue(t,n))}))}function O(e,n,t,r,a){return{rootNames:e,options:n,host:t,oldProgram:r,configFileParsingDiagnostics:a}}function w(n,r,o,s,c){var l,u,d,p,f,m,_,g,y,h,v,b,E=e.isArray(n)?O(n,r,o,s,c):n,T=E.rootNames,S=E.options,L=E.configFileParsingDiagnostics,N=E.projectReferences,k=E.oldProgram,w=new e.Map,K=e.createMultiMap(),H={},W={},z=new e.Map,q="number"===typeof S.maxNodeModuleJsDepth?S.maxNodeModuleJsDepth:0,J=0,X=new e.Map,Y=new e.Map;null===e.tracing||void 0===e.tracing||e.tracing.push("program","createProgram",{configFilePath:S.configFilePath,rootDir:S.rootDir},!0),e.performance.mark("beforeProgram");var Q,Z,$,ee,ne,te=E.host||a(S),re=G(te),ae=S.noLib,ie=e.memoize((function(){return te.getDefaultLibFileName(S)})),oe=te.getDefaultLibLocation?te.getDefaultLibLocation():e.getDirectoryPath(ie()),se=e.createDiagnosticCollection(),ce=te.getCurrentDirectory(),le=e.getSupportedExtensions(S),ue=e.getSuppoertedExtensionsWithJsonIfResolveJsonModule(S,le),de=new e.Map,pe=te.hasInvalidatedResolution||e.returnFalse;if(te.resolveModuleNames)ee=function(n,t,r,a){return te.resolveModuleNames(e.Debug.checkEachDefined(n),t,r,a,S).map((function(n){if(!n||void 0!==n.extension)return n;var t=e.clone(n);return t.extension=e.extensionFromPath(n.resolvedFileName),t}))};else{Z=e.createModuleResolutionCache(ce,vt,S);var fe=function(n,t,r){return e.resolveModuleName(n,t,S,te,Z,r).resolvedModule};ee=function(n,t,r,a){return x(e.Debug.checkEachDefined(n),t,a,fe)}}if(te.resolveTypeReferenceDirectives)ne=function(n,t,r){return te.resolveTypeReferenceDirectives(e.Debug.checkEachDefined(n),t,r,S)};else{$=e.createTypeReferenceDirectiveResolutionCache(ce,vt,void 0,null===Z||void 0===Z?void 0:Z.getPackageJsonInfoCache());var me=function(n,t,r){return e.resolveTypeReferenceDirective(n,t,S,te,r,$).resolvedTypeReferenceDirective};ne=function(n,t,r){return x(e.Debug.checkEachDefined(n),t,r,me)}}var _e,ge,ye,he,ve,be=new e.Map,Ee=new e.Map,Te=e.createMultiMap(),Se=new e.Map,xe=te.useCaseSensitiveFileNames()?new e.Map:void 0,Le=!!(null===(l=te.useSourceOfProjectReferenceRedirect)||void 0===l?void 0:l.call(te))&&!S.disableSourceOfProjectReferenceRedirect,De=P({compilerHost:te,getSymlinkCache:Ht,useSourceOfProjectReferenceRedirect:Le,toPath:Qe,getResolvedProjectReferences:on,getSourceOfProjectReferenceRedirect:dt,forEachResolvedProjectReference:ut}),Ae=De.onProgramCreateComplete,Ce=De.fileExists,Ie=De.directoryExists;null===e.tracing||void 0===e.tracing||e.tracing.push("program","shouldProgramCreateNewSourceFiles",{hasOldProgram:!!k});var Ne,ke=R(k,S);if(null===e.tracing||void 0===e.tracing||e.tracing.pop(),null===e.tracing||void 0===e.tracing||e.tracing.push("program","tryReuseStructureFromOldProgram",{}),Ne=tn(),null===e.tracing||void 0===e.tracing||e.tracing.pop(),2!==Ne){p=[],f=[],N&&(ge||(ge=N.map(Tt)),T.length&&(null===ge||void 0===ge||ge.forEach((function(n,t){if(n){var r=e.outFile(n.commandLine.options);if(Le){if(r||e.getEmitModuleKind(n.commandLine.options)===e.ModuleKind.None)for(var a=0,i=n.commandLine.fileNames;a<i.length;a++){var o=i[a];$n(o,{kind:e.FileIncludeKind.SourceFromProjectReference,index:t})}}else if(r)$n(e.changeExtension(r,".d.ts"),{kind:e.FileIncludeKind.OutputFromProjectReference,index:t});else if(e.getEmitModuleKind(n.commandLine.options)===e.ModuleKind.None)for(var s=e.memoize((function(){return e.getCommonSourceDirectoryOfConfig(n.commandLine,!te.useCaseSensitiveFileNames())})),c=0,l=n.commandLine.fileNames;c<l.length;c++){o=l[c];e.fileExtensionIs(o,".d.ts")||e.fileExtensionIs(o,".json")||$n(e.getOutputDeclarationFileName(o,n.commandLine,!te.useCaseSensitiveFileNames(),s),{kind:e.FileIncludeKind.OutputFromProjectReference,index:t})}}})))),null===e.tracing||void 0===e.tracing||e.tracing.push("program","processRootFiles",{count:T.length}),e.forEach(T,(function(n,t){return Hn(n,!1,!1,{kind:e.FileIncludeKind.RootFile,index:t})})),null===e.tracing||void 0===e.tracing||e.tracing.pop();var Re=T.length?e.getAutomaticTypeDirectiveNames(S,te):e.emptyArray;if(Re.length){null===e.tracing||void 0===e.tracing||e.tracing.push("program","processTypeReferences",{count:Re.length});for(var Oe=S.configFilePath?e.getDirectoryPath(S.configFilePath):te.getCurrentDirectory(),we=e.combinePaths(Oe,e.inferredTypesContainingFile),Pe=We(Re,we),Me=0;Me<Re.length;Me++)gt(Re[Me],Pe[Me],{kind:e.FileIncludeKind.AutomaticTypeDirectiveFile,typeReference:Re[Me],packageId:null===(u=Pe[Me])||void 0===u?void 0:u.packageId});null===e.tracing||void 0===e.tracing||e.tracing.pop()}if(T.length&&!ae){var Fe=ie();!S.lib&&Fe?Hn(Fe,!0,!1,{kind:e.FileIncludeKind.LibFile}):e.forEach(S.lib,(function(n,t){Hn(e.combinePaths(oe,n),!0,!1,{kind:e.FileIncludeKind.LibFile,index:t})}))}_e=e.arrayFrom(e.mapDefinedIterator(Se.entries(),(function(e){var n=e[0],t=e[1];return void 0===t?n:void 0}))),m=e.stableSort(p,Je).concat(f),p=void 0,f=void 0}if(e.Debug.assert(!!_e),k&&te.onReleaseOldSourceFile){for(var Ge=k.getSourceFiles(),Be=0,Ue=Ge;Be<Ue.length;Be++){var Ve=Ue[Be],je=hn(Ve.resolvedPath);(ke||!je||Ve.resolvedPath===Ve.path&&je.resolvedPath!==Ve.path)&&te.onReleaseOldSourceFile(Ve,k.getCompilerOptions(),!!hn(Ve.path))}te.getParsedCommandLine||k.forEachResolvedProjectReference((function(e){ft(e.sourceFile.path)||te.onReleaseOldSourceFile(e.sourceFile,k.getCompilerOptions(),!1)}))}k&&te.onReleaseParsedCommandLine&&D(k.getProjectReferences(),k.getResolvedProjectReferences(),(function(e,n,t){var r=(null===n||void 0===n?void 0:n.commandLine.projectReferences[t])||k.getProjectReferences()[t],a=U(r);(null===ye||void 0===ye?void 0:ye.has(Qe(a)))||te.onReleaseParsedCommandLine(a,e,k.getCompilerOptions())})),$=void 0,k=void 0;var Ke={getRootFileNames:function(){return T},getSourceFile:yn,getSourceFileByPath:hn,getSourceFiles:function(){return m},getMissingFilePaths:function(){return _e},getFilesByNameMap:function(){return Se},getCompilerOptions:function(){return S},getSyntacticDiagnostics:bn,getOptionsDiagnostics:Un,getGlobalDiagnostics:jn,getSemanticDiagnostics:En,getCachedSemanticDiagnostics:Tn,getSuggestionDiagnostics:On,getDeclarationDiagnostics:Ln,getBindAndCheckDiagnostics:Sn,getProgramDiagnostics:xn,getTypeChecker:fn,getClassifiableNames:$e,getDiagnosticsProducingTypeChecker:dn,getCommonSourceDirectory:Ze,emit:mn,getCurrentDirectory:function(){return ce},getNodeCount:function(){return dn().getNodeCount()},getIdentifierCount:function(){return dn().getIdentifierCount()},getSymbolCount:function(){return dn().getSymbolCount()},getTypeCount:function(){return dn().getTypeCount()},getInstantiationCount:function(){return dn().getInstantiationCount()},getRelationCacheSizes:function(){return dn().getRelationCacheSizes()},getFileProcessingDiagnostics:function(){return b},getResolvedTypeReferenceDirectives:function(){return z},isSourceFileFromExternalLibrary:ln,isSourceFileDefaultLibrary:un,dropDiagnosticsProducingTypeChecker:pn,getSourceFileFromReference:Yn,getLibFileFromReference:Xn,sourceFileToPackageName:Ee,redirectTargetsMap:Te,isEmittedFile:jt,getConfigFileParsingDiagnostics:Kn,getResolvedModuleWithFailedLookupLocationsFromCache:Ye,getProjectReferences:sn,getResolvedProjectReferences:on,getProjectReferenceRedirect:ot,getResolvedProjectReferenceToRedirect:lt,getResolvedProjectReferenceByPath:ft,forEachResolvedProjectReference:ut,isSourceOfProjectReferenceRedirect:pt,emitBuildInfo:an,fileExists:Ce,directoryExists:Ie,getSymlinkCache:Ht,realpath:null===(d=te.realpath)||void 0===d?void 0:d.bind(te),useCaseSensitiveFileNames:function(){return te.useCaseSensitiveFileNames()},getFileIncludeReasons:function(){return K},structureIsReused:Ne};return Ae(),null===b||void 0===b||b.forEach((function(n){switch(n.kind){case 1:return se.add(xt(n.file&&hn(n.file),n.fileProcessingReason,n.diagnostic,n.args||e.emptyArray));case 0:var t=I(hn,n.reason),r=t.file,a=t.pos,o=t.end;return se.add(e.createFileDiagnostic.apply(void 0,i([r,e.Debug.checkDefined(a),e.Debug.checkDefined(o)-a,n.diagnostic],n.args||e.emptyArray)));default:e.Debug.assertNever(n)}})),St(),e.performance.mark("afterProgram"),e.performance.measure("Program","beforeProgram","afterProgram"),null===e.tracing||void 0===e.tracing||e.tracing.pop(),Ke;function He(n,t,r){if(!n.length)return e.emptyArray;var a=e.getNormalizedAbsolutePath(t.originalFileName,ce),i=ze(t);null===e.tracing||void 0===e.tracing||e.tracing.push("program","resolveModuleNamesWorker",{containingFileName:a}),e.performance.mark("beforeResolveModule");var o=ee(n,a,r,i);return e.performance.mark("afterResolveModule"),e.performance.measure("ResolveModule","beforeResolveModule","afterResolveModule"),null===e.tracing||void 0===e.tracing||e.tracing.pop(),o}function We(n,t){if(!n.length)return[];var r=e.isString(t)?t:e.getNormalizedAbsolutePath(t.originalFileName,ce),a=e.isString(t)?void 0:ze(t);null===e.tracing||void 0===e.tracing||e.tracing.push("program","resolveTypeReferenceDirectiveNamesWorker",{containingFileName:r}),e.performance.mark("beforeResolveTypeReference");var i=ne(n,r,a);return e.performance.mark("afterResolveTypeReference"),e.performance.measure("ResolveTypeReference","beforeResolveTypeReference","afterResolveTypeReference"),null===e.tracing||void 0===e.tracing||e.tracing.pop(),i}function ze(n){var t=lt(n.originalFileName);if(t||!e.fileExtensionIs(n.originalFileName,".d.ts"))return t;var r=qe(n.originalFileName,n.path);if(r)return r;if(te.realpath&&S.preserveSymlinks&&e.stringContains(n.originalFileName,e.nodeModulesPathPart)){var a=te.realpath(n.originalFileName),i=Qe(a);return i===n.path?void 0:qe(a,i)}}function qe(n,t){var r=dt(n);return e.isString(r)?lt(r):r?ut((function(n){var r=e.outFile(n.commandLine.options);if(r)return Qe(r)===t?n:void 0})):void 0}function Je(n,t){return e.compareValues(Xe(n),Xe(t))}function Xe(n){if(e.containsPath(oe,n.fileName,!1)){var t=e.getBaseFileName(n.fileName);if("lib.d.ts"===t||"lib.es6.d.ts"===t)return 0;var r=e.removeSuffix(e.removePrefix(t,"lib."),".d.ts"),a=e.libs.indexOf(r);if(-1!==a)return a+1}return e.libs.length+2}function Ye(n,t){return Z&&e.resolveModuleNameFromCache(n,t,Z)}function Qe(n){return e.toPath(n,ce,vt)}function Ze(){if(void 0===g){var n=e.filter(m,(function(n){return e.sourceFileMayBeEmitted(n,Ke)}));g=e.getCommonSourceDirectory(S,(function(){return e.mapDefined(n,(function(e){return e.isDeclarationFile?void 0:e.fileName}))}),ce,vt,(function(e){return Et(n,e)}))}return g}function $e(){var n;if(!v){fn(),v=new e.Set;for(var t=0,r=m;t<r.length;t++){var a=r[t];null===(n=a.classifiableNames)||void 0===n||n.forEach((function(e){return v.add(e)}))}}return v}function en(n,t){if(0===Ne&&!t.ambientModuleNames.length)return He(n,t,void 0);var r,a,i,o=k&&k.getSourceFile(t.fileName);if(o!==t&&t.resolvedModules){for(var s=[],c=0,l=n;c<l.length;c++){var u=l[c],d=t.resolvedModules.get(u);s.push(d)}return s}for(var p={},f=0;f<n.length;f++){u=n[f];if(t===o&&!pe(o.path)){var m=e.getResolvedModule(o,u);if(m){e.isTraceEnabled(S,te)&&e.trace(te,e.Diagnostics.Reusing_resolution_of_module_0_to_file_1_from_old_program,u,e.getNormalizedAbsolutePath(t.originalFileName,ce)),(a||(a=new Array(n.length)))[f]=m,(i||(i=[])).push(u);continue}}var _=!1;e.contains(t.ambientModuleNames,u)?(_=!0,e.isTraceEnabled(S,te)&&e.trace(te,e.Diagnostics.Module_0_was_resolved_as_locally_declared_ambient_module_in_file_1,u,e.getNormalizedAbsolutePath(t.originalFileName,ce))):_=h(u),_?(a||(a=new Array(n.length)))[f]=p:(r||(r=[])).push(u)}var g=r&&r.length?He(r,t,i):e.emptyArray;if(!a)return e.Debug.assert(g.length===n.length),g;var y=0;for(f=0;f<a.length;f++)a[f]?a[f]===p&&(a[f]=void 0):(a[f]=g[y],y++);return e.Debug.assert(y===g.length),a;function h(n){var t=e.getResolvedModule(o,n),r=t&&k.getSourceFile(t.resolvedFileName);if(t&&r)return!1;var a=w.get(n);return!!a&&(e.isTraceEnabled(S,te)&&e.trace(te,e.Diagnostics.Module_0_was_resolved_as_ambient_module_declared_in_1_since_this_file_was_not_modified,n,a),!0)}}function nn(){return!D(k.getProjectReferences(),k.getResolvedProjectReferences(),(function(n,t,r){var a=(t?t.commandLine.projectReferences:N)[r],i=Tt(a);return n?!i||i.sourceFile!==n.sourceFile||!e.arrayIsEqualTo(n.commandLine.fileNames,i.commandLine.fileNames):void 0!==i}),(function(n,t){var r=t?ft(t.sourceFile.path).commandLine.projectReferences:N;return!e.arrayIsEqualTo(n,r,e.projectReferenceIsEqualTo)}))}function tn(){var n;if(!k)return 0;var t=k.getCompilerOptions();if(e.changesAffectModuleResolution(t,S))return 0;var r=k.getRootFileNames();if(!e.arrayIsEqualTo(r,T))return 0;if(!e.arrayIsEqualTo(S.types,t.types))return 0;if(!nn())return 0;N&&(ge=N.map(Tt));var a=[],i=[];if(Ne=2,k.getMissingFilePaths().some((function(e){return te.fileExists(e)})))return 0;var o,s=k.getSourceFiles();(function(e){e[e["Exists"]=0]="Exists",e[e["Modified"]=1]="Modified"})(o||(o={}));for(var c=new e.Map,l=0,u=s;l<u.length;l++){var d=u[l],p=te.getSourceFileByPath?te.getSourceFileByPath(d.fileName,d.resolvedPath,S.target,void 0,ke):te.getSourceFile(d.fileName,S.target,void 0,ke);if(!p)return 0;e.Debug.assert(!p.redirectInfo,"Host should not return a redirect source file from `getSourceFile`");var f=void 0;if(d.redirectInfo){if(p!==d.redirectInfo.unredirected)return 0;f=!1,p=d}else if(k.redirectTargetsMap.has(d.path)){if(p!==d)return 0;f=!1}else f=p!==d;p.path=d.path,p.originalFileName=d.originalFileName,p.resolvedPath=d.resolvedPath,p.fileName=d.fileName;var _=k.sourceFileToPackageName.get(d.path);if(void 0!==_){var g=c.get(_),y=f?1:0;if(void 0!==g&&1===y||1===g)return 0;c.set(_,y)}if(f){if(!e.arrayIsEqualTo(d.libReferenceDirectives,p.libReferenceDirectives,Wn))return 0;d.hasNoDefaultLib!==p.hasNoDefaultLib&&(Ne=1),e.arrayIsEqualTo(d.referencedFiles,p.referencedFiles,Wn)||(Ne=1),Jn(p),e.arrayIsEqualTo(d.imports,p.imports,zn)||(Ne=1),e.arrayIsEqualTo(d.moduleAugmentations,p.moduleAugmentations,zn)||(Ne=1),(3145728&d.flags)!==(3145728&p.flags)&&(Ne=1),e.arrayIsEqualTo(d.typeReferenceDirectives,p.typeReferenceDirectives,Wn)||(Ne=1),i.push({oldFile:d,newFile:p})}else pe(d.path)&&(Ne=1,i.push({oldFile:d,newFile:p}));a.push(p)}if(2!==Ne)return Ne;for(var h=i.map((function(e){return e.oldFile})),v=0,E=s;v<E.length;v++){var x=E[v];if(!e.contains(h,x))for(var L=0,D=x.ambientModuleNames;L<D.length;L++){var A=D[L];w.set(A,x.fileName)}}for(var C=0,I=i;C<I.length;C++){var R=I[C],O=(d=R.oldFile,p=R.newFile,j(p)),P=en(O,p),M=e.hasChangesInResolutions(O,P,d.resolvedModules,e.moduleResolutionIsEqualTo);M?(Ne=1,p.resolvedModules=e.zipToMap(O,P)):p.resolvedModules=d.resolvedModules;var F=e.map(p.typeReferenceDirectives,(function(n){return e.toFileNameLowerCase(n.fileName)})),G=We(F,p),B=e.hasChangesInResolutions(F,G,d.resolvedTypeReferenceDirectiveNames,e.typeDirectiveIsEqualTo);B?(Ne=1,p.resolvedTypeReferenceDirectiveNames=e.zipToMap(F,G)):p.resolvedTypeReferenceDirectiveNames=d.resolvedTypeReferenceDirectiveNames}if(2!==Ne)return Ne;if(null===(n=te.hasChangedAutomaticTypeDirectiveNames)||void 0===n?void 0:n.call(te))return 1;_e=k.getMissingFilePaths(),e.Debug.assert(a.length===k.getSourceFiles().length);for(var U=0,V=a;U<V.length;U++){p=V[U];Se.set(p.path,p)}var H=k.getFilesByNameMap();return H.forEach((function(e,n){e?e.path!==n?Se.set(n,Se.get(e.path)):k.isSourceFileFromExternalLibrary(e)&&Y.set(e.path,!0):Se.set(n,e)})),m=a,K=k.getFileIncludeReasons(),b=k.getFileProcessingDiagnostics(),z=k.getResolvedTypeReferenceDirectives(),Ee=k.sourceFileToPackageName,Te=k.redirectTargetsMap,2}function rn(n){return{getPrependNodes:cn,getCanonicalFileName:vt,getCommonSourceDirectory:Ke.getCommonSourceDirectory,getCompilerOptions:Ke.getCompilerOptions,getCurrentDirectory:function(){return ce},getNewLine:function(){return te.getNewLine()},getSourceFile:Ke.getSourceFile,getSourceFileByPath:Ke.getSourceFileByPath,getSourceFiles:Ke.getSourceFiles,getLibFileFromReference:Ke.getLibFileFromReference,isSourceFileFromExternalLibrary:ln,getResolvedProjectReferenceToRedirect:lt,getProjectReferenceRedirect:ot,isSourceOfProjectReferenceRedirect:pt,getSymlinkCache:Ht,writeFile:n||function(e,n,t,r,a){return te.writeFile(e,n,t,r,a)},isEmitBlocked:_n,readFile:function(e){return te.readFile(e)},fileExists:function(n){var t=Qe(n);return!!hn(t)||!e.contains(_e,t)&&te.fileExists(n)},useCaseSensitiveFileNames:function(){return te.useCaseSensitiveFileNames()},getProgramBuildInfo:function(){return Ke.getProgramBuildInfo&&Ke.getProgramBuildInfo()},getSourceFileFromReference:function(e,n){return Ke.getSourceFileFromReference(e,n)},redirectTargetsMap:Te,getFileIncludeReasons:Ke.getFileIncludeReasons}}function an(n){e.Debug.assert(!e.outFile(S)),null===e.tracing||void 0===e.tracing||e.tracing.push("emit","emitBuildInfo",{},!0),e.performance.mark("beforeEmit");var t=e.emitFiles(e.notImplementedResolver,rn(n),void 0,e.noTransformers,!1,!0);return e.performance.mark("afterEmit"),e.performance.measure("Emit","beforeEmit","afterEmit"),null===e.tracing||void 0===e.tracing||e.tracing.pop(),t}function on(){return ge}function sn(){return N}function cn(){return B(N,(function(e,n){var t;return null===(t=ge[n])||void 0===t?void 0:t.commandLine}),(function(e){var n=Qe(e),t=hn(n);return t?t.text:Se.has(n)?void 0:te.readFile(n)}))}function ln(e){return!!Y.get(e.path)}function un(n){if(n.hasNoDefaultLib)return!0;if(!S.noLib)return!1;var t=te.useCaseSensitiveFileNames()?e.equateStringsCaseSensitive:e.equateStringsCaseInsensitive;return S.lib?e.some(S.lib,(function(r){return t(n.fileName,e.combinePaths(oe,r))})):t(n.fileName,ie())}function dn(){return y||(y=e.createTypeChecker(Ke,!0))}function pn(){y=void 0}function fn(){return h||(h=e.createTypeChecker(Ke,!1))}function mn(n,t,r,a,i,o){null===e.tracing||void 0===e.tracing||e.tracing.push("emit","emit",{path:null===n||void 0===n?void 0:n.path},!0);var s=An((function(){return gn(Ke,n,t,r,a,i,o)}));return null===e.tracing||void 0===e.tracing||e.tracing.pop(),s}function _n(e){return de.has(Qe(e))}function gn(n,t,r,a,i,o,s){if(!s){var c=M(n,t,r,a);if(c)return c}var l=dn().getEmitResolver(e.outFile(S)?void 0:t,a);e.performance.mark("beforeEmit");var u=e.emitFiles(l,rn(r),t,e.getTransformers(S,o,i),i,!1,s);return e.performance.mark("afterEmit"),e.performance.measure("Emit","beforeEmit","afterEmit"),u}function yn(e){return hn(Qe(e))}function hn(e){return Se.get(e)||void 0}function vn(n,t,r){return n?t(n,r):e.sortAndDeduplicateDiagnostics(e.flatMap(Ke.getSourceFiles(),(function(e){return r&&r.throwIfCancellationRequested(),t(e,r)})))}function bn(e,n){return vn(e,Dn,n)}function En(e,n){return vn(e,Cn,n)}function Tn(e){var n;return e?null===(n=H.perFile)||void 0===n?void 0:n.get(e.path):H.allDiagnostics}function Sn(e,n){return In(e,n)}function xn(n){var t;if(e.skipTypeChecking(n,S,Ke))return e.emptyArray;var r=se.getDiagnostics(n.fileName);return(null===(t=n.commentDirectives)||void 0===t?void 0:t.length)?Rn(n,n.commentDirectives,r).diagnostics:r}function Ln(n,t){var r=Ke.getCompilerOptions();return!n||e.outFile(r)?Mn(n,t):vn(n,Bn,t)}function Dn(n){return e.isSourceFileJS(n)?(n.additionalSyntacticDiagnostics||(n.additionalSyntacticDiagnostics=Pn(n)),e.concatenate(n.additionalSyntacticDiagnostics,n.parseDiagnostics)):n.parseDiagnostics}function An(n){try{return n()}catch(t){throw t instanceof e.OperationCanceledException&&(h=void 0,y=void 0),t}}function Cn(n,t){return e.concatenate(F(In(n,t),S),xn(n))}function In(e,n){return Gn(e,n,H,Nn)}function Nn(n,t){return An((function(){if(e.skipTypeChecking(n,S,Ke))return e.emptyArray;var r=dn();e.Debug.assert(!!n.bindDiagnostics);var a=e.isCheckJsEnabledForFile(n,S),i=!!n.checkJsDirective&&!1===n.checkJsDirective.enabled,o=!i&&(3===n.scriptKind||4===n.scriptKind||5===n.scriptKind||a||7===n.scriptKind),s=o?n.bindDiagnostics:e.emptyArray,c=o?r.getDiagnostics(n,t):e.emptyArray;return kn(n,o,s,c,a?n.jsDocDiagnostics:void 0)}))}function kn(n,t){for(var r,a=[],i=2;i<arguments.length;i++)a[i-2]=arguments[i];var o=e.flatten(a);if(!t||!(null===(r=n.commentDirectives)||void 0===r?void 0:r.length))return o;for(var s=Rn(n,n.commentDirectives,o),c=s.diagnostics,l=s.directives,u=0,d=l.getUnusedExpectations();u<d.length;u++){var p=d[u];c.push(e.createDiagnosticForRange(n,p.range,e.Diagnostics.Unused_ts_expect_error_directive))}return c}function Rn(n,t,r){var a=e.createCommentDirectivesMap(n,t),i=r.filter((function(e){return-1===wn(e,a)}));return{diagnostics:i,directives:a}}function On(e,n){return An((function(){return dn().getSuggestionDiagnostics(e,n)}))}function wn(n,t){var r=n.file,a=n.start;if(!r)return-1;var i=e.getLineStarts(r),o=e.computeLineAndCharacterOfPosition(i,a).line-1;while(o>=0){if(t.markUsed(o))return o;var s=r.text.slice(i[o],i[o+1]).trim();if(""!==s&&!/^(\s*)\/\/(.*)$/.test(s))return-1;o--}return-1}function Pn(n){return An((function(){var t=[];return r(n,n),e.forEachChildRecursively(n,r,a),t;function r(n,r){switch(r.kind){case 161:case 164:case 166:if(r.questionToken===n)return t.push(s(n,e.Diagnostics.The_0_modifier_can_only_be_used_in_TypeScript_files,"?")),"skip";case 165:case 167:case 168:case 169:case 209:case 252:case 210:case 250:if(r.type===n)return t.push(s(n,e.Diagnostics.Type_annotations_can_only_be_used_in_TypeScript_files)),"skip"}switch(n.kind){case 263:if(n.isTypeOnly)return t.push(s(r,e.Diagnostics._0_declarations_can_only_be_used_in_TypeScript_files,"import type")),"skip";break;case 268:if(n.isTypeOnly)return t.push(s(n,e.Diagnostics._0_declarations_can_only_be_used_in_TypeScript_files,"export type")),"skip";break;case 261:return t.push(s(n,e.Diagnostics.import_can_only_be_used_in_TypeScript_files)),"skip";case 267:if(n.isExportEquals)return t.push(s(n,e.Diagnostics.export_can_only_be_used_in_TypeScript_files)),"skip";break;case 287:var a=n;if(116===a.token)return t.push(s(n,e.Diagnostics.implements_clauses_can_only_be_used_in_TypeScript_files)),"skip";break;case 254:var i=e.tokenToString(117);return e.Debug.assertIsDefined(i),t.push(s(n,e.Diagnostics._0_declarations_can_only_be_used_in_TypeScript_files,i)),"skip";case 257:var o=16&n.flags?e.tokenToString(140):e.tokenToString(139);return e.Debug.assertIsDefined(o),t.push(s(n,e.Diagnostics._0_declarations_can_only_be_used_in_TypeScript_files,o)),"skip";case 255:return t.push(s(n,e.Diagnostics.Type_aliases_can_only_be_used_in_TypeScript_files)),"skip";case 256:var c=e.Debug.checkDefined(e.tokenToString(91));return t.push(s(n,e.Diagnostics._0_declarations_can_only_be_used_in_TypeScript_files,c)),"skip";case 226:return t.push(s(n,e.Diagnostics.Non_null_assertions_can_only_be_used_in_TypeScript_files)),"skip";case 225:return t.push(s(n.type,e.Diagnostics.Type_assertion_expressions_can_only_be_used_in_TypeScript_files)),"skip";case 207:e.Debug.fail()}}function a(n,r){switch(r.decorators!==n||S.experimentalDecorators||t.push(s(r,e.Diagnostics.Experimental_support_for_decorators_is_a_feature_that_is_subject_to_change_in_a_future_release_Set_the_experimentalDecorators_option_in_your_tsconfig_or_jsconfig_to_remove_this_warning)),r.kind){case 253:case 222:case 166:case 167:case 168:case 169:case 209:case 252:case 210:if(n===r.typeParameters)return t.push(o(n,e.Diagnostics.Type_parameter_declarations_can_only_be_used_in_TypeScript_files)),"skip";case 233:if(n===r.modifiers)return i(r.modifiers,233===r.kind),"skip";break;case 164:if(n===r.modifiers){for(var a=0,c=n;a<c.length;a++){var l=c[a];123!==l.kind&&t.push(s(l,e.Diagnostics.The_0_modifier_can_only_be_used_in_TypeScript_files,e.tokenToString(l.kind)))}return"skip"}break;case 161:if(n===r.modifiers)return t.push(o(n,e.Diagnostics.Parameter_modifiers_can_only_be_used_in_TypeScript_files)),"skip";break;case 204:case 205:case 224:case 275:case 276:case 206:if(n===r.typeArguments)return t.push(o(n,e.Diagnostics.Type_arguments_can_only_be_used_in_TypeScript_files)),"skip";break}}function i(n,r){for(var a=0,i=n;a<i.length;a++){var o=i[a];switch(o.kind){case 84:if(r)continue;case 122:case 120:case 121:case 142:case 133:case 125:case 156:t.push(s(o,e.Diagnostics.The_0_modifier_can_only_be_used_in_TypeScript_files,e.tokenToString(o.kind)));break;case 123:case 92:case 87:}}}function o(t,r,a,i,o){var s=t.pos;return e.createFileDiagnostic(n,s,t.end-s,r,a,i,o)}function s(t,r,a,i,o){return e.createDiagnosticForNodeInSourceFile(n,t,r,a,i,o)}}))}function Mn(e,n){return Gn(e,n,W,Fn)}function Fn(n,t){return An((function(){var r=dn().getEmitResolver(n,t);return e.getDeclarationDiagnostics(rn(e.noop),r,n)||e.emptyArray}))}function Gn(n,t,r,a){var i,o=n?null===(i=r.perFile)||void 0===i?void 0:i.get(n.path):r.allDiagnostics;if(o)return o;var s=a(n,t);return n?(r.perFile||(r.perFile=new e.Map)).set(n.path,s):r.allDiagnostics=s,s}function Bn(e,n){return e.isDeclarationFile?[]:Mn(e,n)}function Un(){return e.sortAndDeduplicateDiagnostics(e.concatenate(se.getGlobalDiagnostics(),Vn()))}function Vn(){if(!S.configFile)return e.emptyArray;var n=se.getDiagnostics(S.configFile.fileName);return ut((function(t){n=e.concatenate(n,se.getDiagnostics(t.sourceFile.fileName))})),n}function jn(){return T.length?e.sortAndDeduplicateDiagnostics(dn().getGlobalDiagnostics().slice()):e.emptyArray}function Kn(){return L||e.emptyArray}function Hn(n,t,r,a){Zn(e.normalizePath(n),t,r,void 0,a)}function Wn(e,n){return e.fileName===n.fileName}function zn(e,n){return 78===e.kind?78===n.kind&&e.escapedText===n.escapedText:10===n.kind&&e.text===n.text}function qn(n,t){var r=e.factory.createStringLiteral(n),a=e.factory.createImportDeclaration(void 0,void 0,void 0,r);return e.addEmitFlags(a,67108864),e.setParent(r,a),e.setParent(a,t),r.flags&=-9,a.flags&=-9,r}function Jn(n){if(!n.imports){var t,r,a,i=e.isSourceFileJS(n),o=e.isExternalModule(n);if((S.isolatedModules||o)&&!n.isDeclarationFile){S.importHelpers&&(t=[qn(e.externalHelpersModuleNameText,n)]);var s=e.getJSXRuntimeImport(e.getJSXImplicitImportBase(S,n),S);s&&(t||(t=[])).push(qn(s,n))}for(var c=0,l=n.statements;c<l.length;c++){var u=l[c];d(u,!1)}return(1048576&n.flags||i)&&p(n),n.imports=t||e.emptyArray,n.moduleAugmentations=r||e.emptyArray,void(n.ambientModuleNames=a||e.emptyArray)}function d(i,s){if(e.isAnyImportOrReExport(i)){var c=e.getExternalModuleName(i);!(c&&e.isStringLiteral(c)&&c.text)||s&&e.isExternalModuleNameRelative(c.text)||(t=e.append(t,c))}else if(e.isModuleDeclaration(i)&&e.isAmbientModule(i)&&(s||e.hasSyntacticModifier(i,2)||n.isDeclarationFile)){var l=e.getTextOfIdentifierOrLiteral(i.name);if(o||s&&!e.isExternalModuleNameRelative(l))(r||(r=[])).push(i.name);else if(!s){n.isDeclarationFile&&(a||(a=[])).push(l);var u=i.body;if(u)for(var p=0,f=u.statements;p<f.length;p++){var m=f[p];d(m,!0)}}}}function p(n){var r=/import|require/g;while(null!==r.exec(n.text)){var a=f(n,r.lastIndex);i&&e.isRequireCall(a,!0)||e.isImportCall(a)&&1===a.arguments.length&&e.isStringLiteralLike(a.arguments[0])?t=e.append(t,a.arguments[0]):e.isLiteralImportTypeNode(a)&&(t=e.append(t,a.argument.literal))}}function f(n,t){var r=n,a=function(e){if(e.pos<=t&&(t<e.end||t===e.end&&1===e.kind))return e};while(1){var o=i&&e.hasJSDocNodes(r)&&e.forEach(r.jsDoc,a)||e.forEachChild(r,a);if(!o)return r;r=o}}}function Xn(n){var t=e.toFileNameLowerCase(n.fileName),r=e.libMap.get(t);if(r)return yn(e.combinePaths(oe,r))}function Yn(e,n){return Qn(t(n.fileName,e.fileName),yn)}function Qn(n,t,r,a){if(e.hasExtension(n)){var i=te.getCanonicalFileName(n);if(!S.allowNonTsExtensions&&!e.forEach(ue,(function(n){return e.fileExtensionIs(i,n)})))return void(r&&(e.hasJSFileExtension(i)?r(e.Diagnostics.File_0_is_a_JavaScript_file_Did_you_mean_to_enable_the_allowJs_option,n):r(e.Diagnostics.File_0_has_an_unsupported_extension_The_only_supported_extensions_are_1,n,"'"+le.join("', '")+"'")));var o=t(n);if(r)if(o)A(a)&&i===te.getCanonicalFileName(hn(a.file).fileName)&&r(e.Diagnostics.A_file_cannot_have_a_reference_to_itself);else{var s=ot(n);s?r(e.Diagnostics.Output_file_0_has_not_been_built_from_source_file_1,s,n):r(e.Diagnostics.File_0_not_found,n)}return o}var c=S.allowNonTsExtensions&&t(n);if(c)return c;if(!r||!S.allowNonTsExtensions){var l=e.forEach(le,(function(e){return t(n+e)}));return r&&!l&&r(e.Diagnostics.Could_not_resolve_the_path_0_with_the_extensions_Colon_1,n,"'"+le.join("', '")+"'"),l}r(e.Diagnostics.File_0_not_found,n)}function Zn(e,n,t,r,a){Qn(e,(function(e){return tt(e,Qe(e),n,t,a,r)}),(function(e){for(var n=[],t=1;t<arguments.length;t++)n[t-1]=arguments[t];return Lt(void 0,a,e,n)}),a)}function $n(e,n){return Zn(e,!1,!1,void 0,n)}function et(n,t,r){var a=!A(r)&&e.some(K.get(t.path),A);a?Lt(t,r,e.Diagnostics.Already_included_file_name_0_differs_from_file_name_1_only_in_casing,[t.fileName,n]):Lt(t,r,e.Diagnostics.File_name_0_differs_from_already_included_file_name_1_only_in_casing,[n,t.fileName])}function nt(e,n,t,r,a,i){var o=Object.create(e);return o.fileName=t,o.path=r,o.resolvedPath=a,o.originalFileName=i,o.redirectInfo={redirectTarget:e,unredirected:n},Y.set(r,J>0),Object.defineProperties(o,{id:{get:function(){return this.redirectInfo.redirectTarget.id},set:function(e){this.redirectInfo.redirectTarget.id=e}},symbol:{get:function(){return this.redirectInfo.redirectTarget.symbol},set:function(e){this.redirectInfo.redirectTarget.symbol=e}}}),o}function tt(n,t,r,a,i,o){null===e.tracing||void 0===e.tracing||e.tracing.push("program","findSourceFile",{fileName:n,isDefaultLib:r||void 0,fileIncludeKind:e.FileIncludeKind[i.kind]});var s=rt(n,t,r,a,i,o);return null===e.tracing||void 0===e.tracing||e.tracing.pop(),s}function rt(n,t,r,a,i,o){if(Le){var s=dt(n);if(!s&&te.realpath&&S.preserveSymlinks&&e.isDeclarationFileName(n)&&e.stringContains(n,e.nodeModulesPathPart)){var c=te.realpath(n);c!==n&&(s=dt(c))}if(s){var l=e.isString(s)?tt(s,Qe(s),r,a,i,o):void 0;return l&&it(l,t,void 0),l}}var u,d=n;if(Se.has(t)){var m=Se.get(t);if(at(m||void 0,i),m&&S.forceConsistentCasingInFileNames){var _=m.fileName,g=Qe(_)!==Qe(n);g&&(n=ot(n)||n);var y=e.getNormalizedAbsolutePathWithoutRoot(_,ce),h=e.getNormalizedAbsolutePathWithoutRoot(n,ce);y!==h&&et(n,m,i)}return m&&Y.get(m.path)&&0===J?(Y.set(m.path,!1),S.noResolve||(mt(m,r),_t(m)),S.noLib||ht(m),X.set(m.path,!1),bt(m)):m&&X.get(m.path)&&J<q&&(X.set(m.path,!1),bt(m)),m||void 0}if(A(i)&&!Le){var v=st(n);if(v){if(e.outFile(v.commandLine.options))return;var b=ct(v,n);n=b,u=Qe(b)}}var E=te.getSourceFile(n,S.target,(function(t){return Lt(void 0,i,e.Diagnostics.Cannot_read_file_0_Colon_1,[n,t])}),ke);if(o){var T=e.packageIdToString(o),x=be.get(T);if(x){var L=nt(x,E,n,t,Qe(n),d);return Te.add(x.path,n),it(L,t,u),at(L,i),Ee.set(t,o.name),f.push(L),L}E&&(be.set(T,E),Ee.set(t,o.name))}if(it(E,t,u),E){if(Y.set(t,J>0),E.fileName=n,E.path=t,E.resolvedPath=Qe(n),E.originalFileName=d,at(E,i),te.useCaseSensitiveFileNames()){var D=e.toFileNameLowerCase(t),C=xe.get(D);C?et(n,C,i):xe.set(D,E)}ae=ae||E.hasNoDefaultLib&&!a,S.noResolve||(mt(E,r),_t(E)),S.noLib||ht(E),bt(E),r?p.push(E):f.push(E)}return E}function at(e,n){e&&K.add(e.path,n)}function it(e,n,t){t?(Se.set(t,e),Se.set(n,e||!1)):Se.set(n,e)}function ot(e){var n=st(e);return n&&ct(n,e)}function st(n){if(ge&&ge.length&&!e.fileExtensionIs(n,".d.ts")&&!e.fileExtensionIs(n,".json"))return lt(n)}function ct(n,t){var r=e.outFile(n.commandLine.options);return r?e.changeExtension(r,".d.ts"):e.getOutputDeclarationFileName(t,n.commandLine,!te.useCaseSensitiveFileNames())}function lt(n){void 0===he&&(he=new e.Map,ut((function(e){Qe(S.configFilePath)!==e.sourceFile.path&&e.commandLine.fileNames.forEach((function(n){return he.set(Qe(n),e.sourceFile.path)}))})));var t=he.get(Qe(n));return t&&ft(t)}function ut(n){return e.forEachResolvedProjectReference(ge,n)}function dt(n){if(e.isDeclarationFileName(n))return void 0===ve&&(ve=new e.Map,ut((function(n){var t=e.outFile(n.commandLine.options);if(t){var r=e.changeExtension(t,".d.ts");ve.set(Qe(r),!0)}else{var a=e.memoize((function(){return e.getCommonSourceDirectoryOfConfig(n.commandLine,!te.useCaseSensitiveFileNames())}));e.forEach(n.commandLine.fileNames,(function(t){if(!e.fileExtensionIs(t,".d.ts")&&!e.fileExtensionIs(t,".json")){var r=e.getOutputDeclarationFileName(t,n.commandLine,!te.useCaseSensitiveFileNames(),a);ve.set(Qe(r),t)}}))}}))),ve.get(Qe(n))}function pt(e){return Le&&!!lt(e)}function ft(e){if(ye)return ye.get(e)||void 0}function mt(n,r){e.forEach(n.referencedFiles,(function(a,i){Zn(t(a.fileName,n.fileName),r,!1,void 0,{kind:e.FileIncludeKind.ReferenceFile,file:n.path,index:i})}))}function _t(n){var t=e.map(n.typeReferenceDirectives,(function(n){return e.toFileNameLowerCase(n.fileName)}));if(t)for(var r=We(t,n),a=0;a<t.length;a++){var i=n.typeReferenceDirectives[a],o=r[a],s=e.toFileNameLowerCase(i.fileName);e.setResolvedTypeReferenceDirective(n,s,o),gt(s,o,{kind:e.FileIncludeKind.TypeReferenceDirective,file:n.path,index:a})}}function gt(n,t,r){null===e.tracing||void 0===e.tracing||e.tracing.push("program","processTypeReferenceDirective",{directive:n,hasResolved:!!en,refKind:r.kind,refPath:A(r)?r.file:void 0}),yt(n,t,r),null===e.tracing||void 0===e.tracing||e.tracing.pop()}function yt(n,t,r){var a=z.get(n);if(!a||!a.primary){var i=!0;if(t){if(t.isExternalLibraryImport&&J++,t.primary)Zn(t.resolvedFileName,!1,!1,t.packageId,r);else if(a){if(t.resolvedFileName!==a.resolvedFileName){var o=te.readFile(t.resolvedFileName),s=yn(a.resolvedFileName);o!==s.text&&Lt(s,r,e.Diagnostics.Conflicting_definitions_for_0_found_at_1_and_2_Consider_installing_a_specific_version_of_this_library_to_resolve_the_conflict,[n,t.resolvedFileName,a.resolvedFileName])}i=!1}else Zn(t.resolvedFileName,!1,!1,t.packageId,r);t.isExternalLibraryImport&&J--}else Lt(void 0,r,e.Diagnostics.Cannot_find_type_definition_file_for_0,[n]);i&&z.set(n,t)}}function ht(n){e.forEach(n.libReferenceDirectives,(function(t,r){var a=e.toFileNameLowerCase(t.fileName),i=e.libMap.get(a);if(i)Hn(e.combinePaths(oe,i),!0,!0,{kind:e.FileIncludeKind.LibReferenceDirective,file:n.path,index:r});else{var o=e.removeSuffix(e.removePrefix(a,"lib."),".d.ts"),s=e.getSpellingSuggestion(o,e.libs,e.identity),c=s?e.Diagnostics.Cannot_find_lib_definition_for_0_Did_you_mean_1:e.Diagnostics.Cannot_find_lib_definition_for_0;(b||(b=[])).push({kind:0,reason:{kind:e.FileIncludeKind.LibReferenceDirective,file:n.path,index:r},diagnostic:c,args:[a,s]})}}))}function vt(e){return te.getCanonicalFileName(e)}function bt(n){var t;if(Jn(n),n.imports.length||n.moduleAugmentations.length){var r=j(n),a=en(r,n);e.Debug.assert(a.length===r.length);for(var i=(Le?null===(t=ze(n))||void 0===t?void 0:t.commandLine.options:void 0)||S,o=0;o<r.length;o++){var s=a[o];if(e.setResolvedModule(n,r[o],s),s){var c=s.isExternalLibraryImport,l=!e.resolutionExtensionIsTSOrJson(s.extension),u=c&&l,d=s.resolvedFileName;c&&J++;var p=u&&J>q,f=d&&!V(i,s)&&!i.noResolve&&o<n.imports.length&&!p&&!(l&&!e.getAllowJSCompilerOption(i))&&(e.isInJSFile(n.imports[o])||!(4194304&n.imports[o].flags));if(p)X.set(n.path,!0);else if(f){var m=Qe(d);tt(d,m,!1,!1,{kind:e.FileIncludeKind.Import,file:n.path,index:o},s.packageId)}c&&J--}}}else n.resolvedModules=void 0}function Et(n,t){for(var r=!0,a=te.getCanonicalFileName(e.getNormalizedAbsolutePath(t,ce)),i=0,o=n;i<o.length;i++){var s=o[i];if(!s.isDeclarationFile){var c=te.getCanonicalFileName(e.getNormalizedAbsolutePath(s.fileName,ce));0!==c.indexOf(a)&&(Dt(s,e.Diagnostics.File_0_is_not_under_rootDir_1_rootDir_is_expected_to_contain_all_source_files,[s.fileName,t]),r=!1)}}return r}function Tt(n){ye||(ye=new e.Map);var t,r,a=U(n),i=Qe(a),o=ye.get(i);if(void 0!==o)return o||void 0;if(te.getParsedCommandLine){if(t=te.getParsedCommandLine(a),!t)return it(void 0,i,void 0),void ye.set(i,!1);r=e.Debug.checkDefined(t.options.configFile),e.Debug.assert(!r.path||r.path===i),it(r,i,void 0)}else{var s=e.getNormalizedAbsolutePath(e.getDirectoryPath(a),te.getCurrentDirectory());if(r=te.getSourceFile(a,100),it(r,i,void 0),void 0===r)return void ye.set(i,!1);t=e.parseJsonSourceFileConfigFileContent(r,re,s,void 0,a)}r.fileName=a,r.path=i,r.resolvedPath=i,r.originalFileName=a;var c={commandLine:t,sourceFile:r};return ye.set(i,c),t.projectReferences&&(c.references=t.projectReferences.map(Tt)),c}function St(){S.strictPropertyInitialization&&!e.getStrictOptionValue(S,"strictNullChecks")&&Pt(e.Diagnostics.Option_0_cannot_be_specified_without_specifying_option_1,"strictPropertyInitialization","strictNullChecks"),S.isolatedModules&&(S.out&&Pt(e.Diagnostics.Option_0_cannot_be_specified_with_option_1,"out","isolatedModules"),S.outFile&&Pt(e.Diagnostics.Option_0_cannot_be_specified_with_option_1,"outFile","isolatedModules")),S.inlineSourceMap&&(S.sourceMap&&Pt(e.Diagnostics.Option_0_cannot_be_specified_with_option_1,"sourceMap","inlineSourceMap"),S.mapRoot&&Pt(e.Diagnostics.Option_0_cannot_be_specified_with_option_1,"mapRoot","inlineSourceMap")),S.composite&&(!1===S.declaration&&Pt(e.Diagnostics.Composite_projects_may_not_disable_declaration_emit,"declaration"),!1===S.incremental&&Pt(e.Diagnostics.Composite_projects_may_not_disable_incremental_compilation,"declaration"));var n=e.outFile(S);if(S.tsBuildInfoFile?e.isIncrementalCompilation(S)||Pt(e.Diagnostics.Option_0_cannot_be_specified_without_specifying_option_1_or_option_2,"tsBuildInfoFile","incremental","composite"):!S.incremental||n||S.configFilePath||se.add(e.createCompilerDiagnostic(e.Diagnostics.Option_incremental_can_only_be_specified_using_tsconfig_emitting_to_single_file_or_when_option_tsBuildInfoFile_is_specified)),Ct(),S.composite)for(var t=new e.Set(T.map(Qe)),r=0,a=m;r<a.length;r++){var i=a[r];e.sourceFileMayBeEmitted(i,Ke)&&!t.has(i.path)&&Dt(i,e.Diagnostics.File_0_is_not_listed_within_the_file_list_of_project_1_Projects_must_list_all_files_or_use_an_include_pattern,[i.fileName,S.configFilePath||""])}if(S.paths)for(var o in S.paths)if(e.hasProperty(S.paths,o))if(e.hasZeroOrOneAsteriskCharacter(o)||Nt(!0,o,e.Diagnostics.Pattern_0_can_have_at_most_one_Asterisk_character,o),e.isArray(S.paths[o])){var s=S.paths[o].length;0===s&&Nt(!1,o,e.Diagnostics.Substitutions_for_pattern_0_shouldn_t_be_an_empty_array,o);for(var c=0;c<s;c++){var l=S.paths[o][c],u=typeof l;"string"===u?(e.hasZeroOrOneAsteriskCharacter(l)||It(o,c,e.Diagnostics.Substitution_0_in_pattern_1_can_have_at_most_one_Asterisk_character,l,o),S.baseUrl||e.pathIsRelative(l)||e.pathIsAbsolute(l)||It(o,c,e.Diagnostics.Non_relative_paths_are_not_allowed_when_baseUrl_is_not_set_Did_you_forget_a_leading_Slash)):It(o,c,e.Diagnostics.Substitution_0_for_pattern_1_has_incorrect_type_expected_string_got_2,l,o,u)}}else Nt(!1,o,e.Diagnostics.Substitutions_for_pattern_0_should_be_an_array,o);S.sourceMap||S.inlineSourceMap||(S.inlineSources&&Pt(e.Diagnostics.Option_0_can_only_be_used_when_either_option_inlineSourceMap_or_option_sourceMap_is_provided,"inlineSources"),S.sourceRoot&&Pt(e.Diagnostics.Option_0_can_only_be_used_when_either_option_inlineSourceMap_or_option_sourceMap_is_provided,"sourceRoot")),S.out&&S.outFile&&Pt(e.Diagnostics.Option_0_cannot_be_specified_with_option_1,"out","outFile"),!S.mapRoot||S.sourceMap||S.declarationMap||Pt(e.Diagnostics.Option_0_cannot_be_specified_without_specifying_option_1_or_option_2,"mapRoot","sourceMap","declarationMap"),S.declarationDir&&(e.getEmitDeclarations(S)||Pt(e.Diagnostics.Option_0_cannot_be_specified_without_specifying_option_1_or_option_2,"declarationDir","declaration","composite"),n&&Pt(e.Diagnostics.Option_0_cannot_be_specified_with_option_1,"declarationDir",S.out?"out":"outFile")),S.declarationMap&&!e.getEmitDeclarations(S)&&Pt(e.Diagnostics.Option_0_cannot_be_specified_without_specifying_option_1_or_option_2,"declarationMap","declaration","composite"),S.lib&&S.noLib&&Pt(e.Diagnostics.Option_0_cannot_be_specified_with_option_1,"lib","noLib"),S.noImplicitUseStrict&&e.getStrictOptionValue(S,"alwaysStrict")&&Pt(e.Diagnostics.Option_0_cannot_be_specified_with_option_1,"noImplicitUseStrict","alwaysStrict");var d=S.target||0,p=e.find(m,(function(n){return e.isExternalModule(n)&&!n.isDeclarationFile}));if(S.isolatedModules){S.module===e.ModuleKind.None&&d<2&&Pt(e.Diagnostics.Option_isolatedModules_can_only_be_used_when_either_option_module_is_provided_or_option_target_is_ES2015_or_higher,"isolatedModules","target"),!1===S.preserveConstEnums&&Pt(e.Diagnostics.Option_preserveConstEnums_cannot_be_disabled_when_isolatedModules_is_enabled,"preserveConstEnums","isolatedModules");var f=e.find(m,(function(n){return!e.isExternalModule(n)&&!e.isSourceFileJS(n)&&!n.isDeclarationFile&&6!==n.scriptKind}));if(f){var _=e.getErrorSpanForNode(f,f);se.add(e.createFileDiagnostic(f,_.start,_.length,e.Diagnostics._0_cannot_be_compiled_under_isolatedModules_because_it_is_considered_a_global_script_file_Add_an_import_export_or_an_empty_export_statement_to_make_it_a_module,e.getBaseFileName(f.fileName)))}}else if(p&&d<2&&S.module===e.ModuleKind.None){_=e.getErrorSpanForNode(p,p.externalModuleIndicator);se.add(e.createFileDiagnostic(p,_.start,_.length,e.Diagnostics.Cannot_use_imports_exports_or_module_augmentations_when_module_is_none))}if(n&&!S.emitDeclarationOnly)if(S.module&&S.module!==e.ModuleKind.AMD&&S.module!==e.ModuleKind.System)Pt(e.Diagnostics.Only_amd_and_system_modules_are_supported_alongside_0,S.out?"out":"outFile","module");else if(void 0===S.module&&p){_=e.getErrorSpanForNode(p,p.externalModuleIndicator);se.add(e.createFileDiagnostic(p,_.start,_.length,e.Diagnostics.Cannot_compile_modules_using_option_0_unless_the_module_flag_is_amd_or_system,S.out?"out":"outFile"))}if(S.resolveJsonModule&&(e.getEmitModuleResolutionKind(S)!==e.ModuleResolutionKind.NodeJs?Pt(e.Diagnostics.Option_resolveJsonModule_cannot_be_specified_without_node_module_resolution_strategy,"resolveJsonModule"):e.hasJsonModuleEmitEnabled(S)||Pt(e.Diagnostics.Option_resolveJsonModule_can_only_be_specified_when_module_code_generation_is_commonjs_amd_es2015_or_esNext,"resolveJsonModule","module")),S.outDir||S.rootDir||S.sourceRoot||S.mapRoot){var g=Ze();S.outDir&&""===g&&m.some((function(n){return e.getRootLength(n.fileName)>1}))&&Pt(e.Diagnostics.Cannot_find_the_common_subdirectory_path_for_the_input_files,"outDir")}if(S.useDefineForClassFields&&0===d&&Pt(e.Diagnostics.Option_0_cannot_be_specified_when_option_target_is_ES3,"useDefineForClassFields"),S.checkJs&&!e.getAllowJSCompilerOption(S)&&se.add(e.createCompilerDiagnostic(e.Diagnostics.Option_0_cannot_be_specified_without_specifying_option_1,"checkJs","allowJs")),S.emitDeclarationOnly&&(e.getEmitDeclarations(S)||Pt(e.Diagnostics.Option_0_cannot_be_specified_without_specifying_option_1_or_option_2,"emitDeclarationOnly","declaration","composite"),S.noEmit&&Pt(e.Diagnostics.Option_0_cannot_be_specified_with_option_1,"emitDeclarationOnly","noEmit")),S.emitDecoratorMetadata&&!S.experimentalDecorators&&Pt(e.Diagnostics.Option_0_cannot_be_specified_without_specifying_option_1,"emitDecoratorMetadata","experimentalDecorators"),S.jsxFactory?(S.reactNamespace&&Pt(e.Diagnostics.Option_0_cannot_be_specified_with_option_1,"reactNamespace","jsxFactory"),4!==S.jsx&&5!==S.jsx||Pt(e.Diagnostics.Option_0_cannot_be_specified_when_option_jsx_is_1,"jsxFactory",e.inverseJsxOptionMap.get(""+S.jsx)),e.parseIsolatedEntityName(S.jsxFactory,d)||Mt("jsxFactory",e.Diagnostics.Invalid_value_for_jsxFactory_0_is_not_a_valid_identifier_or_qualified_name,S.jsxFactory)):S.reactNamespace&&!e.isIdentifierText(S.reactNamespace,d)&&Mt("reactNamespace",e.Diagnostics.Invalid_value_for_reactNamespace_0_is_not_a_valid_identifier,S.reactNamespace),S.jsxFragmentFactory&&(S.jsxFactory||Pt(e.Diagnostics.Option_0_cannot_be_specified_without_specifying_option_1,"jsxFragmentFactory","jsxFactory"),4!==S.jsx&&5!==S.jsx||Pt(e.Diagnostics.Option_0_cannot_be_specified_when_option_jsx_is_1,"jsxFragmentFactory",e.inverseJsxOptionMap.get(""+S.jsx)),e.parseIsolatedEntityName(S.jsxFragmentFactory,d)||Mt("jsxFragmentFactory",e.Diagnostics.Invalid_value_for_jsxFragmentFactory_0_is_not_a_valid_identifier_or_qualified_name,S.jsxFragmentFactory)),S.reactNamespace&&(4!==S.jsx&&5!==S.jsx||Pt(e.Diagnostics.Option_0_cannot_be_specified_when_option_jsx_is_1,"reactNamespace",e.inverseJsxOptionMap.get(""+S.jsx))),S.jsxImportSource&&2===S.jsx&&Pt(e.Diagnostics.Option_0_cannot_be_specified_when_option_jsx_is_1,"jsxImportSource",e.inverseJsxOptionMap.get(""+S.jsx)),!S.noEmit&&!S.suppressOutputPathCheck){var y=rn(),h=new e.Set;e.forEachEmittedFile(y,(function(e){S.emitDeclarationOnly||v(e.jsFilePath,h),v(e.declarationFilePath,h)}))}function v(n,t){if(n){var r=Qe(n);if(Se.has(r)){var a=void 0;S.configFilePath||(a=e.chainDiagnosticMessages(void 0,e.Diagnostics.Adding_a_tsconfig_json_file_will_help_organize_projects_that_contain_both_TypeScript_and_JavaScript_files_Learn_more_at_https_Colon_Slash_Slashaka_ms_Slashtsconfig)),a=e.chainDiagnosticMessages(a,e.Diagnostics.Cannot_write_file_0_because_it_would_overwrite_input_file,n),Vt(n,e.createCompilerDiagnosticFromMessageChain(a))}var i=te.useCaseSensitiveFileNames()?r:e.toFileNameLowerCase(r);t.has(i)?Vt(n,e.createCompilerDiagnostic(e.Diagnostics.Cannot_write_file_0_because_it_would_be_overwritten_by_multiple_input_files,n)):t.add(i)}}}function xt(n,t,r,a){var o,s,c,l=A(t)?t:void 0;n&&(null===(o=K.get(n.path))||void 0===o||o.forEach(m)),t&&m(t),l&&1===(null===s||void 0===s?void 0:s.length)&&(s=void 0);var u=l&&I(hn,l),d=s&&e.chainDiagnosticMessages(s,e.Diagnostics.The_file_is_in_the_program_because_Colon),p=n&&e.explainIfFileIsRedirect(n),f=e.chainDiagnosticMessages.apply(void 0,i([p?d?i([d],p):p:d,r],a||e.emptyArray));return u&&C(u)?e.createFileDiagnosticFromMessageChain(u.file,u.pos,u.end-u.pos,f,c):e.createCompilerDiagnosticFromMessageChain(f,c);function m(n){(s||(s=[])).push(e.fileIncludeReasonToDiagnostics(Ke,n)),!l&&A(n)?l=n:l!==n&&(c=e.append(c,At(n))),n===t&&(t=void 0)}}function Lt(e,n,t,r){(b||(b=[])).push({kind:1,file:e&&e.path,fileProcessingReason:n,diagnostic:t,args:r})}function Dt(e,n,t){se.add(xt(e,void 0,n,t))}function At(n){if(A(n)){var t,r=I(hn,n);switch(n.kind){case e.FileIncludeKind.Import:t=e.Diagnostics.File_is_included_via_import_here;break;case e.FileIncludeKind.ReferenceFile:t=e.Diagnostics.File_is_included_via_reference_here;break;case e.FileIncludeKind.TypeReferenceDirective:t=e.Diagnostics.File_is_included_via_type_library_reference_here;break;case e.FileIncludeKind.LibReferenceDirective:t=e.Diagnostics.File_is_included_via_library_reference_here;break;default:e.Debug.assertNever(n)}return C(r)?e.createFileDiagnostic(r.file,r.pos,r.end-r.pos,t):void 0}if(S.configFile){var a,i;switch(n.kind){case e.FileIncludeKind.RootFile:if(!S.configFile.configFileSpecs)return;var o=e.getNormalizedAbsolutePath(T[n.index],ce),s=e.getMatchedFileSpec(Ke,o);if(s){a=e.getTsConfigPropArrayElementValue(S.configFile,"files",s),i=e.Diagnostics.File_is_matched_by_files_list_specified_here;break}var c=e.getMatchedIncludeSpec(Ke,o);if(!c)return;a=e.getTsConfigPropArrayElementValue(S.configFile,"include",c),i=e.Diagnostics.File_is_matched_by_include_pattern_specified_here;break;case e.FileIncludeKind.SourceFromProjectReference:case e.FileIncludeKind.OutputFromProjectReference:var l=e.Debug.checkDefined(null===ge||void 0===ge?void 0:ge[n.index]),u=D(N,ge,(function(e,n,t){return e===l?{sourceFile:(null===n||void 0===n?void 0:n.sourceFile)||S.configFile,index:t}:void 0}));if(!u)return;var d=u.sourceFile,p=u.index,f=e.firstDefined(e.getTsConfigPropArray(d,"references"),(function(n){return e.isArrayLiteralExpression(n.initializer)?n.initializer:void 0}));return f&&f.elements.length>p?e.createDiagnosticForNodeInSourceFile(d,f.elements[p],n.kind===e.FileIncludeKind.OutputFromProjectReference?e.Diagnostics.File_is_output_from_referenced_project_specified_here:e.Diagnostics.File_is_source_from_referenced_project_specified_here):void 0;case e.FileIncludeKind.AutomaticTypeDirectiveFile:if(!S.types)return;a=wt("types",n.typeReference),i=e.Diagnostics.File_is_entry_point_of_type_library_specified_here;break;case e.FileIncludeKind.LibFile:if(void 0!==n.index){a=wt("lib",S.lib[n.index]),i=e.Diagnostics.File_is_library_specified_here;break}var m=e.forEachEntry(e.targetOptionDeclaration.type,(function(e,n){return e===S.target?n:void 0}));a=m?Ot("target",m):void 0,i=e.Diagnostics.File_is_default_library_for_target_specified_here;break;default:e.Debug.assertNever(n)}return a&&e.createDiagnosticForNodeInSourceFile(S.configFile,a,i)}}function Ct(){var n=S.suppressOutputPathCheck?void 0:e.getTsBuildInfoEmitOutputFilePath(S);D(N,ge,(function(t,r,a){var i=(r?r.commandLine.projectReferences:N)[a],o=r&&r.sourceFile;if(t){var s=t.commandLine.options;if(!s.composite||s.noEmit){var c=r?r.commandLine.fileNames:T;c.length&&(s.composite||Ft(o,a,e.Diagnostics.Referenced_project_0_must_have_setting_composite_Colon_true,i.path),s.noEmit&&Ft(o,a,e.Diagnostics.Referenced_project_0_may_not_disable_emit,i.path))}if(i.prepend){var l=e.outFile(s);l?te.fileExists(l)||Ft(o,a,e.Diagnostics.Output_file_0_from_project_1_does_not_exist,l,i.path):Ft(o,a,e.Diagnostics.Cannot_prepend_project_0_because_it_does_not_have_outFile_set,i.path)}!r&&n&&n===e.getTsBuildInfoEmitOutputFilePath(s)&&(Ft(o,a,e.Diagnostics.Cannot_write_file_0_because_it_will_overwrite_tsbuildinfo_file_generated_by_referenced_project_1,n,i.path),de.set(Qe(n),!0))}else Ft(o,a,e.Diagnostics.File_0_not_found,i.path)}))}function It(n,t,r,a,i,o){for(var s=!0,c=Rt(),l=0,u=c;l<u.length;l++){var d=u[l];if(e.isObjectLiteralExpression(d.initializer))for(var p=0,f=e.getPropertyAssignment(d.initializer,n);p<f.length;p++){var m=f[p],_=m.initializer;e.isArrayLiteralExpression(_)&&_.elements.length>t&&(se.add(e.createDiagnosticForNodeInSourceFile(S.configFile,_.elements[t],r,a,i,o)),s=!1)}}s&&se.add(e.createCompilerDiagnostic(r,a,i,o))}function Nt(n,t,r,a){for(var i=!0,o=Rt(),s=0,c=o;s<c.length;s++){var l=c[s];e.isObjectLiteralExpression(l.initializer)&&Ut(l.initializer,n,t,void 0,r,a)&&(i=!1)}i&&se.add(e.createCompilerDiagnostic(r,a))}function kt(n){var t=Bt();return t&&e.getPropertyAssignment(t,n)}function Rt(){return kt("paths")||e.emptyArray}function Ot(n,t){var r=kt(n);return r&&e.firstDefined(r,(function(n){return e.isStringLiteral(n.initializer)&&n.initializer.text===t?n.initializer:void 0}))}function wt(n,t){var r=Bt();return r&&e.getPropertyArrayElementValue(r,n,t)}function Pt(e,n,t,r){Gt(!0,n,t,e,n,t,r)}function Mt(e,n,t){Gt(!1,e,void 0,n,t)}function Ft(n,t,r,a,i){var o=e.firstDefined(e.getTsConfigPropArray(n||S.configFile,"references"),(function(n){return e.isArrayLiteralExpression(n.initializer)?n.initializer:void 0}));o&&o.elements.length>t?se.add(e.createDiagnosticForNodeInSourceFile(n||S.configFile,o.elements[t],r,a,i)):se.add(e.createCompilerDiagnostic(r,a,i))}function Gt(n,t,r,a,i,o,s){var c=Bt(),l=!c||!Ut(c,n,t,r,a,i,o,s);l&&se.add(e.createCompilerDiagnostic(a,i,o,s))}function Bt(){if(void 0===Q){Q=!1;var n=e.getTsConfigObjectLiteralExpression(S.configFile);if(n)for(var t=0,r=e.getPropertyAssignment(n,"compilerOptions");t<r.length;t++){var a=r[t];if(e.isObjectLiteralExpression(a.initializer)){Q=a.initializer;break}}}return Q||void 0}function Ut(n,t,r,a,i,o,s,c){for(var l=e.getPropertyAssignment(n,r,a),u=0,d=l;u<d.length;u++){var p=d[u];se.add(e.createDiagnosticForNodeInSourceFile(S.configFile,t?p.name:p.initializer,i,o,s,c))}return!!l.length}function Vt(e,n){de.set(Qe(e),!0),se.add(n)}function jt(n){if(S.noEmit)return!1;var t=Qe(n);if(hn(t))return!1;var r=e.outFile(S);if(r)return Kt(t,r)||Kt(t,e.removeFileExtension(r)+".d.ts");if(S.declarationDir&&e.containsPath(S.declarationDir,t,ce,!te.useCaseSensitiveFileNames()))return!0;if(S.outDir)return e.containsPath(S.outDir,t,ce,!te.useCaseSensitiveFileNames());if(e.fileExtensionIsOneOf(t,e.supportedJSExtensions)||e.fileExtensionIs(t,".d.ts")){var a=e.removeFileExtension(t);return!!hn(a+".ts")||!!hn(a+".tsx")}return!1}function Kt(n,t){return 0===e.comparePaths(n,t,ce,!te.useCaseSensitiveFileNames())}function Ht(){return te.getSymlinkCache?te.getSymlinkCache():_||(_=e.discoverProbableSymlinks(m,vt,te.getCurrentDirectory()))}}function P(n){var t,r,a=n.compilerHost.fileExists,i=n.compilerHost.directoryExists,o=n.compilerHost.getDirectories,s=n.compilerHost.realpath;return n.useSourceOfProjectReferenceRedirect?(n.compilerHost.fileExists=l,i&&(r=n.compilerHost.directoryExists=function(r){return i.call(n.compilerHost,r)?(p(r),!0):!!n.getResolvedProjectReferences()&&(t||(t=new e.Set,n.forEachResolvedProjectReference((function(r){var a=e.outFile(r.commandLine.options);if(a)t.add(e.getDirectoryPath(n.toPath(a)));else{var i=r.commandLine.options.declarationDir||r.commandLine.options.outDir;i&&t.add(n.toPath(i))}}))),f(r,!1))}),o&&(n.compilerHost.getDirectories=function(e){return!n.getResolvedProjectReferences()||i&&i.call(n.compilerHost,e)?o.call(n.compilerHost,e):[]}),s&&(n.compilerHost.realpath=function(e){var t;return(null===(t=n.getSymlinkCache().getSymlinkedFiles())||void 0===t?void 0:t.get(n.toPath(e)))||s.call(n.compilerHost,e)}),{onProgramCreateComplete:c,fileExists:l,directoryExists:r}):{onProgramCreateComplete:e.noop,fileExists:l};function c(){n.compilerHost.fileExists=a,n.compilerHost.directoryExists=i,n.compilerHost.getDirectories=o}function l(t){return!!a.call(n.compilerHost,t)||!!n.getResolvedProjectReferences()&&(!!e.isDeclarationFileName(t)&&f(t,!0))}function u(t){var r=n.getSourceOfProjectReferenceRedirect(t);return void 0!==r?!e.isString(r)||a.call(n.compilerHost,r):void 0}function d(r){var a=n.toPath(r),i=""+a+e.directorySeparator;return e.forEachKey(t,(function(n){return a===n||e.startsWith(n,i)||e.startsWith(a,n+"/")}))}function p(t){var r;if(n.getResolvedProjectReferences()&&!e.containsIgnoredPath(t)&&s&&e.stringContains(t,e.nodeModulesPathPart)){var a=n.getSymlinkCache(),i=e.ensureTrailingDirectorySeparator(n.toPath(t));if(!(null===(r=a.getSymlinkedDirectories())||void 0===r?void 0:r.has(i))){var o,c=e.normalizePath(s.call(n.compilerHost,t));c!==t&&(o=e.ensureTrailingDirectorySeparator(n.toPath(c)))!==i?a.setSymlinkedDirectory(t,{real:e.ensureTrailingDirectorySeparator(c),realPath:o}):a.setSymlinkedDirectory(i,!1)}}}function f(t,r){var a,i=r?function(e){return u(e)}:function(e){return d(e)},o=i(t);if(void 0!==o)return o;var s=n.getSymlinkCache(),c=s.getSymlinkedDirectories();if(!c)return!1;var l=n.toPath(t);return!!e.stringContains(l,e.nodeModulesPathPart)&&(!(!r||!(null===(a=s.getSymlinkedFiles())||void 0===a?void 0:a.has(l)))||(e.firstDefinedIterator(c.entries(),(function(a){var o=a[0],c=a[1];if(c&&e.startsWith(l,o)){var u=i(l.replace(o,c.realPath));if(r&&u){var d=e.getNormalizedAbsolutePath(t,n.compilerHost.getCurrentDirectory());s.setSymlinkedFile(l,""+c.real+d.replace(new RegExp(o,"i"),""))}return u}}))||!1))}}function M(n,t,r,a){var o=n.getCompilerOptions();if(o.noEmit)return n.getSemanticDiagnostics(t,a),t||e.outFile(o)?e.emitSkippedWithNoDiagnostics:n.emitBuildInfo(r,a);if(o.noEmitOnError){var s=i(i(i(i([],n.getOptionsDiagnostics(a)),n.getSyntacticDiagnostics(t,a)),n.getGlobalDiagnostics(a)),n.getSemanticDiagnostics(t,a));if(0===s.length&&e.getEmitDeclarations(n.getCompilerOptions())&&(s=n.getDeclarationDiagnostics(void 0,a)),s.length){var c;if(!t&&!e.outFile(o)){var l=n.emitBuildInfo(r,a);l.diagnostics&&(s=i(i([],s),l.diagnostics)),c=l.emittedFiles}return{diagnostics:s,sourceMaps:void 0,emittedFiles:c,emitSkipped:!0}}}}function F(n,t){return e.filter(n,(function(e){return!e.skippedOn||!t[e.skippedOn]}))}function G(n,t){return void 0===t&&(t=n),{fileExists:function(e){return t.fileExists(e)},readDirectory:function(n,r,a,i,o){return e.Debug.assertIsDefined(t.readDirectory,"'CompilerHost.readDirectory' must be implemented to correctly process 'projectReferences'"),t.readDirectory(n,r,a,i,o)},readFile:function(e){return t.readFile(e)},useCaseSensitiveFileNames:n.useCaseSensitiveFileNames(),getCurrentDirectory:function(){return n.getCurrentDirectory()},onUnRecoverableConfigFileDiagnostic:n.onUnRecoverableConfigFileDiagnostic||e.returnUndefined,trace:n.trace?function(e){return n.trace(e)}:void 0}}function B(n,t,r){if(!n)return e.emptyArray;for(var a,i=0;i<n.length;i++){var o=n[i],s=t(o,i);if(o.prepend&&s&&s.options){var c=e.outFile(s.options);if(!c)continue;var l=e.getOutputPathsForBundle(s.options,!0),u=l.jsFilePath,d=l.sourceMapFilePath,p=l.declarationFilePath,f=l.declarationMapPath,m=l.buildInfoPath,_=e.createInputFiles(r,u,d,p,f,m);(a||(a=[])).push(_)}}return a||e.emptyArray}function U(n,t){var r=t||n;return e.resolveConfigFileProjectName(r.path)}function V(n,t){var r=t.extension;switch(r){case".ts":case".d.ts":return;case".tsx":return a();case".jsx":return a()||i();case".js":return i();case".json":return o()}function a(){return n.jsx?void 0:e.Diagnostics.Module_0_was_resolved_to_1_but_jsx_is_not_set}function i(){return e.getAllowJSCompilerOption(n)||!e.getStrictOptionValue(n,"noImplicitAny")?void 0:e.Diagnostics.Could_not_find_a_declaration_file_for_module_0_1_implicitly_has_an_any_type}function o(){return n.resolveJsonModule?void 0:e.Diagnostics.Module_0_was_resolved_to_1_but_resolveJsonModule_is_not_used}}function j(e){for(var n=e.imports,t=e.moduleAugmentations,r=n.map((function(e){return e.text})),a=0,i=t;a<i.length;a++){var o=i[a];10===o.kind&&r.push(o.text)}return r}function K(n,t){var r=n.imports,a=n.moduleAugmentations;if(t<r.length)return r[t];for(var i=r.length,o=0,s=a;o<s.length;o++){var c=s[o];if(10===c.kind){if(t===i)return c;i++}}e.Debug.fail("should never ask for module name at index higher than possible module name")}e.formatColorAndReset=v,e.formatLocation=E,e.formatDiagnosticsWithColorAndContext=T,e.flattenDiagnosticMessageText=S,e.loadWithLocalCache=x,e.forEachResolvedProjectReference=L,e.inferredTypesContainingFile="__inferred type names__.ts",e.isReferencedFile=A,e.isReferenceFileLocation=C,e.getReferencedFileLocation=I,e.isProgramUptoDate=N,e.getConfigFileParsingDiagnostics=k,e.createProgram=w,e.emitSkippedWithNoDiagnostics={diagnostics:e.emptyArray,sourceMaps:void 0,emittedFiles:void 0,emitSkipped:!0},e.handleNoEmitOptions=M,e.filterSemanticDiagnotics=F,e.parseConfigHostFromCompilerHostLike=G,e.createPrependNodes=B,e.resolveProjectReferencePath=U,e.getResolutionDiagnostic=V,e.getModuleNameStringLiteralAt=K}(d||(d={})),function(e){function n(e,n,t,r,a,i){var o=[],s=e.emit(n,d,r,t,a,i),c=s.emitSkipped,l=s.diagnostics,u=s.exportedModulesFromDeclarationEmit;return{outputFiles:o,emitSkipped:c,diagnostics:l,exportedModulesFromDeclarationEmit:u};function d(e,n,t){o.push({name:e,writeByteOrderMark:t,text:n})}}e.getFileEmitOutput=n,function(t){function r(n){if(n.declarations&&n.declarations[0]){var t=e.getSourceFileOfNode(n.declarations[0]);return t&&t.resolvedPath}}function a(e,n){var t=e.getSymbolAtLocation(n);return t&&r(t)}function i(n,t,r,a){return e.toPath(n.getProjectReferenceRedirect(t)||t,r,a)}function o(n,t,r){var o;if(t.imports&&t.imports.length>0)for(var s=n.getTypeChecker(),c=0,l=t.imports;c<l.length;c++){var u=l[c],d=a(s,u);d&&L(d)}var p=e.getDirectoryPath(t.resolvedPath);if(t.referencedFiles&&t.referencedFiles.length>0)for(var f=0,m=t.referencedFiles;f<m.length;f++){var _=m[f],g=i(n,_.fileName,p,r);L(g)}if(t.resolvedTypeReferenceDirectiveNames&&t.resolvedTypeReferenceDirectiveNames.forEach((function(e){if(e){var t=e.resolvedFileName,a=i(n,t,p,r);L(a)}})),t.moduleAugmentations.length){s=n.getTypeChecker();for(var y=0,h=t.moduleAugmentations;y<h.length;y++){var v=h[y];if(e.isStringLiteral(v)){var b=s.getSymbolAtLocation(v);b&&x(b)}}}for(var E=0,T=n.getTypeChecker().getAmbientModules();E<T.length;E++){var S=T[E];S.declarations&&S.declarations.length>1&&x(S)}return o;function x(n){if(n.declarations)for(var r=0,a=n.declarations;r<a.length;r++){var i=a[r],o=e.getSourceFileOfNode(i);o&&o!==t&&L(o.resolvedPath)}}function L(n){(o||(o=new e.Set)).add(n)}}function s(e,n){return n&&!n.referencedMap===!e}function c(n,t,r,a){var i=new e.Map,c=n.getCompilerOptions().module!==e.ModuleKind.None?new e.Map:void 0,l=c?new e.Map:void 0,u=new e.Set,d=s(c,r);n.getTypeChecker();for(var p=0,f=n.getSourceFiles();p<f.length;p++){var m=f[p],_=e.Debug.checkDefined(m.version,"Program intended to be used with Builder should have source files with versions set"),g=d?r.fileInfos.get(m.resolvedPath):void 0;if(c){var y=o(n,m,t);if(y&&c.set(m.resolvedPath,y),d){var h=r.exportedModulesMap.get(m.resolvedPath);h&&l.set(m.resolvedPath,h)}}i.set(m.resolvedPath,{version:_,signature:g&&g.signature,affectsGlobalScope:T(m)||void 0})}return{fileInfos:i,referencedMap:c,exportedModulesMap:l,hasCalledUpdateShapeSignature:u,useFileVersionAsSignature:!a&&!d}}function l(e){e.allFilesExcludingDefaultLibraryFile=void 0,e.allFileNames=void 0}function u(n){return{fileInfos:new e.Map(n.fileInfos),referencedMap:n.referencedMap&&new e.Map(n.referencedMap),exportedModulesMap:n.exportedModulesMap&&new e.Map(n.exportedModulesMap),hasCalledUpdateShapeSignature:new e.Set(n.hasCalledUpdateShapeSignature),useFileVersionAsSignature:n.useFileVersionAsSignature}}function d(n,t,r,a,i,o,s){var c=o||new e.Map,l=t.getSourceFileByPath(r);if(!l)return e.emptyArray;if(!m(n,t,l,c,a,i,s))return[l];var u=(n.referencedMap?L:x)(n,t,l,c,a,i,s);return o||p(n,c),u}function p(e,n){n.forEach((function(n,t){return f(e,n,t)}))}function f(e,n,t){e.fileInfos.get(t).signature=n,e.hasCalledUpdateShapeSignature.add(t)}function m(t,r,a,i,o,s,c){if(e.Debug.assert(!!a),e.Debug.assert(!c||!!t.exportedModulesMap,"Compute visible to outside map only if visibleToOutsideReferencedMap present in the state"),t.hasCalledUpdateShapeSignature.has(a.resolvedPath)||i.has(a.resolvedPath))return!1;var l=t.fileInfos.get(a.resolvedPath);if(!l)return e.Debug.fail();var u,d=l.signature;if(!a.isDeclarationFile&&!t.useFileVersionAsSignature){var p=n(r,a,!0,o,void 0,!0),f=e.firstOrUndefined(p.outputFiles);f&&(e.Debug.assert(e.fileExtensionIs(f.name,".d.ts"),"File extension for signature expected to be dts",(function(){return"Found: "+e.getAnyExtensionFromPath(f.name)+" for "+f.name+":: All output files: "+JSON.stringify(p.outputFiles.map((function(e){return e.name})))})),u=(s||e.generateDjb2Hash)(f.text),c&&u!==d&&_(a,p.exportedModulesFromDeclarationEmit,c))}if(void 0===u&&(u=a.version,c&&u!==d)){var m=t.referencedMap?t.referencedMap.get(a.resolvedPath):void 0;c.set(a.resolvedPath,m||!1)}return i.set(a.resolvedPath,u),u!==d}function _(n,t,a){var i;t?(t.forEach((function(e){return o(r(e))})),a.set(n.resolvedPath,i||!1)):a.set(n.resolvedPath,!1);function o(n){n&&(i||(i=new e.Set),i.add(n))}}function g(n,t){t&&(e.Debug.assert(!!n.exportedModulesMap),t.forEach((function(e,t){e?n.exportedModulesMap.set(t,e):n.exportedModulesMap.delete(t)})))}function y(n,t,r){var a=t.getCompilerOptions();if(e.outFile(a))return h(n,t);if(!n.referencedMap||T(r))return h(n,t);var i=new e.Set,o=[r.resolvedPath];while(o.length){var s=o.pop();if(!i.has(s)){i.add(s);var c=n.referencedMap.get(s);if(c)for(var l=c.keys(),u=l.next();!u.done;u=l.next())o.push(u.value)}}return e.arrayFrom(e.mapDefinedIterator(i.keys(),(function(e){var n,r;return null!==(r=null===(n=t.getSourceFileByPath(e))||void 0===n?void 0:n.fileName)&&void 0!==r?r:e})))}function h(n,t){if(!n.allFileNames){var r=t.getSourceFiles();n.allFileNames=r===e.emptyArray?e.emptyArray:r.map((function(e){return e.fileName}))}return n.allFileNames}function v(n,t){return e.arrayFrom(e.mapDefinedIterator(n.referencedMap.entries(),(function(e){var n=e[0],r=e[1];return r.has(t)?n:void 0})))}function b(n){for(var t=0,r=n.statements;t<r.length;t++){var a=r[t];if(!e.isModuleWithStringLiteralName(a))return!1}return!0}function E(n){return e.some(n.moduleAugmentations,(function(n){return e.isGlobalScopeAugmentation(n.parent)}))}function T(n){return E(n)||!e.isExternalOrCommonJsModule(n)&&!b(n)}function S(n,t,r){if(n.allFilesExcludingDefaultLibraryFile)return n.allFilesExcludingDefaultLibraryFile;var a;r&&c(r);for(var i=0,o=t.getSourceFiles();i<o.length;i++){var s=o[i];s!==r&&c(s)}return n.allFilesExcludingDefaultLibraryFile=a||e.emptyArray,n.allFilesExcludingDefaultLibraryFile;function c(e){t.isSourceFileDefaultLibrary(e)||(a||(a=[])).push(e)}}function x(n,t,r){var a=t.getCompilerOptions();return a&&e.outFile(a)?[r]:S(n,t,r)}function L(n,t,r,a,i,o,s){if(T(r))return S(n,t,r);var c=t.getCompilerOptions();if(c&&(c.isolatedModules||e.outFile(c)))return[r];var l=new e.Map;l.set(r.resolvedPath,r);var u=v(n,r.resolvedPath);while(u.length>0){var d=u.pop();if(!l.has(d)){var p=t.getSourceFileByPath(d);l.set(d,p),p&&m(n,t,p,a,i,o,s)&&u.push.apply(u,v(n,p.resolvedPath))}}return e.arrayFrom(e.mapDefinedIterator(l.values(),(function(e){return e})))}t.canReuseOldState=s,t.create=c,t.releaseCache=l,t.clone=u,t.getFilesAffectedBy=d,t.updateSignaturesFromCache=p,t.updateSignatureOfFile=f,t.updateShapeSignature=m,t.updateExportedFilesMapFromCache=g,t.getAllDependencies=y,t.getReferencedByPaths=v,t.getAllFilesExcludingDefaultLibraryFile=S}(e.BuilderState||(e.BuilderState={}))}(d||(d={})),function(e){var n;function t(n,t){return n===t||void 0!==n&&void 0!==t&&n.size===t.size&&!e.forEachKey(n,(function(e){return!t.has(e)}))}function r(n,r,i,o){var s=e.BuilderState.create(n,r,i,o);s.program=n;var c=n.getCompilerOptions();s.compilerOptions=c,e.outFile(c)||(s.semanticDiagnosticsPerFile=new e.Map),s.changedFilesSet=new e.Set;var l=e.BuilderState.canReuseOldState(s.referencedMap,i),u=l?i.compilerOptions:void 0,d=l&&i.semanticDiagnosticsPerFile&&!!s.semanticDiagnosticsPerFile&&!e.compilerOptionsAffectSemanticDiagnostics(c,u);if(l){if(!i.currentChangedFilePath){var p=i.currentAffectedFilesSignatures;e.Debug.assert(!i.affectedFiles&&(!p||!p.size),"Cannot reuse if only few affected files of currentChangedFile were iterated")}var f=i.changedFilesSet;d&&e.Debug.assert(!f||!e.forEachKey(f,(function(e){return i.semanticDiagnosticsPerFile.has(e)})),"Semantic diagnostics shouldnt be available for changed files"),null===f||void 0===f||f.forEach((function(e){return s.changedFilesSet.add(e)})),!e.outFile(c)&&i.affectedFilesPendingEmit&&(s.affectedFilesPendingEmit=i.affectedFilesPendingEmit.slice(),s.affectedFilesPendingEmitKind=i.affectedFilesPendingEmitKind&&new e.Map(i.affectedFilesPendingEmitKind),s.affectedFilesPendingEmitIndex=i.affectedFilesPendingEmitIndex,s.seenAffectedFiles=new e.Set)}var m=s.referencedMap,_=l?i.referencedMap:void 0,g=d&&!c.skipLibCheck===!u.skipLibCheck,y=g&&!c.skipDefaultLibCheck===!u.skipDefaultLibCheck;return s.fileInfos.forEach((function(o,c){var u,p;if(!l||!(u=i.fileInfos.get(c))||u.version!==o.version||!t(p=m&&m.get(c),_&&_.get(c))||p&&e.forEachKey(p,(function(e){return!s.fileInfos.has(e)&&i.fileInfos.has(e)})))s.changedFilesSet.add(c);else if(d){var f=n.getSourceFileByPath(c);if(f.isDeclarationFile&&!g)return;if(f.hasNoDefaultLib&&!y)return;var h=i.semanticDiagnosticsPerFile.get(c);h&&(s.semanticDiagnosticsPerFile.set(c,i.hasReusableDiagnostic?a(h,n,r):h),s.semanticDiagnosticsFromOldState||(s.semanticDiagnosticsFromOldState=new e.Set),s.semanticDiagnosticsFromOldState.add(c))}})),l&&e.forEachEntry(i.fileInfos,(function(e,n){return e.affectsGlobalScope&&!s.fileInfos.has(n)}))?e.BuilderState.getAllFilesExcludingDefaultLibraryFile(s,n,void 0).forEach((function(e){return s.changedFilesSet.add(e.resolvedPath)})):u&&!e.outFile(c)&&e.compilerOptionsAffectEmit(c,u)&&(n.getSourceFiles().forEach((function(e){return k(s,e.resolvedPath,1)})),e.Debug.assert(!s.seenAffectedFiles||!s.seenAffectedFiles.size),s.seenAffectedFiles=s.seenAffectedFiles||new e.Set),s.buildInfoEmitPending=!!s.changedFilesSet.size,s}function a(n,t,r){if(!n.length)return e.emptyArray;var a=e.getDirectoryPath(e.getNormalizedAbsolutePath(e.getTsBuildInfoEmitOutputFilePath(t.getCompilerOptions()),t.getCurrentDirectory()));return n.map((function(e){var n=i(e,t,o);n.reportsUnnecessary=e.reportsUnnecessary,n.reportsDeprecated=e.reportDeprecated,n.source=e.source,n.skippedOn=e.skippedOn;var r=e.relatedInformation;return n.relatedInformation=r?r.length?r.map((function(e){return i(e,t,o)})):[]:void 0,n}));function o(n){return e.toPath(n,a,r)}}function i(e,n,t){var r=e.file;return o(o({},e),{file:r?n.getSourceFileByPath(t(r)):void 0})}function s(n){e.BuilderState.releaseCache(n),n.program=void 0}function c(n){var t=e.BuilderState.clone(n);return t.semanticDiagnosticsPerFile=n.semanticDiagnosticsPerFile&&new e.Map(n.semanticDiagnosticsPerFile),t.changedFilesSet=new e.Set(n.changedFilesSet),t.affectedFiles=n.affectedFiles,t.affectedFilesIndex=n.affectedFilesIndex,t.currentChangedFilePath=n.currentChangedFilePath,t.currentAffectedFilesSignatures=n.currentAffectedFilesSignatures&&new e.Map(n.currentAffectedFilesSignatures),t.currentAffectedFilesExportedModulesMap=n.currentAffectedFilesExportedModulesMap&&new e.Map(n.currentAffectedFilesExportedModulesMap),t.seenAffectedFiles=n.seenAffectedFiles&&new e.Set(n.seenAffectedFiles),t.cleanedDiagnosticsOfLibFiles=n.cleanedDiagnosticsOfLibFiles,t.semanticDiagnosticsFromOldState=n.semanticDiagnosticsFromOldState&&new e.Set(n.semanticDiagnosticsFromOldState),t.program=n.program,t.compilerOptions=n.compilerOptions,t.affectedFilesPendingEmit=n.affectedFilesPendingEmit&&n.affectedFilesPendingEmit.slice(),t.affectedFilesPendingEmitKind=n.affectedFilesPendingEmitKind&&new e.Map(n.affectedFilesPendingEmitKind),t.affectedFilesPendingEmitIndex=n.affectedFilesPendingEmitIndex,t.seenEmittedFiles=n.seenEmittedFiles&&new e.Map(n.seenEmittedFiles),t.programEmitComplete=n.programEmitComplete,t}function l(n,t){e.Debug.assert(!t||!n.affectedFiles||n.affectedFiles[n.affectedFilesIndex-1]!==t||!n.semanticDiagnosticsPerFile.has(t.resolvedPath))}function u(n,t,r){while(1){var a=n.affectedFiles;if(a){var i=n.seenAffectedFiles,o=n.affectedFilesIndex;while(o<a.length){var s=a[o];if(!i.has(s.resolvedPath))return n.affectedFilesIndex=o,p(n,s,t,r),s;o++}n.changedFilesSet.delete(n.currentChangedFilePath),n.currentChangedFilePath=void 0,e.BuilderState.updateSignaturesFromCache(n,n.currentAffectedFilesSignatures),n.currentAffectedFilesSignatures.clear(),e.BuilderState.updateExportedFilesMapFromCache(n,n.currentAffectedFilesExportedModulesMap),n.affectedFiles=void 0}var c=n.changedFilesSet.keys().next();if(c.done)return;var l=e.Debug.checkDefined(n.program),u=l.getCompilerOptions();if(e.outFile(u))return e.Debug.assert(!n.semanticDiagnosticsPerFile),l;n.currentAffectedFilesSignatures||(n.currentAffectedFilesSignatures=new e.Map),n.exportedModulesMap&&(n.currentAffectedFilesExportedModulesMap||(n.currentAffectedFilesExportedModulesMap=new e.Map)),n.affectedFiles=e.BuilderState.getFilesAffectedBy(n,l,c.value,t,r,n.currentAffectedFilesSignatures,n.currentAffectedFilesExportedModulesMap),n.currentChangedFilePath=c.value,n.affectedFilesIndex=0,n.seenAffectedFiles||(n.seenAffectedFiles=new e.Set)}}function d(n){var t=n.affectedFilesPendingEmit;if(t){for(var r=n.seenEmittedFiles||(n.seenEmittedFiles=new e.Map),a=n.affectedFilesPendingEmitIndex;a<t.length;a++){var i=e.Debug.checkDefined(n.program).getSourceFileByPath(t[a]);if(i){var o=r.get(i.resolvedPath),s=e.Debug.checkDefined(e.Debug.checkDefined(n.affectedFilesPendingEmitKind).get(i.resolvedPath));if(void 0===o||o<s)return n.affectedFilesPendingEmitIndex=a,{affectedFile:i,emitKind:s}}}n.affectedFilesPendingEmit=void 0,n.affectedFilesPendingEmitKind=void 0,n.affectedFilesPendingEmitIndex=void 0}}function p(n,t,r,a){var i;if(m(n,t.resolvedPath),n.allFilesExcludingDefaultLibraryFile!==n.affectedFiles)e.Debug.assert(n.hasCalledUpdateShapeSignature.has(t.resolvedPath)||(null===(i=n.currentAffectedFilesSignatures)||void 0===i?void 0:i.has(t.resolvedPath)),"Signature not updated for affected file: "+t.fileName),n.compilerOptions.assumeChangesOnlyAffectDirectDependencies||g(n,t,(function(e,n){return f(e,n,r,a)}));else{if(!n.cleanedDiagnosticsOfLibFiles){n.cleanedDiagnosticsOfLibFiles=!0;var o=e.Debug.checkDefined(n.program),s=o.getCompilerOptions();e.forEach(o.getSourceFiles(),(function(t){return o.isSourceFileDefaultLibrary(t)&&!e.skipTypeChecking(t,s,o)&&m(n,t.resolvedPath)}))}e.BuilderState.updateShapeSignature(n,e.Debug.checkDefined(n.program),t,e.Debug.checkDefined(n.currentAffectedFilesSignatures),r,a,n.currentAffectedFilesExportedModulesMap)}}function f(n,t,r,a){if(m(n,t),!n.changedFilesSet.has(t)){var i=e.Debug.checkDefined(n.program),o=i.getSourceFileByPath(t);o&&(e.BuilderState.updateShapeSignature(n,i,o,e.Debug.checkDefined(n.currentAffectedFilesSignatures),r,a,n.currentAffectedFilesExportedModulesMap),e.getEmitDeclarations(n.compilerOptions)&&k(n,t,0))}return!1}function m(e,n){return!e.semanticDiagnosticsFromOldState||(e.semanticDiagnosticsFromOldState.delete(n),e.semanticDiagnosticsPerFile.delete(n),!e.semanticDiagnosticsFromOldState.size)}function _(n,t){var r=e.Debug.checkDefined(n.currentAffectedFilesSignatures).get(t),a=e.Debug.checkDefined(n.fileInfos.get(t)).signature;return r!==a}function g(n,t,r){if(n.exportedModulesMap&&n.changedFilesSet.has(t.resolvedPath)&&_(n,t.resolvedPath)){if(n.compilerOptions.isolatedModules){var a=new e.Map;a.set(t.resolvedPath,!0);var i=e.BuilderState.getReferencedByPaths(n,t.resolvedPath);while(i.length>0){var o=i.pop();if(!a.has(o)){a.set(o,!0);var s=r(n,o);if(s&&_(n,o)){var c=e.Debug.checkDefined(n.program).getSourceFileByPath(o);i.push.apply(i,e.BuilderState.getReferencedByPaths(n,c.resolvedPath))}}}}e.Debug.assert(!!n.currentAffectedFilesExportedModulesMap);var l=new e.Set;e.forEachEntry(n.currentAffectedFilesExportedModulesMap,(function(e,a){return e&&e.has(t.resolvedPath)&&y(n,a,l,r)}))||e.forEachEntry(n.exportedModulesMap,(function(e,a){return!n.currentAffectedFilesExportedModulesMap.has(a)&&e.has(t.resolvedPath)&&y(n,a,l,r)}))}}function y(n,t,r,a){return e.forEachEntry(n.referencedMap,(function(e,i){return e.has(t)&&h(n,i,r,a)}))}function h(n,t,r,a){return!!e.tryAddToSet(r,t)&&(!!a(n,t)||(e.Debug.assert(!!n.currentAffectedFilesExportedModulesMap),!!e.forEachEntry(n.currentAffectedFilesExportedModulesMap,(function(e,i){return e&&e.has(t)&&h(n,i,r,a)}))||(!!e.forEachEntry(n.exportedModulesMap,(function(e,i){return!n.currentAffectedFilesExportedModulesMap.has(i)&&e.has(t)&&h(n,i,r,a)}))||!!e.forEachEntry(n.referencedMap,(function(e,i){return e.has(t)&&!r.has(i)&&a(n,i)})))))}function v(n,t,r,a,i){i?n.buildInfoEmitPending=!1:t===n.program?(n.changedFilesSet.clear(),n.programEmitComplete=!0):(n.seenAffectedFiles.add(t.resolvedPath),void 0!==r&&(n.seenEmittedFiles||(n.seenEmittedFiles=new e.Map)).set(t.resolvedPath,r),a?(n.affectedFilesPendingEmitIndex++,n.buildInfoEmitPending=!0):n.affectedFilesIndex++)}function b(e,n,t){return v(e,t),{result:n,affected:t}}function E(e,n,t,r,a,i){return v(e,t,r,a,i),{result:n,affected:t}}function T(n,t,r){return e.concatenate(S(n,t,r),e.Debug.checkDefined(n.program).getProgramDiagnostics(t))}function S(n,t,r){var a=t.resolvedPath;if(n.semanticDiagnosticsPerFile){var i=n.semanticDiagnosticsPerFile.get(a);if(i)return e.filterSemanticDiagnotics(i,n.compilerOptions)}var o=e.Debug.checkDefined(n.program).getBindAndCheckDiagnostics(t,r);return n.semanticDiagnosticsPerFile&&n.semanticDiagnosticsPerFile.set(a,o),e.filterSemanticDiagnotics(o,n.compilerOptions)}function x(n,t){if(!e.outFile(n.compilerOptions)){var r,a,i,o,s,c,l=e.Debug.checkDefined(n.program).getCurrentDirectory(),u=e.getDirectoryPath(e.getNormalizedAbsolutePath(e.getTsBuildInfoEmitOutputFilePath(n.compilerOptions),l)),d=[],p=new e.Map,f=e.arrayFrom(n.fileInfos.entries(),(function(t){var r=t[0],a=t[1],i=x(r);e.Debug.assert(d[i-1]===S(r));var o=n.currentAffectedFilesSignatures&&n.currentAffectedFilesSignatures.get(r),s=null!==o&&void 0!==o?o:a.signature;return a.version===s?a.affectsGlobalScope?{version:a.version,signature:void 0,affectsGlobalScope:!0}:a.version:void 0!==s?void 0===o?a:{version:a.version,signature:o,affectsGlobalScope:a.affectsGlobalScope}:{version:a.version,signature:!1,affectsGlobalScope:a.affectsGlobalScope}}));if(n.referencedMap&&(i=e.arrayFrom(n.referencedMap.keys()).sort(e.compareStringsCaseSensitive).map((function(e){return[x(e),D(n.referencedMap.get(e))]}))),n.exportedModulesMap&&(o=e.mapDefined(e.arrayFrom(n.exportedModulesMap.keys()).sort(e.compareStringsCaseSensitive),(function(e){var t=n.currentAffectedFilesExportedModulesMap&&n.currentAffectedFilesExportedModulesMap.get(e);return void 0===t?[x(e),D(n.exportedModulesMap.get(e))]:t?[x(e),D(t)]:void 0}))),n.semanticDiagnosticsPerFile)for(var m=0,_=e.arrayFrom(n.semanticDiagnosticsPerFile.keys()).sort(e.compareStringsCaseSensitive);m<_.length;m++){var g=_[m],y=n.semanticDiagnosticsPerFile.get(g);(s||(s=[])).push(y.length?[x(g),n.hasReusableDiagnostic?y:A(y,S)]:x(g))}if(n.affectedFilesPendingEmit)for(var h=new e.Set,v=0,b=n.affectedFilesPendingEmit.slice(n.affectedFilesPendingEmitIndex).sort(e.compareStringsCaseSensitive);v<b.length;v++){var E=b[v];e.tryAddToSet(h,E)&&(c||(c=[])).push([x(E),n.affectedFilesPendingEmitKind.get(E)])}return{fileNames:d,fileInfos:f,options:L(n.compilerOptions,T),fileIdsList:r,referencedMap:i,exportedModulesMap:o,semanticDiagnosticsPerFile:s,affectedFilesPendingEmit:c}}function T(n){return S(e.getNormalizedAbsolutePath(n,l))}function S(n){return e.ensurePathIsNonModuleName(e.getRelativePathFromDirectory(u,n,t))}function x(e){var n=p.get(e);return void 0===n&&(d.push(S(e)),p.set(e,n=d.length)),n}function D(n){var t=e.arrayFrom(n.keys(),x).sort(e.compareValues),i=t.join(),o=null===a||void 0===a?void 0:a.get(i);return void 0===o&&((r||(r=[])).push(t),(a||(a=new e.Map)).set(i,o=r.length)),o}}function L(n,t){for(var r,a=e.getOptionsNameMap().optionsNameMap,i=0,o=e.getOwnKeys(n).sort(e.compareStringsCaseSensitive);i<o.length;i++){var s=o[i],c=a.get(s.toLowerCase());((null===c||void 0===c?void 0:c.affectsEmit)||(null===c||void 0===c?void 0:c.affectsSemanticDiagnostics)||"skipLibCheck"===s||"skipDefaultLibCheck"===s)&&((r||(r={}))[s]=D(c,n[s],t))}return r}function D(e,n,t){if(e)if("list"===e.type){var r=n;if(e.element.isFilePath&&r.length)return r.map(t)}else if(e.isFilePath)return t(n);return n}function A(n,t){return e.Debug.assert(!!n.length),n.map((function(e){var n=C(e,t);n.reportsUnnecessary=e.reportsUnnecessary,n.reportDeprecated=e.reportsDeprecated,n.source=e.source,n.skippedOn=e.skippedOn;var r=e.relatedInformation;return n.relatedInformation=r?r.length?r.map((function(e){return C(e,t)})):[]:void 0,n}))}function C(e,n){var t=e.file;return o(o({},e),{file:t?n(t.resolvedPath):void 0})}function I(n,t,r,a,i,o){var s,c,l;return void 0===n?(e.Debug.assert(void 0===t),s=r,l=a,e.Debug.assert(!!l),c=l.getProgram()):e.isArray(n)?(l=a,c=e.createProgram({rootNames:n,options:t,host:r,oldProgram:l&&l.getProgramOrUndefined(),configFileParsingDiagnostics:i,projectReferences:o}),s=r):(c=n,s=t,l=r,i=a),{host:s,newProgram:c,oldProgram:l,configFileParsingDiagnostics:i||e.emptyArray}}function N(t,a){var i=a.newProgram,o=a.host,p=a.oldProgram,f=a.configFileParsingDiagnostics,m=p&&p.getState();if(m&&i===m.program&&f===i.getConfigFileParsingDiagnostics())return i=void 0,m=void 0,p;var _,g=e.createGetCanonicalFileName(o.useCaseSensitiveFileNames()),y=e.maybeBind(o,o.createHash),h=r(i,g,m,o.disableUseFileVersionAsSignature);i.getProgramBuildInfo=function(){return x(h,g)},i=void 0,p=void 0,m=void 0;var S=w(h,f);return S.getState=function(){return h},S.backupState=function(){e.Debug.assert(void 0===_),_=c(h)},S.restoreState=function(){h=e.Debug.checkDefined(_),_=void 0},S.getAllDependencies=function(n){return e.BuilderState.getAllDependencies(h,e.Debug.checkDefined(h.program),n)},S.getSemanticDiagnostics=I,S.emit=A,S.releaseProgram=function(){s(h),_=void 0},t===n.SemanticDiagnosticsBuilderProgram?S.getSemanticDiagnosticsOfNextAffectedFile=C:t===n.EmitAndSemanticDiagnosticsBuilderProgram?(S.getSemanticDiagnosticsOfNextAffectedFile=C,S.emitNextAffectedFile=D,S.emitBuildInfo=L):e.notImplemented(),S;function L(n,t){if(h.buildInfoEmitPending){var r=e.Debug.checkDefined(h.program).emitBuildInfo(n||e.maybeBind(o,o.writeFile),t);return h.buildInfoEmitPending=!1,r}return e.emitSkippedWithNoDiagnostics}function D(n,t,r,a){var i=u(h,t,y),s=1,c=!1;if(!i)if(e.outFile(h.compilerOptions)){var l=e.Debug.checkDefined(h.program);if(h.programEmitComplete)return;i=l}else{var p=d(h);if(!p){if(!h.buildInfoEmitPending)return;var f=e.Debug.checkDefined(h.program);return E(h,f.emitBuildInfo(n||e.maybeBind(o,o.writeFile),t),f,1,!1,!0)}i=p.affectedFile,s=p.emitKind,c=!0}return E(h,e.Debug.checkDefined(h.program).emit(i===h.program?void 0:i,n||e.maybeBind(o,o.writeFile),t,r||0===s,a),i,s,c)}function A(r,a,i,s,c){var u,d,p,f=!1;t===n.EmitAndSemanticDiagnosticsBuilderProgram||r||e.outFile(h.compilerOptions)||h.compilerOptions.noEmit||!h.compilerOptions.noEmitOnError||(f=!0,u=h.affectedFilesPendingEmit&&h.affectedFilesPendingEmit.slice(),d=h.affectedFilesPendingEmitKind&&new e.Map(h.affectedFilesPendingEmitKind),p=h.affectedFilesPendingEmitIndex),t===n.EmitAndSemanticDiagnosticsBuilderProgram&&l(h,r);var m=e.handleNoEmitOptions(S,r,a,i);if(m)return m;if(f&&(h.affectedFilesPendingEmit=u,h.affectedFilesPendingEmitKind=d,h.affectedFilesPendingEmitIndex=p),!r&&t===n.EmitAndSemanticDiagnosticsBuilderProgram){var _=[],g=!1,y=void 0,v=[],b=void 0;while(b=D(a,i,s,c))g=g||b.result.emitSkipped,y=e.addRange(y,b.result.diagnostics),v=e.addRange(v,b.result.emittedFiles),_=e.addRange(_,b.result.sourceMaps);return{emitSkipped:g,diagnostics:y||e.emptyArray,emittedFiles:v,sourceMaps:_}}return e.Debug.checkDefined(h.program).emit(r,a||e.maybeBind(o,o.writeFile),i,s,c)}function C(e,r){while(1){var a=u(h,e,y);if(!a)return;if(a===h.program)return b(h,h.program.getSemanticDiagnostics(void 0,e),a);if((t===n.EmitAndSemanticDiagnosticsBuilderProgram||h.compilerOptions.noEmit||h.compilerOptions.noEmitOnError)&&k(h,a.resolvedPath,1),!r||!r(a))return b(h,T(h,a,e),a);v(h,a)}}function I(n,t){l(h,n);var r,a=e.Debug.checkDefined(h.program).getCompilerOptions();if(e.outFile(a))return e.Debug.assert(!h.semanticDiagnosticsPerFile),e.Debug.checkDefined(h.program).getSemanticDiagnostics(n,t);if(n)return T(h,n,t);while(C(t));for(var i=0,o=e.Debug.checkDefined(h.program).getSourceFiles();i<o.length;i++){var s=o[i];r=e.addRange(r,T(h,s,t))}return r||e.emptyArray}}function k(n,t,r){n.affectedFilesPendingEmit||(n.affectedFilesPendingEmit=[]),n.affectedFilesPendingEmitKind||(n.affectedFilesPendingEmitKind=new e.Map);var a=n.affectedFilesPendingEmitKind.get(t);n.affectedFilesPendingEmit.push(t),n.affectedFilesPendingEmitKind.set(t,a||r),void 0===n.affectedFilesPendingEmitIndex&&(n.affectedFilesPendingEmitIndex=0)}function R(n){return e.isString(n)?{version:n,signature:n,affectsGlobalScope:void 0}:e.isString(n.signature)?n:{version:n.version,signature:!1===n.signature?void 0:n.version,affectsGlobalScope:n.affectsGlobalScope}}function O(n,t,r){var a,i=e.getDirectoryPath(e.getNormalizedAbsolutePath(t,r.getCurrentDirectory())),o=e.createGetCanonicalFileName(r.useCaseSensitiveFileNames()),s=n.fileNames.map(d),c=null===(a=n.fileIdsList)||void 0===a?void 0:a.map((function(n){return new e.Set(n.map(f))})),l=new e.Map;n.fileInfos.forEach((function(e,n){return l.set(f(n+1),R(e))}));var u={fileInfos:l,compilerOptions:n.options?e.convertToOptionsWithAbsolutePaths(n.options,p):{},referencedMap:_(n.referencedMap),exportedModulesMap:_(n.exportedModulesMap),semanticDiagnosticsPerFile:n.semanticDiagnosticsPerFile&&e.arrayToMap(n.semanticDiagnosticsPerFile,(function(n){return f(e.isNumber(n)?n:n[0])}),(function(n){return e.isNumber(n)?e.emptyArray:n[1]})),hasReusableDiagnostic:!0,affectedFilesPendingEmit:e.map(n.affectedFilesPendingEmit,(function(e){return f(e[0])})),affectedFilesPendingEmitKind:n.affectedFilesPendingEmit&&e.arrayToMap(n.affectedFilesPendingEmit,(function(e){return f(e[0])}),(function(e){return e[1]})),affectedFilesPendingEmitIndex:n.affectedFilesPendingEmit&&0};return{getState:function(){return u},backupState:e.noop,restoreState:e.noop,getProgram:e.notImplemented,getProgramOrUndefined:e.returnUndefined,releaseProgram:e.noop,getCompilerOptions:function(){return u.compilerOptions},getSourceFile:e.notImplemented,getSourceFiles:e.notImplemented,getOptionsDiagnostics:e.notImplemented,getGlobalDiagnostics:e.notImplemented,getConfigFileParsingDiagnostics:e.notImplemented,getSyntacticDiagnostics:e.notImplemented,getDeclarationDiagnostics:e.notImplemented,getSemanticDiagnostics:e.notImplemented,emit:e.notImplemented,getAllDependencies:e.notImplemented,getCurrentDirectory:e.notImplemented,emitNextAffectedFile:e.notImplemented,getSemanticDiagnosticsOfNextAffectedFile:e.notImplemented,emitBuildInfo:e.notImplemented,close:e.noop};function d(n){return e.toPath(n,i,o)}function p(n){return e.getNormalizedAbsolutePath(n,i)}function f(e){return s[e-1]}function m(e){return c[e-1]}function _(n){return n&&e.arrayToMap(n,(function(e){return f(e[0])}),(function(e){return m(e[1])}))}}function w(n,t){return{getState:e.notImplemented,backupState:e.noop,restoreState:e.noop,getProgram:r,getProgramOrUndefined:function(){return n.program},releaseProgram:function(){return n.program=void 0},getCompilerOptions:function(){return n.compilerOptions},getSourceFile:function(e){return r().getSourceFile(e)},getSourceFiles:function(){return r().getSourceFiles()},getOptionsDiagnostics:function(e){return r().getOptionsDiagnostics(e)},getGlobalDiagnostics:function(e){return r().getGlobalDiagnostics(e)},getConfigFileParsingDiagnostics:function(){return t},getSyntacticDiagnostics:function(e,n){return r().getSyntacticDiagnostics(e,n)},getDeclarationDiagnostics:function(e,n){return r().getDeclarationDiagnostics(e,n)},getSemanticDiagnostics:function(e,n){return r().getSemanticDiagnostics(e,n)},emit:function(e,n,t,a,i){return r().emit(e,n,t,a,i)},emitBuildInfo:function(e,n){return r().emitBuildInfo(e,n)},getAllDependencies:e.notImplemented,getCurrentDirectory:function(){return r().getCurrentDirectory()},close:e.noop};function r(){return e.Debug.checkDefined(n.program)}}(function(e){e[e["DtsOnly"]=0]="DtsOnly",e[e["Full"]=1]="Full"})(e.BuilderFileEmit||(e.BuilderFileEmit={})),function(e){e[e["SemanticDiagnosticsBuilderProgram"]=0]="SemanticDiagnosticsBuilderProgram",e[e["EmitAndSemanticDiagnosticsBuilderProgram"]=1]="EmitAndSemanticDiagnosticsBuilderProgram"}(n=e.BuilderProgramKind||(e.BuilderProgramKind={})),e.getBuilderCreationParameters=I,e.createBuilderProgram=N,e.toBuilderStateFileInfo=R,e.createBuildProgramUsingProgramBuildInfo=O,e.createRedirectedBuilderProgram=w}(d||(d={})),function(e){function n(n,t,r,a,i,o){return e.createBuilderProgram(e.BuilderProgramKind.SemanticDiagnosticsBuilderProgram,e.getBuilderCreationParameters(n,t,r,a,i,o))}function t(n,t,r,a,i,o){return e.createBuilderProgram(e.BuilderProgramKind.EmitAndSemanticDiagnosticsBuilderProgram,e.getBuilderCreationParameters(n,t,r,a,i,o))}function r(n,t,r,a,i,o){var s=e.getBuilderCreationParameters(n,t,r,a,i,o),c=s.newProgram,l=s.configFileParsingDiagnostics;return e.createRedirectedBuilderProgram({program:c,compilerOptions:c.getCompilerOptions()},l)}e.createSemanticDiagnosticsBuilderProgram=n,e.createEmitAndSemanticDiagnosticsBuilderProgram=t,e.createAbstractBuilder=r}(d||(d={})),function(e){function n(n){return e.endsWith(n,"/node_modules/.staging")?e.removeSuffix(n,"/.staging"):e.some(e.ignoredPaths,(function(t){return e.stringContains(n,t)}))?void 0:n}function t(n){var t=e.getRootLength(n);if(n.length===t)return!1;var r=n.indexOf(e.directorySeparator,t);if(-1===r)return!1;var a=n.substring(t,r+1),i=t>1||47!==n.charCodeAt(0);if(i&&0!==n.search(/[a-zA-Z]:/)&&0===a.search(/[a-zA-z]\$\//)){if(r=n.indexOf(e.directorySeparator,r+1),-1===r)return!1;a=n.substring(t+a.length,r+1)}if(i&&0!==a.search(/users\//i))return!0;for(var o=r+1,s=2;s>0;s--)if(o=n.indexOf(e.directorySeparator,o)+1,0===o)return!1;return!0}function r(r,a,i){var o,s,c,l,u,d,p=e.createMultiMap(),f=[],m=e.createMultiMap(),_=!1,g=e.memoize((function(){return r.getCurrentDirectory()})),y=r.getCachedDirectoryStructureHost(),h=new e.Map,v=e.createCacheWithRedirects(),b=e.createCacheWithRedirects(),E=e.createModuleResolutionCache(g(),r.getCanonicalFileName,void 0,v,b),T=new e.Map,S=e.createCacheWithRedirects(),x=e.createTypeReferenceDirectiveResolutionCache(g(),r.getCanonicalFileName,void 0,E.getPackageJsonInfoCache(),S),L=[".ts",".tsx",".js",".jsx",".json"],D=new e.Map,A=new e.Map,C=a&&e.removeTrailingDirectorySeparator(e.getNormalizedAbsolutePath(a,g())),I=C&&r.toPath(C),N=void 0!==I?I.split(e.directorySeparator).length:0,k=new e.Map;return{startRecordingFilesWithChangedResolutions:M,finishRecordingFilesWithChangedResolutions:F,startCachingPerDirectoryResolution:U,finishCachingPerDirectoryResolution:V,resolveModuleNames:z,getResolvedModuleWithFailedLookupLocationsFromCache:q,resolveTypeReferenceDirectives:W,removeResolutionsFromProjectReferenceRedirects:oe,removeResolutionsOfFile:se,hasChangedAutomaticTypeDirectiveNames:function(){return _},invalidateResolutionOfFile:le,invalidateResolutionsOfFailedLookupLocations:pe,setFilesWithInvalidatedNonRelativeUnresolvedImports:ue,createHasInvalidatedResolution:B,isFileWithInvalidatedNonRelativeUnresolvedImports:G,updateTypeRootsWatch:ye,closeTypeRootsWatch:me,clear:P};function R(e){return e.resolvedModule}function O(e){return e.resolvedTypeReferenceDirective}function w(n,t){return!(void 0===n||t.length<=n.length)&&(e.startsWith(t,n)&&t[n.length]===e.directorySeparator)}function P(){e.clearMap(A,e.closeFileWatcherOf),D.clear(),p.clear(),me(),h.clear(),T.clear(),m.clear(),f.length=0,l=void 0,u=void 0,d=void 0,U(),_=!1}function M(){o=[]}function F(){var e=o;return o=void 0,e}function G(e){if(!c)return!1;var n=c.get(e);return!!n&&!!n.length}function B(n){if(pe(),n)return s=void 0,e.returnTrue;var t=s;return s=void 0,function(e){return!!t&&t.has(e)||G(e)}}function U(){E.clear(),x.clear(),p.forEach(ee),p.clear()}function V(){c=void 0,U(),A.forEach((function(e,n){0===e.refCount&&(A.delete(n),e.watcher.close())})),_=!1}function j(n,t,a,i,o){var s,c=e.resolveModuleName(n,t,a,i,E,o);if(!r.getGlobalCache)return c;var l=r.getGlobalCache();if(void 0!==l&&!e.isExternalModuleNameRelative(n)&&(!c.resolvedModule||!e.extensionIsTS(c.resolvedModule.extension))){var u=e.loadModuleFromGlobalCache(e.Debug.checkDefined(r.globalCacheResolutionModuleName)(n),r.projectName,a,i,l,E),d=u.resolvedModule,p=u.failedLookupLocations;if(d)return c.resolvedModule=d,(s=c.failedLookupLocations).push.apply(s,p),c}return c}function K(n,t,r,a,i){return e.resolveTypeReferenceDirective(n,t,r,a,i,x)}function H(n){var t,a=n.names,i=n.containingFile,s=n.redirectedReference,c=n.cache,l=n.perDirectoryCacheWithRedirects,u=n.loader,d=n.getResolutionWithResolvedFileName,p=n.shouldRetryResolution,f=n.reusedNames,m=n.logChanges,_=r.toPath(i),g=c.get(_)||c.set(_,new e.Map).get(_),y=e.getDirectoryPath(_),h=l.getOrCreateMapOfCacheRedirects(s),v=h.get(y);v||(v=new e.Map,h.set(y,v));for(var b=[],E=r.getCompilationSettings(),T=m&&G(_),S=r.getCurrentProgram(),x=S&&S.getResolvedProjectReferenceToRedirect(i),L=x?!s||s.sourceFile.path!==x.sourceFile.path:!!s,D=new e.Map,A=0,C=a;A<C.length;A++){var I=C[A],N=g.get(I);if(!D.has(I)&&L||!N||N.isInvalidated||T&&!e.isExternalModuleNameRelative(I)&&p(N)){var k=N,R=v.get(I);R?N=R:(N=u(I,i,E,(null===(t=r.getCompilerHost)||void 0===t?void 0:t.call(r))||r,s),v.set(I,N)),g.set(I,N),Z(I,N,_,d),k&&te(k,_,d),m&&o&&!O(k,N)&&(o.push(_),m=!1)}e.Debug.assert(void 0!==N&&!N.isInvalidated),D.set(I,!0),b.push(d(N))}return g.forEach((function(n,t){D.has(t)||e.contains(f,t)||(te(n,_,d),g.delete(t))})),b;function O(e,n){if(e===n)return!0;if(!e||!n)return!1;var t=d(e),r=d(n);return t===r||!(!t||!r)&&t.resolvedFileName===r.resolvedFileName}}function W(e,n,t){return H({names:e,containingFile:n,redirectedReference:t,cache:T,perDirectoryCacheWithRedirects:S,loader:K,getResolutionWithResolvedFileName:O,shouldRetryResolution:function(e){return void 0===e.resolvedTypeReferenceDirective}})}function z(n,t,r,a){return H({names:n,containingFile:t,redirectedReference:a,cache:h,perDirectoryCacheWithRedirects:v,loader:j,getResolutionWithResolvedFileName:R,shouldRetryResolution:function(n){return!n.resolvedModule||!e.resolutionExtensionIsTSOrJson(n.resolvedModule.extension)},reusedNames:r,logChanges:i})}function q(e,n){var t=h.get(r.toPath(n));return t&&t.get(e)}function J(n){return e.endsWith(n,"/node_modules/@types")}function X(n,t){if(w(I,t)){n=e.isRootedDiskPath(n)?e.normalizePath(n):e.getNormalizedAbsolutePath(n,g());var r=t.split(e.directorySeparator),a=n.split(e.directorySeparator);return e.Debug.assert(a.length===r.length,"FailedLookup: "+n+" failedLookupLocationPath: "+t),r.length>N+1?{dir:a.slice(0,N+1).join(e.directorySeparator),dirPath:r.slice(0,N+1).join(e.directorySeparator)}:{dir:C,dirPath:I,nonRecursive:!1}}return Y(e.getDirectoryPath(e.getNormalizedAbsolutePath(n,g())),e.getDirectoryPath(t))}function Y(n,r){while(e.pathContainsNodeModules(r))n=e.getDirectoryPath(n),r=e.getDirectoryPath(r);if(e.isNodeModulesDirectory(r))return t(e.getDirectoryPath(r))?{dir:n,dirPath:r}:void 0;var a,i,o=!0;if(void 0!==I)while(!w(r,I)){var s=e.getDirectoryPath(r);if(s===r)break;o=!1,a=r,i=n,r=s,n=e.getDirectoryPath(n)}return t(r)?{dir:i||n,dirPath:a||r,nonRecursive:o}:void 0}function Q(n){return e.fileExtensionIsOneOf(n,L)}function Z(n,t,a,i){if(t.refCount)t.refCount++,e.Debug.assertDefined(t.files);else{t.refCount=1,e.Debug.assert(0===e.length(t.files)),e.isExternalModuleNameRelative(n)?$(t):p.add(n,t);var o=i(t);o&&o.resolvedFileName&&m.add(r.toPath(o.resolvedFileName),t)}(t.files||(t.files=[])).push(a)}function $(n){e.Debug.assert(!!n.refCount);var t=n.failedLookupLocations;if(t.length){f.push(n);for(var a=!1,i=0,o=t;i<o.length;i++){var s=o[i],c=r.toPath(s),l=X(s,c);if(l){var u=l.dir,d=l.dirPath,p=l.nonRecursive;if(!Q(c)){var m=D.get(c)||0;D.set(c,m+1)}d===I?(e.Debug.assert(!p),a=!0):ne(u,d,p)}}a&&ne(C,I,!0)}}function ee(e,n){var t=r.getCurrentProgram();t&&t.getTypeChecker().tryFindAmbientModuleWithoutAugmentations(n)||e.forEach($)}function ne(n,t,r){var a=A.get(t);a?(e.Debug.assert(!!r===!!a.nonRecursive),a.refCount++):A.set(t,{watcher:ae(n,t,r),refCount:1,nonRecursive:r})}function te(n,t,a){if(e.unorderedRemoveItem(e.Debug.assertDefined(n.files),t),n.refCount--,!n.refCount){var i=a(n);if(i&&i.resolvedFileName&&m.remove(r.toPath(i.resolvedFileName),n),e.unorderedRemoveItem(f,n)){for(var o=n.failedLookupLocations,s=!1,c=0,l=o;c<l.length;c++){var u=l[c],d=r.toPath(u),p=X(u,d);if(p){var _=p.dirPath,g=D.get(d);g&&(1===g?D.delete(d):(e.Debug.assert(g>1),D.set(d,g-1))),_===I?s=!0:re(_)}}s&&re(I)}}}function re(e){var n=A.get(e);n.refCount--}function ae(e,n,t){return r.watchDirectoryOfFailedLookupLocation(e,(function(e){var t=r.toPath(e);y&&y.addOrDeleteFileOrDirectory(e,t),de(t,n===t)}),t?0:1)}function ie(e,n,t){var r=e.get(n);r&&(r.forEach((function(e){return te(e,n,t)})),e.delete(n))}function oe(n){if(e.fileExtensionIs(n,".json")){var t=r.getCurrentProgram();if(t){var a=t.getResolvedProjectReferenceByPath(n);a&&a.commandLine.fileNames.forEach((function(e){return se(r.toPath(e))}))}}}function se(e){ie(h,e,R),ie(T,e,O)}function ce(n,t){if(!n)return!1;for(var r=!1,a=0,i=n;a<i.length;a++){var o=i[a];if(!o.isInvalidated&&t(o)){o.isInvalidated=r=!0;for(var c=0,l=e.Debug.assertDefined(o.files);c<l.length;c++){var u=l[c];(s||(s=new e.Set)).add(u),_=_||e.endsWith(u,e.inferredTypesContainingFile)}}}return r}function le(n){se(n);var t=_;ce(m.get(n),e.returnTrue)&&_&&!t&&r.onChangedAutomaticTypeDirectiveNames()}function ue(n){e.Debug.assert(c===n||void 0===c),c=n}function de(t,a){if(a)(d||(d=[])).push(t);else{var i=n(t);if(!i)return!1;if(t=i,r.fileIsOpen(t))return!1;var o=e.getDirectoryPath(t);if(J(t)||e.isNodeModulesDirectory(t)||J(o)||e.isNodeModulesDirectory(o))(l||(l=[])).push(t),(u||(u=new e.Set)).add(t);else{if(!Q(t)&&!D.has(t))return!1;if(e.isEmittedFileOfProgram(r.getCurrentProgram(),t))return!1;(l||(l=[])).push(t);var s=e.parseNodeModuleFromPath(t);s&&(u||(u=new e.Set)).add(s)}}r.scheduleInvalidateResolutionsOfFailedLookupLocations()}function pe(){if(!l&&!u&&!d)return!1;var e=ce(f,fe);return l=void 0,u=void 0,d=void 0,e}function fe(n){return n.failedLookupLocations.some((function(n){var t=r.toPath(n);return e.contains(l,t)||e.firstDefinedIterator((null===u||void 0===u?void 0:u.keys())||e.emptyIterator,(function(n){return!!e.startsWith(t,n)||void 0}))||(null===d||void 0===d?void 0:d.some((function(e){return w(e,t)})))}))}function me(){e.clearMap(k,e.closeFileWatcher)}function _e(e,n){if(w(I,n))return I;var t=Y(e,n);return t&&A.has(t.dirPath)?t.dirPath:void 0}function ge(e,n){return r.watchTypeRootsDirectory(n,(function(t){var a=r.toPath(t);y&&y.addOrDeleteFileOrDirectory(t,a),_=!0,r.onChangedAutomaticTypeDirectiveNames();var i=_e(n,e);i&&de(a,i===a)}),1)}function ye(){var n=r.getCompilationSettings();if(n.types)me();else{var t=e.getEffectiveTypeRoots(n,{directoryExists:he,getCurrentDirectory:g});t?e.mutateMap(k,e.arrayToMap(t,(function(e){return r.toPath(e)})),{createNewValue:ge,onDeleteValue:e.closeFileWatcher}):me()}}function he(n){var a=e.getDirectoryPath(e.getDirectoryPath(n)),i=r.toPath(a);return i===I||t(i)}}e.removeIgnoredPath=n,e.canWatchDirectory=t,e.createResolutionCache=r}(d||(d={})),function(e){(function(n){var t,r;function a(n,t,r){var a=n.importModuleSpecifierPreference,i=n.importModuleSpecifierEnding;return{relativePreference:"relative"===a?0:"non-relative"===a?1:"project-relative"===a?3:2,ending:o()};function o(){switch(i){case"minimal":return 0;case"index":return 1;case"js":return 2;default:return _(r)?2:e.getEmitModuleResolutionKind(t)!==e.ModuleResolutionKind.NodeJs?1:0}}}function o(n,t){return{relativePreference:e.isExternalModuleNameRelative(t)?0:1,ending:e.hasJSFileExtension(t)?2:e.getEmitModuleResolutionKind(n)!==e.ModuleResolutionKind.NodeJs||e.endsWith(t,"index")?1:0}}function s(e,n,t,r,a){var i=u(e,n,t,r,o(e,a));if(i!==a)return i}function c(e,n,t,r,i,o){return void 0===o&&(o={}),u(e,t,r,i,a(o,e,n))}function l(n,t,r,a){var i=p(t,a),o=v(t,r,a);return e.firstDefined(o,(function(e){return S(e,i,a,n,!0)}))}function u(n,t,r,a,i){var o=p(t,a),s=v(t,r,a);return e.firstDefined(s,(function(e){return S(e,o,a,n)}))||f(r,o,n,a,i)}function d(n,t,r,i,o,s){var c=b(n,t);if(c)return[c];var l=p(i.path,o),u=e.getSourceFileOfNode(n.valueDeclaration||e.getNonAugmentationDeclaration(n));if(!u)return[];var d=v(i.path,u.originalFileName,o),m=a(s,r,i),_=e.forEach(d,(function(n){return e.forEach(o.getFileIncludeReasons().get(e.toPath(n.path,o.getCurrentDirectory(),l.getCanonicalFileName)),(function(n){if(n.kind===e.FileIncludeKind.Import&&n.file===i.path){var t=e.getModuleNameStringLiteralAt(i,n.index).text;return 1===m.relativePreference&&e.pathIsRelative(t)?void 0:t}}))}));if(_)return[_];for(var g,y,h,E=e.some(d,(function(e){return e.isInNodeModules})),T=0,x=d;T<x.length;T++){var L=x[T],D=S(L,l,o,r);if(g=e.append(g,D),D&&L.isRedirect)return g;if(!D&&!L.isRedirect){var A=f(L.path,l,r,o,m);e.pathIsBareSpecifier(A)?y=e.append(y,A):E&&!L.isInNodeModules||(h=e.append(h,A))}}return(null===y||void 0===y?void 0:y.length)?y:(null===g||void 0===g?void 0:g.length)?g:e.Debug.checkDefined(h)}function p(n,t){var r=e.createGetCanonicalFileName(!t.useCaseSensitiveFileNames||t.useCaseSensitiveFileNames()),a=e.getDirectoryPath(n);return{getCanonicalFileName:r,importingSourceFileName:n,sourceDirectory:a}}function f(n,t,r,a,i){var o=i.ending,s=i.relativePreference,c=r.baseUrl,l=r.paths,u=r.rootDirs,d=t.sourceDirectory,p=t.getCanonicalFileName,f=u&&T(u,n,d,p,o,r)||A(e.ensurePathIsNonModuleName(e.getRelativePathFromDirectory(d,n,p)),o,r);if(!c&&!l||0===s)return f;var _=e.getNormalizedAbsolutePath(e.getPathsBasePath(r,a)||c,a.getCurrentDirectory()),g=I(n,_,p);if(!g)return f;var h=A(g,o,r),v=l&&E(e.removeFileExtension(g),h,l),b=void 0===v&&void 0!==c?h:v;if(!b)return f;if(1===s)return b;if(3===s){var S=r.configFilePath?e.toPath(e.getDirectoryPath(r.configFilePath),a.getCurrentDirectory(),t.getCanonicalFileName):t.getCanonicalFileName(a.getCurrentDirectory()),x=e.toPath(n,S,p),L=e.startsWith(d,S),D=e.startsWith(x,S);if(L&&!D||!L&&D)return b;var C=y(a,e.getDirectoryPath(x)),k=y(a,d);return k!==C?b:f}return 2!==s&&e.Debug.assertNever(s),N(b)||m(f)<m(b)?f:b}function m(n){for(var t=0,r=e.startsWith(n,"./")?2:0;r<n.length;r++)47===n.charCodeAt(r)&&t++;return t}function _(n){var t=n.imports;return e.firstDefined(t,(function(n){var t=n.text;return e.pathIsRelative(t)?e.hasJSFileExtension(t):void 0}))||!1}function g(n,t){return e.compareBooleans(t.isRedirect,n.isRedirect)||e.compareNumberOfDirectorySeparators(n.path,t.path)}function y(n,t){return n.getNearestAncestorDirectoryWithPackageJson?n.getNearestAncestorDirectoryWithPackageJson(t):!!e.forEachAncestorDirectory(t,(function(t){return!!n.fileExists(e.combinePaths(t,"package.json"))||void 0}))}function h(n,t,r,a,o){var s=e.hostGetCanonicalFileName(r),c=r.getCurrentDirectory(),l=r.isSourceOfProjectReferenceRedirect(t)?r.getProjectReferenceRedirect(t):void 0,u=e.toPath(t,c,s),d=r.redirectTargetsMap.get(u)||e.emptyArray,p=i(i(i([],l?[l]:e.emptyArray),[t]),d),f=p.map((function(n){return e.getNormalizedAbsolutePath(n,c)})),m=!e.every(f,e.containsIgnoredPath);if(!a){var _=e.forEach(f,(function(n){return!(m&&e.containsIgnoredPath(n))&&o(n,l===n)}));if(_)return _}var g=r.getSymlinkCache?r.getSymlinkCache():e.discoverProbableSymlinks(r.getSourceFiles(),s,c),y=g.getSymlinkedDirectoriesByRealpath(),h=e.getNormalizedAbsolutePath(t,c),v=y&&e.forEachAncestorDirectory(e.getDirectoryPath(h),(function(t){var r=y.get(e.ensureTrailingDirectorySeparator(e.toPath(t,c,s)));if(r)return!e.startsWithDirectory(n,t,s)&&e.forEach(f,(function(n){if(e.startsWithDirectory(n,t,s))for(var a=e.getRelativePathFromDirectory(t,n,s),i=0,c=r;i<c.length;i++){var u=c[i],d=e.resolvePath(u,a),p=o(d,n===l);if(m=!0,p)return p}}))}));return v||(a?e.forEach(f,(function(n){return m&&e.containsIgnoredPath(n)?void 0:o(n,n===l)})):void 0)}function v(n,t,r){var a,i=null===(a=r.getModuleSpecifierCache)||void 0===a?void 0:a.call(r),o=e.hostGetCanonicalFileName(r);if(i){var s=i.get(n,e.toPath(t,r.getCurrentDirectory(),o));if("object"===typeof s)return s}var c=new e.Map,l=!1;h(n,t,r,!0,(function(n,t){var r=e.pathContainsNodeModules(n);c.set(n,{path:o(n),isRedirect:t,isInNodeModules:r}),l=l||r}));for(var u,d=[],p=function(n){var t,r=e.ensureTrailingDirectorySeparator(n);c.forEach((function(n,a){var i=n.path,o=n.isRedirect,s=n.isInNodeModules;e.startsWith(i,r)&&((t||(t=[])).push({path:a,isRedirect:o,isInNodeModules:s}),c.delete(a))})),t&&(t.length>1&&t.sort(g),d.push.apply(d,t));var a=e.getDirectoryPath(n);if(a===n)return u=n,"break";n=a,u=n},f=e.getDirectoryPath(n);0!==c.size;){var m=p(f);if(f=u,"break"===m)break}if(c.size){var _=e.arrayFrom(c.values());_.length>1&&_.sort(g),d.push.apply(d,_)}return i&&i.set(n,e.toPath(t,r.getCurrentDirectory(),o),d),d}function b(n,t){var r,a=null===(r=n.declarations)||void 0===r?void 0:r.find((function(n){return e.isNonGlobalAmbientModule(n)&&(!e.isExternalModuleAugmentation(n)||!e.isExternalModuleNameRelative(e.getTextOfIdentifierOrLiteral(n.name)))}));if(a)return a.name.text;var i=e.mapDefined(n.declarations,(function(n){var r,a,i,o;if(e.isModuleDeclaration(n)){var s=d(n);if((null===(r=null===s||void 0===s?void 0:s.parent)||void 0===r?void 0:r.parent)&&e.isModuleBlock(s.parent)&&e.isAmbientModule(s.parent.parent)&&e.isSourceFile(s.parent.parent.parent)){var c=null===(o=null===(i=null===(a=s.parent.parent.symbol.exports)||void 0===a?void 0:a.get("export="))||void 0===i?void 0:i.valueDeclaration)||void 0===o?void 0:o.expression;if(c){var l=t.getSymbolAtLocation(c);if(l){var u=2097152&(null===l||void 0===l?void 0:l.flags)?t.getAliasedSymbol(l):l;if(u===n.symbol)return s.parent.parent}}}}function d(e){while(4&e.flags)e=e.parent;return e}})),o=i[0];return o?o.name.text:void 0}function E(n,t,r){for(var a in r)for(var i=0,o=r[a];i<o.length;i++){var s=o[i],c=e.removeFileExtension(e.normalizePath(s)),l=c.indexOf("*");if(-1!==l){var u=c.substr(0,l),d=c.substr(l+1);if(t.length>=u.length+d.length&&e.startsWith(t,u)&&e.endsWith(t,d)||!d&&t===e.removeTrailingDirectorySeparator(u)){var p=t.substr(u.length,t.length-d.length-u.length);return a.replace("*",p)}}else if(c===t||c===n)return a}}function T(n,t,r,a,i,o){var s=D(t,n,a);if(void 0!==s){var c=D(r,n,a),l=void 0!==c?e.ensurePathIsNonModuleName(e.getRelativePathFromDirectory(c,s,a)):s;return e.getEmitModuleResolutionKind(o)===e.ModuleResolutionKind.NodeJs?A(l,i,o):e.removeFileExtension(l)}}function S(n,t,r,a,i){var o=n.path,s=n.isRedirect,c=t.getCanonicalFileName,l=t.sourceDirectory;if(r.fileExists&&r.readFile){var u=L(o);if(u){var d=o,p=!1;if(!i){var f=u.packageRootIndex,m=void 0;while(1){var _=S(f),g=_.moduleFileToTry,y=_.packageRootPath;if(y){d=y,p=!0;break}if(m||(m=g),f=o.indexOf(e.directorySeparator,f+1),-1===f){d=D(m);break}}}if(!s||p){var h=r.getGlobalTypingsCacheLocation&&r.getGlobalTypingsCacheLocation(),v=c(d.substring(0,u.topLevelNodeModulesIndex));if(e.startsWith(l,v)||h&&e.startsWith(c(h),v)){var b=d.substring(u.topLevelPackageNameIndex+1),T=e.getPackageNameFromTypesPackageName(b);return e.getEmitModuleResolutionKind(a)!==e.ModuleResolutionKind.NodeJs&&T===b?void 0:T}}}}function S(n){var t=o.substring(0,n),i=e.combinePaths(t,"package.json"),s=o;if(r.fileExists(i)){var l=JSON.parse(r.readFile(i)),u=l.typesVersions?e.getPackageJsonTypesVersionsPaths(l.typesVersions):void 0;if(u){var d=o.slice(t.length+1),p=E(e.removeFileExtension(d),A(d,0,a),u.paths);void 0!==p&&(s=e.combinePaths(t,p))}var f=l.typings||l.types||l.main;if(e.isString(f)){var m=e.toPath(f,t,c);if(e.removeFileExtension(m)===e.removeFileExtension(c(s)))return{packageRootPath:t,moduleFileToTry:s}}}return{moduleFileToTry:s}}function D(n){var t=e.removeFileExtension(n);return"/index"!==c(t.substring(u.fileNameIndex))||x(r,t.substring(0,u.fileNameIndex))?t:t.substring(0,u.fileNameIndex)}}function x(n,t){if(n.fileExists)for(var r=e.getSupportedExtensions({allowJs:!0},[{extension:"node",isMixedContent:!1},{extension:"json",isMixedContent:!1,scriptKind:6}]),a=0,i=r;a<i.length;a++){var o=i[a],s=t+o;if(n.fileExists(s))return s}}function L(n){var t,r=0,a=0,i=0,o=0;(function(e){e[e["BeforeNodeModules"]=0]="BeforeNodeModules",e[e["NodeModules"]=1]="NodeModules",e[e["Scope"]=2]="Scope",e[e["PackageContent"]=3]="PackageContent"})(t||(t={}));var s=0,c=0,l=0;while(c>=0)switch(s=c,c=n.indexOf("/",s+1),l){case 0:n.indexOf(e.nodeModulesPathPart,s)===s&&(r=s,a=c,l=1);break;case 1:case 2:1===l&&"@"===n.charAt(s+1)?l=2:(i=c,l=3);break;case 3:l=n.indexOf(e.nodeModulesPathPart,s)===s?1:3;break}return o=s,l>1?{topLevelNodeModulesIndex:r,topLevelPackageNameIndex:a,packageRootIndex:i,fileNameIndex:o}:void 0}function D(n,t,r){return e.firstDefined(t,(function(e){var t=I(n,e,r);return N(t)?void 0:t}))}function A(n,t,r){if(e.fileExtensionIs(n,".json"))return n;var a=e.removeFileExtension(n);switch(t){case 0:return e.removeSuffix(a,"/index");case 1:return a;case 2:return a+C(n,r);default:return e.Debug.assertNever(t)}}function C(n,t){var r=e.extensionFromPath(n);switch(r){case".ts":case".d.ts":return".js";case".tsx":return 1===t.jsx?".jsx":".js";case".js":case".jsx":case".json":return r;case".tsbuildinfo":return e.Debug.fail("Extension .tsbuildinfo is unsupported:: FileName:: "+n);default:return e.Debug.assertNever(r)}}function I(n,t,r){var a=e.getRelativePathToDirectoryOrUrl(t,n,t,r,!1);return e.isRootedDiskPath(a)?void 0:a}function N(n){return e.startsWith(n,"..")}(function(e){e[e["Relative"]=0]="Relative",e[e["NonRelative"]=1]="NonRelative",e[e["Shortest"]=2]="Shortest",e[e["ExternalNonRelative"]=3]="ExternalNonRelative"})(t||(t={})),function(e){e[e["Minimal"]=0]="Minimal",e[e["Index"]=1]="Index",e[e["JsExtension"]=2]="JsExtension"}(r||(r={})),n.updateModuleSpecifier=s,n.getModuleSpecifier=c,n.getNodeModulesPackageName=l,n.getModuleSpecifiers=d,n.countPathComponents=m,n.forEachFileNameOfModule=h})(e.moduleSpecifiers||(e.moduleSpecifiers={}))}(d||(d={})),function(e){var n=e.sys?{getCurrentDirectory:function(){return e.sys.getCurrentDirectory()},getNewLine:function(){return e.sys.newLine},getCanonicalFileName:e.createGetCanonicalFileName(e.sys.useCaseSensitiveFileNames)}:void 0;function t(t,r){var a=t===e.sys?n:{getCurrentDirectory:function(){return t.getCurrentDirectory()},getNewLine:function(){return t.newLine},getCanonicalFileName:e.createGetCanonicalFileName(t.useCaseSensitiveFileNames)};if(!r)return function(n){return t.write(e.formatDiagnostic(n,a))};var i=new Array(1);return function(n){i[0]=n,t.write(e.formatDiagnosticsWithColorAndContext(i,a)+a.getNewLine()),i[0]=void 0}}function r(n,t,r){return!(!n.clearScreen||r.preserveWatchOutput||r.extendedDiagnostics||r.diagnostics||!e.contains(e.screenStartingMessageCodes,t.code))&&(n.clearScreen(),!0)}function a(n,t){return e.contains(e.screenStartingMessageCodes,n.code)?t+t:t}function o(e){return e.now?e.now().toLocaleTimeString("en-US",{timeZone:"UTC"}):(new Date).toLocaleTimeString()}function s(n,t){return t?function(t,a,i){r(n,t,i);var s="["+e.formatColorAndReset(o(n),e.ForegroundColorEscapeSequences.Grey)+"] ";s+=""+e.flattenDiagnosticMessageText(t.messageText,n.newLine)+(a+a),n.write(s)}:function(t,i,s){var c="";r(n,t,s)||(c+=i),c+=o(n)+" - ",c+=""+e.flattenDiagnosticMessageText(t.messageText,n.newLine)+a(t,i),n.write(c)}}function c(n,t,r,a,i,o){var s=i;s.onUnRecoverableConfigFileDiagnostic=function(e){return C(i,o,e)};var c=e.getParsedCommandLineOfConfigFile(n,t,s,r,a);return s.onUnRecoverableConfigFileDiagnostic=void 0,c}function l(n){return e.countWhere(n,(function(n){return n.category===e.DiagnosticCategory.Error}))}function u(n){return 1===n?e.Diagnostics.Found_1_error_Watching_for_file_changes:e.Diagnostics.Found_0_errors_Watching_for_file_changes}function d(n,t){if(0===n)return"";var r=e.createCompilerDiagnostic(1===n?e.Diagnostics.Found_1_error:e.Diagnostics.Found_0_errors,n);return""+t+e.flattenDiagnosticMessageText(r.messageText,t)+t+t}function p(e){return!!e.getState}function f(n,t){var r=n.getCompilerOptions();r.explainFiles?m(p(n)?n.getProgram():n,t):(r.listFiles||r.listFilesOnly)&&e.forEach(n.getSourceFiles(),(function(e){t(e.fileName)}))}function m(n,t){for(var r,a,i=n.getFileIncludeReasons(),o=e.createGetCanonicalFileName(n.useCaseSensitiveFileNames()),s=function(t){return e.convertToRelativePath(t,n.getCurrentDirectory(),o)},c=0,l=n.getSourceFiles();c<l.length;c++){var u=l[c];t(""+v(u,s)),null===(r=i.get(u.path))||void 0===r||r.forEach((function(e){return t("  "+h(n,e,s).messageText)})),null===(a=_(u,s))||void 0===a||a.forEach((function(e){return t("  "+e.messageText)}))}}function _(n,t){var r;return n.path!==n.resolvedPath&&(r||(r=[])).push(e.chainDiagnosticMessages(void 0,e.Diagnostics.File_is_output_of_project_reference_source_0,v(n.originalFileName,t))),n.redirectInfo&&(r||(r=[])).push(e.chainDiagnosticMessages(void 0,e.Diagnostics.File_redirects_to_file_0,v(n.redirectInfo.redirectTarget,t))),r}function g(n,t){var r,a=n.getCompilerOptions().configFile;if(null===(r=null===a||void 0===a?void 0:a.configFileSpecs)||void 0===r?void 0:r.validatedFilesSpec){var i=e.createGetCanonicalFileName(n.useCaseSensitiveFileNames()),o=i(t),s=e.getDirectoryPath(e.getNormalizedAbsolutePath(a.fileName,n.getCurrentDirectory()));return e.find(a.configFileSpecs.validatedFilesSpec,(function(n){return i(e.getNormalizedAbsolutePath(n,s))===o}))}}function y(n,t){var r,a,i=n.getCompilerOptions().configFile;if(null===(r=null===i||void 0===i?void 0:i.configFileSpecs)||void 0===r?void 0:r.validatedIncludeSpecs){var o=e.fileExtensionIs(t,".json"),s=e.getDirectoryPath(e.getNormalizedAbsolutePath(i.fileName,n.getCurrentDirectory())),c=n.useCaseSensitiveFileNames();return e.find(null===(a=null===i||void 0===i?void 0:i.configFileSpecs)||void 0===a?void 0:a.validatedIncludeSpecs,(function(n){if(o&&!e.endsWith(n,".json"))return!1;var r=e.getPatternFromSpec(n,s,"files");return!!r&&e.getRegexFromPattern("("+r+")$",c).test(t)}))}}function h(n,t,r){var a,i,o=n.getCompilerOptions();if(e.isReferencedFile(t)){var s=e.getReferencedFileLocation((function(e){return n.getSourceFileByPath(e)}),t),c=e.isReferenceFileLocation(s)?s.file.text.substring(s.pos,s.end):'"'+s.text+'"',l=void 0;switch(e.Debug.assert(e.isReferenceFileLocation(s)||t.kind===e.FileIncludeKind.Import,"Only synthetic references are imports"),t.kind){case e.FileIncludeKind.Import:l=e.isReferenceFileLocation(s)?s.packageId?e.Diagnostics.Imported_via_0_from_file_1_with_packageId_2:e.Diagnostics.Imported_via_0_from_file_1:s.text===e.externalHelpersModuleNameText?s.packageId?e.Diagnostics.Imported_via_0_from_file_1_with_packageId_2_to_import_importHelpers_as_specified_in_compilerOptions:e.Diagnostics.Imported_via_0_from_file_1_to_import_importHelpers_as_specified_in_compilerOptions:s.packageId?e.Diagnostics.Imported_via_0_from_file_1_with_packageId_2_to_import_jsx_and_jsxs_factory_functions:e.Diagnostics.Imported_via_0_from_file_1_to_import_jsx_and_jsxs_factory_functions;break;case e.FileIncludeKind.ReferenceFile:e.Debug.assert(!s.packageId),l=e.Diagnostics.Referenced_via_0_from_file_1;break;case e.FileIncludeKind.TypeReferenceDirective:l=s.packageId?e.Diagnostics.Type_library_referenced_via_0_from_file_1_with_packageId_2:e.Diagnostics.Type_library_referenced_via_0_from_file_1;break;case e.FileIncludeKind.LibReferenceDirective:e.Debug.assert(!s.packageId),l=e.Diagnostics.Library_referenced_via_0_from_file_1;break;default:e.Debug.assertNever(t)}return e.chainDiagnosticMessages(void 0,l,c,v(s.file,r),s.packageId&&e.packageIdToString(s.packageId))}switch(t.kind){case e.FileIncludeKind.RootFile:if(!(null===(a=o.configFile)||void 0===a?void 0:a.configFileSpecs))return e.chainDiagnosticMessages(void 0,e.Diagnostics.Root_file_specified_for_compilation);var u=e.getNormalizedAbsolutePath(n.getRootFileNames()[t.index],n.getCurrentDirectory()),d=g(n,u);if(d)return e.chainDiagnosticMessages(void 0,e.Diagnostics.Part_of_files_list_in_tsconfig_json);var p=y(n,u);return p?e.chainDiagnosticMessages(void 0,e.Diagnostics.Matched_by_include_pattern_0_in_1,p,v(o.configFile,r)):e.chainDiagnosticMessages(void 0,e.Diagnostics.Root_file_specified_for_compilation);case e.FileIncludeKind.SourceFromProjectReference:case e.FileIncludeKind.OutputFromProjectReference:var f=t.kind===e.FileIncludeKind.OutputFromProjectReference,m=e.Debug.checkDefined(null===(i=n.getResolvedProjectReferences())||void 0===i?void 0:i[t.index]);return e.chainDiagnosticMessages(void 0,e.outFile(o)?f?e.Diagnostics.Output_from_referenced_project_0_included_because_1_specified:e.Diagnostics.Source_from_referenced_project_0_included_because_1_specified:f?e.Diagnostics.Output_from_referenced_project_0_included_because_module_is_specified_as_none:e.Diagnostics.Source_from_referenced_project_0_included_because_module_is_specified_as_none,v(m.sourceFile.fileName,r),o.outFile?"--outFile":"--out");case e.FileIncludeKind.AutomaticTypeDirectiveFile:return e.chainDiagnosticMessages(void 0,o.types?t.packageId?e.Diagnostics.Entry_point_of_type_library_0_specified_in_compilerOptions_with_packageId_1:e.Diagnostics.Entry_point_of_type_library_0_specified_in_compilerOptions:t.packageId?e.Diagnostics.Entry_point_for_implicit_type_library_0_with_packageId_1:e.Diagnostics.Entry_point_for_implicit_type_library_0,t.typeReference,t.packageId&&e.packageIdToString(t.packageId));case e.FileIncludeKind.LibFile:if(void 0!==t.index)return e.chainDiagnosticMessages(void 0,e.Diagnostics.Library_0_specified_in_compilerOptions,o.lib[t.index]);var _=e.forEachEntry(e.targetOptionDeclaration.type,(function(e,n){return e===o.target?n:void 0}));return e.chainDiagnosticMessages(void 0,_?e.Diagnostics.Default_library_for_target_0:e.Diagnostics.Default_library,_);default:e.Debug.assertNever(t)}}function v(n,t){var r=e.isString(n)?n:n.fileName;return t?t(r):r}function b(n,t,r,a,i,o,s,c){var u=!!n.getCompilerOptions().listFilesOnly,d=n.getConfigFileParsingDiagnostics().slice(),p=d.length;e.addRange(d,n.getSyntacticDiagnostics(void 0,o)),d.length===p&&(e.addRange(d,n.getOptionsDiagnostics(o)),u||(e.addRange(d,n.getGlobalDiagnostics(o)),d.length===p&&e.addRange(d,n.getSemanticDiagnostics(void 0,o))));var m=u?{emitSkipped:!0,diagnostics:e.emptyArray}:n.emit(void 0,i,o,s,c),_=m.emittedFiles,g=m.diagnostics;e.addRange(d,g);var y=e.sortAndDeduplicateDiagnostics(d);if(y.forEach(t),r){var h=n.getCurrentDirectory();e.forEach(_,(function(n){var t=e.getNormalizedAbsolutePath(n,h);r("TSFILE: "+t)})),f(n,r)}return a&&a(l(y)),{emitResult:m,diagnostics:y}}function E(n,t,r,a,i,o,s,c){var l=b(n,t,r,a,i,o,s,c),u=l.emitResult,d=l.diagnostics;return u.emitSkipped&&d.length>0?e.ExitStatus.DiagnosticsPresent_OutputsSkipped:d.length>0?e.ExitStatus.DiagnosticsPresent_OutputsGenerated:e.ExitStatus.Success}function T(n,t){void 0===n&&(n=e.sys);var r=t||s(n);return{onWatchStatusChange:r,watchFile:e.maybeBind(n,n.watchFile)||e.returnNoopFileWatcher,watchDirectory:e.maybeBind(n,n.watchDirectory)||e.returnNoopFileWatcher,setTimeout:e.maybeBind(n,n.setTimeout)||e.noop,clearTimeout:e.maybeBind(n,n.clearTimeout)||e.noop}}function S(n,t){var r=n.trace?t.extendedDiagnostics?e.WatchLogLevel.Verbose:t.diagnostics?e.WatchLogLevel.TriggerOnly:e.WatchLogLevel.None:e.WatchLogLevel.None,a=r!==e.WatchLogLevel.None?function(e){return n.trace(e)}:e.noop,i=e.getWatchFactory(n,r,a);return i.writeLog=a,i}function x(n,t,r){void 0===r&&(r=n);var a=n.useCaseSensitiveFileNames(),i=e.memoize((function(){return n.getNewLine()}));return{getSourceFile:function(r,a,i){var o;try{e.performance.mark("beforeIORead"),o=n.readFile(r,t().charset),e.performance.mark("afterIORead"),e.performance.measure("I/O Read","beforeIORead","afterIORead")}catch(s){i&&i(s.message),o=""}return void 0!==o?e.createSourceFile(r,o,a):void 0},getDefaultLibLocation:e.maybeBind(n,n.getDefaultLibLocation),getDefaultLibFileName:function(e){return n.getDefaultLibFileName(e)},writeFile:o,getCurrentDirectory:e.memoize((function(){return n.getCurrentDirectory()})),useCaseSensitiveFileNames:function(){return a},getCanonicalFileName:e.createGetCanonicalFileName(a),getNewLine:function(){return e.getNewLineCharacter(t(),i)},fileExists:function(e){return n.fileExists(e)},readFile:function(e){return n.readFile(e)},trace:e.maybeBind(n,n.trace),directoryExists:e.maybeBind(r,r.directoryExists),getDirectories:e.maybeBind(r,r.getDirectories),realpath:e.maybeBind(n,n.realpath),getEnvironmentVariable:e.maybeBind(n,n.getEnvironmentVariable)||function(){return""},createHash:e.maybeBind(n,n.createHash),readDirectory:e.maybeBind(n,n.readDirectory),disableUseFileVersionAsSignature:n.disableUseFileVersionAsSignature};function o(t,r,a,i){try{e.performance.mark("beforeIOWrite"),e.writeFileEnsuringDirectories(t,r,a,(function(e,t,r){return n.writeFile(e,t,r)}),(function(e){return n.createDirectory(e)}),(function(e){return n.directoryExists(e)})),e.performance.mark("afterIOWrite"),e.performance.measure("I/O Write","beforeIOWrite","afterIOWrite")}catch(o){i&&i(o.message)}}}function L(n,t){var r=n.getSourceFile,a=e.maybeBind(t,t.createHash)||e.generateDjb2Hash;n.getSourceFile=function(){for(var e=[],t=0;t<arguments.length;t++)e[t]=arguments[t];var o=r.call.apply(r,i([n],e));return o&&(o.version=a(o.text)),o}}function D(n,t){var r=e.memoize((function(){return e.getDirectoryPath(e.normalizePath(n.getExecutingFilePath()))}));return{useCaseSensitiveFileNames:function(){return n.useCaseSensitiveFileNames},getNewLine:function(){return n.newLine},getCurrentDirectory:e.memoize((function(){return n.getCurrentDirectory()})),getDefaultLibLocation:r,getDefaultLibFileName:function(n){return e.combinePaths(r(),e.getDefaultLibFileName(n))},fileExists:function(e){return n.fileExists(e)},readFile:function(e,t){return n.readFile(e,t)},directoryExists:function(e){return n.directoryExists(e)},getDirectories:function(e){return n.getDirectories(e)},readDirectory:function(e,t,r,a,i){return n.readDirectory(e,t,r,a,i)},realpath:e.maybeBind(n,n.realpath),getEnvironmentVariable:e.maybeBind(n,n.getEnvironmentVariable),trace:function(e){return n.write(e+n.newLine)},createDirectory:function(e){return n.createDirectory(e)},writeFile:function(e,t,r){return n.writeFile(e,t,r)},createHash:e.maybeBind(n,n.createHash),createProgram:t||e.createEmitAndSemanticDiagnosticsBuilderProgram,disableUseFileVersionAsSignature:n.disableUseFileVersionAsSignature}}function A(n,t,r,a){void 0===n&&(n=e.sys);var i=function(e){return n.write(e+n.newLine)},o=D(n,t);return e.copyProperties(o,T(n,a)),o.afterProgramCreate=function(t){var a=t.getCompilerOptions(),s=e.getNewLineCharacter(a,(function(){return n.newLine}));b(t,r,i,(function(n){return o.onWatchStatusChange(e.createCompilerDiagnostic(u(n),n),s,a,n)}))},o}function C(n,t,r){t(r),n.exit(e.ExitStatus.DiagnosticsPresent_OutputsSkipped)}function I(e){var n=e.configFileName,r=e.optionsToExtend,a=e.watchOptionsToExtend,i=e.extraFileExtensions,o=e.system,s=e.createProgram,c=e.reportDiagnostic,l=e.reportWatchStatus,u=c||t(o),d=A(o,s,u,l);return d.onUnRecoverableConfigFileDiagnostic=function(e){return C(o,u,e)},d.configFileName=n,d.optionsToExtend=r,d.watchOptionsToExtend=a,d.extraFileExtensions=i,d}function N(e){var n=e.rootFiles,r=e.options,a=e.watchOptions,i=e.projectReferences,o=e.system,s=e.createProgram,c=e.reportDiagnostic,l=e.reportWatchStatus,u=A(o,s,c||t(o),l);return u.rootFiles=n,u.options=r,u.watchOptions=a,u.projectReferences=i,u}function k(n){var r=n.system||e.sys,a=n.host||(n.host=e.createIncrementalCompilerHost(n.options,r)),i=e.createIncrementalProgram(n),o=E(i,n.reportDiagnostic||t(r),(function(e){return a.trace&&a.trace(e)}),n.reportErrorSummary||n.options.pretty?function(e){return r.write(d(e,r.newLine))}:void 0);return n.afterProgramEmitAndDiagnostics&&n.afterProgramEmitAndDiagnostics(i),o}e.createDiagnosticReporter=t,e.screenStartingMessageCodes=[e.Diagnostics.Starting_compilation_in_watch_mode.code,e.Diagnostics.File_change_detected_Starting_incremental_compilation.code],e.getLocaleTimeString=o,e.createWatchStatusReporter=s,e.parseConfigFileWithSystem=c,e.getErrorCountForSummary=l,e.getWatchErrorSummaryDiagnosticMessage=u,e.getErrorSummaryText=d,e.isBuilderProgram=p,e.listFiles=f,e.explainFiles=m,e.explainIfFileIsRedirect=_,e.getMatchedFileSpec=g,e.getMatchedIncludeSpec=y,e.fileIncludeReasonToDiagnostics=h,e.emitFilesAndReportErrors=b,e.emitFilesAndReportErrorsAndGetExitStatus=E,e.noopFileWatcher={close:e.noop},e.returnNoopFileWatcher=function(){return e.noopFileWatcher},e.createWatchHost=T,e.WatchType={ConfigFile:"Config file",ExtendedConfigFile:"Extended config file",SourceFile:"Source file",MissingFile:"Missing file",WildcardDirectory:"Wild card directory",FailedLookupLocations:"Failed Lookup Locations",TypeRoots:"Type roots",ConfigFileOfReferencedProject:"Config file of referened project",ExtendedConfigOfReferencedProject:"Extended config file of referenced project",WildcardDirectoryOfReferencedProject:"Wild card directory of referenced project"},e.createWatchFactory=S,e.createCompilerHostFromProgramHost=x,e.setGetSourceFileAsHashVersioned=L,e.createProgramHost=D,e.createWatchCompilerHostOfConfigFile=I,e.createWatchCompilerHostOfFilesAndCompilerOptions=N,e.performIncrementalCompilation=k}(d||(d={})),function(e){function n(n,t){if(!e.outFile(n)){var r=e.getTsBuildInfoEmitOutputFilePath(n);if(r){var a=t.readFile(r);if(a){var i=e.getBuildInfo(a);if(i.version===e.version&&i.program)return e.createBuildProgramUsingProgramBuildInfo(i.program,r,t)}}}}function t(n,t){void 0===t&&(t=e.sys);var r=e.createCompilerHostWorker(n,void 0,t);return r.createHash=e.maybeBind(t,t.createHash),r.disableUseFileVersionAsSignature=t.disableUseFileVersionAsSignature,e.setGetSourceFileAsHashVersioned(r,t),e.changeCompilerHostLikeToUseCache(r,(function(n){return e.toPath(n,r.getCurrentDirectory(),r.getCanonicalFileName)})),r}function r(r){var a=r.rootNames,i=r.options,o=r.configFileParsingDiagnostics,s=r.projectReferences,c=r.host,l=r.createProgram;c=c||t(i),l=l||e.createEmitAndSemanticDiagnosticsBuilderProgram;var u=n(i,c);return l(a,i,c,u,o,s)}function a(n,t,r,a,i,o,s,c){return e.isArray(n)?e.createWatchCompilerHostOfFilesAndCompilerOptions({rootFiles:n,options:t,watchOptions:c,projectReferences:s,system:r,createProgram:a,reportDiagnostic:i,reportWatchStatus:o}):e.createWatchCompilerHostOfConfigFile({configFileName:n,optionsToExtend:t,watchOptionsToExtend:s,extraFileExtensions:c,system:r,createProgram:a,reportDiagnostic:i,reportWatchStatus:o})}function s(t){var r,a,s,c,l,u,d,p,f,m,_,g=t.extendedConfigCache,y=new e.Map,h=!1,v=t.useCaseSensitiveFileNames(),b=t.getCurrentDirectory(),E=t.configFileName,T=t.optionsToExtend,S=void 0===T?{}:T,x=t.watchOptionsToExtend,L=t.extraFileExtensions,D=t.createProgram,A=t.rootFiles,C=t.options,I=t.watchOptions,N=t.projectReferences,k=!1,R=!1,O=void 0===E?void 0:e.createCachedDirectoryStructureHost(t,b,v),w=O||t,P=e.parseConfigHostFromCompilerHostLike(t,w),M=$();E&&t.configFileParsingResult&&(be(t.configFileParsingResult),M=$()),ce(e.Diagnostics.Starting_compilation_in_watch_mode),E&&!t.configFileParsingResult&&(M=e.getNewLineCharacter(S,(function(){return t.getNewLine()})),e.Debug.assert(!A),ve(),M=$());var F,G=e.createWatchFactory(t,C),B=G.watchFile,U=G.watchDirectory,V=G.writeLog,j=e.createGetCanonicalFileName(v);V("Current directory: "+b+" CaseSensitiveFileNames: "+v),E&&(F=B(E,me,e.PollingInterval.High,I,e.WatchType.ConfigFile));var K=e.createCompilerHostFromProgramHost(t,(function(){return C}),w);e.setGetSourceFileAsHashVersioned(K,t);var H=K.getSourceFile;K.getSourceFile=function(e){for(var n=[],t=1;t<arguments.length;t++)n[t-1]=arguments[t];return ae.apply(void 0,i([e,ee(e)],n))},K.getSourceFileByPath=ae,K.getNewLine=function(){return M},K.fileExists=re,K.onReleaseOldSourceFile=se,K.onReleaseParsedCommandLine=Se,K.toPath=ee,K.getCompilationSettings=function(){return C},K.useSourceOfProjectReferenceRedirect=e.maybeBind(t,t.useSourceOfProjectReferenceRedirect),K.watchDirectoryOfFailedLookupLocation=function(n,t,r){return U(n,t,r,I,e.WatchType.FailedLookupLocations)},K.watchTypeRootsDirectory=function(n,t,r){return U(n,t,r,I,e.WatchType.TypeRoots)},K.getCachedDirectoryStructureHost=function(){return O},K.scheduleInvalidateResolutionsOfFailedLookupLocations=de,K.onInvalidatedResolution=fe,K.onChangedAutomaticTypeDirectiveNames=fe,K.fileIsOpen=e.returnFalse,K.getCurrentProgram=X,K.writeLog=V,K.getParsedCommandLine=Ee;var W=e.createResolutionCache(K,E?e.getDirectoryPath(e.getNormalizedAbsolutePath(E,b)):b,!1);K.resolveModuleNames=t.resolveModuleNames?function(){for(var e=[],n=0;n<arguments.length;n++)e[n]=arguments[n];return t.resolveModuleNames.apply(t,e)}:function(e,n,t,r){return W.resolveModuleNames(e,n,t,r)},K.resolveTypeReferenceDirectives=t.resolveTypeReferenceDirectives?function(){for(var e=[],n=0;n<arguments.length;n++)e[n]=arguments[n];return t.resolveTypeReferenceDirectives.apply(t,e)}:function(e,n,t){return W.resolveTypeReferenceDirectives(e,n,t)};var z=!!t.resolveModuleNames||!!t.resolveTypeReferenceDirectives;return r=n(C,K),Y(),Ie(),E&&ke(ee(E),C,I,e.WatchType.ExtendedConfigFile),E?{getCurrentProgram:J,getProgram:ge,close:q}:{getCurrentProgram:J,getProgram:ge,updateRootFileNames:Z,close:q};function q(){ue(),W.clear(),e.clearMap(y,(function(e){e&&e.fileWatcher&&(e.fileWatcher.close(),e.fileWatcher=void 0)})),F&&(F.close(),F=void 0),null===g||void 0===g||g.clear(),g=void 0,p&&(e.clearMap(p,e.closeFileWatcherOf),p=void 0),c&&(e.clearMap(c,e.closeFileWatcherOf),c=void 0),s&&(e.clearMap(s,e.closeFileWatcher),s=void 0),d&&(e.clearMap(d,(function(n){var t;null===(t=n.watcher)||void 0===t||t.close(),n.watcher=void 0,n.watchedDirectories&&e.clearMap(n.watchedDirectories,e.closeFileWatcherOf),n.watchedDirectories=void 0})),d=void 0)}function J(){return r}function X(){return r&&r.getProgramOrUndefined()}function Y(){V("Synchronizing program"),ue();var n=J();h&&(M=$(),n&&e.changesAffectModuleResolution(n.getCompilerOptions(),C)&&W.clear());var a=W.createHasInvalidatedResolution(z);return e.isProgramUptoDate(X(),A,C,oe,re,a,le,Ee,N)?R&&(r=D(void 0,void 0,K,r,_,N),R=!1):Q(a),t.afterProgramCreate&&n!==r&&t.afterProgramCreate(r),r}function Q(n){V("CreatingProgramWith::"),V("  roots: "+JSON.stringify(A)),V("  options: "+JSON.stringify(C)),N&&V("  projectReferences: "+JSON.stringify(N));var t=h||!X();if(h=!1,R=!1,W.startCachingPerDirectoryResolution(),K.hasInvalidatedResolution=n,K.hasChangedAutomaticTypeDirectiveNames=le,r=D(A,C,K,r,_,N),W.finishCachingPerDirectoryResolution(),e.updateMissingFilePathsWatch(r.getProgram(),s||(s=new e.Map),Ae),t&&W.updateTypeRootsWatch(),f){for(var a=0,i=f;a<i.length;a++){var o=i[a];s.has(o)||y.delete(o)}f=void 0}}function Z(n){e.Debug.assert(!E,"Cannot update root file names with config file watch mode"),A=n,fe()}function $(){return e.getNewLineCharacter(C||S,(function(){return t.getNewLine()}))}function ee(n){return e.toPath(n,b,j)}function ne(e){return"boolean"===typeof e}function te(e){return"boolean"===typeof e.version}function re(e){var n=ee(e);return!ne(y.get(n))&&w.fileExists(e)}function ae(n,t,r,a,i){var o=y.get(t);if(!ne(o)){if(void 0===o||i||te(o)){var s=H(n,r,a);if(o)s?(o.sourceFile=s,o.version=s.version,o.fileWatcher||(o.fileWatcher=xe(t,n,Le,e.PollingInterval.Low,I,e.WatchType.SourceFile))):(o.fileWatcher&&o.fileWatcher.close(),y.set(t,!1));else if(s){var c=xe(t,n,Le,e.PollingInterval.Low,I,e.WatchType.SourceFile);y.set(t,{sourceFile:s,version:s.version,fileWatcher:c})}else y.set(t,!1);return s}return o.sourceFile}}function ie(e){var n=y.get(e);void 0!==n&&(ne(n)?y.set(e,{version:!1}):n.version=!1)}function oe(e){var n=y.get(e);return n&&n.version?n.version:void 0}function se(e,n,t){var r=y.get(e.resolvedPath);void 0!==r&&(ne(r)?(f||(f=[])).push(e.path):r.sourceFile===e&&(r.fileWatcher&&r.fileWatcher.close(),y.delete(e.resolvedPath),t||W.removeResolutionsOfFile(e.path)))}function ce(n){t.onWatchStatusChange&&t.onWatchStatusChange(e.createCompilerDiagnostic(n),M,C||S)}function le(){return W.hasChangedAutomaticTypeDirectiveNames()}function ue(){return!!u&&(t.clearTimeout(u),u=void 0,!0)}function de(){if(!t.setTimeout||!t.clearTimeout)return W.invalidateResolutionsOfFailedLookupLocations();var e=ue();V("Scheduling invalidateFailedLookup"+(e?", Cancelled earlier one":"")),u=t.setTimeout(pe,250)}function pe(){u=void 0,W.invalidateResolutionsOfFailedLookupLocations()&&fe()}function fe(){t.setTimeout&&t.clearTimeout&&(l&&t.clearTimeout(l),V("Scheduling update"),l=t.setTimeout(_e,250))}function me(){e.Debug.assert(!!E),a=e.ConfigFileProgramReloadLevel.Full,fe()}function _e(){l=void 0,ce(e.Diagnostics.File_change_detected_Starting_incremental_compilation),ge()}function ge(){switch(a){case e.ConfigFileProgramReloadLevel.Partial:e.perfLogger.logStartUpdateProgram("PartialConfigReload"),ye();break;case e.ConfigFileProgramReloadLevel.Full:e.perfLogger.logStartUpdateProgram("FullConfigReload"),he();break;default:e.perfLogger.logStartUpdateProgram("SynchronizeProgram"),Y();break}return e.perfLogger.logStopUpdateProgram("Done"),J()}function ye(){V("Reloading new file names and options"),A=e.getFileNamesFromConfigSpecs(C.configFile.configFileSpecs,e.getNormalizedAbsolutePath(e.getDirectoryPath(E),b),C,P,L),e.updateErrorForNoInputFiles(A,e.getNormalizedAbsolutePath(E,b),C.configFile.configFileSpecs,_,k)&&(R=!0),Y()}function he(){V("Reloading config file: "+E),a=e.ConfigFileProgramReloadLevel.None,O&&O.clearCache(),ve(),h=!0,Y(),Ie(),ke(ee(E),C,I,e.WatchType.ExtendedConfigFile)}function ve(){be(e.getParsedCommandLineOfConfigFile(E,S,P,g||(g=new e.Map),x,L))}function be(n){A=n.fileNames,C=n.options,I=n.watchOptions,N=n.projectReferences,m=n.wildcardDirectories,_=e.getConfigFileParsingDiagnostics(n).slice(),k=e.canJsonReportNoInputFiles(n.raw),R=!0}function Ee(n){var r=ee(n),a=null===d||void 0===d?void 0:d.get(r);if(a){if(!a.reloadLevel)return a.parsedCommandLine;if(a.parsedCommandLine&&a.reloadLevel===e.ConfigFileProgramReloadLevel.Partial&&!t.getParsedCommandLine){V("Reloading new file names and options");var i=e.getFileNamesFromConfigSpecs(a.parsedCommandLine.options.configFile.configFileSpecs,e.getNormalizedAbsolutePath(e.getDirectoryPath(n),b),C,P);return a.parsedCommandLine=o(o({},a.parsedCommandLine),{fileNames:i}),a.reloadLevel=void 0,a.parsedCommandLine}}V("Loading config file: "+n);var s=t.getParsedCommandLine?t.getParsedCommandLine(n):Te(n);return a?(a.parsedCommandLine=s,a.reloadLevel=void 0):(d||(d=new e.Map)).set(r,a={parsedCommandLine:s}),Re(n,r,a),s}function Te(n){var t=P.onUnRecoverableConfigFileDiagnostic;P.onUnRecoverableConfigFileDiagnostic=e.noop;var r=e.getParsedCommandLineOfConfigFile(n,void 0,P,g||(g=new e.Map),x);return P.onUnRecoverableConfigFileDiagnostic=t,r}function Se(n){var t,r=ee(n),a=null===d||void 0===d?void 0:d.get(r);a&&(d.delete(r),a.watchedDirectories&&e.clearMap(a.watchedDirectories,e.closeFileWatcherOf),null===(t=a.watcher)||void 0===t||t.close(),e.clearSharedExtendedConfigFileWatcher(r,p))}function xe(e,n,t,r,a,i){return B(n,(function(n,r){return t(n,r,e)}),r,a,i)}function Le(n,t,r){De(n,r,t),t===e.FileWatcherEventKind.Deleted&&y.has(r)&&W.invalidateResolutionOfFile(r),ie(r),fe()}function De(e,n,t){O&&O.addOrDeleteFile(e,n,t)}function Ae(n){return(null===d||void 0===d?void 0:d.has(n))?e.noopFileWatcher:xe(n,n,Ce,e.PollingInterval.Medium,I,e.WatchType.MissingFile)}function Ce(n,t,r){De(n,r,t),t===e.FileWatcherEventKind.Created&&s.has(r)&&(s.get(r).close(),s.delete(r),ie(r),fe())}function Ie(){m?e.updateWatchingWildcardDirectories(c||(c=new e.Map),new e.Map(e.getEntries(m)),Ne):c&&e.clearMap(c,e.closeFileWatcherOf)}function Ne(n,t){return U(n,(function(t){e.Debug.assert(!!E);var r=ee(t);O&&O.addOrDeleteFileOrDirectory(t,r),ie(r),e.isIgnoredFileFromWildCardWatching({watchedDirPath:ee(n),fileOrDirectory:t,fileOrDirectoryPath:r,configFileName:E,extraFileExtensions:L,options:C,program:J()||A,currentDirectory:b,useCaseSensitiveFileNames:v,writeLog:V,toPath:ee})||a!==e.ConfigFileProgramReloadLevel.Full&&(a=e.ConfigFileProgramReloadLevel.Partial,fe())}),t,I,e.WatchType.WildcardDirectory)}function ke(n,t,r,i){e.updateSharedExtendedConfigFileWatcher(n,t,p||(p=new e.Map),(function(n,t){return B(n,(function(r,i){var o;De(n,t,i),g&&e.cleanExtendedConfigCache(g,t,ee);var s=null===(o=p.get(t))||void 0===o?void 0:o.projects;(null===s||void 0===s?void 0:s.size)&&s.forEach((function(n){if(ee(E)===n)a=e.ConfigFileProgramReloadLevel.Full;else{var t=null===d||void 0===d?void 0:d.get(n);t&&(t.reloadLevel=e.ConfigFileProgramReloadLevel.Full),W.removeResolutionsFromProjectReferenceRedirects(n)}fe()}))}),e.PollingInterval.High,r,i)}),ee)}function Re(n,t,r){var a,i,o,s,c;r.watcher||(r.watcher=B(n,(function(r,a){De(n,t,a);var i=null===d||void 0===d?void 0:d.get(t);i&&(i.reloadLevel=e.ConfigFileProgramReloadLevel.Full),W.removeResolutionsFromProjectReferenceRedirects(t),fe()}),e.PollingInterval.High,(null===(a=r.parsedCommandLine)||void 0===a?void 0:a.watchOptions)||I,e.WatchType.ConfigFileOfReferencedProject)),(null===(i=r.parsedCommandLine)||void 0===i?void 0:i.wildcardDirectories)?e.updateWatchingWildcardDirectories(r.watchedDirectories||(r.watchedDirectories=new e.Map),new e.Map(e.getEntries(null===(o=r.parsedCommandLine)||void 0===o?void 0:o.wildcardDirectories)),(function(a,i){var o;return U(a,(function(r){var i=ee(r);O&&O.addOrDeleteFileOrDirectory(r,i),ie(i);var o=null===d||void 0===d?void 0:d.get(t);(null===o||void 0===o?void 0:o.parsedCommandLine)&&(e.isIgnoredFileFromWildCardWatching({watchedDirPath:ee(a),fileOrDirectory:r,fileOrDirectoryPath:i,configFileName:n,options:o.parsedCommandLine.options,program:o.parsedCommandLine.fileNames,currentDirectory:b,useCaseSensitiveFileNames:v,writeLog:V,toPath:ee})||o.reloadLevel!==e.ConfigFileProgramReloadLevel.Full&&(o.reloadLevel=e.ConfigFileProgramReloadLevel.Partial,fe()))}),i,(null===(o=r.parsedCommandLine)||void 0===o?void 0:o.watchOptions)||I,e.WatchType.WildcardDirectoryOfReferencedProject)})):r.watchedDirectories&&(e.clearMap(r.watchedDirectories,e.closeFileWatcherOf),r.watchedDirectories=void 0),ke(t,null===(s=r.parsedCommandLine)||void 0===s?void 0:s.options,(null===(c=r.parsedCommandLine)||void 0===c?void 0:c.watchOptions)||I,e.WatchType.ExtendedConfigOfReferencedProject)}}e.readBuilderProgram=n,e.createIncrementalCompilerHost=t,e.createIncrementalProgram=r,e.createWatchCompilerHost=a,e.createWatchProgram=s}(d||(d={})),function(e){function n(n){return e.fileExtensionIs(n,".json")?n:e.combinePaths(n,"tsconfig.json")}(function(e){e[e["Unbuildable"]=0]="Unbuildable",e[e["UpToDate"]=1]="UpToDate",e[e["UpToDateWithUpstreamTypes"]=2]="UpToDateWithUpstreamTypes",e[e["OutOfDateWithPrepend"]=3]="OutOfDateWithPrepend",e[e["OutputMissing"]=4]="OutputMissing",e[e["OutOfDateWithSelf"]=5]="OutOfDateWithSelf",e[e["OutOfDateWithUpstream"]=6]="OutOfDateWithUpstream",e[e["UpstreamOutOfDate"]=7]="UpstreamOutOfDate",e[e["UpstreamBlocked"]=8]="UpstreamBlocked",e[e["ComputingUpstream"]=9]="ComputingUpstream",e[e["TsVersionOutputOfDate"]=10]="TsVersionOutputOfDate",e[e["ContainerOnly"]=11]="ContainerOnly"})(e.UpToDateStatusType||(e.UpToDateStatusType={})),e.resolveConfigFileProjectName=n}(d||(d={})),function(e){var n,t,r,a=new Date(-864e13),o=new Date(864e13);function s(e,n,t){var r,a=e.get(n);return a||(r=t(),e.set(n,r)),a||r}function c(n,t){return s(n,t,(function(){return new e.Map}))}function l(e,n){return n>e?n:e}function u(n){return e.fileExtensionIs(n,".d.ts")}function d(e){return!!e&&!!e.buildOrder}function p(e){return d(e)?e.buildOrder:e}function f(n,t){return function(r){var a=t?"["+e.formatColorAndReset(e.getLocaleTimeString(n),e.ForegroundColorEscapeSequences.Grey)+"] ":e.getLocaleTimeString(n)+" - ";a+=""+e.flattenDiagnosticMessageText(r.messageText,n.newLine)+(n.newLine+n.newLine),n.write(a)}}function m(n,t,r,a){var i=e.createProgramHost(n,t);return i.getModifiedTime=n.getModifiedTime?function(e){return n.getModifiedTime(e)}:e.returnUndefined,i.setModifiedTime=n.setModifiedTime?function(e,t){return n.setModifiedTime(e,t)}:e.noop,i.deleteFile=n.deleteFile?function(e){return n.deleteFile(e)}:e.noop,i.reportDiagnostic=r||e.createDiagnosticReporter(n),i.reportSolutionBuilderStatus=a||f(n),i.now=e.maybeBind(n,n.now),i}function _(n,t,r,a,i){void 0===n&&(n=e.sys);var o=m(n,t,r,a);return o.reportErrorSummary=i,o}function g(n,t,r,a,i){void 0===n&&(n=e.sys);var o=m(n,t,r,a),s=e.createWatchHost(n,i);return e.copyProperties(o,s),o}function y(n){var t={};return e.commonOptionsWithBuild.forEach((function(r){e.hasProperty(n,r.name)&&(t[r.name]=n[r.name])})),t}function h(e,n,t){return le(!1,e,n,t)}function v(e,n,t,r){return le(!0,e,n,t,r)}function b(n,t,r,a,i){var o=t,s=t,c=o.getCurrentDirectory(),l=e.createGetCanonicalFileName(o.useCaseSensitiveFileNames()),u=y(a),d=e.createCompilerHostFromProgramHost(o,(function(){return E.projectCompilerOptions}));e.setGetSourceFileAsHashVersioned(d,o),d.getParsedCommandLine=function(e){return L(E,e,T(E,e))},d.resolveModuleNames=e.maybeBind(o,o.resolveModuleNames),d.resolveTypeReferenceDirectives=e.maybeBind(o,o.resolveTypeReferenceDirectives);var p=d.resolveModuleNames?void 0:e.createModuleResolutionCache(c,l),f=d.resolveTypeReferenceDirectives?void 0:e.createTypeReferenceDirectiveResolutionCache(c,l,void 0,null===p||void 0===p?void 0:p.getPackageJsonInfoCache());if(!d.resolveModuleNames){var m=function(n,t,r){return e.resolveModuleName(n,t,E.projectCompilerOptions,d,p,r).resolvedModule};d.resolveModuleNames=function(n,t,r,a){return e.loadWithLocalCache(e.Debug.checkEachDefined(n),t,a,m)}}if(!d.resolveTypeReferenceDirectives){var _=function(n,t,r){return e.resolveTypeReferenceDirective(n,t,E.projectCompilerOptions,d,r,E.typeReferenceDirectiveResolutionCache).resolvedTypeReferenceDirective};d.resolveTypeReferenceDirectives=function(n,t,r){return e.loadWithLocalCache(e.Debug.checkEachDefined(n),t,r,_)}}var g=e.createWatchFactory(s,a),h=g.watchFile,v=g.watchDirectory,b=g.writeLog,E={host:o,hostWithWatch:s,currentDirectory:c,getCanonicalFileName:l,parseConfigFileHost:e.parseConfigHostFromCompilerHostLike(o),write:e.maybeBind(o,o.trace),options:a,baseCompilerOptions:u,rootNames:r,baseWatchOptions:i,resolvedConfigFilePaths:new e.Map,configFileCache:new e.Map,projectStatus:new e.Map,buildInfoChecked:new e.Map,extendedConfigCache:new e.Map,builderPrograms:new e.Map,diagnostics:new e.Map,projectPendingBuild:new e.Map,projectErrorsReported:new e.Map,compilerHost:d,moduleResolutionCache:p,typeReferenceDirectiveResolutionCache:f,buildOrder:void 0,readFileWithCache:function(e){return o.readFile(e)},projectCompilerOptions:u,cache:void 0,allProjectBuildPending:!0,needsSummary:!0,watchAllProjectsPending:n,currentInvalidatedProject:void 0,watch:n,allWatchedWildcardDirectories:new e.Map,allWatchedInputFiles:new e.Map,allWatchedConfigFiles:new e.Map,allWatchedExtendedConfigFiles:new e.Map,timerToBuildInvalidatedProject:void 0,reportFileChangeDetected:!1,watchFile:h,watchDirectory:v,writeLog:b};return E}function E(n,t){return e.toPath(t,n.currentDirectory,n.getCanonicalFileName)}function T(e,n){var t=e.resolvedConfigFilePaths,r=t.get(n);if(void 0!==r)return r;var a=E(e,n);return t.set(n,a),a}function S(e){return!!e.options}function x(e,n){var t=e.configFileCache.get(n);return t&&S(t)?t:void 0}function L(n,t,r){var a,i=n.configFileCache,o=i.get(r);if(o)return S(o)?o:void 0;var s,c=n.parseConfigFileHost,l=n.baseCompilerOptions,u=n.baseWatchOptions,d=n.extendedConfigCache,p=n.host;return p.getParsedCommandLine?(s=p.getParsedCommandLine(t),s||(a=e.createCompilerDiagnostic(e.Diagnostics.File_0_not_found,t))):(c.onUnRecoverableConfigFileDiagnostic=function(e){return a=e},s=e.getParsedCommandLineOfConfigFile(t,l,c,d,u),c.onUnRecoverableConfigFileDiagnostic=e.noop),i.set(r,s||a),s}function D(n,t){return e.resolveConfigFileProjectName(e.resolvePath(n.currentDirectory,t))}function A(n,t){for(var r,a,i=new e.Map,o=new e.Map,s=[],c=0,l=t;c<l.length;c++){var u=l[c];d(u)}return a?{buildOrder:r||e.emptyArray,circularDiagnostics:a}:r||e.emptyArray;function d(t,c){var l=T(n,t);if(!o.has(l))if(i.has(l))c||(a||(a=[])).push(e.createCompilerDiagnostic(e.Diagnostics.Project_references_may_not_form_a_circular_graph_Cycle_detected_Colon_0,s.join("\r\n")));else{i.set(l,!0),s.push(t);var u=L(n,t,l);if(u&&u.projectReferences)for(var p=0,f=u.projectReferences;p<f.length;p++){var m=f[p],_=D(n,m.path);d(_,c||m.circular)}s.pop(),o.set(l,!0),(r||(r=[])).push(t)}}}function C(e){return e.buildOrder||I(e)}function I(n){var t=A(n,n.rootNames.map((function(e){return D(n,e)})));n.resolvedConfigFilePaths.clear();var r=new e.Map(p(t).map((function(e){return[T(n,e),!0]}))),a={onDeleteValue:e.noop};return e.mutateMapSkippingNewValues(n.configFileCache,r,a),e.mutateMapSkippingNewValues(n.projectStatus,r,a),e.mutateMapSkippingNewValues(n.buildInfoChecked,r,a),e.mutateMapSkippingNewValues(n.builderPrograms,r,a),e.mutateMapSkippingNewValues(n.diagnostics,r,a),e.mutateMapSkippingNewValues(n.projectPendingBuild,r,a),e.mutateMapSkippingNewValues(n.projectErrorsReported,r,a),n.watch&&(e.mutateMapSkippingNewValues(n.allWatchedConfigFiles,r,{onDeleteValue:e.closeFileWatcher}),n.allWatchedExtendedConfigFiles.forEach((function(e){e.projects.forEach((function(n){r.has(n)||e.projects.delete(n)})),e.close()})),e.mutateMapSkippingNewValues(n.allWatchedWildcardDirectories,r,{onDeleteValue:function(n){return n.forEach(e.closeFileWatcherOf)}}),e.mutateMapSkippingNewValues(n.allWatchedInputFiles,r,{onDeleteValue:function(n){return n.forEach(e.closeFileWatcher)}})),n.buildOrder=t}function N(n,t,r){var a=t&&D(n,t),i=C(n);if(d(i))return i;if(a){var o=T(n,a),s=e.findIndex(i,(function(e){return T(n,e)===o}));if(-1===s)return}var c=a?A(n,[a]):i;return e.Debug.assert(!d(c)),e.Debug.assert(!r||void 0!==a),e.Debug.assert(!r||c[c.length-1]===a),r?c.slice(0,c.length-1):c}function k(n){n.cache&&R(n);var t=n.compilerHost,r=n.host,a=n.readFileWithCache,o=t.getSourceFile,s=e.changeCompilerHostLikeToUseCache(r,(function(e){return E(n,e)}),(function(){for(var e=[],n=0;n<arguments.length;n++)e[n]=arguments[n];return o.call.apply(o,i([t],e))})),c=s.originalReadFile,l=s.originalFileExists,u=s.originalDirectoryExists,d=s.originalCreateDirectory,p=s.originalWriteFile,f=s.getSourceFileWithCache,m=s.readFileWithCache;n.readFileWithCache=m,t.getSourceFile=f,n.cache={originalReadFile:c,originalFileExists:l,originalDirectoryExists:u,originalCreateDirectory:d,originalWriteFile:p,originalReadFileWithCache:a,originalGetSourceFile:o}}function R(e){if(e.cache){var n=e.cache,t=e.host,r=e.compilerHost,a=e.extendedConfigCache,i=e.moduleResolutionCache,o=e.typeReferenceDirectiveResolutionCache;t.readFile=n.originalReadFile,t.fileExists=n.originalFileExists,t.directoryExists=n.originalDirectoryExists,t.createDirectory=n.originalCreateDirectory,t.writeFile=n.originalWriteFile,r.getSourceFile=n.originalGetSourceFile,e.readFileWithCache=n.originalReadFileWithCache,a.clear(),null===i||void 0===i||i.clear(),null===o||void 0===o||o.clear(),e.cache=void 0}}function O(e,n){e.projectStatus.delete(n),e.diagnostics.delete(n)}function w(e,n,t){var r=e.projectPendingBuild,a=r.get(n);(void 0===a||a<t)&&r.set(n,t)}function P(n,t){if(n.allProjectBuildPending){n.allProjectBuildPending=!1,n.options.watch&&pe(n,e.Diagnostics.Starting_compilation_in_watch_mode),k(n);var r=p(C(n));r.forEach((function(t){return n.projectPendingBuild.set(T(n,t),e.ConfigFileProgramReloadLevel.None)})),t&&t.throwIfCancellationRequested()}}function M(n,t){return n.projectPendingBuild.delete(t),n.currentInvalidatedProject=void 0,n.diagnostics.has(t)?e.ExitStatus.DiagnosticsPresent_OutputsSkipped:e.ExitStatus.Success}function F(e,n,r,a,i){var o=!0;return{kind:t.UpdateOutputFileStamps,project:n,projectPath:r,buildOrder:i,getCompilerOptions:function(){return a.options},getCurrentDirectory:function(){return e.currentDirectory},updateOutputFileStatmps:function(){X(e,a,r),o=!1},done:function(){return o&&X(e,a,r),M(e,r)}}}function G(s,c,d,p,f,m,_){var g,y,h,v=s===t.Build?r.CreateProgram:r.EmitBundle;return s===t.Build?{kind:s,project:d,projectPath:p,buildOrder:_,getCompilerOptions:function(){return m.options},getCurrentDirectory:function(){return c.currentDirectory},getBuilderProgram:function(){return S(e.identity)},getProgram:function(){return S((function(e){return e.getProgramOrUndefined()}))},getSourceFile:function(e){return S((function(n){return n.getSourceFile(e)}))},getSourceFiles:function(){return x((function(e){return e.getSourceFiles()}))},getOptionsDiagnostics:function(e){return x((function(n){return n.getOptionsDiagnostics(e)}))},getGlobalDiagnostics:function(e){return x((function(n){return n.getGlobalDiagnostics(e)}))},getConfigFileParsingDiagnostics:function(){return x((function(e){return e.getConfigFileParsingDiagnostics()}))},getSyntacticDiagnostics:function(e,n){return x((function(t){return t.getSyntacticDiagnostics(e,n)}))},getAllDependencies:function(e){return x((function(n){return n.getAllDependencies(e)}))},getSemanticDiagnostics:function(e,n){return x((function(t){return t.getSemanticDiagnostics(e,n)}))},getSemanticDiagnosticsOfNextAffectedFile:function(e,n){return S((function(t){return t.getSemanticDiagnosticsOfNextAffectedFile&&t.getSemanticDiagnosticsOfNextAffectedFile(e,n)}))},emit:function(e,n,t,a,i){return e||a?S((function(r){return r.emit(e,n,t,a,i)})):(P(r.SemanticDiagnostics,t),v===r.EmitBuildInfo?R(n,t):v===r.Emit?k(n,t,i):void 0)},done:b}:{kind:s,project:d,projectPath:p,buildOrder:_,getCompilerOptions:function(){return m.options},getCurrentDirectory:function(){return c.currentDirectory},emit:function(e,n){return v!==r.EmitBundle?h:w(e,n)},done:b};function b(e,n,t){return P(r.Done,e,n,t),M(c,p)}function S(e){return P(r.CreateProgram),g&&e(g)}function x(n){return S(n)||e.emptyArray}function A(){var t,a;if(e.Debug.assert(void 0===g),c.options.dry)return de(c,e.Diagnostics.A_non_dry_build_would_build_project_0,d),y=n.Success,void(v=r.QueueReferencingProjects);if(c.options.verbose&&de(c,e.Diagnostics.Building_project_0,d),0===m.fileNames.length)return me(c,p,e.getConfigFileParsingDiagnostics(m)),y=n.None,void(v=r.QueueReferencingProjects);var i=c.host,o=c.compilerHost;c.projectCompilerOptions=m.options,null===(t=c.moduleResolutionCache)||void 0===t||t.update(m.options),null===(a=c.typeReferenceDirectiveResolutionCache)||void 0===a||a.update(m.options),g=i.createProgram(m.fileNames,m.options,o,j(c,p,m),e.getConfigFileParsingDiagnostics(m),m.projectReferences),c.watch&&c.builderPrograms.set(p,g),v++}function C(e,n,t){var r;e.length?(r=H(c,p,g,m,e,n,t),y=r.buildResult,v=r.step):v++}function I(t){e.Debug.assertIsDefined(g),C(i(i(i(i([],g.getConfigFileParsingDiagnostics()),g.getOptionsDiagnostics(t)),g.getGlobalDiagnostics(t)),g.getSyntacticDiagnostics(void 0,t)),n.SyntaxErrors,"Syntactic")}function N(t){C(e.Debug.checkDefined(g).getSemanticDiagnostics(void 0,t),n.TypeErrors,"Semantic")}function k(t,i,o){var s,d;e.Debug.assertIsDefined(g),e.Debug.assert(v===r.Emit),g.backupState();var f=function(e){return(d||(d=[])).push(e)},_=[],h=e.emitFilesAndReportErrors(g,f,void 0,void 0,(function(e,n,t){return _.push({name:e,text:n,writeByteOrderMark:t})}),i,!1,o).emitResult;if(d)return g.restoreState(),s=H(c,p,g,m,d,n.DeclarationEmitErrors,"Declaration file"),y=s.buildResult,v=s.step,{emitSkipped:!0,diagnostics:h.diagnostics};var b=c.host,T=c.compilerHost,S=n.DeclarationOutputUnchanged,x=a,L=!1,D=e.createDiagnosticCollection(),A=new e.Map;return _.forEach((function(r){var a,i=r.name,o=r.text,s=r.writeByteOrderMark;!L&&u(i)&&(b.fileExists(i)&&c.readFileWithCache(i)===o?a=b.getModifiedTime(i):(S&=~n.DeclarationOutputUnchanged,L=!0)),A.set(E(c,i),i),e.writeFile(t?{writeFile:t}:T,D,i,o,s),void 0!==a&&(x=l(a,x))})),O(D,A,x,L,_.length?_[0].name:e.getFirstProjectOutput(m,!b.useCaseSensitiveFileNames()),S),h}function R(t,a){e.Debug.assertIsDefined(g),e.Debug.assert(v===r.EmitBuildInfo);var o=g.emitBuildInfo(t,a);return o.diagnostics.length&&(fe(c,o.diagnostics),c.diagnostics.set(p,i(i([],c.diagnostics.get(p)),o.diagnostics)),y=n.EmitErrors&y),o.emittedFiles&&c.write&&o.emittedFiles.forEach((function(e){return V(c,m,e)})),K(c,g,m),v=r.QueueReferencingProjects,o}function O(t,a,i,s,l,u){var d,f=t.getDiagnostics();if(f.length)return d=H(c,p,g,m,f,n.EmitErrors,"Emit"),y=d.buildResult,v=d.step,f;c.write&&a.forEach((function(e){return V(c,m,e)}));var _=J(c,m,i,e.Diagnostics.Updating_unchanged_output_timestamps_of_project_0,a);return c.diagnostics.delete(p),c.projectStatus.set(p,{type:e.UpToDateStatusType.UpToDate,newestDeclarationFileContentChangedTime:s?o:_,oldestOutputFileName:l}),K(c,g,m),v=r.QueueReferencingProjects,y=u,f}function w(i,o){if(e.Debug.assert(s===t.UpdateBundle),c.options.dry)return de(c,e.Diagnostics.A_non_dry_build_would_update_output_of_project_0,d),y=n.Success,void(v=r.QueueReferencingProjects);c.options.verbose&&de(c,e.Diagnostics.Updating_output_of_project_0,d);var l=c.compilerHost;c.projectCompilerOptions=m.options;var u=e.emitUsingBuildInfo(m,l,(function(e){var n=D(c,e.path);return L(c,n,T(c,n))}),o);if(e.isString(u))return de(c,e.Diagnostics.Cannot_update_output_of_project_0_because_there_was_error_reading_file_1,d,ue(c,u)),v=r.BuildInvalidatedProjectOfBundle,h=G(t.Build,c,d,p,f,m,_);e.Debug.assert(!!u.length);var g=e.createDiagnosticCollection(),b=new e.Map;u.forEach((function(n){var t=n.name,r=n.text,a=n.writeByteOrderMark;b.set(E(c,t),t),e.writeFile(i?{writeFile:i}:l,g,t,r,a)}));var S=O(g,b,a,!1,u[0].name,n.DeclarationOutputUnchanged);return{emitSkipped:!1,diagnostics:S}}function P(n,t,a,i){while(v<=n&&v<r.Done){var o=v;switch(v){case r.CreateProgram:A();break;case r.SyntaxDiagnostics:I(t);break;case r.SemanticDiagnostics:N(t);break;case r.Emit:k(a,t,i);break;case r.EmitBuildInfo:R(a,t);break;case r.EmitBundle:w(a,i);break;case r.BuildInvalidatedProjectOfBundle:e.Debug.checkDefined(h).done(t,a,i),v=r.Done;break;case r.QueueReferencingProjects:Y(c,d,p,f,m,_,e.Debug.checkDefined(y)),v++;break;case r.Done:default:e.assertType(v)}e.Debug.assert(v>o)}}}function B(n,t,r){var a=n.options;return!(t.type===e.UpToDateStatusType.OutOfDateWithPrepend&&!a.force)||(0===r.fileNames.length||!!e.getConfigFileParsingDiagnostics(r).length||!e.isIncrementalCompilation(r.options))}function U(n,r,a){if(n.projectPendingBuild.size&&!d(r)){if(n.currentInvalidatedProject)return e.arrayIsEqualTo(n.currentInvalidatedProject.buildOrder,r)?n.currentInvalidatedProject:void 0;for(var i=n.options,o=n.projectPendingBuild,s=0;s<r.length;s++){var c=r[s],l=T(n,c),u=n.projectPendingBuild.get(l);if(void 0!==u){a&&(a=!1,ye(n,r));var p=L(n,c,l);if(p){u===e.ConfigFileProgramReloadLevel.Full?(re(n,c,l,p),ae(n,l,p),ie(n,c,l,p),oe(n,c,l,p)):u===e.ConfigFileProgramReloadLevel.Partial&&(p.fileNames=e.getFileNamesFromConfigSpecs(p.options.configFile.configFileSpecs,e.getDirectoryPath(c),p.options,n.parseConfigFileHost),e.updateErrorForNoInputFiles(p.fileNames,c,p.options.configFile.configFileSpecs,p.errors,e.canJsonReportNoInputFiles(p.raw)),oe(n,c,l,p));var f=q(n,p,l);if(ve(n,c,f),!i.force){if(f.type===e.UpToDateStatusType.UpToDate){me(n,l,e.getConfigFileParsingDiagnostics(p)),o.delete(l),i.dry&&de(n,e.Diagnostics.Project_0_is_up_to_date,c);continue}if(f.type===e.UpToDateStatusType.UpToDateWithUpstreamTypes)return me(n,l,e.getConfigFileParsingDiagnostics(p)),F(n,c,l,p,r)}if(f.type!==e.UpToDateStatusType.UpstreamBlocked){if(f.type!==e.UpToDateStatusType.ContainerOnly)return G(B(n,f,p)?t.Build:t.UpdateBundle,n,c,l,s,p,r);me(n,l,e.getConfigFileParsingDiagnostics(p)),o.delete(l)}else me(n,l,e.getConfigFileParsingDiagnostics(p)),o.delete(l),i.verbose&&de(n,f.upstreamProjectBlocked?e.Diagnostics.Skipping_build_of_project_0_because_its_dependency_1_was_not_built:e.Diagnostics.Skipping_build_of_project_0_because_its_dependency_1_has_errors,c,f.upstreamProjectName)}else _e(n,l),o.delete(l)}}}}function V(e,n,t){var r=e.write;r&&n.options.listEmittedFiles&&r("TSFILE: "+t)}function j(n,t,r){var a=n.options,i=n.builderPrograms,o=n.compilerHost;if(!a.force){var s=i.get(t);return s||e.readBuilderProgram(r.options,o)}}function K(n,t,r){t?(t&&n.write&&e.listFiles(t,n.write),n.host.afterProgramEmitAndDiagnostics&&n.host.afterProgramEmitAndDiagnostics(t),t.releaseProgram()):n.host.afterEmitBundle&&n.host.afterEmitBundle(r),n.projectCompilerOptions=n.baseCompilerOptions}function H(t,a,i,o,s,c,l){var u=!(c&n.SyntaxErrors)&&i&&!e.outFile(i.getCompilerOptions());return me(t,a,s),t.projectStatus.set(a,{type:e.UpToDateStatusType.Unbuildable,reason:l+" errors"}),u?{buildResult:c,step:r.EmitBuildInfo}:(K(t,i,o),{buildResult:c,step:r.QueueReferencingProjects})}function W(n,t,r,a){var i=e.getModifiedTime(n.host,t);if(r<i)return{type:e.UpToDateStatusType.OutOfDateWithSelf,outOfDateOutputFileName:a,newerInputFileName:t}}function z(n,t,r){for(var i=!!n.options.force,s=void 0,c=a,d=n.host,p=0,f=t.fileNames;p<f.length;p++){var m=f[p];if(!d.fileExists(m))return{type:e.UpToDateStatusType.Unbuildable,reason:m+" does not exist"};if(!i){var _=e.getModifiedTime(d,m);d.getModifiedTime(m),_>c&&(s=m,c=_)}}if(!t.fileNames.length&&!e.canJsonReportNoInputFiles(t.raw))return{type:e.UpToDateStatusType.ContainerOnly};var g,y=e.getAllProjectOutputs(t,!d.useCaseSensitiveFileNames()),h="(none)",v=o,b="(none)",E=a,S=a,x=!1;if(!i)for(var D=0,A=y;D<A.length;D++){var C=A[D];if(!d.fileExists(C)){g=C;break}var I=e.getModifiedTime(d,C);if(I<v&&(v=I,h=C),I<c){x=!0;break}if(I>E&&(E=I,b=C),u(C)){var N=e.getModifiedTime(d,C);S=l(S,N)}}var k,R=!1,O=!1;if(t.projectReferences){n.projectStatus.set(r,{type:e.UpToDateStatusType.ComputingUpstream});for(var w=0,P=t.projectReferences;w<P.length;w++){var M=P[w];O=O||!!M.prepend;var F=e.resolveProjectReferencePath(M),G=T(n,F),B=q(n,L(n,F,G),G);if(B.type!==e.UpToDateStatusType.ComputingUpstream&&B.type!==e.UpToDateStatusType.ContainerOnly){if(B.type===e.UpToDateStatusType.Unbuildable||B.type===e.UpToDateStatusType.UpstreamBlocked)return{type:e.UpToDateStatusType.UpstreamBlocked,upstreamProjectName:M.path,upstreamProjectBlocked:B.type===e.UpToDateStatusType.UpstreamBlocked};if(B.type!==e.UpToDateStatusType.UpToDate)return{type:e.UpToDateStatusType.UpstreamOutOfDate,upstreamProjectName:M.path};if(!i&&!g){if(B.newestInputFileTime&&B.newestInputFileTime<=v)continue;if(B.newestDeclarationFileContentChangedTime&&B.newestDeclarationFileContentChangedTime<=v){R=!0,k=M.path;continue}return e.Debug.assert(void 0!==h,"Should have an oldest output filename here"),{type:e.UpToDateStatusType.OutOfDateWithUpstream,outOfDateOutputFileName:h,newerProjectName:M.path}}}}}if(void 0!==g)return{type:e.UpToDateStatusType.OutputMissing,missingOutputFileName:g};if(x)return{type:e.UpToDateStatusType.OutOfDateWithSelf,outOfDateOutputFileName:h,newerInputFileName:s};var U=W(n,t.options.configFilePath,v,h);if(U)return U;var V=e.forEach(t.options.configFile.extendedSourceFiles||e.emptyArray,(function(e){return W(n,e,v,h)}));if(V)return V;if(!i&&!n.buildInfoChecked.has(r)){n.buildInfoChecked.set(r,!0);var j=e.getTsBuildInfoEmitOutputFilePath(t.options);if(j){var K=n.readFileWithCache(j),H=K&&e.getBuildInfo(K);if(H&&(H.bundle||H.program)&&H.version!==e.version)return{type:e.UpToDateStatusType.TsVersionOutputOfDate,version:H.version}}}return O&&R?{type:e.UpToDateStatusType.OutOfDateWithPrepend,outOfDateOutputFileName:h,newerProjectName:k}:{type:R?e.UpToDateStatusType.UpToDateWithUpstreamTypes:e.UpToDateStatusType.UpToDate,newestDeclarationFileContentChangedTime:S,newestInputFileTime:c,newestOutputFileTime:E,newestInputFileName:s,newestOutputFileName:b,oldestOutputFileName:h}}function q(n,t,r){if(void 0===t)return{type:e.UpToDateStatusType.Unbuildable,reason:"File deleted mid-build"};var a=n.projectStatus.get(r);if(void 0!==a)return a;var i=z(n,t,r);return n.projectStatus.set(r,i),i}function J(n,t,r,a,i){var o=n.host,s=e.getAllProjectOutputs(t,!o.useCaseSensitiveFileNames());if(!i||s.length!==i.size)for(var c=!!n.options.verbose,d=o.now?o.now():new Date,p=0,f=s;p<f.length;p++){var m=f[p];i&&i.has(E(n,m))||(c&&(c=!1,de(n,a,t.options.configFilePath)),u(m)&&(r=l(r,e.getModifiedTime(o,m))),o.setModifiedTime(m,d))}return r}function X(n,t,r){if(n.options.dry)return de(n,e.Diagnostics.A_non_dry_build_would_update_timestamps_for_output_of_project_0,t.options.configFilePath);var i=J(n,t,a,e.Diagnostics.Updating_output_timestamps_of_project_0);n.projectStatus.set(r,{type:e.UpToDateStatusType.UpToDate,newestDeclarationFileContentChangedTime:i,oldestOutputFileName:e.getFirstProjectOutput(t,!n.host.useCaseSensitiveFileNames())})}function Y(t,r,a,i,o,s,c){if(!(c&n.AnyErrors)&&o.options.composite)for(var l=i+1;l<s.length;l++){var u=s[l],d=T(t,u);if(!t.projectPendingBuild.has(d)){var p=L(t,u,d);if(p&&p.projectReferences)for(var f=0,m=p.projectReferences;f<m.length;f++){var _=m[f],g=D(t,_.path);if(T(t,g)===a){var y=t.projectStatus.get(d);if(y)switch(y.type){case e.UpToDateStatusType.UpToDate:if(c&n.DeclarationOutputUnchanged){_.prepend?t.projectStatus.set(d,{type:e.UpToDateStatusType.OutOfDateWithPrepend,outOfDateOutputFileName:y.oldestOutputFileName,newerProjectName:r}):y.type=e.UpToDateStatusType.UpToDateWithUpstreamTypes;break}case e.UpToDateStatusType.UpToDateWithUpstreamTypes:case e.UpToDateStatusType.OutOfDateWithPrepend:c&n.DeclarationOutputUnchanged||t.projectStatus.set(d,{type:e.UpToDateStatusType.OutOfDateWithUpstream,outOfDateOutputFileName:y.type===e.UpToDateStatusType.OutOfDateWithPrepend?y.outOfDateOutputFileName:y.oldestOutputFileName,newerProjectName:r});break;case e.UpToDateStatusType.UpstreamBlocked:T(t,D(t,y.upstreamProjectName))===a&&O(t,d);break}w(t,d,e.ConfigFileProgramReloadLevel.None);break}}}}}function Q(n,t,r,a,i,o){var s=N(n,t,o);if(!s)return e.ExitStatus.InvalidProject_OutputsSkipped;P(n,r);var c=!0,l=0;while(1){var u=U(n,s,c);if(!u)break;c=!1,u.done(r,a,null===i||void 0===i?void 0:i(u.project)),n.diagnostics.has(u.projectPath)||l++}return R(n),ge(n,s),se(n,s),d(s)?e.ExitStatus.ProjectReferenceCycle_OutputsSkipped:s.some((function(e){return n.diagnostics.has(T(n,e))}))?l?e.ExitStatus.DiagnosticsPresent_OutputsGenerated:e.ExitStatus.DiagnosticsPresent_OutputsSkipped:e.ExitStatus.Success}function Z(n,t,r){var a=N(n,t,r);if(!a)return e.ExitStatus.InvalidProject_OutputsSkipped;if(d(a))return fe(n,a.circularDiagnostics),e.ExitStatus.ProjectReferenceCycle_OutputsSkipped;for(var i=n.options,o=n.host,s=i.dry?[]:void 0,c=0,l=a;c<l.length;c++){var u=l[c],p=T(n,u),f=L(n,u,p);if(void 0!==f){var m=e.getAllProjectOutputs(f,!o.useCaseSensitiveFileNames());if(m.length)for(var _=new e.Set(f.fileNames.map((function(e){return E(n,e)}))),g=0,y=m;g<y.length;g++){var h=y[g];_.has(E(n,h))||o.fileExists(h)&&(s?s.push(h):(o.deleteFile(h),$(n,p,e.ConfigFileProgramReloadLevel.None)))}}else _e(n,p)}return s&&de(n,e.Diagnostics.A_non_dry_build_would_delete_the_following_files_Colon_0,s.map((function(e){return"\r\n * "+e})).join("")),e.ExitStatus.Success}function $(n,t,r){n.host.getParsedCommandLine&&r===e.ConfigFileProgramReloadLevel.Partial&&(r=e.ConfigFileProgramReloadLevel.Full),r===e.ConfigFileProgramReloadLevel.Full&&(n.configFileCache.delete(t),n.buildOrder=void 0),n.needsSummary=!0,O(n,t),w(n,t,r),k(n)}function ee(e,n,t){e.reportFileChangeDetected=!0,$(e,n,t),ne(e)}function ne(e){var n=e.hostWithWatch;n.setTimeout&&n.clearTimeout&&(e.timerToBuildInvalidatedProject&&n.clearTimeout(e.timerToBuildInvalidatedProject),e.timerToBuildInvalidatedProject=n.setTimeout(te,250,e))}function te(n){n.timerToBuildInvalidatedProject=void 0,n.reportFileChangeDetected&&(n.reportFileChangeDetected=!1,n.projectErrorsReported.clear(),pe(n,e.Diagnostics.File_change_detected_Starting_incremental_compilation));var t=C(n),r=U(n,t,!1);r&&(r.done(),n.projectPendingBuild.size)?n.watch&&!n.timerToBuildInvalidatedProject&&ne(n):(R(n),ge(n,t))}function re(n,t,r,a){n.watch&&!n.allWatchedConfigFiles.has(r)&&n.allWatchedConfigFiles.set(r,n.watchFile(t,(function(){ee(n,r,e.ConfigFileProgramReloadLevel.Full)}),e.PollingInterval.High,null===a||void 0===a?void 0:a.watchOptions,e.WatchType.ConfigFile,t))}function ae(n,t,r){e.updateSharedExtendedConfigFileWatcher(t,null===r||void 0===r?void 0:r.options,n.allWatchedExtendedConfigFiles,(function(t,a){return n.watchFile(t,(function(){var t;return null===(t=n.allWatchedExtendedConfigFiles.get(a))||void 0===t?void 0:t.projects.forEach((function(t){return ee(n,t,e.ConfigFileProgramReloadLevel.Full)}))}),e.PollingInterval.High,null===r||void 0===r?void 0:r.watchOptions,e.WatchType.ExtendedConfigFile)}),(function(e){return E(n,e)}))}function ie(n,t,r,a){n.watch&&e.updateWatchingWildcardDirectories(c(n.allWatchedWildcardDirectories,r),new e.Map(e.getEntries(a.wildcardDirectories)),(function(i,o){return n.watchDirectory(i,(function(o){var s;e.isIgnoredFileFromWildCardWatching({watchedDirPath:E(n,i),fileOrDirectory:o,fileOrDirectoryPath:E(n,o),configFileName:t,currentDirectory:n.currentDirectory,options:a.options,program:n.builderPrograms.get(r)||(null===(s=x(n,r))||void 0===s?void 0:s.fileNames),useCaseSensitiveFileNames:n.parseConfigFileHost.useCaseSensitiveFileNames,writeLog:function(e){return n.writeLog(e)},toPath:function(e){return E(n,e)}})||ee(n,r,e.ConfigFileProgramReloadLevel.Partial)}),o,null===a||void 0===a?void 0:a.watchOptions,e.WatchType.WildcardDirectory,t)}))}function oe(n,t,r,a){n.watch&&e.mutateMap(c(n.allWatchedInputFiles,r),e.arrayToMap(a.fileNames,(function(e){return E(n,e)})),{createNewValue:function(i,o){return n.watchFile(o,(function(){return ee(n,r,e.ConfigFileProgramReloadLevel.None)}),e.PollingInterval.Low,null===a||void 0===a?void 0:a.watchOptions,e.WatchType.SourceFile,t)},onDeleteValue:e.closeFileWatcher})}function se(e,n){if(e.watchAllProjectsPending){e.watchAllProjectsPending=!1;for(var t=0,r=p(n);t<r.length;t++){var a=r[t],i=T(e,a),o=L(e,a,i);re(e,a,i,o),ae(e,i,o),o&&(ie(e,a,i,o),oe(e,a,i,o))}}}function ce(n){e.clearMap(n.allWatchedConfigFiles,e.closeFileWatcher),e.clearMap(n.allWatchedExtendedConfigFiles,e.closeFileWatcherOf),e.clearMap(n.allWatchedWildcardDirectories,(function(n){return e.clearMap(n,e.closeFileWatcherOf)})),e.clearMap(n.allWatchedInputFiles,(function(n){return e.clearMap(n,e.closeFileWatcher)}))}function le(n,t,r,a,i){var o=b(n,t,r,a,i);return{build:function(e,n,t,r){return Q(o,e,n,t,r)},clean:function(e){return Z(o,e)},buildReferences:function(e,n,t,r){return Q(o,e,n,t,r,!0)},cleanReferences:function(e){return Z(o,e,!0)},getNextInvalidatedProject:function(e){return P(o,e),U(o,C(o),!1)},getBuildOrder:function(){return C(o)},getUpToDateStatusOfProject:function(e){var n=D(o,e),t=T(o,n);return q(o,L(o,n,t),t)},invalidateProject:function(n,t){return $(o,n,t||e.ConfigFileProgramReloadLevel.None)},buildNextInvalidatedProject:function(){return te(o)},getAllParsedConfigs:function(){return e.arrayFrom(e.mapDefinedIterator(o.configFileCache.values(),(function(e){return S(e)?e:void 0})))},close:function(){return ce(o)}}}function ue(n,t){return e.convertToRelativePath(t,n.currentDirectory,(function(e){return n.getCanonicalFileName(e)}))}function de(n,t){for(var r=[],a=2;a<arguments.length;a++)r[a-2]=arguments[a];n.host.reportSolutionBuilderStatus(e.createCompilerDiagnostic.apply(void 0,i([t],r)))}function pe(n,t){for(var r,a,o=[],s=2;s<arguments.length;s++)o[s-2]=arguments[s];null===(a=(r=n.hostWithWatch).onWatchStatusChange)||void 0===a||a.call(r,e.createCompilerDiagnostic.apply(void 0,i([t],o)),n.host.getNewLine(),n.baseCompilerOptions)}function fe(e,n){var t=e.host;n.forEach((function(e){return t.reportDiagnostic(e)}))}function me(e,n,t){fe(e,t),e.projectErrorsReported.set(n,!0),t.length&&e.diagnostics.set(n,t)}function _e(e,n){me(e,n,[e.configFileCache.get(n)])}function ge(n,t){if(n.needsSummary){n.needsSummary=!1;var r=n.watch||!!n.host.reportErrorSummary,a=n.diagnostics,i=0;d(t)?(ye(n,t.buildOrder),fe(n,t.circularDiagnostics),r&&(i+=e.getErrorCountForSummary(t.circularDiagnostics))):(t.forEach((function(t){var r=T(n,t);n.projectErrorsReported.has(r)||fe(n,a.get(r)||e.emptyArray)})),r&&a.forEach((function(n){return i+=e.getErrorCountForSummary(n)}))),n.watch?pe(n,e.getWatchErrorSummaryDiagnosticMessage(i),i):n.host.reportErrorSummary&&n.host.reportErrorSummary(i)}}function ye(n,t){n.options.verbose&&de(n,e.Diagnostics.Projects_in_this_build_Colon_0,t.map((function(e){return"\r\n    * "+ue(n,e)})).join(""))}function he(n,t,r){if(n.options.force&&(r.type===e.UpToDateStatusType.UpToDate||r.type===e.UpToDateStatusType.UpToDateWithUpstreamTypes))return de(n,e.Diagnostics.Project_0_is_being_forcibly_rebuilt,ue(n,t));switch(r.type){case e.UpToDateStatusType.OutOfDateWithSelf:return de(n,e.Diagnostics.Project_0_is_out_of_date_because_oldest_output_1_is_older_than_newest_input_2,ue(n,t),ue(n,r.outOfDateOutputFileName),ue(n,r.newerInputFileName));case e.UpToDateStatusType.OutOfDateWithUpstream:return de(n,e.Diagnostics.Project_0_is_out_of_date_because_oldest_output_1_is_older_than_newest_input_2,ue(n,t),ue(n,r.outOfDateOutputFileName),ue(n,r.newerProjectName));case e.UpToDateStatusType.OutputMissing:return de(n,e.Diagnostics.Project_0_is_out_of_date_because_output_file_1_does_not_exist,ue(n,t),ue(n,r.missingOutputFileName));case e.UpToDateStatusType.UpToDate:if(void 0!==r.newestInputFileTime)return de(n,e.Diagnostics.Project_0_is_up_to_date_because_newest_input_1_is_older_than_oldest_output_2,ue(n,t),ue(n,r.newestInputFileName||""),ue(n,r.oldestOutputFileName||""));break;case e.UpToDateStatusType.OutOfDateWithPrepend:return de(n,e.Diagnostics.Project_0_is_out_of_date_because_output_of_its_dependency_1_has_changed,ue(n,t),ue(n,r.newerProjectName));case e.UpToDateStatusType.UpToDateWithUpstreamTypes:return de(n,e.Diagnostics.Project_0_is_up_to_date_with_d_ts_files_from_its_dependencies,ue(n,t));case e.UpToDateStatusType.UpstreamOutOfDate:return de(n,e.Diagnostics.Project_0_is_out_of_date_because_its_dependency_1_is_out_of_date,ue(n,t),ue(n,r.upstreamProjectName));case e.UpToDateStatusType.UpstreamBlocked:return de(n,r.upstreamProjectBlocked?e.Diagnostics.Project_0_can_t_be_built_because_its_dependency_1_was_not_built:e.Diagnostics.Project_0_can_t_be_built_because_its_dependency_1_has_errors,ue(n,t),ue(n,r.upstreamProjectName));case e.UpToDateStatusType.Unbuildable:return de(n,e.Diagnostics.Failed_to_parse_file_0_Colon_1,ue(n,t),r.reason);case e.UpToDateStatusType.TsVersionOutputOfDate:return de(n,e.Diagnostics.Project_0_is_out_of_date_because_output_for_it_was_generated_with_version_1_that_differs_with_current_version_2,ue(n,t),r.version,e.version);case e.UpToDateStatusType.ContainerOnly:case e.UpToDateStatusType.ComputingUpstream:break;default:e.assertType(r)}}function ve(e,n,t){e.options.verbose&&he(e,n,t)}(function(e){e[e["None"]=0]="None",e[e["Success"]=1]="Success",e[e["DeclarationOutputUnchanged"]=2]="DeclarationOutputUnchanged",e[e["ConfigFileErrors"]=4]="ConfigFileErrors",e[e["SyntaxErrors"]=8]="SyntaxErrors",e[e["TypeErrors"]=16]="TypeErrors",e[e["DeclarationEmitErrors"]=32]="DeclarationEmitErrors",e[e["EmitErrors"]=64]="EmitErrors",e[e["AnyErrors"]=124]="AnyErrors"})(n||(n={})),e.isCircularBuildOrder=d,e.getBuildOrderFromAnyBuildOrder=p,e.createBuilderStatusReporter=f,e.createSolutionBuilderHost=_,e.createSolutionBuilderWithWatchHost=g,e.createSolutionBuilder=h,e.createSolutionBuilderWithWatch=v,function(e){e[e["Build"]=0]="Build",e[e["UpdateBundle"]=1]="UpdateBundle",e[e["UpdateOutputFileStamps"]=2]="UpdateOutputFileStamps"}(t=e.InvalidatedProjectKind||(e.InvalidatedProjectKind={})),function(e){e[e["CreateProgram"]=0]="CreateProgram",e[e["SyntaxDiagnostics"]=1]="SyntaxDiagnostics",e[e["SemanticDiagnostics"]=2]="SemanticDiagnostics",e[e["Emit"]=3]="Emit",e[e["EmitBundle"]=4]="EmitBundle",e[e["EmitBuildInfo"]=5]="EmitBuildInfo",e[e["BuildInvalidatedProjectOfBundle"]=6]="BuildInvalidatedProjectOfBundle",e[e["QueueReferencingProjects"]=7]="QueueReferencingProjects",e[e["Done"]=8]="Done"}(r||(r={}))}(d||(d={})),function(e){(function(n){function t(n){return e.sys.args.indexOf(n)>=0}function r(n){var t=e.sys.args.indexOf(n);return t>=0&&t<e.sys.args.length-1?e.sys.args[t+1]:void 0}function a(){var n=new Date;return e.padLeft(n.getHours().toString(),2,"0")+":"+e.padLeft(n.getMinutes().toString(),2,"0")+":"+e.padLeft(n.getSeconds().toString(),2,"0")+"."+e.padLeft(n.getMilliseconds().toString(),3,"0")}n.ActionSet="action::set",n.ActionInvalidate="action::invalidate",n.ActionPackageInstalled="action::packageInstalled",n.EventTypesRegistry="event::typesRegistry",n.EventBeginInstallTypes="event::beginInstallTypes",n.EventEndInstallTypes="event::endInstallTypes",n.EventInitializationFailed="event::initializationFailed",function(e){e.GlobalCacheLocation="--globalTypingsCacheLocation",e.LogFile="--logFile",e.EnableTelemetry="--enableTelemetry",e.TypingSafeListLocation="--typingSafeListLocation",e.TypesMapLocation="--typesMapLocation",e.NpmLocation="--npmLocation",e.ValidateDefaultNpmLocation="--validateDefaultNpmLocation"}(n.Arguments||(n.Arguments={})),n.hasArgument=t,n.findArgument=r,n.nowString=a})(e.server||(e.server={}))}(d||(d={})),function(e){(function(n){function t(n,t){var r=new e.Version(e.getProperty(t,"ts"+e.versionMajorMinor)||e.getProperty(t,"latest"));return r.compareTo(n.version)<=0}function r(e){return n.nodeCoreModules.has(e)?"node":e}function a(n,t){var r=e.readConfigFile(t,(function(e){return n.readFile(e)}));return new e.Map(e.getEntries(r.config))}function i(n,t){var r=e.readConfigFile(t,(function(e){return n.readFile(e)}));if(r.config)return new e.Map(e.getEntries(r.config.simpleMap))}function o(n,a,i,o,s,c,l,u,d){if(!l||!l.enable)return{cachedTypingPaths:[],newTypingNames:[],filesToWatch:[]};var p=new e.Map;i=e.mapDefined(i,(function(n){var t=e.normalizePath(n);if(e.hasJSFileExtension(t))return t}));var f=[];l.include&&L(l.include,"Explicitly included types");var m=l.exclude||[],_=new e.Set(i.map(e.getDirectoryPath));if(_.add(o),_.forEach((function(n){var t=e.combinePaths(n,"package.json");D(t,f);var r=e.combinePaths(n,"bower.json");D(r,f);var a=e.combinePaths(n,"bower_components");C(a,f);var i=e.combinePaths(n,"node_modules");C(i,f)})),l.disableFilenameBasedTypeAcquisition||A(i),u){var g=e.deduplicate(u.map(r),e.equateStringsCaseSensitive,e.compareStringsCaseSensitive);L(g,"Inferred typings from unresolved imports")}c.forEach((function(e,n){var r=d.get(n);p.has(n)&&void 0===p.get(n)&&void 0!==r&&t(e,r)&&p.set(n,e.typingLocation)}));for(var y=0,h=m;y<h.length;y++){var v=h[y],b=p.delete(v);b&&a&&a("Typing for "+v+" is in exclude list, will be ignored.")}var E=[],T=[];p.forEach((function(e,n){void 0!==e?T.push(e):E.push(n)}));var S={cachedTypingPaths:T,newTypingNames:E,filesToWatch:f};return a&&a("Result: "+JSON.stringify(S)),S;function x(e){p.has(e)||p.set(e,void 0)}function L(n,t){a&&a(t+": "+JSON.stringify(n)),e.forEach(n,x)}function D(t,r){if(n.fileExists(t)){r.push(t);var a=e.readConfigFile(t,(function(e){return n.readFile(e)})).config,i=e.flatMap([a.dependencies,a.devDependencies,a.optionalDependencies,a.peerDependencies],e.getOwnKeys);L(i,"Typing names in '"+t+"' dependencies")}}function A(n){var t=e.mapDefined(n,(function(n){if(e.hasJSFileExtension(n)){var t=e.removeFileExtension(e.getBaseFileName(n.toLowerCase())),r=e.removeMinAndVersionNumbers(t);return s.get(r)}}));t.length&&L(t,"Inferred typings from file names");var r=e.some(n,(function(n){return e.fileExtensionIs(n,".jsx")}));r&&(a&&a("Inferred 'react' typings due to presence of '.jsx' extension"),x("react"))}function C(t,r){if(r.push(t),n.directoryExists(t)){var i=n.readDirectory(t,[".json"],void 0,void 0,2);a&&a("Searching for typing names in "+t+"; all files: "+JSON.stringify(i));for(var o=[],s=0,c=i;s<c.length;s++){var l=c[s],u=e.normalizePath(l),d=e.getBaseFileName(u);if("package.json"===d||"bower.json"===d){var f=e.readConfigFile(u,(function(e){return n.readFile(e)})),m=f.config;if(("package.json"!==d||!m._requiredBy||0!==e.filter(m._requiredBy,(function(e){return"#"===e[0]||"/"===e})).length)&&m.name){var _=m.types||m.typings;if(_){var g=e.getNormalizedAbsolutePath(_,e.getDirectoryPath(u));a&&a("    Package '"+m.name+"' provides its own types."),p.set(m.name,g)}else o.push(m.name)}}}L(o,"    Found package names")}}}n.isTypingUpToDate=t,n.nodeCoreModuleList=["assert","async_hooks","buffer","child_process","cluster","console","constants","crypto","dgram","dns","domain","events","fs","http","https","http2","inspector","net","os","path","perf_hooks","process","punycode","querystring","readline","repl","stream","string_decoder","timers","tls","tty","url","util","v8","vm","zlib"],n.nodeCoreModules=new e.Set(n.nodeCoreModuleList),n.nonRelativeModuleNameForTypingCache=r,n.loadSafeList=a,n.loadTypesMap=i,n.discoverTypings=o,function(e){e[e["Ok"]=0]="Ok",e[e["EmptyName"]=1]="EmptyName",e[e["NameTooLong"]=2]="NameTooLong",e[e["NameStartsWithDot"]=3]="NameStartsWithDot",e[e["NameStartsWithUnderscore"]=4]="NameStartsWithUnderscore",e[e["NameContainsNonURISafeCharacters"]=5]="NameContainsNonURISafeCharacters"}(n.NameValidationResult||(n.NameValidationResult={}));var s=214;function c(e){return l(e,!0)}function l(e,n){if(!e)return 1;if(e.length>s)return 2;if(46===e.charCodeAt(0))return 3;if(95===e.charCodeAt(0))return 4;if(n){var t=/^@([^/]+)\/([^/]+)$/.exec(e);if(t){var r=l(t[1],!1);if(0!==r)return{name:t[1],isScopeName:!0,result:r};var a=l(t[2],!1);return 0!==a?{name:t[2],isScopeName:!1,result:a}:0}}return encodeURIComponent(e)!==e?5:0}function u(e,n){return"object"===typeof e?d(n,e.result,e.name,e.isScopeName):d(n,e,n,!1)}function d(n,t,r,a){var i=a?"Scope":"Package";switch(t){case 1:return"'"+n+"':: "+i+" name '"+r+"' cannot be empty";case 2:return"'"+n+"':: "+i+" name '"+r+"' should be less than "+s+" characters";case 3:return"'"+n+"':: "+i+" name '"+r+"' cannot start with '.'";case 4:return"'"+n+"':: "+i+" name '"+r+"' cannot start with '_'";case 5:return"'"+n+"':: "+i+" name '"+r+"' contains non URI safe characters";case 0:return e.Debug.fail();default:throw e.Debug.assertNever(t)}}n.validatePackageName=c,n.renderPackageNameValidationFailure=u})(e.JsTyping||(e.JsTyping={}))}(d||(d={})),function(e){var n,t;function r(e){return{indentSize:4,tabSize:4,newLineCharacter:e||"\n",convertTabsToSpaces:!0,indentStyle:n.Smart,insertSpaceAfterConstructor:!1,insertSpaceAfterCommaDelimiter:!0,insertSpaceAfterSemicolonInForStatements:!0,insertSpaceBeforeAndAfterBinaryOperators:!0,insertSpaceAfterKeywordsInControlFlowStatements:!0,insertSpaceAfterFunctionKeywordForAnonymousFunctions:!1,insertSpaceAfterOpeningAndBeforeClosingNonemptyParenthesis:!1,insertSpaceAfterOpeningAndBeforeClosingNonemptyBrackets:!1,insertSpaceAfterOpeningAndBeforeClosingNonemptyBraces:!0,insertSpaceAfterOpeningAndBeforeClosingTemplateStringBraces:!1,insertSpaceAfterOpeningAndBeforeClosingJsxExpressionBraces:!1,insertSpaceBeforeFunctionParenthesis:!1,placeOpenBraceOnNewLineForFunctions:!1,placeOpenBraceOnNewLineForControlBlocks:!1,semicolons:t.Ignore,trimTrailingWhitespace:!0}}(function(e){var n=function(){function e(e){this.text=e}return e.prototype.getText=function(e,n){return 0===e&&n===this.text.length?this.text:this.text.substring(e,n)},e.prototype.getLength=function(){return this.text.length},e.prototype.getChangeRange=function(){},e}();function t(e){return new n(e)}e.fromString=t})(e.ScriptSnapshot||(e.ScriptSnapshot={})),function(e){e[e["Dependencies"]=1]="Dependencies",e[e["DevDependencies"]=2]="DevDependencies",e[e["PeerDependencies"]=4]="PeerDependencies",e[e["OptionalDependencies"]=8]="OptionalDependencies",e[e["All"]=15]="All"}(e.PackageJsonDependencyGroup||(e.PackageJsonDependencyGroup={})),function(e){e[e["Off"]=0]="Off",e[e["On"]=1]="On",e[e["Auto"]=2]="Auto"}(e.PackageJsonAutoImportPreference||(e.PackageJsonAutoImportPreference={})),function(e){e[e["Semantic"]=0]="Semantic",e[e["PartialSemantic"]=1]="PartialSemantic",e[e["Syntactic"]=2]="Syntactic"}(e.LanguageServiceMode||(e.LanguageServiceMode={})),e.emptyOptions={},function(e){e["Original"]="original",e["TwentyTwenty"]="2020"}(e.SemanticClassificationFormat||(e.SemanticClassificationFormat={})),function(e){e["none"]="none",e["definition"]="definition",e["reference"]="reference",e["writtenReference"]="writtenReference"}(e.HighlightSpanKind||(e.HighlightSpanKind={})),function(e){e[e["None"]=0]="None",e[e["Block"]=1]="Block",e[e["Smart"]=2]="Smart"}(n=e.IndentStyle||(e.IndentStyle={})),function(e){e["Ignore"]="ignore",e["Insert"]="insert",e["Remove"]="remove"}(t=e.SemicolonPreference||(e.SemicolonPreference={})),e.getDefaultFormatCodeSettings=r,e.testFormatSettings=r("\n"),function(e){e[e["aliasName"]=0]="aliasName",e[e["className"]=1]="className",e[e["enumName"]=2]="enumName",e[e["fieldName"]=3]="fieldName",e[e["interfaceName"]=4]="interfaceName",e[e["keyword"]=5]="keyword",e[e["lineBreak"]=6]="lineBreak",e[e["numericLiteral"]=7]="numericLiteral",e[e["stringLiteral"]=8]="stringLiteral",e[e["localName"]=9]="localName",e[e["methodName"]=10]="methodName",e[e["moduleName"]=11]="moduleName",e[e["operator"]=12]="operator",e[e["parameterName"]=13]="parameterName",e[e["propertyName"]=14]="propertyName",e[e["punctuation"]=15]="punctuation",e[e["space"]=16]="space",e[e["text"]=17]="text",e[e["typeParameterName"]=18]="typeParameterName",e[e["enumMemberName"]=19]="enumMemberName",e[e["functionName"]=20]="functionName",e[e["regularExpressionLiteral"]=21]="regularExpressionLiteral",e[e["link"]=22]="link",e[e["linkName"]=23]="linkName",e[e["linkText"]=24]="linkText"}(e.SymbolDisplayPartKind||(e.SymbolDisplayPartKind={})),function(e){e["Comment"]="comment",e["Region"]="region",e["Code"]="code",e["Imports"]="imports"}(e.OutliningSpanKind||(e.OutliningSpanKind={})),function(e){e[e["JavaScript"]=0]="JavaScript",e[e["SourceMap"]=1]="SourceMap",e[e["Declaration"]=2]="Declaration"}(e.OutputFileType||(e.OutputFileType={})),function(e){e[e["None"]=0]="None",e[e["InMultiLineCommentTrivia"]=1]="InMultiLineCommentTrivia",e[e["InSingleQuoteStringLiteral"]=2]="InSingleQuoteStringLiteral",e[e["InDoubleQuoteStringLiteral"]=3]="InDoubleQuoteStringLiteral",e[e["InTemplateHeadOrNoSubstitutionTemplate"]=4]="InTemplateHeadOrNoSubstitutionTemplate",e[e["InTemplateMiddleOrTail"]=5]="InTemplateMiddleOrTail",e[e["InTemplateSubstitutionPosition"]=6]="InTemplateSubstitutionPosition"}(e.EndOfLineState||(e.EndOfLineState={})),function(e){e[e["Punctuation"]=0]="Punctuation",e[e["Keyword"]=1]="Keyword",e[e["Operator"]=2]="Operator",e[e["Comment"]=3]="Comment",e[e["Whitespace"]=4]="Whitespace",e[e["Identifier"]=5]="Identifier",e[e["NumberLiteral"]=6]="NumberLiteral",e[e["BigIntLiteral"]=7]="BigIntLiteral",e[e["StringLiteral"]=8]="StringLiteral",e[e["RegExpLiteral"]=9]="RegExpLiteral"}(e.TokenClass||(e.TokenClass={})),function(e){e["unknown"]="",e["warning"]="warning",e["keyword"]="keyword",e["scriptElement"]="script",e["moduleElement"]="module",e["classElement"]="class",e["localClassElement"]="local class",e["interfaceElement"]="interface",e["typeElement"]="type",e["enumElement"]="enum",e["enumMemberElement"]="enum member",e["variableElement"]="var",e["localVariableElement"]="local var",e["functionElement"]="function",e["localFunctionElement"]="local function",e["memberFunctionElement"]="method",e["memberGetAccessorElement"]="getter",e["memberSetAccessorElement"]="setter",e["memberVariableElement"]="property",e["constructorImplementationElement"]="constructor",e["callSignatureElement"]="call",e["indexSignatureElement"]="index",e["constructSignatureElement"]="construct",e["parameterElement"]="parameter",e["typeParameterElement"]="type parameter",e["primitiveType"]="primitive type",e["label"]="label",e["alias"]="alias",e["constElement"]="const",e["letElement"]="let",e["directory"]="directory",e["externalModuleName"]="external module name",e["jsxAttribute"]="JSX attribute",e["string"]="string",e["link"]="link",e["linkName"]="link name",e["linkText"]="link text"}(e.ScriptElementKind||(e.ScriptElementKind={})),function(e){e["none"]="",e["publicMemberModifier"]="public",e["privateMemberModifier"]="private",e["protectedMemberModifier"]="protected",e["exportedModifier"]="export",e["ambientModifier"]="declare",e["staticModifier"]="static",e["abstractModifier"]="abstract",e["optionalModifier"]="optional",e["deprecatedModifier"]="deprecated",e["dtsModifier"]=".d.ts",e["tsModifier"]=".ts",e["tsxModifier"]=".tsx",e["jsModifier"]=".js",e["jsxModifier"]=".jsx",e["jsonModifier"]=".json"}(e.ScriptElementKindModifier||(e.ScriptElementKindModifier={})),function(e){e["comment"]="comment",e["identifier"]="identifier",e["keyword"]="keyword",e["numericLiteral"]="number",e["bigintLiteral"]="bigint",e["operator"]="operator",e["stringLiteral"]="string",e["whiteSpace"]="whitespace",e["text"]="text",e["punctuation"]="punctuation",e["className"]="class name",e["enumName"]="enum name",e["interfaceName"]="interface name",e["moduleName"]="module name",e["typeParameterName"]="type parameter name",e["typeAliasName"]="type alias name",e["parameterName"]="parameter name",e["docCommentTagName"]="doc comment tag name",e["jsxOpenTagName"]="jsx open tag name",e["jsxCloseTagName"]="jsx close tag name",e["jsxSelfClosingTagName"]="jsx self closing tag name",e["jsxAttribute"]="jsx attribute",e["jsxText"]="jsx text",e["jsxAttributeStringLiteralValue"]="jsx attribute string literal value"}(e.ClassificationTypeNames||(e.ClassificationTypeNames={})),function(e){e[e["comment"]=1]="comment",e[e["identifier"]=2]="identifier",e[e["keyword"]=3]="keyword",e[e["numericLiteral"]=4]="numericLiteral",e[e["operator"]=5]="operator",e[e["stringLiteral"]=6]="stringLiteral",e[e["regularExpressionLiteral"]=7]="regularExpressionLiteral",e[e["whiteSpace"]=8]="whiteSpace",e[e["text"]=9]="text",e[e["punctuation"]=10]="punctuation",e[e["className"]=11]="className",e[e["enumName"]=12]="enumName",e[e["interfaceName"]=13]="interfaceName",e[e["moduleName"]=14]="moduleName",e[e["typeParameterName"]=15]="typeParameterName",e[e["typeAliasName"]=16]="typeAliasName",e[e["parameterName"]=17]="parameterName",e[e["docCommentTagName"]=18]="docCommentTagName",e[e["jsxOpenTagName"]=19]="jsxOpenTagName",e[e["jsxCloseTagName"]=20]="jsxCloseTagName",e[e["jsxSelfClosingTagName"]=21]="jsxSelfClosingTagName",e[e["jsxAttribute"]=22]="jsxAttribute",e[e["jsxText"]=23]="jsxText",e[e["jsxAttributeStringLiteralValue"]=24]="jsxAttributeStringLiteralValue",e[e["bigintLiteral"]=25]="bigintLiteral"}(e.ClassificationType||(e.ClassificationType={}))}(d||(d={})),function(e){function n(n){switch(n.kind){case 250:return e.isInJSFile(n)&&e.getJSDocEnumTag(n)?7:1;case 161:case 199:case 164:case 163:case 289:case 290:case 166:case 165:case 167:case 168:case 169:case 252:case 209:case 210:case 288:case 281:return 1;case 160:case 254:case 255:case 178:return 2;case 335:return void 0===n.name?3:2;case 292:case 253:return 3;case 257:return e.isAmbientModule(n)||1===e.getModuleInstanceState(n)?5:4;case 256:case 265:case 266:case 261:case 262:case 267:case 268:return 7;case 298:return 5}return 7}function t(t){return t=me(t),298===t.kind?1:267===t.parent.kind||273===t.parent.kind||266===t.parent.kind||263===t.parent.kind||e.isImportEqualsDeclaration(t.parent)&&t===t.parent.name?7:a(t)?r(t):e.isDeclarationName(t)?n(t.parent):e.isEntityName(t)&&(e.isJSDocNameReference(t.parent)||e.isJSDocLink(t.parent))?7:l(t)?2:i(t)?4:e.isTypeParameterDeclaration(t.parent)?(e.Debug.assert(e.isJSDocTemplateTag(t.parent.parent)),2):e.isLiteralTypeNode(t.parent)?3:1}function r(n){var t=158===n.kind?n:e.isQualifiedName(n.parent)&&n.parent.right===n?n.parent:void 0;return t&&261===t.parent.kind?7:4}function a(n){while(158===n.parent.kind)n=n.parent;return e.isInternalModuleImportEqualsDeclaration(n.parent)&&n.parent.moduleReference===n}function i(e){return s(e)||c(e)}function s(e){var n=e,t=!0;if(158===n.parent.kind){while(n.parent&&158===n.parent.kind)n=n.parent;t=n.right===e}return 174===n.parent.kind&&!t}function c(e){var n=e,t=!0;if(202===n.parent.kind){while(n.parent&&202===n.parent.kind)n=n.parent;t=n.name===e}if(!t&&224===n.parent.kind&&287===n.parent.parent.kind){var r=n.parent.parent.parent;return 253===r.kind&&116===n.parent.parent.token||254===r.kind&&93===n.parent.parent.token}return!1}function l(n){switch(e.isRightSideOfQualifiedNameOrPropertyAccess(n)&&(n=n.parent),n.kind){case 107:return!e.isExpressionNode(n);case 188:return!0}switch(n.parent.kind){case 174:return!0;case 196:return!n.parent.isTypeOf;case 224:return!e.isExpressionWithTypeArgumentsInClassExtendsClause(n.parent)}return!1}function u(n,t,r){return void 0===t&&(t=!1),void 0===r&&(r=!1),v(n,e.isCallExpression,g,t,r)}function d(n,t,r){return void 0===t&&(t=!1),void 0===r&&(r=!1),v(n,e.isNewExpression,g,t,r)}function p(n,t,r){return void 0===t&&(t=!1),void 0===r&&(r=!1),v(n,e.isCallOrNewExpression,g,t,r)}function f(n,t,r){return void 0===t&&(t=!1),void 0===r&&(r=!1),v(n,e.isTaggedTemplateExpression,y,t,r)}function m(n,t,r){return void 0===t&&(t=!1),void 0===r&&(r=!1),v(n,e.isDecorator,g,t,r)}function _(n,t,r){return void 0===t&&(t=!1),void 0===r&&(r=!1),v(n,e.isJsxOpeningLikeElement,h,t,r)}function g(e){return e.expression}function y(e){return e.tag}function h(e){return e.tagName}function v(n,t,r,a,i){var o=a?E(n):b(n);return i&&(o=e.skipOuterExpressions(o)),!!o&&!!o.parent&&t(o.parent)&&r(o.parent)===o}function b(e){return I(e)?e.parent:e}function E(e){return I(e)||N(e)?e.parent:e}function T(e,n){while(e){if(246===e.kind&&e.label.escapedText===n)return e.label;e=e.parent}}function S(n,t){return!!e.isPropertyAccessExpression(n.expression)&&n.expression.name.text===t}function x(n){var t;return e.isIdentifier(n)&&(null===(t=e.tryCast(n.parent,e.isBreakOrContinueStatement))||void 0===t?void 0:t.label)===n}function L(n){var t;return e.isIdentifier(n)&&(null===(t=e.tryCast(n.parent,e.isLabeledStatement))||void 0===t?void 0:t.label)===n}function D(e){return L(e)||x(e)}function A(n){var t;return(null===(t=e.tryCast(n.parent,e.isJSDocTag))||void 0===t?void 0:t.tagName)===n}function C(n){var t;return(null===(t=e.tryCast(n.parent,e.isQualifiedName))||void 0===t?void 0:t.right)===n}function I(n){var t;return(null===(t=e.tryCast(n.parent,e.isPropertyAccessExpression))||void 0===t?void 0:t.name)===n}function N(n){var t;return(null===(t=e.tryCast(n.parent,e.isElementAccessExpression))||void 0===t?void 0:t.argumentExpression)===n}function k(n){var t;return(null===(t=e.tryCast(n.parent,e.isModuleDeclaration))||void 0===t?void 0:t.name)===n}function R(n){var t;return e.isIdentifier(n)&&(null===(t=e.tryCast(n.parent,e.isFunctionLike))||void 0===t?void 0:t.name)===n}function O(n){switch(n.parent.kind){case 164:case 163:case 289:case 292:case 166:case 165:case 168:case 169:case 257:return e.getNameOfDeclaration(n.parent)===n;case 203:return n.parent.argumentExpression===n;case 159:return!0;case 192:return 190===n.parent.parent.kind;default:return!1}}function w(n){return e.isExternalModuleImportEqualsDeclaration(n.parent.parent)&&e.getExternalModuleImportEqualsDeclarationExpression(n.parent.parent)===n}function P(n){e.isJSDocTypeAlias(n)&&(n=n.parent.parent);while(1){if(n=n.parent,!n)return;switch(n.kind){case 298:case 166:case 165:case 252:case 209:case 168:case 169:case 253:case 254:case 256:case 257:return n}}}function M(n){switch(n.kind){case 298:return e.isExternalModule(n)?"module":"script";case 257:return"module";case 253:case 222:return"class";case 254:return"interface";case 255:case 328:case 335:return"type";case 256:return"enum";case 250:return s(n);case 199:return s(e.getRootDeclaration(n));case 210:case 252:case 209:return"function";case 168:return"getter";case 169:return"setter";case 166:case 165:return"method";case 289:var t=n.initializer;return e.isFunctionLike(t)?"method":"property";case 164:case 163:case 290:case 291:return"property";case 172:return"index";case 171:return"construct";case 170:return"call";case 167:return"constructor";case 160:return"type parameter";case 292:return"enum member";case 161:return e.hasSyntacticModifier(n,16476)?"property":"parameter";case 261:case 266:case 271:case 264:case 270:return"alias";case 217:var r=e.getAssignmentDeclarationKind(n),a=n.right;switch(r){case 7:case 8:case 9:case 0:return"";case 1:case 2:var i=M(a);return""===i?"const":i;case 3:return e.isFunctionExpression(a)?"method":"property";case 4:return"property";case 5:return e.isFunctionExpression(a)?"method":"property";case 6:return"local class";default:return e.assertType(r),""}case 78:return e.isImportClause(n.parent)?"alias":"";case 267:var o=M(n.expression);return""===o?"const":o;default:return""}function s(n){return e.isVarConst(n)?"const":e.isLet(n)?"let":"var"}}function F(n){switch(n.kind){case 107:return!0;case 78:return e.identifierIsThisKeyword(n)&&161===n.parent.kind;default:return!1}}e.scanner=e.createScanner(99,!0),function(e){e[e["None"]=0]="None",e[e["Value"]=1]="Value",e[e["Type"]=2]="Type",e[e["Namespace"]=4]="Namespace",e[e["All"]=7]="All"}(e.SemanticMeaning||(e.SemanticMeaning={})),e.getMeaningFromDeclaration=n,e.getMeaningFromLocation=t,e.isInRightSideOfInternalImportEqualsDeclaration=a,e.isCallExpressionTarget=u,e.isNewExpressionTarget=d,e.isCallOrNewExpressionTarget=p,e.isTaggedTemplateTag=f,e.isDecoratorTarget=m,e.isJsxOpeningLikeElementTagName=_,e.climbPastPropertyAccess=b,e.climbPastPropertyOrElementAccess=E,e.getTargetLabel=T,e.hasPropertyAccessExpressionWithName=S,e.isJumpStatementTarget=x,e.isLabelOfLabeledStatement=L,e.isLabelName=D,e.isTagName=A,e.isRightSideOfQualifiedName=C,e.isRightSideOfPropertyAccess=I,e.isArgumentExpressionOfElementAccess=N,e.isNameOfModuleDeclaration=k,e.isNameOfFunctionDeclaration=R,e.isLiteralNameOfPropertyDeclarationOrIndexAccess=O,e.isExpressionOfExternalModuleImportEqualsDeclaration=w,e.getContainerNode=P,e.getNodeKind=M,e.isThis=F;var G=/^\/\/\/\s*</;function B(n,t){var r=e.getLineStarts(t),a=t.getLineAndCharacterOfPosition(n).line;return r[a]}function U(e,n){return H(e.pos,e.end,n)}function V(e,n){return K(e,n.pos)&&K(e,n.end)}function j(e,n){return e.pos<=n&&n<=e.end}function K(e,n){return e.pos<n&&n<e.end}function H(e,n,t){return e<=t.pos&&n>=t.end}function W(e,n,t){return e.pos<=n&&e.end>=t}function z(e,n,t){return J(e.pos,e.end,n,t)}function q(e,n,t,r){return J(e.getStart(n),e.end,t,r)}function J(e,n,t,r){var a=Math.max(e,t),i=Math.min(n,r);return a<i}function X(n,t,r){return e.Debug.assert(n.pos<=t),t<n.end||!Y(n,r)}function Y(n,t){if(void 0===n||e.nodeIsMissing(n))return!1;switch(n.kind){case 253:case 254:case 256:case 201:case 197:case 178:case 231:case 258:case 259:case 265:case 269:return Q(n,19,t);case 288:return Y(n.block,t);case 205:if(!n.arguments)return!0;case 204:case 208:case 187:return Q(n,21,t);case 175:case 176:return Y(n.type,t);case 167:case 168:case 169:case 252:case 209:case 166:case 165:case 171:case 170:case 210:return n.body?Y(n.body,t):n.type?Y(n.type,t):$(n,21,t);case 257:return!!n.body&&Y(n.body,t);case 235:return n.elseStatement?Y(n.elseStatement,t):Y(n.thenStatement,t);case 234:return Y(n.expression,t)||$(n,26,t);case 200:case 198:case 203:case 159:case 180:return Q(n,23,t);case 172:return n.type?Y(n.type,t):$(n,23,t);case 285:case 286:return!1;case 238:case 239:case 240:case 237:return Y(n.statement,t);case 236:return $(n,114,t)?Q(n,21,t):Y(n.statement,t);case 177:return Y(n.exprName,t);case 212:case 211:case 213:case 220:case 221:var r=n;return Y(r.expression,t);case 206:return Y(n.template,t);case 219:var a=e.lastOrUndefined(n.templateSpans);return Y(a,t);case 229:return e.nodeIsPresent(n.literal);case 268:case 262:return e.nodeIsPresent(n.moduleSpecifier);case 215:return Y(n.operand,t);case 217:return Y(n.right,t);case 218:return Y(n.whenFalse,t);default:return!0}}function Q(n,t,r){var a=n.getChildren(r);if(a.length){var i=e.last(a);if(i.kind===t)return!0;if(26===i.kind&&1!==a.length)return a[a.length-2].kind===t}return!1}function Z(n){var t=ne(n);if(t){var r=t.getChildren(),a=e.indexOfNode(r,n);return{listItemIndex:a,list:t}}}function $(e,n,t){return!!ee(e,n,t)}function ee(n,t,r){return e.find(n.getChildren(r),(function(e){return e.kind===t}))}function ne(n){var t=e.find(n.parent.getChildren(),(function(t){return e.isSyntaxList(t)&&U(t,n)}));return e.Debug.assert(!t||e.contains(t.getChildren(),n)),t}function te(e){return 87===e.kind}function re(e){return 83===e.kind}function ae(e){return 97===e.kind}function ie(n){if(e.isNamedDeclaration(n))return n.name;if(e.isClassDeclaration(n)){var t=e.find(n.modifiers,te);if(t)return t}if(e.isClassExpression(n)){var r=e.find(n.getChildren(),re);if(r)return r}}function oe(n){if(e.isNamedDeclaration(n))return n.name;if(e.isFunctionDeclaration(n)){var t=e.find(n.modifiers,te);if(t)return t}if(e.isFunctionExpression(n)){var r=e.find(n.getChildren(),ae);if(r)return r}}function se(n){var t;return e.findAncestor(n,(function(n){return e.isTypeNode(n)&&(t=n),!e.isQualifiedName(n.parent)&&!e.isTypeNode(n.parent)&&!e.isTypeElement(n.parent)})),t}function ce(e,n){var t=n.getContextualType(e);if(t)return t;var r=se(e);return r&&n.getTypeAtLocation(r)}function le(n,t){if(!t)switch(n.kind){case 253:case 222:return ie(n);case 252:case 209:return oe(n)}if(e.isNamedDeclaration(n))return n.name}function ue(n,t){if(n.importClause){if(n.importClause.name&&n.importClause.namedBindings)return;if(n.importClause.name)return n.importClause.name;if(n.importClause.namedBindings){if(e.isNamedImports(n.importClause.namedBindings)){var r=e.singleOrUndefined(n.importClause.namedBindings.elements);if(!r)return;return r.name}if(e.isNamespaceImport(n.importClause.namedBindings))return n.importClause.namedBindings.name}}if(!t)return n.moduleSpecifier}function de(n,t){if(n.exportClause){if(e.isNamedExports(n.exportClause)){var r=e.singleOrUndefined(n.exportClause.elements);if(!r)return;return n.exportClause.elements[0].name}if(e.isNamespaceExport(n.exportClause))return n.exportClause.name}if(!t)return n.moduleSpecifier}function pe(e){if(1===e.types.length)return e.types[0].expression}function fe(n,t){var r=n.parent;if(e.isModifier(n)&&(t||87!==n.kind)?e.contains(r.modifiers,n):83===n.kind?e.isClassDeclaration(r)||e.isClassExpression(n):97===n.kind?e.isFunctionDeclaration(r)||e.isFunctionExpression(n):117===n.kind?e.isInterfaceDeclaration(r):91===n.kind?e.isEnumDeclaration(r):149===n.kind?e.isTypeAliasDeclaration(r):140===n.kind||139===n.kind?e.isModuleDeclaration(r):99===n.kind?e.isImportEqualsDeclaration(r):134===n.kind?e.isGetAccessorDeclaration(r):146===n.kind&&e.isSetAccessorDeclaration(r)){var a=le(r,t);if(a)return a}if((112===n.kind||84===n.kind||118===n.kind)&&e.isVariableDeclarationList(r)&&1===r.declarations.length){var i=r.declarations[0];if(e.isIdentifier(i.name))return i.name}if(149===n.kind){if(e.isImportClause(r)&&r.isTypeOnly){a=ue(r.parent,t);if(a)return a}if(e.isExportDeclaration(r)&&r.isTypeOnly){a=de(r,t);if(a)return a}}if(126===n.kind){if(e.isImportSpecifier(r)&&r.propertyName||e.isExportSpecifier(r)&&r.propertyName||e.isNamespaceImport(r)||e.isNamespaceExport(r))return r.name;if(e.isExportDeclaration(r)&&r.exportClause&&e.isNamespaceExport(r.exportClause))return r.exportClause.name}if(99===n.kind&&e.isImportDeclaration(r)){a=ue(r,t);if(a)return a}if(92===n.kind){if(e.isExportDeclaration(r)){a=de(r,t);if(a)return a}if(e.isExportAssignment(r))return e.skipOuterExpressions(r.expression)}if(143===n.kind&&e.isExternalModuleReference(r))return r.expression;if(153===n.kind&&(e.isImportDeclaration(r)||e.isExportDeclaration(r))&&r.moduleSpecifier)return r.moduleSpecifier;if((93===n.kind||116===n.kind)&&e.isHeritageClause(r)&&r.token===n.kind){a=pe(r);if(a)return a}if(93===n.kind){if(e.isTypeParameterDeclaration(r)&&r.constraint&&e.isTypeReferenceNode(r.constraint))return r.constraint.typeName;if(e.isConditionalTypeNode(r)&&e.isTypeReferenceNode(r.extendsType))return r.extendsType.typeName}if(135===n.kind&&e.isInferTypeNode(r))return r.typeParameter.name;if(100===n.kind&&e.isTypeParameterDeclaration(r)&&e.isMappedTypeNode(r.parent))return r.name;if(138===n.kind&&e.isTypeOperatorNode(r)&&138===r.operator&&e.isTypeReferenceNode(r.type))return r.type.typeName;if(142===n.kind&&e.isTypeOperatorNode(r)&&142===r.operator&&e.isArrayTypeNode(r.type)&&e.isTypeReferenceNode(r.type.elementType))return r.type.elementType.typeName;if(!t){if((102===n.kind&&e.isNewExpression(r)||113===n.kind&&e.isVoidExpression(r)||111===n.kind&&e.isTypeOfExpression(r)||130===n.kind&&e.isAwaitExpression(r)||124===n.kind&&e.isYieldExpression(r)||88===n.kind&&e.isDeleteExpression(r))&&r.expression)return e.skipOuterExpressions(r.expression);if((100===n.kind||101===n.kind)&&e.isBinaryExpression(r)&&r.operatorToken===n)return e.skipOuterExpressions(r.right);if(126===n.kind&&e.isAsExpression(r)&&e.isTypeReferenceNode(r.type))return r.type.typeName;if(100===n.kind&&e.isForInStatement(r)||157===n.kind&&e.isForOfStatement(r))return e.skipOuterExpressions(r.expression)}return n}function me(e){return fe(e,!1)}function _e(e){return fe(e,!0)}function ge(n,t){return ye(n,t,(function(n){return e.isPropertyNameLiteral(n)||e.isKeyword(n.kind)||e.isPrivateIdentifier(n)}))}function ye(e,n,t){return ve(e,n,!1,t,!1)}function he(e,n){return ve(e,n,!0,void 0,!1)}function ve(e,n,t,r,a){var i=e;e:while(1){for(var o=0,s=i.getChildren(e);o<s.length;o++){var c=s[o],l=t?c.getFullStart():c.getStart(e,!0);if(l>n)break;var u=c.getEnd();if(n<u||n===u&&(1===c.kind||a)){i=c;continue e}if(r&&u===n){var d=Se(n,e,c);if(d&&r(d))return d}}return i}}function be(e,n){var t=he(e,n);while(Ie(t)){var r=Te(t,t.parent,e);if(!r)return;t=r}return t}function Ee(n,t){var r=he(n,t);return e.isToken(r)&&t>r.getStart(n)&&t<r.getEnd()?r:Se(t,n)}function Te(n,t,r){return a(t);function a(t){return e.isToken(t)&&t.pos===n.end?t:e.firstDefined(t.getChildren(r),(function(e){var t=e.pos<=n.pos&&e.end>n.end||e.pos===n.end;return t&&Ue(e,r)?a(e):void 0}))}}function Se(n,t,r,a){var i=o(r||t);return e.Debug.assert(!(i&&Ie(i))),i;function o(i){if(xe(i)&&1!==i.kind)return i;var s=i.getChildren(t),c=e.binarySearchKey(s,n,(function(e,n){return n}),(function(e,t){return n<s[e].end?!s[e-1]||n>=s[e-1].end?0:1:-1}));if(c>=0&&s[c]){var l=s[c];if(n<l.end){var u=l.getStart(t,!a),d=u>=n||!Ue(l,t)||Ie(l);if(d){var p=De(s,c,t);return p&&Le(p,t)}return o(l)}}e.Debug.assert(void 0!==r||298===i.kind||1===i.kind||e.isJSDocCommentContainingNode(i));var f=De(s,s.length,t);return f&&Le(f,t)}}function xe(n){return e.isToken(n)&&!Ie(n)}function Le(e,n){if(xe(e))return e;var t=e.getChildren(n);if(0===t.length)return e;var r=De(t,t.length,n);return r&&Le(r,n)}function De(n,t,r){for(var a=t-1;a>=0;a--){var i=n[a];if(Ie(i))e.Debug.assert(a>0,"`JsxText` tokens should not be the first child of `JsxElement | JsxSelfClosingElement`");else if(Ue(n[a],r))return n[a]}}function Ae(n,t,r){if(void 0===r&&(r=Se(t,n)),r&&e.isStringTextContainingNode(r)){var a=r.getStart(n),i=r.getEnd();if(a<t&&t<i)return!0;if(t===i)return!!r.isUnterminated}return!1}function Ce(e,n){var t=he(e,n);return!!t&&(11===t.kind||(29===t.kind&&11===t.parent.kind||(29===t.kind&&284===t.parent.kind||(!(!t||19!==t.kind||284!==t.parent.kind)||29===t.kind&&277===t.parent.kind))))}function Ie(n){return e.isJsxText(n)&&n.containsOnlyTriviaWhiteSpaces}function Ne(n,t){var r=he(n,t);return e.isTemplateLiteralKind(r.kind)&&t>r.getStart(n)}function ke(n,t){var r=he(n,t);return!!e.isJsxText(r)||(!(18!==r.kind||!e.isJsxExpression(r.parent)||!e.isJsxElement(r.parent.parent))||!(29!==r.kind||!e.isJsxOpeningLikeElement(r.parent)||!e.isJsxElement(r.parent.parent)))}function Re(e,n){function t(t){while(t)if(t.kind>=275&&t.kind<=284||11===t.kind||29===t.kind||31===t.kind||78===t.kind||19===t.kind||18===t.kind||43===t.kind)t=t.parent;else{if(274!==t.kind)return!1;if(n>t.getStart(e))return!0;t=t.parent}return!1}return t(he(e,n))}function Oe(n,t,r){var a=e.tokenToString(n.kind),i=e.tokenToString(t),o=n.getFullStart(),s=r.text.lastIndexOf(i,o);if(-1!==s){if(r.text.lastIndexOf(a,o-1)<s){var c=Se(s+1,r);if(c&&c.kind===t)return c}var l=n.kind,u=0;while(1){var d=Se(n.getFullStart(),r);if(!d)return;if(n=d,n.kind===t){if(0===u)return n;u--}else n.kind===l&&u++}}}function we(e,n,t){return n?e.getNonNullableType():t?e.getNonOptionalType():e}function Pe(n,t,r){var a=Fe(n,t);return void 0!==a&&(e.isPartOfTypeNode(a.called)||0!==Me(a.called,a.nTypeArguments,r).length||Pe(a.called,t,r))}function Me(n,t,r){var a=r.getTypeAtLocation(n);e.isOptionalChain(n.parent)&&(a=we(a,e.isOptionalChainRoot(n.parent),!0));var i=e.isNewExpression(n.parent)?a.getConstructSignatures():a.getCallSignatures();return i.filter((function(e){return!!e.typeParameters&&e.typeParameters.length>=t}))}function Fe(n,t){if(-1!==t.text.lastIndexOf("<",n?n.pos:t.text.length)){var r=n,a=0,i=0;while(r){switch(r.kind){case 29:if(r=Se(r.getFullStart(),t),r&&28===r.kind&&(r=Se(r.getFullStart(),t)),!r||!e.isIdentifier(r))return;if(!a)return e.isDeclarationName(r)?void 0:{called:r,nTypeArguments:i};a--;break;case 49:a=3;break;case 48:a=2;break;case 31:a++;break;case 19:if(r=Oe(r,18,t),!r)return;break;case 21:if(r=Oe(r,20,t),!r)return;break;case 23:if(r=Oe(r,22,t),!r)return;break;case 27:i++;break;case 38:case 78:case 10:case 8:case 9:case 109:case 94:case 111:case 93:case 138:case 24:case 51:case 57:case 58:break;default:if(e.isTypeNode(r))break;return}r=Se(r.getFullStart(),t)}}}function Ge(n,t,r){return e.formatting.getRangeOfEnclosingComment(n,t,void 0,r)}function Be(n,t){var r=he(n,t);return!!e.findAncestor(r,e.isJSDoc)}function Ue(e,n){return 1===e.kind?!!e.jsDoc:0!==e.getWidth(n)}function Ve(n,t){void 0===t&&(t=0);var r=[],a=e.isDeclaration(n)?e.getCombinedNodeFlagsAlwaysIncludeJSDoc(n)&~t:0;return 8&a&&r.push("private"),16&a&&r.push("protected"),4&a&&r.push("public"),32&a&&r.push("static"),128&a&&r.push("abstract"),1&a&&r.push("export"),8192&a&&r.push("deprecated"),8388608&n.flags&&r.push("declare"),267===n.kind&&r.push("export"),r.length>0?r.join(","):""}function je(n){return 174===n.kind||204===n.kind?n.typeArguments:e.isFunctionLike(n)||253===n.kind||254===n.kind?n.typeParameters:void 0}function Ke(e){return 2===e||3===e}function He(n){return!(10!==n&&13!==n&&!e.isTemplateLiteralKind(n))}function We(e){return 18<=e&&e<=77}function ze(n,t,r){return e.isTemplateLiteralKind(n.kind)&&n.getStart(r)<t&&t<n.end||!!n.isUnterminated&&t===n.end}function qe(e){switch(e){case 122:case 120:case 121:return!0}return!1}function Je(n){var t=e.clone(n);return e.setConfigFileInOptions(t,n&&n.configFile),t}function Xe(e){if(200===e.kind||201===e.kind){if(217===e.parent.kind&&e.parent.left===e&&62===e.parent.operatorToken.kind)return!0;if(240===e.parent.kind&&e.parent.initializer===e)return!0;if(Xe(289===e.parent.kind?e.parent.parent:e.parent))return!0}return!1}function Ye(e,n){return Ze(e,n,!0)}function Qe(e,n){return Ze(e,n,!1)}function Ze(e,n,t){var r=Ge(e,n,void 0);return!!r&&t===G.test(e.text.substring(r.pos,r.end))}function $e(e){if(e)switch(e.kind){case 10:case 14:return nn(e);default:return en(e)}}function en(n,t,r){return e.createTextSpanFromBounds(n.getStart(t),(r||n).getEnd())}function nn(n){if(!n.isUnterminated)return e.createTextSpanFromBounds(n.getStart()+1,n.getEnd()-1)}function tn(n,t){return e.createRange(n.getStart(t),n.end)}function rn(n){return e.createTextSpanFromBounds(n.pos,n.end)}function an(n){return e.createRange(n.start,n.start+n.length)}function on(n,t,r){return sn(e.createTextSpan(n,t),r)}function sn(e,n){return{span:e,newText:n}}function cn(n){return e.contains(e.typeKeywords,n)}function ln(e){return 149===e.kind}function un(e){return!!(1536&e.flags)&&34===e.name.charCodeAt(0)}function dn(){var n=[];return function(t){var r=e.getNodeId(t);return!n[r]&&(n[r]=!0)}}function pn(e){return e.getText(0,e.getLength())}function fn(e,n){for(var t="",r=0;r<n;r++)t+=e;return t}function mn(e){return e.isTypeParameter()&&e.getConstraint()||e}function _n(n){return 159===n.kind?e.isStringOrNumericLiteralLike(n.expression)?n.expression.text:void 0:e.isPrivateIdentifier(n)?e.idText(n):e.getTextOfIdentifierOrLiteral(n)}function gn(e){return e.getSourceFiles().some((function(n){return!n.isDeclarationFile&&!e.isSourceFileFromExternalLibrary(n)&&!(!n.externalModuleIndicator&&!n.commonJsModuleIndicator)}))}function yn(e){return e.getSourceFiles().some((function(n){return!n.isDeclarationFile&&!e.isSourceFileFromExternalLibrary(n)&&!!n.externalModuleIndicator}))}function hn(e){return!!e.module||e.target>=2||!!e.noEmit}function vn(n,t){return{fileExists:function(e){return n.fileExists(e)},getCurrentDirectory:function(){return t.getCurrentDirectory()},readFile:e.maybeBind(t,t.readFile),useCaseSensitiveFileNames:e.maybeBind(t,t.useCaseSensitiveFileNames),getSymlinkCache:e.maybeBind(t,t.getSymlinkCache)||n.getSymlinkCache,getModuleSpecifierCache:e.maybeBind(t,t.getModuleSpecifierCache),getGlobalTypingsCacheLocation:e.maybeBind(t,t.getGlobalTypingsCacheLocation),getSourceFiles:function(){return n.getSourceFiles()},redirectTargetsMap:n.redirectTargetsMap,getProjectReferenceRedirect:function(e){return n.getProjectReferenceRedirect(e)},isSourceOfProjectReferenceRedirect:function(e){return n.isSourceOfProjectReferenceRedirect(e)},getNearestAncestorDirectoryWithPackageJson:e.maybeBind(t,t.getNearestAncestorDirectoryWithPackageJson),getFileIncludeReasons:function(){return n.getFileIncludeReasons()}}}function bn(e,n){return o(o({},vn(e,n)),{getCommonSourceDirectory:function(){return e.getCommonSourceDirectory()}})}function En(e,n,t,r){return e||n&&n.length?Tn(e,n,t,r):void 0}function Tn(n,t,r,a,i){return e.factory.createImportDeclaration(void 0,void 0,n||t?e.factory.createImportClause(!!i,n,t&&t.length?e.factory.createNamedImports(t):void 0):void 0,"string"===typeof r?Sn(r,a):r)}function Sn(n,t){return e.factory.createStringLiteral(n,0===t)}function xn(n,t){return e.isStringDoubleQuoted(n,t)?1:0}function Ln(n,t){if(t.quotePreference&&"auto"!==t.quotePreference)return"single"===t.quotePreference?0:1;var r=n.imports&&e.find(n.imports,(function(n){return e.isStringLiteral(n)&&!e.nodeIsSynthesized(n.parent)}));return r?xn(r,n):1}function Dn(n){switch(n){case 0:return"'";case 1:return'"';default:return e.Debug.assertNever(n)}}function An(n){var t=Cn(n);return void 0===t?void 0:e.unescapeLeadingUnderscores(t)}function Cn(n){return"default"!==n.escapedName?n.escapedName:e.firstDefined(n.declarations,(function(n){var t=e.getNameOfDeclaration(n);return t&&78===t.kind?t.escapedText:void 0}))}function In(n){return e.isStringLiteralLike(n)&&(e.isExternalModuleReference(n.parent)||e.isImportDeclaration(n.parent)||e.isRequireCall(n.parent,!1)&&n.parent.arguments[0]===n||e.isImportCall(n.parent)&&n.parent.arguments[0]===n)}function Nn(n){return e.isBindingElement(n)&&e.isObjectBindingPattern(n.parent)&&e.isIdentifier(n.name)&&!n.propertyName}function kn(e,n){var t=e.getTypeAtLocation(n.parent);return t&&e.getPropertyOfType(t,n.name.text)}function Rn(n,t,r){if(n)while(n.parent){if(e.isSourceFile(n.parent)||!On(r,n.parent,t))return n;n=n.parent}}function On(n,t,r){return e.textSpanContainsPosition(n,t.getStart(r))&&t.getEnd()<=e.textSpanEnd(n)}function wn(n,t){return n.modifiers&&e.find(n.modifiers,(function(e){return e.kind===t}))}function Pn(n,t,r,a){var i=e.isArray(r)?r[0]:r,o=233===i.kind?e.isRequireVariableStatement:e.isAnyImportSyntax,s=e.filter(t.statements,o),c=e.isArray(r)?e.stableSort(r,e.OrganizeImports.compareImportsOrRequireStatements):[r];if(s.length)if(s&&e.OrganizeImports.importsAreSorted(s))for(var l=0,u=c;l<u.length;l++){var d=u[l],p=e.OrganizeImports.getImportDeclarationInsertionIndex(s,d);if(0===p){var f=s[0]===t.statements[0]?{leadingTriviaOption:e.textChanges.LeadingTriviaOption.Exclude}:{};n.insertNodeBefore(t,s[0],d,!1,f)}else{var m=s[p-1];n.insertNodeAfter(t,m,d)}}else{var _=e.lastOrUndefined(s);_?n.insertNodesAfter(t,_,c):n.insertNodesAtTopOfFile(t,c,a)}else n.insertNodesAtTopOfFile(t,c,a)}function Mn(n,t){return e.Debug.assert(n.isTypeOnly),e.cast(n.getChildAt(0,t),ln)}function Fn(e,n){return!!e&&!!n&&e.start===n.start&&e.length===n.length}function Gn(e,n){return e.fileName===n.fileName&&Fn(e.textSpan,n.textSpan)}function Bn(e,n){if(e)for(var t=0;t<e.length;t++)if(e.indexOf(e[t])===t){var r=n(e[t],t);if(r)return r}}function Un(n,t,r){for(var a=t;a<r;a++)if(!e.isWhiteSpaceLike(n.charCodeAt(a)))return!1;return!0}function Vn(e){return e.declarations&&e.declarations.length>0&&161===e.declarations[0].kind}e.getLineStartPositionForPosition=B,e.rangeContainsRange=U,e.rangeContainsRangeExclusive=V,e.rangeContainsPosition=j,e.rangeContainsPositionExclusive=K,e.startEndContainsRange=H,e.rangeContainsStartEnd=W,e.rangeOverlapsWithStartEnd=z,e.nodeOverlapsWithStartEnd=q,e.startEndOverlapsWithStartEnd=J,e.positionBelongsToNode=X,e.findListItemInfo=Z,e.hasChildOfKind=$,e.findChildOfKind=ee,e.findContainingList=ne,e.getContextualTypeOrAncestorTypeNodeType=ce,e.getAdjustedReferenceLocation=me,e.getAdjustedRenameLocation=_e,e.getTouchingPropertyName=ge,e.getTouchingToken=ye,e.getTokenAtPosition=he,e.findFirstNonJsxWhitespaceToken=be,e.findTokenOnLeftOfPosition=Ee,e.findNextToken=Te,e.findPrecedingToken=Se,e.isInString=Ae,e.isInsideJsxElementOrAttribute=Ce,e.isInTemplateString=Ne,e.isInJSXText=ke,e.isInsideJsxElement=Re,e.findPrecedingMatchingToken=Oe,e.removeOptionality=we,e.isPossiblyTypeArgumentPosition=Pe,e.getPossibleGenericSignatures=Me,e.getPossibleTypeArgumentsInfo=Fe,e.isInComment=Ge,e.hasDocComment=Be,e.getNodeModifiers=Ve,e.getTypeArgumentOrTypeParameterList=je,e.isComment=Ke,e.isStringOrRegularExpressionOrTemplateLiteral=He,e.isPunctuation=We,e.isInsideTemplateLiteral=ze,e.isAccessibilityModifier=qe,e.cloneCompilerOptions=Je,e.isArrayLiteralOrObjectLiteralDestructuringPattern=Xe,e.isInReferenceComment=Ye,e.isInNonReferenceComment=Qe,e.getReplacementSpanForContextToken=$e,e.createTextSpanFromNode=en,e.createTextSpanFromStringLiteralLikeContent=nn,e.createTextRangeFromNode=tn,e.createTextSpanFromRange=rn,e.createTextRangeFromSpan=an,e.createTextChangeFromStartLength=on,e.createTextChange=sn,e.typeKeywords=[128,127,155,131,94,135,138,141,103,144,145,142,147,148,109,113,150,151,152],e.isTypeKeyword=cn,e.isTypeKeywordToken=ln,e.isExternalModuleSymbol=un,e.nodeSeenTracker=dn,e.getSnapshotText=pn,e.repeatString=fn,e.skipConstraint=mn,e.getNameFromPropertyName=_n,e.programContainsModules=gn,e.programContainsEs6Modules=yn,e.compilerOptionsIndicateEs6Modules=hn,e.createModuleSpecifierResolutionHost=vn,e.getModuleSpecifierResolverHost=bn,e.makeImportIfNecessary=En,e.makeImport=Tn,e.makeStringLiteral=Sn,function(e){e[e["Single"]=0]="Single",e[e["Double"]=1]="Double"}(e.QuotePreference||(e.QuotePreference={})),e.quotePreferenceFromString=xn,e.getQuotePreference=Ln,e.getQuoteFromPreference=Dn,e.symbolNameNoDefault=An,e.symbolEscapedNameNoDefault=Cn,e.isModuleSpecifierLike=In,e.isObjectBindingElementWithoutPropertyName=Nn,e.getPropertySymbolFromBindingElement=kn,e.getParentNodeInSpan=Rn,e.findModifier=wn,e.insertImports=Pn,e.getTypeKeywordOfTypeOnlyImport=Mn,e.textSpansEqual=Fn,e.documentSpansEqual=Gn,e.forEachUnique=Bn,e.isTextWhiteSpaceLike=Un,e.isFirstDeclarationOfSymbolParameter=Vn;var jn=Kn();function Kn(){var n,t,r,a,i=10*e.defaultMaximumTruncationLength;d();var o=function(n){return c(n,e.SymbolDisplayPartKind.text)};return{displayParts:function(){var t=n.length&&n[n.length-1].text;return a>i&&t&&"..."!==t&&(e.isWhiteSpaceLike(t.charCodeAt(t.length-1))||n.push(Wn(" ",e.SymbolDisplayPartKind.space)),n.push(Wn("...",e.SymbolDisplayPartKind.punctuation))),n},writeKeyword:function(n){return c(n,e.SymbolDisplayPartKind.keyword)},writeOperator:function(n){return c(n,e.SymbolDisplayPartKind.operator)},writePunctuation:function(n){return c(n,e.SymbolDisplayPartKind.punctuation)},writeTrailingSemicolon:function(n){return c(n,e.SymbolDisplayPartKind.punctuation)},writeSpace:function(n){return c(n,e.SymbolDisplayPartKind.space)},writeStringLiteral:function(n){return c(n,e.SymbolDisplayPartKind.stringLiteral)},writeParameter:function(n){return c(n,e.SymbolDisplayPartKind.parameterName)},writeProperty:function(n){return c(n,e.SymbolDisplayPartKind.propertyName)},writeLiteral:function(n){return c(n,e.SymbolDisplayPartKind.stringLiteral)},writeSymbol:l,writeLine:u,write:o,writeComment:o,getText:function(){return""},getTextPos:function(){return 0},getColumn:function(){return 0},getLine:function(){return 0},isAtStartOfLine:function(){return!1},hasTrailingWhitespace:function(){return!1},hasTrailingComment:function(){return!1},rawWrite:e.notImplemented,getIndent:function(){return r},increaseIndent:function(){r++},decreaseIndent:function(){r--},clear:d,trackSymbol:e.noop,reportInaccessibleThisError:e.noop,reportInaccessibleUniqueSymbolError:e.noop,reportPrivateInBaseOfClassExpression:e.noop};function s(){if(!(a>i)&&t){var o=e.getIndentString(r);o&&(a+=o.length,n.push(Wn(o,e.SymbolDisplayPartKind.space))),t=!1}}function c(e,t){a>i||(s(),a+=e.length,n.push(Wn(e,t)))}function l(e,t){a>i||(s(),a+=e.length,n.push(Hn(e,t)))}function u(){a>i||(a+=1,n.push(ct()),t=!0)}function d(){n=[],t=!0,r=0,a=0}}function Hn(n,t){return Wn(n,r(t));function r(n){var t=n.flags;return 3&t?Vn(n)?e.SymbolDisplayPartKind.parameterName:e.SymbolDisplayPartKind.localName:4&t||32768&t||65536&t?e.SymbolDisplayPartKind.propertyName:8&t?e.SymbolDisplayPartKind.enumMemberName:16&t?e.SymbolDisplayPartKind.functionName:32&t?e.SymbolDisplayPartKind.className:64&t?e.SymbolDisplayPartKind.interfaceName:384&t?e.SymbolDisplayPartKind.enumName:1536&t?e.SymbolDisplayPartKind.moduleName:8192&t?e.SymbolDisplayPartKind.methodName:262144&t?e.SymbolDisplayPartKind.typeParameterName:524288&t||2097152&t?e.SymbolDisplayPartKind.aliasName:e.SymbolDisplayPartKind.text}}function Wn(n,t){return{text:n,kind:e.SymbolDisplayPartKind[t]}}function zn(){return Wn(" ",e.SymbolDisplayPartKind.space)}function qn(n){return Wn(e.tokenToString(n),e.SymbolDisplayPartKind.keyword)}function Jn(n){return Wn(e.tokenToString(n),e.SymbolDisplayPartKind.punctuation)}function Xn(n){return Wn(e.tokenToString(n),e.SymbolDisplayPartKind.operator)}function Yn(n){return Wn(n,e.SymbolDisplayPartKind.parameterName)}function Qn(n){return Wn(n,e.SymbolDisplayPartKind.propertyName)}function Zn(n){var t=e.stringToToken(n);return void 0===t?$n(n):qn(t)}function $n(n){return Wn(n,e.SymbolDisplayPartKind.text)}function et(n){return Wn(n,e.SymbolDisplayPartKind.aliasName)}function nt(n){return Wn(n,e.SymbolDisplayPartKind.typeParameterName)}function tt(n){return Wn(n,e.SymbolDisplayPartKind.linkText)}function rt(n,t){return{text:e.getTextOfNode(n),kind:e.SymbolDisplayPartKind[e.SymbolDisplayPartKind.linkName],target:{fileName:e.getSourceFileOfNode(t).fileName,textSpan:en(t)}}}function at(n){return Wn(n,e.SymbolDisplayPartKind.link)}function it(n,t){var r,a=[at("{@link ")];if(n.name){var i=null===t||void 0===t?void 0:t.getSymbolAtLocation(n.name),o=(null===i||void 0===i?void 0:i.valueDeclaration)||(null===(r=null===i||void 0===i?void 0:i.declarations)||void 0===r?void 0:r[0]);o?(a.push(rt(n.name,o)),n.text&&a.push(tt(n.text))):a.push(tt(e.getTextOfNode(n.name)+n.text))}else n.text&&a.push(tt(n.text));return a.push(at("}")),a}e.symbolPart=Hn,e.displayPart=Wn,e.spacePart=zn,e.keywordPart=qn,e.punctuationPart=Jn,e.operatorPart=Xn,e.parameterNamePart=Yn,e.propertyNamePart=Qn,e.textOrKeywordPart=Zn,e.textPart=$n,e.typeAliasNamePart=et,e.typeParameterNamePart=nt,e.linkTextPart=tt,e.linkNamePart=rt,e.linkPart=at,e.buildLinkParts=it;var ot="\r\n";function st(e,n){var t;return(null===n||void 0===n?void 0:n.newLineCharacter)||(null===(t=e.getNewLine)||void 0===t?void 0:t.call(e))||ot}function ct(){return Wn("\n",e.SymbolDisplayPartKind.lineBreak)}function lt(e){try{return e(jn),jn.displayParts()}finally{jn.clear()}}function ut(e,n,t,r){return void 0===r&&(r=0),lt((function(a){e.writeType(n,t,17408|r,a)}))}function dt(e,n,t,r,a){return void 0===a&&(a=0),lt((function(i){e.writeSymbol(n,t,r,8|a,i)}))}function pt(e,n,t,r){return void 0===r&&(r=0),r|=25632,lt((function(a){e.writeSignature(n,t,r,void 0,a)}))}function ft(n){return!!n.parent&&e.isImportOrExportSpecifier(n.parent)&&n.parent.propertyName===n}function mt(n,t){return e.ensureScriptKind(n,t.getScriptKind&&t.getScriptKind(n))}function _t(n,t){var r=n;while(yt(r)||gt(r)&&r.target)r=gt(r)&&r.target?r.target:e.skipAlias(r,t);return r}function gt(e){return 0!==(33554432&e.flags)}function yt(e){return 0!==(2097152&e.flags)}function ht(n,t){return e.getSymbolId(e.skipAlias(n,t))}function vt(n,t){while(e.isWhiteSpaceLike(n.charCodeAt(t)))t+=1;return t}function bt(n,t){while(t>-1&&e.isWhiteSpaceSingleLine(n.charCodeAt(t)))t-=1;return t+1}function Et(e,n){void 0===n&&(n=!0);var t=e&&St(e);return t&&!n&&Dt(t),t}function Tt(n,t,r){var a=r(n);return a?e.setOriginalNode(a,n):a=St(n,r),a&&!t&&Dt(a),a}function St(n,t){var r=t?e.visitEachChild(n,(function(e){return Tt(e,!0,t)}),e.nullTransformationContext):e.visitEachChild(n,Et,e.nullTransformationContext);if(r===n){var a=e.isStringLiteral(n)?e.setOriginalNode(e.factory.createStringLiteralFromNode(n),n):e.isNumericLiteral(n)?e.setOriginalNode(e.factory.createNumericLiteral(n.text,n.numericLiteralFlags),n):e.factory.cloneNode(n);return e.setTextRange(a,n)}return r.parent=void 0,r}function xt(n,t){return void 0===t&&(t=!0),n&&e.factory.createNodeArray(n.map((function(e){return Et(e,t)})),n.hasTrailingComma)}function Lt(n,t,r){return e.factory.createNodeArray(n.map((function(e){return Tt(e,t,r)})),n.hasTrailingComma)}function Dt(e){At(e),Ct(e)}function At(e){kt(e,512,Rt)}function Ct(n){kt(n,1024,e.getLastChild)}function It(e,n){var t=e.getSourceFile(),r=t.text;Nt(e,r)?Pt(e,n,t):Ft(e,n,t),Mt(e,n,t)}function Nt(e,n){for(var t=e.getFullStart(),r=e.getStart(),a=t;a<r;a++)if(10===n.charCodeAt(a))return!0;return!1}function kt(n,t,r){e.addEmitFlags(n,t);var a=r(n);a&&kt(a,t,r)}function Rt(e){return e.forEachChild((function(e){return e}))}function Ot(n,t){for(var r=n,a=1;!e.isFileLevelUniqueName(t,r);a++)r=n+"_"+a;return r}function wt(n,t,r,a){for(var i=0,o=-1,s=0,c=n;s<c.length;s++){var l=c[s],u=l.fileName,d=l.textChanges;e.Debug.assert(u===t);for(var p=0,f=d;p<f.length;p++){var m=f[p],_=m.span,g=m.newText,y=Bt(g,r);if(-1!==y&&(o=_.start+i+y,!a))return o;i+=g.length-_.length}}return e.Debug.assert(a),e.Debug.assert(o>=0),o}function Pt(n,t,r,a,i){e.forEachLeadingCommentRange(r.text,n.pos,Gt(t,r,a,i,e.addSyntheticLeadingComment))}function Mt(n,t,r,a,i){e.forEachTrailingCommentRange(r.text,n.end,Gt(t,r,a,i,e.addSyntheticTrailingComment))}function Ft(n,t,r,a,i){e.forEachTrailingCommentRange(r.text,n.pos,Gt(t,r,a,i,e.addSyntheticLeadingComment))}function Gt(e,n,t,r,a){return function(i,o,s,c){3===s?(i+=2,o-=2):i+=2,a(e,t||s,n.text.slice(i,o),void 0!==r?r:c)}}function Bt(n,t){if(e.startsWith(n,t))return 0;var r=n.indexOf(" "+t);return-1===r&&(r=n.indexOf("."+t)),-1===r&&(r=n.indexOf('"'+t)),-1===r?-1:r+1}function Ut(n){return e.isBinaryExpression(n)&&27===n.operatorToken.kind||e.isObjectLiteralExpression(n)||e.isAsExpression(n)&&e.isObjectLiteralExpression(n.expression)}function Vt(e,n){var t=e.parent;switch(t.kind){case 205:return n.getContextualType(t);case 217:var r=t,a=r.left,i=r.operatorToken,o=r.right;return Kt(i.kind)?n.getTypeAtLocation(e===o?a:o):n.getContextualType(e);case 285:return t.expression===e?zt(t,n):void 0;default:return n.getContextualType(e)}}function jt(n,t,r){var a=Ln(n,t),i=JSON.stringify(r);return 0===a?"'"+e.stripQuotes(i).replace(/'/g,"\\'").replace(/\\"/g,'"')+"'":i}function Kt(e){switch(e){case 36:case 34:case 37:case 35:return!0;default:return!1}}function Ht(e){switch(e.kind){case 10:case 14:case 219:case 206:return!0;default:return!1}}function Wt(e){return!!e.getStringIndexType()||!!e.getNumberIndexType()}function zt(e,n){return n.getTypeAtLocation(e.parent.parent.expression)}function qt(e,n,t,r){var a=t.getTypeChecker(),i=!0,o=function(){i=!1},s=a.typeToTypeNode(e,n,1,{trackSymbol:function(e,n,t){i=i&&0===a.isSymbolAccessible(e,n,t,!1).accessibility},reportInaccessibleThisError:o,reportPrivateInBaseOfClassExpression:o,reportInaccessibleUniqueSymbolError:o,moduleResolverHost:bn(t,r)});return i?s:void 0}function Jt(e){return 170===e||171===e||172===e||163===e||165===e}function Xt(e){return 252===e||167===e||166===e||168===e||169===e}function Yt(e){return 257===e}function Qt(e){return 233===e||234===e||236===e||241===e||242===e||243===e||247===e||249===e||164===e||255===e||262===e||261===e||268===e||260===e||267===e}function Zt(n,t){var r=n.getLastToken(t);if(r&&26===r.kind)return!1;if(Jt(n.kind)){if(r&&27===r.kind)return!1}else if(Yt(n.kind)){var a=e.last(n.getChildren(t));if(a&&e.isModuleBlock(a))return!1}else if(Xt(n.kind)){a=e.last(n.getChildren(t));if(a&&e.isFunctionBlock(a))return!1}else if(!Qt(n.kind))return!1;if(236===n.kind)return!0;var i=e.findAncestor(n,(function(e){return!e.parent})),o=Te(n,i,t);if(!o||19===o.kind)return!0;var s=t.getLineAndCharacterOfPosition(n.getEnd()).line,c=t.getLineAndCharacterOfPosition(o.getStart(t)).line;return s!==c}function $t(n,t,r){var a=e.findAncestor(t,(function(t){return t.end!==n?"quit":e.syntaxMayBeASICandidate(t.kind)}));return!!a&&Zt(a,r)}function er(n){var t=0,r=0,a=5;return e.forEachChild(n,(function i(o){if(Qt(o.kind)){var s=o.getLastToken(n);s&&26===s.kind?t++:r++}return t+r>=a||e.forEachChild(o,i)})),0===t&&r<=1||t/r>1/a}function nr(e,n){return or(e,e.getDirectories,n)||[]}function tr(n,t,r,a,i){return or(n,n.readDirectory,t,r,a,i)||e.emptyArray}function rr(e,n){return or(e,e.fileExists,n)}function ar(n,t){return ir((function(){return e.directoryProbablyExists(t,n)}))||!1}function ir(e){try{return e()}catch(n){return}}function or(e,n){for(var t=[],r=2;r<arguments.length;r++)t[r-2]=arguments[r];return ir((function(){return n&&n.apply(e,t)}))}function sr(n,t,r){var a=[];return e.forEachAncestorDirectory(n,(function(n){if(n===r)return!0;var i=e.combinePaths(n,"package.json");rr(t,i)&&a.push(i)})),a}function cr(n,t){var r;return e.forEachAncestorDirectory(n,(function(n){return"node_modules"===n||(r=e.findConfigFile(n,(function(e){return rr(t,e)}),"package.json"),!!r||void 0)})),r}function lr(n,t){if(!t.fileExists)return[];var r=[];return e.forEachAncestorDirectory(e.getDirectoryPath(n),(function(n){var a=e.combinePaths(n,"package.json");if(t.fileExists(a)){var i=ur(a,t);i&&r.push(i)}})),r}function ur(n,t){if(t.readFile){var r=["dependencies","devDependencies","optionalDependencies","peerDependencies"],a=t.readFile(n)||"",i=pr(a),s={};if(i)for(var c=0,l=r;c<l.length;c++){var u=l[c],d=i[u];if(d){var p=new e.Map;for(var f in d)p.set(f,d[f]);s[u]=p}}var m=[[1,s.dependencies],[2,s.devDependencies],[8,s.optionalDependencies],[4,s.peerDependencies]];return o(o({},s),{parseable:!!i,fileName:n,get:_,has:function(e,n){return!!_(e,n)}})}function _(e,n){void 0===n&&(n=15);for(var t=0,r=m;t<r.length;t++){var a=r[t],i=a[0],o=a[1];if(o&&n&i){var s=o.get(e);if(void 0!==s)return s}}}}function dr(n,t){var r,a=(t.getPackageJsonsVisibleToFile&&t.getPackageJsonsVisibleToFile(n.fileName)||lr(n.fileName,t)).filter((function(e){return e.parseable}));return{allowsImportingAmbientModule:o,allowsImportingSourceFile:s,allowsImportingSpecifier:c};function i(n){for(var t=d(n),r=0,i=a;r<i.length;r++){var o=i[r];if(o.has(t)||o.has(e.getTypesPackageName(t)))return!0}return!1}function o(n,t){if(!a.length||!n.valueDeclaration)return!0;var r=n.valueDeclaration.getSourceFile(),o=u(r.fileName,t);if("undefined"===typeof o)return!0;var s=e.stripQuotes(n.getName());return!!l(s)||(i(o)||i(s))}function s(e,n){if(!a.length)return!0;var t=u(e.fileName,n);return!t||i(t)}function c(n){return!(a.length&&!l(n))||(!(!e.pathIsRelative(n)&&!e.isRootedDiskPath(n))||i(n))}function l(t){return!!(e.isSourceFileJS(n)&&e.JsTyping.nodeCoreModules.has(t)&&(void 0===r&&(r=fr(n)),r))}function u(r,a){if(e.stringContains(r,"node_modules")){var i=e.moduleSpecifiers.getNodeModulesPackageName(t.getCompilationSettings(),n.path,r,a);if(i)return e.pathIsRelative(i)||e.isRootedDiskPath(i)?void 0:d(i)}}function d(n){var t=e.getPathComponents(e.getPackageNameFromTypesPackageName(n)).slice(1);return e.startsWith(t[0],"@")?t[0]+"/"+t[1]:t[0]}}function pr(e){try{return JSON.parse(e)}catch(n){return}}function fr(n){return e.some(n.imports,(function(n){var t=n.text;return e.JsTyping.nodeCoreModules.has(t)}))}function mr(n){return e.contains(e.getPathComponents(n),"node_modules")}function _r(e){return void 0!==e.file&&void 0!==e.start&&void 0!==e.length}function gr(n,t){var r=en(n),a=e.binarySearchKey(t,r,e.identity,e.compareTextSpans);if(a>=0){var i=t[a];return e.Debug.assertEqual(i.file,n.getSourceFile(),"Diagnostics proided to 'findDiagnosticForNode' must be from a single SourceFile"),e.cast(i,_r)}}function yr(n,t){var r,a=e.binarySearchKey(t,n.start,(function(e){return e.start}),e.compareValues);a<0&&(a=~a);while((null===(r=t[a-1])||void 0===r?void 0:r.start)===n.start)a--;var i=[],o=e.textSpanEnd(n);while(1){var s=e.tryCast(t[a],_r);if(!s||s.start>o)break;e.textSpanContainsTextSpan(n,s)&&i.push(s),a++}return i}function hr(n){var t=n.startPosition,r=n.endPosition;return e.createTextSpanFromBounds(t,void 0===r?t:r)}function vr(n,t,r){return void 0===r&&(r=e.identity),n?e.isArray(n)?r(e.map(n,t)):t(n,0):void 0}function br(n){return e.isArray(n)?e.first(n):n}function Er(n,t){return 33554432&n.flags||"export="!==n.escapedName&&"default"!==n.escapedName?n.name:e.firstDefined(n.declarations,(function(n){var t;return e.isExportAssignment(n)?null===(t=e.tryCast(e.skipOuterExpressions(n.expression),e.isIdentifier))||void 0===t?void 0:t.text:void 0}))||e.codefix.moduleSymbolToValidIdentifier(Tr(n),t)}function Tr(n){var t;return e.Debug.checkDefined(n.parent,"Symbol parent was undefined. Flags: "+e.Debug.formatSymbolFlags(n.flags)+". Declarations: "+(null===(t=n.declarations)||void 0===t?void 0:t.map((function(n){var t=e.Debug.formatSyntaxKind(n.kind),r=e.isInJSFile(n),a=n.expression;return(r?"[JS]":"")+t+(a?" (expression: "+e.Debug.formatSyntaxKind(a.kind)+")":"")})).join(", "))+".")}function Sr(e,n,t){var r=n.length;if(r+t>e.length)return!1;for(var a=0;a<r;a++)if(n.charCodeAt(a)!==e.charCodeAt(a+t))return!1;return!0}function xr(e){return 95===e.charCodeAt(0)}function Lr(e){return!Dr(e)}function Dr(n){var t=n.getSourceFile();return!(!t.externalModuleIndicator&&!t.commonJsModuleIndicator)&&(e.isInJSFile(n)||!e.findAncestor(n,e.isGlobalScopeAugmentation))}function Ar(){var n,t,r,a={isEmpty:function(){return!n},clear:function(){n=void 0,t=void 0},set:function(e,r){n=e,r&&(t=r)},get:function(e,a,i){if(!r||e===r)return i&&t===i||null===n||void 0===n||n.forEach((function(e){for(var n,t,r,i=0,o=e;i<o.length;i++){var s=o[i];(null===(n=s.symbol.declarations)||void 0===n?void 0:n.length)&&(s.symbol=a.getMergedSymbol(1===s.exportKind&&null!==(t=s.symbol.declarations[0].localSymbol)&&void 0!==t?t:s.symbol.declarations[0].symbol)),(null===(r=s.moduleSymbol.declarations)||void 0===r?void 0:r.length)&&(s.moduleSymbol=a.getMergedSymbol(s.moduleSymbol.declarations[0].symbol))}})),n},onFileChanged:function(n,t,a){return(!i(n)||!i(t))&&(r&&r!==t.path||a&&fr(n)!==fr(t)||!e.arrayIsEqualTo(n.moduleAugmentations,t.moduleAugmentations)||!o(n,t)?(this.clear(),!0):(r=t.path,!1))}};return e.Debug.isDebugging&&Object.defineProperty(a,"__cache",{get:function(){return n}}),a;function i(e){return!e.commonJsModuleIndicator&&!e.externalModuleIndicator&&!e.moduleAugmentations&&!e.ambientModuleNames}function o(n,t){if(!e.arrayIsEqualTo(n.ambientModuleNames,t.ambientModuleNames))return!1;for(var r=-1,a=-1,i=function(i){var o=function(n){return e.isNonGlobalAmbientModule(n)&&n.name.text===i};if(r=e.findIndex(n.statements,o,r+1),a=e.findIndex(t.statements,o,a+1),n.statements[r]!==t.statements[a])return{value:!1}},o=0,s=t.ambientModuleNames;o<s.length;o++){var c=s[o],l=i(c);if("object"===typeof l)return l.value}return!0}}function Cr(){var n,t,r={get:function(e,r){if(n&&e===t)return n.get(r)},set:function(r,a,i){n&&r!==t&&n.clear(),t=r,(n||(n=new e.Map)).set(a,i)},clear:function(){n=void 0,t=void 0},count:function(){return n?n.size:0}};return e.Debug.isDebugging&&Object.defineProperty(r,"__cache",{get:function(){return n}}),r}function Ir(n,t,r,a,i,o){var s;if(t===r)return!1;var c=null===o||void 0===o?void 0:o.get(t.path,r.path);if(void 0!==c)return!!c;var l=e.hostGetCanonicalFileName(i),u=null===(s=i.getGlobalTypingsCacheLocation)||void 0===s?void 0:s.call(i),d=!!e.moduleSpecifiers.forEachFileNameOfModule(t.fileName,r.fileName,i,!1,(function(e){var a=n.getSourceFile(e);return(a===r||!a)&&Nr(t.fileName,e,l,u)}));if(a){var p=d&&a.allowsImportingSourceFile(r,i);return null===o||void 0===o||o.set(t.path,r.path,p),p}return d}function Nr(n,t,r,a){var i=e.forEachAncestorDirectory(t,(function(n){return"node_modules"===e.getBaseFileName(n)?n:void 0})),o=i&&e.getDirectoryPath(r(i));return void 0===o||e.startsWith(r(n),o)||!!a&&e.startsWith(r(a),o)}e.getNewLineOrDefaultFromHost=st,e.lineBreakPart=ct,e.mapToDisplayParts=lt,e.typeToDisplayParts=ut,e.symbolToDisplayParts=dt,e.signatureToDisplayParts=pt,e.isImportOrExportSpecifierName=ft,e.getScriptKind=mt,e.getSymbolTarget=_t,e.getUniqueSymbolId=ht,e.getFirstNonSpaceCharacterPosition=vt,e.getPrecedingNonSpaceCharacterPosition=bt,e.getSynthesizedDeepClone=Et,e.getSynthesizedDeepCloneWithReplacements=Tt,e.getSynthesizedDeepClones=xt,e.getSynthesizedDeepClonesWithReplacements=Lt,e.suppressLeadingAndTrailingTrivia=Dt,e.suppressLeadingTrivia=At,e.suppressTrailingTrivia=Ct,e.copyComments=It,e.getUniqueName=Ot,e.getRenameLocation=wt,e.copyLeadingComments=Pt,e.copyTrailingComments=Mt,e.copyTrailingAsLeadingComments=Ft,e.needsParentheses=Ut,e.getContextualTypeFromParent=Vt,e.quote=jt,e.isEqualityOperatorKind=Kt,e.isStringLiteralOrTemplate=Ht,e.hasIndexSignature=Wt,e.getSwitchedType=zt,e.ANONYMOUS="anonymous function",e.getTypeNodeIfAccessible=qt,e.syntaxRequiresTrailingCommaOrSemicolonOrASI=Jt,e.syntaxRequiresTrailingFunctionBlockOrSemicolonOrASI=Xt,e.syntaxRequiresTrailingModuleBlockOrSemicolonOrASI=Yt,e.syntaxRequiresTrailingSemicolonOrASI=Qt,e.syntaxMayBeASICandidate=e.or(Jt,Xt,Yt,Qt),e.positionIsASICandidate=$t,e.probablyUsesSemicolons=er,e.tryGetDirectories=nr,e.tryReadDirectory=tr,e.tryFileExists=rr,e.tryDirectoryExists=ar,e.tryAndIgnoreErrors=ir,e.tryIOAndConsumeErrors=or,e.findPackageJsons=sr,e.findPackageJson=cr,e.getPackageJsonsVisibleToFile=lr,e.createPackageJsonInfo=ur,e.createPackageJsonImportFilter=dr,e.consumesNodeCoreModules=fr,e.isInsideNodeModules=mr,e.isDiagnosticWithLocation=_r,e.findDiagnosticForNode=gr,e.getDiagnosticsWithinSpan=yr,e.getRefactorContextSpan=hr,e.mapOneOrMany=vr,e.firstOrOnly=br,e.getNameForExportedSymbol=Er,e.stringContainsAt=Sr,e.startsWithUnderscore=xr,e.isGlobalDeclaration=Lr,e.isNonGlobalDeclaration=Dr,function(e){e[e["Named"]=0]="Named",e[e["Default"]=1]="Default",e[e["Namespace"]=2]="Namespace",e[e["CommonJS"]=3]="CommonJS"}(e.ImportKind||(e.ImportKind={})),function(e){e[e["Named"]=0]="Named",e[e["Default"]=1]="Default",e[e["ExportEquals"]=2]="ExportEquals",e[e["UMD"]=3]="UMD"}(e.ExportKind||(e.ExportKind={})),e.createExportMapCache=Ar,e.createModuleSpecifierCache=Cr,e.isImportableFile=Ir}(d||(d={})),function(e){function n(){var n=e.createScanner(99,!1);function o(e,n,t){return i(l(e,n,t),e)}function l(i,o,l){var u=0,p=0,f=[],m=c(o),_=m.prefix,g=m.pushTemplate;i=_+i;var y=_.length;g&&f.push(15),n.setText(i);var h=0,v=[],b=0;do{u=n.scan(),e.isTrivia(u)||(S(),p=u);var E=n.getTextPos();if(a(n.getTokenPos(),E,y,d(u),v),E>=i.length){var T=r(n,u,e.lastOrUndefined(f));void 0!==T&&(h=T)}}while(1!==u);function S(){switch(u){case 43:case 67:t[p]||13!==n.reScanSlashToken()||(u=13);break;case 29:78===p&&b++;break;case 31:b>0&&b--;break;case 128:case 147:case 144:case 131:case 148:b>0&&!l&&(u=78);break;case 15:f.push(u);break;case 18:f.length>0&&f.push(u);break;case 19:if(f.length>0){var r=e.lastOrUndefined(f);15===r?(u=n.reScanTemplateToken(!1),17===u?f.pop():e.Debug.assertEqual(u,16,"Should have been a template middle.")):(e.Debug.assertEqual(r,18,"Should have been an open brace"),f.pop())}break;default:if(!e.isKeyword(u))break;(24===p||e.isKeyword(p)&&e.isKeyword(u)&&!s(p,u))&&(u=78)}}return{endOfLineState:h,spans:v}}return{getClassificationsForLine:o,getEncodedLexicalClassifications:l}}e.createClassifier=n;var t=e.arrayToNumericMap([78,10,8,9,13,107,45,46,21,23,19,109,94],(function(e){return e}),(function(){return!0}));function r(n,t,r){switch(t){case 10:if(!n.isUnterminated())return;var a=n.getTokenText(),i=a.length-1,o=0;while(92===a.charCodeAt(i-o))o++;if(0===(1&o))return;return 34===a.charCodeAt(0)?3:2;case 3:return n.isUnterminated()?1:void 0;default:if(e.isTemplateLiteralKind(t)){if(!n.isUnterminated())return;switch(t){case 17:return 5;case 14:return 4;default:return e.Debug.fail("Only 'NoSubstitutionTemplateLiteral's and 'TemplateTail's can be unterminated; got SyntaxKind #"+t)}}return 15===r?6:void 0}}function a(e,n,t,r,a){if(8!==r){0===e&&t>0&&(e+=t);var i=n-e;i>0&&a.push(e-t,i,r)}}function i(n,t){for(var r=[],a=n.spans,i=0,s=0;s<a.length;s+=3){var c=a[s],l=a[s+1],u=a[s+2];if(i>=0){var d=c-i;d>0&&r.push({length:d,classification:e.TokenClass.Whitespace})}r.push({length:l,classification:o(u)}),i=c+l}var p=t.length-i;return p>0&&r.push({length:p,classification:e.TokenClass.Whitespace}),{entries:r,finalLexState:n.endOfLineState}}function o(n){switch(n){case 1:return e.TokenClass.Comment;case 3:return e.TokenClass.Keyword;case 4:return e.TokenClass.NumberLiteral;case 25:return e.TokenClass.BigIntLiteral;case 5:return e.TokenClass.Operator;case 6:return e.TokenClass.StringLiteral;case 8:return e.TokenClass.Whitespace;case 10:return e.TokenClass.Punctuation;case 2:case 11:case 12:case 13:case 14:case 15:case 16:case 9:case 17:return e.TokenClass.Identifier;default:return}}function s(n,t){if(!e.isAccessibilityModifier(n))return!0;switch(t){case 134:case 146:case 132:case 123:return!0;default:return!1}}function c(n){switch(n){case 3:return{prefix:'"\\\n'};case 2:return{prefix:"'\\\n"};case 1:return{prefix:"/*\n"};case 4:return{prefix:"`\n"};case 5:return{prefix:"}\n",pushTemplate:!0};case 6:return{prefix:"",pushTemplate:!0};case 0:return{prefix:""};default:return e.Debug.assertNever(n)}}function l(e){switch(e){case 41:case 43:case 44:case 39:case 40:case 47:case 48:case 49:case 29:case 31:case 32:case 33:case 101:case 100:case 126:case 34:case 35:case 36:case 37:case 50:case 52:case 51:case 55:case 56:case 73:case 72:case 77:case 69:case 70:case 71:case 63:case 64:case 65:case 67:case 68:case 62:case 27:case 60:case 74:case 75:case 76:return!0;default:return!1}}function u(e){switch(e){case 39:case 40:case 54:case 53:case 45:case 46:return!0;default:return!1}}function d(n){if(e.isKeyword(n))return 3;if(l(n)||u(n))return 5;if(n>=18&&n<=77)return 10;switch(n){case 8:return 4;case 9:return 25;case 10:return 6;case 13:return 7;case 7:case 3:case 2:return 1;case 5:case 4:return 8;case 78:default:return e.isTemplateLiteralKind(n)?6:2}}function p(e,n,t,r,a){return h(m(e,n,t,r,a))}function f(e,n){switch(n){case 257:case 253:case 254:case 252:case 222:case 209:case 210:e.throwIfCancellationRequested()}}function m(n,t,r,a,i){var o=[];return r.forEachChild((function o(c){if(c&&e.textSpanIntersectsWith(i,c.pos,c.getFullWidth())){if(f(t,c.kind),e.isIdentifier(c)&&!e.nodeIsMissing(c)&&a.has(c.escapedText)){var l=n.getSymbolAtLocation(c),u=l&&_(l,e.getMeaningFromLocation(c),n);u&&s(c.getStart(r),c.getEnd(),u)}c.forEachChild(o)}})),{spans:o,endOfLineState:0};function s(n,t,r){var a=t-n;e.Debug.assert(a>0,"Classification had non-positive length of "+a),o.push(n),o.push(a),o.push(r)}}function _(e,n,t){var r=e.getFlags();return 0===(2885600&r)?void 0:32&r?11:384&r?12:524288&r?16:1536&r?4&n||1&n&&g(e)?14:void 0:2097152&r?_(t.getAliasedSymbol(e),n,t):2&n?64&r?13:262144&r?15:void 0:void 0}function g(n){return e.some(n.declarations,(function(n){return e.isModuleDeclaration(n)&&1===e.getModuleInstanceState(n)}))}function y(e){switch(e){case 1:return"comment";case 2:return"identifier";case 3:return"keyword";case 4:return"number";case 25:return"bigint";case 5:return"operator";case 6:return"string";case 8:return"whitespace";case 9:return"text";case 10:return"punctuation";case 11:return"class name";case 12:return"enum name";case 13:return"interface name";case 14:return"module name";case 15:return"type parameter name";case 16:return"type alias name";case 17:return"parameter name";case 18:return"doc comment tag name";case 19:return"jsx open tag name";case 20:return"jsx close tag name";case 21:return"jsx self closing tag name";case 22:return"jsx attribute";case 23:return"jsx text";case 24:return"jsx attribute string literal value";default:return}}function h(n){e.Debug.assert(n.spans.length%3===0);for(var t=n.spans,r=[],a=0;a<t.length;a+=3)r.push({textSpan:e.createTextSpan(t[a],t[a+1]),classificationType:y(t[a+2])});return r}function v(e,n,t){return h(b(e,n,t))}function b(n,t,r){var a=r.start,i=r.length,o=e.createScanner(99,!1,t.languageVariant,t.text),s=e.createScanner(99,!1,t.languageVariant,t.text),c=[];return T(t),{spans:c,endOfLineState:0};function l(e,n,t){c.push(e),c.push(n),c.push(t)}function u(n){o.setTextPos(n.pos);while(1){var r=o.getTextPos();if(!e.couldStartTrivia(t.text,r))return r;var a=o.scan(),i=o.getTextPos(),s=i-r;if(!e.isTrivia(a))return r;switch(a){case 4:case 5:continue;case 2:case 3:d(n,a,r,s),o.setTextPos(i);continue;case 7:var c=t.text,u=c.charCodeAt(r);if(60===u||62===u){l(r,s,1);continue}e.Debug.assert(124===u||61===u),y(c,r,i);break;case 6:break;default:e.Debug.assertNever(a)}}}function d(n,r,a,i){if(3===r){var o=e.parseIsolatedJSDocComment(t.text,a,i);if(o&&o.jsDoc)return e.setParent(o.jsDoc,n),void m(o.jsDoc)}else if(2===r&&_(a,i))return;p(a,i)}function p(e,n){l(e,n,1)}function m(e){var n,t,r,a,i,o,s,c=e.pos;if(e.tags)for(var u=0,d=e.tags;u<d.length;u++){var f=d[u];f.pos!==c&&p(c,f.pos-c),l(f.pos,1,10),l(f.tagName.pos,f.tagName.end-f.tagName.pos,18),c=f.tagName.end;var m=f.tagName.end;switch(f.kind){case 330:var _=f;v(_),m=_.isNameFirst&&(null===(n=_.typeExpression)||void 0===n?void 0:n.end)||_.name.end;break;case 337:var y=f;m=y.isNameFirst&&(null===(t=y.typeExpression)||void 0===t?void 0:t.end)||y.name.end;break;case 334:g(f),c=f.end,m=f.typeParameters.end;break;case 335:var h=f;m=302===(null===(r=h.typeExpression)||void 0===r?void 0:r.kind)&&(null===(a=h.fullName)||void 0===a?void 0:a.end)||(null===(i=h.typeExpression)||void 0===i?void 0:i.end)||m;break;case 328:m=f.typeExpression.end;break;case 333:T(f.typeExpression),c=f.end,m=f.typeExpression.end;break;case 332:case 329:m=f.typeExpression.end;break;case 331:T(f.typeExpression),c=f.end,m=(null===(o=f.typeExpression)||void 0===o?void 0:o.end)||m;break;case 336:m=(null===(s=f.name)||void 0===s?void 0:s.end)||m;break;case 318:case 319:m=f.class.end;break}"object"===typeof f.comment?p(f.comment.pos,f.comment.end-f.comment.pos):"string"===typeof f.comment&&p(m,f.end-m)}return void(c!==e.end&&p(c,e.end-c));function v(e){e.isNameFirst&&(p(c,e.name.pos-c),l(e.name.pos,e.name.end-e.name.pos,17),c=e.name.end),e.typeExpression&&(p(c,e.typeExpression.pos-c),T(e.typeExpression),c=e.typeExpression.end),e.isNameFirst||(p(c,e.name.pos-c),l(e.name.pos,e.name.end-e.name.pos,17),c=e.name.end)}}function _(n,r){var a=/^(\/\/\/\s*)(<)(?:(\S+)((?:[^/]|\/[^>])*)(\/>)?)?/im,i=/(\S+)(\s*)(=)(\s*)('[^']+'|"[^"]+")/gim,o=t.text.substr(n,r),s=a.exec(o);if(!s)return!1;if(!s[3]||!(s[3]in e.commentPragmas))return!1;var c=n;p(c,s[1].length),c+=s[1].length,l(c,s[2].length,10),c+=s[2].length,l(c,s[3].length,21),c+=s[3].length;var u=s[4],d=c;while(1){var f=i.exec(u);if(!f)break;var m=c+f.index;m>d&&(p(d,m-d),d=m),l(d,f[1].length,22),d+=f[1].length,f[2].length&&(p(d,f[2].length),d+=f[2].length),l(d,f[3].length,5),d+=f[3].length,f[4].length&&(p(d,f[4].length),d+=f[4].length),l(d,f[5].length,24),d+=f[5].length}c+=s[4].length,c>d&&p(d,c-d),s[5]&&(l(c,s[5].length,10),c+=s[5].length);var _=n+r;return c<_&&p(c,_-c),!0}function g(e){for(var n=0,t=e.getChildren();n<t.length;n++){var r=t[n];T(r)}}function y(n,t,r){var a;for(a=t;a<r;a++)if(e.isLineBreak(n.charCodeAt(a)))break;l(t,a-t,1),s.setTextPos(a);while(s.getTextPos()<r)h()}function h(){var e=s.getTextPos(),n=s.scan(),t=s.getTextPos(),r=E(n);r&&l(e,t-e,r)}function v(n){if(e.isJSDoc(n))return!0;if(e.nodeIsMissing(n))return!0;var t=b(n);if(!e.isToken(n)&&11!==n.kind&&void 0===t)return!1;var r=11===n.kind?n.pos:u(n),a=n.end-r;if(e.Debug.assert(a>=0),a>0){var i=t||E(n.kind,n);i&&l(r,a,i)}return!0}function b(e){switch(e.parent&&e.parent.kind){case 276:if(e.parent.tagName===e)return 19;break;case 277:if(e.parent.tagName===e)return 20;break;case 275:if(e.parent.tagName===e)return 21;break;case 281:if(e.parent.name===e)return 22;break}}function E(n,t){if(e.isKeyword(n))return 3;if((29===n||31===n)&&t&&e.getTypeArgumentOrTypeParameterList(t.parent))return 10;if(e.isPunctuation(n)){if(t){var r=t.parent;if(62===n&&(250===r.kind||164===r.kind||161===r.kind||281===r.kind))return 5;if(217===r.kind||215===r.kind||216===r.kind||218===r.kind)return 5}return 10}if(8===n)return 4;if(9===n)return 25;if(10===n)return t&&281===t.parent.kind?24:6;if(13===n)return 6;if(e.isTemplateLiteralKind(n))return 6;if(11===n)return 23;if(78===n){if(t)switch(t.parent.kind){case 253:return t.parent.name===t?11:void 0;case 160:return t.parent.name===t?15:void 0;case 254:return t.parent.name===t?13:void 0;case 256:return t.parent.name===t?12:void 0;case 257:return t.parent.name===t?14:void 0;case 161:return t.parent.name===t?e.isThisIdentifier(t)?3:17:void 0}return 2}}function T(r){if(r&&e.decodedTextSpanIntersectsWith(a,i,r.pos,r.getFullWidth())){f(n,r.kind);for(var o=0,s=r.getChildren(t);o<s.length;o++){var c=s[o];v(c)||T(c)}}}}e.getSemanticClassifications=p,e.getEncodedSemanticClassifications=m,e.getSyntacticClassifications=v,e.getEncodedSyntacticClassifications=b}(d||(d={})),function(e){(function(n){(function(n){function t(n,t,a,i){var o=r(n,t,a,i);e.Debug.assert(o.spans.length%3===0);for(var s=o.spans,c=[],l=0;l<s.length;l+=3)c.push({textSpan:e.createTextSpan(s[l],s[l+1]),classificationType:s[l+2]});return c}function r(e,n,t,r){return{spans:a(e,t,r,n),endOfLineState:0}}function a(e,n,t,r){var a=[],o=function(e,t,r){a.push(e.getStart(n),e.getWidth(n),(t+1<<8)+r)};return e&&n&&i(e,n,t,o,r),a}function i(n,t,r,a,i){var l=n.getTypeChecker(),d=!1;function m(_){switch(_.kind){case 257:case 253:case 254:case 252:case 222:case 209:case 210:i.throwIfCancellationRequested()}if(_&&e.textSpanIntersectsWith(r,_.pos,_.getFullWidth())&&0!==_.getFullWidth()){var g=d;if((e.isJsxElement(_)||e.isJsxSelfClosingElement(_))&&(d=!0),e.isJsxExpression(_)&&(d=!1),e.isIdentifier(_)&&!d&&!u(_)){var y=l.getSymbolAtLocation(_);if(y){2097152&y.flags&&(y=l.getAliasedSymbol(y));var h=o(y,e.getMeaningFromLocation(_));if(void 0!==h){var v=0;if(_.parent){var b=e.isBindingElement(_.parent)||f.get(_.parent.kind)===h;b&&_.parent.name===_&&(v=1)}6===h&&p(_)&&(h=9),h=s(l,_,h);var E=y.valueDeclaration;if(E){var T=e.getCombinedModifierFlags(E),S=e.getCombinedNodeFlags(E);32&T&&(v|=2),256&T&&(v|=4),0!==h&&2!==h&&(64&T||2&S||8&y.getFlags())&&(v|=8),7!==h&&10!==h||!c(E,t)||(v|=32),n.isSourceFileDefaultLibrary(E.getSourceFile())&&(v|=16)}else y.declarations&&y.declarations.some((function(e){return n.isSourceFileDefaultLibrary(e.getSourceFile())}))&&(v|=16);a(_,h,v)}}}e.forEachChild(_,m),d=g}}m(t)}function o(n,t){var r=n.getFlags();if(32&r)return 0;if(384&r)return 1;if(524288&r)return 5;if(64&r){if(2&t)return 2}else if(262144&r)return 4;var a=n.valueDeclaration||n.declarations&&n.declarations[0];return a&&e.isBindingElement(a)&&(a=l(a)),a&&f.get(a.kind)}function s(e,n,t){if(7===t||9===t||6===t){var r=e.getTypeAtLocation(n);if(r){var a=function(e){return e(r)||r.isUnion()&&r.types.some(e)};if(6!==t&&a((function(e){return e.getConstructSignatures().length>0})))return 0;if(a((function(e){return e.getCallSignatures().length>0}))&&!a((function(e){return e.getProperties().length>0}))||d(n))return 9===t?11:10}}return t}function c(n,t){return e.isBindingElement(n)&&(n=l(n)),e.isVariableDeclaration(n)?(!e.isSourceFile(n.parent.parent.parent)||e.isCatchClause(n.parent))&&n.getSourceFile()===t:!!e.isFunctionDeclaration(n)&&(!e.isSourceFile(n.parent)&&n.getSourceFile()===t)}function l(n){while(1){if(!e.isBindingElement(n.parent.parent))return n.parent.parent;n=n.parent.parent}}function u(n){var t=n.parent;return t&&(e.isImportClause(t)||e.isImportSpecifier(t)||e.isNamespaceImport(t))}function d(n){while(p(n))n=n.parent;return e.isCallExpression(n.parent)&&n.parent.expression===n}function p(n){return e.isQualifiedName(n.parent)&&n.parent.right===n||e.isPropertyAccessExpression(n.parent)&&n.parent.name===n}(function(e){e[e["typeOffset"]=8]="typeOffset",e[e["modifierMask"]=255]="modifierMask"})(n.TokenEncodingConsts||(n.TokenEncodingConsts={})),function(e){e[e["class"]=0]="class",e[e["enum"]=1]="enum",e[e["interface"]=2]="interface",e[e["namespace"]=3]="namespace",e[e["typeParameter"]=4]="typeParameter",e[e["type"]=5]="type",e[e["parameter"]=6]="parameter",e[e["variable"]=7]="variable",e[e["enumMember"]=8]="enumMember",e[e["property"]=9]="property",e[e["function"]=10]="function",e[e["member"]=11]="member"}(n.TokenType||(n.TokenType={})),function(e){e[e["declaration"]=0]="declaration",e[e["static"]=1]="static",e[e["async"]=2]="async",e[e["readonly"]=3]="readonly",e[e["defaultLibrary"]=4]="defaultLibrary",e[e["local"]=5]="local"}(n.TokenModifier||(n.TokenModifier={})),n.getSemanticClassifications=t,n.getEncodedSemanticClassifications=r;var f=new e.Map([[250,7],[161,6],[164,9],[257,3],[256,1],[292,8],[253,0],[166,11],[252,10],[209,10],[165,11],[168,9],[169,9],[163,9],[254,2],[255,5],[160,4],[289,9],[290,9]])})(n.v2020||(n.v2020={}))})(e.classifier||(e.classifier={}))}(d||(d={})),function(e){(function(n){(function(t){function r(n,t,r,i,o,s,l,u){if(e.isInReferenceComment(n,t)){var p=F(n,t,o,s);return p&&c(p)}if(e.isInString(n,t,r)){if(!r||!e.isStringLiteralLike(r))return;p=d(n,r,t,i,o,s,u);return a(p,r,n,i,l,o,u)}}function a(t,r,a,i,o,s,l){if(void 0!==t){var u=e.createTextSpanFromStringLiteralLikeContent(r);switch(t.kind){case 0:return c(t.paths);case 1:var d=[];return n.getCompletionEntriesFromSymbols(t.symbols,d,r,a,a,i,99,o,4,l,s),{isGlobalCompletion:!1,isMemberCompletion:!0,isNewIdentifierLocation:t.hasIndexSignature,optionalReplacementSpan:u,entries:d};case 2:d=t.types.map((function(t){return{name:t.value,kindModifiers:"",kind:"string",sortText:n.SortText.LocationPriority,replacementSpan:e.getReplacementSpanForContextToken(r)}}));return{isGlobalCompletion:!1,isMemberCompletion:!1,isNewIdentifierLocation:t.isNewIdentifier,optionalReplacementSpan:u,entries:d};default:return e.Debug.assertNever(t)}}}function o(n,t,r,a,i,o,c,l,u){if(a&&e.isStringLiteralLike(a)){var p=d(t,a,r,i,o,c,u);return p&&s(n,a,p,t,i,l)}}function s(t,r,a,i,o,s){switch(a.kind){case 0:var c=e.find(a.paths,(function(e){return e.name===t}));return c&&n.createCompletionDetails(t,l(c.extension),c.kind,[e.textPart(t)]);case 1:c=e.find(a.symbols,(function(e){return e.name===t}));return c&&n.createCompletionDetailsForSymbol(c,o,i,r,s);case 2:return e.find(a.types,(function(e){return e.value===t}))?n.createCompletionDetails(t,"","type",[e.textPart(t)]):void 0;default:return e.Debug.assertNever(a)}}function c(e){var t=!1,r=!0,a=e.map((function(e){var t=e.name,r=e.kind,a=e.span,i=e.extension;return{name:t,kind:r,kindModifiers:l(i),sortText:n.SortText.LocationPriority,replacementSpan:a}}));return{isGlobalCompletion:t,isMemberCompletion:!1,isNewIdentifierLocation:r,entries:a}}function l(n){switch(n){case".d.ts":return".d.ts";case".js":return".js";case".json":return".json";case".jsx":return".jsx";case".ts":return".ts";case".tsx":return".tsx";case".tsbuildinfo":return e.Debug.fail("Extension .tsbuildinfo is unsupported.");case void 0:return"";default:return e.Debug.assertNever(n)}}var u;function d(n,t,r,a,i,o,s){var c=p(t.parent);switch(c.kind){case 192:var l=p(c.parent);switch(l.kind){case 174:var u=l,d=e.findAncestor(c,(function(e){return e.parent===u}));return d?{kind:2,types:y(a.getTypeArgumentConstraint(d)),isNewIdentifier:!1}:void 0;case 190:var h=l,v=h.indexType,b=h.objectType;if(!e.rangeContainsPosition(v,r))return;return _(a.getTypeFromTypeNode(b));case 196:return{kind:0,paths:E(n,t,i,o,a,s)};case 183:if(!e.isTypeReferenceNode(l.parent))return;var T=f(l,c),S=y(a.getTypeArgumentConstraint(l)).filter((function(n){return!e.contains(T,n.value)}));return{kind:2,types:S,isNewIdentifier:!1};default:return}case 289:return e.isObjectLiteralExpression(c.parent)&&c.name===t?g(a,c.parent):C();case 203:var x=c,L=x.expression,D=x.argumentExpression;return t===e.skipParentheses(D)?_(a.getTypeAtLocation(L)):void 0;case 204:case 205:if(!e.isRequireCall(c,!1)&&!e.isImportCall(c)){var A=e.SignatureHelp.getArgumentInfoForCompletions(t,r,n);return A?m(A,a):C()}case 262:case 268:case 273:return{kind:0,paths:E(n,t,i,o,a,s)};default:return C()}function C(){return{kind:2,types:y(e.getContextualTypeFromParent(t,a)),isNewIdentifier:!1}}}function p(n){switch(n.kind){case 187:return e.walkUpParenthesizedTypes(n);case 208:return e.walkUpParenthesizedExpressions(n);default:return n}}function f(n,t){return e.mapDefined(n.types,(function(n){return n!==t&&e.isLiteralTypeNode(n)&&e.isStringLiteral(n.literal)?n.literal.text:void 0}))}function m(n,t){var r=!1,a=new e.Map,i=[];t.getResolvedSignature(n.invocation,i,n.argumentCount);var o=e.flatMap(i,(function(i){if(e.signatureHasRestParameter(i)||!(n.argumentCount>i.parameters.length)){var o=t.getParameterType(i,n.argumentIndex);return r=r||!!(4&o.flags),y(o,a)}}));return{kind:2,types:o,isNewIdentifier:r}}function _(n){return n&&{kind:1,symbols:e.filter(n.getApparentProperties(),(function(n){return!(n.valueDeclaration&&e.isPrivateIdentifierClassElementDeclaration(n.valueDeclaration))})),hasIndexSignature:e.hasIndexSignature(n)}}function g(t,r){var a=t.getContextualType(r);if(a){var i=t.getContextualType(r,4),o=n.getPropertiesForObjectExpression(a,i,r,t);return{kind:1,symbols:o,hasIndexSignature:e.hasIndexSignature(a)}}}function y(n,t){return void 0===t&&(t=new e.Map),n?(n=e.skipConstraint(n),n.isUnion()?e.flatMap(n.types,(function(e){return y(e,t)})):!n.isStringLiteral()||1024&n.flags||!e.addToSeen(t,n.value)?e.emptyArray:[n]):e.emptyArray}function h(e,n,t){return{name:e,kind:n,extension:t}}function v(e){return h(e,"directory",void 0)}function b(n,t,r){var a=U(n,t),i=0===n.length?void 0:e.createTextSpan(t,n.length);return r.map((function(n){var t=n.name,r=n.kind,o=n.extension;return-1!==Math.max(t.indexOf(e.directorySeparator),t.indexOf(e.altDirectorySeparator))?{name:t,kind:r,extension:o,span:i}:{name:t,kind:r,extension:o,span:a}}))}function E(e,n,t,r,a,i){return b(n.text,n.getStart(e)+1,T(e,n,t,r,a,i))}function T(n,t,r,a,i,o){var s=e.normalizeSlashes(t.text),c=n.path,l=e.getDirectoryPath(c);return V(s)||!r.baseUrl&&(e.isRootedDiskPath(s)||e.isUrl(s))?x(s,l,r,a,c,o):N(s,l,r,a,i)}function S(e,n){return void 0===n&&(n=!1),{extensions:L(e),includeExtensions:n}}function x(e,n,t,r,a,i){var o=S(t,"js"===i.importModuleSpecifierEnding);return t.rootDirs?A(t.rootDirs,e,n,o,t,r,a):C(e,n,o,r,a)}function L(n){var t=e.getSupportedExtensions(n);return n.resolveJsonModule&&e.getEmitModuleResolutionKind(n)===e.ModuleResolutionKind.NodeJs?t.concat(".json"):t}function D(n,t,r,a){n=n.map((function(n){return e.normalizePath(e.isRootedDiskPath(n)?n:e.combinePaths(t,n))}));var o=e.firstDefined(n,(function(n){return e.containsPath(n,r,t,a)?r.substr(n.length):void 0}));return e.deduplicate(i(i([],n.map((function(n){return e.combinePaths(n,o)}))),[r]),e.equateStringsCaseSensitive,e.compareStringsCaseSensitive)}function A(n,t,r,a,i,o,s){var c=i.project||o.getCurrentDirectory(),l=!(o.useCaseSensitiveFileNames&&o.useCaseSensitiveFileNames()),u=D(n,c,r,l);return e.flatMap(u,(function(e){return C(t,e,a,o,s)}))}function C(n,t,r,a,i,o){var s=r.extensions,c=r.includeExtensions;void 0===o&&(o=[]),void 0===n&&(n=""),n=e.normalizeSlashes(n),e.hasTrailingDirectorySeparator(n)||(n=e.getDirectoryPath(n)),""===n&&(n="."+e.directorySeparator),n=e.ensureTrailingDirectorySeparator(n);var l=e.resolvePath(t,n),u=e.hasTrailingDirectorySeparator(l)?l:e.getDirectoryPath(l),d=!(a.useCaseSensitiveFileNames&&a.useCaseSensitiveFileNames());if(!e.tryDirectoryExists(a,u))return o;var p=e.tryReadDirectory(a,u,s,void 0,["./*"]);if(p){for(var f=new e.Map,m=0,_=p;m<_.length;m++){var g=_[m];if(g=e.normalizePath(g),!i||0!==e.comparePaths(g,i,t,d)){var y=c||e.fileExtensionIs(g,".json")?e.getBaseFileName(g):e.removeFileExtension(e.getBaseFileName(g));f.set(y,e.tryGetExtensionFromPath(g))}}f.forEach((function(e,n){o.push(h(n,"script",e))}))}var b=e.tryGetDirectories(a,u);if(b)for(var E=0,T=b;E<T.length;E++){var S=T[E],x=e.getBaseFileName(e.normalizePath(S));"@types"!==x&&o.push(v(x))}var L=e.findPackageJson(u,a);if(L){var D=e.readJson(L,a),A=D.typesVersions;if("object"===typeof A){var C=e.getPackageJsonTypesVersionsPaths(A),N=C&&C.paths,k=l.slice(e.ensureTrailingDirectorySeparator(u).length);N&&I(o,k,u,s,N,a)}}return o}function I(n,t,r,a,i,o){for(var s in i)if(e.hasProperty(i,s)){var c=i[s];if(c)for(var l=function(e,t,r){n.some((function(n){return n.name===e}))||n.push(h(e,t,r))},u=0,d=R(s,c,t,r,a,o);u<d.length;u++){var p=d[u],f=p.name,m=p.kind,_=p.extension;l(f,m,_)}}}function N(n,t,r,a,i){var o=r.baseUrl,s=r.paths,c=[],l=S(r);if(o){var u=r.project||a.getCurrentDirectory(),d=e.normalizePath(e.combinePaths(u,o));C(n,d,l,a,void 0,c),s&&I(c,n,d,l.extensions,s,a)}for(var p=k(n),f=0,m=M(n,p,i);f<m.length;f++){var _=m[f];c.push(h(_,"external module name",void 0))}if(G(a,r,t,p,l,c),e.getEmitModuleResolutionKind(r)===e.ModuleResolutionKind.NodeJs){var g=!1;if(void 0===p)for(var y=function(e){c.some((function(n){return n.name===e}))||(g=!0,c.push(h(e,"external module name",void 0)))},v=0,b=B(a,t);v<b.length;v++){var E=b[v];y(E)}g||e.forEachAncestorDirectory(t,(function(t){var r=e.combinePaths(t,"node_modules");e.tryDirectoryExists(a,r)&&C(n,r,l,a,void 0,c)}))}return c}function k(n){return H(n)?e.hasTrailingDirectorySeparator(n)?n:e.getDirectoryPath(n):void 0}function R(n,t,r,a,i,o){if(!e.endsWith(n,"*"))return e.stringContains(n,"*")?e.emptyArray:l(n);var s=n.slice(0,n.length-1),c=e.tryRemovePrefix(r,s);return void 0===c?l(s):e.flatMap(t,(function(e){return O(c,a,e,i,o)}));function l(n){return e.startsWith(n,r)?[v(n)]:e.emptyArray}}function O(n,t,r,a,o){if(o.readDirectory){var s=e.hasZeroOrOneAsteriskCharacter(r)?e.tryParsePattern(r):void 0;if(s){var c=e.resolvePath(s.prefix),l=e.hasTrailingDirectorySeparator(s.prefix)?c:e.getDirectoryPath(c),u=e.hasTrailingDirectorySeparator(s.prefix)?"":e.getBaseFileName(c),d=H(n),p=d?e.hasTrailingDirectorySeparator(n)?n:e.getDirectoryPath(n):void 0,f=d?e.combinePaths(l,u+p):l,m=e.normalizePath(s.suffix),_=e.normalizePath(e.combinePaths(t,f)),g=d?_:e.ensureTrailingDirectorySeparator(_)+u,y=m?"**/*":"./*",b=e.mapDefined(e.tryReadDirectory(o,_,a,void 0,[y]),(function(n){var t=e.tryGetExtensionFromPath(n),r=T(n);return void 0===r?void 0:h(e.removeFileExtension(r),"script",t)})),E=e.mapDefined(e.tryGetDirectories(o,_).map((function(n){return e.combinePaths(_,n)})),(function(e){var n=T(e);return void 0===n?void 0:v(n)}));return i(i([],b),E)}}function T(n){var t=w(e.normalizePath(n),g,m);return void 0===t?void 0:P(t)}}function w(n,t,r){return e.startsWith(n,t)&&e.endsWith(n,r)?n.slice(t.length,n.length-r.length):void 0}function P(n){return n[0]===e.directorySeparator?n.slice(1):n}function M(n,t,r){var a=r.getAmbientModules().map((function(n){return e.stripQuotes(n.name)})),i=a.filter((function(t){return e.startsWith(t,n)}));if(void 0!==t){var o=e.ensureTrailingDirectorySeparator(t);return i.map((function(n){return e.removePrefix(n,o)}))}return i}function F(n,t,r,a){var i=e.getTokenAtPosition(n,t),o=e.getLeadingCommentRanges(n.text,i.pos),s=o&&e.find(o,(function(e){return t>=e.pos&&t<=e.end}));if(s){var c=n.text.slice(s.pos,t),l=j.exec(c);if(l){var u=l[1],d=l[2],p=l[3],f=e.getDirectoryPath(n.path),m="path"===d?C(p,f,S(r,!0),a,n.path):"types"===d?G(a,r,f,k(p),S(r)):e.Debug.fail();return b(p,s.pos+u.length,m)}}}function G(n,t,r,a,i,o){void 0===o&&(o=[]);for(var s=new e.Map,c=e.tryAndIgnoreErrors((function(){return e.getEffectiveTypeRoots(t,n)}))||e.emptyArray,l=0,u=c;l<u.length;l++){var d=u[l];g(d)}for(var p=0,f=e.findPackageJsons(r,n);p<f.length;p++){var m=f[p],_=e.combinePaths(e.getDirectoryPath(m),"node_modules/@types");g(_)}return o;function g(r){if(e.tryDirectoryExists(n,r))for(var c=0,l=e.tryGetDirectories(n,r);c<l.length;c++){var u=l[c],d=e.unmangleScopedPackageName(u);if(!t.types||e.contains(t.types,d))if(void 0===a)s.has(d)||(o.push(h(d,"external module name",void 0)),s.set(d,!0));else{var p=e.combinePaths(r,u),f=e.tryRemoveDirectoryPrefix(a,d,e.hostGetCanonicalFileName(n));void 0!==f&&C(f,p,i,n,void 0,o)}}}}function B(n,t){if(!n.readFile||!n.fileExists)return e.emptyArray;for(var r=[],a=0,i=e.findPackageJsons(t,n);a<i.length;a++)for(var o=i[a],s=e.readJson(o,n),c=0,l=K;c<l.length;c++){var u=l[c],d=s[u];if(d)for(var p in d)d.hasOwnProperty(p)&&!e.startsWith(p,"@types/")&&r.push(p)}return r}function U(n,t){var r=Math.max(n.lastIndexOf(e.directorySeparator),n.lastIndexOf(e.altDirectorySeparator)),a=-1!==r?r+1:0,i=n.length-a;return 0===i||e.isIdentifierText(n.substr(a,i),99)?void 0:e.createTextSpan(t+a,i)}function V(e){if(e&&e.length>=2&&46===e.charCodeAt(0)){var n=e.length>=3&&46===e.charCodeAt(1)?2:1,t=e.charCodeAt(n);return 47===t||92===t}return!1}t.getStringLiteralCompletions=r,t.getStringLiteralCompletionDetails=o,function(e){e[e["Paths"]=0]="Paths",e[e["Properties"]=1]="Properties",e[e["Types"]=2]="Types"}(u||(u={}));var j=/^(\/\/\/\s*<reference\s+(path|types)\s*=\s*(?:'|"))([^\3"]*)$/,K=["dependencies","devDependencies","peerDependencies","optionalDependencies"];function H(n){return e.stringContains(n,e.directorySeparator)}})(n.StringCompletions||(n.StringCompletions={}))})(e.Completions||(e.Completions={}))}(d||(d={})),function(e){(function(n){var t,r,a,i,o,s;function c(e){return!!(1&e.kind)}function l(e){return!!(2&e.kind)}function u(e){return!!(e&&4&e.kind)}function d(e){return!(!e||32!==e.kind)}function p(e){return u(e)||d(e)}function f(e){return(u(e)||d(e))&&!!e.isFromPackageJson}function m(e){return!!(8&e.kind)}function _(e){return!!(16&e.kind)}function g(t,r,a,i,o,s,c){var l=r.getTypeChecker(),u=r.getCompilerOptions(),d=e.findPrecedingToken(o,i);if(!c||e.isInString(i,o,d)||de(i,c,d,o)){if(" "===c)return s.includeCompletionsForImportStatements&&s.includeCompletionsWithInsertText?{isGlobalCompletion:!0,isMemberCompletion:!1,isNewIdentifierLocation:!0,isIncomplete:!0,entries:[]}:void 0;var p=n.StringCompletions.getStringLiteralCompletions(i,o,d,l,u,t,a,s);if(p)return p;if(d&&e.isBreakOrContinueStatement(d.parent)&&(80===d.kind||85===d.kind||78===d.kind))return O(d.parent);var f=z(r,a,i,E(i,u),o,s,void 0,t);if(f)switch(f.kind){case 0:return b(i,l,u,a,f,s);case 1:return y(e.JsDoc.getJSDocTagNameCompletions());case 2:return y(e.JsDoc.getJSDocTagCompletions());case 3:return y(e.JsDoc.getJSDocParameterNameCompletions(f.tag));case 4:return h(f.keywords);default:return e.Debug.assertNever(f)}}}function y(e){return{isGlobalCompletion:!1,isMemberCompletion:!1,isNewIdentifierLocation:!1,entries:e}}function h(n){return{isGlobalCompletion:!1,isMemberCompletion:!1,isNewIdentifierLocation:!1,entries:n.map((function(n){return{name:e.tokenToString(n),kind:"keyword",kindModifiers:"",sortText:t.GlobalsOrKeywords}}))}}function v(n){return 78===(null===n||void 0===n?void 0:n.kind)?e.createTextSpanFromNode(n):void 0}function b(n,t,r,a,i,o){var s=i.symbols,c=i.completionKind,l=i.isInSnippetScope,u=i.isNewIdentifierLocation,d=i.location,p=i.propertyAccessToConvert,f=i.keywordFilters,m=i.literals,_=i.symbolToOriginInfoMap,g=i.recommendedCompletion,y=i.isJsxInitializer,h=i.isTypeOnlyLocation,b=i.isJsxIdentifierExpected,L=i.importCompletionNode,A=i.insideJsDocTagTypeExpression,C=i.symbolToSortTextMap;if(1===e.getLanguageVariant(n.scriptKind)){var I=S(d,n);if(I)return I}var N=[];if(E(n,r)){var k=R(s,N,void 0,d,n,t,r.target,a,c,o,r,h,p,b,y,L,g,_,C);x(n,d.pos,k,r.target,N)}else{if(!u&&(!s||0===s.length)&&0===f)return;R(s,N,void 0,d,n,t,r.target,a,c,o,r,h,p,b,y,L,g,_,C)}if(0!==f)for(var O=new e.Set(N.map((function(e){return e.name}))),w=0,P=Q(f,!A&&e.isSourceFileJS(n));w<P.length;w++){var M=P[w];O.has(M.name)||N.push(M)}for(var F=0,G=m;F<G.length;F++){var B=G[F];N.push(D(n,o,B))}return{isGlobalCompletion:l,isMemberCompletion:T(c),isNewIdentifierLocation:u,optionalReplacementSpan:v(d),entries:N}}function E(n,t){return e.isSourceFileJS(n)&&!e.isCheckJsEnabledForFile(n,t)}function T(e){switch(e){case 0:case 3:case 2:return!0;default:return!1}}function S(n,r){var a=e.findAncestor(n,(function(e){switch(e.kind){case 277:return!0;case 43:case 31:case 78:case 202:return!1;default:return"quit"}}));if(a){var i=!!e.findChildOfKind(a,31,r),o=a.parent.openingElement.tagName,s=o.getText(r),c=s+(i?"":">"),l=e.createTextSpanFromNode(a.tagName),u={name:c,kind:"class",kindModifiers:void 0,sortText:t.LocationPriority};return{isGlobalCompletion:!1,isMemberCompletion:!0,isNewIdentifierLocation:!1,optionalReplacementSpan:l,entries:[u]}}}function x(n,r,a,i,o){e.getNameTable(n).forEach((function(n,s){if(n!==r){var c=e.unescapeLeadingUnderscores(s);!a.has(c)&&e.isIdentifierText(c,i)&&(a.add(c),o.push({name:c,kind:"warning",kindModifiers:"",sortText:t.JavascriptIdentifiers,isFromUncheckedFile:!0}))}}))}function L(n,t,r){return"object"===typeof r?e.pseudoBigIntToString(r)+"n":e.isString(r)?e.quote(n,t,r):JSON.stringify(r)}function D(e,n,r){return{name:L(e,n,r),kind:"string",kindModifiers:"",sortText:t.LocationPriority}}function A(n,t,r,a,i,o,s,p,g,y,h,v,b,E,T,S){var x,L,D,A,R,O=e.getReplacementSpanForContextToken(r),w=g&&_(g),P=g&&l(g)||p;if(g&&c(g))L=p?"this"+(w?"?.":"")+"["+I(i,S,s)+"]":"this"+(w?"?.":".")+s;else if((P||w)&&h){L=P?p?"["+I(i,S,s)+"]":"["+s+"]":s,(w||h.questionDotToken)&&(L="?."+L);var M=e.findChildOfKind(h,24,i)||e.findChildOfKind(h,28,i);if(!M)return;var F=e.startsWith(s,h.name.text)?h.name.end:M.end;O=e.createTextSpanFromBounds(M.getStart(i),F)}if(v&&(void 0===L&&(L=s),L="{"+L+"}","boolean"!==typeof v&&(O=e.createTextSpanFromNode(v,i))),g&&m(g)&&h){void 0===L&&(L=s);var G=e.findPrecedingToken(h.pos,i),B="";G&&e.positionIsASICandidate(G.end,G.parent,i)&&(B=";"),B+="(await "+h.expression.getText()+")",L=p?""+B+L:B+(w?"?.":".")+L,O=e.createTextSpanFromBounds(h.getStart(i),h.end)}if(d(g)&&(e.Debug.assertIsDefined(b),x=C(s,b,g,E,T,S),L=x.insertText,O=x.replacementSpan,R=[e.textPart(g.moduleSpecifier)],A=!!S.includeCompletionsWithSnippetText||void 0),void 0===L||S.includeCompletionsWithInsertText)return(u(g)||d(g))&&(D={exportName:g.exportName,fileName:g.fileName,ambientModuleName:g.fileName?void 0:e.stripQuotes(g.moduleSymbol.name),isPackageJsonImport:!!g.isFromPackageJson||void 0,moduleSpecifier:d(g)?g.moduleSpecifier:void 0}),{name:s,kind:e.SymbolDisplay.getSymbolKind(o,n,a),kindModifiers:e.SymbolDisplay.getSymbolModifiers(o,n),sortText:t,source:k(g),hasAction:g&&u(g)||void 0,isRecommended:N(n,y,o)||void 0,insertText:L,replacementSpan:O,sourceDisplay:R,isSnippet:A,isPackageJsonImport:f(g)||void 0,isImportStatementCompletion:d(g)||void 0,data:D}}function C(n,t,r,a,i,o){var s=t.getSourceFile(),c=e.createTextSpanFromNode(t,s),l=e.quote(s,o,r.moduleSpecifier),u=r.isDefaultExport?1:"export="===r.exportName?2:0,d=o.includeCompletionsWithSnippetText?"$1":"",p=e.codefix.getImportKind(s,u,i),f=a?";":"";switch(p){case 3:return{replacementSpan:c,insertText:"import "+n+d+" = require("+l+")"+f};case 1:return{replacementSpan:c,insertText:"import "+n+d+" from "+l+f};case 2:return{replacementSpan:c,insertText:"import * as "+n+d+" from "+l+f};case 0:return{replacementSpan:c,insertText:"import { "+n+d+" } from "+l+f}}}function I(n,t,r){return/^\d+$/.test(r)?r:e.quote(n,t,r)}function N(e,n,t){return e===n||!!(1048576&e.flags)&&t.getExportSymbolOfSymbol(e)===n}function k(n){return u(n)?e.stripQuotes(n.moduleSymbol.name):d(n)?n.moduleSpecifier:1===(null===n||void 0===n?void 0:n.kind)?r.ThisProperty:void 0}function R(n,r,a,i,o,s,c,l,u,d,p,f,m,_,g,y,h,v,b){for(var E=e.timestamp(),T=he(i),S=e.probablyUsesSemicolons(o),x=new e.Map,L=0;L<n.length;L++){var D=n[L],C=null===v||void 0===v?void 0:v[L],I=J(D,c,C,u,!!_);if(I&&!x.get(I.name)&&(1!==u||!b||w(D,b))){var N=I.name,k=I.needsConvertPropertyAccess,R=A(D,b&&b[e.getSymbolId(D)]||t.LocationPriority,a,i,o,s,N,k,C,h,m,g,y,S,p,d);if(R){var O=!C&&!(void 0===D.parent&&!e.some(D.declarations,(function(e){return e.getSourceFile()===i.getSourceFile()})));x.set(N,O),r.push(R)}}}return l("getCompletionsAtPosition: getCompletionEntriesFromSymbols: "+(e.timestamp()-E)),{has:function(e){return x.has(e)},add:function(e){return x.set(e,!0)}};function w(n,r){if(!e.isSourceFile(i)){if(e.isExportAssignment(i.parent))return!0;if(T&&n.valueDeclaration===T)return!1;var a=e.skipAlias(n,s);if(o.externalModuleIndicator&&!p.allowUmdGlobalAccess&&r[e.getSymbolId(n)]===t.GlobalsOrKeywords&&(r[e.getSymbolId(a)]===t.AutoImportSuggestions||r[e.getSymbolId(a)]===t.LocationPriority))return!1;if(n=a,e.isInRightSideOfInternalImportEqualsDeclaration(i))return!!(1920&n.flags);if(f)return be(n,s)}return!!(111551&e.getCombinedLocalAndExportSymbolFlags(n))}}function O(e){var n=w(e);if(n.length)return{isGlobalCompletion:!1,isMemberCompletion:!1,isNewIdentifierLocation:!1,entries:n}}function w(n){var r=[],a=new e.Map,i=n;while(i){if(e.isFunctionLike(i))break;if(e.isLabeledStatement(i)){var o=i.label.text;a.has(o)||(a.set(o,!0),r.push({name:o,kindModifiers:"",kind:"label",sortText:t.LocationPriority}))}i=i.parent}return r}function P(n,t,r,a,i,o,s){if(i.data){var c=q(i.name,i.data,n,o);if(c)return{type:"symbol",symbol:c.symbol,location:e.getTouchingPropertyName(r,a),previousToken:e.findPrecedingToken(a,r,void 0),isJsxInitializer:!1,isTypeOnlyLocation:!1,origin:c.origin}}var l=n.getCompilerOptions(),u=z(n,t,r,E(r,l),a,{includeCompletionsForModuleExports:!0,includeCompletionsWithInsertText:!0},i,o);if(!u)return{type:"none"};if(0!==u.kind)return{type:"request",request:u};var d=u.symbols,p=u.literals,f=u.location,m=u.completionKind,_=u.symbolToOriginInfoMap,g=u.previousToken,y=u.isJsxInitializer,h=u.isTypeOnlyLocation,v=e.find(p,(function(e){return L(r,s,e)===i.name}));return void 0!==v?{type:"literal",literal:v}:e.firstDefined(d,(function(e,n){var t=_[n],r=J(e,l.target,t,m,u.isJsxIdentifierExpected);return r&&r.name===i.name&&k(t)===i.source?{type:"symbol",symbol:e,location:f,origin:t,previousToken:g,isJsxInitializer:y,isTypeOnlyLocation:h}:void 0}))||{type:"none"}}function M(t,r,a,i,o,s,c,l,u){var d=t.getTypeChecker(),p=t.getCompilerOptions(),f=o.name,m=e.findPrecedingToken(i,a);if(e.isInString(a,i,m))return n.StringCompletions.getStringLiteralCompletionDetails(f,a,i,m,d,p,s,u,l);var _=P(t,r,a,i,o,s,l);switch(_.type){case"request":var g=_.request;switch(g.kind){case 1:return e.JsDoc.getJSDocTagNameCompletionDetails(f);case 2:return e.JsDoc.getJSDocTagCompletionDetails(f);case 3:return e.JsDoc.getJSDocParameterNameCompletionDetails(f);case 4:return g.keywords.indexOf(e.stringToToken(f))>-1?F(f,"keyword",e.SymbolDisplayPartKind.keyword):void 0;default:return e.Debug.assertNever(g)}case"symbol":var y=_.symbol,h=_.location,v=_.origin,b=_.previousToken,E=U(v,y,t,d,s,p,a,i,b,c,l,o.data),T=E.codeActions,S=E.sourceDisplay;return G(y,d,a,h,u,T,S);case"literal":var x=_.literal;return F(L(a,l,x),"string","string"===typeof x?e.SymbolDisplayPartKind.stringLiteral:e.SymbolDisplayPartKind.numericLiteral);case"none":return Y().some((function(e){return e.name===f}))?F(f,"keyword",e.SymbolDisplayPartKind.keyword):void 0;default:e.Debug.assertNever(_)}}function F(n,t,r){return B(n,"",t,[e.displayPart(n,r)])}function G(n,t,r,a,i,o,s){var c=t.runWithCancellationToken(i,(function(t){return e.SymbolDisplay.getSymbolDisplayPartsDocumentationAndSymbolKind(t,n,r,a,a,7)})),l=c.displayParts,u=c.documentation,d=c.symbolKind,p=c.tags;return B(n.name,e.SymbolDisplay.getSymbolModifiers(t,n),d,l,u,p,o,s)}function B(e,n,t,r,a,i,o,s){return{name:e,kindModifiers:n,kind:t,displayParts:r,documentation:a,tags:i,codeActions:o,source:s,sourceDisplay:s}}function U(n,t,r,a,i,o,s,c,l,d,p,f){if(null===f||void 0===f?void 0:f.moduleSpecifier)return{codeActions:void 0,sourceDisplay:[e.textPart(f.moduleSpecifier)]};if(!n||!u(n))return{codeActions:void 0,sourceDisplay:void 0};var m=n.moduleSymbol,_=a.getMergedSymbol(e.skipAlias(t.exportSymbol||t,a)),g=e.codefix.getImportCompletionAction(_,m,s,e.getNameForExportedSymbol(t,o.target),i,r,d,l&&e.isIdentifier(l)?l.getStart(s):c,p),y=g.moduleSpecifier,h=g.codeAction;return{sourceDisplay:[e.textPart(y)],codeActions:[h]}}function V(e,n,t,r,a,i,o){var s=P(e,n,t,r,a,i,o);return"symbol"===s.type?s.symbol:void 0}function j(n,t,r){return e.firstDefined(t&&(t.isUnion()?t.types:[t]),(function(t){var a=t&&t.symbol;return a&&424&a.flags&&!e.isAbstractConstructorSymbol(a)?H(a,n,r):void 0}))}function K(n,t,r,a){var i=n.parent;switch(n.kind){case 78:return e.getContextualTypeFromParent(n,a);case 62:switch(i.kind){case 250:return a.getContextualType(i.initializer);case 217:return a.getTypeAtLocation(i.left);case 281:return a.getContextualTypeForJsxAttribute(i);default:return}case 102:return a.getContextualType(i);case 81:return e.getSwitchedType(e.cast(i,e.isCaseClause),a);case 18:return e.isJsxExpression(i)&&274!==i.parent.kind?a.getContextualTypeForJsxAttribute(i.parent):void 0;default:var o=e.SignatureHelp.getArgumentInfoForCompletions(n,t,r);return o?a.getContextualTypeForArgumentAtIndex(o.invocation,o.argumentIndex+(27===n.kind?1:0)):e.isEqualityOperatorKind(n.kind)&&e.isBinaryExpression(i)&&e.isEqualityOperatorKind(i.operatorToken.kind)?a.getTypeAtLocation(i.left):a.getContextualType(n)}}function H(n,t,r){var a=r.getAccessibleSymbolChain(n,t,67108863,!1);return a?e.first(a):n.parent&&(W(n.parent)?n:H(n.parent,t,r))}function W(e){var n;return!!(null===(n=e.declarations)||void 0===n?void 0:n.some((function(e){return 298===e.kind})))}function z(n,r,a,i,o,s,c,l){var u=n.getTypeChecker(),d=e.timestamp(),p=e.getTokenAtPosition(a,o);r("getCompletionData: Get current token: "+(e.timestamp()-d)),d=e.timestamp();var f=e.isInComment(a,o,p);r("getCompletionData: Is inside comment: "+(e.timestamp()-d));var m=!1,_=!1;if(f){if(e.hasDocComment(a,o)){if(64===a.text.charCodeAt(o-1))return{kind:1};var g=e.getLineStartPositionForPosition(o,a);if(!/[^\*|\s(/)]/.test(a.text.substring(g,o)))return{kind:2}}var y=ae(p,o);if(y){if(y.tagName.pos<=o&&o<=y.tagName.end)return{kind:1};if($(y)&&y.typeExpression&&302===y.typeExpression.kind&&(p=e.getTokenAtPosition(a,o),p&&(e.isDeclarationName(p)||337===p.parent.kind&&p.parent.name===p)||(m=an(y.typeExpression))),!m&&e.isJSDocParameterTag(y)&&(e.nodeIsMissing(y.name)||y.name.pos<=o&&o<=y.name.end))return{kind:3,tag:y}}if(!m)return void r("Returning an empty list because completion was inside a regular comment or plain text part of a JsDoc comment.")}d=e.timestamp();var h=e.findPrecedingToken(o,a,void 0);r("getCompletionData: Get previous token 1: "+(e.timestamp()-d));var v=h;if(v&&o<=v.end&&(e.isMemberName(v)||e.isKeyword(v.kind))){var b=e.timestamp();v=e.findPrecedingToken(v.getFullStart(),a,void 0),r("getCompletionData: Get previous token 2: "+(e.timestamp()-b))}var E,T,S=p,x=!1,L=!1,D=!1,A=!1,C=!1,I=!1,N=e.getTouchingPropertyName(a,o);if(v){var k=ge(v);if(153===k)return{kind:4,keywords:[153]};if(k&&s.includeCompletionsForImportStatements&&s.includeCompletionsWithInsertText&&(T=k),!T&&Oe(v))return void r("Returning an empty list because completion was requested in an invalid position.");var R=v.parent;if(24===v.kind||28===v.kind)switch(x=24===v.kind,L=28===v.kind,R.kind){case 202:if(E=R,S=E.expression,(e.isCallExpression(S)||e.isFunctionLike(S))&&S.end===v.pos&&S.getChildCount(a)&&21!==e.last(S.getChildren(a)).kind)return;break;case 158:S=R.left;break;case 257:S=R.name;break;case 196:case 227:S=R;break;default:return}else if(!T&&1===a.languageVariant){if(R&&202===R.kind&&(v=R,R=R.parent),p.parent===N)switch(p.kind){case 31:274!==p.parent.kind&&276!==p.parent.kind||(N=p);break;case 43:275===p.parent.kind&&(N=p);break}switch(R.kind){case 277:43===v.kind&&(A=!0,N=v);break;case 217:if(!pe(R))break;case 275:case 274:case 276:I=!0,29===v.kind&&(D=!0,N=v);break;case 284:19===h.kind&&31===p.kind&&(I=!0);break;case 281:if(R.initializer===h&&h.end<o){I=!0;break}switch(h.kind){case 62:C=!0;break;case 78:I=!0,R!==h.parent&&!R.initializer&&e.findChildOfKind(R,62,a)&&(C=h)}break}}}var O=e.timestamp(),w=5,P=!1,M=!1,F=0,G=[],B=[],U=[],V=new e.Map,W=De(),z=e.memoizeOne((function(t){return e.createModuleSpecifierResolutionHost(t?l.getPackageJsonAutoImportProvider():n,l)}));if(x||L)ee();else if(D){var q=u.getJsxIntrinsicTagNamesAt(N);e.Debug.assertEachIsDefined(q,"getJsxIntrinsicTagNames() should all be defined"),he(),G=q.concat(G),w=1,F=0}else if(A){var J=v.parent.parent.openingElement.tagName,X=u.getSymbolAtLocation(J);X&&(G=[X]),w=1,F=0}else if(!he())return;r("getCompletionData: Semantic work: "+(e.timestamp()-O));var Y=h&&K(h,o,a,u),Q=e.mapDefined(Y&&(Y.isUnion()?Y.types:[Y]),(function(e){return e.isLiteral()?e.value:void 0})),Z=h&&Y&&j(h,Y,u);return{kind:0,symbols:G,completionKind:w,isInSnippetScope:_,propertyAccessToConvert:E,isNewIdentifierLocation:P,location:N,keywordFilters:F,literals:Q,symbolToOriginInfoMap:B,recommendedCompletion:Z,previousToken:h,isJsxInitializer:C,insideJsDocTagTypeExpression:m,symbolToSortTextMap:U,isTypeOnlyLocation:W,isJsxIdentifierExpected:I,importCompletionNode:T};function $(e){switch(e.kind){case 330:case 337:case 331:case 333:case 335:return!0;default:return!1}}function ee(){w=2;var n=e.isLiteralImportTypeNode(S),t=m||n&&!S.isTypeOf||e.isPartOfTypeNode(S.parent)||e.isPossiblyTypeArgumentPosition(v,a,u),r=e.isInRightSideOfInternalImportEqualsDeclaration(S);if(e.isEntityName(S)||n||e.isPropertyAccessExpression(S)){var i=e.isModuleDeclaration(S.parent);i&&(P=!0);var o=u.getSymbolAtLocation(S);if(o&&(o=e.skipAlias(o,u),1920&o.flags)){var c=u.getExportsOfModule(o);e.Debug.assertEachIsDefined(c,"getExportsOfModule() should all be defined");for(var l=function(e){return u.isValidPropertyAccess(n?S:S.parent,e.name)},d=function(e){return be(e,u)},p=i?function(e){var n;return!!(1920&e.flags)&&!(null===(n=e.declarations)||void 0===n?void 0:n.every((function(e){return e.parent===S.parent})))}:r?function(e){return d(e)||l(e)}:t?d:l,f=0,_=c;f<_.length;f++){var g=_[f];p(g)&&G.push(g)}if(!t&&o.declarations&&o.declarations.some((function(e){return 298!==e.kind&&257!==e.kind&&256!==e.kind}))){var y=u.getTypeOfSymbolAtLocation(o,S).getNonOptionalType(),h=!1;if(y.isNullableType()){var b=x&&!L&&!1!==s.includeAutomaticOptionalChainCompletions;(b||L)&&(y=y.getNonNullableType(),b&&(h=!0))}te(y,!!(32768&S.flags),h)}return}}if(!e.isMetaProperty(S)||102!==S.keywordToken&&99!==S.keywordToken||v!==S.getChildAt(1)){if(!t){y=u.getTypeAtLocation(S).getNonOptionalType(),h=!1;if(y.isNullableType()){b=x&&!L&&!1!==s.includeAutomaticOptionalChainCompletions;(b||L)&&(y=y.getNonNullableType(),b&&(h=!0))}te(y,!!(32768&S.flags),h)}}else{var E=102===S.keywordToken?"target":"meta";G.push(u.createSymbol(4,e.escapeLeadingUnderscores(E)))}}function te(n,t,r){P=!!n.getStringIndexType(),L&&e.some(n.getCallSignatures())&&(P=!0);var a=196===S.kind?S:S.parent;if(i)G.push.apply(G,e.filter(oe(n,u),(function(e){return u.isValidPropertyAccessForCompletions(a,n,e)})));else for(var o=0,c=n.getApparentProperties();o<c.length;o++){var l=c[o];u.isValidPropertyAccessForCompletions(a,n,l)&&de(l,!1,r)}if(t&&s.includeCompletionsWithInsertText){var d=u.getPromisedTypeOfPromise(n);if(d)for(var p=0,f=d.getApparentProperties();p<f.length;p++){l=f[p];u.isValidPropertyAccessForCompletions(a,d,l)&&de(l,!0,r)}}}function de(n,r,a){var i=e.firstDefined(n.declarations,(function(n){return e.tryCast(e.getNameOfDeclaration(n),e.isComputedPropertyName)}));if(i){var o=ye(i.expression),c=o&&u.getSymbolAtLocation(o),l=c&&H(c,v,u);if(l&&e.addToSeen(V,e.getSymbolId(l))){var d=G.length;G.push(l);var p=l.parent;if(p&&e.isExternalModuleSymbol(p)){var f={kind:g(6),moduleSymbol:p,isDefaultExport:!1,symbolName:l.name,exportName:l.name,fileName:e.isExternalModuleNameRelative(e.stripQuotes(p.name))?e.cast(p.valueDeclaration,e.isSourceFile).fileName:void 0};B[d]=f}else B[d]={kind:g(2)}}else s.includeCompletionsWithInsertText&&(_(n),m(n),G.push(n))}else _(n),m(n),G.push(n);function m(n){me(n)&&(U[e.getSymbolId(n)]=t.LocalDeclarationPriority)}function _(n){s.includeCompletionsWithInsertText&&(r&&e.addToSeen(V,e.getSymbolId(n))?B[G.length]={kind:g(8)}:a&&(B[G.length]={kind:16}))}function g(e){return a?16|e:e}}function ye(n){return e.isIdentifier(n)?n:e.isPropertyAccessExpression(n)?ye(n.expression):void 0}function he(){var e=Fe()||Ge()||Te()||Be()||Ue()||ve()||Ve()||Ee()||(Se(),1);return 1===e}function ve(){return He(v)?(w=5,P=!0,F=4,1):0}function Ee(){var e=ze(v),n=e&&u.getContextualType(e.attributes);if(!n)return 0;var t=e&&u.getContextualType(e.attributes,4);return G=rn(ie(n,t,e.attributes,u),e.attributes.properties),en(),w=3,P=!1,1}function Te(){return T?(Ie(!0),1):0}function Se(){F=We(v)?5:1,w=1,P=Pe(),h!==v&&e.Debug.assert(!!h,"Expected 'contextToken' to be defined when different from 'previousToken'.");var n=h!==v?h.getStart():o,r=Re(v,n,a)||a;_=Le(r);var i=2887656|(W?0:111551);G=u.getSymbolsInScope(r,i),e.Debug.assertEachIsDefined(G,"getSymbolsInScope() should all be defined");for(var c=0,l=G;c<l.length;c++){var d=l[c];u.isArgumentsSymbol(d)||e.some(d.declarations,(function(e){return e.getSourceFile()===a}))||(U[e.getSymbolId(d)]=t.GlobalsOrKeywords)}if(s.includeCompletionsWithInsertText&&298!==r.kind){var p=u.tryGetThisTypeAt(r,!1);if(p&&!fe(p,a,u))for(var f=0,m=oe(p,u);f<m.length;f++){d=m[f];B[G.length]={kind:1},G.push(d),U[e.getSymbolId(d)]=t.SuggestedClassMembers}}Ie(!1),W&&(F=v&&e.isAssertionExpression(v.parent)?6:7)}function xe(){return!!T||!M&&(!!s.includeCompletionsForModuleExports&&(!(!a.externalModuleIndicator&&!a.commonJsModuleIndicator)||(!!e.compilerOptionsIndicateEs6Modules(n.getCompilerOptions())||e.programContainsModules(n))))}function Le(n){switch(n.kind){case 298:case 219:case 284:case 231:return!0;default:return e.isStatement(n)}}function De(){return m||!Ae(v)&&(e.isPossiblyTypeArgumentPosition(v,a,u)||e.isPartOfTypeNode(N)||Ce(v))}function Ae(n){return n&&(111===n.kind&&(177===n.parent.kind||e.isTypeOfExpression(n.parent))||127===n.kind&&173===n.parent.kind)}function Ce(n){if(n){var t=n.parent.kind;switch(n.kind){case 58:return 164===t||163===t||161===t||250===t||e.isFunctionLikeKind(t);case 62:return 255===t;case 126:return 225===t;case 29:return 174===t||207===t;case 93:return 160===t}}return!1}function Ie(t){var r,i,o,u,d;if(xe()){e.Debug.assert(!(null===c||void 0===c?void 0:c.data));var p=e.timestamp(),f=null===(r=l.getModuleSpecifierCache)||void 0===r?void 0:r.call(l);null===(i=l.log)||void 0===i||i.call(l,"collectAutoImports: starting, "+(t?"":"not ")+"resolving module specifiers"),f&&(null===(o=l.log)||void 0===o||o.call(l,"collectAutoImports: module specifier cache size: "+f.count()));var m=h&&e.isIdentifier(h)?h.text.toLowerCase():"",_=e.codefix.getSymbolToExportInfoMap(a,l,n),g=null===(u=l.getPackageJsonAutoImportProvider)||void 0===u?void 0:u.call(l),y=c?void 0:e.createPackageJsonImportFilter(a,l);_.forEach((function(r,i){var o=i.substring(0,i.indexOf("|"));if(c||!e.isStringANonContextualKeyword(o)){var u=c&&e.some(r,(function(n){return c.source===e.stripQuotes(n.moduleSymbol.name)}));if(u||v(o)){var d=t?e.codefix.getModuleSpecifierForBestExportInfo(r,a,n,l,s):{moduleSpecifier:void 0,exportInfo:e.find(r,b)},p=d.moduleSpecifier,f=d.exportInfo;if(!f)return;var m=e.tryCast(f.moduleSymbol.valueDeclaration,e.isSourceFile),_=1===f.exportKind,g=_&&e.getLocalSymbolForExportDefault(f.symbol)||f.symbol;Ne(g,{kind:t?32:4,moduleSpecifier:p,symbolName:o,exportName:2===f.exportKind?"export=":f.symbol.name,fileName:null===m||void 0===m?void 0:m.fileName,isDefaultExport:_,moduleSymbol:f.moduleSymbol,isFromPackageJson:f.isFromPackageJson})}}})),null===(d=l.log)||void 0===d||d.call(l,"collectAutoImports: done in "+(e.timestamp()-p)+" ms")}function v(e){var n=e.toLowerCase();return t&&m?m[0]===n[0]&&ke(n,m):ke(n,m)}function b(t){var r=e.tryCast(t.moduleSymbol.valueDeclaration,e.isSourceFile);return r?e.isImportableFile(t.isFromPackageJson?g:n,a,r,y,z(t.isFromPackageJson),f):!y||y.allowsImportingAmbientModule(t.moduleSymbol,z(t.isFromPackageJson))}}function Ne(n,r){var a=e.getSymbolId(n);U[a]!==t.GlobalsOrKeywords&&(B[G.length]=r,U[a]=T?t.LocationPriority:t.AutoImportSuggestions,G.push(n))}function ke(e,n){if(0===n.length)return!0;for(var t=0,r=e.length,a=0;a<r;a++)if(e.charCodeAt(a)===n.charCodeAt(t)&&(t++,t===n.length))return!0;return!1}function Re(n,t,r){var a=n;while(a&&!e.positionBelongsToNode(a,t,r))a=a.parent;return a}function Oe(n){var t=e.timestamp(),a=Me(n)||qe(n)||Ye(n)||we(n);return r("getCompletionsAtPosition: isCompletionListBlocker: "+(e.timestamp()-t)),a}function we(e){if(11===e.kind)return!0;if(31===e.kind&&e.parent){if(276===e.parent.kind)return 276!==N.parent.kind;if(277===e.parent.kind||275===e.parent.kind)return!!e.parent.parent&&274===e.parent.parent.kind}return!1}function Pe(){if(v){var e=v.parent.kind;switch(re(v)){case 27:return 204===e||167===e||205===e||200===e||217===e||175===e||201===e;case 20:return 204===e||167===e||205===e||208===e||187===e;case 22:return 200===e||172===e||159===e;case 139:case 140:return!0;case 24:return 257===e;case 18:return 253===e||201===e;case 62:return 250===e||217===e;case 15:return 219===e;case 16:return 229===e;case 122:case 120:case 121:return 164===e}}return!1}function Me(n){return(e.isRegularExpressionLiteral(n)||e.isStringTextContainingNode(n))&&(e.rangeContainsPositionExclusive(e.createTextRangeFromSpan(e.createTextSpanFromNode(n)),o)||o===n.end&&(!!n.isUnterminated||e.isRegularExpressionLiteral(n)))}function Fe(){var n=ce(v);if(!n)return 0;var t=e.isIntersectionTypeNode(n.parent)?n.parent:void 0,r=t||n,a=le(r,u);if(!a)return 0;var i=u.getTypeFromTypeNode(r),o=oe(a,u),s=oe(i,u),c=new e.Set;return s.forEach((function(e){return c.add(e.escapedName)})),G=e.filter(o,(function(e){return!c.has(e.escapedName)})),w=0,P=!0,1}function Ge(){var n,t,r=je(v);if(!r)return 0;if(w=0,201===r.kind){var a=_e(r,u);if(void 0===a)return 16777216&r.flags?2:(M=!0,0);var i=u.getContextualType(r,4),o=(i||a).getStringIndexType(),s=(i||a).getNumberIndexType();if(P=!!o||!!s,n=ie(a,i,r,u),t=r.properties,0===n.length&&!s)return M=!0,0}else{e.Debug.assert(197===r.kind),P=!1;var c=e.getRootDeclaration(r.parent);if(!e.isVariableLike(c))return e.Debug.fail("Root declaration is not variable-like.");var l=e.hasInitializer(c)||e.hasType(c)||240===c.parent.parent.kind;if(l||161!==c.kind||(e.isExpression(c.parent)?l=!!u.getContextualType(c.parent):166!==c.parent.kind&&169!==c.parent.kind||(l=e.isExpression(c.parent.parent)&&!!u.getContextualType(c.parent.parent))),l){var d=u.getTypeAtLocation(r);if(!d)return 2;var p=e.getContainingClass(r);n=u.getPropertiesOfType(d).filter((function(n){return!(24&e.getDeclarationModifierFlagsFromSymbol(n))||p&&e.contains(d.symbol.declarations,p)})),t=r.elements}}return n&&n.length>0&&(G=Ze(n,e.Debug.checkDefined(t))),en(),1}function Be(){var n=!v||18!==v.kind&&27!==v.kind?void 0:e.tryCast(v.parent,e.isNamedImportsOrExports);if(!n)return 0;var t=(265===n.kind?n.parent.parent:n.parent).moduleSpecifier;if(!t)return 265===n.kind?2:0;var r=u.getSymbolAtLocation(t);if(!r)return 2;w=3,P=!1;var a=u.getExportsAndPropertiesOfModule(r),i=new e.Set(n.elements.filter((function(e){return!an(e)})).map((function(e){return(e.propertyName||e.name).escapedText})));return G=a.filter((function(e){return"default"!==e.escapedName&&!i.has(e.escapedName)})),1}function Ue(){var n,r=!v||18!==v.kind&&27!==v.kind?void 0:e.tryCast(v.parent,e.isNamedExports);if(!r)return 0;var a=e.findAncestor(r,e.or(e.isSourceFile,e.isModuleDeclaration));return w=5,P=!1,null===(n=a.locals)||void 0===n||n.forEach((function(n,r){var i,o;G.push(n),(null===(o=null===(i=a.symbol)||void 0===i?void 0:i.exports)||void 0===o?void 0:o.has(r))&&(U[e.getSymbolId(n)]=t.OptionalMember)})),1}function Ve(){var n=se(a,v,N,o);if(!n)return 0;if(w=3,P=!0,F=41===v.kind?0:e.isClassLike(n)?2:3,!e.isClassLike(n))return 1;var t=26===v.kind?v.parent.parent:v.parent,r=e.isClassElement(t)?e.getEffectiveModifierFlags(t):0;if(78===v.kind&&!an(v))switch(v.getText()){case"private":r|=8;break;case"static":r|=32;break;case"override":r|=16384;break}if(!(8&r)){var i=e.isClassLike(n)&&16384&r?e.singleElementArray(e.getEffectiveBaseTypeNode(n)):e.getAllSuperTypeNodes(n),s=e.flatMap(i,(function(e){var t=u.getTypeAtLocation(e);return 32&r?(null===t||void 0===t?void 0:t.symbol)&&u.getPropertiesOfType(u.getTypeOfSymbolAtLocation(t.symbol,n)):t&&u.getPropertiesOfType(t)}));G=tn(s,n.members,r)}return 1}function je(n){if(n){var t=n.parent;switch(n.kind){case 18:case 27:if(e.isObjectLiteralExpression(t)||e.isObjectBindingPattern(t))return t;break;case 41:return e.isMethodDeclaration(t)?e.tryCast(t.parent,e.isObjectLiteralExpression):void 0;case 78:return"async"===n.text&&e.isShorthandPropertyAssignment(n.parent)?n.parent.parent:void 0}}}function Ke(n){return!!n.parent&&e.isParameter(n.parent)&&e.isConstructorDeclaration(n.parent.parent)&&(e.isParameterPropertyModifier(n.kind)||e.isDeclarationName(n))}function He(n){if(n){var t=n.parent;switch(n.kind){case 20:case 27:return e.isConstructorDeclaration(n.parent)?n.parent:void 0;default:if(Ke(n))return t.parent}}}function We(n){if(n){var t,r=e.findAncestor(n.parent,(function(n){return e.isClassLike(n)?"quit":!(!e.isFunctionLikeDeclaration(n)||t!==n.body)||(t=n,!1)}));return r&&r}}function ze(n){if(n){var t=n.parent;switch(n.kind){case 31:case 30:case 43:case 78:case 202:case 282:case 281:case 283:if(t&&(275===t.kind||276===t.kind)){if(31===n.kind){var r=e.findPrecedingToken(n.pos,a,void 0);if(!t.typeArguments||r&&43===r.kind)break}return t}if(281===t.kind)return t.parent.parent;break;case 10:if(t&&(281===t.kind||283===t.kind))return t.parent.parent;break;case 19:if(t&&284===t.kind&&t.parent&&281===t.parent.kind)return t.parent.parent.parent;if(t&&283===t.kind)return t.parent.parent;break}}}function qe(n){var t=n.parent,r=t.kind;switch(n.kind){case 27:return 250===r||Qe(n)||233===r||256===r||Xe(r)||254===r||198===r||255===r||e.isClassLike(t)&&!!t.typeParameters&&t.typeParameters.end>=n.pos;case 24:return 198===r;case 58:return 199===r;case 22:return 198===r;case 20:return 288===r||Xe(r);case 18:return 256===r;case 29:return 253===r||222===r||254===r||255===r||e.isFunctionLikeKind(r);case 123:return 164===r&&!e.isClassLike(t.parent);case 25:return 161===r||!!t.parent&&198===t.parent.kind;case 122:case 120:case 121:return 161===r&&!e.isConstructorDeclaration(t.parent);case 126:return 266===r||271===r||264===r;case 134:case 146:return!ue(n);case 83:case 91:case 117:case 97:case 112:case 99:case 118:case 84:case 135:case 149:return!0;case 41:return e.isFunctionLike(n.parent)&&!e.isMethodDeclaration(n.parent)}if(ne(re(n))&&ue(n))return!1;if(Ke(n)&&(!e.isIdentifier(n)||e.isParameterPropertyModifier(re(n))||an(n)))return!1;switch(re(n)){case 125:case 83:case 84:case 133:case 91:case 97:case 117:case 118:case 120:case 121:case 122:case 123:case 112:return!0;case 129:return e.isPropertyDeclaration(n.parent)}var a=e.findAncestor(n.parent,e.isClassLike);if(a&&n===h&&Je(n,o))return!1;var i=e.getAncestor(n.parent,164);if(i&&n!==h&&e.isClassLike(h.parent.parent)&&o<=h.end){if(Je(n,h.end))return!1;if(62!==n.kind&&(e.isInitializedProperty(i)||e.hasType(i)))return!0}return e.isDeclarationName(n)&&!e.isShorthandPropertyAssignment(n.parent)&&!e.isJsxAttribute(n.parent)&&!(e.isClassLike(n.parent)&&(n!==h||o>h.end))}function Je(n,t){return 62!==n.kind&&(26===n.kind||!e.positionsAreOnSameLine(n.end,t,a))}function Xe(n){return e.isFunctionLikeKind(n)&&167!==n}function Ye(e){if(8===e.kind){var n=e.getFullText();return"."===n.charAt(n.length-1)}return!1}function Qe(n){return 251===n.parent.kind&&!e.isPossiblyTypeArgumentPosition(n,a,u)}function Ze(n,t){if(0===t.length)return n;for(var r=new e.Set,a=new e.Set,i=0,o=t;i<o.length;i++){var s=o[i];if((289===s.kind||290===s.kind||199===s.kind||166===s.kind||168===s.kind||169===s.kind||291===s.kind)&&!an(s)){var c=void 0;if(e.isSpreadAssignment(s))$e(s,r);else if(e.isBindingElement(s)&&s.propertyName)78===s.propertyName.kind&&(c=s.propertyName.escapedText);else{var l=e.getNameOfDeclaration(s);c=l&&e.isPropertyNameLiteral(l)?e.getEscapedTextOfIdentifierOrLiteral(l):void 0}void 0!==c&&a.add(c)}}var u=n.filter((function(e){return!a.has(e.escapedName)}));return nn(r,u),u}function $e(e,n){var t=e.expression,r=u.getSymbolAtLocation(t),a=r&&u.getTypeOfSymbolAtLocation(r,t),i=a&&a.properties;i&&i.forEach((function(e){n.add(e.name)}))}function en(){G.forEach((function(n){16777216&n.flags&&(U[e.getSymbolId(n)]=U[e.getSymbolId(n)]||t.OptionalMember)}))}function nn(n,r){if(0!==n.size)for(var a=0,i=r;a<i.length;a++){var o=i[a];n.has(o.name)&&(U[e.getSymbolId(o)]=t.MemberDeclaredBySpreadAssignment)}}function tn(n,t,r){for(var a=new e.Set,i=0,o=t;i<o.length;i++){var s=o[i];if((164===s.kind||166===s.kind||168===s.kind||169===s.kind)&&(!an(s)&&!e.hasEffectiveModifier(s,8)&&e.hasEffectiveModifier(s,32)===!!(32&r))){var c=e.getPropertyNameForPropertyNameNode(s.name);c&&a.add(c)}}return n.filter((function(n){return!a.has(n.escapedName)&&!!n.declarations&&!(8&e.getDeclarationModifierFlagsFromSymbol(n))&&!(n.valueDeclaration&&e.isPrivateIdentifierClassElementDeclaration(n.valueDeclaration))}))}function rn(n,t){for(var r=new e.Set,a=new e.Set,i=0,o=t;i<o.length;i++){var s=o[i];an(s)||(281===s.kind?r.add(s.name.escapedText):e.isJsxSpreadAttribute(s)&&$e(s,a))}var c=n.filter((function(e){return!r.has(e.escapedName)}));return nn(a,c),c}function an(e){return e.getStart(a)<=o&&o<=e.getEnd()}}function q(n,t,r,a){var i=t.isPackageJsonImport?a.getPackageJsonAutoImportProvider():r,o=i.getTypeChecker(),s=t.ambientModuleName?o.tryFindAmbientModule(t.ambientModuleName):t.fileName?o.getMergedSymbol(e.Debug.checkDefined(i.getSourceFile(t.fileName)).symbol):void 0;if(s){var c="export="===t.exportName?o.resolveExternalModuleSymbol(s):o.tryGetMemberInModuleExportsAndProperties(t.exportName,s);if(c){var l="default"===t.exportName;return c=l&&e.getLocalSymbolForExportDefault(c)||c,{symbol:c,origin:{kind:t.moduleSpecifier?32:4,moduleSymbol:s,symbolName:n,isDefaultExport:l,exportName:t.exportName,fileName:t.fileName}}}}}function J(n,t,r,a,i){var o=p(r)?r.symbolName:n.name;if(!(void 0===o||1536&n.flags&&e.isSingleOrDoubleQuote(o.charCodeAt(0))||e.isKnownSymbol(n))){var s={name:o,needsConvertPropertyAccess:!1};if(e.isIdentifierText(o,t,i?1:0)||n.valueDeclaration&&e.isPrivateIdentifierClassElementDeclaration(n.valueDeclaration))return s;switch(a){case 3:return;case 0:return{name:JSON.stringify(o),needsConvertPropertyAccess:!1};case 2:case 1:return 32===o.charCodeAt(0)?void 0:{name:o,needsConvertPropertyAccess:!0};case 5:case 4:return s;default:e.Debug.assertNever(a)}}}(function(e){e["LocalDeclarationPriority"]="0",e["LocationPriority"]="1",e["OptionalMember"]="2",e["MemberDeclaredBySpreadAssignment"]="3",e["SuggestedClassMembers"]="4",e["GlobalsOrKeywords"]="5",e["AutoImportSuggestions"]="6",e["JavascriptIdentifiers"]="7"})(t=n.SortText||(n.SortText={})),function(e){e["ThisProperty"]="ThisProperty/"}(r=n.CompletionSource||(n.CompletionSource={})),function(e){e[e["ThisType"]=1]="ThisType",e[e["SymbolMember"]=2]="SymbolMember",e[e["Export"]=4]="Export",e[e["Promise"]=8]="Promise",e[e["Nullable"]=16]="Nullable",e[e["ResolvedExport"]=32]="ResolvedExport",e[e["SymbolMemberNoExport"]=2]="SymbolMemberNoExport",e[e["SymbolMemberExport"]=6]="SymbolMemberExport"}(a||(a={})),function(e){e[e["None"]=0]="None",e[e["All"]=1]="All",e[e["ClassElementKeywords"]=2]="ClassElementKeywords",e[e["InterfaceElementKeywords"]=3]="InterfaceElementKeywords",e[e["ConstructorParameterKeywords"]=4]="ConstructorParameterKeywords",e[e["FunctionLikeBodyKeywords"]=5]="FunctionLikeBodyKeywords",e[e["TypeAssertionKeywords"]=6]="TypeAssertionKeywords",e[e["TypeKeywords"]=7]="TypeKeywords",e[e["Last"]=7]="Last"}(i||(i={})),function(e){e[e["Continue"]=0]="Continue",e[e["Success"]=1]="Success",e[e["Fail"]=2]="Fail"}(o||(o={})),n.getCompletionsAtPosition=g,n.getCompletionEntriesFromSymbols=R,n.getCompletionEntryDetails=M,n.createCompletionDetailsForSymbol=G,n.createCompletionDetails=B,n.getCompletionEntrySymbol=V,function(e){e[e["Data"]=0]="Data",e[e["JsDocTagName"]=1]="JsDocTagName",e[e["JsDocTag"]=2]="JsDocTag",e[e["JsDocParameterName"]=3]="JsDocParameterName",e[e["Keywords"]=4]="Keywords"}(s||(s={})),function(e){e[e["ObjectPropertyDeclaration"]=0]="ObjectPropertyDeclaration",e[e["Global"]=1]="Global",e[e["PropertyAccess"]=2]="PropertyAccess",e[e["MemberLike"]=3]="MemberLike",e[e["String"]=4]="String",e[e["None"]=5]="None"}(n.CompletionKind||(n.CompletionKind={}));var X=[],Y=e.memoize((function(){for(var n=[],r=80;r<=157;r++)n.push({name:e.tokenToString(r),kind:"keyword",kindModifiers:"",sortText:t.GlobalsOrKeywords});return n}));function Q(n,t){if(!t)return Z(n);var r=n+7+1;return X[r]||(X[r]=Z(n).filter((function(n){return!$(e.stringToToken(n.name))})))}function Z(n){return X[n]||(X[n]=Y().filter((function(t){var r=e.stringToToken(t.name);switch(n){case 0:return!1;case 1:return te(r)||133===r||139===r||149===r||140===r||e.isTypeKeyword(r)&&150!==r;case 5:return te(r);case 2:return ne(r);case 3:return ee(r);case 4:return e.isParameterPropertyModifier(r);case 6:return e.isTypeKeyword(r)||84===r;case 7:return e.isTypeKeyword(r);default:return e.Debug.assertNever(n)}})))}function $(e){switch(e){case 125:case 128:case 155:case 131:case 133:case 91:case 154:case 116:case 135:case 117:case 137:case 138:case 139:case 140:case 141:case 144:case 145:case 156:case 120:case 121:case 122:case 142:case 147:case 148:case 149:case 151:case 152:return!0;default:return!1}}function ee(e){return 142===e}function ne(n){switch(n){case 125:case 132:case 134:case 146:case 129:case 133:case 156:return!0;default:return e.isClassMemberModifier(n)}}function te(n){return 129===n||130===n||126===n||!e.isContextualKeyword(n)&&!ne(n)}function re(n){return e.isIdentifier(n)?n.originalKeywordKind||0:n.kind}function ae(n,t){var r=e.findAncestor(n,e.isJSDoc);return r&&r.tags&&(e.rangeContainsPosition(r,t)?e.findLast(r.tags,(function(e){return e.pos<t})):void 0)}function ie(n,t,r,a){var i=t&&t!==n,o=!i||3&t.flags?n:a.getUnionType([n,t]),s=o.isUnion()?a.getAllPossiblePropertiesOfTypes(o.types.filter((function(n){return!(131068&n.flags||a.isArrayLikeType(n)||e.typeHasCallOrConstructSignatures(n,a)||a.isTypeInvalidDueToUnionDiscriminant(n,r))}))):o.getApparentProperties();return i?s.filter(c):s;function c(n){return e.some(n.declarations,(function(e){return e.parent!==r}))}}function oe(n,t){return n.isUnion()?e.Debug.checkEachDefined(t.getAllPossiblePropertiesOfTypes(n.types),"getAllPossiblePropertiesOfTypes() should all be defined"):e.Debug.checkEachDefined(n.getApparentProperties(),"getApparentProperties() should all be defined")}function se(n,t,r,a){switch(r.kind){case 338:return e.tryCast(r.parent,e.isObjectTypeDeclaration);case 1:var i=e.tryCast(e.lastOrUndefined(e.cast(r.parent,e.isSourceFile).statements),e.isObjectTypeDeclaration);if(i&&!e.findChildOfKind(i,19,n))return i;break;case 78:if(e.isPropertyDeclaration(r.parent)&&r.parent.initializer===r)return;if(ue(r))return e.findAncestor(r,e.isObjectTypeDeclaration)}if(t){if(132===r.kind||e.isIdentifier(t)&&e.isPropertyDeclaration(t.parent)&&e.isClassLike(r))return e.findAncestor(t,e.isClassLike);switch(t.kind){case 62:return;case 26:case 19:return ue(r)&&r.parent.name===r?r.parent.parent:e.tryCast(r,e.isObjectTypeDeclaration);case 18:case 27:return e.tryCast(t.parent,e.isObjectTypeDeclaration);default:if(!ue(t))return e.getLineAndCharacterOfPosition(n,t.getEnd()).line!==e.getLineAndCharacterOfPosition(n,a).line&&e.isObjectTypeDeclaration(r)?r:void 0;var o=e.isClassLike(t.parent.parent)?ne:ee;return o(t.kind)||41===t.kind||e.isIdentifier(t)&&o(e.stringToToken(t.text))?t.parent.parent:void 0}}}function ce(n){if(n){var t=n.parent;switch(n.kind){case 18:if(e.isTypeLiteralNode(t))return t;break;case 26:case 27:case 78:if(163===t.kind&&e.isTypeLiteralNode(t.parent))return t.parent;break}}}function le(n,t){if(n){if(e.isTypeNode(n)&&e.isTypeReferenceType(n.parent))return t.getTypeArgumentConstraint(n);var r=le(n.parent,t);if(r)switch(n.kind){case 163:return t.getTypeOfPropertyOfContextualType(r,n.symbol.escapedName);case 184:case 178:case 183:return r}}}function ue(n){return n.parent&&e.isClassOrTypeElement(n.parent)&&e.isObjectTypeDeclaration(n.parent.parent)}function de(n,t,r,a){switch(t){case".":case"@":return!0;case'"':case"'":case"`":return!!r&&e.isStringLiteralOrTemplate(r)&&a===r.getStart(n)+1;case"#":return!!r&&e.isPrivateIdentifier(r)&&!!e.getContainingClass(r);case"<":return!!r&&29===r.kind&&(!e.isBinaryExpression(r.parent)||pe(r.parent));case"/":return!!r&&(e.isStringLiteralLike(r)?!!e.tryGetImportFromModuleSpecifier(r):43===r.kind&&e.isJsxClosingElement(r.parent));case" ":return!!r&&e.isImportKeyword(r)&&298===r.parent.kind;default:return e.Debug.assertNever(t)}}function pe(n){var t=n.left;return e.nodeIsMissing(t)}function fe(e,n,t){var r=t.resolveName("self",void 0,111551,!1);if(r&&t.getTypeOfSymbolAtLocation(r,n)===e)return!0;var a=t.resolveName("global",void 0,111551,!1);if(a&&t.getTypeOfSymbolAtLocation(a,n)===e)return!0;var i=t.resolveName("globalThis",void 0,111551,!1);return!(!i||t.getTypeOfSymbolAtLocation(i,n)!==e)}function me(n){return!!(n.valueDeclaration&&32&e.getEffectiveModifierFlags(n.valueDeclaration)&&e.isClassLike(n.valueDeclaration.parent))}function _e(n,t){var r=t.getContextualType(n);return r||(e.isBinaryExpression(n.parent)&&62===n.parent.operatorToken.kind&&n===n.parent.left?t.getTypeAtLocation(n.parent):void 0)}function ge(n){var t=r();return 153===t||t&&e.rangeIsOnSingleLine(t,t.getSourceFile())?t:void 0;function r(){var t=n.parent;return e.isImportEqualsDeclaration(t)?ye(t.moduleReference)?t:void 0:e.isNamedImports(t)||e.isNamespaceImport(t)?ye(t.parent.parent.moduleSpecifier)&&(e.isNamespaceImport(t)||t.elements.length<2)&&!t.parent.name?19===n.kind||78===n.kind?153:t.parent.parent:void 0:e.isImportKeyword(n)&&e.isSourceFile(t)?n:e.isImportKeyword(n)&&e.isImportDeclaration(t)&&ye(t.moduleSpecifier)?t:void 0}}function ye(n){var t;return!!e.nodeIsMissing(n)||!(null===(t=e.tryCast(e.isExternalModuleReference(n)?n.expression:n,e.isStringLiteralLike))||void 0===t?void 0:t.text)}function he(n){var t=e.findAncestor(n,(function(n){return e.isFunctionBlock(n)||ve(n)||e.isBindingPattern(n)?"quit":e.isVariableDeclaration(n)}));return t}function ve(n){return n.parent&&e.isArrowFunction(n.parent)&&n.parent.body===n}function be(n,t,r){void 0===r&&(r=new e.Map);var a=e.skipAlias(n.exportSymbol||n,t);return!!(788968&a.flags)||!!(1536&a.flags)&&e.addToSeen(r,e.getSymbolId(a))&&t.getExportsOfModule(a).some((function(e){return be(e,t,r)}))}n.getPropertiesForObjectExpression=ie})(e.Completions||(e.Completions={}))}(d||(d={})),function(e){(function(n){function t(n,t,i,s,c){var l=e.getTouchingPropertyName(i,s);if(l.parent&&(e.isJsxOpeningElement(l.parent)&&l.parent.tagName===l||e.isJsxClosingElement(l.parent))){var u=l.parent.parent,d=u.openingElement,p=u.closingElement,f=[d,p].map((function(e){var n=e.tagName;return r(n,i)}));return[{fileName:i.fileName,highlightSpans:f}]}return a(s,l,n,t,c)||o(l,i)}function r(n,t){return{fileName:t.fileName,textSpan:e.createTextSpanFromNode(n,t),kind:"none"}}function a(n,t,r,a,i){var o=new e.Set(i.map((function(e){return e.fileName}))),s=e.FindAllReferences.getReferenceEntriesForNode(n,t,r,i,a,void 0,o);if(s){var c=e.arrayToMultiMap(s.map(e.FindAllReferences.toHighlightSpan),(function(e){return e.fileName}),(function(e){return e.span}));return e.mapDefined(e.arrayFrom(c.entries()),(function(n){var t=n[0],a=n[1];if(!o.has(t)){if(!r.redirectTargetsMap.has(t))return;var s=r.getSourceFile(t),c=e.find(i,(function(e){return!!e.redirectInfo&&e.redirectInfo.redirectTarget===s}));t=c.fileName,e.Debug.assert(o.has(t))}return{fileName:t,highlightSpans:a}}))}}function o(e,n){var t=s(e,n);return t&&[{fileName:n.fileName,highlightSpans:t}]}function s(n,t){switch(n.kind){case 98:case 90:return e.isIfStatement(n.parent)?D(n.parent,t):void 0;case 104:return o(n.parent,e.isReturnStatement,T);case 108:return o(n.parent,e.isThrowStatement,E);case 110:case 82:case 95:var a=82===n.kind?n.parent.parent:n.parent;return o(a,e.isTryStatement,b);case 106:return o(n.parent,e.isSwitchStatement,v);case 81:case 87:return e.isDefaultClause(n.parent)||e.isCaseClause(n.parent)?o(n.parent.parent.parent,e.isSwitchStatement,v):void 0;case 80:case 85:return o(n.parent,e.isBreakOrContinueStatement,h);case 96:case 114:case 89:return o(n.parent,(function(n){return e.isIterationStatement(n,!0)}),y);case 132:return i(e.isConstructorDeclaration,[132]);case 134:case 146:return i(e.isAccessor,[134,146]);case 130:return o(n.parent,e.isAwaitExpression,S);case 129:return s(S(n));case 124:return s(x(n));default:return e.isModifierKind(n.kind)&&(e.isDeclaration(n.parent)||e.isVariableStatement(n.parent))?s(m(n.kind,n.parent)):void 0}function i(r,a){return o(n.parent,r,(function(n){return e.mapDefined(n.symbol.declarations,(function(n){return r(n)?e.find(n.getChildren(t),(function(n){return e.contains(a,n.kind)})):void 0}))}))}function o(e,n,r){return n(e)?s(r(e,t)):void 0}function s(e){return e&&e.map((function(e){return r(e,t)}))}}function c(n){return e.isThrowStatement(n)?[n]:e.isTryStatement(n)?e.concatenate(n.catchClause?c(n.catchClause):n.tryBlock&&c(n.tryBlock),n.finallyBlock&&c(n.finallyBlock)):e.isFunctionLike(n)?void 0:d(n,c)}function l(n){var t=n;while(t.parent){var r=t.parent;if(e.isFunctionBlock(r)||298===r.kind)return r;if(e.isTryStatement(r)&&r.tryBlock===t&&r.catchClause)return t;t=r}}function u(n){return e.isBreakOrContinueStatement(n)?[n]:e.isFunctionLike(n)?void 0:d(n,u)}function d(n,t){var r=[];return n.forEachChild((function(n){var a=t(n);void 0!==a&&r.push.apply(r,e.toArray(a))})),r}function p(e,n){var t=f(n);return!!t&&t===e}function f(n){return e.findAncestor(n,(function(t){switch(t.kind){case 245:if(241===n.kind)return!1;case 238:case 239:case 240:case 237:case 236:return!n.label||C(t,n.label.escapedText);default:return e.isFunctionLike(t)&&"quit"}}))}function m(n,t){return e.mapDefined(_(t,e.modifierToFlag(n)),(function(t){return e.findModifier(t,n)}))}function _(n,t){var r=n.parent;switch(r.kind){case 258:case 298:case 231:case 285:case 286:return 128&t&&e.isClassDeclaration(n)?i(i([],n.members),[n]):r.statements;case 167:case 166:case 252:return i(i([],r.parameters),e.isClassLike(r.parent)?r.parent.members:[]);case 253:case 222:case 254:case 178:var a=r.members;if(92&t){var o=e.find(r.members,e.isConstructorDeclaration);if(o)return i(i([],a),o.parameters)}else if(128&t)return i(i([],a),[r]);return a;case 201:return;default:e.Debug.assertNever(r,"Invalid container kind.")}}function g(n,t){for(var r=[],a=2;a<arguments.length;a++)r[a-2]=arguments[a];return!(!t||!e.contains(r,t.kind))&&(n.push(t),!0)}function y(n){var t=[];if(g(t,n.getFirstToken(),96,114,89)&&236===n.kind)for(var r=n.getChildren(),a=r.length-1;a>=0;a--)if(g(t,r[a],114))break;return e.forEach(u(n.statement),(function(e){p(n,e)&&g(t,e.getFirstToken(),80,85)})),t}function h(e){var n=f(e);if(n)switch(n.kind){case 238:case 239:case 240:case 236:case 237:return y(n);case 245:return v(n)}}function v(n){var t=[];return g(t,n.getFirstToken(),106),e.forEach(n.caseBlock.clauses,(function(r){g(t,r.getFirstToken(),81,87),e.forEach(u(r),(function(e){p(n,e)&&g(t,e.getFirstToken(),80)}))})),t}function b(n,t){var r=[];if(g(r,n.getFirstToken(),110),n.catchClause&&g(r,n.catchClause.getFirstToken(),82),n.finallyBlock){var a=e.findChildOfKind(n,95,t);g(r,a,95)}return r}function E(n,t){var r=l(n);if(r){var a=[];return e.forEach(c(r),(function(n){a.push(e.findChildOfKind(n,108,t))})),e.isFunctionBlock(r)&&e.forEachReturnStatement(r,(function(n){a.push(e.findChildOfKind(n,104,t))})),a}}function T(n,t){var r=e.getContainingFunction(n);if(r){var a=[];return e.forEachReturnStatement(e.cast(r.body,e.isBlock),(function(n){a.push(e.findChildOfKind(n,104,t))})),e.forEach(c(r.body),(function(n){a.push(e.findChildOfKind(n,108,t))})),a}}function S(n){var t=e.getContainingFunction(n);if(t){var r=[];return t.modifiers&&t.modifiers.forEach((function(e){g(r,e,129)})),e.forEachChild(t,(function(n){L(n,(function(n){e.isAwaitExpression(n)&&g(r,n.getFirstToken(),130)}))})),r}}function x(n){var t=e.getContainingFunction(n);if(t){var r=[];return e.forEachChild(t,(function(n){L(n,(function(n){e.isYieldExpression(n)&&g(r,n.getFirstToken(),124)}))})),r}}function L(n,t){t(n),e.isFunctionLike(n)||e.isClassLike(n)||e.isInterfaceDeclaration(n)||e.isModuleDeclaration(n)||e.isTypeAliasDeclaration(n)||e.isTypeNode(n)||e.forEachChild(n,(function(e){return L(e,t)}))}function D(n,t){for(var a=A(n,t),i=[],o=0;o<a.length;o++){if(90===a[o].kind&&o<a.length-1){for(var s=a[o],c=a[o+1],l=!0,u=c.getStart(t)-1;u>=s.end;u--)if(!e.isWhiteSpaceSingleLine(t.text.charCodeAt(u))){l=!1;break}if(l){i.push({fileName:t.fileName,textSpan:e.createTextSpanFromBounds(s.getStart(),c.end),kind:"reference"}),o++;continue}}i.push(r(a[o],t))}return i}function A(n,t){var r=[];while(e.isIfStatement(n.parent)&&n.parent.elseStatement===n)n=n.parent;while(1){var a=n.getChildren(t);g(r,a[0],98);for(var i=a.length-1;i>=0;i--)if(g(r,a[i],90))break;if(!n.elseStatement||!e.isIfStatement(n.elseStatement))break;n=n.elseStatement}return r}function C(n,t){return!!e.findAncestor(n.parent,(function(n){return e.isLabeledStatement(n)?n.label.escapedText===t:"quit"}))}n.getDocumentHighlights=t})(e.DocumentHighlights||(e.DocumentHighlights={}))}(d||(d={})),function(e){function n(e){return!!e.sourceFile}function t(e,n){return r(e,n)}function r(t,r,i){void 0===r&&(r="");var o=new e.Map,s=e.createGetCanonicalFileName(!!t);function c(){var t=e.arrayFrom(o.keys()).filter((function(e){return e&&"_"===e.charAt(0)})).map((function(e){var t=o.get(e),r=[];return t.forEach((function(e,t){n(e)?r.push({name:t,scriptKind:e.sourceFile.scriptKind,refCount:e.languageServiceRefCount}):e.forEach((function(e,n){return r.push({name:t,scriptKind:n,refCount:e.languageServiceRefCount})}))})),r.sort((function(e,n){return n.refCount-e.refCount})),{bucket:e,sourceFiles:r}}));return JSON.stringify(t,void 0,2)}function l(n,t,i,o,c){var l=e.toPath(n,r,s),d=a(t);return u(n,l,t,d,i,o,c)}function u(e,n,t,r,a,i,o){return m(e,n,t,r,a,i,!0,o)}function d(n,t,i,o,c){var l=e.toPath(n,r,s),u=a(t);return p(n,l,t,u,i,o,c)}function p(e,n,t,r,a,i,o){return m(e,n,t,r,a,i,!1,o)}function f(t,r){var a=n(t)?t:t.get(e.Debug.checkDefined(r,"If there are more than one scriptKind's for same document the scriptKind should be provided"));return e.Debug.assert(void 0===r||!a||a.sourceFile.scriptKind===r,"Script kind should match provided ScriptKind:"+r+" and sourceFile.scriptKind: "+(null===a||void 0===a?void 0:a.sourceFile.scriptKind)+", !entry: "+!a),a}function m(t,r,a,s,c,l,u,d){d=e.ensureScriptKind(t,d);var p=6===d?100:a.target||1,m=e.getOrUpdate(o,s,(function(){return new e.Map})),_=m.get(r),g=_&&f(_,d);if(!g&&i){var y=i.getDocument(s,r);y&&(e.Debug.assert(u),g={sourceFile:y,languageServiceRefCount:0},h())}if(g)g.sourceFile.version!==l&&(g.sourceFile=e.updateLanguageServiceSourceFile(g.sourceFile,c,l,c.getChangeRange(g.sourceFile.scriptSnapshot)),i&&i.setDocument(s,r,g.sourceFile)),u&&g.languageServiceRefCount++;else{y=e.createLanguageServiceSourceFile(t,c,p,l,!1,d);i&&i.setDocument(s,r,y),g={sourceFile:y,languageServiceRefCount:1},h()}return e.Debug.assert(0!==g.languageServiceRefCount),g.sourceFile;function h(){if(_)if(n(_)){var t=new e.Map;t.set(_.sourceFile.scriptKind,_),t.set(d,g),m.set(r,t)}else _.set(d,g);else m.set(r,g)}}function _(n,t,i){var o=e.toPath(n,r,s),c=a(t);return g(o,c,i)}function g(t,r,a){var i=e.Debug.checkDefined(o.get(r)),s=i.get(t),c=f(s,a);c.languageServiceRefCount--,e.Debug.assert(c.languageServiceRefCount>=0),0===c.languageServiceRefCount&&(n(s)?i.delete(t):(s.delete(a),1===s.size&&i.set(t,e.firstDefinedIterator(s.values(),e.identity))))}function y(n,t){return e.arrayFrom(o.entries(),(function(e){var r=e[0],a=e[1],i=a.get(n),o=i&&f(i,t);return[r,o&&o.languageServiceRefCount]}))}return{acquireDocument:l,acquireDocumentWithKey:u,updateDocument:d,updateDocumentWithKey:p,releaseDocument:_,releaseDocumentWithKey:g,getLanguageServiceRefCounts:y,reportStats:c,getKeyForCompilationSettings:a}}function a(n){return e.sourceFileAffectingCompilerOptions.map((function(t){return e.getCompilerOptionValue(n,t)})).join("|")}e.createDocumentRegistry=t,e.createDocumentRegistryInternal=r}(d||(d={})),function(e){(function(n){function t(e,n,t,i){var s=c(e,t,i);return function(c,l,u){var d=r(e,n,s,l,t,i),p=d.directImports,f=d.indirectUsers;return o({indirectUsers:f},a(p,c,l.exportKind,t,u))}}function r(n,t,r,a,o,s){var c=a.exportingModuleSymbol,l=a.exportKind,u=e.nodeSeenTracker(),d=e.nodeSeenTracker(),p=[],f=!!c.globalExports,m=f?void 0:[];return g(c),{directImports:p,indirectUsers:_()};function _(){if(f)return n;if(c.declarations)for(var r=0,a=c.declarations;r<a.length;r++){var i=a[r];e.isExternalModuleAugmentation(i)&&t.has(i.getSourceFile().fileName)&&S(i)}return m.map(e.getSourceFileOfNode)}function g(n){var t=x(n);if(t)for(var r=0,a=t;r<a.length;r++){var i=a[r];if(u(i))switch(s&&s.throwIfCancellationRequested(),i.kind){case 204:if(e.isImportCall(i)){b(i);break}if(!f){var c=i.parent;if(2===l&&250===c.kind){var d=c.name;if(78===d.kind){p.push(d);break}}}break;case 78:break;case 261:T(i,i.name,e.hasSyntacticModifier(i,1),!1);break;case 262:p.push(i);var m=i.importClause&&i.importClause.namedBindings;m&&264===m.kind?T(i,m.name,!1,!0):!f&&e.isDefaultImport(i)&&S(h(i));break;case 268:i.exportClause?270===i.exportClause.kind?S(h(i),!0):p.push(i):g(y(i,o));break;case 196:i.isTypeOf&&!i.qualifier&&E(i)&&S(i.getSourceFile(),!0),p.push(i);break;default:e.Debug.failBadSyntaxKind(i,"Unexpected import kind.")}}}function b(n){var t=e.findAncestor(n,v)||n.getSourceFile();S(t,!!E(n,!0))}function E(n,t){return void 0===t&&(t=!1),e.findAncestor(n,(function(n){return t&&v(n)?"quit":e.some(n.modifiers,(function(e){return 92===e.kind}))}))}function T(n,t,r,a){if(2===l)a||p.push(n);else if(!f){var s=h(n);e.Debug.assert(298===s.kind||257===s.kind),r||i(s,t,o)?S(s,!0):S(s)}}function S(n,t){void 0===t&&(t=!1),e.Debug.assert(!f);var r=d(n);if(r&&(m.push(n),t)){var a=o.getMergedSymbol(n.symbol);if(a){e.Debug.assert(!!(1536&a.flags));var i=x(a);if(i)for(var s=0,c=i;s<c.length;s++){var l=c[s];e.isImportTypeNode(l)||S(h(l),!0)}}}}function x(n){return r.get(e.getSymbolId(n).toString())}}function a(n,t,r,a,i){var o=[],s=[];function c(e,n){o.push([e,n])}if(n)for(var l=0,u=n;l<u.length;l++){var d=u[l];p(d)}return{importSearches:o,singleReferences:s};function p(n){if(261!==n.kind)if(78!==n.kind)if(196!==n.kind){if(10===n.moduleSpecifier.kind)if(268!==n.kind){var o=n.importClause||{name:void 0,namedBindings:void 0},l=o.name,u=o.namedBindings;if(u)switch(u.kind){case 264:f(u.name);break;case 265:0!==r&&1!==r||m(u);break;default:e.Debug.assertNever(u)}if(l&&(1===r||2===r)&&(!i||l.escapedText===e.symbolEscapedNameNoDefault(t))){var d=a.getSymbolAtLocation(l);c(l,d)}}else n.exportClause&&e.isNamedExports(n.exportClause)&&m(n.exportClause)}else if(n.qualifier){var p=e.getFirstIdentifier(n.qualifier);p.escapedText===e.symbolName(t)&&s.push(p)}else 2===r&&s.push(n.argument.literal);else f(n);else b(n)&&f(n.name)}function f(e){2!==r||i&&!_(e.escapedText)||c(e,a.getSymbolAtLocation(e))}function m(e){if(e)for(var n=0,r=e.elements;n<r.length;n++){var o=r[n],l=o.name,u=o.propertyName;if(_((u||l).escapedText))if(u)s.push(u),i&&l.escapedText!==t.escapedName||c(l,a.getSymbolAtLocation(l));else{var d=271===o.kind&&o.propertyName?a.getExportSpecifierLocalTargetSymbol(o):a.getSymbolAtLocation(l);c(l,d)}}}function _(e){return e===t.escapedName||0!==r&&"default"===e}}function i(n,t,r){var a=r.getSymbolAtLocation(t);return!!l(n,(function(n){if(e.isExportDeclaration(n)){var t=n.exportClause,i=n.moduleSpecifier;return!i&&t&&e.isNamedExports(t)&&t.elements.some((function(e){return r.getExportSpecifierLocalTargetSymbol(e)===a}))}}))}function s(e,n,t){for(var r=[],a=e.getTypeChecker(),i=0,o=n;i<o.length;i++){var s=o[i],c=t.valueDeclaration;if(298===(null===c||void 0===c?void 0:c.kind)){for(var l=0,d=s.referencedFiles;l<d.length;l++){var p=d[l];e.getSourceFileFromReference(s,p)===c&&r.push({kind:"reference",referencingFile:s,ref:p})}for(var f=0,m=s.typeReferenceDirectives;f<m.length;f++){p=m[f];var _=e.getResolvedTypeReferenceDirectives().get(p.fileName);void 0!==_&&_.resolvedFileName===c.fileName&&r.push({kind:"reference",referencingFile:s,ref:p})}}u(s,(function(e,n){var i=a.getSymbolAtLocation(n);i===t&&r.push({kind:"import",literal:n})}))}return r}function c(n,t,r){for(var a=new e.Map,i=0,o=n;i<o.length;i++){var s=o[i];r&&r.throwIfCancellationRequested(),u(s,(function(n,r){var i=t.getSymbolAtLocation(r);if(i){var o=e.getSymbolId(i).toString(),s=a.get(o);s||a.set(o,s=[]),s.push(n)}}))}return a}function l(n,t){return e.forEach(298===n.kind?n.statements:n.body.statements,(function(n){return t(n)||v(n)&&e.forEach(n.body&&n.body.statements,t)}))}function u(n,t){if(n.externalModuleIndicator||void 0!==n.imports)for(var r=0,a=n.imports;r<a.length;r++){var i=a[r];t(e.importFromModuleSpecifier(i),i)}else l(n,(function(n){switch(n.kind){case 268:case 262:var r=n;r.moduleSpecifier&&e.isStringLiteral(r.moduleSpecifier)&&t(r,r.moduleSpecifier);break;case 261:r=n;b(r)&&t(r,r.moduleReference.expression);break}}))}function d(n,t,r,a){return a?i():i()||o();function i(){var i,o=n.parent,l=o.parent;if(t.exportSymbol)return 202===o.kind?(null===(i=t.declarations)||void 0===i?void 0:i.some((function(e){return e===o})))&&e.isBinaryExpression(l)?m(l,!1):void 0:s(t.exportSymbol,c(o));var u=f(o,n);if(u&&e.hasSyntacticModifier(u,1)){if(e.isImportEqualsDeclaration(u)&&u.moduleReference===n){if(a)return;var d=r.getSymbolAtLocation(u.name);return{kind:0,symbol:d}}return s(t,c(u))}if(e.isNamespaceExport(o))return s(t,0);if(e.isExportAssignment(o))return p(o);if(e.isExportAssignment(l))return p(l);if(e.isBinaryExpression(o))return m(o,!0);if(e.isBinaryExpression(l))return m(l,!0);if(e.isJSDocTypedefTag(o))return s(t,0);function p(e){if(e.symbol.parent){var n=e.isExportEquals?2:1;return{kind:1,symbol:t,exportInfo:{exportingModuleSymbol:e.symbol.parent,exportKind:n}}}}function m(n,a){var i;switch(e.getAssignmentDeclarationKind(n)){case 1:i=0;break;case 2:i=2;break;default:return}var o=a?r.getSymbolAtLocation(e.getNameOfAccessExpression(e.cast(n.left,e.isAccessExpression))):t;return o&&s(o,i)}}function o(){var a=m(n);if(a){var i=r.getImmediateAliasedSymbol(t);if(i){i=g(i,r),"export="===i.escapedName&&(i=p(i,r));var o=e.symbolEscapedNameNoDefault(i);return void 0===o||"default"===o||o===t.escapedName?{kind:0,symbol:i}:void 0}}}function s(e,n){var t=_(e,n,r);return t&&{kind:1,symbol:e,exportInfo:t}}function c(n){return e.hasSyntacticModifier(n,512)?1:0}}function p(n,t){if(2097152&n.flags)return e.Debug.checkDefined(t.getImmediateAliasedSymbol(n));var r=e.Debug.checkDefined(n.valueDeclaration);return e.isExportAssignment(r)?e.Debug.checkDefined(r.expression.symbol):e.isBinaryExpression(r)?e.Debug.checkDefined(r.right.symbol):e.isSourceFile(r)?e.Debug.checkDefined(r.symbol):e.Debug.fail()}function f(n,t){var r=e.isVariableDeclaration(n)?n:e.isBindingElement(n)?e.walkUpBindingElementsAndPatterns(n):void 0;return r?n.name!==t||e.isCatchClause(r.parent)?void 0:e.isVariableStatement(r.parent.parent)?r.parent.parent:void 0:n}function m(n){var t=n.parent;switch(t.kind){case 261:return t.name===n&&b(t);case 266:return!t.propertyName;case 263:case 264:return e.Debug.assert(t.name===n),!0;case 199:return e.isInJSFile(n)&&e.isRequireVariableDeclaration(t);default:return!1}}function _(n,t,r){var a=n.parent;if(a){var i=r.getMergedSymbol(a);return e.isExternalModuleSymbol(i)?{exportingModuleSymbol:i,exportKind:t}:void 0}}function g(n,t){if(n.declarations)for(var r=0,a=n.declarations;r<a.length;r++){var i=a[r];if(e.isExportSpecifier(i)&&!i.propertyName&&!i.parent.parent.moduleSpecifier)return t.getExportSpecifierLocalTargetSymbol(i);if(e.isPropertyAccessExpression(i)&&e.isModuleExportsAccessExpression(i.expression)&&!e.isPrivateIdentifier(i.name))return t.getSymbolAtLocation(i);if(e.isShorthandPropertyAssignment(i)&&e.isBinaryExpression(i.parent.parent)&&2===e.getAssignmentDeclarationKind(i.parent.parent))return t.getExportSpecifierLocalTargetSymbol(i.name)}return n}function y(e,n){return n.getMergedSymbol(h(e).symbol)}function h(n){if(204===n.kind)return n.getSourceFile();var t=n.parent;return 298===t.kind?t:(e.Debug.assert(258===t.kind),e.cast(t.parent,v))}function v(e){return 257===e.kind&&10===e.name.kind}function b(e){return 273===e.moduleReference.kind&&10===e.moduleReference.expression.kind}n.createImportTracker=t,function(e){e[e["Named"]=0]="Named",e[e["Default"]=1]="Default",e[e["ExportEquals"]=2]="ExportEquals"}(n.ExportKind||(n.ExportKind={})),function(e){e[e["Import"]=0]="Import",e[e["Export"]=1]="Export"}(n.ImportExport||(n.ImportExport={})),n.findModuleReferences=s,n.getImportOrExportSymbol=d,n.getExportInfo=_})(e.FindAllReferences||(e.FindAllReferences={}))}(d||(d={})),function(e){(function(n){var t;function r(e,n){return void 0===n&&(n=1),{kind:n,node:e.name||e,context:s(e)}}function a(e){return e&&void 0===e.kind}function s(n){if(e.isDeclaration(n))return c(n);if(n.parent){if(!e.isDeclaration(n.parent)&&!e.isExportAssignment(n.parent)){if(e.isInJSFile(n)){var t=e.isBinaryExpression(n.parent)?n.parent:e.isAccessExpression(n.parent)&&e.isBinaryExpression(n.parent.parent)&&n.parent.parent.left===n.parent?n.parent.parent:void 0;if(t&&0!==e.getAssignmentDeclarationKind(t))return c(t)}if(e.isJsxOpeningElement(n.parent)||e.isJsxClosingElement(n.parent))return n.parent.parent;if(e.isJsxSelfClosingElement(n.parent)||e.isLabeledStatement(n.parent)||e.isBreakOrContinueStatement(n.parent))return n.parent;if(e.isStringLiteralLike(n)){var r=e.tryGetImportFromModuleSpecifier(n);if(r){var a=e.findAncestor(r,(function(n){return e.isDeclaration(n)||e.isStatement(n)||e.isJSDocTag(n)}));return e.isDeclaration(a)?c(a):a}}var i=e.findAncestor(n,e.isComputedPropertyName);return i?c(i.parent):void 0}return n.parent.name===n||e.isConstructorDeclaration(n.parent)||e.isExportAssignment(n.parent)||(e.isImportOrExportSpecifier(n.parent)||e.isBindingElement(n.parent))&&n.parent.propertyName===n||87===n.kind&&e.hasSyntacticModifier(n.parent,513)?c(n.parent):void 0}}function c(n){if(n)switch(n.kind){case 250:return e.isVariableDeclarationList(n.parent)&&1===n.parent.declarations.length?e.isVariableStatement(n.parent.parent)?n.parent.parent:e.isForInOrOfStatement(n.parent.parent)?c(n.parent.parent):n.parent:n;case 199:return c(n.parent.parent);case 266:return n.parent.parent.parent;case 271:case 264:return n.parent.parent;case 263:case 270:return n.parent;case 217:return e.isExpressionStatement(n.parent)?n.parent:n;case 240:case 239:return{start:n.initializer,end:n.expression};case 289:case 290:return e.isArrayLiteralOrObjectLiteralDestructuringPattern(n.parent)?c(e.findAncestor(n.parent,(function(n){return e.isBinaryExpression(n)||e.isForInOrOfStatement(n)}))):n;default:return n}}function l(e,n,t){if(t){var r=a(t)?D(t.start,n,t.end):D(t,n);return r.start!==e.start||r.length!==e.length?{contextSpan:r}:void 0}}function u(n,r,a,i,o){var s=e.getTouchingPropertyName(i,o),c=t.getReferencedSymbolsForNode(o,s,n,a,r,{use:1}),l=n.getTypeChecker();return c&&c.length?e.mapDefined(c,(function(e){var n=e.definition,t=e.references;return n&&{definition:l.runWithCancellationToken(r,(function(e){return g(n,e,s)})),references:t.map(b)}})):void 0}function d(n,t,r,a,o){var s,c=e.getTouchingPropertyName(a,o),l=p(n,t,r,c,o);if(202===c.parent.kind||199===c.parent.kind||203===c.parent.kind||105===c.kind)s=l&&i([],l);else{var u=l&&i([],l),d=new e.Map;while(u&&u.length){var f=u.shift();if(e.addToSeen(d,e.getNodeId(f.node))){s=e.append(s,f);var m=p(n,t,r,f.node,f.node.pos);m&&u.push.apply(u,m)}}}var _=n.getTypeChecker();return e.map(s,(function(e){return S(e,_)}))}function p(n,a,i,o,s){if(298!==o.kind){var c=n.getTypeChecker();if(290===o.parent.kind){var l=[];return t.getReferenceEntriesForShorthandPropertyAssignment(o,c,(function(e){return l.push(r(e))})),l}if(105===o.kind||e.isSuperProperty(o.parent)){var u=c.getSymbolAtLocation(o);return u.valueDeclaration&&[r(u.valueDeclaration)]}return m(s,o,n,i,a,{implementations:!0,use:1})}}function f(n,r,a,i,o,s,c){return e.map(_(t.getReferencedSymbolsForNode(o,i,n,a,r,s)),(function(e){return c(e,i,n.getTypeChecker())}))}function m(n,r,a,i,o,s,c){return void 0===s&&(s={}),void 0===c&&(c=new e.Set(i.map((function(e){return e.fileName})))),_(t.getReferencedSymbolsForNode(n,r,a,i,o,s,c))}function _(n){return n&&e.flatMap(n,(function(e){return e.references}))}function g(n,t,r){var a=function(){switch(n.type){case 0:var a=n.symbol,i=h(a,t,r),s=i.displayParts,l=i.kind,u=s.map((function(e){return e.text})).join(""),d=a.declarations&&e.firstOrUndefined(a.declarations),p=d?e.getNameOfDeclaration(d)||d:r;return o(o({},y(p)),{name:u,kind:l,displayParts:s,context:c(d)});case 1:p=n.node;return o(o({},y(p)),{name:p.text,kind:"label",displayParts:[e.displayPart(p.text,e.SymbolDisplayPartKind.text)]});case 2:p=n.node;var f=e.tokenToString(p.kind);return o(o({},y(p)),{name:f,kind:"keyword",displayParts:[{text:f,kind:"keyword"}]});case 3:p=n.node,a=t.getSymbolAtLocation(p);var m=a&&e.SymbolDisplay.getSymbolDisplayPartsDocumentationAndSymbolKind(t,a,p.getSourceFile(),e.getContainerNode(p),p).displayParts||[e.textPart("this")];return o(o({},y(p)),{name:"this",kind:"var",displayParts:m});case 4:p=n.node;return o(o({},y(p)),{name:p.text,kind:"var",displayParts:[e.displayPart(e.getTextOfNode(p),e.SymbolDisplayPartKind.stringLiteral)]});case 5:return{textSpan:e.createTextSpanFromRange(n.reference),sourceFile:n.file,name:n.reference.fileName,kind:"string",displayParts:[e.displayPart('"'+n.reference.fileName+'"',e.SymbolDisplayPartKind.stringLiteral)]};default:return e.Debug.assertNever(n)}}(),i=a.sourceFile,s=a.textSpan,u=a.name,d=a.kind,p=a.displayParts,f=a.context;return o({containerKind:"",containerName:"",fileName:i.fileName,kind:d,name:u,textSpan:s,displayParts:p},l(s,i,f))}function y(n){var t=n.getSourceFile();return{sourceFile:t,textSpan:D(e.isComputedPropertyName(n)?n.expression:n,t)}}function h(n,r,a){var i=t.getIntersectingMeaningFromDeclarations(a,n),o=n.declarations&&e.firstOrUndefined(n.declarations)||a,s=e.SymbolDisplay.getSymbolDisplayPartsDocumentationAndSymbolKind(r,n,o.getSourceFile(),o,o,i),c=s.displayParts,l=s.symbolKind;return{displayParts:c,kind:l}}function v(e,n,t,r){return o(o({},E(e)),r&&T(e,n,t))}function b(e){var n=E(e);if(0===e.kind)return o(o({},n),{isWriteAccess:!1,isDefinition:!1});var t=e.kind,r=e.node;return o(o({},n),{isWriteAccess:C(r),isDefinition:I(r),isInString:2===t||void 0})}function E(e){if(0===e.kind)return{textSpan:e.textSpan,fileName:e.fileName};var n=e.node.getSourceFile(),t=D(e.node,n);return o({textSpan:t,fileName:n.fileName},l(t,n,e.context))}function T(n,t,r){if(0!==n.kind&&e.isIdentifier(t)){var a=n.node,i=n.kind,o=a.parent,s=t.text,c=e.isShorthandPropertyAssignment(o);if(c||e.isObjectBindingElementWithoutPropertyName(o)&&o.name===a&&void 0===o.dotDotDotToken){var l={prefixText:s+": "},u={suffixText:": "+s};if(3===i)return l;if(4===i)return u;if(c){var d=o.parent;return e.isObjectLiteralExpression(d)&&e.isBinaryExpression(d.parent)&&e.isModuleExportsAccessExpression(d.parent.left)?l:u}return l}if(e.isImportSpecifier(o)&&!o.propertyName){var p=e.isExportSpecifier(t.parent)?r.getExportSpecifierLocalTargetSymbol(t.parent):r.getSymbolAtLocation(t);return e.contains(p.declarations,o)?{prefixText:s+" as "}:e.emptyOptions}if(e.isExportSpecifier(o)&&!o.propertyName)return t===n.node||r.getSymbolAtLocation(t)===r.getSymbolAtLocation(n.node)?{prefixText:s+" as "}:{suffixText:" as "+s}}return e.emptyOptions}function S(e,n){var t=E(e);if(0!==e.kind){var r=e.node;return o(o({},t),x(r,n))}return o(o({},t),{kind:"",displayParts:[]})}function x(n,t){var r=t.getSymbolAtLocation(e.isDeclaration(n)&&n.name?n.name:n);return r?h(r,t,n):201===n.kind?{kind:"interface",displayParts:[e.punctuationPart(20),e.textPart("object literal"),e.punctuationPart(21)]}:222===n.kind?{kind:"local class",displayParts:[e.punctuationPart(20),e.textPart("anonymous local class"),e.punctuationPart(21)]}:{kind:e.getNodeKind(n),displayParts:[]}}function L(e){var n=E(e);if(0===e.kind)return{fileName:n.fileName,span:{textSpan:n.textSpan,kind:"reference"}};var t=C(e.node),r=o({textSpan:n.textSpan,kind:t?"writtenReference":"reference",isInString:2===e.kind||void 0},n.contextSpan&&{contextSpan:n.contextSpan});return{fileName:n.fileName,span:r}}function D(n,t,r){var a=n.getStart(t),i=(r||n).getEnd();return e.isStringLiteralLike(n)&&(e.Debug.assert(void 0===r),a+=1,i-=1),e.createTextSpanFromBounds(a,i)}function A(e){return 0===e.kind?e.textSpan:D(e.node,e.node.getSourceFile())}function C(n){var t=e.getDeclarationFromName(n);return!!t&&N(t)||87===n.kind||e.isWriteAccess(n)}function I(n){return 87===n.kind||!!e.getDeclarationFromName(n)||e.isLiteralComputedPropertyDeclarationName(n)||132===n.kind&&e.isConstructorDeclaration(n.parent)}function N(n){if(8388608&n.flags)return!0;switch(n.kind){case 217:case 199:case 253:case 222:case 87:case 256:case 292:case 271:case 263:case 261:case 266:case 254:case 328:case 335:case 281:case 257:case 260:case 264:case 270:case 161:case 290:case 255:case 160:return!0;case 289:return!e.isArrayLiteralOrObjectLiteralDestructuringPattern(n.parent);case 252:case 209:case 167:case 166:case 168:case 169:return!!n.body;case 250:case 164:return!!n.initializer||e.isCatchClause(n.parent);case 165:case 163:case 337:case 330:return!1;default:return e.Debug.failBadSyntaxKind(n)}}(function(e){e[e["Symbol"]=0]="Symbol",e[e["Label"]=1]="Label",e[e["Keyword"]=2]="Keyword",e[e["This"]=3]="This",e[e["String"]=4]="String",e[e["TripleSlashReference"]=5]="TripleSlashReference"})(n.DefinitionKind||(n.DefinitionKind={})),function(e){e[e["Span"]=0]="Span",e[e["Node"]=1]="Node",e[e["StringLiteral"]=2]="StringLiteral",e[e["SearchedLocalFoundProperty"]=3]="SearchedLocalFoundProperty",e[e["SearchedPropertyFoundLocal"]=4]="SearchedPropertyFoundLocal"}(n.EntryKind||(n.EntryKind={})),n.nodeEntry=r,n.isContextWithStartAndEndNode=a,n.getContextNode=c,n.toContextSpan=l,function(e){e[e["Other"]=0]="Other",e[e["References"]=1]="References",e[e["Rename"]=2]="Rename"}(n.FindReferencesUse||(n.FindReferencesUse={})),n.findReferencedSymbols=u,n.getImplementationsAtPosition=d,n.findReferenceOrRenameEntries=f,n.getReferenceEntriesForNode=m,n.toRenameLocation=v,n.toReferenceEntry=b,n.toHighlightSpan=L,n.getTextSpanOfEntry=A,function(t){function a(n,t,r,a,i,u,p){var _,g;if(void 0===u&&(u={}),void 0===p&&(p=new e.Set(a.map((function(e){return e.fileName})))),1===u.use?t=e.getAdjustedReferenceLocation(t):2===u.use&&(t=e.getAdjustedRenameLocation(t)),e.isSourceFile(t)){var y=e.GoToDefinition.getReferenceAtPosition(t,n,r);if(!(null===y||void 0===y?void 0:y.file))return;var h=r.getTypeChecker().getMergedSymbol(y.file.symbol);if(h)return d(r,h,!1,a,p);var v=r.getFileIncludeReasons();if(!v)return;return[{definition:{type:5,reference:y.reference,file:t},references:o(y.file,v,r)||e.emptyArray}]}if(!u.implementations){var b=f(t,a,i);if(b)return b}var E=r.getTypeChecker(),T=E.getSymbolAtLocation(e.isConstructorDeclaration(t)&&t.parent.name||t);if(T){if("export="===T.escapedName)return d(r,T.parent,!1,a,p);var S=c(T,r,a,i,u,p);if(S&&!(33554432&T.flags))return S;var x=s(t,T,E),L=x&&c(x,r,a,i,u,p),D=m(T,t,a,p,E,i,u);return l(r,S,D,L)}if(!u.implementations&&e.isStringLiteralLike(t)){if(e.isModuleSpecifierLike(t)){v=r.getFileIncludeReasons();var A=null===(g=null===(_=t.getSourceFile().resolvedModules)||void 0===_?void 0:_.get(t.text))||void 0===g?void 0:g.resolvedFileName,C=A?r.getSourceFile(A):void 0;if(C)return[{definition:{type:4,node:t},references:o(C,v,r)||e.emptyArray}]}return se(t,a,E,i)}}function i(n,t,r,a){var i,s;void 0===a&&(a=new e.Set(r.map((function(e){return e.fileName}))));var c=null===(i=t.getSourceFile(n))||void 0===i?void 0:i.symbol;if(c)return(null===(s=d(t,c,!1,r,a)[0])||void 0===s?void 0:s.references)||e.emptyArray;var l=t.getFileIncludeReasons(),u=t.getSourceFile(n);return u&&l&&o(u,l,t)||e.emptyArray}function o(n,t,r){for(var a,i=t.get(n.path)||e.emptyArray,o=0,s=i;o<s.length;o++){var c=s[o];if(e.isReferencedFile(c)){var l=r.getSourceFileByPath(c.file),u=e.getReferencedFileLocation(r.getSourceFileByPath,c);e.isReferenceFileLocation(u)&&(a=e.append(a,{kind:0,fileName:l.fileName,textSpan:e.createTextSpanFromRange(u)}))}}return a}function s(n,t,r){if(n.parent&&e.isNamespaceExportDeclaration(n.parent)){var a=r.getAliasedSymbol(t),i=r.getMergedSymbol(a);if(a!==i)return i}}function c(n,t,r,a,i,o){var s=1536&n.flags&&n.declarations&&e.find(n.declarations,e.isSourceFile);if(s){var c=n.exports.get("export="),u=d(t,n,!!c,r,o);if(!c||!o.has(s.fileName))return u;var p=t.getTypeChecker();return n=e.skipAlias(c,p),l(t,u,m(n,void 0,r,o,p,a,i))}}function l(n){for(var t,r=[],a=1;a<arguments.length;a++)r[a-1]=arguments[a];for(var i=0,o=r;i<o.length;i++){var s=o[i];if(s&&s.length)if(t)for(var c=function(r){if(!r.definition||0!==r.definition.type)return t.push(r),"continue";var a=r.definition.symbol,i=e.findIndex(t,(function(e){return!!e.definition&&0===e.definition.type&&e.definition.symbol===a}));if(-1===i)return t.push(r),"continue";var o=t[i];t[i]={definition:o.definition,references:o.references.concat(r.references).sort((function(t,r){var a=u(n,t),i=u(n,r);if(a!==i)return e.compareValues(a,i);var o=A(t),s=A(r);return o.start!==s.start?e.compareValues(o.start,s.start):e.compareValues(o.length,s.length)}))}},l=0,d=s;l<d.length;l++){var p=d[l];c(p)}else t=s}return t}function u(e,n){var t=0===n.kind?e.getSourceFile(n.fileName):n.node.getSourceFile();return e.getSourceFiles().indexOf(t)}function d(t,a,i,o,s){e.Debug.assert(!!a.valueDeclaration);var c=e.mapDefined(n.findModuleReferences(t,o,a),(function(n){if("import"===n.kind){var t=n.literal.parent;if(e.isLiteralTypeNode(t)){var a=e.cast(t.parent,e.isImportTypeNode);if(i&&!a.qualifier)return}return r(n.literal)}return{kind:0,fileName:n.referencingFile.fileName,textSpan:e.createTextSpanFromRange(n.ref)}}));if(a.declarations)for(var l=0,u=a.declarations;l<u.length;l++){var d=u[l];switch(d.kind){case 298:break;case 257:s.has(d.getSourceFile().fileName)&&c.push(r(d.name));break;default:e.Debug.assert(!!(33554432&a.flags),"Expected a module symbol to be declared by a SourceFile or ModuleDeclaration.")}}var p=a.exports.get("export=");if(null===p||void 0===p?void 0:p.declarations)for(var f=0,m=p.declarations;f<m.length;f++){d=m[f];var _=d.getSourceFile();if(s.has(_.fileName)){var g=e.isBinaryExpression(d)&&e.isPropertyAccessExpression(d.left)?d.left.expression:e.isExportAssignment(d)?e.Debug.checkDefined(e.findChildOfKind(d,92,_)):e.getNameOfDeclaration(d)||d;c.push(r(g))}}return c.length?[{definition:{type:0,symbol:a},references:c}]:e.emptyArray}function p(n){return 142===n.kind&&e.isTypeOperatorNode(n.parent)&&142===n.parent.operator}function f(n,t,r){if(e.isTypeKeyword(n.kind)){if(113===n.kind&&e.isVoidExpression(n.parent))return;if(142===n.kind&&!p(n))return;return M(t,n.kind,r,142===n.kind?p:void 0)}if(e.isJumpStatementTarget(n)){var a=e.getTargetLabel(n.parent,n.text);return a&&w(a.parent,a)}return e.isLabelOfLabeledStatement(n)?w(n.parent,n):e.isThis(n)?oe(n,t,r):105===n.kind?ae(n):void 0}function m(n,t,r,a,i,o,s){var c=t&&y(n,t,i,!ve(s))||n,l=t?fe(t,c):7,u=[],d=new b(r,a,t?g(t):0,i,o,l,s,u),p=ve(s)&&c.declarations?e.find(c.declarations,e.isExportSpecifier):void 0;if(p)V(p.name,c,p,d.createSearch(t,n,void 0),d,!0,!0);else if(t&&87===t.kind&&"default"===c.escapedName&&c.parent)z(t,c,d),E(t,c,{exportingModuleSymbol:c.parent,exportKind:1},d);else{var f=d.createSearch(t,c,void 0,{allSearchSymbols:t?ce(c,t,i,2===s.use,!!s.providePrefixAndSuffixTextForRename,!!s.implementations):[c]});_(c,d,f)}return u}function _(n,t,r){var a=C(n);if(a)G(a,a.getSourceFile(),r,t,!(e.isSourceFile(a)&&!e.contains(t.sourceFiles,a)));else for(var i=0,o=t.sourceFiles;i<o.length;i++){var s=o[i];t.cancellationToken.throwIfCancellationRequested(),L(s,r,t)}}function g(n){switch(n.kind){case 167:case 132:return 1;case 78:if(e.isClassLike(n.parent))return e.Debug.assert(n.parent.name===n),2;default:return 0}}function y(n,t,r,a){var i=t.parent;return e.isExportSpecifier(i)&&a?j(t,n,i,r):e.firstDefined(n.declarations,(function(a){if(!a.parent){if(33554432&n.flags)return;e.Debug.fail("Unexpected symbol at "+e.Debug.formatSyntaxKind(t.kind)+": "+e.Debug.formatSymbol(n))}return e.isTypeLiteralNode(a.parent)&&e.isUnionTypeNode(a.parent.parent)?r.getPropertyOfType(r.getTypeFromTypeNode(a.parent.parent),n.name):void 0}))}var h;function v(n){if(33555968&n.flags){var t=n.declarations&&e.find(n.declarations,(function(n){return!e.isSourceFile(n)&&!e.isModuleDeclaration(n)}));return t&&t.symbol}}t.getReferencedSymbolsForNode=a,t.getReferencesForFileName=i,function(e){e[e["None"]=0]="None",e[e["Constructor"]=1]="Constructor",e[e["Class"]=2]="Class"}(h||(h={}));var b=function(){function t(n,t,r,a,i,o,s,c){this.sourceFiles=n,this.sourceFilesSet=t,this.specialSearchKind=r,this.checker=a,this.cancellationToken=i,this.searchMeaning=o,this.options=s,this.result=c,this.inheritsFromCache=new e.Map,this.markSeenContainingTypeReference=e.nodeSeenTracker(),this.markSeenReExportRHS=e.nodeSeenTracker(),this.symbolIdToReferences=[],this.sourceFileToSeenSymbols=[]}return t.prototype.includesSourceFile=function(e){return this.sourceFilesSet.has(e.fileName)},t.prototype.getImportSearches=function(e,t){return this.importTracker||(this.importTracker=n.createImportTracker(this.sourceFiles,this.sourceFilesSet,this.checker,this.cancellationToken)),this.importTracker(e,t,2===this.options.use)},t.prototype.createSearch=function(n,t,r,a){void 0===a&&(a={});var i=a.text,o=void 0===i?e.stripQuotes(e.symbolName(e.getLocalSymbolForExportDefault(t)||v(t)||t)):i,s=a.allSearchSymbols,c=void 0===s?[t]:s,l=e.escapeLeadingUnderscores(o),u=this.options.implementations&&n?he(n,t,this.checker):void 0;return{symbol:t,comingFrom:r,text:o,escapedText:l,parents:u,allSearchSymbols:c,includes:function(n){return e.contains(c,n)}}},t.prototype.referenceAdder=function(n){var t=e.getSymbolId(n),a=this.symbolIdToReferences[t];return a||(a=this.symbolIdToReferences[t]=[],this.result.push({definition:{type:0,symbol:n},references:a})),function(e,n){return a.push(r(e,n))}},t.prototype.addStringOrCommentReference=function(e,n){this.result.push({definition:void 0,references:[{kind:0,fileName:e,textSpan:n}]})},t.prototype.markSearchedSymbols=function(n,t){for(var r=e.getNodeId(n),a=this.sourceFileToSeenSymbols[r]||(this.sourceFileToSeenSymbols[r]=new e.Set),i=!1,o=0,s=t;o<s.length;o++){var c=s[o];i=e.tryAddToSet(a,e.getSymbolId(c))||i}return i},t}();function E(e,n,t,r){var a=r.getImportSearches(n,t),i=a.importSearches,o=a.singleReferences,s=a.indirectUsers;if(o.length)for(var c=r.referenceAdder(n),l=0,u=o;l<u.length;l++){var d=u[l];S(d,r)&&c(d)}for(var p=0,f=i;p<f.length;p++){var m=f[p],_=m[0],g=m[1];F(_.getSourceFile(),r.createSearch(_,g,1),r)}if(s.length){var y=void 0;switch(t.exportKind){case 0:y=r.createSearch(e,n,1);break;case 1:y=2===r.options.use?void 0:r.createSearch(e,n,1,{text:"default"});break;case 2:break}if(y)for(var h=0,v=s;h<v.length;h++){var b=v[h];L(b,y,r)}}}function T(t,r,a,i,o,s,c,l){for(var u=n.createImportTracker(t,new e.Set(t.map((function(e){return e.fileName}))),r,a),d=u(i,{exportKind:c?1:0,exportingModuleSymbol:o},!1),p=d.importSearches,f=d.indirectUsers,m=0,_=p;m<_.length;m++){var g=_[m][0];l(g)}for(var y=0,h=f;y<h.length;y++)for(var v=h[y],b=0,E=R(v,c?"default":s);b<E.length;b++){var T=E[b],S=r.getSymbolAtLocation(T),x=e.some(null===S||void 0===S?void 0:S.declarations,(function(n){return!!e.tryCast(n,e.isExportAssignment)}));!e.isIdentifier(T)||e.isImportOrExportSpecifier(T.parent)||S!==i&&!x||l(T)}}function S(n,t){return!!B(n,t)&&(2!==t.options.use||!!e.isIdentifier(n)&&!(e.isImportOrExportSpecifier(n.parent)&&"default"===n.escapedText))}function x(e,n){if(e.declarations)for(var t=0,r=e.declarations;t<r.length;t++){var a=r[t],i=a.getSourceFile();F(i,n.createSearch(a,e,0),n,n.includesSourceFile(i))}}function L(n,t,r){void 0!==e.getNameTable(n).get(t.escapedText)&&F(n,t,r)}function D(n,t){return e.isArrayLiteralOrObjectLiteralDestructuringPattern(n.parent.parent)?t.getPropertySymbolOfDestructuringAssignment(n):void 0}function C(n){var t=n.declarations,r=n.flags,a=n.parent,i=n.valueDeclaration;if(i&&(209===i.kind||222===i.kind))return i;if(t){if(8196&r){var o=e.find(t,(function(n){return e.hasEffectiveModifier(n,8)||e.isPrivateIdentifierClassElementDeclaration(n)}));return o?e.getAncestor(o,253):void 0}if(!t.some(e.isObjectBindingElementWithoutPropertyName)){var s=a&&!(262144&n.flags);if(!s||e.isExternalModuleSymbol(a)&&!a.globalExports){for(var c,l=0,u=t;l<u.length;l++){var d=u[l],p=e.getContainerNode(d);if(c&&c!==p)return;if(!p||298===p.kind&&!e.isExternalOrCommonJsModule(p))return;if(c=p,e.isFunctionExpression(c)){var f=void 0;while(f=e.getNextJSDocCommentLocation(c))c=f}}return s?c.getSourceFile():c}}}}function I(e,n,t,r){return void 0===r&&(r=t),N(e,n,t,(function(){return!0}),r)||!1}function N(n,t,r,a,i){void 0===i&&(i=r);var o=e.isParameterPropertyDeclaration(n.parent,n.parent.parent)?e.first(t.getSymbolsOfParameterPropertyDeclaration(n.parent,n.text)):t.getSymbolAtLocation(n);if(o)for(var s=0,c=R(r,o.name,i);s<c.length;s++){var l=c[s];if(e.isIdentifier(l)&&l!==n&&l.escapedText===n.escapedText){var u=t.getSymbolAtLocation(l);if(u===o||t.getShorthandAssignmentValueSymbol(l.parent)===o||e.isExportSpecifier(l.parent)&&j(l,u,l.parent,t)===o){var d=a(l);if(d)return d}}}}function k(n,t,r,a){if(!n.name||!e.isIdentifier(n.name))return!1;for(var i=e.Debug.checkDefined(r.getSymbolAtLocation(n.name)),o=0,s=t;o<s.length;o++)for(var c=s[o],l=0,u=R(c,i.name);l<u.length;l++){var d=u[l];if(e.isIdentifier(d)&&d!==n.name&&d.escapedText===n.name.escapedText){var p=e.climbPastPropertyAccess(d),f=e.isCallExpression(p.parent)&&p.parent.expression===p?p.parent:void 0,m=r.getSymbolAtLocation(d);if(m&&r.getRootSymbols(m).some((function(e){return e===i}))&&a(d,f))return!0}}return!1}function R(n,t,r){return void 0===r&&(r=n),O(n,t,r).map((function(t){return e.getTouchingPropertyName(n,t)}))}function O(n,t,r){void 0===r&&(r=n);var a=[];if(!t||!t.length)return a;var i=n.text,o=i.length,s=t.length,c=i.indexOf(t,r.pos);while(c>=0){if(c>r.end)break;var l=c+s;0!==c&&e.isIdentifierPart(i.charCodeAt(c-1),99)||l!==o&&e.isIdentifierPart(i.charCodeAt(l),99)||a.push(c),c=i.indexOf(t,c+s+1)}return a}function w(n,t){var a=n.getSourceFile(),i=t.text,o=e.mapDefined(R(a,i,n),(function(n){return n===t||e.isJumpStatementTarget(n)&&e.getTargetLabel(n,i)===t?r(n):void 0}));return[{definition:{type:1,node:t},references:o}]}function P(n,t){switch(n.kind){case 79:case 78:return n.text.length===t.length;case 14:case 10:var r=n;return(e.isLiteralNameOfPropertyDeclarationOrIndexAccess(r)||e.isNameOfModuleDeclaration(n)||e.isExpressionOfExternalModuleImportEqualsDeclaration(n)||e.isCallExpression(n.parent)&&e.isBindableObjectDefinePropertyCall(n.parent)&&n.parent.arguments[1]===n)&&r.text.length===t.length;case 8:return e.isLiteralNameOfPropertyDeclarationOrIndexAccess(n)&&n.text.length===t.length;case 87:return"default".length===t.length;default:return!1}}function M(n,t,a,i){var o=e.flatMap(n,(function(n){return a.throwIfCancellationRequested(),e.mapDefined(R(n,e.tokenToString(t),n),(function(e){if(e.kind===t&&(!i||i(e)))return r(e)}))}));return o.length?[{definition:{type:2,node:o[0].node},references:o}]:void 0}function F(e,n,t,r){return void 0===r&&(r=!0),t.cancellationToken.throwIfCancellationRequested(),G(e,e,n,t,r)}function G(e,n,t,r,a){if(r.markSearchedSymbols(n,t.allSearchSymbols))for(var i=0,o=O(n,t.text,e);i<o.length;i++){var s=o[i];U(n,s,t,r,a)}}function B(n,t){return!!(e.getMeaningFromLocation(n)&t.searchMeaning)}function U(n,t,r,a,i){var o=e.getTouchingPropertyName(n,t);if(P(o,r.text)){if(B(o,a)){var s=a.checker.getSymbolAtLocation(o);if(s){var c=o.parent;if(!e.isImportSpecifier(c)||c.propertyName!==o){if(e.isExportSpecifier(c))return e.Debug.assert(78===o.kind),void V(o,s,c,r,a,i);var l=pe(r,s,o,a);if(l){switch(a.specialSearchKind){case 0:i&&z(o,l,a);break;case 1:q(o,n,r,a);break;case 2:J(o,r,a);break;default:e.Debug.assertNever(a.specialSearchKind)}s=e.isInJSFile(o)&&199===o.parent.kind&&e.isRequireVariableDeclaration(o.parent)?o.parent.symbol:s,H(o,s,r,a)}else W(s,r,a)}}}}else!a.options.implementations&&(a.options.findInStrings&&e.isInString(n,t)||a.options.findInComments&&e.isInNonReferenceComment(n,t))&&a.addStringOrCommentReference(n.fileName,e.createTextSpan(t,r.text.length))}function V(t,r,a,i,o,s,c){e.Debug.assert(!c||!!o.options.providePrefixAndSuffixTextForRename,"If alwaysGetReferences is true, then prefix/suffix text must be enabled");var l=a.parent,u=a.propertyName,d=a.name,p=l.parent,f=j(t,r,a,o.checker);if(c||i.includes(f)){if(u?t===u?(p.moduleSpecifier||v(),s&&2!==o.options.use&&o.markSeenReExportRHS(d)&&z(d,e.Debug.checkDefined(a.symbol),o)):o.markSeenReExportRHS(t)&&v():2===o.options.use&&"default"===d.escapedText||v(),!ve(o.options)||c){var m=87===t.originalKeywordKind||87===a.name.originalKeywordKind,_=m?1:0,g=e.Debug.checkDefined(a.symbol),y=n.getExportInfo(g,_,o.checker);y&&E(t,g,y,o)}if(1!==i.comingFrom&&p.moduleSpecifier&&!u&&!ve(o.options)){var h=o.checker.getExportSpecifierLocalTargetSymbol(a);h&&x(h,o)}}function v(){s&&z(t,f,o)}}function j(e,n,t,r){return K(e,t)&&r.getExportSpecifierLocalTargetSymbol(t)||n}function K(n,t){var r=t.parent,a=t.propertyName,i=t.name;return e.Debug.assert(a===n||i===n),a?a===n:!r.parent.moduleSpecifier}function H(e,t,r,a){var i=n.getImportOrExportSymbol(e,t,a.checker,1===r.comingFrom);if(i){var o=i.symbol;0===i.kind?ve(a.options)||x(o,a):E(e,o,i.exportInfo,a)}}function W(n,t,r){var a=n.flags,i=n.valueDeclaration,o=r.checker.getShorthandAssignmentValueSymbol(i),s=i&&e.getNameOfDeclaration(i);33554432&a||!s||!t.includes(o)||z(s,o,r)}function z(e,n,t){var r="kind"in n?n:{kind:void 0,symbol:n},a=r.kind,i=r.symbol,o=t.referenceAdder(i);t.options.implementations?ee(e,o,t):o(e,a)}function q(n,t,r,a){e.isNewExpressionTarget(n)&&z(n,r.symbol,a);var i=function(){return a.referenceAdder(r.symbol)};if(e.isClassLike(n.parent))e.Debug.assert(87===n.kind||n.parent.name===n),X(r.symbol,t,i());else{var o=ye(n);o&&(Q(o,i()),$(o,a))}}function J(n,t,r){z(n,t.symbol,r);var a=n.parent;if(2!==r.options.use&&e.isClassLike(a)){e.Debug.assert(a.name===n);for(var i=r.referenceAdder(t.symbol),o=0,s=a.members;o<s.length;o++){var c=s[o];e.isMethodOrAccessor(c)&&e.hasSyntacticModifier(c,32)&&(c.body&&c.body.forEachChild((function n(t){107===t.kind?i(t):e.isFunctionLike(t)||e.isClassLike(t)||t.forEachChild(n)})))}}}function X(n,t,r){var a=Y(n);if(a&&a.declarations)for(var i=0,o=a.declarations;i<o.length;i++){var s=o[i],c=e.findChildOfKind(s,132,t);e.Debug.assert(167===s.kind&&!!c),r(c)}n.exports&&n.exports.forEach((function(n){var t=n.valueDeclaration;if(t&&166===t.kind){var a=t.body;a&&ge(a,107,(function(n){e.isNewExpressionTarget(n)&&r(n)}))}}))}function Y(e){return e.members&&e.members.get("__constructor")}function Q(n,t){var r=Y(n.symbol);if(r&&r.declarations)for(var a=0,i=r.declarations;a<i.length;a++){var o=i[a];e.Debug.assert(167===o.kind);var s=o.body;s&&ge(s,105,(function(n){e.isCallExpressionTarget(n)&&t(n)}))}}function Z(e){return!!Y(e.symbol)}function $(e,n){if(!Z(e)){var t=e.symbol,r=n.createSearch(void 0,t,void 0);_(t,n,r)}}function ee(n,t,r){if(e.isDeclarationName(n)&&me(n.parent))t(n);else if(78===n.kind){290===n.parent.kind&&_e(n,r.checker,t);var a=ne(n);if(a)t(a);else{var i=e.findAncestor(n,(function(n){return!e.isQualifiedName(n.parent)&&!e.isTypeNode(n.parent)&&!e.isTypeElement(n.parent)})),o=i.parent;if(e.hasType(o)&&o.type===i&&r.markSeenContainingTypeReference(o))if(e.hasInitializer(o))c(o.initializer);else if(e.isFunctionLike(o)&&o.body){var s=o.body;231===s.kind?e.forEachReturnStatement(s,(function(e){e.expression&&c(e.expression)})):c(s)}else e.isAssertionExpression(o)&&c(o.expression)}}function c(e){te(e)&&t(e)}}function ne(n){return e.isIdentifier(n)||e.isPropertyAccessExpression(n)?ne(n.parent):e.isExpressionWithTypeArguments(n)?e.tryCast(n.parent.parent,e.isClassLike):void 0}function te(e){switch(e.kind){case 208:return te(e.expression);case 210:case 209:case 201:case 222:case 200:return!0;default:return!1}}function re(n,t,r,a){if(n===t)return!0;var i=e.getSymbolId(n)+","+e.getSymbolId(t),o=r.get(i);if(void 0!==o)return o;r.set(i,!1);var s=!!n.declarations&&n.declarations.some((function(n){return e.getAllSuperTypeNodes(n).some((function(e){var n=a.getTypeAtLocation(e);return!!n&&!!n.symbol&&re(n.symbol,t,r,a)}))}));return r.set(i,s),s}function ae(n){var t=e.getSuperContainer(n,!1);if(t){var a=32;switch(t.kind){case 164:case 163:case 166:case 165:case 167:case 168:case 169:a&=e.getSyntacticModifierFlags(t),t=t.parent;break;default:return}var i=t.getSourceFile(),o=e.mapDefined(R(i,"super",t),(function(n){if(105===n.kind){var i=e.getSuperContainer(n,!1);return i&&(32&e.getSyntacticModifierFlags(i))===a&&i.parent.symbol===t.symbol?r(n):void 0}}));return[{definition:{type:0,symbol:t.symbol},references:o}]}}function ie(e){return 78===e.kind&&161===e.parent.kind&&e.parent.name===e}function oe(n,t,a){var i=e.getThisContainer(n,!1),o=32;switch(i.kind){case 166:case 165:if(e.isObjectLiteralMethod(i)){o&=e.getSyntacticModifierFlags(i),i=i.parent;break}case 164:case 163:case 167:case 168:case 169:o&=e.getSyntacticModifierFlags(i),i=i.parent;break;case 298:if(e.isExternalModule(i)||ie(n))return;case 252:case 209:break;default:return}var s=e.flatMap(298===i.kind?t:[i.getSourceFile()],(function(n){return a.throwIfCancellationRequested(),R(n,"this",e.isSourceFile(i)?n:i).filter((function(n){if(!e.isThis(n))return!1;var t=e.getThisContainer(n,!1);switch(i.kind){case 209:case 252:return i.symbol===t.symbol;case 166:case 165:return e.isObjectLiteralMethod(i)&&i.symbol===t.symbol;case 222:case 253:case 201:return t.parent&&i.symbol===t.parent.symbol&&(32&e.getSyntacticModifierFlags(t))===o;case 298:return 298===t.kind&&!e.isExternalModule(t)&&!ie(n)}}))})).map((function(e){return r(e)})),c=e.firstDefined(s,(function(n){return e.isParameter(n.node.parent)?n.node:void 0}));return[{definition:{type:3,node:c||n},references:s}]}function se(n,t,a,i){var o=e.getContextualTypeOrAncestorTypeNodeType(n,a),s=e.flatMap(t,(function(t){return i.throwIfCancellationRequested(),e.mapDefined(R(t,n.text),(function(t){if(e.isStringLiteralLike(t)&&t.text===n.text){if(!o)return r(t,2);var i=e.getContextualTypeOrAncestorTypeNodeType(t,a);if(o!==a.getStringType()&&o===i)return r(t,2)}}))}));return[{definition:{type:4,node:n},references:s}]}function ce(e,n,t,r,a,i){var o=[];return le(e,n,t,r,!(r&&a),(function(n,t,r){r&&de(e)!==de(r)&&(r=void 0),o.push(r||t||n)}),(function(){return!i})),o}function le(n,t,r,a,i,o,c){var l=e.getContainingObjectLiteralElement(t);if(l){var u=r.getShorthandAssignmentValueSymbol(t.parent);if(u&&a)return o(u,void 0,void 0,3);var d=r.getContextualType(l.parent),p=d&&e.firstDefined(e.getPropertySymbolsFromContextualType(l,r,d,!0),(function(e){return L(e,4)}));if(p)return p;var f=D(t,r),m=f&&o(f,void 0,void 0,4);if(m)return m;var _=u&&o(u,void 0,void 0,3);if(_)return _}var g=s(t,n,r);if(g){var y=o(g,void 0,void 0,1);if(y)return y}var h=L(n);if(h)return h;if(n.valueDeclaration&&e.isParameterPropertyDeclaration(n.valueDeclaration,n.valueDeclaration.parent)){var v=r.getSymbolsOfParameterPropertyDeclaration(e.cast(n.valueDeclaration,e.isParameter),n.name);return e.Debug.assert(2===v.length&&!!(1&v[0].flags)&&!!(4&v[1].flags)),L(1&n.flags?v[1]:v[0])}var b=e.getDeclarationOfKind(n,271);if(!a||b&&!b.propertyName){var E=b&&r.getExportSpecifierLocalTargetSymbol(b);if(E){var T=o(E,void 0,void 0,1);if(T)return T}}if(!a){var S=void 0;return S=i?e.isObjectBindingElementWithoutPropertyName(t.parent)?e.getPropertySymbolFromBindingElement(r,t.parent):void 0:A(n,r),S&&L(S,4)}e.Debug.assert(a);var x=i;if(x){S=A(n,r);return S&&L(S,4)}function L(n,t){return e.firstDefined(r.getRootSymbols(n),(function(e){return o(n,e,void 0,t)||(e.parent&&96&e.parent.flags&&c(e)?ue(e.parent,e.name,r,(function(r){return o(n,e,r,t)})):void 0)}))}function A(n,t){var r=e.getDeclarationOfKind(n,199);if(r&&e.isObjectBindingElementWithoutPropertyName(r))return e.getPropertySymbolFromBindingElement(t,r)}}function ue(n,t,r,a){var i=new e.Map;return o(n);function o(n){if(96&n.flags&&e.addToSeen(i,e.getSymbolId(n)))return e.firstDefined(n.declarations,(function(n){return e.firstDefined(e.getAllSuperTypeNodes(n),(function(n){var i=r.getTypeAtLocation(n),s=i&&i.symbol&&r.getPropertyOfType(i,t);return i&&s&&(e.firstDefined(r.getRootSymbols(s),a)||o(i.symbol))}))}))}}function de(n){if(!n.valueDeclaration)return!1;var t=e.getEffectiveModifierFlags(n.valueDeclaration);return!!(32&t)}function pe(n,t,r,a){var i=a.checker;return le(t,r,i,!1,2!==a.options.use||!!a.options.providePrefixAndSuffixTextForRename,(function(r,a,i,o){return i&&de(t)!==de(i)&&(i=void 0),n.includes(i||a||r)?{symbol:!a||6&e.getCheckFlags(r)?r:a,kind:o}:void 0}),(function(e){return!(n.parents&&!n.parents.some((function(n){return re(e.parent,n,a.inheritsFromCache,i)})))}))}function fe(n,t){var r=e.getMeaningFromLocation(n),a=t.declarations;if(a){var i=void 0;do{i=r;for(var o=0,s=a;o<s.length;o++){var c=s[o],l=e.getMeaningFromDeclaration(c);l&r&&(r|=l)}}while(r!==i)}return r}function me(n){return 8388608&n.flags?!(e.isInterfaceDeclaration(n)||e.isTypeAliasDeclaration(n)):e.isVariableLike(n)?e.hasInitializer(n):e.isFunctionLikeDeclaration(n)?!!n.body:e.isClassLike(n)||e.isModuleOrEnumDeclaration(n)}function _e(n,t,r){var a=t.getSymbolAtLocation(n),i=t.getShorthandAssignmentValueSymbol(a.valueDeclaration);if(i)for(var o=0,s=i.getDeclarations();o<s.length;o++){var c=s[o];1&e.getMeaningFromDeclaration(c)&&r(c)}}function ge(n,t,r){e.forEachChild(n,(function(e){e.kind===t&&r(e),ge(e,t,r)}))}function ye(n){return e.tryGetClassExtendingExpressionWithTypeArguments(e.climbPastPropertyAccess(n).parent)}function he(n,t,r){var a=e.isRightSideOfPropertyAccess(n)?n.parent:void 0,i=a&&r.getTypeAtLocation(a.expression),o=e.mapDefined(i&&(i.isUnionOrIntersection()?i.types:i.symbol===t.parent?void 0:[i]),(function(e){return e.symbol&&96&e.symbol.flags?e.symbol:void 0}));return 0===o.length?void 0:o}function ve(e){return 2===e.use&&e.providePrefixAndSuffixTextForRename}t.eachExportReference=T,t.isSymbolReferencedInFile=I,t.eachSymbolReferenceInFile=N,t.someSignatureUsage=k,t.getIntersectingMeaningFromDeclarations=fe,t.getReferenceEntriesForShorthandPropertyAssignment=_e}(t=n.Core||(n.Core={}))})(e.FindAllReferences||(e.FindAllReferences={}))}(d||(d={})),function(e){(function(n){function t(n){return(e.isFunctionExpression(n)||e.isClassExpression(n))&&e.isNamedDeclaration(n)}function r(n){return(e.isFunctionExpression(n)||e.isArrowFunction(n)||e.isClassExpression(n))&&e.isVariableDeclaration(n.parent)&&n===n.parent.initializer&&e.isIdentifier(n.parent.name)&&!!(2&e.getCombinedNodeFlags(n.parent))}function a(n){return e.isSourceFile(n)||e.isModuleDeclaration(n)||e.isFunctionDeclaration(n)||e.isFunctionExpression(n)||e.isClassDeclaration(n)||e.isClassExpression(n)||e.isMethodDeclaration(n)||e.isMethodSignature(n)||e.isGetAccessorDeclaration(n)||e.isSetAccessorDeclaration(n)}function i(n){return e.isSourceFile(n)||e.isModuleDeclaration(n)&&e.isIdentifier(n.name)||e.isFunctionDeclaration(n)||e.isClassDeclaration(n)||e.isMethodDeclaration(n)||e.isMethodSignature(n)||e.isGetAccessorDeclaration(n)||e.isSetAccessorDeclaration(n)||t(n)||r(n)}function o(n){return e.isSourceFile(n)?n:e.isNamedDeclaration(n)?n.name:r(n)?n.parent.name:e.Debug.checkDefined(n.modifiers&&e.find(n.modifiers,s))}function s(e){return 87===e.kind}function c(e,n){var t=o(n);return t&&e.getSymbolAtLocation(t)}function l(n,t){if(e.isSourceFile(t))return{text:t.fileName,pos:0,end:0};if((e.isFunctionDeclaration(t)||e.isClassDeclaration(t))&&!e.isNamedDeclaration(t)){var a=t.modifiers&&e.find(t.modifiers,s);if(a)return{text:"default",pos:a.getStart(),end:a.getEnd()}}var i=r(t)?t.parent.name:e.Debug.checkDefined(e.getNameOfDeclaration(t),"Expected call hierarchy item to have a name"),o=e.isIdentifier(i)?e.idText(i):e.isStringOrNumericLiteralLike(i)?i.text:e.isComputedPropertyName(i)&&e.isStringOrNumericLiteralLike(i.expression)?i.expression.text:void 0;if(void 0===o){var c=n.getTypeChecker(),l=c.getSymbolAtLocation(i);l&&(o=c.symbolToString(l,t))}if(void 0===o){var u=e.createPrinter({removeComments:!0,omitTrailingSemicolon:!0});o=e.usingSingleLineStringWriter((function(e){return u.writeNode(4,t,t.getSourceFile(),e)}))}return{text:o,pos:i.getStart(),end:i.getEnd()}}function u(n){var t,a;if(r(n))return e.isModuleBlock(n.parent.parent.parent.parent)&&e.isIdentifier(n.parent.parent.parent.parent.parent.name)?n.parent.parent.parent.parent.parent.name.getText():void 0;switch(n.kind){case 168:case 169:case 166:return 201===n.parent.kind?null===(t=e.getAssignedName(n.parent))||void 0===t?void 0:t.getText():null===(a=e.getNameOfDeclaration(n.parent))||void 0===a?void 0:a.getText();case 252:case 253:case 257:if(e.isModuleBlock(n.parent)&&e.isIdentifier(n.parent.parent.name))return n.parent.parent.name.getText()}}function d(n,t){if(t.body)return t;if(e.isConstructorDeclaration(t))return e.getFirstConstructorWithBody(t.parent);if(e.isFunctionDeclaration(t)||e.isMethodDeclaration(t)){var r=c(n,t);return r&&r.valueDeclaration&&e.isFunctionLikeDeclaration(r.valueDeclaration)&&r.valueDeclaration.body?r.valueDeclaration:void 0}return t}function p(n,t){var r,a=c(n,t);if(a&&a.declarations){var o=e.indicesOf(a.declarations),s=e.map(a.declarations,(function(e){return{file:e.getSourceFile().fileName,pos:e.pos}}));o.sort((function(n,t){return e.compareStringsCaseSensitive(s[n].file,s[t].file)||s[n].pos-s[t].pos}));for(var l=e.map(o,(function(e){return a.declarations[e]})),u=void 0,d=0,p=l;d<p.length;d++){var f=p[d];i(f)&&(u&&u.parent===f.parent&&u.end===f.pos||(r=e.append(r,f)),u=f)}}return r}function f(n,t){var r,a,i;return e.isFunctionLikeDeclaration(t)?null!==(a=null!==(r=d(n,t))&&void 0!==r?r:p(n,t))&&void 0!==a?a:t:null!==(i=p(n,t))&&void 0!==i?i:t}function m(n,t){var o=n.getTypeChecker(),s=!1;while(1){if(i(t))return f(o,t);if(a(t)){var c=e.findAncestor(t,i);return c&&f(o,c)}if(e.isDeclarationName(t)){if(i(t.parent))return f(o,t.parent);if(a(t.parent)){c=e.findAncestor(t.parent,i);return c&&f(o,c)}return e.isVariableDeclaration(t.parent)&&t.parent.initializer&&r(t.parent.initializer)?t.parent.initializer:void 0}if(e.isConstructorDeclaration(t))return i(t.parent)?t.parent:void 0;if(e.isVariableDeclaration(t)&&t.initializer&&r(t.initializer))return t.initializer;if(!s){var l=o.getSymbolAtLocation(t);if(l&&(2097152&l.flags&&(l=o.getAliasedSymbol(l)),l.valueDeclaration)){s=!0,t=l.valueDeclaration;continue}}return}}function _(n,t){var r=t.getSourceFile(),a=l(n,t),i=u(t),o=e.getNodeKind(t),s=e.getNodeModifiers(t),c=e.createTextSpanFromBounds(e.skipTrivia(r.text,t.getFullStart(),!1,!0),t.getEnd()),d=e.createTextSpanFromBounds(a.pos,a.end);return{file:r.fileName,kind:o,kindModifiers:s,name:a.text,containerName:i,span:c,selectionSpan:d}}function g(e){return void 0!==e}function y(n){if(1===n.kind){var t=n.node;if(e.isCallOrNewExpressionTarget(t,!0,!0)||e.isTaggedTemplateTag(t,!0,!0)||e.isDecoratorTarget(t,!0,!0)||e.isJsxOpeningLikeElementTagName(t,!0,!0)||e.isRightSideOfPropertyAccess(t)||e.isArgumentExpressionOfElementAccess(t)){var r=t.getSourceFile(),a=e.findAncestor(t,i)||r;return{declaration:a,range:e.createTextRangeFromNode(t,r)}}}}function h(n){return e.getNodeId(n.declaration)}function v(e,n){return{from:e,fromSpans:n}}function b(n,t){return v(_(n,t[0].declaration),e.map(t,(function(n){return e.createTextSpanFromRange(n.range)})))}function E(n,t,r){if(e.isSourceFile(t)||e.isModuleDeclaration(t))return[];var a=o(t),i=e.filter(e.FindAllReferences.findReferenceOrRenameEntries(n,r,n.getSourceFiles(),a,0,{use:1},y),g);return i?e.group(i,h,(function(e){return b(n,e)})):[]}function T(n,t){function r(r){var a=e.isTaggedTemplateExpression(r)?r.tag:e.isJsxOpeningLikeElement(r)?r.tagName:e.isAccessExpression(r)?r:r.expression,i=m(n,a);if(i){var o=e.createTextRangeFromNode(a,r.getSourceFile());if(e.isArray(i))for(var s=0,c=i;s<c.length;s++){var l=c[s];t.push({declaration:l,range:o})}else t.push({declaration:i,range:o})}}function a(n){if(n&&!(8388608&n.flags))if(i(n)){if(e.isClassLike(n))for(var t=0,o=n.members;t<o.length;t++){var s=o[t];s.name&&e.isComputedPropertyName(s.name)&&a(s.name.expression)}}else{switch(n.kind){case 78:case 261:case 262:case 268:case 254:case 255:return;case 207:case 225:return void a(n.expression);case 250:case 161:return a(n.name),void a(n.initializer);case 204:return r(n),a(n.expression),void e.forEach(n.arguments,a);case 205:return r(n),a(n.expression),void e.forEach(n.arguments,a);case 206:return r(n),a(n.tag),void a(n.template);case 276:case 275:return r(n),a(n.tagName),void a(n.attributes);case 162:return r(n),void a(n.expression);case 202:case 203:r(n),e.forEachChild(n,a);break}e.isPartOfTypeNode(n)||e.forEachChild(n,a)}}return a}function S(n,t){e.forEach(n.statements,t)}function x(n,t){!e.hasSyntacticModifier(n,2)&&n.body&&e.isModuleBlock(n.body)&&e.forEach(n.body.statements,t)}function L(n,t,r){var a=d(n,t);a&&(e.forEach(a.parameters,r),r(a.body))}function D(n,t){e.forEach(n.decorators,t);var r=e.getClassExtendsHeritageElement(n);r&&t(r.expression);for(var a=0,i=n.members;a<i.length;a++){var o=i[a];e.forEach(o.decorators,t),e.isPropertyDeclaration(o)?t(o.initializer):e.isConstructorDeclaration(o)&&o.body&&(e.forEach(o.parameters,t),t(o.body))}}function A(n,t){var r=[],a=T(n,r);switch(t.kind){case 298:S(t,a);break;case 257:x(t,a);break;case 252:case 209:case 210:case 166:case 168:case 169:L(n.getTypeChecker(),t,a);break;case 253:case 222:D(t,a);break;default:e.Debug.assertNever(t)}return r}function C(e,n){return{to:e,fromSpans:n}}function I(n,t){return C(_(n,t[0].declaration),e.map(t,(function(n){return e.createTextSpanFromRange(n.range)})))}function N(n,t){return 8388608&t.flags||e.isMethodSignature(t)?[]:e.group(A(n,t),h,(function(e){return I(n,e)}))}n.resolveCallHierarchyDeclaration=m,n.createCallHierarchyItem=_,n.getIncomingCalls=E,n.getOutgoingCalls=N})(e.CallHierarchy||(e.CallHierarchy={}))}(d||(d={})),function(e){function n(n,r,o,s,c,l,u){var d=e.hostUsesCaseSensitiveFileNames(s),p=e.createGetCanonicalFileName(d),f=t(r,o,p,u),m=t(o,r,p,u);return e.textChanges.ChangeTracker.with({host:s,formatContext:c,preferences:l},(function(e){a(n,e,f,r,o,s.getCurrentDirectory(),d),i(n,e,f,m,s,p)}))}function t(n,t,a,i){var o=a(n);return function(e){var n=i&&i.tryGetSourcePosition({fileName:e,pos:0}),t=s(n?n.fileName:e);return n?void 0===t?void 0:r(n.fileName,t,e,a):t};function s(n){if(a(n)===o)return t;var r=e.tryRemoveDirectoryPrefix(n,o,a);return void 0===r?void 0:t+"/"+r}}function r(n,t,r,a){var i=e.getRelativePathFromFile(n,t,a);return s(e.getDirectoryPath(r),i)}function a(n,t,r,a,i,o,c){var l=n.getCompilerOptions().configFile;if(l){var u=e.getDirectoryPath(l.fileName),f=e.getTsConfigObjectLiteralExpression(l);f&&p(f,(function(n,r){switch(r){case"files":case"include":case"exclude":var s=m(n);if(!s&&"include"===r&&e.isArrayLiteralExpression(n.initializer)){var d=e.mapDefined(n.initializer.elements,(function(n){return e.isStringLiteral(n)?n.text:void 0})),f=e.getFileMatcherPatterns(u,[],d,c,o);e.getRegexFromPattern(e.Debug.checkDefined(f.includeFilePattern),c).test(a)&&!e.getRegexFromPattern(e.Debug.checkDefined(f.includeFilePattern),c).test(i)&&t.insertNodeAfter(l,e.last(n.initializer.elements),e.factory.createStringLiteral(g(i)))}break;case"compilerOptions":p(n.initializer,(function(n,t){var r=e.getOptionFromName(t);r&&(r.isFilePath||"list"===r.type&&r.element.isFilePath)?m(n):"paths"===t&&p(n.initializer,(function(n){if(e.isArrayLiteralExpression(n.initializer))for(var t=0,r=n.initializer.elements;t<r.length;t++){var a=r[t];_(a)}}))}));break}}))}function m(n){for(var t=e.isArrayLiteralExpression(n.initializer)?n.initializer.elements:[n.initializer],r=!1,a=0,i=t;a<i.length;a++){var o=i[a];r=_(o)||r}return r}function _(n){if(!e.isStringLiteral(n))return!1;var a=s(u,n.text),i=r(a);return void 0!==i&&(t.replaceRangeWithText(l,d(n,l),g(i)),!0)}function g(n){return e.getRelativePathFromDirectory(u,n,!c)}}function i(n,t,r,a,i,o){for(var d=n.getSourceFiles(),p=function(p){var f=r(p.fileName),m=null!==f&&void 0!==f?f:p.fileName,_=e.getDirectoryPath(m),g=a(p.fileName),y=g||p.fileName,h=e.getDirectoryPath(y),v=void 0!==f||void 0!==g;u(p,t,(function(n){if(e.pathIsRelative(n)){var t=s(h,n),a=r(t);return void 0===a?void 0:e.ensurePathIsNonModuleName(e.getRelativePathFromDirectory(_,a,o))}}),(function(t){var a=n.getTypeChecker().getSymbolAtLocation(t);if(!(null===a||void 0===a?void 0:a.declarations)||!a.declarations.some((function(n){return e.isAmbientModule(n)}))){var s=void 0!==g?l(t,e.resolveModuleName(t.text,y,n.getCompilerOptions(),i),r,d):c(a,t,p,n,i,r);return void 0!==s&&(s.updated||v&&e.pathIsRelative(t.text))?e.moduleSpecifiers.updateModuleSpecifier(n.getCompilerOptions(),o(m),s.newFileName,e.createModuleSpecifierResolutionHost(n,i),t.text):void 0}}))},f=0,m=d;f<m.length;f++){var _=m[f];p(_)}}function o(n,t){return e.normalizePath(e.combinePaths(n,t))}function s(n,t){return e.ensurePathIsNonModuleName(o(n,t))}function c(n,t,r,a,i,o){if(n){var s=e.find(n.declarations,e.isSourceFile).fileName,c=o(s);return void 0===c?{newFileName:s,updated:!1}:{newFileName:c,updated:!0}}var u=i.resolveModuleNames?i.getResolvedModuleWithFailedLookupLocationsFromCache&&i.getResolvedModuleWithFailedLookupLocationsFromCache(t.text,r.fileName):a.getResolvedModuleWithFailedLookupLocationsFromCache(t.text,r.fileName);return l(t,u,o,a.getSourceFiles())}function l(n,t,r,a){if(t){if(t.resolvedModule){var i=l(t.resolvedModule.resolvedFileName);if(i)return i}var o=e.forEach(t.failedLookupLocations,s)||e.pathIsRelative(n.text)&&e.forEach(t.failedLookupLocations,c);return o||t.resolvedModule&&{newFileName:t.resolvedModule.resolvedFileName,updated:!1}}function s(n){var t=r(n);return t&&e.find(a,(function(e){return e.fileName===t}))?c(n):void 0}function c(n){return e.endsWith(n,"/package.json")?void 0:l(n)}function l(e){var n=r(e);return n&&{newFileName:n,updated:!0}}}function u(n,t,r,a){for(var i=0,o=n.referencedFiles||e.emptyArray;i<o.length;i++){var s=o[i],c=r(s.fileName);void 0!==c&&c!==n.text.slice(s.pos,s.end)&&t.replaceRangeWithText(n,s,c)}for(var l=0,u=n.imports;l<u.length;l++){var p=u[l];c=a(p);void 0!==c&&c!==p.text&&t.replaceRangeWithText(n,d(p,n),c)}}function d(n,t){return e.createRange(n.getStart(t)+1,n.end-1)}function p(n,t){if(e.isObjectLiteralExpression(n))for(var r=0,a=n.properties;r<a.length;r++){var i=a[r];e.isPropertyAssignment(i)&&e.isStringLiteral(i.name)&&t(i,i.name.text)}}e.getEditsForFileRename=n,e.getPathUpdater=t}(d||(d={})),function(e){(function(n){function t(n,t,o){var c=s(t,o,n),l=c&&[E(c.reference.fileName,c.fileName,c.unverified)]||e.emptyArray;if(null===c||void 0===c?void 0:c.file)return l;var u=e.getTouchingPropertyName(t,o);if(u!==t){var d=u.parent,m=n.getTypeChecker();if(e.isJumpStatementTarget(u)){var h=e.getTargetLabel(u.parent,u.text);return h?[y(m,h,"label",u.text,void 0)]:void 0}var b=f(u,m);if(!b)return e.concatenate(l,p(u,m));var T=S(m,u);if(T&&(!e.isJsxOpeningLikeElement(u.parent)||!x(T))){var L=v(m,T);if(m.getRootSymbols(b).some((function(e){return r(e,T)})))return[L];var D=_(m,b,u,T)||e.emptyArray;return 105===u.kind?i([L],D):i(i([],D),[L])}if(290===u.parent.kind){var A=m.getShorthandAssignmentValueSymbol(b.valueDeclaration),C=(null===A||void 0===A?void 0:A.declarations)?A.declarations.map((function(e){return g(e,m,A,u)})):e.emptyArray;return e.concatenate(C,a(m,u)||e.emptyArray)}if(e.isPropertyName(u)&&e.isBindingElement(d)&&e.isObjectBindingPattern(d.parent)&&u===(d.propertyName||d.name)){var I=e.getNameFromPropertyName(u),N=m.getTypeAtLocation(d.parent);return void 0===I?e.emptyArray:e.flatMap(N.isUnion()?N.types:[N],(function(e){var n=e.getProperty(I);return n&&_(m,n,u)}))}return e.concatenate(l,a(m,u)||_(m,b,u))}}function r(n,t){return n===t.symbol||n===t.symbol.parent||e.isAssignmentExpression(t.parent)||!e.isCallLikeExpression(t.parent)&&n===t.parent.symbol}function a(n,t){var r=e.getContainingObjectLiteralElement(t);if(r){var a=r&&n.getContextualType(r.parent);if(a)return e.flatMap(e.getPropertySymbolsFromContextualType(r,n,a,!1),(function(e){return _(n,e,t)}))}}function s(n,t,r){var a,i,o=b(n.referencedFiles,t);if(o){var s=r.getSourceFileFromReference(n,o);return s&&{reference:o,fileName:s.fileName,file:s,unverified:!1}}var c=b(n.typeReferenceDirectives,t);if(c){var l=r.getResolvedTypeReferenceDirectives().get(c.fileName);s=l&&r.getSourceFile(l.resolvedFileName);return s&&{reference:c,fileName:s.fileName,file:s,unverified:!1}}var u=b(n.libReferenceDirectives,t);if(u){s=r.getLibFileFromReference(u);return s&&{reference:u,fileName:s.fileName,file:s,unverified:!1}}if(null===(a=n.resolvedModules)||void 0===a?void 0:a.size){var d=e.getTokenAtPosition(n,t);if(e.isModuleSpecifierLike(d)&&e.isExternalModuleNameRelative(d.text)&&n.resolvedModules.has(d.text)){var p=null===(i=n.resolvedModules.get(d.text))||void 0===i?void 0:i.resolvedFileName,f=p||e.resolvePath(e.getDirectoryPath(n.fileName),d.text);return{file:r.getSourceFile(f),fileName:f,reference:{pos:d.getStart(),end:d.getEnd(),fileName:d.text},unverified:!p}}}}function c(n,t,r){var a=e.getTouchingPropertyName(t,r);if(a!==t){var i=n.getSymbolAtLocation(a);if(i){var o=n.getTypeOfSymbolAtLocation(i,a),s=u(i,o,n),c=s&&l(s,n,a);return c&&0!==c.length?c:l(o,n,a)}}}function l(n,t,r){return e.flatMap(!n.isUnion()||32&n.flags?[n]:n.types,(function(e){return e.symbol&&_(t,e.symbol,r)}))}function u(n,t,r){if(t.symbol===n||n.valueDeclaration&&t.symbol&&e.isVariableDeclaration(n.valueDeclaration)&&n.valueDeclaration.initializer===t.symbol.valueDeclaration){var a=t.getCallSignatures();if(1===a.length)return r.getReturnTypeOfSignature(e.first(a))}}function d(n,r,a){var i=t(n,r,a);if(i&&0!==i.length){var o=b(r.referencedFiles,a)||b(r.typeReferenceDirectives,a)||b(r.libReferenceDirectives,a);if(o)return{definitions:i,textSpan:e.createTextSpanFromRange(o)};var s=e.getTouchingPropertyName(r,a),c=e.createTextSpan(s.getStart(),s.getWidth());return{definitions:i,textSpan:c}}}function p(n,t){if(e.isPropertyAccessExpression(n.parent)&&n.parent.name===n){var r=t.getTypeAtLocation(n.parent.expression);return e.mapDefined(r.isUnionOrIntersection()?r.types:[r],(function(e){var n=t.getIndexInfoOfType(e,0);return n&&n.declaration&&v(t,n.declaration)}))}}function f(e,n){var t=n.getSymbolAtLocation(e);if((null===t||void 0===t?void 0:t.declarations)&&2097152&t.flags&&m(e,t.declarations[0])){var r=n.getAliasedSymbol(t);if(r.declarations)return r}return t}function m(n,t){if(78!==n.kind)return!1;if(n.parent===t)return!0;switch(t.kind){case 263:case 261:return!0;case 266:return 265===t.parent.kind;case 199:case 250:return e.isInJSFile(t)&&e.isRequireVariableDeclaration(t);default:return!1}}function _(n,t,r,a){var i=e.filter(t.declarations,(function(n){return n!==a&&(!e.isAssignmentDeclaration(n)||n===t.valueDeclaration)}))||void 0;return o()||s()||e.map(i,(function(e){return g(e,n,t,r)}));function o(){if(32&t.flags&&!(19&t.flags)&&(e.isNewExpressionTarget(r)||132===r.kind)){var n=e.find(i,e.isClassLike)||e.Debug.fail("Expected declaration to have at least one class-like declaration");return c(n.members,!0)}}function s(){return e.isCallOrNewExpressionTarget(r)||e.isNameOfFunctionDeclaration(r)?c(i,!1):void 0}function c(a,i){if(a){var o=a.filter(i?e.isConstructorDeclaration:e.isFunctionLike),s=o.filter((function(e){return!!e.body}));return o.length?0!==s.length?s.map((function(e){return g(e,n,t,r)})):[g(e.last(o),n,t,r)]:void 0}}}function g(n,t,r,a){var i=t.symbolToString(r),o=e.SymbolDisplay.getSymbolKind(t,r,a),s=r.parent?t.symbolToString(r.parent,a):"";return y(t,n,o,i,s)}function y(n,t,r,a,i){var s=e.getNameOfDeclaration(t)||t,c=s.getSourceFile(),l=e.createTextSpanFromNode(s,c);return o(o({fileName:c.fileName,textSpan:l,kind:r,name:a,containerKind:void 0,containerName:i},e.FindAllReferences.toContextSpan(l,c,e.FindAllReferences.getContextNode(t))),{isLocal:!h(n,t)})}function h(n,t){if(n.isDeclarationVisible(t))return!0;if(!t.parent)return!1;if(e.hasInitializer(t.parent)&&t.parent.initializer===t)return h(n,t.parent);switch(t.kind){case 164:case 168:case 169:case 166:if(e.hasEffectiveModifier(t,8))return!1;case 167:case 289:case 290:case 201:case 222:case 210:case 209:return h(n,t.parent);default:return!1}}function v(e,n){return g(n,e,n.symbol,n)}function b(n,t){return e.find(n,(function(n){return e.textRangeContainsPositionInclusive(n,t)}))}function E(n,t,r){return{fileName:t,textSpan:e.createTextSpanFromBounds(0,0),kind:"script",name:n,containerName:void 0,containerKind:void 0,unverified:r}}function T(n){var t=e.findAncestor(n,(function(n){return!e.isRightSideOfPropertyAccess(n)})),r=null===t||void 0===t?void 0:t.parent;return r&&e.isCallLikeExpression(r)&&e.getInvokedExpression(r)===t?r:void 0}function S(n,t){var r=T(t),a=r&&n.getResolvedSignature(r);return e.tryCast(a&&a.declaration,(function(n){return e.isFunctionLike(n)&&!e.isFunctionTypeNode(n)}))}function x(e){switch(e.kind){case 167:case 176:case 171:return!0;default:return!1}}n.getDefinitionAtPosition=t,n.getReferenceAtPosition=s,n.getTypeDefinitionAtPosition=c,n.getDefinitionAndBoundSpan=d,n.findReferenceInPosition=b})(e.GoToDefinition||(e.GoToDefinition={}))}(d||(d={})),function(e){(function(n){var t,r,a=["abstract","access","alias","argument","async","augments","author","borrows","callback","class","classdesc","constant","constructor","constructs","copyright","default","deprecated","description","emits","enum","event","example","exports","extends","external","field","file","fileoverview","fires","function","generator","global","hideconstructor","host","ignore","implements","inheritdoc","inner","instance","interface","kind","lends","license","link","listens","member","memberof","method","mixes","module","name","namespace","override","package","param","private","property","protected","public","readonly","requires","returns","see","since","static","summary","template","this","throws","todo","tutorial","type","typedef","var","variation","version","virtual","yields"];function o(n,t){var r=[];return e.forEachUnique(n,(function(n){for(var a=0,i=c(n);a<i.length;a++){var o=i[a].comment;if(void 0!==o){var l=u(o,t);e.contains(r,l,s)||r.push(l)}}})),e.flatten(e.intersperse(r,[e.lineBreakPart()]))}function s(n,t){return e.arraysEqual(n,t,(function(e,n){return e.kind===n.kind&&e.text===n.text}))}function c(n){switch(n.kind){case 330:case 337:return[n];case 328:case 335:return[n,n.parent];default:return e.getJSDocCommentsAndTags(n)}}function l(n,t){var r=[];return e.forEachUnique(n,(function(n){for(var a=0,i=e.getJSDocTags(n);a<i.length;a++){var o=i[a];r.push({name:o.tagName.text,text:d(o,t)})}})),r}function u(n,t){return"string"===typeof n?[e.textPart(n)]:e.flatMap(n,(function(n){return 313===n.kind?[e.textPart(n.text)]:e.buildLinkParts(n,t)}))}function d(n,t){var r=n.comment,a=n.kind,o=p(a);switch(a){case 319:return c(n.class);case 318:return c(n.class);case 334:return l(n.typeParameters.map((function(e){return e.getText()})).join(", "));case 333:return c(n.typeExpression);case 335:case 328:case 337:case 330:case 336:var s=n.name;return s?c(s):void 0===r?void 0:u(r,t);default:return void 0===r?void 0:u(r,t)}function c(e){return l(e.getText())}function l(n){return r?n.match(/^https?$/)?i([e.textPart(n)],u(r,t)):i([o(n),e.spacePart()],u(r,t)):[e.textPart(n)]}}function p(n){switch(n){case 330:return e.parameterNamePart;case 337:return e.propertyNamePart;case 334:return e.typeParameterNamePart;case 335:case 328:return e.typeAliasNamePart;default:return e.textPart}}function f(){return t||(t=e.map(a,(function(n){return{name:n,kind:"keyword",kindModifiers:"",sortText:e.Completions.SortText.LocationPriority}})))}function m(){return r||(r=e.map(a,(function(n){return{name:"@"+n,kind:"keyword",kindModifiers:"",sortText:e.Completions.SortText.LocationPriority}})))}function _(n){return{name:n,kind:"",kindModifiers:"",displayParts:[e.textPart(n)],documentation:e.emptyArray,tags:void 0,codeActions:void 0}}function g(n){if(!e.isIdentifier(n.name))return e.emptyArray;var t=n.name.text,r=n.parent,a=r.parent;return e.isFunctionLike(a)?e.mapDefined(a.parameters,(function(a){if(e.isIdentifier(a.name)){var i=a.name.text;if(!r.tags.some((function(t){return t!==n&&e.isJSDocParameterTag(t)&&e.isIdentifier(t.name)&&t.name.escapedText===i}))&&(void 0===t||e.startsWith(i,t)))return{name:i,kind:"parameter",kindModifiers:"",sortText:e.Completions.SortText.LocationPriority}}})):[]}function y(n){return{name:n,kind:"parameter",kindModifiers:"",displayParts:[e.textPart(n)],documentation:e.emptyArray,tags:void 0,codeActions:void 0}}function h(n,t,r,a){var i=e.getTokenAtPosition(t,r),o=e.findAncestor(i,e.isJSDoc);if(!o||void 0===o.comment&&!e.length(o.tags)){var s=i.getStart(t);if(o||!(s<r)){var c=T(i,a);if(c){var l=c.commentOwner,u=c.parameters,d=c.hasReturn;if(!(l.getStart(t)<r)){var p=v(t,r),f=e.hasJSFileExtension(t.fileName),m=(u?b(u||[],f,p,n):"")+(d?E(p,n):""),_="/**",g=" */";if(m){var y=_+n+p+" * ",h=s===r?n+p:"",S=y+n+m+p+g+h;return{newText:S,caretOffset:y.length}}return{newText:_+g,caretOffset:3}}}}}}function v(n,t){for(var r=n.text,a=e.getLineStartPositionForPosition(t,n),i=a;i<=t&&e.isWhiteSpaceSingleLine(r.charCodeAt(i));i++);return r.slice(a,i)}function b(e,n,t,r){return e.map((function(e,a){var i=e.name,o=e.dotDotDotToken,s=78===i.kind?i.text:"param"+a,c=n?o?"{...any} ":"{any} ":"";return t+" * @param "+c+s+r})).join("")}function E(e,n){return e+" * @returns"+n}function T(n,t){return e.forEachAncestor(n,(function(e){return S(e,t)}))}function S(n,t){switch(n.kind){case 252:case 209:case 166:case 167:case 165:case 210:var r=n;return{commentOwner:n,parameters:r.parameters,hasReturn:x(r,t)};case 289:return S(n.initializer,t);case 253:case 254:case 163:case 256:case 292:case 255:return{commentOwner:n};case 233:var a=n,i=a.declarationList.declarations,o=1===i.length&&i[0].initializer?L(i[0].initializer):void 0;return o?{commentOwner:n,parameters:o.parameters,hasReturn:x(o,t)}:{commentOwner:n};case 298:return"quit";case 257:return 257===n.parent.kind?void 0:{commentOwner:n};case 234:return S(n.expression,t);case 217:var s=n;return 0===e.getAssignmentDeclarationKind(s)?"quit":e.isFunctionLike(s.right)?{commentOwner:n,parameters:s.right.parameters,hasReturn:x(s.right,t)}:{commentOwner:n};case 164:var c=n.initializer;if(c&&(e.isFunctionExpression(c)||e.isArrowFunction(c)))return{commentOwner:n,parameters:c.parameters,hasReturn:x(c,t)}}}function x(n,t){return!!(null===t||void 0===t?void 0:t.generateReturnInDocTemplate)&&(e.isArrowFunction(n)&&e.isExpression(n.body)||e.isFunctionLikeDeclaration(n)&&n.body&&e.isBlock(n.body)&&!!e.forEachReturnStatement(n.body,(function(e){return e})))}function L(n){while(208===n.kind)n=n.expression;switch(n.kind){case 209:case 210:return n;case 222:return e.find(n.members,e.isConstructorDeclaration)}}n.getJsDocCommentsFromDeclarations=o,n.getJsDocTagsFromDeclarations=l,n.getJSDocTagNameCompletions=f,n.getJSDocTagNameCompletionDetails=_,n.getJSDocTagCompletions=m,n.getJSDocTagCompletionDetails=_,n.getJSDocParameterNameCompletions=g,n.getJSDocParameterNameCompletionDetails=y,n.getDocCommentTemplateAtPosition=h})(e.JsDoc||(e.JsDoc={}))}(d||(d={})),function(e){(function(n){function t(n,t,a,i,o,s){var c=e.createPatternMatcher(i);if(!c)return e.emptyArray;for(var d=[],p=function(e){if(a.throwIfCancellationRequested(),s&&e.isDeclarationFile)return"continue";e.getNamedDeclarations().forEach((function(n,a){r(c,a,n,t,e.fileName,d)}))},f=0,m=n;f<m.length;f++){var _=m[f];p(_)}return d.sort(l),(void 0===o?d:d.slice(0,o)).map(u)}function r(e,n,t,r,i,o){var s=e.getMatchForLastSegmentOfPattern(n);if(s)for(var l=0,u=t;l<u.length;l++){var d=u[l];if(a(d,r))if(e.patternContainsDots){var p=e.getFullMatch(c(d),n);p&&o.push({name:n,fileName:i,matchKind:p.kind,isCaseSensitive:p.isCaseSensitive,declaration:d})}else o.push({name:n,fileName:i,matchKind:s.kind,isCaseSensitive:s.isCaseSensitive,declaration:d})}}function a(e,n){switch(e.kind){case 263:case 266:case 261:var t=n.getSymbolAtLocation(e.name),r=n.getAliasedSymbol(t);return t.escapedName!==r.escapedName;default:return!0}}function i(n,t){var r=e.getNameOfDeclaration(n);return!!r&&(s(r,t)||159===r.kind&&o(r.expression,t))}function o(n,t){return s(n,t)||e.isPropertyAccessExpression(n)&&(t.push(n.name.text),!0)&&o(n.expression,t)}function s(n,t){return e.isPropertyNameLiteral(n)&&(t.push(e.getTextOfIdentifierOrLiteral(n)),!0)}function c(n){var t=[],r=e.getNameOfDeclaration(n);if(r&&159===r.kind&&!o(r.expression,t))return e.emptyArray;t.shift();var a=e.getContainerNode(n);while(a){if(!i(a,t))return e.emptyArray;a=e.getContainerNode(a)}return t.reverse()}function l(n,t){return e.compareValues(n.matchKind,t.matchKind)||e.compareStringsCaseSensitiveUI(n.name,t.name)}function u(n){var t=n.declaration,r=e.getContainerNode(t),a=r&&e.getNameOfDeclaration(r);return{name:n.name,kind:e.getNodeKind(t),kindModifiers:e.getNodeModifiers(t),matchKind:e.PatternMatchKind[n.matchKind],isCaseSensitive:n.isCaseSensitive,fileName:n.fileName,textSpan:e.createTextSpanFromNode(t),containerName:a?a.text:"",containerKind:a?e.getNodeKind(r):""}}n.getNavigateToItems=t})(e.NavigateTo||(e.NavigateTo={}))}(d||(d={})),function(e){(function(n){var t,r,a,i,s,c=/\s+/g,l=150,u=[],d=[],p=[];function f(n,t){r=t,a=n;try{return e.map(H(v(n)),z)}finally{_()}}function m(e,n){r=n,a=e;try{return W(v(e))}finally{_()}}function _(){a=void 0,r=void 0,u=[],i=void 0,p=[]}function g(e){return re(e.getText(a))}function y(e){return e.node.kind}function h(e,n){e.children?e.children.push(n):e.children=[n]}function v(n){e.Debug.assert(!u.length);var t={node:n,name:void 0,additionalNodes:void 0,parent:void 0,children:void 0,indent:0};i=t;for(var r=0,a=n.statements;r<a.length;r++){var o=a[r];N(o)}return D(),e.Debug.assert(!i&&!u.length),t}function b(e,n){h(i,E(e,n))}function E(n,t){return{node:n,name:t||(e.isDeclaration(n)||e.isExpression(n)?e.getNameOfDeclaration(n):void 0),additionalNodes:void 0,parent:i,children:void 0,indent:i.indent+1}}function T(n){s||(s=new e.Map),s.set(n,!0)}function S(e){for(var n=0;n<e;n++)D()}function x(n,t){var r=[];while(!e.isPropertyNameLiteral(t)){var a=e.getNameOrArgument(t),i=e.getElementOrPropertyAccessName(t);t=t.expression,"prototype"===i||e.isPrivateIdentifier(a)||r.push(a)}r.push(t);for(var o=r.length-1;o>0;o--){a=r[o];L(n,a)}return[r.length-1,r[0]]}function L(e,n){var t=E(e,n);h(i,t),u.push(i),d.push(s),s=void 0,i=t}function D(){i.children&&(k(i.children,i),U(i.children)),i=u.pop(),s=d.pop()}function A(e,n,t){L(e,t),N(n),D()}function C(n){n.initializer&&te(n.initializer)?(L(n),e.forEachChild(n.initializer,N),D()):A(n,n.initializer)}function I(n){return!e.hasDynamicName(n)||217!==n.kind&&e.isPropertyAccessExpression(n.name.expression)&&e.isIdentifier(n.name.expression.expression)&&"Symbol"===e.idText(n.name.expression.expression)}function N(n){var t;if(r.throwIfCancellationRequested(),n&&!e.isToken(n))switch(n.kind){case 167:var a=n;A(a,a.body);for(var i=0,o=a.parameters;i<o.length;i++){var c=o[i];e.isParameterPropertyDeclaration(c,a)&&b(c)}break;case 166:case 168:case 169:case 165:I(n)&&A(n,n.body);break;case 164:I(n)&&C(n);break;case 163:I(n)&&b(n);break;case 263:var l=n;l.name&&b(l.name);var u=l.namedBindings;if(u)if(264===u.kind)b(u);else for(var d=0,p=u.elements;d<p.length;d++){var f=p[d];b(f)}break;case 290:A(n,n.name);break;case 291:var m=n.expression;e.isIdentifier(m)?b(n,m):b(n);break;case 199:case 289:case 250:var _=n;e.isBindingPattern(_.name)?N(_.name):C(_);break;case 252:var g=n.name;g&&e.isIdentifier(g)&&T(g.text),A(n,n.body);break;case 210:case 209:A(n,n.body);break;case 256:L(n);for(var y=0,h=n.members;y<h.length;y++){var v=h[y];Q(v)||b(v)}D();break;case 253:case 222:case 254:L(n);for(var E=0,k=n.members;E<k.length;E++){v=k[E];N(v)}D();break;case 257:A(n,Y(n).body);break;case 267:var R=n.expression;_=e.isObjectLiteralExpression(R)||e.isCallExpression(R)?R:e.isArrowFunction(R)||e.isFunctionExpression(R)?R.body:void 0;_?(L(n),N(_),D()):b(n);break;case 271:case 261:case 172:case 170:case 171:case 255:b(n);break;case 204:case 217:var O=e.getAssignmentDeclarationKind(n);switch(O){case 1:case 2:return void A(n,n.right);case 6:case 3:var w=n,P=w.left,M=3===O?P.expression:P,F=0,G=void 0;return e.isIdentifier(M.expression)?(T(M.expression.text),G=M.expression):(t=x(w,M.expression),F=t[0],G=t[1]),6===O?e.isObjectLiteralExpression(w.right)&&w.right.properties.length>0&&(L(w,G),e.forEachChild(w.right,N),D()):e.isFunctionExpression(w.right)||e.isArrowFunction(w.right)?A(n,w.right,G):(L(w,G),A(n,w.right,P.name),D()),void S(F);case 7:case 9:var B=n,U=(G=7===O?B.arguments[0]:B.arguments[0].expression,B.arguments[1]),V=x(n,G),j=(F=V[0],V[1]);return L(n,j),L(n,e.setTextRange(e.factory.createIdentifier(U.text),U)),N(n.arguments[2]),D(),D(),void S(F);case 5:w=n,P=w.left;var K=P.expression;if(e.isIdentifier(K)&&"prototype"!==e.getElementOrPropertyAccessName(P)&&s&&s.has(K.text))return void(e.isFunctionExpression(w.right)||e.isArrowFunction(w.right)?A(n,w.right,K):e.isBindableStaticAccessExpression(P)&&(L(w,K),A(w.left,w.right,e.getNameOrArgument(P)),D()));break;case 4:case 0:case 8:break;default:e.Debug.assertNever(O)}default:e.hasJSDocNodes(n)&&e.forEach(n.jsDoc,(function(n){e.forEach(n.tags,(function(n){e.isJSDocTypeAlias(n)&&b(n)}))})),e.forEachChild(n,N)}}function k(n,t){var r=new e.Map;e.filterMutate(n,(function(n,a){var i=n.name||e.getNameOfDeclaration(n.node),o=i&&g(i);if(!o)return!0;var s=r.get(o);if(!s)return r.set(o,n),!0;if(s instanceof Array){for(var c=0,l=s;c<l.length;c++){var u=l[c];if(w(u,n,a,t))return!1}return s.push(n),!0}u=s;return!w(u,n,a,t)&&(r.set(o,[u,n]),!0)}))}n.getNavigationBarItems=f,n.getNavigationTree=m;var R=(t={},t[5]=!0,t[3]=!0,t[7]=!0,t[9]=!0,t[0]=!1,t[1]=!1,t[2]=!1,t[8]=!1,t[6]=!0,t[4]=!1,t);function O(n,t,r,a){function i(n){return e.isFunctionExpression(n)||e.isFunctionDeclaration(n)||e.isVariableDeclaration(n)}var s=e.isBinaryExpression(t.node)||e.isCallExpression(t.node)?e.getAssignmentDeclarationKind(t.node):0,c=e.isBinaryExpression(n.node)||e.isCallExpression(n.node)?e.getAssignmentDeclarationKind(n.node):0;if(R[s]&&R[c]||i(n.node)&&R[s]||i(t.node)&&R[c]||e.isClassDeclaration(n.node)&&M(n.node)&&R[s]||e.isClassDeclaration(t.node)&&R[c]||e.isClassDeclaration(n.node)&&M(n.node)&&i(t.node)||e.isClassDeclaration(t.node)&&i(n.node)&&M(n.node)){var l=n.additionalNodes&&e.lastOrUndefined(n.additionalNodes)||n.node;if(!e.isClassDeclaration(n.node)&&!e.isClassDeclaration(t.node)||i(n.node)||i(t.node)){var u=i(n.node)?n.node:i(t.node)?t.node:void 0;if(void 0!==u){var d=e.setTextRange(e.factory.createConstructorDeclaration(void 0,void 0,[],void 0),u),p=E(d);p.indent=n.indent+1,p.children=n.node===u?n.children:t.children,n.children=n.node===u?e.concatenate([p],t.children||[t]):e.concatenate(n.children||[o({},n)],[p])}else(n.children||t.children)&&(n.children=e.concatenate(n.children||[o({},n)],t.children||[t]),n.children&&(k(n.children,n),U(n.children)));l=n.node=e.setTextRange(e.factory.createClassDeclaration(void 0,void 0,n.name||e.factory.createIdentifier("__class__"),void 0,void 0,[]),n.node)}else n.children=e.concatenate(n.children,t.children),n.children&&k(n.children,n);var f=t.node;return a.children[r-1].node.end===l.end?e.setTextRange(l,{pos:l.pos,end:f.end}):(n.additionalNodes||(n.additionalNodes=[]),n.additionalNodes.push(e.setTextRange(e.factory.createClassDeclaration(void 0,void 0,n.name||e.factory.createIdentifier("__class__"),void 0,void 0,[]),t.node))),!0}return 0!==s}function w(e,n,t,r){return!!O(e,n,t,r)||!!P(e.node,n.node,r)&&(B(e,n),!0)}function P(n,t,r){if(n.kind!==t.kind||n.parent!==t.parent&&(!F(n,r)||!F(t,r)))return!1;switch(n.kind){case 164:case 166:case 168:case 169:return e.hasSyntacticModifier(n,32)===e.hasSyntacticModifier(t,32);case 257:return G(n,t)&&X(n)===X(t);default:return!0}}function M(e){return!!(8&e.flags)}function F(n,t){var r=e.isModuleBlock(n.parent)?n.parent.parent:n.parent;return r===t.node||e.contains(t.additionalNodes,r)}function G(e,n){return e.body.kind===n.body.kind&&(257!==e.body.kind||G(e.body,n.body))}function B(n,t){var r;n.additionalNodes=n.additionalNodes||[],n.additionalNodes.push(t.node),t.additionalNodes&&(r=n.additionalNodes).push.apply(r,t.additionalNodes),n.children=e.concatenate(n.children,t.children),n.children&&(k(n.children,n),U(n.children))}function U(e){e.sort(V)}function V(n,t){return e.compareStringsCaseSensitiveUI(j(n.node),j(t.node))||e.compareValues(y(n),y(t))}function j(n){if(257===n.kind)return J(n);var t=e.getNameOfDeclaration(n);if(t&&e.isPropertyName(t)){var r=e.getPropertyNameForPropertyNameNode(t);return r&&e.unescapeLeadingUnderscores(r)}switch(n.kind){case 209:case 210:case 222:return ee(n);default:return}}function K(n,t){if(257===n.kind)return re(J(n));if(t){var r=e.isIdentifier(t)?t.text:e.isElementAccessExpression(t)?"["+g(t.argumentExpression)+"]":g(t);if(r.length>0)return re(r)}switch(n.kind){case 298:var a=n;return e.isExternalModule(a)?'"'+e.escapeString(e.getBaseFileName(e.removeFileExtension(e.normalizePath(a.fileName))))+'"':"<global>";case 267:return e.isExportAssignment(n)&&n.isExportEquals?"export=":"default";case 210:case 252:case 209:case 253:case 222:return 512&e.getSyntacticModifierFlags(n)?"default":ee(n);case 167:return"constructor";case 171:return"new()";case 170:return"()";case 172:return"[]";default:return"<unknown>"}}function H(e){var n=[];function t(e){if(r(e)&&(n.push(e),e.children))for(var a=0,i=e.children;a<i.length;a++){var o=i[a];t(o)}}return t(e),n;function r(e){if(e.children)return!0;switch(y(e)){case 253:case 222:case 256:case 254:case 257:case 298:case 255:case 335:case 328:return!0;case 210:case 252:case 209:return n(e);default:return!1}function n(e){if(!e.node.body)return!1;switch(y(e.parent)){case 258:case 298:case 166:case 167:return!0;default:return!1}}}}function W(n){return{text:K(n.node,n.name),kind:e.getNodeKind(n.node),kindModifiers:$(n.node),spans:q(n),nameSpan:n.name&&Z(n.name),childItems:e.map(n.children,W)}}function z(n){return{text:K(n.node,n.name),kind:e.getNodeKind(n.node),kindModifiers:$(n.node),spans:q(n),childItems:e.map(n.children,t)||p,indent:n.indent,bolded:!1,grayed:!1};function t(n){return{text:K(n.node,n.name),kind:e.getNodeKind(n.node),kindModifiers:e.getNodeModifiers(n.node),spans:q(n),childItems:p,indent:0,bolded:!1,grayed:!1}}}function q(e){var n=[Z(e.node)];if(e.additionalNodes)for(var t=0,r=e.additionalNodes;t<r.length;t++){var a=r[t];n.push(Z(a))}return n}function J(n){return e.isAmbientModule(n)?e.getTextOfNode(n.name):X(n)}function X(n){var t=[e.getTextOfIdentifierOrLiteral(n.name)];while(n.body&&257===n.body.kind)n=n.body,t.push(e.getTextOfIdentifierOrLiteral(n.name));return t.join(".")}function Y(n){return n.body&&e.isModuleDeclaration(n.body)?Y(n.body):n}function Q(e){return!e.name||159===e.name.kind}function Z(n){return 298===n.kind?e.createTextSpanFromRange(n):e.createTextSpanFromNode(n,a)}function $(n){return n.parent&&250===n.parent.kind&&(n=n.parent),e.getNodeModifiers(n)}function ee(n){var t=n.parent;if(n.name&&e.getFullWidth(n.name)>0)return re(e.declarationNameToString(n.name));if(e.isVariableDeclaration(t))return re(e.declarationNameToString(t.name));if(e.isBinaryExpression(t)&&62===t.operatorToken.kind)return g(t.left).replace(c,"");if(e.isPropertyAssignment(t))return g(t.name);if(512&e.getSyntacticModifierFlags(n))return"default";if(e.isClassLike(n))return"<class>";if(e.isCallExpression(t)){var r=ne(t.expression);if(void 0!==r){if(r=re(r),r.length>l)return r+" callback";var i=re(e.mapDefined(t.arguments,(function(n){return e.isStringLiteralLike(n)?n.getText(a):void 0})).join(", "));return r+"("+i+") callback"}}return"<function>"}function ne(n){if(e.isIdentifier(n))return n.text;if(e.isPropertyAccessExpression(n)){var t=ne(n.expression),r=n.name.text;return void 0===t?r:t+"."+r}}function te(e){switch(e.kind){case 210:case 209:case 222:return!0;default:return!1}}function re(e){return e=e.length>l?e.substring(0,l)+"...":e,e.replace(/\\?(\r?\n|\r|\u2028|\u2029)/g,"")}})(e.NavigationBar||(e.NavigationBar={}))}(d||(d={})),function(e){(function(n){function t(n,t,a,s,l,u){var d=e.textChanges.ChangeTracker.fromContext({host:a,formatContext:t,preferences:l}),f=function(t){return e.stableSort(o(r(t,n,s,u)),(function(e,n){return v(e,n)}))},m=n.statements.filter(e.isImportDeclaration);T(m,f);var _=n.statements.filter(e.isExportDeclaration);T(_,c);for(var g=0,y=n.statements.filter(e.isAmbientModule);g<y.length;g++){var h=y[g];if(h.body){var b=h.body.statements.filter(e.isImportDeclaration);T(b,f);var E=h.body.statements.filter(e.isExportDeclaration);T(E,c)}}return d.getChanges();function T(r,o){if(0!==e.length(r)){e.suppressLeadingTrivia(r[0]);var s=e.group(r,(function(e){return i(e.moduleSpecifier)})),c=e.stableSort(s,(function(e,n){return p(e[0].moduleSpecifier,n[0].moduleSpecifier)})),l=e.flatMap(c,(function(e){return i(e[0].moduleSpecifier)?o(e):e}));if(0===l.length)d.deleteNodes(n,r,{trailingTriviaOption:e.textChanges.TrailingTriviaOption.Include},!0);else{var u={leadingTriviaOption:e.textChanges.LeadingTriviaOption.Exclude,trailingTriviaOption:e.textChanges.TrailingTriviaOption.Include,suffix:e.getNewLineOrDefaultFromHost(a,t.options)};d.replaceNodeWithNodes(n,r[0],l,u);var f=d.nodeHasTrailingComment(n,r[0],u);d.deleteNodes(n,r.slice(1),{trailingTriviaOption:e.textChanges.TrailingTriviaOption.Include},f)}}}}function r(n,t,r,i){if(i)return n;for(var o=r.getTypeChecker(),s=o.getJsxNamespace(t),c=o.getJsxFragmentFactory(t),u=!!(2&t.transformFlags),d=[],p=0,f=n;p<f.length;p++){var m=f[p],_=m.importClause,g=m.moduleSpecifier;if(_){var y=_.name,h=_.namedBindings;if(y&&!b(y)&&(y=void 0),h)if(e.isNamespaceImport(h))b(h.name)||(h=void 0);else{var v=h.elements.filter((function(e){return b(e.name)}));v.length<h.elements.length&&(h=v.length?e.factory.updateNamedImports(h,v):void 0)}y||h?d.push(l(m,y,h)):a(t,g)&&(t.isDeclarationFile?d.push(e.factory.createImportDeclaration(m.decorators,m.modifiers,void 0,g)):d.push(m))}else d.push(m)}return d;function b(n){return u&&(n.text===s||c&&n.text===c)||e.FindAllReferences.Core.isSymbolReferencedInFile(n,o,t)}}function a(n,t){var r=e.isStringLiteral(t)&&t.text;return e.isString(r)&&e.some(n.moduleAugmentations,(function(n){return e.isStringLiteral(n)&&n.text===r}))}function i(n){return void 0!==n&&e.isStringLiteralLike(n)?n.text:void 0}function o(n){var t;if(0===n.length)return n;var r=s(n),a=r.importWithoutClause,i=r.typeOnlyImports,o=r.regularImports,c=[];a&&c.push(a);for(var d=0,p=[o,i];d<p.length;d++){var m=p[d],_=m===i,g=m.defaultImports,y=m.namespaceImports,h=m.namedImports;if(_||1!==g.length||1!==y.length||0!==h.length){for(var v=e.stableSort(y,(function(e,n){return f(e.importClause.namedBindings.name,n.importClause.namedBindings.name)})),b=0,E=v;b<E.length;b++){var T=E[b];c.push(l(T,void 0,T.importClause.namedBindings))}if(0!==g.length||0!==h.length){var S=void 0,x=[];if(1===g.length)S=g[0].importClause.name;else for(var L=0,D=g;L<D.length;L++){N=D[L];x.push(e.factory.createImportSpecifier(e.factory.createIdentifier("default"),N.importClause.name))}x.push.apply(x,e.flatMap(h,(function(e){return e.importClause.namedBindings.elements})));var A=u(x),C=g.length>0?g[0]:h[0],I=0===A.length?S?void 0:e.factory.createNamedImports(e.emptyArray):0===h.length?e.factory.createNamedImports(A):e.factory.updateNamedImports(h[0].importClause.namedBindings,A);_&&S&&I?(c.push(l(C,S,void 0)),c.push(l(null!==(t=h[0])&&void 0!==t?t:C,void 0,I))):c.push(l(C,S,I))}}else{var N=g[0];c.push(l(N,N.importClause.name,y[0].importClause.namedBindings))}}return c}function s(n){for(var t,r={defaultImports:[],namespaceImports:[],namedImports:[]},a={defaultImports:[],namespaceImports:[],namedImports:[]},i=0,o=n;i<o.length;i++){var s=o[i];if(void 0!==s.importClause){var c=s.importClause.isTypeOnly?r:a,l=s.importClause,u=l.name,d=l.namedBindings;u&&c.defaultImports.push(s),d&&(e.isNamespaceImport(d)?c.namespaceImports.push(s):c.namedImports.push(s))}else t=t||s}return{importWithoutClause:t,typeOnlyImports:r,regularImports:a}}function c(n){if(0===n.length)return n;var t=m(n),r=t.exportWithoutClause,a=t.namedExports,i=t.typeOnlyExports,o=[];r&&o.push(r);for(var s=0,c=[a,i];s<c.length;s++){var l=c[s];if(0!==l.length){var d=[];d.push.apply(d,e.flatMap(l,(function(n){return n.exportClause&&e.isNamedExports(n.exportClause)?n.exportClause.elements:e.emptyArray})));var p=u(d),f=l[0];o.push(e.factory.updateExportDeclaration(f,f.decorators,f.modifiers,f.isTypeOnly,f.exportClause&&(e.isNamedExports(f.exportClause)?e.factory.updateNamedExports(f.exportClause,p):e.factory.updateNamespaceExport(f.exportClause,f.exportClause.name)),f.moduleSpecifier))}}return o;function m(e){for(var n,t=[],r=[],a=0,i=e;a<i.length;a++){var o=i[a];void 0===o.exportClause?n=n||o:o.isTypeOnly?r.push(o):t.push(o)}return{exportWithoutClause:n,namedExports:t,typeOnlyExports:r}}}function l(n,t,r){return e.factory.updateImportDeclaration(n,n.decorators,n.modifiers,e.factory.updateImportClause(n.importClause,n.importClause.isTypeOnly,t,r),n.moduleSpecifier)}function u(n){return e.stableSort(n,d)}function d(e,n){return f(e.propertyName||e.name,n.propertyName||n.name)||f(e.name,n.name)}function p(n,t){var r=void 0===n?void 0:i(n),a=void 0===t?void 0:i(t);return e.compareBooleans(void 0===r,void 0===a)||e.compareBooleans(e.isExternalModuleNameRelative(r),e.isExternalModuleNameRelative(a))||e.compareStringsCaseInsensitive(r,a)}function f(n,t){return e.compareStringsCaseInsensitive(n.text,t.text)}function m(n){var t;switch(n.kind){case 261:return null===(t=e.tryCast(n.moduleReference,e.isExternalModuleReference))||void 0===t?void 0:t.expression;case 262:return n.moduleSpecifier;case 233:return n.declarationList.declarations[0].initializer.arguments[0]}}function _(n){return e.arrayIsSorted(n,v)}function g(n){return e.arrayIsSorted(n,d)}function y(n,t){var r=e.binarySearch(n,t,e.identity,v);return r<0?~r:r}function h(n,t){var r=e.binarySearch(n,t,e.identity,d);return r<0?~r:r}function v(e,n){return p(m(e),m(n))||b(e,n)}function b(n,t){return e.compareValues(E(n),E(t))}function E(e){var n;switch(e.kind){case 262:return e.importClause?e.importClause.isTypeOnly?1:264===(null===(n=e.importClause.namedBindings)||void 0===n?void 0:n.kind)?2:e.importClause.name?3:4:0;case 261:return 5;case 233:return 6}}n.organizeImports=t,n.coalesceImports=o,n.coalesceExports=c,n.compareImportOrExportSpecifiers=d,n.compareModuleSpecifiers=p,n.importsAreSorted=_,n.importSpecifiersAreSorted=g,n.getImportDeclarationInsertionIndex=y,n.getImportSpecifierInsertionIndex=h,n.compareImportsOrRequireStatements=v})(e.OrganizeImports||(e.OrganizeImports={}))}(d||(d={})),function(e){(function(n){function t(e,n){var t=[];return r(e,n,t),a(e,t),t.sort((function(e,n){return e.textSpan.start-n.textSpan.start}))}function r(n,t,r){var a=40,o=0,s=i(i([],n.statements),[n.endOfFileToken]),d=s.length;while(o<d){while(o<d&&!e.isAnyImportSyntax(s[o]))m(s[o]),o++;if(o===d)break;var p=o;while(o<d&&e.isAnyImportSyntax(s[o]))c(s[o],n,t,r),o++;var f=o-1;f!==p&&r.push(l(e.findChildOfKind(s[p],99,n).getStart(n),s[f].getEnd(),"imports"))}function m(i){var o;if(0!==a){t.throwIfCancellationRequested(),(e.isDeclaration(i)||e.isVariableStatement(i)||1===i.kind)&&c(i,n,t,r),e.isFunctionLike(i)&&e.isBinaryExpression(i.parent)&&e.isPropertyAccessExpression(i.parent.left)&&c(i.parent.left,n,t,r);var s=u(i,n);s&&r.push(s),a--,e.isCallExpression(i)?(a++,m(i.expression),a--,i.arguments.forEach(m),null===(o=i.typeArguments)||void 0===o||o.forEach(m)):e.isIfStatement(i)&&i.elseStatement&&e.isIfStatement(i.elseStatement)?(m(i.expression),m(i.thenStatement),a++,m(i.elseStatement),a--):i.forEachChild(m),a++}}}function a(n,t){for(var r=[],a=n.getLineStarts(),i=0,o=a;i<o.length;i++){var c=o[i],l=n.getLineEndOfPosition(c),u=n.text.substring(c,l),d=s(u);if(d&&!e.isInComment(n,c))if(d[1]){var p=r.pop();p&&(p.textSpan.length=l-p.textSpan.start,p.hintSpan.length=l-p.textSpan.start,t.push(p))}else{var m=e.createTextSpanFromBounds(n.text.indexOf("//",c),l);r.push(f(m,"region",m,!1,d[2]||"#region"))}}}n.collectElements=t;var o=/^\s*\/\/\s*#(end)?region(?:\s+(.*))?(?:\r)?$/;function s(e){return o.exec(e)}function c(n,t,r,a){var i=e.getLeadingCommentRangesOfNode(n,t);if(i){for(var o=-1,c=-1,u=0,d=t.getFullText(),p=0,f=i;p<f.length;p++){var m=f[p],_=m.kind,g=m.pos,y=m.end;switch(r.throwIfCancellationRequested(),_){case 2:var h=d.slice(g,y);if(s(h)){v(),u=0;break}0===u&&(o=g),c=y,u++;break;case 3:v(),a.push(l(g,y,"comment")),u=0;break;default:e.Debug.assertNever(_)}}v()}function v(){u>1&&a.push(l(o,c,"comment"))}}function l(n,t,r){return f(e.createTextSpanFromBounds(n,t),r)}function u(n,t){switch(n.kind){case 231:if(e.isFunctionLike(n.parent))return d(n.parent,n,t);switch(n.parent.kind){case 236:case 239:case 240:case 238:case 235:case 237:case 244:case 288:return g(n.parent);case 248:var r=n.parent;if(r.tryBlock===n)return g(n.parent);if(r.finallyBlock===n){var a=e.findChildOfKind(r,95,t);if(a)return g(a)}default:return f(e.createTextSpanFromNode(n,t),"code")}case 258:return g(n.parent);case 253:case 222:case 254:case 256:case 259:case 178:case 197:return g(n);case 180:return g(n,!1,!e.isTupleTypeNode(n.parent),22);case 285:case 286:return y(n.statements);case 201:return _(n);case 200:return _(n,22);case 274:return s(n);case 278:return c(n);case 275:case 276:return u(n.attributes);case 219:case 14:return m(n);case 198:return g(n,!1,!e.isBindingElement(n.parent),22);case 210:return o(n);case 204:return i(n)}function i(n){if(n.arguments.length){var r=e.findChildOfKind(n,20,t),a=e.findChildOfKind(n,21,t);if(r&&a&&!e.positionsAreOnSameLine(r.pos,a.pos,t))return p(r,a,n,t,!1,!0)}}function o(n){if(!e.isBlock(n.body)&&!e.positionsAreOnSameLine(n.body.getFullStart(),n.body.getEnd(),t)){var r=e.createTextSpanFromBounds(n.body.getFullStart(),n.body.getEnd());return f(r,"code",e.createTextSpanFromNode(n))}}function s(n){var r=e.createTextSpanFromBounds(n.openingElement.getStart(t),n.closingElement.getEnd()),a=n.openingElement.tagName.getText(t),i="<"+a+">...</"+a+">";return f(r,"code",r,!1,i)}function c(n){var r=e.createTextSpanFromBounds(n.openingFragment.getStart(t),n.closingFragment.getEnd()),a="<>...</>";return f(r,"code",r,!1,a)}function u(e){if(0!==e.properties.length)return l(e.getStart(t),e.getEnd(),"code")}function m(e){if(14!==e.kind||0!==e.text.length)return l(e.getStart(t),e.getEnd(),"code")}function _(n,t){return void 0===t&&(t=18),g(n,!1,!e.isArrayLiteralExpression(n.parent)&&!e.isCallExpression(n.parent),t)}function g(r,a,i,o,s){void 0===a&&(a=!1),void 0===i&&(i=!0),void 0===o&&(o=18),void 0===s&&(s=18===o?19:23);var c=e.findChildOfKind(n,o,t),l=e.findChildOfKind(n,s,t);return c&&l&&p(c,l,r,t,a,i)}function y(n){return n.length?f(e.createTextSpanFromRange(n),"code"):void 0}}function d(n,t,r){var a=m(n,t,r),i=e.findChildOfKind(t,19,r);return a&&i&&p(a,i,n,r,210!==n.kind)}function p(n,t,r,a,i,o){void 0===i&&(i=!1),void 0===o&&(o=!0);var s=e.createTextSpanFromBounds(o?n.getFullStart():n.getStart(a),t.getEnd());return f(s,"code",e.createTextSpanFromNode(r,a),i)}function f(e,n,t,r,a){return void 0===t&&(t=e),void 0===r&&(r=!1),void 0===a&&(a="..."),{textSpan:e,kind:n,hintSpan:t,bannerText:a,autoCollapse:r}}function m(n,t,r){if(e.isNodeArrayMultiLine(n.parameters,r)){var a=e.findChildOfKind(n,20,r);if(a)return a}return e.findChildOfKind(t,18,r)}})(e.OutliningElementsCollector||(e.OutliningElementsCollector={}))}(d||(d={})),function(e){var n;function t(e,n){return{kind:e,isCaseSensitive:n}}function r(n){var t=new e.Map,r=n.trim().split(".").map((function(e){return f(e.trim())}));if(!r.some((function(e){return!e.subWordTextChunks.length})))return{getFullMatch:function(e,n){return a(e,n,r,t)},getMatchForLastSegmentOfPattern:function(n){return s(n,e.last(r),t)},patternContainsDots:r.length>1}}function a(n,t,r,a){var i=s(t,e.last(r),a);if(i&&!(r.length-1>n.length)){for(var o,l=r.length-2,u=n.length-1;l>=0;l-=1,u-=1)o=c(o,s(n[u],r[l],a));return o}}function i(e,n){var t=n.get(e);return t||n.set(e,t=S(e)),t}function o(r,a,o){var s=g(r,a.textLowerCase);if(0===s)return t(a.text.length===r.length?n.exact:n.prefix,e.startsWith(r,a.text));if(a.isLowerCase){if(-1===s)return;for(var c=i(r,o),l=0,d=c;l<d.length;l++){var f=d[l];if(u(r,f,a.text,!0))return t(n.substring,u(r,f,a.text,!1))}if(a.text.length<r.length&&m(r.charCodeAt(s)))return t(n.substring,!1)}else{if(r.indexOf(a.text)>0)return t(n.substring,!0);if(a.characterSpans.length>0){var _=i(r,o),y=!!p(r,_,a,!1)||!p(r,_,a,!0)&&void 0;if(void 0!==y)return t(n.camelCase,y)}}}function s(e,n,t){if(N(n.totalTextChunk.text,(function(e){return 32!==e&&42!==e}))){var r=o(e,n.totalTextChunk,t);if(r)return r}for(var a,i=n.subWordTextChunks,s=0,l=i;s<l.length;s++){var u=l[s];a=c(a,o(e,u,t))}return a}function c(n,t){return e.min(n,t,l)}function l(n,t){return void 0===n?1:void 0===t?-1:e.compareValues(n.kind,t.kind)||e.compareBooleans(!n.isCaseSensitive,!t.isCaseSensitive)}function u(e,n,t,r,a){return void 0===a&&(a={start:0,length:t.length}),a.length<=n.length&&I(0,a.length,(function(i){return d(t.charCodeAt(a.start+i),e.charCodeAt(n.start+i),r)}))}function d(e,n,t){return t?y(e)===y(n):e===n}function p(n,t,r,a){var i,o,s=r.characterSpans,c=0,l=0;while(1){if(l===s.length)return!0;if(c===t.length)return!1;for(var d=t[c],p=!1;l<s.length;l++){var f=s[l];if(p&&(!m(r.text.charCodeAt(s[l-1].start))||!m(r.text.charCodeAt(s[l].start))))break;if(!u(n,d,r.text,a,f))break;p=!0,i=void 0===i?c:i,o=void 0===o||o,d=e.createTextSpan(d.start+f.length,d.length-f.length)}p||void 0===o||(o=!1),c++}}function f(e){return{totalTextChunk:E(e),subWordTextChunks:b(e)}}function m(n){if(n>=65&&n<=90)return!0;if(n<127||!e.isUnicodeIdentifierStart(n,99))return!1;var t=String.fromCharCode(n);return t===t.toUpperCase()}function _(n){if(n>=97&&n<=122)return!0;if(n<127||!e.isUnicodeIdentifierStart(n,99))return!1;var t=String.fromCharCode(n);return t===t.toLowerCase()}function g(e,n){for(var t=e.length-n.length,r=function(t){if(N(n,(function(n,r){return y(e.charCodeAt(r+t))===n})))return{value:t}},a=0;a<=t;a++){var i=r(a);if("object"===typeof i)return i.value}return-1}function y(e){return e>=65&&e<=90?e-65+97:e<127?e:String.fromCharCode(e).toLowerCase().charCodeAt(0)}function h(e){return e>=48&&e<=57}function v(e){return m(e)||_(e)||h(e)||95===e||36===e}function b(e){for(var n=[],t=0,r=0,a=0;a<e.length;a++){var i=e.charCodeAt(a);v(i)?(0===r&&(t=a),r++):r>0&&(n.push(E(e.substr(t,r))),r=0)}return r>0&&n.push(E(e.substr(t,r))),n}function E(e){var n=e.toLowerCase();return{text:e,textLowerCase:n,isLowerCase:e===n,characterSpans:T(e)}}function T(e){return x(e,!1)}function S(e){return x(e,!0)}function x(n,t){for(var r=[],a=0,i=1;i<n.length;i++){var o=h(n.charCodeAt(i-1)),s=h(n.charCodeAt(i)),c=C(n,t,i),l=t&&A(n,i,a);(L(n.charCodeAt(i-1))||L(n.charCodeAt(i))||o!==s||c||l)&&(D(n,a,i)||r.push(e.createTextSpan(a,i-a)),a=i)}return D(n,a,n.length)||r.push(e.createTextSpan(a,n.length-a)),r}function L(e){switch(e){case 33:case 34:case 35:case 37:case 38:case 39:case 40:case 41:case 42:case 44:case 45:case 46:case 47:case 58:case 59:case 63:case 64:case 91:case 92:case 93:case 95:case 123:case 125:return!0}return!1}function D(e,n,t){return N(e,(function(e){return L(e)&&95!==e}),n,t)}function A(e,n,t){return n!==t&&n+1<e.length&&m(e.charCodeAt(n))&&_(e.charCodeAt(n+1))&&N(e,m,t,n)}function C(e,n,t){var r=m(e.charCodeAt(t-1)),a=m(e.charCodeAt(t));return a&&(!n||!r)}function I(e,n,t){for(var r=e;r<n;r++)if(!t(r))return!1;return!0}function N(e,n,t,r){return void 0===t&&(t=0),void 0===r&&(r=e.length),I(t,r,(function(t){return n(e.charCodeAt(t),t)}))}(function(e){e[e["exact"]=0]="exact",e[e["prefix"]=1]="prefix",e[e["substring"]=2]="substring",e[e["camelCase"]=3]="camelCase"})(n=e.PatternMatchKind||(e.PatternMatchKind={})),e.createPatternMatcher=r,e.breakIntoCharacterSpans=T,e.breakIntoWordSpans=S}(d||(d={})),function(e){function n(n,t,r){void 0===t&&(t=!0),void 0===r&&(r=!1);var a,i,o,s={languageVersion:1,pragmas:void 0,checkJsDirective:void 0,referencedFiles:[],typeReferenceDirectives:[],libReferenceDirectives:[],amdDependencies:[],hasNoDefaultLib:void 0,moduleName:void 0},c=[],l=0,u=!1;function d(){return i=o,o=e.scanner.scan(),18===o?l++:19===o&&l--,o}function p(){var n=e.scanner.getTokenValue(),t=e.scanner.getTokenPos();return{fileName:n,pos:t,end:t+n.length}}function f(){a||(a=[]),a.push({ref:p(),depth:l})}function m(){c.push(p()),_()}function _(){0===l&&(u=!0)}function g(){var n=e.scanner.getToken();return 133===n&&(n=d(),139===n&&(n=d(),10===n&&f()),!0)}function y(){if(24===i)return!1;var n=e.scanner.getToken();if(99===n){if(n=d(),20===n){if(n=d(),10===n||14===n)return m(),!0}else{if(10===n)return m(),!0;if(149===n){var t=e.scanner.lookAhead((function(){var n=e.scanner.scan();return 153!==n&&(41===n||18===n||78===n||e.isKeyword(n))}));t&&(n=d())}if(78===n||e.isKeyword(n))if(n=d(),153===n){if(n=d(),10===n)return m(),!0}else if(62===n){if(v(!0))return!0}else{if(27!==n)return!0;n=d()}if(18===n){n=d();while(19!==n&&1!==n)n=d();19===n&&(n=d(),153===n&&(n=d(),10===n&&m()))}else 41===n&&(n=d(),126===n&&(n=d(),(78===n||e.isKeyword(n))&&(n=d(),153===n&&(n=d(),10===n&&m()))))}return!0}return!1}function h(){var n=e.scanner.getToken();if(92===n){if(_(),n=d(),149===n){var t=e.scanner.lookAhead((function(){var n=e.scanner.scan();return 41===n||18===n}));t&&(n=d())}if(18===n){n=d();while(19!==n&&1!==n)n=d();19===n&&(n=d(),153===n&&(n=d(),10===n&&m()))}else if(41===n)n=d(),153===n&&(n=d(),10===n&&m());else if(99===n){if(n=d(),149===n){t=e.scanner.lookAhead((function(){var n=e.scanner.scan();return 78===n||e.isKeyword(n)}));t&&(n=d())}if((78===n||e.isKeyword(n))&&(n=d(),62===n&&v(!0)))return!0}return!0}return!1}function v(n,t){void 0===t&&(t=!1);var r=n?d():e.scanner.getToken();return 143===r&&(r=d(),20===r&&(r=d(),(10===r||t&&14===r)&&m()),!0)}function b(){var n=e.scanner.getToken();if(78===n&&"define"===e.scanner.getTokenValue()){if(n=d(),20!==n)return!0;if(n=d(),10===n||14===n){if(n=d(),27!==n)return!0;n=d()}if(22!==n)return!0;n=d();while(23!==n&&1!==n)10!==n&&14!==n||m(),n=d();return!0}return!1}function E(){e.scanner.setText(n),d();while(1){if(1===e.scanner.getToken())break;g()||y()||h()||r&&(v(!1,!0)||b())||d()}e.scanner.setText(void 0)}if(t&&E(),e.processCommentPragmas(s,n),e.processPragmasIntoFields(s,e.noop),u){if(a)for(var T=0,S=a;T<S.length;T++){var x=S[T];c.push(x.ref)}return{referencedFiles:s.referencedFiles,typeReferenceDirectives:s.typeReferenceDirectives,libReferenceDirectives:s.libReferenceDirectives,importedFiles:c,isLibFile:!!s.hasNoDefaultLib,ambientExternalModules:void 0}}var L=void 0;if(a)for(var D=0,A=a;D<A.length;D++){x=A[D];0===x.depth?(L||(L=[]),L.push(x.ref.fileName)):c.push(x.ref)}return{referencedFiles:s.referencedFiles,typeReferenceDirectives:s.typeReferenceDirectives,libReferenceDirectives:s.libReferenceDirectives,importedFiles:c,isLibFile:!!s.hasNoDefaultLib,ambientExternalModules:L}}e.preProcessFile=n}(d||(d={})),function(e){(function(n){function t(n,t,a,i){var o=e.getAdjustedRenameLocation(e.getTouchingPropertyName(t,a));if(l(o)){var c=r(o,n.getTypeChecker(),t,n,i);if(c)return c}return s(e.Diagnostics.You_cannot_rename_this_element)}function r(n,t,r,c,l){var u=t.getSymbolAtLocation(n);if(u){var d=u.declarations;if(d&&0!==d.length){if(d.some((function(e){return a(c,e)})))return s(e.Diagnostics.You_cannot_rename_elements_that_are_defined_in_the_standard_TypeScript_library);if(!(e.isIdentifier(n)&&87===n.originalKeywordKind&&u.parent&&1536&u.parent.flags)){if(e.isStringLiteralLike(n)&&e.tryGetImportFromModuleSpecifier(n))return l&&l.allowRenameOfImportPath?i(n,r,u):void 0;var p=e.SymbolDisplay.getSymbolKind(t,u,n),f=e.isImportOrExportSpecifierName(n)||e.isStringOrNumericLiteralLike(n)&&159===n.parent.kind?e.stripQuotes(e.getTextOfIdentifierOrLiteral(n)):void 0,m=f||t.symbolToString(u),_=f||t.getFullyQualifiedName(u);return o(m,_,p,e.SymbolDisplay.getSymbolModifiers(t,u),n,r)}}}else if(e.isStringLiteralLike(n)){var g=e.getContextualTypeOrAncestorTypeNodeType(n,t);if(g&&(128&g.flags||1048576&g.flags&&e.every(g.types,(function(e){return!!(128&e.flags)}))))return o(n.text,n.text,"string","",n,r)}else if(e.isLabelName(n)){var y=e.getTextOfNode(n);return o(y,y,"label","",n,r)}}function a(n,t){var r=t.getSourceFile();return n.isSourceFileDefaultLibrary(r)&&e.fileExtensionIs(r.fileName,".d.ts")}function i(n,t,r){if(!e.isExternalModuleNameRelative(n.text))return s(e.Diagnostics.You_cannot_rename_a_module_via_a_global_import);var a=r.declarations&&e.find(r.declarations,e.isSourceFile);if(a){var i=e.endsWith(n.text,"/index")||e.endsWith(n.text,"/index.js")?void 0:e.tryRemoveSuffix(e.removeFileExtension(a.fileName),"/index"),o=void 0===i?a.fileName:i,c=void 0===i?"module":"directory",l=n.text.lastIndexOf("/")+1,u=e.createTextSpan(n.getStart(t)+1+l,n.text.length-l);return{canRename:!0,fileToRename:o,kind:c,displayName:o,fullDisplayName:o,kindModifiers:"",triggerSpan:u}}}function o(e,n,t,r,a,i){return{canRename:!0,fileToRename:void 0,kind:t,displayName:e,fullDisplayName:n,kindModifiers:r,triggerSpan:c(a,i)}}function s(n){return{canRename:!1,localizedErrorMessage:e.getLocaleSpecificMessage(n)}}function c(n,t){var r=n.getStart(t),a=n.getWidth(t);return e.isStringLiteralLike(n)&&(r+=1,a-=2),e.createTextSpan(r,a)}function l(n){switch(n.kind){case 78:case 79:case 10:case 14:case 107:return!0;case 8:return e.isLiteralNameOfPropertyDeclarationOrIndexAccess(n);default:return!1}}n.getRenameInfo=t})(e.Rename||(e.Rename={}))}(d||(d={})),function(e){(function(n){function t(n,t){var a,s={textSpan:e.createTextSpanFromBounds(t.getFullStart(),t.getEnd())},c=t;e:while(1){var l=i(c);if(!l.length)break;for(var f=0;f<l.length;f++){var m=l[f-1],_=l[f],g=l[f+1];if(e.getTokenPosOfNode(_,t,!0)>n)break e;var y=e.singleOrUndefined(e.getTrailingCommentRanges(t.text,_.end));if(y&&2===y.kind&&x(y.pos,y.end),r(t,n,_)){if(e.isBlock(_)||e.isTemplateSpan(_)||e.isTemplateHead(_)||e.isTemplateTail(_)||m&&e.isTemplateHead(m)||e.isVariableDeclarationList(_)&&e.isVariableStatement(c)||e.isSyntaxList(_)&&e.isVariableDeclarationList(c)||e.isVariableDeclaration(_)&&e.isSyntaxList(c)&&1===l.length||e.isJSDocTypeExpression(_)||e.isJSDocSignature(_)||e.isJSDocTypeLiteral(_)){c=_;break}if(e.isTemplateSpan(c)&&g&&e.isTemplateMiddleOrTemplateTail(g)){var h=_.getFullStart()-"${".length,v=g.getStart()+"}".length;S(h,v)}var b=e.isSyntaxList(_)&&u(m)&&d(g)&&!e.positionsAreOnSameLine(m.getStart(),g.getStart(),t),E=b?m.getEnd():_.getStart(),T=b?g.getStart():p(t,_);e.hasJSDocNodes(_)&&(null===(a=_.jsDoc)||void 0===a?void 0:a.length)&&S(e.first(_.jsDoc).getStart(),T),S(E,T),(e.isStringLiteral(_)||e.isTemplateLiteral(_))&&S(E+1,T-1),c=_;break}if(f===l.length-1)break e}}return s;function S(t,r){if(t!==r){var a=e.createTextSpanFromBounds(t,r);(!s||!e.textSpansEqual(a,s.textSpan)&&e.textSpanIntersectsWithPosition(a,n))&&(s=o({textSpan:a},s&&{parent:s}))}}function x(e,n){S(e,n);var r=e;while(47===t.text.charCodeAt(r))r++;S(r,n)}}function r(n,t,r){if(e.Debug.assert(r.pos<=t),t<r.end)return!0;var a=r.getEnd();return a===t&&e.getTouchingPropertyName(n,t).pos<r.end}n.getSmartSelectionRange=t;var a=e.or(e.isImportDeclaration,e.isImportEqualsDeclaration);function i(n){if(e.isSourceFile(n))return s(n.getChildAt(0).getChildren(),a);if(e.isMappedTypeNode(n)){var t=n.getChildren(),r=t[0],i=t.slice(1),o=e.Debug.checkDefined(i.pop());e.Debug.assertEqual(r.kind,18),e.Debug.assertEqual(o.kind,19);var u=s(i,(function(e){return e===n.readonlyToken||142===e.kind||e===n.questionToken||57===e.kind})),d=s(u,(function(e){var n=e.kind;return 22===n||160===n||23===n}));return[r,l(c(d,(function(e){var n=e.kind;return 58===n}))),o]}if(e.isPropertySignature(n)){i=s(n.getChildren(),(function(t){return t===n.name||e.contains(n.modifiers,t)}));return c(i,(function(e){var n=e.kind;return 58===n}))}if(e.isParameter(n)){var p=s(n.getChildren(),(function(e){return e===n.dotDotDotToken||e===n.name})),f=s(p,(function(e){return e===p[0]||e===n.questionToken}));return c(f,(function(e){var n=e.kind;return 62===n}))}return e.isBindingElement(n)?c(n.getChildren(),(function(e){var n=e.kind;return 62===n})):n.getChildren()}function s(e,n){for(var t,r=[],a=0,i=e;a<i.length;a++){var o=i[a];n(o)?(t=t||[],t.push(o)):(t&&(r.push(l(t)),t=void 0),r.push(o))}return t&&r.push(l(t)),r}function c(n,t,r){if(void 0===r&&(r=!0),n.length<2)return n;var a=e.findIndex(n,t);if(-1===a)return n;var i=n.slice(0,a),o=n[a],s=e.last(n),c=r&&26===s.kind,u=n.slice(a+1,c?n.length-1:void 0),d=e.compact([i.length?l(i):void 0,o,u.length?l(u):void 0]);return c?d.concat(s):d}function l(n){return e.Debug.assertGreaterThanOrEqual(n.length,1),e.setTextRangePosEnd(e.parseNodeFactory.createSyntaxList(n),n[0].pos,e.last(n).end)}function u(e){var n=e&&e.kind;return 18===n||22===n||20===n||276===n}function d(e){var n=e&&e.kind;return 19===n||23===n||21===n||277===n}function p(e,n){switch(n.kind){case 330:case 328:case 337:case 335:case 332:return e.getLineEndOfPosition(n.getStart());default:return n.getEnd()}}})(e.SmartSelectionRange||(e.SmartSelectionRange={}))}(d||(d={})),function(e){(function(n){var t,r;function a(n,t,r,a,i){var s=n.getTypeChecker(),l=e.findTokenOnLeftOfPosition(t,r);if(l){var u=!!a&&"characterTyped"===a.kind;if(!u||!e.isInString(t,r,l)&&!e.isInComment(t,r)){var d=!!a&&"invoked"===a.kind,p=D(l,r,t,s,d);if(p){i.throwIfCancellationRequested();var f=o(p,s,t,l,u);return i.throwIfCancellationRequested(),f?s.runWithCancellationToken(i,(function(e){return 0===f.kind?k(f.candidates,f.resolvedSignature,p,t,e):R(f.symbol,p,t,e)})):e.isSourceFileJS(t)?c(p,n,i):void 0}}}}function o(n,t,r,a,i){var o=n.invocation,c=n.argumentCount;switch(o.kind){case 0:if(i&&!s(a,o.node,r))return;var u=[],d=t.getResolvedSignatureForSignatureHelp(o.node,u,c);return 0===u.length?void 0:{kind:0,candidates:u,resolvedSignature:d};case 1:var p=o.called;if(i&&!l(a,r,e.isIdentifier(p)?p.parent:p))return;u=e.getPossibleGenericSignatures(p,c,t);if(0!==u.length)return{kind:0,candidates:u,resolvedSignature:e.first(u)};var f=t.getSymbolAtLocation(p);return f&&{kind:1,symbol:f};case 2:return{kind:0,candidates:[o.signature],resolvedSignature:o.signature};default:return e.Debug.assertNever(o)}}function s(n,t,r){if(!e.isCallOrNewExpression(t))return!1;var a=t.getChildren(r);switch(n.kind){case 20:return e.contains(a,n);case 27:var i=e.findContainingList(n);return!!i&&e.contains(a,i);case 29:return l(n,r,t.expression);default:return!1}}function c(n,t,r){if(2!==n.invocation.kind){var a=C(n.invocation),i=e.isPropertyAccessExpression(a)?a.name.text:void 0,o=t.getTypeChecker();return void 0===i?void 0:e.firstDefined(t.getSourceFiles(),(function(t){return e.firstDefined(t.getNamedDeclarations().get(i),(function(e){var a=e.symbol&&o.getTypeOfSymbolAtLocation(e.symbol,e),i=a&&a.getCallSignatures();if(i&&i.length)return o.runWithCancellationToken(r,(function(e){return k(i,i[0],n,t,e,!0)}))}))}))}}function l(n,t,r){var a=n.getFullStart(),i=n.parent;while(i){var o=e.findPrecedingToken(a,t,i,!0);if(o)return e.rangeContainsRange(r,o);i=i.parent}return e.Debug.fail("Could not find preceding token")}function u(e,n,t){var r=f(e,n,t);return!r||r.isTypeParameterList||0!==r.invocation.kind?void 0:{invocation:r.invocation.node,argumentCount:r.argumentCount,argumentIndex:r.argumentIndex}}function d(n,t){var r=p(n,t);if(r){var a=r.list,i=r.argumentIndex,o=E(a);0!==i&&e.Debug.assertLessThan(i,o);var s=x(a,t);return{list:a,argumentIndex:i,argumentCount:o,argumentsSpan:s}}}function p(n,t){if(29===n.kind||20===n.kind)return{list:A(n.parent,n,t),argumentIndex:0};var r=e.findContainingList(n);return r&&{list:r,argumentIndex:b(r,n)}}function f(n,t,r){var a=n.parent;if(e.isCallOrNewExpression(a)){var i=a,o=d(n,r);if(!o)return;var s=o.list,c=o.argumentIndex,l=o.argumentCount,u=o.argumentsSpan,p=!!a.typeArguments&&a.typeArguments.pos===s.pos;return{isTypeParameterList:p,invocation:{kind:0,node:i},argumentsSpan:u,argumentIndex:c,argumentCount:l}}if(e.isNoSubstitutionTemplateLiteral(n)&&e.isTaggedTemplateExpression(a))return e.isInsideTemplateLiteral(n,t,r)?S(a,0,r):void 0;if(e.isTemplateHead(n)&&206===a.parent.kind){var f=a,m=f.parent;e.Debug.assert(219===f.kind);c=e.isInsideTemplateLiteral(n,t,r)?0:1;return S(m,c,r)}if(e.isTemplateSpan(a)&&e.isTaggedTemplateExpression(a.parent.parent)){var _=a;m=a.parent.parent;if(e.isTemplateTail(n)&&!e.isInsideTemplateLiteral(n,t,r))return;var g=_.parent.templateSpans.indexOf(_);c=T(g,n,t,r);return S(m,c,r)}if(e.isJsxOpeningLikeElement(a)){var y=a.attributes.pos,h=e.skipTrivia(r.text,a.attributes.end,!1);return{isTypeParameterList:!1,invocation:{kind:0,node:a},argumentsSpan:e.createTextSpan(y,h-y),argumentIndex:0,argumentCount:1}}var v=e.getPossibleTypeArgumentsInfo(n,r);if(v){var b=v.called,E=v.nTypeArguments;i={kind:1,called:b},u=e.createTextSpanFromBounds(b.getStart(r),n.end);return{isTypeParameterList:!0,invocation:i,argumentsSpan:u,argumentIndex:E,argumentCount:E+1}}}function m(e,n,t,r){return y(e,n,t,r)||f(e,n,t)}function _(n){return e.isBinaryExpression(n.parent)?_(n.parent):n}function g(n){return e.isBinaryExpression(n.left)?g(n.left)+1:2}function y(n,t,r,a){var i=h(n,r,a);if(i){var o=i.contextualType,s=i.argumentIndex,c=i.argumentCount,l=i.argumentsSpan,u=o.getNonNullableType(),d=u.getCallSignatures();if(1===d.length){var p={kind:2,signature:e.first(d),node:n,symbol:v(u.symbol)};return{isTypeParameterList:!1,invocation:p,argumentsSpan:l,argumentIndex:s,argumentCount:c}}}}function h(n,t,r){if(20===n.kind||27===n.kind){var a=n.parent;switch(a.kind){case 208:case 166:case 209:case 210:var i=d(n,t);if(!i)return;var o=i.argumentIndex,s=i.argumentCount,c=i.argumentsSpan,l=e.isMethodDeclaration(a)?r.getContextualTypeForObjectLiteralElement(a):r.getContextualType(a);return l&&{contextualType:l,argumentIndex:o,argumentCount:s,argumentsSpan:c};case 217:var u=_(a),p=r.getContextualType(u),f=20===n.kind?0:g(a)-1,m=g(u);return p&&{contextualType:p,argumentIndex:f,argumentCount:m,argumentsSpan:e.createTextSpanFromNode(a)};default:return}}}function v(n){return"__type"===n.name&&e.firstDefined(n.declarations,(function(n){return e.isFunctionTypeNode(n)?n.parent.symbol:void 0}))||n}function b(e,n){for(var t=0,r=0,a=e.getChildren();r<a.length;r++){var i=a[r];if(i===n)break;27!==i.kind&&t++}return t}function E(n){var t=n.getChildren(),r=e.countWhere(t,(function(e){return 27!==e.kind}));return t.length>0&&27===e.last(t).kind&&r++,r}function T(n,t,r,a){return e.Debug.assert(r>=t.getStart(),"Assumed 'position' could not occur before node."),e.isTemplateLiteralToken(t)?e.isInsideTemplateLiteral(t,r,a)?0:n+2:n+1}function S(n,t,r){var a=e.isNoSubstitutionTemplateLiteral(n.template)?1:n.template.templateSpans.length+1;return 0!==t&&e.Debug.assertLessThan(t,a),{isTypeParameterList:!1,invocation:{kind:0,node:n},argumentsSpan:L(n,r),argumentIndex:t,argumentCount:a}}function x(n,t){var r=n.getFullStart(),a=e.skipTrivia(t.text,n.getEnd(),!1);return e.createTextSpan(r,a-r)}function L(n,t){var r=n.template,a=r.getStart(),i=r.getEnd();if(219===r.kind){var o=e.last(r.templateSpans);0===o.literal.getFullWidth()&&(i=e.skipTrivia(t.text,i,!1))}return e.createTextSpan(a,i-a)}function D(n,t,r,a,i){for(var o=function(n){e.Debug.assert(e.rangeContainsRange(n.parent,n),"Not a subspan",(function(){return"Child: "+e.Debug.formatSyntaxKind(n.kind)+", parent: "+e.Debug.formatSyntaxKind(n.parent.kind)}));var i=m(n,t,r,a);if(i)return{value:i}},s=n;!e.isSourceFile(s)&&(i||!e.isBlock(s));s=s.parent){var c=o(s);if("object"===typeof c)return c.value}}function A(n,t,r){var a=n.getChildren(r),i=a.indexOf(t);return e.Debug.assert(i>=0&&a.length>i+1),a[i+1]}function C(n){return 0===n.kind?e.getInvokedExpression(n.node):n.called}function I(e){return 0===e.kind?e.node:1===e.kind?e.called:e.node}(function(e){e[e["Call"]=0]="Call",e[e["TypeArgs"]=1]="TypeArgs",e[e["Contextual"]=2]="Contextual"})(t||(t={})),n.getSignatureHelpItems=a,function(e){e[e["Candidate"]=0]="Candidate",e[e["Type"]=1]="Type"}(r||(r={})),n.getArgumentInfoForCompletions=u;var N=70246400;function k(n,t,r,a,i,o){var s,c=r.isTypeParameterList,l=r.argumentCount,u=r.argumentsSpan,d=r.invocation,p=r.argumentIndex,f=I(d),m=2===d.kind?d.symbol:i.getSymbolAtLocation(C(d))||o&&(null===(s=t.declaration)||void 0===s?void 0:s.symbol),_=m?e.symbolToDisplayParts(i,m,o?a:void 0,void 0):e.emptyArray,g=e.map(n,(function(e){return P(e,_,c,i,f,a)}));0!==p&&e.Debug.assertLessThan(p,l);for(var y=0,h=0,v=0;v<g.length;v++){var b=g[v];if(n[v]===t&&(y=h,b.length>1))for(var E=0,T=0,S=b;T<S.length;T++){var x=S[T];if(x.isVariadic||x.parameters.length>=l){y=h+E;break}E++}h+=b.length}e.Debug.assert(-1!==y);var L={items:e.flatMapToMutable(g,e.identity),applicableSpan:u,selectedItemIndex:y,argumentIndex:p,argumentCount:l},D=L.items[y];if(D.isVariadic){var A=e.findIndex(D.parameters,(function(e){return!!e.isRest}));-1<A&&A<D.parameters.length-1?L.argumentIndex=D.parameters.length:L.argumentIndex=Math.min(L.argumentIndex,D.parameters.length-1)}return L}function R(e,n,t,r){var a=n.argumentCount,i=n.argumentsSpan,o=n.invocation,s=n.argumentIndex,c=r.getLocalTypeParametersOfClassOrInterfaceOrTypeAlias(e);if(c){var l=[O(e,c,r,I(o),t)];return{items:l,applicableSpan:i,selectedItemIndex:0,argumentIndex:s,argumentCount:a}}}function O(n,t,r,a,o){var s=e.symbolToDisplayParts(r,n),c=e.createPrinter({removeComments:!0}),l=t.map((function(e){return U(e,r,a,o,c)})),u=n.getDocumentationComment(r),d=n.getJsDocTags(r),p=i(i([],s),[e.punctuationPart(29)]);return{isVariadic:!1,prefixDisplayParts:p,suffixDisplayParts:[e.punctuationPart(31)],separatorDisplayParts:w,parameters:l,documentation:u,tags:d}}var w=[e.punctuationPart(27),e.spacePart()];function P(n,t,r,a,o,s){var c=(r?F:G)(n,a,o,s);return e.map(c,(function(e){var r=e.isVariadic,s=e.parameters,c=e.prefix,l=e.suffix,u=i(i([],t),c),d=i(i([],l),M(n,o,a)),p=n.getDocumentationComment(a),f=n.getJsDocTags();return{isVariadic:r,prefixDisplayParts:u,suffixDisplayParts:d,separatorDisplayParts:w,parameters:s,documentation:p,tags:f}}))}function M(n,t,r){return e.mapToDisplayParts((function(e){e.writePunctuation(":"),e.writeSpace(" ");var a=r.getTypePredicateOfSignature(n);a?r.writeTypePredicate(a,t,void 0,e):r.writeType(r.getReturnTypeOfSignature(n),t,void 0,e)}))}function F(n,t,r,a){var o=(n.target||n).typeParameters,s=e.createPrinter({removeComments:!0}),c=(o||e.emptyArray).map((function(e){return U(e,t,r,a,s)})),l=n.thisParameter?[t.symbolToParameterDeclaration(n.thisParameter,r,N)]:[];return t.getExpandedParameters(n).map((function(n){var o=e.factory.createNodeArray(i(i([],l),e.map(n,(function(e){return t.symbolToParameterDeclaration(e,r,N)})))),u=e.mapToDisplayParts((function(e){s.writeList(2576,o,a,e)}));return{isVariadic:!1,parameters:c,prefix:[e.punctuationPart(29)],suffix:i([e.punctuationPart(31)],u)}}))}function G(n,t,r,a){var o=t.hasEffectiveRestParameter(n),s=e.createPrinter({removeComments:!0}),c=e.mapToDisplayParts((function(i){if(n.typeParameters&&n.typeParameters.length){var o=e.factory.createNodeArray(n.typeParameters.map((function(e){return t.typeParameterToDeclaration(e,r,N)})));s.writeList(53776,o,a,i)}})),l=t.getExpandedParameters(n);return l.map((function(n){return{isVariadic:o&&(1===l.length||!!(32768&n[n.length-1].checkFlags)),parameters:n.map((function(e){return B(e,t,r,a,s)})),prefix:i(i([],c),[e.punctuationPart(20)]),suffix:[e.punctuationPart(21)]}}))}function B(n,t,r,a,i){var o=e.mapToDisplayParts((function(e){var o=t.symbolToParameterDeclaration(n,r,N);i.writeNode(4,o,a,e)})),s=t.isOptionalParameter(n.valueDeclaration),c=!!(32768&n.checkFlags);return{name:n.name,documentation:n.getDocumentationComment(t),displayParts:o,isOptional:s,isRest:c}}function U(n,t,r,a,i){var o=e.mapToDisplayParts((function(e){var o=t.typeParameterToDeclaration(n,r,N);i.writeNode(4,o,a,e)}));return{name:n.symbol.name,documentation:n.symbol.getDocumentationComment(t),displayParts:o,isOptional:!1,isRest:!1}}})(e.SignatureHelp||(e.SignatureHelp={}))}(d||(d={})),function(e){var n=/^data:(?:application\/json(?:;charset=[uU][tT][fF]-8);base64,([A-Za-z0-9+\/=]+)$)?/;function t(n){var t=e.createGetCanonicalFileName(n.useCaseSensitiveFileNames()),r=n.getCurrentDirectory(),a=new e.Map,o=new e.Map;return{tryGetSourcePosition:l,tryGetGeneratedPosition:u,toLineColumnOffset:m,clearCache:_};function s(n){return e.toPath(n,r,t)}function c(r,a){var i,c=s(r),l=o.get(c);if(l)return l;if(n.getDocumentPositionMapper)i=n.getDocumentPositionMapper(r,a);else if(n.readFile){var u=f(r);i=u&&e.getDocumentPositionMapper({getSourceFileLike:f,getCanonicalFileName:t,log:function(e){return n.log(e)}},r,e.getLineInfo(u.text,e.getLineStarts(u)),(function(e){return!n.fileExists||n.fileExists(e)?n.readFile(e):void 0}))}return o.set(c,i||e.identitySourceMapConsumer),i||e.identitySourceMapConsumer}function l(n){if(e.isDeclarationFileName(n.fileName)){var t=d(n.fileName);if(t){var r=c(n.fileName).getSourcePosition(n);return r&&r!==n?l(r)||r:void 0}}}function u(a){if(!e.isDeclarationFileName(a.fileName)){var i=d(a.fileName);if(i){var o=n.getProgram();if(!o.isSourceOfProjectReferenceRedirect(i.fileName)){var s=o.getCompilerOptions(),l=e.outFile(s),u=l?e.removeFileExtension(l)+".d.ts":e.getDeclarationEmitOutputFilePathWorker(a.fileName,o.getCompilerOptions(),r,o.getCommonSourceDirectory(),t);if(void 0!==u){var p=c(u,a.fileName).getGeneratedPosition(a);return p===a?void 0:p}}}}}function d(e){var t=n.getProgram();if(t){var r=s(e),a=t.getSourceFileByPath(r);return a&&a.resolvedPath===r?a:void 0}}function p(e){var t=s(e),r=a.get(t);if(void 0!==r)return r||void 0;if(n.readFile&&(!n.fileExists||n.fileExists(t))){var o=n.readFile(t),c=!!o&&i(o);return a.set(t,c),c||void 0}a.set(t,!1)}function f(e){return n.getSourceFileLike?n.getSourceFileLike(e):d(e)||p(e)}function m(e,n){var t=f(e);return t.getLineAndCharacterOfPosition(n)}function _(){a.clear(),o.clear()}}function r(t,r,i,o){var s=e.tryGetSourceMappingURL(i);if(s){var c=n.exec(s);if(c){if(c[1]){var l=c[1];return a(t,e.base64decode(e.sys,l),r)}s=void 0}}var u=[];s&&u.push(s),u.push(r+".map");for(var d=s&&e.getNormalizedAbsolutePath(s,e.getDirectoryPath(r)),p=0,f=u;p<f.length;p++){var m=f[p],_=e.getNormalizedAbsolutePath(m,e.getDirectoryPath(r)),g=o(_,d);if(e.isString(g))return a(t,g,_);if(void 0!==g)return g||void 0}}function a(n,t,r){var a=e.tryParseRawSourceMap(t);if(a&&a.sources&&a.file&&a.mappings&&(!a.sourcesContent||!a.sourcesContent.some(e.isString)))return e.createDocumentPositionMapper(n,a,r)}function i(n,t){return{text:n,lineMap:t,getLineAndCharacterOfPosition:function(n){return e.computeLineAndCharacterOfPosition(e.getLineStarts(this),n)}}}e.getSourceMapper=t,e.getDocumentPositionMapper=r}(d||(d={})),function(e){var n=new e.Map;function t(t,a,s){a.getSemanticDiagnostics(t,s);var c=[],u=a.getTypeChecker();t.commonJsModuleIndicator&&(e.programContainsEs6Modules(a)||e.compilerOptionsIndicateEs6Modules(a.getCompilerOptions()))&&r(t)&&c.push(e.createDiagnosticForNode(l(t.commonJsModuleIndicator),e.Diagnostics.File_is_a_CommonJS_module_it_may_be_converted_to_an_ES6_module));var d=e.isSourceFileJS(t);if(n.clear(),E(t),e.getAllowSyntheticDefaultImports(a.getCompilerOptions()))for(var p=0,f=t.imports;p<f.length;p++){var m=f[p],_=e.importFromModuleSpecifier(m),g=i(_);if(g){var v=e.getResolvedModule(t,m.text),b=v&&a.getSourceFile(v.resolvedFileName);b&&b.externalModuleIndicator&&e.isExportAssignment(b.externalModuleIndicator)&&b.externalModuleIndicator.isExportEquals&&c.push(e.createDiagnosticForNode(g,e.Diagnostics.Import_may_be_converted_to_a_default_import))}}return e.addRange(c,t.bindSuggestionDiagnostics),e.addRange(c,a.getSuggestionDiagnostics(t,s)),c.sort((function(e,n){return e.start-n.start}));function E(n){if(d)y(n,u)&&c.push(e.createDiagnosticForNode(e.isVariableDeclaration(n.parent)?n.parent.name:n,e.Diagnostics.This_constructor_function_may_be_converted_to_a_class_declaration));else{if(e.isVariableStatement(n)&&n.parent===t&&2&n.declarationList.flags&&1===n.declarationList.declarations.length){var r=n.declarationList.declarations[0].initializer;r&&e.isRequireCall(r,!0)&&c.push(e.createDiagnosticForNode(r,e.Diagnostics.require_call_may_be_converted_to_an_import))}e.codefix.parameterShouldGetTypeFromJSDoc(n)&&c.push(e.createDiagnosticForNode(n.name||n,e.Diagnostics.JSDoc_types_may_be_moved_to_TypeScript_types))}h(n)&&o(n,u,c),n.forEachChild(E)}}function r(n){return n.statements.some((function(n){switch(n.kind){case 233:return n.declarationList.declarations.some((function(n){return!!n.initializer&&e.isRequireCall(a(n.initializer),!0)}));case 234:var t=n.expression;if(!e.isBinaryExpression(t))return e.isRequireCall(t,!0);var r=e.getAssignmentDeclarationKind(t);return 1===r||2===r;default:return!1}}))}function a(n){return e.isPropertyAccessExpression(n)?a(n.expression):n}function i(n){switch(n.kind){case 262:var t=n.importClause,r=n.moduleSpecifier;return t&&!t.name&&t.namedBindings&&264===t.namedBindings.kind&&e.isStringLiteral(r)?t.namedBindings.name:void 0;case 261:return n.name;default:return}}function o(t,r,a){s(t,r)&&!n.has(g(t))&&a.push(e.createDiagnosticForNode(!t.name&&e.isVariableDeclaration(t.parent)&&e.isIdentifier(t.parent.name)?t.parent.name:t,e.Diagnostics.This_may_be_converted_to_an_async_function))}function s(n,t){return!e.isAsyncFunction(n)&&n.body&&e.isBlock(n.body)&&u(n.body,t)&&c(n,t)}function c(e,n){var t=n.getSignatureFromDeclaration(e),r=t?n.getReturnTypeOfSignature(t):void 0;return!!r&&!!n.getPromisedTypeOfPromise(r)}function l(n){return e.isBinaryExpression(n)?n.left:n}function u(n,t){return!!e.forEachReturnStatement(n,(function(e){return d(e,t)}))}function d(n,t){return e.isReturnStatement(n)&&!!n.expression&&p(n.expression,t)}function p(n,t){if(!f(n)||!n.arguments.every((function(e){return _(e,t)})))return!1;var r=n.expression;while(f(r)||e.isPropertyAccessExpression(r)){if(e.isCallExpression(r)&&!r.arguments.every((function(e){return _(e,t)})))return!1;r=r.expression}return!0}function f(n){return e.isCallExpression(n)&&(e.hasPropertyAccessExpressionWithName(n,"then")&&m(n)||e.hasPropertyAccessExpressionWithName(n,"catch"))}function m(n){return!(n.arguments.length>2)&&(n.arguments.length<2||e.some(n.arguments,(function(n){return 103===n.kind||e.isIdentifier(n)&&"undefined"===n.text})))}function _(t,r){switch(t.kind){case 252:case 209:case 210:n.set(g(t),!0);case 103:return!0;case 78:case 202:var a=r.getSymbolAtLocation(t);return!!a&&(r.isUndefinedSymbol(a)||e.some(e.skipAlias(a,r).declarations,(function(n){return e.isFunctionLike(n)||e.hasInitializer(n)&&!!n.initializer&&e.isFunctionLike(n.initializer)})));default:return!1}}function g(e){return e.pos.toString()+":"+e.end.toString()}function y(n,t){var r,a,i,o;if(209===n.kind){if(e.isVariableDeclaration(n.parent)&&(null===(r=n.symbol.members)||void 0===r?void 0:r.size))return!0;var s=t.getSymbolOfExpando(n,!1);return!(!s||!(null===(a=s.exports)||void 0===a?void 0:a.size)&&!(null===(i=s.members)||void 0===i?void 0:i.size))}return 252===n.kind&&!!(null===(o=n.symbol.members)||void 0===o?void 0:o.size)}function h(e){switch(e.kind){case 252:case 166:case 209:case 210:return!0;default:return!1}}e.computeSuggestionDiagnostics=t,e.returnsPromise=c,e.isReturnStatementWithFixablePromiseHandler=d,e.isFixablePromiseHandler=p,e.canBeConvertedToAsync=h}(d||(d={})),function(e){(function(n){var t=70246400;function r(n,t,r){var i=a(n,t,r);if(""!==i)return i;var o=e.getCombinedLocalAndExportSymbolFlags(t);return 32&o?e.getDeclarationOfKind(t,222)?"local class":"class":384&o?"enum":524288&o?"type":64&o?"interface":262144&o?"type parameter":8&o?"enum member":2097152&o?"alias":1536&o?"module":i}function a(n,t,r){var a=n.getRootSymbols(t);if(1===a.length&&8192&e.first(a).flags&&0!==n.getTypeOfSymbolAtLocation(t,r).getNonNullableType().getCallSignatures().length)return"method";if(n.isUndefinedSymbol(t))return"var";if(n.isArgumentsSymbol(t))return"local var";if(107===r.kind&&e.isExpression(r))return"parameter";var i=e.getCombinedLocalAndExportSymbolFlags(t);if(3&i)return e.isFirstDeclarationOfSymbolParameter(t)?"parameter":t.valueDeclaration&&e.isVarConst(t.valueDeclaration)?"const":e.forEach(t.declarations,e.isLet)?"let":l(t)?"local var":"var";if(16&i)return l(t)?"local function":"function";if(32768&i)return"getter";if(65536&i)return"setter";if(8192&i)return"method";if(16384&i)return"constructor";if(4&i){if(33554432&i&&6&t.checkFlags){var o=e.forEach(n.getRootSymbols(t),(function(e){var n=e.getFlags();if(98311&n)return"property"}));if(!o){var s=n.getTypeOfSymbolAtLocation(t,r);return s.getCallSignatures().length?"method":"property"}return o}switch(r.parent&&r.parent.kind){case 276:case 274:case 275:return 78===r.kind?"property":"JSX attribute";case 281:return"JSX attribute";default:return"property"}}return""}function i(n){return!!(8192&e.getCombinedNodeFlagsAlwaysIncludeJSDoc(n))}function o(n){if(n.declarations&&n.declarations.length){var t=n.declarations,r=t[0],a=t.slice(1),o=e.length(a)&&i(r)&&e.some(a,(function(e){return!i(e)}))?8192:0,s=e.getNodeModifiers(r,o);if(s)return s.split(",")}return[]}function s(n,t){if(!t)return"";var r=new e.Set(o(t));if(2097152&t.flags){var a=n.getAliasedSymbol(t);a!==t&&e.forEach(o(a),(function(e){r.add(e)}))}return 16777216&t.flags&&r.add("optional"),r.size>0?e.arrayFrom(r.values()).join(","):""}function c(n,i,o,s,l,u,d){var p;void 0===u&&(u=e.getMeaningFromLocation(l));var f,m,_,g,y=[],h=[],v=[],b=e.getCombinedLocalAndExportSymbolFlags(i),E=1&u?a(n,i,l):"",T=!1,S=107===l.kind&&e.isInExpressionContext(l),x=!1;if(107===l.kind&&!S)return{displayParts:[e.keywordPart(107)],documentation:[],symbolKind:"primitive type",tags:void 0};if(""!==E||32&b||2097152&b){"getter"!==E&&"setter"!==E||(E="property");var L=void 0;if(f=S?n.getTypeAtLocation(l):n.getTypeOfSymbolAtLocation(i,l),l.parent&&202===l.parent.kind){var D=l.parent.name;(D===l||D&&0===D.getFullWidth())&&(l=l.parent)}var A=void 0;if(e.isCallOrNewExpression(l)?A=l:(e.isCallExpressionTarget(l)||e.isNewExpressionTarget(l)||l.parent&&(e.isJsxOpeningLikeElement(l.parent)||e.isTaggedTemplateExpression(l.parent))&&e.isFunctionLike(i.valueDeclaration))&&(A=l.parent),A){L=n.getResolvedSignature(A);var C=205===A.kind||e.isCallExpression(A)&&105===A.expression.kind,I=C?f.getConstructSignatures():f.getCallSignatures();if(!L||e.contains(I,L.target)||e.contains(I,L)||(L=I.length?I[0]:void 0),L){switch(C&&32&b?(E="constructor",Z(f.symbol,E)):2097152&b?(E="alias",$(E),y.push(e.spacePart()),C&&(4&L.flags&&(y.push(e.keywordPart(125)),y.push(e.spacePart())),y.push(e.keywordPart(102)),y.push(e.spacePart())),Q(i)):Z(i,E),E){case"JSX attribute":case"property":case"var":case"const":case"let":case"parameter":case"local var":y.push(e.punctuationPart(58)),y.push(e.spacePart()),16&e.getObjectFlags(f)||!f.symbol||(e.addRange(y,e.symbolToDisplayParts(n,f.symbol,s,void 0,5)),y.push(e.lineBreakPart())),C&&(4&L.flags&&(y.push(e.keywordPart(125)),y.push(e.spacePart())),y.push(e.keywordPart(102)),y.push(e.spacePart())),ee(L,I,262144);break;default:ee(L,I)}T=!0,x=I.length>1}}else if(e.isNameOfFunctionDeclaration(l)&&!(98304&b)||132===l.kind&&167===l.parent.kind){var N=l.parent,k=i.declarations&&e.find(i.declarations,(function(e){return e===(132===l.kind?N.parent:N)}));if(k){I=167===N.kind?f.getNonNullableType().getConstructSignatures():f.getNonNullableType().getCallSignatures();L=n.isImplementationOfOverload(N)?I[0]:n.getSignatureFromDeclaration(N),167===N.kind?(E="constructor",Z(f.symbol,E)):Z(170!==N.kind||2048&f.symbol.flags||4096&f.symbol.flags?i:f.symbol,E),L&&ee(L,I),T=!0,x=I.length>1}}}if(32&b&&!T&&!S&&(X(),e.getDeclarationOfKind(i,222)?$("local class"):y.push(e.keywordPart(83)),y.push(e.spacePart()),Q(i),ne(i,o)),64&b&&2&u&&(J(),y.push(e.keywordPart(117)),y.push(e.spacePart()),Q(i),ne(i,o)),524288&b&&2&u&&(J(),y.push(e.keywordPart(149)),y.push(e.spacePart()),Q(i),ne(i,o),y.push(e.spacePart()),y.push(e.operatorPart(62)),y.push(e.spacePart()),e.addRange(y,e.typeToDisplayParts(n,n.getDeclaredTypeOfSymbol(i),s,8388608))),384&b&&(J(),e.some(i.declarations,(function(n){return e.isEnumDeclaration(n)&&e.isEnumConst(n)}))&&(y.push(e.keywordPart(84)),y.push(e.spacePart())),y.push(e.keywordPart(91)),y.push(e.spacePart()),Q(i)),1536&b&&!S){J();var R=e.getDeclarationOfKind(i,257),O=R&&R.name&&78===R.name.kind;y.push(e.keywordPart(O?140:139)),y.push(e.spacePart()),Q(i)}if(262144&b&&2&u)if(J(),y.push(e.punctuationPart(20)),y.push(e.textPart("type parameter")),y.push(e.punctuationPart(21)),y.push(e.spacePart()),Q(i),i.parent)Y(),Q(i.parent,s),ne(i.parent,s);else{var w=e.getDeclarationOfKind(i,160);if(void 0===w)return e.Debug.fail();R=w.parent;if(R)if(e.isFunctionLikeKind(R.kind)){Y();L=n.getSignatureFromDeclaration(R);171===R.kind?(y.push(e.keywordPart(102)),y.push(e.spacePart())):170!==R.kind&&R.name&&Q(R.symbol),e.addRange(y,e.signatureToDisplayParts(n,L,o,32))}else 255===R.kind&&(Y(),y.push(e.keywordPart(149)),y.push(e.spacePart()),Q(R.symbol),ne(R.symbol,o))}if(8&b){E="enum member",Z(i,"enum member");R=null===(p=i.declarations)||void 0===p?void 0:p[0];if(292===(null===R||void 0===R?void 0:R.kind)){var P=n.getConstantValue(R);void 0!==P&&(y.push(e.spacePart()),y.push(e.operatorPart(62)),y.push(e.spacePart()),y.push(e.displayPart(e.getTextOfConstantValue(P),"number"===typeof P?e.SymbolDisplayPartKind.numericLiteral:e.SymbolDisplayPartKind.stringLiteral)))}}if(2097152&i.flags){if(J(),!T){var M=n.getAliasedSymbol(i);if(M!==i&&M.declarations&&M.declarations.length>0){var F=M.declarations[0],G=e.getNameOfDeclaration(F);if(G){var B=e.isModuleWithStringLiteralName(F)&&e.hasSyntacticModifier(F,2),U="default"!==i.name&&!B,V=c(n,M,e.getSourceFileOfNode(F),F,G,u,U?i:M);y.push.apply(y,V.displayParts),y.push(e.lineBreakPart()),_=V.documentation,g=V.tags}else _=M.getContextualDocumentationComment(F,n),g=M.getJsDocTags(n)}}if(i.declarations)switch(i.declarations[0].kind){case 260:y.push(e.keywordPart(92)),y.push(e.spacePart()),y.push(e.keywordPart(140));break;case 267:y.push(e.keywordPart(92)),y.push(e.spacePart()),y.push(e.keywordPart(i.declarations[0].isExportEquals?62:87));break;case 271:y.push(e.keywordPart(92));break;default:y.push(e.keywordPart(99))}y.push(e.spacePart()),Q(i),e.forEach(i.declarations,(function(t){if(261===t.kind){var r=t;if(e.isExternalModuleImportEqualsDeclaration(r))y.push(e.spacePart()),y.push(e.operatorPart(62)),y.push(e.spacePart()),y.push(e.keywordPart(143)),y.push(e.punctuationPart(20)),y.push(e.displayPart(e.getTextOfNode(e.getExternalModuleImportEqualsDeclarationExpression(r)),e.SymbolDisplayPartKind.stringLiteral)),y.push(e.punctuationPart(21));else{var a=n.getSymbolAtLocation(r.moduleReference);a&&(y.push(e.spacePart()),y.push(e.operatorPart(62)),y.push(e.spacePart()),Q(a,s))}return!0}}))}if(!T)if(""!==E){if(f)if(S?(J(),y.push(e.keywordPart(107))):Z(i,E),"property"===E||"JSX attribute"===E||3&b||"local var"===E||S){if(y.push(e.punctuationPart(58)),y.push(e.spacePart()),f.symbol&&262144&f.symbol.flags){var j=e.mapToDisplayParts((function(r){var a=n.typeParameterToDeclaration(f,s,t);q().writeNode(4,a,e.getSourceFileOfNode(e.getParseTreeNode(s)),r)}));e.addRange(y,j)}else e.addRange(y,e.typeToDisplayParts(n,f,s));if(i.target&&i.target.tupleLabelDeclaration){var K=i.target.tupleLabelDeclaration;e.Debug.assertNode(K.name,e.isIdentifier),y.push(e.spacePart()),y.push(e.punctuationPart(20)),y.push(e.textPart(e.idText(K.name))),y.push(e.punctuationPart(21))}}else if(16&b||8192&b||16384&b||131072&b||98304&b||"method"===E){I=f.getNonNullableType().getCallSignatures();I.length&&(ee(I[0],I),x=I.length>1)}}else E=r(n,i,l);if(0!==h.length||x||(h=i.getContextualDocumentationComment(s,n)),0===h.length&&4&b&&i.parent&&i.declarations&&e.forEach(i.parent.declarations,(function(e){return 298===e.kind})))for(var H=0,W=i.declarations;H<W.length;H++){R=W[H];if(R.parent&&217===R.parent.kind){var z=n.getSymbolAtLocation(R.parent.right);if(z&&(h=z.getDocumentationComment(n),v=z.getJsDocTags(n),h.length>0))break}}return 0!==v.length||x||(v=i.getJsDocTags(n)),0===h.length&&_&&(h=_),0===v.length&&g&&(v=g),{displayParts:y,documentation:h,symbolKind:E,tags:0===v.length?void 0:v};function q(){return m||(m=e.createPrinter({removeComments:!0})),m}function J(){y.length&&y.push(e.lineBreakPart()),X()}function X(){d&&($("alias"),y.push(e.spacePart()))}function Y(){y.push(e.spacePart()),y.push(e.keywordPart(100)),y.push(e.spacePart())}function Q(t,r){d&&t===i&&(t=d);var a=e.symbolToDisplayParts(n,t,r||o,void 0,7);e.addRange(y,a),16777216&i.flags&&y.push(e.punctuationPart(57))}function Z(n,t){J(),t&&($(t),n&&!e.some(n.declarations,(function(n){return e.isArrowFunction(n)||(e.isFunctionExpression(n)||e.isClassExpression(n))&&!n.name}))&&(y.push(e.spacePart()),Q(n)))}function $(n){switch(n){case"var":case"function":case"let":case"const":case"constructor":return void y.push(e.textOrKeywordPart(n));default:return y.push(e.punctuationPart(20)),y.push(e.textOrKeywordPart(n)),void y.push(e.punctuationPart(21))}}function ee(t,r,a){void 0===a&&(a=0),e.addRange(y,e.signatureToDisplayParts(n,t,s,32|a)),r.length>1&&(y.push(e.spacePart()),y.push(e.punctuationPart(20)),y.push(e.operatorPart(39)),y.push(e.displayPart((r.length-1).toString(),e.SymbolDisplayPartKind.numericLiteral)),y.push(e.spacePart()),y.push(e.textPart(2===r.length?"overload":"overloads")),y.push(e.punctuationPart(21))),h=t.getDocumentationComment(n),v=t.getJsDocTags(),r.length>1&&0===h.length&&0===v.length&&(h=r[0].getDocumentationComment(n),v=r[0].getJsDocTags())}function ne(r,a){var i=e.mapToDisplayParts((function(i){var o=n.symbolToTypeParameterDeclarations(r,a,t);q().writeList(53776,o,e.getSourceFileOfNode(e.getParseTreeNode(a)),i)}));e.addRange(y,i)}}function l(n){return!n.parent&&e.forEach(n.declarations,(function(n){if(209===n.kind)return!0;if(250!==n.kind&&252!==n.kind)return!1;for(var t=n.parent;!e.isFunctionBlock(t);t=t.parent)if(298===t.kind||258===t.kind)return!1;return!0}))}n.getSymbolKind=r,n.getSymbolModifiers=s,n.getSymbolDisplayPartsDocumentationAndSymbolKind=c})(e.SymbolDisplay||(e.SymbolDisplay={}))}(d||(d={})),function(e){function n(n,t){var r=[],i=t.compilerOptions?a(t.compilerOptions,r):{},o=e.getDefaultCompilerOptions();for(var s in o)e.hasProperty(o,s)&&void 0===i[s]&&(i[s]=o[s]);for(var c=0,l=e.transpileOptionValueCompilerOptions;c<l.length;c++){var u=l[c];i[u.name]=u.transpileOptionValue}i.suppressOutputPathCheck=!0,i.allowNonTsExtensions=!0;var d=t.fileName||(t.compilerOptions&&t.compilerOptions.jsx?"module.tsx":"module.ts"),p=e.createSourceFile(d,n,i.target);t.moduleName&&(p.moduleName=t.moduleName),t.renamedDependencies&&(p.renamedDependencies=new e.Map(e.getEntries(t.renamedDependencies)));var f,m,_=e.getNewLineCharacter(i),g={getSourceFile:function(n){return n===e.normalizePath(d)?p:void 0},writeFile:function(n,t){e.fileExtensionIs(n,".map")?(e.Debug.assertEqual(m,void 0,"Unexpected multiple source map outputs, file:",n),m=t):(e.Debug.assertEqual(f,void 0,"Unexpected multiple outputs, file:",n),f=t)},getDefaultLibFileName:function(){return"lib.d.ts"},useCaseSensitiveFileNames:function(){return!1},getCanonicalFileName:function(e){return e},getCurrentDirectory:function(){return""},getNewLine:function(){return _},fileExists:function(e){return e===d},readFile:function(){return""},directoryExists:function(){return!0},getDirectories:function(){return[]}},y=e.createProgram([d],i,g);return t.reportDiagnostics&&(e.addRange(r,y.getSyntacticDiagnostics(p)),e.addRange(r,y.getOptionsDiagnostics())),y.emit(void 0,void 0,void 0,void 0,t.transformers),void 0===f?e.Debug.fail("Output generation failed"):{outputText:f,diagnostics:r,sourceMapText:m}}function t(t,r,a,i,o){var s=n(t,{compilerOptions:r,fileName:a,reportDiagnostics:!!i,moduleName:o});return e.addRange(i,s.diagnostics),s.outputText}var r;function a(n,t){r=r||e.filter(e.optionDeclarations,(function(n){return"object"===typeof n.type&&!e.forEachEntry(n.type,(function(e){return"number"!==typeof e}))})),n=e.cloneCompilerOptions(n);for(var a=function(r){if(!e.hasProperty(n,r.name))return"continue";var a=n[r.name];e.isString(a)?n[r.name]=e.parseCustomTypeOption(r,a,t):e.forEachEntry(r.type,(function(e){return e===a}))||t.push(e.createCompilerDiagnosticForInvalidCustomType(r))},i=0,o=r;i<o.length;i++){var s=o[i];a(s)}return n}e.transpileModule=n,e.transpile=t,e.fixupCompilerOptions=a}(d||(d={})),function(e){(function(n){(function(e){e[e["FormatDocument"]=0]="FormatDocument",e[e["FormatSelection"]=1]="FormatSelection",e[e["FormatOnEnter"]=2]="FormatOnEnter",e[e["FormatOnSemicolon"]=3]="FormatOnSemicolon",e[e["FormatOnOpeningCurlyBrace"]=4]="FormatOnOpeningCurlyBrace",e[e["FormatOnClosingCurlyBrace"]=5]="FormatOnClosingCurlyBrace"})(n.FormattingRequestKind||(n.FormattingRequestKind={}));var t=function(){function n(e,n,t){this.sourceFile=e,this.formattingRequestKind=n,this.options=t}return n.prototype.updateContext=function(n,t,r,a,i){this.currentTokenSpan=e.Debug.checkDefined(n),this.currentTokenParent=e.Debug.checkDefined(t),this.nextTokenSpan=e.Debug.checkDefined(r),this.nextTokenParent=e.Debug.checkDefined(a),this.contextNode=e.Debug.checkDefined(i),this.contextNodeAllOnSameLine=void 0,this.nextNodeAllOnSameLine=void 0,this.tokensAreOnSameLine=void 0,this.contextNodeBlockIsOnOneLine=void 0,this.nextNodeBlockIsOnOneLine=void 0},n.prototype.ContextNodeAllOnSameLine=function(){return void 0===this.contextNodeAllOnSameLine&&(this.contextNodeAllOnSameLine=this.NodeIsOnOneLine(this.contextNode)),this.contextNodeAllOnSameLine},n.prototype.NextNodeAllOnSameLine=function(){return void 0===this.nextNodeAllOnSameLine&&(this.nextNodeAllOnSameLine=this.NodeIsOnOneLine(this.nextTokenParent)),this.nextNodeAllOnSameLine},n.prototype.TokensAreOnSameLine=function(){if(void 0===this.tokensAreOnSameLine){var e=this.sourceFile.getLineAndCharacterOfPosition(this.currentTokenSpan.pos).line,n=this.sourceFile.getLineAndCharacterOfPosition(this.nextTokenSpan.pos).line;this.tokensAreOnSameLine=e===n}return this.tokensAreOnSameLine},n.prototype.ContextNodeBlockIsOnOneLine=function(){return void 0===this.contextNodeBlockIsOnOneLine&&(this.contextNodeBlockIsOnOneLine=this.BlockIsOnOneLine(this.contextNode)),this.contextNodeBlockIsOnOneLine},n.prototype.NextNodeBlockIsOnOneLine=function(){return void 0===this.nextNodeBlockIsOnOneLine&&(this.nextNodeBlockIsOnOneLine=this.BlockIsOnOneLine(this.nextTokenParent)),this.nextNodeBlockIsOnOneLine},n.prototype.NodeIsOnOneLine=function(e){var n=this.sourceFile.getLineAndCharacterOfPosition(e.getStart(this.sourceFile)).line,t=this.sourceFile.getLineAndCharacterOfPosition(e.getEnd()).line;return n===t},n.prototype.BlockIsOnOneLine=function(n){var t=e.findChildOfKind(n,18,this.sourceFile),r=e.findChildOfKind(n,19,this.sourceFile);if(t&&r){var a=this.sourceFile.getLineAndCharacterOfPosition(t.getEnd()).line,i=this.sourceFile.getLineAndCharacterOfPosition(r.getStart(this.sourceFile)).line;return a===i}return!1},n}();n.FormattingContext=t})(e.formatting||(e.formatting={}))}(d||(d={})),function(e){(function(n){var t,r=e.createScanner(99,!1,0),a=e.createScanner(99,!1,1);function i(t,i,o,s,c){var l=1===i?a:r;l.setText(t),l.setTextPos(o);var u,d,p,f,m,_=!0,g=c({advance:y,readTokenInfo:L,readEOFTokenRange:A,isOnToken:C,isOnEOF:I,getCurrentLeadingTrivia:function(){return u},lastTrailingTriviaWasNewLine:function(){return _},skipToEndOf:k,skipToStartOf:R});return m=void 0,l.setText(void 0),g;function y(){m=void 0;var n=l.getStartPos()!==o;n?_=!!d&&4===e.last(d).kind:l.scan(),u=void 0,d=void 0;var t=l.getStartPos();while(t<s){var r=l.getToken();if(!e.isTrivia(r))break;l.scan();var a={pos:t,end:l.getStartPos(),kind:r};t=l.getStartPos(),u=e.append(u,a)}p=l.getStartPos()}function h(e){switch(e.kind){case 33:case 70:case 71:case 49:case 48:return!0}return!1}function v(n){if(n.parent)switch(n.parent.kind){case 281:case 276:case 277:case 275:return e.isKeyword(n.kind)||78===n.kind}return!1}function b(n){return e.isJsxText(n)}function E(e){return 13===e.kind}function T(e){return 16===e.kind||17===e.kind}function S(n){return n.parent&&e.isJsxAttribute(n.parent)&&n.parent.initializer===n}function x(e){return 43===e||67===e}function L(t){e.Debug.assert(C());var r=h(t)?1:E(t)?2:T(t)?3:v(t)?4:b(t)?5:S(t)?6:0;if(m&&r===f)return N(m,t);l.getStartPos()!==p&&(e.Debug.assert(void 0!==m),l.setTextPos(p),l.scan());var a=D(t,r),i=n.createTextRangeWithKind(l.getStartPos(),l.getTextPos(),a);d&&(d=void 0);while(l.getStartPos()<s){if(a=l.scan(),!e.isTrivia(a))break;var o=n.createTextRangeWithKind(l.getStartPos(),l.getTextPos(),a);if(d||(d=[]),d.push(o),4===a){l.scan();break}}return m={leadingTrivia:u,trailingTrivia:d,token:i},N(m,t)}function D(n,t){var r=l.getToken();switch(f=0,t){case 1:if(31===r){f=1;var a=l.reScanGreaterToken();return e.Debug.assert(n.kind===a),a}break;case 2:if(x(r)){f=2;a=l.reScanSlashToken();return e.Debug.assert(n.kind===a),a}break;case 3:if(19===r)return f=3,l.reScanTemplateToken(!1);break;case 4:return f=4,l.scanJsxIdentifier();case 5:return f=5,l.reScanJsxToken(!1);case 6:return f=6,l.reScanJsxAttributeValue();case 0:break;default:e.Debug.assertNever(t)}return r}function A(){return e.Debug.assert(I()),n.createTextRangeWithKind(l.getStartPos(),l.getTextPos(),1)}function C(){var n=m?m.token.kind:l.getToken(),t=m?m.token.pos:l.getStartPos();return t<s&&1!==n&&!e.isTrivia(n)}function I(){var e=m?m.token.kind:l.getToken();return 1===e}function N(n,t){return e.isToken(t)&&n.token.kind!==t.kind&&(n.token.kind=t.kind),n}function k(e){l.setTextPos(e.end),p=l.getStartPos(),f=void 0,m=void 0,_=!1,u=void 0,d=void 0}function R(e){l.setTextPos(e.pos),p=l.getStartPos(),f=void 0,m=void 0,_=!1,u=void 0,d=void 0}}(function(e){e[e["Scan"]=0]="Scan",e[e["RescanGreaterThanToken"]=1]="RescanGreaterThanToken",e[e["RescanSlashToken"]=2]="RescanSlashToken",e[e["RescanTemplateToken"]=3]="RescanTemplateToken",e[e["RescanJsxIdentifier"]=4]="RescanJsxIdentifier",e[e["RescanJsxText"]=5]="RescanJsxText",e[e["RescanJsxAttributeValue"]=6]="RescanJsxAttributeValue"})(t||(t={})),n.getFormattingScanner=i})(e.formatting||(e.formatting={}))}(d||(d={})),function(e){(function(n){n.anyContext=e.emptyArray,function(e){e[e["StopProcessingSpaceActions"]=1]="StopProcessingSpaceActions",e[e["StopProcessingTokenActions"]=2]="StopProcessingTokenActions",e[e["InsertSpace"]=4]="InsertSpace",e[e["InsertNewLine"]=8]="InsertNewLine",e[e["DeleteSpace"]=16]="DeleteSpace",e[e["DeleteToken"]=32]="DeleteToken",e[e["InsertTrailingSemicolon"]=64]="InsertTrailingSemicolon",e[e["StopAction"]=3]="StopAction",e[e["ModifySpaceAction"]=28]="ModifySpaceAction",e[e["ModifyTokenAction"]=96]="ModifyTokenAction"}(n.RuleAction||(n.RuleAction={})),function(e){e[e["None"]=0]="None",e[e["CanDeleteNewLines"]=1]="CanDeleteNewLines"}(n.RuleFlags||(n.RuleFlags={}))})(e.formatting||(e.formatting={}))}(d||(d={})),function(e){(function(n){function t(){for(var t=[],o=0;o<=157;o++)1!==o&&t.push(o);function L(){for(var e=[],n=0;n<arguments.length;n++)e[n]=arguments[n];return{tokens:t.filter((function(n){return!e.some((function(e){return e===n}))})),isSpecific:!1}}var D={tokens:t,isSpecific:!1},C=a(i(i([],t),[3])),O=a(i(i([],t),[1])),F=s(80,157),G=s(29,77),ee=[100,101,157,126,137],oe=[45,46,54,53],fe=[8,9,78,20,22,18,107,102],ge=[78,20,107,102],ye=[78,21,23,102],he=[78,20,107,102],ve=[78,21,23,102],be=[2,3],Ee=i([78],e.typeKeywords),Te=C,Se=a([78,3,83,92,99]),xe=a([21,3,89,110,95,90]),Le=[r("IgnoreBeforeComment",D,be,n.anyContext,1),r("IgnoreAfterLineComment",2,D,n.anyContext,1),r("NotSpaceBeforeColon",D,58,[W,y,h],16),r("SpaceAfterColon",58,D,[W,y],4),r("NoSpaceBeforeQuestionMark",D,57,[W,y,h],16),r("SpaceAfterQuestionMarkInConditionalOperator",57,D,[W,b],4),r("NoSpaceAfterQuestionMark",57,D,[W],16),r("NoSpaceBeforeDot",D,[24,28],[W],16),r("NoSpaceAfterDot",[24,28],D,[W],16),r("NoSpaceBetweenImportParenInImportType",99,20,[W,H],16),r("NoSpaceAfterUnaryPrefixOperator",oe,fe,[W,y],16),r("NoSpaceAfterUnaryPreincrementOperator",45,ge,[W],16),r("NoSpaceAfterUnaryPredecrementOperator",46,he,[W],16),r("NoSpaceBeforeUnaryPostincrementOperator",ye,45,[W,pe],16),r("NoSpaceBeforeUnaryPostdecrementOperator",ve,46,[W,pe],16),r("SpaceAfterPostincrementWhenFollowedByAdd",45,39,[W,g],4),r("SpaceAfterAddWhenFollowedByUnaryPlus",39,39,[W,g],4),r("SpaceAfterAddWhenFollowedByPreincrement",39,45,[W,g],4),r("SpaceAfterPostdecrementWhenFollowedBySubtract",46,40,[W,g],4),r("SpaceAfterSubtractWhenFollowedByUnaryMinus",40,40,[W,g],4),r("SpaceAfterSubtractWhenFollowedByPredecrement",40,46,[W,g],4),r("NoSpaceAfterCloseBrace",19,[27,26],[W],16),r("NewLineBeforeCloseBraceInBlockContext",C,19,[x],8),r("SpaceAfterCloseBrace",19,L(21),[W,w],4),r("SpaceBetweenCloseBraceAndElse",19,90,[W],4),r("SpaceBetweenCloseBraceAndWhile",19,114,[W],4),r("NoSpaceBetweenEmptyBraceBrackets",18,19,[W,M],16),r("SpaceAfterConditionalClosingParen",21,22,[P],4),r("NoSpaceBetweenFunctionKeywordAndStar",97,41,[k],16),r("SpaceAfterStarInGeneratorDeclaration",41,78,[k],4),r("SpaceAfterFunctionInFuncDecl",97,D,[I],4),r("NewLineAfterOpenBraceInBlockContext",18,D,[x],8),r("SpaceAfterGetSetInMember",[134,146],78,[I],4),r("NoSpaceBetweenYieldKeywordAndStar",124,41,[W,ue],16),r("SpaceBetweenYieldOrYieldStarAndOperand",[124,41],D,[W,ue],4),r("NoSpaceBetweenReturnAndSemicolon",104,26,[W],16),r("SpaceAfterCertainKeywords",[112,108,102,88,104,111,130],D,[W],4),r("SpaceAfterLetConstInVariableDeclaration",[118,84],D,[W,ne],4),r("NoSpaceBeforeOpenParenInFuncCall",D,20,[W,B,U],16),r("SpaceBeforeBinaryKeywordOperator",D,ee,[W,g],4),r("SpaceAfterBinaryKeywordOperator",ee,D,[W,g],4),r("SpaceAfterVoidOperator",113,D,[W,le],4),r("SpaceBetweenAsyncAndOpenParen",129,20,[K,W],4),r("SpaceBetweenAsyncAndFunctionKeyword",129,[97,78],[W],4),r("NoSpaceBetweenTagAndTemplateString",[78,21],[14,15],[W],16),r("SpaceBeforeJsxAttribute",D,78,[X,W],4),r("SpaceBeforeSlashInJsxOpeningElement",D,43,[Q,W],4),r("NoSpaceBeforeGreaterThanTokenInJsxOpeningElement",43,31,[Q,W],16),r("NoSpaceBeforeEqualInJsxAttribute",D,62,[Y,W],16),r("NoSpaceAfterEqualInJsxAttribute",62,D,[Y,W],16),r("NoSpaceAfterModuleImport",[139,143],20,[W],16),r("SpaceAfterCertainTypeScriptKeywords",[125,83,133,87,91,92,93,134,116,99,117,139,140,120,122,121,142,146,123,149,153,138,135],D,[W],4),r("SpaceBeforeCertainTypeScriptKeywords",D,[93,116,153],[W],4),r("SpaceAfterModuleName",10,18,[re],4),r("SpaceBeforeArrow",D,38,[W],4),r("SpaceAfterArrow",38,D,[W],4),r("NoSpaceAfterEllipsis",25,78,[W],16),r("NoSpaceAfterOptionalParameters",57,[21,27],[W,y],16),r("NoSpaceBetweenEmptyInterfaceBraceBrackets",18,19,[W,ae],16),r("NoSpaceBeforeOpenAngularBracket",Ee,29,[W,se],16),r("NoSpaceBetweenCloseParenAndAngularBracket",21,29,[W,se],16),r("NoSpaceAfterOpenAngularBracket",29,D,[W,se],16),r("NoSpaceBeforeCloseAngularBracket",D,31,[W,se],16),r("NoSpaceAfterCloseAngularBracket",31,[20,22,31,27],[W,se,N],16),r("SpaceBeforeAt",[21,78],59,[W],4),r("NoSpaceAfterAt",59,D,[W],16),r("SpaceAfterDecorator",D,[125,78,92,87,83,123,122,120,121,134,146,22,41],[$],4),r("NoSpaceBeforeNonNullAssertionOperator",D,53,[W,de],16),r("NoSpaceAfterNewKeywordOnConstructorSignature",102,20,[W,ie],16),r("SpaceLessThanAndNonJSXTypeAnnotation",29,29,[W],4)],De=[r("SpaceAfterConstructor",132,20,[l("insertSpaceAfterConstructor"),W],4),r("NoSpaceAfterConstructor",132,20,[d("insertSpaceAfterConstructor"),W],16),r("SpaceAfterComma",27,D,[l("insertSpaceAfterCommaDelimiter"),W,q,V,j],4),r("NoSpaceAfterComma",27,D,[d("insertSpaceAfterCommaDelimiter"),W,q],16),r("SpaceAfterAnonymousFunctionKeyword",[97,41],20,[l("insertSpaceAfterFunctionKeywordForAnonymousFunctions"),I],4),r("NoSpaceAfterAnonymousFunctionKeyword",[97,41],20,[d("insertSpaceAfterFunctionKeywordForAnonymousFunctions"),I],16),r("SpaceAfterKeywordInControl",F,20,[l("insertSpaceAfterKeywordsInControlFlowStatements"),P],4),r("NoSpaceAfterKeywordInControl",F,20,[d("insertSpaceAfterKeywordsInControlFlowStatements"),P],16),r("SpaceAfterOpenParen",20,D,[l("insertSpaceAfterOpeningAndBeforeClosingNonemptyParenthesis"),W],4),r("SpaceBeforeCloseParen",D,21,[l("insertSpaceAfterOpeningAndBeforeClosingNonemptyParenthesis"),W],4),r("SpaceBetweenOpenParens",20,20,[l("insertSpaceAfterOpeningAndBeforeClosingNonemptyParenthesis"),W],4),r("NoSpaceBetweenParens",20,21,[W],16),r("NoSpaceAfterOpenParen",20,D,[d("insertSpaceAfterOpeningAndBeforeClosingNonemptyParenthesis"),W],16),r("NoSpaceBeforeCloseParen",D,21,[d("insertSpaceAfterOpeningAndBeforeClosingNonemptyParenthesis"),W],16),r("SpaceAfterOpenBracket",22,D,[l("insertSpaceAfterOpeningAndBeforeClosingNonemptyBrackets"),W],4),r("SpaceBeforeCloseBracket",D,23,[l("insertSpaceAfterOpeningAndBeforeClosingNonemptyBrackets"),W],4),r("NoSpaceBetweenBrackets",22,23,[W],16),r("NoSpaceAfterOpenBracket",22,D,[d("insertSpaceAfterOpeningAndBeforeClosingNonemptyBrackets"),W],16),r("NoSpaceBeforeCloseBracket",D,23,[d("insertSpaceAfterOpeningAndBeforeClosingNonemptyBrackets"),W],16),r("SpaceAfterOpenBrace",18,D,[f("insertSpaceAfterOpeningAndBeforeClosingNonemptyBraces"),T],4),r("SpaceBeforeCloseBrace",D,19,[f("insertSpaceAfterOpeningAndBeforeClosingNonemptyBraces"),T],4),r("NoSpaceBetweenEmptyBraceBrackets",18,19,[W,M],16),r("NoSpaceAfterOpenBrace",18,D,[u("insertSpaceAfterOpeningAndBeforeClosingNonemptyBraces"),W],16),r("NoSpaceBeforeCloseBrace",D,19,[u("insertSpaceAfterOpeningAndBeforeClosingNonemptyBraces"),W],16),r("SpaceBetweenEmptyBraceBrackets",18,19,[l("insertSpaceAfterOpeningAndBeforeClosingEmptyBraces")],4),r("NoSpaceBetweenEmptyBraceBrackets",18,19,[u("insertSpaceAfterOpeningAndBeforeClosingEmptyBraces"),W],16),r("SpaceAfterTemplateHeadAndMiddle",[15,16],D,[l("insertSpaceAfterOpeningAndBeforeClosingTemplateStringBraces"),z],4,1),r("SpaceBeforeTemplateMiddleAndTail",D,[16,17],[l("insertSpaceAfterOpeningAndBeforeClosingTemplateStringBraces"),W],4),r("NoSpaceAfterTemplateHeadAndMiddle",[15,16],D,[d("insertSpaceAfterOpeningAndBeforeClosingTemplateStringBraces"),z],16,1),r("NoSpaceBeforeTemplateMiddleAndTail",D,[16,17],[d("insertSpaceAfterOpeningAndBeforeClosingTemplateStringBraces"),W],16),r("SpaceAfterOpenBraceInJsxExpression",18,D,[l("insertSpaceAfterOpeningAndBeforeClosingJsxExpressionBraces"),W,J],4),r("SpaceBeforeCloseBraceInJsxExpression",D,19,[l("insertSpaceAfterOpeningAndBeforeClosingJsxExpressionBraces"),W,J],4),r("NoSpaceAfterOpenBraceInJsxExpression",18,D,[d("insertSpaceAfterOpeningAndBeforeClosingJsxExpressionBraces"),W,J],16),r("NoSpaceBeforeCloseBraceInJsxExpression",D,19,[d("insertSpaceAfterOpeningAndBeforeClosingJsxExpressionBraces"),W,J],16),r("SpaceAfterSemicolonInFor",26,D,[l("insertSpaceAfterSemicolonInForStatements"),W,m],4),r("NoSpaceAfterSemicolonInFor",26,D,[d("insertSpaceAfterSemicolonInForStatements"),W,m],16),r("SpaceBeforeBinaryOperator",D,G,[l("insertSpaceBeforeAndAfterBinaryOperators"),W,g],4),r("SpaceAfterBinaryOperator",G,D,[l("insertSpaceBeforeAndAfterBinaryOperators"),W,g],4),r("NoSpaceBeforeBinaryOperator",D,G,[d("insertSpaceBeforeAndAfterBinaryOperators"),W,g],16),r("NoSpaceAfterBinaryOperator",G,D,[d("insertSpaceBeforeAndAfterBinaryOperators"),W,g],16),r("SpaceBeforeOpenParenInFuncDecl",D,20,[l("insertSpaceBeforeFunctionParenthesis"),W,I],4),r("NoSpaceBeforeOpenParenInFuncDecl",D,20,[d("insertSpaceBeforeFunctionParenthesis"),W,I],16),r("NewLineBeforeOpenBraceInControl",xe,18,[l("placeOpenBraceOnNewLineForControlBlocks"),P,S],8,1),r("NewLineBeforeOpenBraceInFunction",Te,18,[l("placeOpenBraceOnNewLineForFunctions"),I,S],8,1),r("NewLineBeforeOpenBraceInTypeScriptDeclWithBlock",Se,18,[l("placeOpenBraceOnNewLineForFunctions"),R,S],8,1),r("SpaceAfterTypeAssertion",31,D,[l("insertSpaceAfterTypeAssertion"),W,ce],4),r("NoSpaceAfterTypeAssertion",31,D,[d("insertSpaceAfterTypeAssertion"),W,ce],16),r("SpaceBeforeTypeAnnotation",D,[57,58],[l("insertSpaceBeforeTypeAnnotation"),W,v],4),r("NoSpaceBeforeTypeAnnotation",D,[57,58],[d("insertSpaceBeforeTypeAnnotation"),W,v],16),r("NoOptionalSemicolon",26,O,[c("semicolons",e.SemicolonPreference.Remove),me],32),r("OptionalSemicolon",D,O,[c("semicolons",e.SemicolonPreference.Insert),_e],64)],Ae=[r("NoSpaceBeforeSemicolon",D,26,[W],16),r("SpaceBeforeOpenBraceInControl",xe,18,[p("placeOpenBraceOnNewLineForControlBlocks"),P,te,E],4,1),r("SpaceBeforeOpenBraceInFunction",Te,18,[p("placeOpenBraceOnNewLineForFunctions"),I,A,te,E],4,1),r("SpaceBeforeOpenBraceInTypeScriptDeclWithBlock",Se,18,[p("placeOpenBraceOnNewLineForFunctions"),R,te,E],4,1),r("NoSpaceBeforeComma",D,27,[W],16),r("NoSpaceBeforeOpenBracket",L(129,81),22,[W],16),r("NoSpaceAfterCloseBracket",23,D,[W,Z],16),r("SpaceAfterSemicolon",26,D,[W],4),r("SpaceBetweenForAndAwaitKeyword",96,130,[W],4),r("SpaceBetweenStatements",[21,89,90,81],D,[W,q,_],4),r("SpaceAfterTryCatchFinally",[110,82,95],18,[W],4)];return i(i(i([],Le),De),Ae)}function r(e,n,t,r,a,i){return void 0===i&&(i=0),{leftTokenRange:o(n),rightTokenRange:o(t),rule:{debugName:e,context:r,action:a,flags:i}}}function a(e){return{tokens:e,isSpecific:!0}}function o(n){return"number"===typeof n?a([n]):e.isArray(n)?a(n):n}function s(n,t,r){void 0===r&&(r=[]);for(var i=[],o=n;o<=t;o++)e.contains(r,o)||i.push(o);return a(i)}function c(e,n){return function(t){return t.options&&t.options[e]===n}}function l(e){return function(n){return n.options&&n.options.hasOwnProperty(e)&&!!n.options[e]}}function u(e){return function(n){return n.options&&n.options.hasOwnProperty(e)&&!n.options[e]}}function d(e){return function(n){return!n.options||!n.options.hasOwnProperty(e)||!n.options[e]}}function p(e){return function(n){return!n.options||!n.options.hasOwnProperty(e)||!n.options[e]||n.TokensAreOnSameLine()}}function f(e){return function(n){return!n.options||!n.options.hasOwnProperty(e)||!!n.options[e]}}function m(e){return 238===e.contextNode.kind}function _(e){return!m(e)}function g(e){switch(e.contextNode.kind){case 217:return 27!==e.contextNode.operatorToken.kind;case 218:case 185:case 225:case 271:case 266:case 173:case 183:case 184:return!0;case 199:case 255:case 261:case 250:case 161:case 292:case 164:case 163:return 62===e.currentTokenSpan.kind||62===e.nextTokenSpan.kind;case 239:case 160:return 100===e.currentTokenSpan.kind||100===e.nextTokenSpan.kind||62===e.currentTokenSpan.kind||62===e.nextTokenSpan.kind;case 240:return 157===e.currentTokenSpan.kind||157===e.nextTokenSpan.kind}return!1}function y(e){return!g(e)}function h(e){return!v(e)}function v(n){var t=n.contextNode.kind;return 164===t||163===t||161===t||250===t||e.isFunctionLikeKind(t)}function b(e){return 218===e.contextNode.kind||185===e.contextNode.kind}function E(e){return e.TokensAreOnSameLine()||A(e)}function T(e){return 197===e.contextNode.kind||191===e.contextNode.kind||L(e)}function S(e){return A(e)&&!(e.NextNodeAllOnSameLine()||e.NextNodeBlockIsOnOneLine())}function x(e){return D(e)&&!(e.ContextNodeAllOnSameLine()||e.ContextNodeBlockIsOnOneLine())}function L(e){return D(e)&&(e.ContextNodeAllOnSameLine()||e.ContextNodeBlockIsOnOneLine())}function D(e){return C(e.contextNode)}function A(e){return C(e.nextTokenParent)}function C(e){if(O(e))return!0;switch(e.kind){case 231:case 259:case 201:case 258:return!0}return!1}function I(e){switch(e.contextNode.kind){case 252:case 166:case 165:case 168:case 169:case 170:case 209:case 167:case 210:case 254:return!0}return!1}function N(e){return!I(e)}function k(e){return 252===e.contextNode.kind||209===e.contextNode.kind}function R(e){return O(e.contextNode)}function O(e){switch(e.kind){case 253:case 222:case 254:case 256:case 178:case 257:case 268:case 269:case 262:case 265:return!0}return!1}function w(e){switch(e.currentTokenParent.kind){case 253:case 257:case 256:case 288:case 258:case 245:return!0;case 231:var n=e.currentTokenParent.parent;if(!n||210!==n.kind&&209!==n.kind)return!0}return!1}function P(e){switch(e.contextNode.kind){case 235:case 245:case 238:case 239:case 240:case 237:case 248:case 236:case 244:case 288:return!0;default:return!1}}function M(e){return 201===e.contextNode.kind}function F(e){return 204===e.contextNode.kind}function G(e){return 205===e.contextNode.kind}function B(e){return F(e)||G(e)}function U(e){return 27!==e.currentTokenSpan.kind}function V(e){return 23!==e.nextTokenSpan.kind}function j(e){return 21!==e.nextTokenSpan.kind}function K(e){return 210===e.contextNode.kind}function H(e){return 196===e.contextNode.kind}function W(e){return e.TokensAreOnSameLine()&&11!==e.contextNode.kind}function z(e){return 11!==e.contextNode.kind}function q(e){return 274!==e.contextNode.kind&&278!==e.contextNode.kind}function J(e){return 284===e.contextNode.kind||283===e.contextNode.kind}function X(e){return 281===e.nextTokenParent.kind}function Y(e){return 281===e.contextNode.kind}function Q(e){return 275===e.contextNode.kind}function Z(e){return!I(e)&&!A(e)}function $(e){return e.TokensAreOnSameLine()&&!!e.contextNode.decorators&&ee(e.currentTokenParent)&&!ee(e.nextTokenParent)}function ee(n){while(e.isExpressionNode(n))n=n.parent;return 162===n.kind}function ne(e){return 251===e.currentTokenParent.kind&&e.currentTokenParent.getStart(e.sourceFile)===e.currentTokenSpan.pos}function te(e){return 2!==e.formattingRequestKind}function re(e){return 257===e.contextNode.kind}function ae(e){return 178===e.contextNode.kind}function ie(e){return 171===e.contextNode.kind}function oe(e,n){if(29!==e.kind&&31!==e.kind)return!1;switch(n.kind){case 174:case 207:case 255:case 253:case 222:case 254:case 252:case 209:case 210:case 166:case 165:case 170:case 171:case 204:case 205:case 224:return!0;default:return!1}}function se(e){return oe(e.currentTokenSpan,e.currentTokenParent)||oe(e.nextTokenSpan,e.nextTokenParent)}function ce(e){return 207===e.contextNode.kind}function le(e){return 113===e.currentTokenSpan.kind&&213===e.currentTokenParent.kind}function ue(e){return 220===e.contextNode.kind&&void 0!==e.contextNode.expression}function de(e){return 226===e.contextNode.kind}function pe(e){return!fe(e)}function fe(e){switch(e.contextNode.kind){case 235:case 238:case 239:case 240:case 236:case 237:return!0;default:return!1}}function me(n){var t=n.nextTokenSpan.kind,r=n.nextTokenSpan.pos;if(e.isTrivia(t)){var a=n.nextTokenParent===n.currentTokenParent?e.findNextToken(n.currentTokenParent,e.findAncestor(n.currentTokenParent,(function(e){return!e.parent})),n.sourceFile):n.nextTokenParent.getFirstToken(n.sourceFile);if(!a)return!0;t=a.kind,r=a.getStart(n.sourceFile)}var i=n.sourceFile.getLineAndCharacterOfPosition(n.currentTokenSpan.pos).line,o=n.sourceFile.getLineAndCharacterOfPosition(r).line;return i===o?19===t||1===t:230!==t&&26!==t&&(254===n.contextNode.kind||255===n.contextNode.kind?!e.isPropertySignature(n.currentTokenParent)||!!n.currentTokenParent.type||20!==t:e.isPropertyDeclaration(n.currentTokenParent)?!n.currentTokenParent.initializer:238!==n.currentTokenParent.kind&&232!==n.currentTokenParent.kind&&230!==n.currentTokenParent.kind&&22!==t&&20!==t&&39!==t&&40!==t&&43!==t&&13!==t&&27!==t&&219!==t&&15!==t&&14!==t&&24!==t)}function _e(n){return e.positionIsASICandidate(n.currentTokenSpan.end,n.currentTokenParent,n.sourceFile)}n.getAllRules=t})(e.formatting||(e.formatting={}))}(d||(d={})),function(e){(function(n){function t(e,n){return{options:e,getRules:a(),host:n}}var r;function a(){return void 0===r&&(r=o(n.getAllRules())),r}function i(e){var n=0;return 1&e&&(n|=28),2&e&&(n|=96),28&e&&(n|=28),96&e&&(n|=96),n}function o(n){var t=s(n);return function(n){var r=t[c(n.currentTokenSpan.kind,n.nextTokenSpan.kind)];if(r){for(var a=[],o=0,s=0,l=r;s<l.length;s++){var u=l[s],d=~i(o);u.action&d&&e.every(u.context,(function(e){return e(n)}))&&(a.push(u),o|=u.action)}if(a.length)return a}}}function s(e){for(var n=new Array(p*p),t=new Array(n.length),r=0,a=e;r<a.length;r++)for(var i=a[r],o=i.leftTokenRange.isSpecific&&i.rightTokenRange.isSpecific,s=0,l=i.leftTokenRange.tokens;s<l.length;s++)for(var u=l[s],d=0,m=i.rightTokenRange.tokens;d<m.length;d++){var _=m[d],g=c(u,_),y=n[g];void 0===y&&(y=n[g]=[]),f(y,i.rule,o,t,g)}return n}function c(n,t){return e.Debug.assert(n<=157&&t<=157,"Must compute formatting context from tokens"),n*p+t}n.getFormatContext=t;var l,u=5,d=31,p=158;function f(e,t,r,a,i){var o=3&t.action?r?l.StopRulesSpecific:l.StopRulesAny:t.context!==n.anyContext?r?l.ContextRulesSpecific:l.ContextRulesAny:r?l.NoContextRulesSpecific:l.NoContextRulesAny,s=a[i]||0;e.splice(m(s,o),0,t),a[i]=_(s,o)}function m(e,n){for(var t=0,r=0;r<=n;r+=u)t+=e&d,e>>=u;return t}function _(n,t){var r=1+(n>>t&d);return e.Debug.assert((r&d)===r,"Adding more rules into the sub-bucket than allowed. Maximum allowed is 32 rules."),n&~(d<<t)|r<<t}(function(e){e[e["StopRulesSpecific"]=0]="StopRulesSpecific",e[e["StopRulesAny"]=1*u]="StopRulesAny",e[e["ContextRulesSpecific"]=2*u]="ContextRulesSpecific",e[e["ContextRulesAny"]=3*u]="ContextRulesAny",e[e["NoContextRulesSpecific"]=4*u]="NoContextRulesSpecific",e[e["NoContextRulesAny"]=5*u]="NoContextRulesAny"})(l||(l={}))})(e.formatting||(e.formatting={}))}(d||(d={})),function(e){(function(n){function t(n,t,r){var a={pos:n,end:t,kind:r};return e.Debug.isDebugging&&Object.defineProperty(a,"__debugKind",{get:function(){return e.Debug.formatSyntaxKind(r)}}),a}var r,a,i,o,s;function c(n,t,r){var a=t.getLineAndCharacterOfPosition(n).line;if(0===a)return[];var i=e.getEndLinePosition(a,t);while(e.isWhiteSpaceSingleLine(t.text.charCodeAt(i)))i--;e.isLineBreak(t.text.charCodeAt(i))&&i--;var o={pos:e.getStartPositionOfLine(a-1,t),end:i+1};return S(o,t,r,2)}function l(e,n,t){var r=m(e,26,n);return T(_(r),n,t,3)}function u(n,t,r){var a=m(n,18,t);if(!a)return[];var i=a.parent,o=_(i),s={pos:e.getLineStartPositionForPosition(o.getStart(t),t),end:n};return S(s,t,r,4)}function d(e,n,t){var r=m(e,19,n);return T(_(r),n,t,5)}function p(e,n){var t={pos:0,end:e.text.length};return S(t,e,n,0)}function f(n,t,r,a){var i={pos:e.getLineStartPositionForPosition(n,r),end:t};return S(i,r,a,1)}function m(n,t,r){var a=e.findPrecedingToken(n,r);return a&&a.kind===t&&n===a.getEnd()?a:void 0}function _(e){var n=e;while(n&&n.parent&&n.parent.end===e.end&&!g(n.parent,n))n=n.parent;return n}function g(n,t){switch(n.kind){case 253:case 254:return e.rangeContainsRange(n.members,t);case 257:var r=n.body;return!!r&&258===r.kind&&e.rangeContainsRange(r.statements,t);case 298:case 231:case 258:return e.rangeContainsRange(n.statements,t);case 288:return e.rangeContainsRange(n.block.statements,t)}return!1}function y(n,t){return r(t);function r(a){var i=e.forEachChild(a,(function(r){return e.startEndContainsRange(r.getStart(t),r.end,n)&&r}));if(i){var o=r(i);if(o)return o}return a}}function h(n,t){if(!n.length)return i;var r=n.filter((function(n){return e.rangeOverlapsWithStartEnd(t,n.start,n.start+n.length)})).sort((function(e,n){return e.start-n.start}));if(!r.length)return i;var a=0;return function(n){while(1){if(a>=r.length)return!1;var t=r[a];if(n.end<=t.start)return!1;if(e.startEndOverlapsWithStartEnd(n.pos,n.end,t.start,t.start+t.length))return!0;a++}};function i(){return!1}}function v(n,t,r){var a=n.getStart(r);if(a===t.pos&&n.end===t.end)return a;var i=e.findPrecedingToken(t.pos,r);return i?i.end>=t.pos?n.pos:i.end:n.pos}function b(e,t,r){var a,i=-1;while(e){var o=r.getLineAndCharacterOfPosition(e.getStart(r)).line;if(-1!==i&&o!==i)break;if(n.SmartIndenter.shouldIndentChildNode(t,e,a,r))return t.indentSize;i=o,a=e,e=e.parent}return 0}function E(e,t,r,a,i,o){var s={pos:0,end:t.text.length};return n.getFormattingScanner(t.text,r,s.pos,s.end,(function(n){return x(s,e,a,i,n,o,1,(function(e){return!1}),t)}))}function T(n,t,r,a){if(!n)return[];var i={pos:e.getLineStartPositionForPosition(n.getStart(t),t),end:n.end};return S(i,t,r,a)}function S(e,t,r,a){var i=y(e,t);return n.getFormattingScanner(t.text,t.languageVariant,v(i,e,t),e.end,(function(o){return x(e,i,n.SmartIndenter.getIndentationForNode(i,e,t,r.options),b(i,r.options,t),o,r,a,h(t.parseDiagnostics,e),t)}))}function x(t,r,a,i,o,s,c,l,u){var d,p,f,m,_=s.options,g=s.getRules,y=s.host,h=new n.FormattingContext(u,c,_),v=-1,b=[];if(o.advance(),o.isOnToken()){var E=u.getLineAndCharacterOfPosition(r.getStart(u)).line,T=E;r.decorators&&(T=u.getLineAndCharacterOfPosition(e.getNonDecoratorTokenPosOfNode(r,u)).line),R(r,r,E,T,a,i)}if(!o.isOnToken()){var S=n.SmartIndenter.nodeWillIndentChild(_,r,void 0,u,!1)?a+_.indentSize:a,x=o.getCurrentLeadingTrivia();x&&O(x,S,!1,(function(e){return P(e,u.getLineAndCharacterOfPosition(e.pos),r,r,void 0)}))}return!1!==_.trimTrailingWhitespace&&K(),b;function L(t,r,a,i,o){if(e.rangeOverlapsWithStartEnd(i,t,r)||e.rangeContainsStartEnd(i,t,r)){if(-1!==o)return o}else{var s=u.getLineAndCharacterOfPosition(t).line,c=e.getLineStartPositionForPosition(t,u),l=n.SmartIndenter.findFirstNonWhitespaceColumn(c,t,u,_);if(s!==a||t===l){var d=n.SmartIndenter.getBaseIndentation(_);return d>l?d:l}}return-1}function I(e,t,r,a,i,o){var s=n.SmartIndenter.shouldIndentChildNode(_,e)?_.indentSize:0;return o===t?{indentation:t===m?v:i.getIndentation(),delta:Math.min(_.indentSize,i.getDelta(e)+s)}:-1===r?20===e.kind&&t===m?{indentation:v,delta:i.getDelta(e)}:n.SmartIndenter.childStartsOnTheSameLineWithElseInIfStatement(a,e,t,u)||n.SmartIndenter.childIsUnindentedBranchOfConditionalExpression(a,e,t,u)||n.SmartIndenter.argumentStartsOnSameLineAsPreviousArgument(a,e,t,u)?{indentation:i.getIndentation(),delta:s}:{indentation:i.getIndentation()+i.getDelta(e),delta:s}:{indentation:r,delta:s}}function N(n){if(n.modifiers&&n.modifiers.length)return n.modifiers[0].kind;switch(n.kind){case 253:return 83;case 254:return 117;case 252:return 97;case 256:return 256;case 168:return 134;case 169:return 146;case 166:if(n.asteriskToken)return 41;case 164:case 161:var t=e.getNameOfDeclaration(n);if(t)return t.kind}}function k(e,t,r,a){return{getIndentationForComment:function(e,n,t){switch(e){case 19:case 23:case 21:return r+o(t)}return-1!==n?n:r},getIndentationForToken:function(e,n,t,a){return!a&&i(e,n,t)?r+o(t):r},getIndentation:function(){return r},getDelta:o,recomputeIndentation:function(t,i){n.SmartIndenter.shouldIndentChildNode(_,i,e,u)&&(r+=t?_.indentSize:-_.indentSize,a=n.SmartIndenter.shouldIndentChildNode(_,e)?_.indentSize:0)}};function i(n,r,a){switch(r){case 18:case 19:case 21:case 90:case 114:case 59:return!1;case 43:case 31:switch(a.kind){case 276:case 277:case 275:case 224:return!1}break;case 22:case 23:if(191!==a.kind)return!1;break}return t!==n&&!(e.decorators&&r===N(e))}function o(t){return n.SmartIndenter.nodeWillIndentChild(_,e,t,u,!0)?a:0}}function R(r,a,i,s,c,g){if(e.rangeOverlapsWithStartEnd(t,r.getStart(u),r.getEnd())){var y=k(r,i,c,g),h=a;e.forEachChild(r,(function(e){T(e,-1,r,y,i,s,!1)}),(function(e){S(e,r,i,y)}));while(o.isOnToken()){var b=o.readTokenInfo(r);if(b.token.end>r.end)break;x(b,r,y,r)}if(!r.parent&&o.isOnEOF()){var E=o.readEOFTokenRange();E.end<=r.end&&d&&M(E,u.getLineAndCharacterOfPosition(E.pos).line,r,d,f,p,a,y)}}function T(n,a,i,s,c,l,d,p){var f=n.getStart(u),m=u.getLineAndCharacterOfPosition(f).line,_=m;n.decorators&&(_=u.getLineAndCharacterOfPosition(e.getNonDecoratorTokenPosOfNode(n,u)).line);var g=-1;if(d&&e.rangeContainsRange(t,i)&&(g=L(f,n.end,c,t,a),-1!==g&&(a=g)),!e.rangeOverlapsWithStartEnd(t,n.pos,n.end))return n.end<t.pos&&o.skipToEndOf(n),a;if(0===n.getFullWidth())return a;while(o.isOnToken()){var y=o.readTokenInfo(r);if(y.token.end>f){y.token.pos>f&&o.skipToStartOf(n);break}x(y,r,s,r)}if(!o.isOnToken())return a;if(e.isToken(n)){y=o.readTokenInfo(n);if(11!==n.kind)return e.Debug.assert(y.token.end===n.end,"Token end is child end"),x(y,r,s,n),a}var v=162===n.kind?m:l,b=I(n,m,g,r,s,v);return R(n,h,m,_,b.indentation,b.delta),h=r,p&&200===i.kind&&-1===a&&(a=b.indentation),a}function S(t,a,i,s){e.Debug.assert(e.isNodeArray(t));var c=D(a,t),l=s,d=i;if(0!==c)while(o.isOnToken()){var p=o.readTokenInfo(a);if(p.token.end>t.pos)break;if(p.token.kind===c){d=u.getLineAndCharacterOfPosition(p.token.pos).line,x(p,a,s,a);var f=void 0;if(-1!==v)f=v;else{var m=e.getLineStartPositionForPosition(p.token.pos,u);f=n.SmartIndenter.findFirstNonWhitespaceColumn(m,p.token.pos,u,_)}l=k(a,i,f,_.indentSize)}else x(p,a,s,a)}for(var g=-1,y=0;y<t.length;y++){var h=t[y];g=T(h,g,r,l,d,d,!0,0===y)}var b=A(c);if(0!==b&&o.isOnToken()){p=o.readTokenInfo(a);if(27===p.token.kind&&e.isCallLikeExpression(a)){var E=u.getLineAndCharacterOfPosition(p.token.pos).line;d!==E&&(o.advance(),p=o.isOnToken()?o.readTokenInfo(a):void 0)}p&&p.token.kind===b&&e.rangeContainsRange(a,p.token)&&x(p,a,l,a,!0)}}function x(n,r,a,i,s){e.Debug.assert(e.rangeContainsRange(r,n.token));var c=o.lastTrailingTriviaWasNewLine(),p=!1;n.leadingTrivia&&w(n.leadingTrivia,r,h,a);var f=0,_=e.rangeContainsRange(t,n.token),g=u.getLineAndCharacterOfPosition(n.token.pos);if(_){var y=l(n.token),b=d;if(f=P(n.token,g,r,h,a),!y)if(0===f){var E=b&&u.getLineAndCharacterOfPosition(b.end).line;p=c&&g.line!==E}else p=1===f}if(n.trailingTrivia&&w(n.trailingTrivia,r,h,a),p){var T=_&&!l(n.token)?a.getIndentationForToken(g.line,n.token.kind,i,!!s):-1,S=!0;if(n.leadingTrivia){var x=a.getIndentationForComment(n.token.kind,T,i);S=O(n.leadingTrivia,x,S,(function(e){return F(e.pos,x,!1)}))}-1!==T&&S&&(F(n.token.pos,T,1===f),m=g.line,v=T)}o.advance(),h=r}}function O(n,r,a,i){for(var o=0,s=n;o<s.length;o++){var c=s[o],l=e.rangeContainsRange(t,c);switch(c.kind){case 3:l&&U(c,r,!a),a=!1;break;case 2:a&&l&&i(c),a=!1;break;case 4:a=!0;break}}return a}function w(n,r,a,i){for(var o=0,s=n;o<s.length;o++){var c=s[o];if(e.isComment(c.kind)&&e.rangeContainsRange(t,c)){var l=u.getLineAndCharacterOfPosition(c.pos);P(c,l,r,a,i)}}}function P(e,n,r,a,i){var o=l(e),s=0;if(!o)if(d)s=M(e,n.line,r,d,f,p,a,i);else{var c=u.getLineAndCharacterOfPosition(t.pos);V(c.line,n.line)}return d=e,p=r,f=n.line,s}function M(n,t,r,a,i,o,s,c){h.updateContext(a,o,n,r,s);var l=g(h),d=!1!==h.options.trimTrailingWhitespace,p=0;return l?e.forEachRight(l,(function(o){switch(p=q(o,a,i,n,t),p){case 2:r.getStart(u)===n.pos&&c.recomputeIndentation(!1,s);break;case 1:r.getStart(u)===n.pos&&c.recomputeIndentation(!0,s);break;default:e.Debug.assert(0===p)}d=d&&!(16&o.action)&&1!==o.flags})):d=d&&1!==n.kind,t!==i&&d&&V(i,t,a),p}function F(n,t,r){var a=C(t,_);if(r)W(n,0,a);else{var i=u.getLineAndCharacterOfPosition(n),o=e.getStartPositionOfLine(i.line,u);(t!==G(o,i.character)||B(a,o))&&W(o,i.character,a)}}function G(e,n){for(var t=0,r=0;r<n;r++)9===u.text.charCodeAt(e+r)?t+=_.tabSize-t%_.tabSize:t++;return t}function B(e,n){return e!==u.text.substr(n,e.length)}function U(t,r,a,i){void 0===i&&(i=!0);var o=u.getLineAndCharacterOfPosition(t.pos).line,s=u.getLineAndCharacterOfPosition(t.end).line;if(o!==s){for(var c=[],l=t.pos,d=o;d<s;d++){var p=e.getEndLinePosition(d,u);c.push({pos:l,end:p}),l=e.getStartPositionOfLine(d+1,u)}if(i&&c.push({pos:l,end:t.end}),0!==c.length){var f=e.getStartPositionOfLine(o,u),m=n.SmartIndenter.findFirstNonWhitespaceCharacterAndColumn(f,c[0].pos,u,_),g=0;a&&(g=1,o++);for(var y=r-m.column,h=g;h<c.length;h++,o++){var v=e.getStartPositionOfLine(o,u),b=0===h?m:n.SmartIndenter.findFirstNonWhitespaceCharacterAndColumn(c[h].pos,c[h].end,u,_),E=b.column+y;if(E>0){var T=C(E,_);W(v,b.character,T)}else H(v,b.character)}}}else a||F(t.pos,r,!1)}function V(n,t,r){for(var a=n;a<t;a++){var i=e.getStartPositionOfLine(a,u),o=e.getEndLinePosition(a,u);if(!(r&&(e.isComment(r.kind)||e.isStringOrRegularExpressionOrTemplateLiteral(r.kind))&&r.pos<=o&&r.end>o)){var s=j(i,o);-1!==s&&(e.Debug.assert(s===i||!e.isWhiteSpaceSingleLine(u.text.charCodeAt(s-1))),H(s,o+1-s))}}}function j(n,t){var r=t;while(r>=n&&e.isWhiteSpaceSingleLine(u.text.charCodeAt(r)))r--;return r!==t?r+1:-1}function K(){var e=d?d.end:t.pos,n=u.getLineAndCharacterOfPosition(e).line,r=u.getLineAndCharacterOfPosition(t.end).line;V(n,r+1,d)}function H(n,t){t&&b.push(e.createTextChangeFromStartLength(n,t,""))}function W(n,t,r){(t||r)&&b.push(e.createTextChangeFromStartLength(n,t,r))}function z(n,t){t&&b.push(e.createTextChangeFromStartLength(n,0,t))}function q(n,t,r,a,i){var o=i!==r;switch(n.action){case 1:return 0;case 16:if(t.end!==a.pos)return H(t.end,a.pos-t.end),o?2:0;break;case 32:H(t.pos,t.end-t.pos);break;case 8:if(1!==n.flags&&r!==i)return 0;var s=i-r;if(1!==s)return W(t.end,a.pos-t.end,e.getNewLineOrDefaultFromHost(y,_)),o?0:1;break;case 4:if(1!==n.flags&&r!==i)return 0;var c=a.pos-t.end;if(1!==c||32!==u.text.charCodeAt(t.end))return W(t.end,a.pos-t.end," "),o?2:0;break;case 64:z(t.end,";")}return 0}}function L(n,t,r,a){void 0===a&&(a=e.getTokenAtPosition(n,t));var i=e.findAncestor(a,e.isJSDoc);i&&(a=i.parent);var o=a.getStart(n);if(!(o<=t&&t<a.getEnd())){r=null===r?void 0:void 0===r?e.findPrecedingToken(t,n):r;var s=r&&e.getTrailingCommentRanges(n.text,r.end),c=e.getLeadingCommentRangesOfNode(a,n),l=e.concatenate(s,c);return l&&e.find(l,(function(r){return e.rangeContainsPositionExclusive(r,t)||t===r.end&&(2===r.kind||t===n.getFullWidth())}))}}function D(e,n){switch(e.kind){case 167:case 252:case 209:case 166:case 165:case 210:if(e.typeParameters===n)return 29;if(e.parameters===n)return 20;break;case 204:case 205:if(e.typeArguments===n)return 29;if(e.arguments===n)return 20;break;case 174:if(e.typeArguments===n)return 29;break;case 178:return 18}return 0}function A(e){switch(e){case 20:return 21;case 29:return 31;case 18:return 19}return 0}function C(n,t){var r=!i||i.tabSize!==t.tabSize||i.indentSize!==t.indentSize;if(r&&(i={tabSize:t.tabSize,indentSize:t.indentSize},o=s=void 0),t.convertTabsToSpaces){var a=void 0,c=Math.floor(n/t.indentSize),l=n%t.indentSize;return s||(s=[]),void 0===s[c]?(a=e.repeatString(" ",t.indentSize*c),s[c]=a):a=s[c],l?a+e.repeatString(" ",l):a}var u=Math.floor(n/t.tabSize),d=n-u*t.tabSize,p=void 0;return o||(o=[]),void 0===o[u]?o[u]=p=e.repeatString("\t",u):p=o[u],d?p+e.repeatString(" ",d):p}n.createTextRangeWithKind=t,function(e){e[e["Unknown"]=-1]="Unknown"}(r||(r={})),n.formatOnEnter=c,n.formatOnSemicolon=l,n.formatOnOpeningCurly=u,n.formatOnClosingCurly=d,n.formatDocument=p,n.formatSelection=f,n.formatNodeGivenIndentation=E,function(e){e[e["None"]=0]="None",e[e["LineAdded"]=1]="LineAdded",e[e["LineRemoved"]=2]="LineRemoved"}(a||(a={})),n.getRangeOfEnclosingComment=L,n.getIndentationString=C})(e.formatting||(e.formatting={}))}(d||(d={})),function(e){(function(n){(function(t){var r,a;function i(t,r,a,i){if(void 0===i&&(i=!1),t>r.text.length)return u(a);if(a.indentStyle===e.IndentStyle.None)return 0;var l=e.findPrecedingToken(t,r,void 0,!0),d=n.getRangeOfEnclosingComment(r,t,l||null);if(d&&3===d.kind)return o(r,t,a,d);if(!l)return u(a);var p=e.isStringOrRegularExpressionOrTemplateLiteral(l.kind);if(p&&l.getStart(r)<=t&&t<l.end)return 0;var m=r.getLineAndCharacterOfPosition(t).line;if(a.indentStyle===e.IndentStyle.Block)return s(r,t,a);if(27===l.kind&&217!==l.parent.kind){var _=f(l,r,a);if(-1!==_)return _}var g=T(t,l.parent,r);return g&&!e.rangeContainsRange(g,l)?L(g,r,a)+a.indentSize:c(r,t,l,m,i,a)}function o(n,t,r,a){var i=e.getLineAndCharacterOfPosition(n,t).line-1,o=e.getLineAndCharacterOfPosition(n,a.pos).line;if(e.Debug.assert(o>=0),i<=o)return N(e.getStartPositionOfLine(o,n),t,n,r);var s=e.getStartPositionOfLine(i,n),c=I(s,t,n,r),l=c.column,u=c.character;if(0===l)return l;var d=n.text.charCodeAt(s+u);return 42===d?l-1:l}function s(n,t,r){var a=t;while(a>0){var i=n.text.charCodeAt(a);if(!e.isWhiteSpaceLike(i))break;a--}var o=e.getLineStartPositionForPosition(a,n);return N(o,a,n,r)}function c(n,t,r,a,i,o){var s,c=r;while(c){if(e.positionBelongsToNode(c,t,n)&&O(o,c,s,n,!0)){var l=g(c,n),p=_(r,c,a,n),f=0!==p?i&&2===p?o.indentSize:0:a!==l.line?o.indentSize:0;return d(c,l,void 0,f,n,!0,o)}var m=D(c,n,o,!0);if(-1!==m)return m;s=c,c=c.parent}return u(o)}function l(e,n,t,r){var a=t.getLineAndCharacterOfPosition(e.getStart(t));return d(e,a,n,0,t,!1,r)}function u(e){return e.baseIndentSize||0}function d(e,n,t,r,a,i,o){var s,c=e.parent;while(c){var l=!0;if(t){var d=e.getStart(a);l=d<t.pos||d>t.end}var f=p(c,e,a),_=f.line===n.line||h(c,e,n.line,a);if(l){var v=null===(s=E(e,a))||void 0===s?void 0:s[0],b=!!v&&g(v,a).line>f.line,T=D(e,a,o,b);if(-1!==T)return T+r;if(T=m(e,c,n,_,a,o),-1!==T)return T+r}O(o,c,e,a,i)&&!_&&(r+=o.indentSize);var S=y(c,e,n.line,a);e=c,c=e.parent,n=S?a.getLineAndCharacterOfPosition(e.getStart(a)):f}return r+u(o)}function p(e,n,t){var r=E(n,t),a=r?r.pos:e.getStart(t);return t.getLineAndCharacterOfPosition(a)}function f(n,t,r){var a=e.findListItemInfo(n);return a&&a.listItemIndex>0?A(a.list.getChildren(),a.listItemIndex-1,t,r):-1}function m(n,t,r,a,i,o){var s=(e.isDeclaration(n)||e.isStatementButNotDeclaration(n))&&(298===t.kind||!a);return s?C(r,i,o):-1}function _(n,t,r,a){var i=e.findNextToken(n,t,a);if(!i)return 0;if(18===i.kind)return 1;if(19===i.kind){var o=g(i,a).line;return r===o?2:0}return 0}function g(e,n){return n.getLineAndCharacterOfPosition(e.getStart(n))}function y(n,t,r,a){if(!e.isCallExpression(n)||!e.contains(n.arguments,t))return!1;var i=n.expression.getEnd(),o=e.getLineAndCharacterOfPosition(a,i).line;return o===r}function h(n,t,r,a){if(235===n.kind&&n.elseStatement===t){var i=e.findChildOfKind(n,90,a);e.Debug.assert(void 0!==i);var o=g(i,a).line;return o===r}return!1}function v(n,t,r,a){if(e.isConditionalExpression(n)&&(t===n.whenTrue||t===n.whenFalse)){var i=e.getLineAndCharacterOfPosition(a,n.condition.end).line;if(t===n.whenTrue)return r===i;var o=g(n.whenTrue,a).line,s=e.getLineAndCharacterOfPosition(a,n.whenTrue.end).line;return i===o&&s===r}return!1}function b(n,t,r,a){if(e.isCallOrNewExpression(n)){if(!n.arguments)return!1;var i=e.find(n.arguments,(function(e){return e.pos===t.pos}));if(!i)return!1;var o=n.arguments.indexOf(i);if(0===o)return!1;var s=n.arguments[o-1],c=e.getLineAndCharacterOfPosition(a,s.getEnd()).line;if(r===c)return!0}return!1}function E(e,n){return e.parent&&S(e.getStart(n),e.getEnd(),e.parent,n)}function T(e,n,t){return n&&S(e,e,n,t)}function S(n,t,r,a){switch(r.kind){case 174:return i(r.typeArguments);case 201:return i(r.properties);case 200:return i(r.elements);case 178:return i(r.members);case 252:case 209:case 210:case 166:case 165:case 170:case 167:case 176:case 171:return i(r.typeParameters)||i(r.parameters);case 253:case 222:case 254:case 255:case 334:return i(r.typeParameters);case 205:case 204:return i(r.typeArguments)||i(r.arguments);case 251:return i(r.declarations);case 265:case 269:return i(r.elements);case 197:case 198:return i(r.elements)}function i(i){return i&&e.rangeContainsStartEnd(x(r,i,a),n,t)?i:void 0}}function x(e,n,t){for(var r=e.getChildren(t),a=1;a<r.length-1;a++)if(r[a].pos===n.pos&&r[a].end===n.end)return{pos:r[a-1].end,end:r[a+1].getStart(t)};return n}function L(e,n,t){return e?C(n.getLineAndCharacterOfPosition(e.pos),n,t):-1}function D(e,n,t,r){if(e.parent&&251===e.parent.kind)return-1;var a=E(e,n);if(a){var i=a.indexOf(e);if(-1!==i){var o=A(a,i,n,t);if(-1!==o)return o}return L(a,n,t)+(r?t.indentSize:0)}return-1}function A(n,t,r,a){e.Debug.assert(t>=0&&t<n.length);for(var i=n[t],o=g(i,r),s=t-1;s>=0;s--)if(27!==n[s].kind){var c=r.getLineAndCharacterOfPosition(n[s].end).line;if(c!==o.line)return C(o,r,a);o=g(n[s],r)}return-1}function C(e,n,t){var r=n.getPositionOfLineAndCharacter(e.line,0);return N(r,r+e.character,n,t)}function I(n,t,r,a){for(var i=0,o=0,s=n;s<t;s++){var c=r.text.charCodeAt(s);if(!e.isWhiteSpaceSingleLine(c))break;9===c?o+=a.tabSize+o%a.tabSize:o++,i++}return{column:o,character:i}}function N(e,n,t,r){return I(e,n,t,r).column}function k(e,n,t,r,a){var i=t?t.kind:0;switch(n.kind){case 234:case 253:case 222:case 254:case 256:case 255:case 200:case 231:case 258:case 201:case 178:case 191:case 180:case 259:case 286:case 285:case 208:case 202:case 204:case 205:case 233:case 267:case 243:case 218:case 198:case 197:case 276:case 279:case 275:case 284:case 165:case 170:case 171:case 161:case 175:case 176:case 187:case 206:case 214:case 269:case 265:case 271:case 266:case 164:return!0;case 250:case 289:case 217:if(!e.indentMultiLineObjectLiteralBeginningOnBlankLine&&r&&201===i)return w(r,t);if(217!==n.kind)return!0;break;case 236:case 237:case 239:case 240:case 238:case 235:case 252:case 209:case 166:case 167:case 168:case 169:return 231!==i;case 210:return r&&208===i?w(r,t):231!==i;case 268:return 269!==i;case 262:return 263!==i||!!t.namedBindings&&265!==t.namedBindings.kind;case 274:return 277!==i;case 278:return 280!==i;case 184:case 183:if(178===i||180===i)return!1;break}return a}function R(e,n){switch(e){case 243:case 247:case 241:case 242:return 231!==n.kind;default:return!1}}function O(e,n,t,r,a){return void 0===a&&(a=!1),k(e,n,t,r,!1)&&!(a&&t&&R(t.kind,n))}function w(n,t){var r=e.skipTrivia(n.text,t.pos),a=n.getLineAndCharacterOfPosition(r).line,i=n.getLineAndCharacterOfPosition(t.end).line;return a===i}(function(e){e[e["Unknown"]=-1]="Unknown"})(r||(r={})),t.getIndentation=i,t.getIndentationForNode=l,t.getBaseIndentation=u,function(e){e[e["Unknown"]=0]="Unknown",e[e["OpenBrace"]=1]="OpenBrace",e[e["CloseBrace"]=2]="CloseBrace"}(a||(a={})),t.isArgumentAndStartLineOverlapsExpressionBeingCalled=y,t.childStartsOnTheSameLineWithElseInIfStatement=h,t.childIsUnindentedBranchOfConditionalExpression=v,t.argumentStartsOnSameLineAsPreviousArgument=b,t.getContainingList=E,t.findFirstNonWhitespaceCharacterAndColumn=I,t.findFirstNonWhitespaceColumn=N,t.nodeWillIndentChild=k,t.shouldIndentChildNode=O})(n.SmartIndenter||(n.SmartIndenter={}))})(e.formatting||(e.formatting={}))}(d||(d={})),function(e){(function(n){function t(n){var t=n.__pos;return e.Debug.assert("number"===typeof t),t}function r(n,t){e.Debug.assert("number"===typeof t),n.__pos=t}function a(n){var t=n.__end;return e.Debug.assert("number"===typeof t),t}function s(n,t){e.Debug.assert("number"===typeof t),n.__end=t}var c,l;function u(n,t){return e.skipTrivia(n,t,!1,!0)}function d(n,t){var r=t;while(r<n.length){var a=n.charCodeAt(r);if(!e.isWhiteSpaceSingleLine(a))return 47===a;r++}return!1}(function(e){e[e["Exclude"]=0]="Exclude",e[e["IncludeAll"]=1]="IncludeAll",e[e["JSDoc"]=2]="JSDoc",e[e["StartLine"]=3]="StartLine"})(c=n.LeadingTriviaOption||(n.LeadingTriviaOption={})),function(e){e[e["Exclude"]=0]="Exclude",e[e["ExcludeWhitespace"]=1]="ExcludeWhitespace",e[e["Include"]=2]="Include"}(l=n.TrailingTriviaOption||(n.TrailingTriviaOption={}));var p,f={leadingTriviaOption:c.Exclude,trailingTriviaOption:l.Exclude};function m(e,n,t,r){return{pos:_(e,n,r),end:y(e,t,r)}}function _(n,t,r,a){var i,o;void 0===a&&(a=!1);var s=r.leadingTriviaOption;if(s===c.Exclude)return t.getStart(n);if(s===c.StartLine)return e.getLineStartPositionForPosition(t.getStart(n),n);if(s===c.JSDoc){var l=e.getJSDocCommentRanges(t,n.text);if(null===l||void 0===l?void 0:l.length)return e.getLineStartPositionForPosition(l[0].pos,n)}var d=t.getFullStart(),p=t.getStart(n);if(d===p)return p;var f=e.getLineStartPositionForPosition(d,n),m=e.getLineStartPositionForPosition(p,n);if(m===f)return s===c.IncludeAll?d:p;if(a){var _=(null===(i=e.getLeadingCommentRanges(n.text,d))||void 0===i?void 0:i[0])||(null===(o=e.getTrailingCommentRanges(n.text,d))||void 0===o?void 0:o[0]);if(_)return e.skipTrivia(n.text,_.end,!0,!0)}var g=d>0?1:0,y=e.getStartPositionOfLine(e.getLineOfLocalPosition(n,f)+g,n);return y=u(n.text,y),e.getStartPositionOfLine(e.getLineOfLocalPosition(n,y),n)}function g(n,t,r){var a=t.end,i=r.trailingTriviaOption;if(i===l.Include){var o=e.getTrailingCommentRanges(n.text,a);if(o)for(var s=e.getLineOfLocalPosition(n,t.end),c=0,u=o;c<u.length;c++){var d=u[c];if(2===d.kind||e.getLineOfLocalPosition(n,d.pos)>s)break;var p=e.getLineOfLocalPosition(n,d.end);if(p>s)return e.skipTrivia(n.text,d.end,!0,!0)}}}function y(n,t,r){var a,i=t.end,o=r.trailingTriviaOption;if(o===l.Exclude)return i;if(o===l.ExcludeWhitespace){var s=e.concatenate(e.getTrailingCommentRanges(n.text,i),e.getLeadingCommentRanges(n.text,i)),c=null===(a=null===s||void 0===s?void 0:s[s.length-1])||void 0===a?void 0:a.end;return c||i}var u=g(n,t,r);if(u)return u;var d=e.skipTrivia(n.text,i,!0);return d===i||o!==l.Include&&!e.isLineBreak(n.text.charCodeAt(d-1))?i:d}function h(e,n){return!!n&&!!e.parent&&(27===n.kind||26===n.kind&&201===e.parent.kind)}function v(n){return e.isFunctionExpression(n)||e.isFunctionDeclaration(n)}(function(e){e[e["Remove"]=0]="Remove",e[e["ReplaceWithSingleNode"]=1]="ReplaceWithSingleNode",e[e["ReplaceWithMultipleNodes"]=2]="ReplaceWithMultipleNodes",e[e["Text"]=3]="Text"})(p||(p={})),n.isThisTypeAnnotatable=v;var b,E,T=function(){function n(n,t){this.newLineCharacter=n,this.formatContext=t,this.changes=[],this.newFiles=[],this.classesWithNodesInsertedAtStart=new e.Map,this.deletedNodes=[]}return n.fromContext=function(t){return new n(e.getNewLineOrDefaultFromHost(t.host,t.formatContext.options),t.formatContext)},n.with=function(e,t){var r=n.fromContext(e);return t(r),r.getChanges()},n.prototype.pushRaw=function(n,t){e.Debug.assertEqual(n.fileName,t.fileName);for(var r=0,a=t.textChanges;r<a.length;r++){var i=a[r];this.changes.push({kind:p.Text,sourceFile:n,text:i.newText,range:e.createTextRangeFromSpan(i.span)})}},n.prototype.deleteRange=function(e,n){this.changes.push({kind:p.Remove,sourceFile:e,range:n})},n.prototype.delete=function(e,n){this.deletedNodes.push({sourceFile:e,node:n})},n.prototype.deleteNode=function(e,n,t){void 0===t&&(t={leadingTriviaOption:c.IncludeAll}),this.deleteRange(e,m(e,n,n,t))},n.prototype.deleteNodes=function(e,n,t,r){void 0===t&&(t={leadingTriviaOption:c.IncludeAll});for(var a=0,i=n;a<i.length;a++){var o=i[a],s=_(e,o,t,r),l=y(e,o,t);this.deleteRange(e,{pos:s,end:l}),r=!!g(e,o,t)}},n.prototype.deleteModifier=function(n,t){this.deleteRange(n,{pos:t.getStart(n),end:e.skipTrivia(n.text,t.end,!0)})},n.prototype.deleteNodeRange=function(e,n,t,r){void 0===r&&(r={leadingTriviaOption:c.IncludeAll});var a=_(e,n,r),i=y(e,t,r);this.deleteRange(e,{pos:a,end:i})},n.prototype.deleteNodeRangeExcludingEnd=function(e,n,t,r){void 0===r&&(r={leadingTriviaOption:c.IncludeAll});var a=_(e,n,r),i=void 0===t?e.text.length:_(e,t,r);this.deleteRange(e,{pos:a,end:i})},n.prototype.replaceRange=function(e,n,t,r){void 0===r&&(r={}),this.changes.push({kind:p.ReplaceWithSingleNode,sourceFile:e,range:n,options:r,node:t})},n.prototype.replaceNode=function(e,n,t,r){void 0===r&&(r=f),this.replaceRange(e,m(e,n,n,r),t,r)},n.prototype.replaceNodeRange=function(e,n,t,r,a){void 0===a&&(a=f),this.replaceRange(e,m(e,n,t,a),r,a)},n.prototype.replaceRangeWithNodes=function(e,n,t,r){void 0===r&&(r={}),this.changes.push({kind:p.ReplaceWithMultipleNodes,sourceFile:e,range:n,options:r,nodes:t})},n.prototype.replaceNodeWithNodes=function(e,n,t,r){void 0===r&&(r=f),this.replaceRangeWithNodes(e,m(e,n,n,r),t,r)},n.prototype.replaceNodeWithText=function(e,n,t){this.replaceRangeWithText(e,m(e,n,n,f),t)},n.prototype.replaceNodeRangeWithNodes=function(e,n,t,r,a){void 0===a&&(a=f),this.replaceRangeWithNodes(e,m(e,n,t,a),r,a)},n.prototype.nodeHasTrailingComment=function(e,n,t){return void 0===t&&(t=f),!!g(e,n,t)},n.prototype.nextCommaToken=function(n,t){var r=e.findNextToken(t,t.parent,n);return r&&27===r.kind?r:void 0},n.prototype.replacePropertyAssignment=function(e,n,t){var r=this.nextCommaToken(e,n)?"":","+this.newLineCharacter;this.replaceNode(e,n,t,{suffix:r})},n.prototype.insertNodeAt=function(n,t,r,a){void 0===a&&(a={}),this.replaceRange(n,e.createRange(t),r,a)},n.prototype.insertNodesAt=function(n,t,r,a){void 0===a&&(a={}),this.replaceRangeWithNodes(n,e.createRange(t),r,a)},n.prototype.insertNodeAtTopOfFile=function(e,n,t){this.insertAtTopOfFile(e,n,t)},n.prototype.insertNodesAtTopOfFile=function(e,n,t){this.insertAtTopOfFile(e,n,t)},n.prototype.insertAtTopOfFile=function(n,t,r){var a=R(n),i={prefix:0===a?void 0:this.newLineCharacter,suffix:(e.isLineBreak(n.text.charCodeAt(a))?"":this.newLineCharacter)+(r?this.newLineCharacter:"")};e.isArray(t)?this.insertNodesAt(n,a,t,i):this.insertNodeAt(n,a,t,i)},n.prototype.insertFirstParameter=function(n,t,r){var a=e.firstOrUndefined(t);a?this.insertNodeBefore(n,a,r):this.insertNodeAt(n,t.pos,r)},n.prototype.insertNodeBefore=function(e,n,t,r,a){void 0===r&&(r=!1),void 0===a&&(a={}),this.insertNodeAt(e,_(e,n,a),t,this.getOptionsForInsertNodeBefore(n,t,r))},n.prototype.insertModifierAt=function(n,t,r,a){void 0===a&&(a={}),this.insertNodeAt(n,t,e.factory.createToken(r),a)},n.prototype.insertModifierBefore=function(e,n,t){return this.insertModifierAt(e,t.getStart(e),n,{suffix:" "})},n.prototype.insertCommentBeforeLine=function(n,t,r,a){var i=e.getStartPositionOfLine(t,n),o=e.getFirstNonSpaceCharacterPosition(n.text,i),s=O(n,o),c=e.getTouchingToken(n,s?o:r),l=n.text.slice(i,o),u=(s?"":this.newLineCharacter)+"//"+a+this.newLineCharacter+l;this.insertText(n,c.getStart(n),u)},n.prototype.insertJsdocCommentBefore=function(n,t,r){var a=t.getStart(n);if(t.jsDoc)for(var i=0,o=t.jsDoc;i<o.length;i++){var s=o[i];this.deleteRange(n,{pos:e.getLineStartPositionForPosition(s.getStart(n),n),end:y(n,s,{})})}var c=e.getPrecedingNonSpaceCharacterPosition(n.text,a-1),l=n.text.slice(c,a);this.insertNodeAt(n,a,r,{preserveLeadingWhitespace:!1,suffix:this.newLineCharacter+l})},n.prototype.replaceRangeWithText=function(e,n,t){this.changes.push({kind:p.Text,sourceFile:e,range:n,text:t})},n.prototype.insertText=function(n,t,r){this.replaceRangeWithText(n,e.createRange(t),r)},n.prototype.tryInsertTypeAnnotation=function(n,t,r){var a,i;if(e.isFunctionLike(t)){if(i=e.findChildOfKind(t,21,n),!i){if(!e.isArrowFunction(t))return!1;i=e.first(t.parameters)}}else i=null!==(a=250===t.kind?t.exclamationToken:t.questionToken)&&void 0!==a?a:t.name;return this.insertNodeAt(n,i.end,r,{prefix:": "}),!0},n.prototype.tryInsertThisTypeAnnotation=function(n,t,r){var a=e.findChildOfKind(t,20,n).getStart(n)+1,i=t.parameters.length?", ":"";this.insertNodeAt(n,a,r,{prefix:"this: ",suffix:i})},n.prototype.insertTypeParameters=function(n,t,r){var a=(e.findChildOfKind(t,20,n)||e.first(t.parameters)).getStart(n);this.insertNodesAt(n,a,r,{prefix:"<",suffix:">",joiner:", "})},n.prototype.getOptionsForInsertNodeBefore=function(n,t,r){return e.isStatement(n)||e.isClassElement(n)?{suffix:r?this.newLineCharacter+this.newLineCharacter:this.newLineCharacter}:e.isVariableDeclaration(n)?{suffix:", "}:e.isParameter(n)?e.isParameter(t)?{suffix:", "}:{}:e.isStringLiteral(n)&&e.isImportDeclaration(n.parent)||e.isNamedImports(n)?{suffix:", "}:e.isImportSpecifier(n)?{suffix:","+(r?this.newLineCharacter:" ")}:e.Debug.failBadSyntaxKind(n)},n.prototype.insertNodeAtConstructorStart=function(n,t,r){var a=e.firstOrUndefined(t.body.statements);a&&t.body.multiLine?this.insertNodeBefore(n,a,r):this.replaceConstructorBody(n,t,i([r],t.body.statements))},n.prototype.insertNodeAtConstructorStartAfterSuperCall=function(n,t,r){var a=e.find(t.body.statements,(function(n){return e.isExpressionStatement(n)&&e.isSuperCall(n.expression)}));a&&t.body.multiLine?this.insertNodeAfter(n,a,r):this.replaceConstructorBody(n,t,i(i([],t.body.statements),[r]))},n.prototype.insertNodeAtConstructorEnd=function(n,t,r){var a=e.lastOrUndefined(t.body.statements);a&&t.body.multiLine?this.insertNodeAfter(n,a,r):this.replaceConstructorBody(n,t,i(i([],t.body.statements),[r]))},n.prototype.replaceConstructorBody=function(n,t,r){this.replaceNode(n,t.body,e.factory.createBlock(r,!0))},n.prototype.insertNodeAtEndOfScope=function(n,t,r){var a=_(n,t.getLastToken(),{});this.insertNodeAt(n,a,r,{prefix:e.isLineBreak(n.text.charCodeAt(t.getLastToken().pos))?this.newLineCharacter:this.newLineCharacter+this.newLineCharacter,suffix:this.newLineCharacter})},n.prototype.insertNodeAtClassStart=function(e,n,t){this.insertNodeAtStartWorker(e,n,t)},n.prototype.insertNodeAtObjectStart=function(e,n,t){this.insertNodeAtStartWorker(e,n,t)},n.prototype.insertNodeAtStartWorker=function(e,n,t){var r,a=null!==(r=this.guessIndentationFromExistingMembers(e,n))&&void 0!==r?r:this.computeIndentationForNewMember(e,n);this.insertNodeAt(e,L(n).pos,t,this.getInsertNodeAtStartInsertOptions(e,n,a))},n.prototype.guessIndentationFromExistingMembers=function(n,t){for(var r,a=t,i=0,o=L(t);i<o.length;i++){var s=o[i];if(e.rangeStartPositionsAreOnSameLine(a,s,n))return;var c=s.getStart(n),l=e.formatting.SmartIndenter.findFirstNonWhitespaceColumn(e.getLineStartPositionForPosition(c,n),c,n,this.formatContext.options);if(void 0===r)r=l;else if(l!==r)return;a=s}return r},n.prototype.computeIndentationForNewMember=function(n,t){var r,a=t.getStart(n);return e.formatting.SmartIndenter.findFirstNonWhitespaceColumn(e.getLineStartPositionForPosition(a,n),a,n,this.formatContext.options)+(null!==(r=this.formatContext.options.indentSize)&&void 0!==r?r:4)},n.prototype.getInsertNodeAtStartInsertOptions=function(n,t,r){var a=L(t),i=0===a.length,o=e.addToSeen(this.classesWithNodesInsertedAtStart,e.getNodeId(t),{node:t,sourceFile:n}),s=e.isObjectLiteralExpression(t)&&(!e.isJsonSourceFile(n)||!i),c=e.isObjectLiteralExpression(t)&&e.isJsonSourceFile(n)&&i&&!o;return{indentation:r,prefix:(c?",":"")+this.newLineCharacter,suffix:s?",":""}},n.prototype.insertNodeAfterComma=function(e,n,t){var r=this.insertNodeAfterWorker(e,this.nextCommaToken(e,n)||n,t);this.insertNodeAt(e,r,t,this.getInsertNodeAfterOptions(e,n))},n.prototype.insertNodeAfter=function(e,n,t){var r=this.insertNodeAfterWorker(e,n,t);this.insertNodeAt(e,r,t,this.getInsertNodeAfterOptions(e,n))},n.prototype.insertNodeAtEndOfList=function(e,n,t){this.insertNodeAt(e,n.end,t,{prefix:", "})},n.prototype.insertNodesAfter=function(n,t,r){var a=this.insertNodeAfterWorker(n,t,e.first(r));this.insertNodesAt(n,a,r,this.getInsertNodeAfterOptions(n,t))},n.prototype.insertNodeAfterWorker=function(n,t,r){w(t,r)&&59!==n.text.charCodeAt(t.end-1)&&this.replaceRange(n,e.createRange(t.end),e.factory.createToken(26));var a=y(n,t,{});return a},n.prototype.getInsertNodeAfterOptions=function(n,t){var r=this.getInsertNodeAfterOptionsWorker(t);return o(o({},r),{prefix:t.end===n.end&&e.isStatement(t)?r.prefix?"\n"+r.prefix:"\n":r.prefix})},n.prototype.getInsertNodeAfterOptionsWorker=function(n){switch(n.kind){case 253:case 257:return{prefix:this.newLineCharacter,suffix:this.newLineCharacter};case 250:case 10:case 78:return{prefix:", "};case 289:return{suffix:","+this.newLineCharacter};case 92:return{prefix:" "};case 161:return{};default:return e.Debug.assert(e.isStatement(n)||e.isClassOrTypeElement(n)),{suffix:this.newLineCharacter}}},n.prototype.insertName=function(n,t,r){if(e.Debug.assert(!t.name),210===t.kind){var a=e.findChildOfKind(t,38,n),i=e.findChildOfKind(t,20,n);i?(this.insertNodesAt(n,i.getStart(n),[e.factory.createToken(97),e.factory.createIdentifier(r)],{joiner:" "}),P(this,n,a)):(this.insertText(n,e.first(t.parameters).getStart(n),"function "+r+"("),this.replaceRange(n,a,e.factory.createToken(21))),231!==t.body.kind&&(this.insertNodesAt(n,t.body.getStart(n),[e.factory.createToken(18),e.factory.createToken(104)],{joiner:" ",suffix:" "}),this.insertNodesAt(n,t.body.end,[e.factory.createToken(26),e.factory.createToken(19)],{joiner:" "}))}else{var o=e.findChildOfKind(t,209===t.kind?97:83,n).end;this.insertNodeAt(n,o,e.factory.createIdentifier(r),{prefix:" "})}},n.prototype.insertExportModifier=function(e,n){this.insertText(e,n.getStart(e),"export ")},n.prototype.insertNodeInListAfter=function(n,t,r,a){if(void 0===a&&(a=e.formatting.SmartIndenter.getContainingList(t,n)),a){var i=e.indexOfNode(a,t);if(!(i<0)){var o=t.getEnd();if(i!==a.length-1){var s=e.getTokenAtPosition(n,t.end);if(s&&h(t,s)){var c=a[i+1],l=u(n.text,c.getFullStart()),p=""+e.tokenToString(s.kind)+n.text.substring(s.end,l);this.insertNodesAt(n,l,[r],{suffix:p})}}else{var f=t.getStart(n),m=e.getLineStartPositionForPosition(f,n),_=void 0,g=!1;if(1===a.length)_=27;else{var y=e.findPrecedingToken(t.pos,n);_=h(t,y)?y.kind:27;var v=e.getLineStartPositionForPosition(a[i-1].getStart(n),n);g=v!==m}if(d(n.text,t.end)&&(g=!0),g){this.replaceRange(n,e.createRange(o),e.factory.createToken(_));var b=e.formatting.SmartIndenter.findFirstNonWhitespaceColumn(m,f,n,this.formatContext.options),E=e.skipTrivia(n.text,o,!0,!1);while(E!==o&&e.isLineBreak(n.text.charCodeAt(E-1)))E--;this.replaceRange(n,e.createRange(E),r,{indentation:b,prefix:this.newLineCharacter})}else this.replaceRange(n,e.createRange(o),r,{prefix:e.tokenToString(_)+" "})}}}else e.Debug.fail("node is not a list element")},n.prototype.parenthesizeExpression=function(n,t){this.replaceRange(n,e.rangeOfNode(t),e.factory.createParenthesizedExpression(t))},n.prototype.finishClassesWithNodesInsertedAtStart=function(){var n=this;this.classesWithNodesInsertedAtStart.forEach((function(t){var r=t.node,a=t.sourceFile,i=x(r,a),o=i[0],s=i[1];if(void 0!==o&&void 0!==s){var c=0===L(r).length,l=e.positionsAreOnSameLine(o,s,a);c&&l&&o!==s-1&&n.deleteRange(a,e.createRange(o,s-1)),l&&n.insertText(a,s-1,n.newLineCharacter)}}))},n.prototype.finishDeleteDeclarations=function(){for(var n=this,t=new e.Set,r=function(n,r){a.deletedNodes.some((function(t){return t.sourceFile===n&&e.rangeContainsRangeExclusive(t.node,r)}))||(e.isArray(r)?a.deleteRange(n,e.rangeOfTypeParameters(n,r)):E.deleteDeclaration(a,t,n,r))},a=this,i=0,o=this.deletedNodes;i<o.length;i++){var s=o[i],c=s.sourceFile,l=s.node;r(c,l)}t.forEach((function(r){var a=r.getSourceFile(),i=e.formatting.SmartIndenter.getContainingList(r,a);if(r===e.last(i)){var o=e.findLastIndex(i,(function(e){return!t.has(e)}),i.length-2);-1!==o&&n.deleteRange(a,{pos:i[o].end,end:S(a,i[o+1])})}}))},n.prototype.getChanges=function(e){this.finishDeleteDeclarations(),this.finishClassesWithNodesInsertedAtStart();for(var n=b.getTextChangesFromChanges(this.changes,this.newLineCharacter,this.formatContext,e),t=0,r=this.newFiles;t<r.length;t++){var a=r[t],i=a.oldFile,o=a.fileName,s=a.statements;n.push(b.newFileChanges(i,o,s,this.newLineCharacter,this.formatContext))}return n},n.prototype.createNewFile=function(e,n,t){this.newFiles.push({oldFile:e,fileName:n,statements:t})},n}();function S(n,t){return e.skipTrivia(n.text,_(n,t,{leadingTriviaOption:c.IncludeAll}),!1,!0)}function x(n,t){var r=e.findChildOfKind(n,18,t),a=e.findChildOfKind(n,19,t);return[null===r||void 0===r?void 0:r.end,null===a||void 0===a?void 0:a.end]}function L(n){return e.isObjectLiteralExpression(n)?n.properties:n.members}function D(e,n,t,r){return b.newFileChangesWorker(void 0,n,e,t,r)}function A(n,t){for(var r=t.length-1;r>=0;r--){var a=t[r],i=a.span,o=a.newText;n=""+n.substring(0,i.start)+o+n.substring(e.textSpanEnd(i))}return n}function C(n){return e.skipTrivia(n,0)===n.length}function I(n){var r=e.visitEachChild(n,I,e.nullTransformationContext,N,I),i=e.nodeIsSynthesized(r)?r:Object.create(r);return e.setTextRangePosEnd(i,t(n),a(n)),i}function N(n,r,i,o,s){var c=e.visitNodes(n,r,i,o,s);if(!c)return c;var l=c===n?e.factory.createNodeArray(c.slice(0)):c;return e.setTextRangePosEnd(l,t(n),a(n)),l}function k(n){var t=0,a=e.createTextWriter(n),i=function(e){e&&r(e,t)},o=function(e){e&&s(e,t)},c=function(e){e&&r(e,t)},l=function(e){e&&s(e,t)},u=function(e){e&&r(e,t)},d=function(e){e&&s(e,t)};function p(n,r){if(r||!C(n)){t=a.getTextPos();var i=0;while(e.isWhiteSpaceLike(n.charCodeAt(n.length-i-1)))i++;t-=i}}function f(e){a.write(e),p(e,!1)}function m(e){a.writeComment(e)}function _(e){a.writeKeyword(e),p(e,!1)}function g(e){a.writeOperator(e),p(e,!1)}function y(e){a.writePunctuation(e),p(e,!1)}function h(e){a.writeTrailingSemicolon(e),p(e,!1)}function v(e){a.writeParameter(e),p(e,!1)}function b(e){a.writeProperty(e),p(e,!1)}function E(e){a.writeSpace(e),p(e,!1)}function T(e){a.writeStringLiteral(e),p(e,!1)}function S(e,n){a.writeSymbol(e,n),p(e,!1)}function x(e){a.writeLine(e)}function L(){a.increaseIndent()}function D(){a.decreaseIndent()}function A(){return a.getText()}function I(e){a.rawWrite(e),p(e,!1)}function N(e){a.writeLiteral(e),p(e,!0)}function k(){return a.getTextPos()}function R(){return a.getLine()}function O(){return a.getColumn()}function w(){return a.getIndent()}function P(){return a.isAtStartOfLine()}function M(){a.clear(),t=0}return{onBeforeEmitNode:i,onAfterEmitNode:o,onBeforeEmitNodeArray:c,onAfterEmitNodeArray:l,onBeforeEmitToken:u,onAfterEmitToken:d,write:f,writeComment:m,writeKeyword:_,writeOperator:g,writePunctuation:y,writeTrailingSemicolon:h,writeParameter:v,writeProperty:b,writeSpace:E,writeStringLiteral:T,writeSymbol:S,writeLine:x,increaseIndent:L,decreaseIndent:D,getText:A,rawWrite:I,writeLiteral:N,getTextPos:k,getLine:R,getColumn:O,getIndent:w,isAtStartOfLine:P,hasTrailingComment:function(){return a.hasTrailingComment()},hasTrailingWhitespace:function(){return a.hasTrailingWhitespace()},clear:M}}function R(n){for(var t,r=0,a=n.statements;r<a.length;r++){var i=a[r];if(!e.isPrologueDirective(i))break;t=i}var o=0,s=n.text;if(t)return o=t.end,h(),o;var c=e.getShebang(s);void 0!==c&&(o=c.length,h());var l,u,d=e.getLeadingCommentRanges(s,o);if(!d)return o;for(var p=0,f=d;p<f.length;p++){var m=f[p];if(3===m.kind){if(e.isPinnedComment(s,m.pos)){l={range:m,pinnedOrTripleSlash:!0};continue}}else if(e.isRecognizedTripleSlashComment(s,m.pos,m.end)){l={range:m,pinnedOrTripleSlash:!0};continue}if(l){if(l.pinnedOrTripleSlash)break;var _=n.getLineAndCharacterOfPosition(m.pos).line,g=n.getLineAndCharacterOfPosition(l.range.end).line;if(_>=g+2)break}if(n.statements.length){void 0===u&&(u=n.getLineAndCharacterOfPosition(n.statements[0].getStart()).line);var y=n.getLineAndCharacterOfPosition(m.end).line;if(u<y+2)break}l={range:m,pinnedOrTripleSlash:!1}}return l&&(o=l.range.end,h()),o;function h(){if(o<s.length){var n=s.charCodeAt(o);e.isLineBreak(n)&&(o++,o<s.length&&13===n&&10===s.charCodeAt(o)&&o++)}}}function O(n,t){return!e.isInComment(n,t)&&!e.isInString(n,t)&&!e.isInTemplateString(n,t)&&!e.isInJSXText(n,t)}function w(n,t){return(e.isPropertySignature(n)||e.isPropertyDeclaration(n))&&e.isClassOrTypeElement(t)&&159===t.name.kind||e.isStatementButNotDeclaration(n)&&e.isStatementButNotDeclaration(t)}function P(e,n,t,r){void 0===r&&(r={leadingTriviaOption:c.IncludeAll});var a=_(n,t,r),i=y(n,t,r);e.deleteRange(n,{pos:a,end:i})}function M(n,t,r,a){var i=e.Debug.checkDefined(e.formatting.SmartIndenter.getContainingList(a,r)),o=e.indexOfNode(i,a);e.Debug.assert(-1!==o),1!==i.length?(e.Debug.assert(!t.has(a),"Deleting a node twice"),t.add(a),n.deleteRange(r,{pos:S(r,a),end:o===i.length-1?y(r,a,{}):S(r,i[o+1])})):P(n,r,a)}n.ChangeTracker=T,n.getNewFileText=D,function(n){function t(n,t,r,a){return e.mapDefined(e.group(n,(function(e){return e.sourceFile.path})),(function(n){for(var o=n[0].sourceFile,s=e.stableSort(n,(function(e,n){return e.range.pos-n.range.pos||e.range.end-n.range.end})),c=function(n){e.Debug.assert(s[n].range.end<=s[n+1].range.pos,"Changes overlap",(function(){return JSON.stringify(s[n].range)+" and "+JSON.stringify(s[n+1].range)}))},l=0;l<s.length-1;l++)c(l);var u=e.mapDefined(s,(function(n){var s=e.createTextSpanFromRange(n.range),c=i(n,o,t,r,a);if(s.length!==c.length||!e.stringContainsAt(o.text,c,s.start))return e.createTextChange(s,c)}));return u.length>0?{fileName:o.fileName,textChanges:u}:void 0}))}function r(n,t,r,i,o){var s=a(n,e.getScriptKindFromFileName(t),r,i,o);return{fileName:t,textChanges:[e.createTextChange(e.createTextSpan(0,0),s)],isNewFile:!0}}function a(n,t,r,a,i){var o=r.map((function(e){return 4===e?"":l(e,n,a).text})).join(a),s=e.createSourceFile("any file name",o,99,!0,t),c=e.formatting.formatDocument(s,i);return A(o,c)+a}function i(n,t,r,a,i){if(n.kind===p.Remove)return"";if(n.kind===p.Text)return n.text;var o=n.options,s=void 0===o?{}:o,l=n.range.pos,u=function(e){return c(e,t,l,s,r,a,i)},d=n.kind===p.ReplaceWithMultipleNodes?n.nodes.map((function(n){return e.removeSuffix(u(n),r)})).join(n.options.joiner||r):u(n.node),f=s.preserveLeadingWhitespace||void 0!==s.indentation||e.getLineStartPositionForPosition(l,t)===l?d:d.replace(/^\s+/,"");return(s.prefix||"")+f+(!s.suffix||e.endsWith(f,s.suffix)?"":s.suffix)}function s(n,t){var r=n.options,a=!r.semicolons||r.semicolons===e.SemicolonPreference.Ignore,i=r.semicolons===e.SemicolonPreference.Remove||a&&!e.probablyUsesSemicolons(t);return o(o({},r),{semicolons:i?e.SemicolonPreference.Remove:e.SemicolonPreference.Ignore})}function c(n,t,r,a,i,c,u){var d=a.indentation,p=a.prefix,f=a.delta,m=l(n,t,i),_=m.node,g=m.text;u&&u(_,g);var y=s(c,t),h=void 0!==d?d:e.formatting.SmartIndenter.getIndentation(r,t,y,p===i||e.getLineStartPositionForPosition(r,t)===r);void 0===f&&(f=e.formatting.SmartIndenter.shouldIndentChildNode(y,n)&&y.indentSize||0);var v={text:g,getLineAndCharacterOfPosition:function(n){return e.getLineAndCharacterOfPosition(this,n)}},b=e.formatting.formatNodeGivenIndentation(_,v,t.languageVariant,h,f,o(o({},c),{options:y}));return A(g,b)}function l(n,t,r){var a=k(r),i="\n"===r?1:0;return e.createPrinter({newLine:i,neverAsciiEscape:!0,preserveSourceNewlines:!0,terminateUnterminatedLiterals:!0},a).writeNode(4,n,t,a),{text:a.getText(),node:I(n)}}n.getTextChangesFromChanges=t,n.newFileChanges=r,n.newFileChangesWorker=a,n.getNonformattedText=l}(b||(b={})),n.applyChanges=A,n.isValidLocationToAddComment=O,function(n){function t(n,t,o,s){switch(s.kind){case 161:var u=s.parent;e.isArrowFunction(u)&&1===u.parameters.length&&!e.findChildOfKind(u,20,o)?n.replaceNodeWithText(o,s,"()"):M(n,t,o,s);break;case 262:case 261:var d=o.imports.length&&s===e.first(o.imports).parent||s===e.find(o.statements,e.isAnyImportSyntax);P(n,o,s,{leadingTriviaOption:d?c.Exclude:e.hasJSDocNodes(s)?c.JSDoc:c.StartLine});break;case 199:var p=s.parent,f=198===p.kind&&s!==e.last(p.elements);f?P(n,o,s):M(n,t,o,s);break;case 250:i(n,t,o,s);break;case 160:M(n,t,o,s);break;case 266:var m=s.parent;1===m.elements.length?a(n,o,m):M(n,t,o,s);break;case 264:a(n,o,s);break;case 26:P(n,o,s,{trailingTriviaOption:l.Exclude});break;case 97:P(n,o,s,{leadingTriviaOption:c.Exclude});break;case 253:case 252:P(n,o,s,{leadingTriviaOption:e.hasJSDocNodes(s)?c.JSDoc:c.StartLine});break;default:s.parent?e.isImportClause(s.parent)&&s.parent.name===s?r(n,o,s.parent):e.isCallExpression(s.parent)&&e.contains(s.parent.arguments,s)?M(n,t,o,s):P(n,o,s):P(n,o,s)}}function r(n,t,r){if(r.namedBindings){var a=r.name.getStart(t),i=e.getTokenAtPosition(t,r.name.end);if(i&&27===i.kind){var o=e.skipTrivia(t.text,i.end,!1,!0);n.deleteRange(t,{pos:a,end:o})}else P(n,t,r.name)}else P(n,t,r.parent)}function a(n,t,r){if(r.parent.name){var a=e.Debug.checkDefined(e.getTokenAtPosition(t,r.pos-1));n.deleteRange(t,{pos:a.getStart(t),end:r.end})}else{var i=e.getAncestor(r,262);P(n,t,i)}}function i(n,t,r,a){var i=a.parent;if(288!==i.kind)if(1===i.declarations.length){var o=i.parent;switch(o.kind){case 240:case 239:n.replaceNode(r,a,e.factory.createObjectLiteralExpression());break;case 238:P(n,r,i);break;case 233:P(n,r,o,{leadingTriviaOption:e.hasJSDocNodes(o)?c.JSDoc:c.StartLine});break;default:e.Debug.assertNever(o)}}else M(n,t,r,a);else n.deleteNodeRange(r,e.findChildOfKind(i,20,r),e.findChildOfKind(i,21,r))}n.deleteDeclaration=t}(E||(E={})),n.deleteNode=P})(e.textChanges||(e.textChanges={}))}(d||(d={})),function(e){(function(n){var t=e.createMultiMap(),r=new e.Map;function a(n){return e.isArray(n)?e.formatStringFromArgs(e.getLocaleSpecificMessage(n[0]),n.slice(1)):e.getLocaleSpecificMessage(n)}function s(e,n,t){return d(e,a(t),n,void 0,void 0)}function c(e,n,t,r,i,o){return d(e,a(t),n,r,a(i),o)}function u(e,n,t,r,i,o){return d(e,a(t),n,r,i&&a(i),o)}function d(e,n,t,r,a,i){return{fixName:e,description:n,changes:t,fixId:r,fixAllDescription:a,commands:i?[i]:void 0}}function p(n){for(var a=0,i=n.errorCodes;a<i.length;a++){var o=i[a];t.add(String(o),n)}if(n.fixIds)for(var s=0,c=n.fixIds;s<c.length;s++){var l=c[s];e.Debug.assert(!r.has(l)),r.set(l,n)}}function f(){return e.arrayFrom(t.keys())}function m(n,t){for(var r=n.errorCodes,a=0,i=0,s=t;i<s.length;i++){var c=s[i];if(e.contains(r,c.code)&&a++,a>1)break}var u=a<2;return function(e){var n=e.fixId,t=e.fixAllDescription,r=l(e,["fixId","fixAllDescription"]);return u?r:o(o({},r),{fixId:n,fixAllDescription:t})}}function _(n){var r=E(n),a=t.get(String(n.errorCode));return e.flatMap(a,(function(t){return e.map(t.getCodeActions(n),m(t,r))}))}function g(n){return r.get(e.cast(n.fixId,e.isString)).getAllCodeActions(n)}function y(e,n){return{changes:e,commands:n}}function h(e,n){return{fileName:e,textChanges:n}}function v(n,t,r){var a=[],i=e.textChanges.ChangeTracker.with(n,(function(e){return b(n,t,(function(n){return r(e,n,a)}))}));return y(i,0===a.length?void 0:a)}function b(n,t,r){for(var a=0,i=E(n);a<i.length;a++){var o=i[a];e.contains(t,o.code)&&r(o)}}function E(n){var t=n.program,r=n.sourceFile,a=n.cancellationToken;return i(i(i([],t.getSemanticDiagnostics(r,a)),t.getSyntacticDiagnostics(r,a)),e.computeSuggestionDiagnostics(r,t,a))}n.createCodeFixActionWithoutFixAll=s,n.createCodeFixAction=c,n.createCodeFixActionMaybeFixAll=u,n.registerCodeFix=p,n.getSupportedErrorCodes=f,n.getFixes=_,n.getAllFixes=g,n.createCombinedCodeActions=y,n.createFileTextChanges=h,n.codeFixAll=v,n.eachDiagnostic=b})(e.codefix||(e.codefix={}))}(d||(d={})),function(e){(function(n){var t=new e.Map;function r(e,n){t.set(e,n)}function a(r){return e.arrayFrom(e.flatMapIterator(t.values(),(function(e){var t;return r.cancellationToken&&r.cancellationToken.isCancellationRequested()||!(null===(t=e.kinds)||void 0===t?void 0:t.some((function(e){return n.refactorKindBeginsWith(e,r.kind)})))?void 0:e.getAvailableActions(r)})))}function i(e,n,r){var a=t.get(n);return a&&a.getEditsForAction(e,r)}n.registerRefactor=r,n.getApplicableRefactors=a,n.getEditsForRefactor=i})(e.refactor||(e.refactor={}))}(d||(d={})),function(e){(function(n){var t="addConvertToUnknownForNonOverlappingTypes",r=[e.Diagnostics.Conversion_of_type_0_to_type_1_may_be_a_mistake_because_neither_type_sufficiently_overlaps_with_the_other_If_this_was_intentional_convert_the_expression_to_unknown_first.code];function a(n,t,r){var a=e.getTokenAtPosition(t,r),i=e.Debug.checkDefined(e.findAncestor(a,(function(n){return e.isAsExpression(n)||e.isTypeAssertionExpression(n)})),"Expected to find an assertion expression"),o=e.isAsExpression(i)?e.factory.createAsExpression(i.expression,e.factory.createKeywordTypeNode(152)):e.factory.createTypeAssertion(e.factory.createKeywordTypeNode(152),i.expression);n.replaceNode(t,i.expression,o)}n.registerCodeFix({errorCodes:r,getCodeActions:function(r){var i=e.textChanges.ChangeTracker.with(r,(function(e){return a(e,r.sourceFile,r.span.start)}));return[n.createCodeFixAction(t,i,e.Diagnostics.Add_unknown_conversion_for_non_overlapping_types,t,e.Diagnostics.Add_unknown_to_all_conversions_of_non_overlapping_types)]},fixIds:[t],getAllCodeActions:function(e){return n.codeFixAll(e,r,(function(e,n){return a(e,n.file,n.start)}))}})})(e.codefix||(e.codefix={}))}(d||(d={})),function(e){(function(n){n.registerCodeFix({errorCodes:[e.Diagnostics.await_expressions_are_only_allowed_at_the_top_level_of_a_file_when_that_file_is_a_module_but_this_file_has_no_imports_or_exports_Consider_adding_an_empty_export_to_make_this_file_a_module.code,e.Diagnostics.for_await_loops_are_only_allowed_at_the_top_level_of_a_file_when_that_file_is_a_module_but_this_file_has_no_imports_or_exports_Consider_adding_an_empty_export_to_make_this_file_a_module.code],getCodeActions:function(t){var r=t.sourceFile,a=e.textChanges.ChangeTracker.with(t,(function(n){var t=e.factory.createExportDeclaration(void 0,void 0,!1,e.factory.createNamedExports([]),void 0);n.insertNodeAtEndOfScope(r,r,t)}));return[n.createCodeFixActionWithoutFixAll("addEmptyExportDeclaration",a,e.Diagnostics.Add_export_to_make_this_file_into_a_module)]}})})(e.codefix||(e.codefix={}))}(d||(d={})),function(e){(function(n){var t="addMissingAsync",r=[e.Diagnostics.Argument_of_type_0_is_not_assignable_to_parameter_of_type_1.code,e.Diagnostics.Type_0_is_not_assignable_to_type_1.code,e.Diagnostics.Type_0_is_not_comparable_to_type_1.code];function a(r,a,o,s){var c=o((function(e){return i(e,r.sourceFile,a,s)}));return n.createCodeFixAction(t,c,e.Diagnostics.Add_async_modifier_to_containing_function,t,e.Diagnostics.Add_all_missing_async_modifiers)}function i(n,t,r,a){if(!a||!a.has(e.getNodeId(r))){null===a||void 0===a||a.add(e.getNodeId(r));var i=e.factory.updateModifiers(e.getSynthesizedDeepClone(r,!0),e.factory.createNodeArray(e.factory.createModifiersFromModifierFlags(256|e.getSyntacticModifierFlags(r))));n.replaceNode(t,r,i)}}function o(n,t){if(t){var r=e.getTokenAtPosition(n,t.start),a=e.findAncestor(r,(function(r){return r.getStart(n)<t.start||r.getEnd()>e.textSpanEnd(t)?"quit":(e.isArrowFunction(r)||e.isMethodDeclaration(r)||e.isFunctionExpression(r)||e.isFunctionDeclaration(r))&&e.textSpansEqual(t,e.createTextSpanFromNode(r,n))}));return a}}function s(n,t){return function(r){var a=r.start,i=r.length,o=r.relatedInformation,s=r.code;return e.isNumber(a)&&e.isNumber(i)&&e.textSpansEqual({start:a,length:i},n)&&s===t&&!!o&&e.some(o,(function(n){return n.code===e.Diagnostics.Did_you_mean_to_mark_this_function_as_async.code}))}}n.registerCodeFix({fixIds:[t],errorCodes:r,getCodeActions:function(n){var t=n.sourceFile,r=n.errorCode,i=n.cancellationToken,c=n.program,l=n.span,u=e.find(c.getDiagnosticsProducingTypeChecker().getDiagnostics(t,i),s(l,r)),d=u&&u.relatedInformation&&e.find(u.relatedInformation,(function(n){return n.code===e.Diagnostics.Did_you_mean_to_mark_this_function_as_async.code})),p=o(t,d);if(p){var f=function(t){return e.textChanges.ChangeTracker.with(n,t)};return[a(n,p,f)]}},getAllCodeActions:function(t){var i=t.sourceFile,s=new e.Set;return n.codeFixAll(t,r,(function(n,r){var c=r.relatedInformation&&e.find(r.relatedInformation,(function(n){return n.code===e.Diagnostics.Did_you_mean_to_mark_this_function_as_async.code})),l=o(i,c);if(l){var u=function(e){return e(n),[]};return a(t,l,u,s)}}))}})})(e.codefix||(e.codefix={}))}(d||(d={})),function(e){(function(n){var t="addMissingAwait",r=e.Diagnostics.Property_0_does_not_exist_on_type_1.code,a=[e.Diagnostics.This_expression_is_not_callable.code,e.Diagnostics.This_expression_is_not_constructable.code],o=i([e.Diagnostics.An_arithmetic_operand_must_be_of_type_any_number_bigint_or_an_enum_type.code,e.Diagnostics.The_left_hand_side_of_an_arithmetic_operation_must_be_of_type_any_number_bigint_or_an_enum_type.code,e.Diagnostics.The_right_hand_side_of_an_arithmetic_operation_must_be_of_type_any_number_bigint_or_an_enum_type.code,e.Diagnostics.Operator_0_cannot_be_applied_to_type_1.code,e.Diagnostics.Operator_0_cannot_be_applied_to_types_1_and_2.code,e.Diagnostics.This_condition_will_always_return_0_since_the_types_1_and_2_have_no_overlap.code,e.Diagnostics.This_condition_will_always_return_true_since_this_0_is_always_defined.code,e.Diagnostics.Type_0_is_not_an_array_type.code,e.Diagnostics.Type_0_is_not_an_array_type_or_a_string_type.code,e.Diagnostics.Type_0_is_not_an_array_type_or_a_string_type_Use_compiler_option_downlevelIteration_to_allow_iterating_of_iterators.code,e.Diagnostics.Type_0_is_not_an_array_type_or_a_string_type_or_does_not_have_a_Symbol_iterator_method_that_returns_an_iterator.code,e.Diagnostics.Type_0_is_not_an_array_type_or_does_not_have_a_Symbol_iterator_method_that_returns_an_iterator.code,e.Diagnostics.Type_0_must_have_a_Symbol_iterator_method_that_returns_an_iterator.code,e.Diagnostics.Type_0_must_have_a_Symbol_asyncIterator_method_that_returns_an_async_iterator.code,e.Diagnostics.Argument_of_type_0_is_not_assignable_to_parameter_of_type_1.code,r],a);function s(t,r,a,i,o,s){var c=t.sourceFile,l=t.program,u=t.cancellationToken,p=d(r,c,u,l,i);if(p){var f=o((function(n){e.forEach(p.initializers,(function(e){var t=e.expression;return _(n,a,c,i,t,s)})),s&&p.needsSecondPassForFixAll&&_(n,a,c,i,r,s)}));return n.createCodeFixActionWithoutFixAll("addMissingAwaitToInitializer",f,1===p.initializers.length?[e.Diagnostics.Add_await_to_initializer_for_0,p.initializers[0].declarationSymbol.name]:e.Diagnostics.Add_await_to_initializers)}}function c(r,a,i,o,s,c){var l=s((function(e){return _(e,i,r.sourceFile,o,a,c)}));return n.createCodeFixAction(t,l,e.Diagnostics.Add_await,t,e.Diagnostics.Fix_all_expressions_possibly_missing_await)}function l(n,t,r,a,i){var o=i.getDiagnosticsProducingTypeChecker(),s=o.getDiagnostics(n,a);return e.some(s,(function(n){var a=n.start,i=n.length,o=n.relatedInformation,s=n.code;return e.isNumber(a)&&e.isNumber(i)&&e.textSpansEqual({start:a,length:i},r)&&s===t&&!!o&&e.some(o,(function(n){return n.code===e.Diagnostics.Did_you_forget_to_use_await.code}))}))}function u(n,t,r,a,i){var o=e.getTokenAtPosition(n,r.start),s=e.findAncestor(o,(function(t){return t.getStart(n)<r.start||t.getEnd()>e.textSpanEnd(r)?"quit":e.isExpression(t)&&e.textSpansEqual(r,e.createTextSpanFromNode(t,n))}));return s&&l(n,t,r,a,i)&&m(s)?s:void 0}function d(n,t,r,a,i){var o=p(n,i);if(o){for(var s,c=o.isCompleteFix,l=function(n){var o=i.getSymbolAtLocation(n);if(!o)return"continue";var l=e.tryCast(o.valueDeclaration,e.isVariableDeclaration),u=l&&e.tryCast(l.name,e.isIdentifier),d=e.getAncestor(l,233);if(!l||!d||l.type||!l.initializer||d.getSourceFile()!==t||e.hasSyntacticModifier(d,1)||!u||!m(l.initializer))return c=!1,"continue";var p=a.getSemanticDiagnostics(t,r),_=e.FindAllReferences.Core.eachSymbolReferenceInFile(u,i,t,(function(e){return n!==e&&!f(e,p,t,i)}));if(_)return c=!1,"continue";(s||(s=[])).push({expression:l.initializer,declarationSymbol:o})},u=0,d=o.identifiers;u<d.length;u++){var _=d[u];l(_)}return s&&{initializers:s,needsSecondPassForFixAll:!c}}}function p(n,t){if(e.isPropertyAccessExpression(n.parent)&&e.isIdentifier(n.parent.expression))return{identifiers:[n.parent.expression],isCompleteFix:!0};if(e.isIdentifier(n))return{identifiers:[n],isCompleteFix:!0};if(e.isBinaryExpression(n)){for(var r=void 0,a=!0,i=0,o=[n.left,n.right];i<o.length;i++){var s=o[i],c=t.getTypeAtLocation(s);if(t.getPromisedTypeOfPromise(c)){if(!e.isIdentifier(s)){a=!1;continue}(r||(r=[])).push(s)}}return r&&{identifiers:r,isCompleteFix:a}}}function f(n,t,r,a){var i=e.isPropertyAccessExpression(n.parent)?n.parent.name:e.isBinaryExpression(n.parent)?n.parent:n,s=e.find(t,(function(e){return e.start===i.getStart(r)&&e.start+e.length===i.getEnd()}));return s&&e.contains(o,s.code)||1&a.getTypeAtLocation(i).flags}function m(n){return 32768&n.kind||!!e.findAncestor(n,(function(n){return n.parent&&e.isArrowFunction(n.parent)&&n.parent.body===n||e.isBlock(n)&&(252===n.parent.kind||209===n.parent.kind||210===n.parent.kind||166===n.parent.kind)}))}function _(n,t,i,o,s,c){if(e.isBinaryExpression(s))for(var l=0,u=[s.left,s.right];l<u.length;l++){var d=u[l];if(c&&e.isIdentifier(d)){var p=o.getSymbolAtLocation(d);if(p&&c.has(e.getSymbolId(p)))continue}var f=o.getTypeAtLocation(d),m=o.getPromisedTypeOfPromise(f)?e.factory.createAwaitExpression(d):d;n.replaceNode(i,d,m)}else if(t===r&&e.isPropertyAccessExpression(s.parent)){if(c&&e.isIdentifier(s.parent.expression)){p=o.getSymbolAtLocation(s.parent.expression);if(p&&c.has(e.getSymbolId(p)))return}n.replaceNode(i,s.parent.expression,e.factory.createParenthesizedExpression(e.factory.createAwaitExpression(s.parent.expression))),g(n,s.parent.expression,i)}else if(e.contains(a,t)&&e.isCallOrNewExpression(s.parent)){if(c&&e.isIdentifier(s)){p=o.getSymbolAtLocation(s);if(p&&c.has(e.getSymbolId(p)))return}n.replaceNode(i,s,e.factory.createParenthesizedExpression(e.factory.createAwaitExpression(s))),g(n,s,i)}else{if(c&&e.isVariableDeclaration(s.parent)&&e.isIdentifier(s.parent.name)){p=o.getSymbolAtLocation(s.parent.name);if(p&&!e.tryAddToSet(c,e.getSymbolId(p)))return}n.replaceNode(i,s,e.factory.createAwaitExpression(s))}}function g(n,t,r){var a=e.findPrecedingToken(t.pos,r);a&&e.positionIsASICandidate(a.end,a.parent,r)&&n.insertText(r,t.getStart(r),";")}n.registerCodeFix({fixIds:[t],errorCodes:o,getCodeActions:function(n){var t=n.sourceFile,r=n.errorCode,a=n.span,i=n.cancellationToken,o=n.program,l=u(t,r,a,i,o);if(l){var d=n.program.getTypeChecker(),p=function(t){return e.textChanges.ChangeTracker.with(n,t)};return e.compact([s(n,l,r,d,p),c(n,l,r,d,p)])}},getAllCodeActions:function(t){var r=t.sourceFile,a=t.program,i=t.cancellationToken,l=t.program.getTypeChecker(),d=new e.Set;return n.codeFixAll(t,o,(function(e,n){var o=u(r,n.code,n,i,a);if(o){var p=function(n){return n(e),[]};return s(t,o,n.code,l,p,d)||c(t,o,n.code,l,p,d)}}))}})})(e.codefix||(e.codefix={}))}(d||(d={})),function(e){(function(n){var t="addMissingConst",r=[e.Diagnostics.Cannot_find_name_0.code,e.Diagnostics.No_value_exists_in_scope_for_the_shorthand_property_0_Either_declare_one_or_provide_an_initializer.code];function a(n,t,r,a,u){var d=e.getTokenAtPosition(t,r),p=e.findAncestor(d,(function(n){return e.isForInOrOfStatement(n.parent)?n.parent.initializer===n:!o(n)&&"quit"}));if(p)return i(n,p,t,u);var f=d.parent;if(e.isBinaryExpression(f)&&62===f.operatorToken.kind&&e.isExpressionStatement(f.parent))return i(n,d,t,u);if(e.isArrayLiteralExpression(f)){var m=a.getTypeChecker();if(!e.every(f.elements,(function(e){return s(e,m)})))return;return i(n,f,t,u)}var _=e.findAncestor(d,(function(n){return!!e.isExpressionStatement(n.parent)||!c(n)&&"quit"}));if(_){var g=a.getTypeChecker();if(!l(_,g))return;return i(n,_,t,u)}}function i(n,t,r,a){a&&!e.tryAddToSet(a,t)||n.insertModifierBefore(r,84,t)}function o(e){switch(e.kind){case 78:case 200:case 201:case 289:case 290:return!0;default:return!1}}function s(n,t){var r=e.isIdentifier(n)?n:e.isAssignmentExpression(n,!0)&&e.isIdentifier(n.left)?n.left:void 0;return!!r&&!t.getSymbolAtLocation(r)}function c(e){switch(e.kind){case 78:case 217:case 27:return!0;default:return!1}}function l(n,t){return!!e.isBinaryExpression(n)&&(27===n.operatorToken.kind?e.every([n.left,n.right],(function(e){return l(e,t)})):62===n.operatorToken.kind&&e.isIdentifier(n.left)&&!t.getSymbolAtLocation(n.left))}n.registerCodeFix({errorCodes:r,getCodeActions:function(r){var i=e.textChanges.ChangeTracker.with(r,(function(e){return a(e,r.sourceFile,r.span.start,r.program)}));if(i.length>0)return[n.createCodeFixAction(t,i,e.Diagnostics.Add_const_to_unresolved_variable,t,e.Diagnostics.Add_const_to_all_unresolved_variables)]},fixIds:[t],getAllCodeActions:function(t){var i=new e.Set;return n.codeFixAll(t,r,(function(e,n){return a(e,n.file,n.start,t.program,i)}))}})})(e.codefix||(e.codefix={}))}(d||(d={})),function(e){(function(n){var t="addMissingDeclareProperty",r=[e.Diagnostics.Property_0_will_overwrite_the_base_property_in_1_If_this_is_intentional_add_an_initializer_Otherwise_add_a_declare_modifier_or_remove_the_redundant_declaration.code];function a(n,t,r,a){var i=e.getTokenAtPosition(t,r);if(e.isIdentifier(i)){var o=i.parent;164!==o.kind||a&&!e.tryAddToSet(a,o)||n.insertModifierBefore(t,133,o)}}n.registerCodeFix({errorCodes:r,getCodeActions:function(r){var i=e.textChanges.ChangeTracker.with(r,(function(e){return a(e,r.sourceFile,r.span.start)}));if(i.length>0)return[n.createCodeFixAction(t,i,e.Diagnostics.Prefix_with_declare,t,e.Diagnostics.Prefix_all_incorrect_property_declarations_with_declare)]},fixIds:[t],getAllCodeActions:function(t){var i=new e.Set;return n.codeFixAll(t,r,(function(e,n){return a(e,n.file,n.start,i)}))}})})(e.codefix||(e.codefix={}))}(d||(d={})),function(e){(function(n){var t="addMissingInvocationForDecorator",r=[e.Diagnostics._0_accepts_too_few_arguments_to_be_used_as_a_decorator_here_Did_you_mean_to_call_it_first_and_write_0.code];function a(n,t,r){var a=e.getTokenAtPosition(t,r),i=e.findAncestor(a,e.isDecorator);e.Debug.assert(!!i,"Expected position to be owned by a decorator.");var o=e.factory.createCallExpression(i.expression,void 0,void 0);n.replaceNode(t,i.expression,o)}n.registerCodeFix({errorCodes:r,getCodeActions:function(r){var i=e.textChanges.ChangeTracker.with(r,(function(e){return a(e,r.sourceFile,r.span.start)}));return[n.createCodeFixAction(t,i,e.Diagnostics.Call_decorator_expression,t,e.Diagnostics.Add_to_all_uncalled_decorators)]},fixIds:[t],getAllCodeActions:function(e){return n.codeFixAll(e,r,(function(e,n){return a(e,n.file,n.start)}))}})})(e.codefix||(e.codefix={}))}(d||(d={})),function(e){(function(n){var t="addNameToNamelessParameter",r=[e.Diagnostics.Parameter_has_a_name_but_no_type_Did_you_mean_0_Colon_1.code];function a(n,t,r){var a=e.getTokenAtPosition(t,r);if(!e.isIdentifier(a))return e.Debug.fail("add-name-to-nameless-parameter operates on identifiers, but got a "+e.Debug.formatSyntaxKind(a.kind));var i=a.parent;if(!e.isParameter(i))return e.Debug.fail("Tried to add a parameter name to a non-parameter: "+e.Debug.formatSyntaxKind(a.kind));var o=i.parent.parameters.indexOf(i);e.Debug.assert(!i.type,"Tried to add a parameter name to a parameter that already had one."),e.Debug.assert(o>-1,"Parameter not found in parent parameter list.");var s=e.factory.createParameterDeclaration(void 0,i.modifiers,i.dotDotDotToken,"arg"+o,i.questionToken,e.factory.createTypeReferenceNode(a,void 0),i.initializer);n.replaceNode(t,a,s)}n.registerCodeFix({errorCodes:r,getCodeActions:function(r){var i=e.textChanges.ChangeTracker.with(r,(function(e){return a(e,r.sourceFile,r.span.start)}));return[n.createCodeFixAction(t,i,e.Diagnostics.Add_parameter_name,t,e.Diagnostics.Add_names_to_all_parameters_without_names)]},fixIds:[t],getAllCodeActions:function(e){return n.codeFixAll(e,r,(function(e,n){return a(e,n.file,n.start)}))}})})(e.codefix||(e.codefix={}))}(d||(d={})),function(e){(function(n){var t="annotateWithTypeFromJSDoc",r=[e.Diagnostics.JSDoc_types_may_be_moved_to_TypeScript_types.code];function a(n,t){var r=e.getTokenAtPosition(n,t);return e.tryCast(e.isParameter(r.parent)?r.parent.parent:r.parent,i)}function i(e){return c(e)&&o(e)}function o(n){return e.isFunctionLikeDeclaration(n)?n.parameters.some(o)||!n.type&&!!e.getJSDocReturnType(n):!n.type&&!!e.getJSDocType(n)}function s(n,t,r){if(e.isFunctionLikeDeclaration(r)&&(e.getJSDocReturnType(r)||r.parameters.some((function(n){return!!e.getJSDocType(n)})))){if(!r.typeParameters){var a=e.getJSDocTypeParameterDeclarations(r);a.length&&n.insertTypeParameters(t,r,a)}var i=e.isArrowFunction(r)&&!e.findChildOfKind(r,20,t);i&&n.insertNodeBefore(t,e.first(r.parameters),e.factory.createToken(20));for(var o=0,s=r.parameters;o<s.length;o++){var c=s[o];if(!c.type){var u=e.getJSDocType(c);u&&n.tryInsertTypeAnnotation(t,c,l(u))}}if(i&&n.insertNodeAfter(t,e.last(r.parameters),e.factory.createToken(21)),!r.type){var d=e.getJSDocReturnType(r);d&&n.tryInsertTypeAnnotation(t,r,l(d))}}else{var p=e.Debug.checkDefined(e.getJSDocType(r),"A JSDocType for this declaration should exist");e.Debug.assert(!r.type,"The JSDocType decl should have a type"),n.tryInsertTypeAnnotation(t,r,l(p))}}function c(n){return e.isFunctionLikeDeclaration(n)||250===n.kind||163===n.kind||164===n.kind}function l(n){switch(n.kind){case 304:case 305:return e.factory.createTypeReferenceNode("any",e.emptyArray);case 308:return u(n);case 307:return l(n.type);case 306:return d(n);case 310:return p(n);case 309:return f(n);case 174:return _(n);default:var t=e.visitEachChild(n,l,e.nullTransformationContext);return e.setEmitFlags(t,1),t}}function u(n){return e.factory.createUnionTypeNode([e.visitNode(n.type,l),e.factory.createTypeReferenceNode("undefined",e.emptyArray)])}function d(n){return e.factory.createUnionTypeNode([e.visitNode(n.type,l),e.factory.createTypeReferenceNode("null",e.emptyArray)])}function p(n){return e.factory.createArrayTypeNode(e.visitNode(n.type,l))}function f(n){var t;return e.factory.createFunctionTypeNode(e.emptyArray,n.parameters.map(m),null!==(t=n.type)&&void 0!==t?t:e.factory.createKeywordTypeNode(128))}function m(n){var t=n.parent.parameters.indexOf(n),r=310===n.type.kind&&t===n.parent.parameters.length-1,a=n.name||(r?"rest":"arg"+t),i=r?e.factory.createToken(25):n.dotDotDotToken;return e.factory.createParameterDeclaration(n.decorators,n.modifiers,i,a,n.questionToken,e.visitNode(n.type,l),n.initializer)}function _(n){var t=n.typeName,r=n.typeArguments;if(e.isIdentifier(n.typeName)){if(e.isJSDocIndexSignature(n))return g(n);var a=n.typeName.text;switch(n.typeName.text){case"String":case"Boolean":case"Object":case"Number":a=a.toLowerCase();break;case"array":case"date":case"promise":a=a[0].toUpperCase()+a.slice(1);break}t=e.factory.createIdentifier(a),r="Array"!==a&&"Promise"!==a||n.typeArguments?e.visitNodes(n.typeArguments,l):e.factory.createNodeArray([e.factory.createTypeReferenceNode("any",e.emptyArray)])}return e.factory.createTypeReferenceNode(t,r)}function g(n){var t=e.factory.createParameterDeclaration(void 0,void 0,void 0,144===n.typeArguments[0].kind?"n":"s",void 0,e.factory.createTypeReferenceNode(144===n.typeArguments[0].kind?"number":"string",[]),void 0),r=e.factory.createTypeLiteralNode([e.factory.createIndexSignature(void 0,void 0,[t],n.typeArguments[1])]);return e.setEmitFlags(r,1),r}n.registerCodeFix({errorCodes:r,getCodeActions:function(r){var i=a(r.sourceFile,r.span.start);if(i){var o=e.textChanges.ChangeTracker.with(r,(function(e){return s(e,r.sourceFile,i)}));return[n.createCodeFixAction(t,o,e.Diagnostics.Annotate_with_type_from_JSDoc,t,e.Diagnostics.Annotate_everything_with_types_from_JSDoc)]}},fixIds:[t],getAllCodeActions:function(e){return n.codeFixAll(e,r,(function(e,n){var t=a(n.file,n.start);t&&s(e,n.file,t)}))}}),n.parameterShouldGetTypeFromJSDoc=i})(e.codefix||(e.codefix={}))}(d||(d={})),function(e){(function(n){var t="convertFunctionToEs6Class",r=[e.Diagnostics.This_constructor_function_may_be_converted_to_a_class_declaration.code];function a(n,t,r,a,c,l){var u=a.getSymbolAtLocation(e.getTokenAtPosition(t,r));if(u&&u.valueDeclaration&&19&u.flags){var d=u.valueDeclaration;if(e.isFunctionDeclaration(d))n.replaceNode(t,d,g(d));else if(e.isVariableDeclaration(d)){var p=_(d);if(!p)return;var f=d.parent.parent;e.isVariableDeclarationList(d.parent)&&d.parent.declarations.length>1?(n.delete(t,d),n.insertNodeAfter(t,f,p)):n.replaceNode(t,f,p)}}function m(r){var a=[];return r.members&&r.members.forEach((function(e,r){if("constructor"===r&&e.valueDeclaration)n.delete(t,e.valueDeclaration.parent);else{var i=d(e,void 0);i&&a.push.apply(a,i)}})),r.exports&&r.exports.forEach((function(n){if("prototype"===n.name&&n.declarations){var t=n.declarations[0];if(1===n.declarations.length&&e.isPropertyAccessExpression(t)&&e.isBinaryExpression(t.parent)&&62===t.parent.operatorToken.kind&&e.isObjectLiteralExpression(t.parent.right)){var r=t.parent.right,i=d(r.symbol,void 0);i&&a.push.apply(a,i)}}else{i=d(n,[e.factory.createToken(123)]);i&&a.push.apply(a,i)}})),a;function u(n,t){return e.isAccessExpression(n)?!(!e.isPropertyAccessExpression(n)||!o(n))||e.isFunctionLike(t):e.every(n.properties,(function(n){return!(!e.isMethodDeclaration(n)&&!e.isGetOrSetAccessorDeclaration(n))||(!!(e.isPropertyAssignment(n)&&e.isFunctionExpression(n.initializer)&&n.name)||!!o(n))}))}function d(r,a){var d=[];if(!(8192&r.flags)&&!(4096&r.flags))return d;var p=r.valueDeclaration,f=p.parent,m=f.right;if(!u(p,m))return d;var _=f.parent&&234===f.parent.kind?f.parent:f;if(n.delete(t,_),!m)return d.push(e.factory.createPropertyDeclaration([],a,r.name,void 0,void 0,void 0)),d;if(e.isAccessExpression(p)&&(e.isFunctionExpression(m)||e.isArrowFunction(m))){var g=e.getQuotePreference(t,c),y=s(p,l,g);return y?v(d,m,y):d}if(e.isObjectLiteralExpression(m))return e.flatMap(m.properties,(function(n){return e.isMethodDeclaration(n)||e.isGetOrSetAccessorDeclaration(n)?d.concat(n):e.isPropertyAssignment(n)&&e.isFunctionExpression(n.initializer)?v(d,n.initializer,n.name):o(n)?d:[]}));if(e.isSourceFileJS(t))return d;if(!e.isPropertyAccessExpression(p))return d;var h=e.factory.createPropertyDeclaration(void 0,a,p.name,void 0,void 0,m);return e.copyLeadingComments(f.parent,h,t),d.push(h),d;function v(n,t,r){return e.isFunctionExpression(t)?b(n,t,r):E(n,t,r)}function b(n,r,o){var s=e.concatenate(a,i(r,129)),c=e.factory.createMethodDeclaration(void 0,s,void 0,o,void 0,void 0,r.parameters,void 0,r.body);return e.copyLeadingComments(f,c,t),n.concat(c)}function E(n,r,o){var s,c=r.body;s=231===c.kind?c:e.factory.createBlock([e.factory.createReturnStatement(c)]);var l=e.concatenate(a,i(r,129)),u=e.factory.createMethodDeclaration(void 0,l,void 0,o,void 0,void 0,r.parameters,void 0,s);return e.copyLeadingComments(f,u,t),n.concat(u)}}}function _(n){var t=n.initializer;if(t&&e.isFunctionExpression(t)&&e.isIdentifier(n.name)){var r=m(n.symbol);t.body&&r.unshift(e.factory.createConstructorDeclaration(void 0,void 0,t.parameters,t.body));var a=i(n.parent.parent,92),o=e.factory.createClassDeclaration(void 0,a,n.name,void 0,void 0,r);return o}}function g(n){var t=m(u);n.body&&t.unshift(e.factory.createConstructorDeclaration(void 0,void 0,n.parameters,n.body));var r=i(n,92),a=e.factory.createClassDeclaration(void 0,r,n.name,void 0,void 0,t);return a}}function i(n,t){return e.filter(n.modifiers,(function(e){return e.kind===t}))}function o(n){return!!n.name&&!(!e.isIdentifier(n.name)||"constructor"!==n.name.text)}function s(n,t,r){if(e.isPropertyAccessExpression(n))return n.name;var a=n.argumentExpression;return e.isNumericLiteral(a)?a:e.isStringLiteralLike(a)?e.isIdentifierText(a.text,t.target)?e.factory.createIdentifier(a.text):e.isNoSubstitutionTemplateLiteral(a)?e.factory.createStringLiteral(a.text,0===r):a:void 0}n.registerCodeFix({errorCodes:r,getCodeActions:function(r){var i=e.textChanges.ChangeTracker.with(r,(function(e){return a(e,r.sourceFile,r.span.start,r.program.getTypeChecker(),r.preferences,r.program.getCompilerOptions())}));return[n.createCodeFixAction(t,i,e.Diagnostics.Convert_function_to_an_ES2015_class,t,e.Diagnostics.Convert_all_constructor_functions_to_classes)]},fixIds:[t],getAllCodeActions:function(e){return n.codeFixAll(e,r,(function(n,t){return a(n,t.file,t.start,e.program.getTypeChecker(),e.preferences,e.program.getCompilerOptions())}))}})})(e.codefix||(e.codefix={}))}(d||(d={})),function(e){(function(n){var t,r="convertToAsyncFunction",a=[e.Diagnostics.This_may_be_converted_to_an_async_function.code],o=!0;function s(n,t,r,a){var i,o=e.getTokenAtPosition(t,r);if(i=e.isIdentifier(o)&&e.isVariableDeclaration(o.parent)&&o.parent.initializer&&e.isFunctionLikeDeclaration(o.parent.initializer)?o.parent.initializer:e.tryCast(e.getContainingFunction(e.getTokenAtPosition(t,r)),e.canBeConvertedToAsync),i){var s=new e.Map,u=e.isInJSFile(i),d=l(i,a),f=p(i,a,s);if(e.returnsPromise(f,a)){var m=f.body&&e.isBlock(f.body)?c(f.body,a):e.emptyArray,g={checker:a,synthNamesMap:s,setOfExpressionsToReturn:d,isInJSFile:u};if(m.length){var y=i.modifiers?i.modifiers.end:i.decorators?e.skipTrivia(t.text,i.decorators.end):i.getStart(t),h=i.modifiers?{prefix:" "}:{suffix:" "};n.insertModifierAt(t,y,129,h);for(var v=function(r){e.forEachChild(r,(function a(i){if(e.isCallExpression(i)){var o=_(i,g);n.replaceNodeWithNodes(t,r,o)}else e.isFunctionLike(i)||e.forEachChild(i,a)}))},b=0,E=m;b<E.length;b++){var T=E[b];v(T)}}}}}function c(n,t){var r=[];return e.forEachReturnStatement(n,(function(n){e.isReturnStatementWithFixablePromiseHandler(n,t)&&r.push(n)})),r}function l(n,t){if(!n.body)return new e.Set;var r=new e.Set;return e.forEachChild(n.body,(function n(a){u(a,t,"then")?(r.add(e.getNodeId(a)),e.forEach(a.arguments,n)):u(a,t,"catch")?(r.add(e.getNodeId(a)),e.forEachChild(a,n)):d(a,t)?r.add(e.getNodeId(a)):e.forEachChild(a,n)})),r}function u(n,t,r){if(!e.isCallExpression(n))return!1;var a=e.hasPropertyAccessExpressionWithName(n,r),i=a&&t.getTypeAtLocation(n);return!(!i||!t.getPromisedTypeOfPromise(i))}function d(n,t){return!!e.isExpression(n)&&!!t.getPromisedTypeOfPromise(t.getTypeAtLocation(n))}function p(n,t,r){var a=new e.Map,i=e.createMultiMap();return e.forEachChild(n,(function n(o){if(e.isIdentifier(o)){var s=t.getSymbolAtLocation(o);if(s){var c=t.getTypeAtLocation(o),l=x(c,t),u=e.getSymbolId(s).toString();if(!l||e.isParameter(o.parent)||e.isFunctionLikeDeclaration(o.parent)||r.has(u)){if(o.parent&&(e.isParameter(o.parent)||e.isVariableDeclaration(o.parent)||e.isBindingElement(o.parent))){var d=o.text,p=i.get(d);if(p&&p.some((function(e){return e!==s}))){var m=f(o,i);a.set(u,m.identifier),r.set(u,m),i.add(d,s)}else{var _=e.getSynthesizedDeepClone(o);r.set(u,N(_)),i.add(d,s)}}}else{var g=e.firstOrUndefined(l.parameters),y=(null===g||void 0===g?void 0:g.valueDeclaration)&&e.isParameter(g.valueDeclaration)&&e.tryCast(g.valueDeclaration.name,e.isIdentifier)||e.factory.createUniqueName("result",16),h=f(y,i);r.set(u,h),i.add(y.text,s)}}}else e.forEachChild(o,n)})),e.getSynthesizedDeepCloneWithReplacements(n,!0,(function(n){if(e.isBindingElement(n)&&e.isIdentifier(n.name)&&e.isObjectBindingPattern(n.parent)){var r=t.getSymbolAtLocation(n.name),i=r&&a.get(String(e.getSymbolId(r)));if(i&&i.text!==(n.name||n.propertyName).getText())return e.factory.createBindingElement(n.dotDotDotToken,n.propertyName||n.name,i,n.initializer)}else if(e.isIdentifier(n)){r=t.getSymbolAtLocation(n),i=r&&a.get(String(e.getSymbolId(r)));if(i)return e.factory.createIdentifier(i.text)}}))}function f(n,t){var r=(t.get(n.text)||e.emptyArray).length,a=0===r?n:e.factory.createIdentifier(n.text+"_"+r);return N(a)}function m(){return o=!1,e.emptyArray}function _(n,t,r){if(u(n,t.checker,"then"))return 0===n.arguments.length?m():h(n,t,r);if(u(n,t.checker,"catch"))return g(n,t,r);if(e.isPropertyAccessExpression(n))return _(n.expression,t,r);var a=t.checker.getTypeAtLocation(n);return a&&t.checker.getPromisedTypeOfPromise(a)?(e.Debug.assertNode(n.original.parent,e.isPropertyAccessExpression),v(n,t,r)):m()}function g(n,t,r){var a,i=e.singleOrUndefined(n.arguments),o=i?A(i,t):void 0;r&&!w(n,t)&&(R(r)?(a=r,t.synthNamesMap.forEach((function(e,n){if(e.identifier.text===r.identifier.text){var a=y(r);t.synthNamesMap.set(n,a)}}))):a=N(e.factory.createUniqueName("result",16),r.types),a.hasBeenDeclared=!0);var s,c,l=e.factory.createBlock(_(n.expression,t,a)),u=i?T(i,a,o,n,t):e.emptyArray,d=o?R(o)?o.identifier.text:o.bindingPattern:"e",p=e.factory.createVariableDeclaration(d),f=e.factory.createCatchClause(p,e.factory.createBlock(u));if(a&&!w(n,t)){c=e.getSynthesizedDeepClone(a.identifier);var m=a.types,g=t.checker.getUnionType(m,2),h=t.isInJSFile?void 0:t.checker.typeToTypeNode(g,void 0,void 0),v=[e.factory.createVariableDeclaration(c,void 0,h)];s=e.factory.createVariableStatement(void 0,e.factory.createVariableDeclarationList(v,1))}var b=e.factory.createTryStatement(l,f,void 0),E=r&&c&&O(r)&&e.factory.createVariableStatement(void 0,e.factory.createVariableDeclarationList([e.factory.createVariableDeclaration(e.getSynthesizedDeepClone(r.bindingPattern),void 0,void 0,c)],2));return e.compact([s,b,E])}function y(n){var t=e.factory.createUniqueName(n.identifier.text,16);return N(t)}function h(n,t,r){var a=n.arguments,i=a[0],o=a[1],s=A(i,t),c=T(i,r,s,n,t);if(o){var l=A(o,t),u=e.factory.createBlock(_(n.expression,t,s).concat(c)),d=T(o,r,l,n,t),p=l?R(l)?l.identifier.text:l.bindingPattern:"e",f=e.factory.createVariableDeclaration(p),m=e.factory.createCatchClause(f,e.factory.createBlock(d));return[e.factory.createTryStatement(u,m,void 0)]}return _(n.expression,t,s).concat(c)}function v(n,t,r){return w(n,t)?[e.factory.createReturnStatement(e.getSynthesizedDeepClone(n))]:b(r,e.factory.createAwaitExpression(n),void 0)}function b(n,t,r){return!n||C(n)?[e.factory.createExpressionStatement(t)]:R(n)&&n.hasBeenDeclared?[e.factory.createExpressionStatement(e.factory.createAssignment(e.getSynthesizedDeepClone(n.identifier),t))]:[e.factory.createVariableStatement(void 0,e.factory.createVariableDeclarationList([e.factory.createVariableDeclaration(e.getSynthesizedDeepClone(I(n)),void 0,r,t)],2))]}function E(n,t){if(t&&n){var r=e.factory.createUniqueName("result",16);return i(i([],b(N(r),n,t)),[e.factory.createReturnStatement(r)])}return[e.factory.createReturnStatement(n)]}function T(n,t,r,a,i){var o,s,c,l,u;switch(n.kind){case 103:break;case 202:case 78:if(!r)break;var d=e.factory.createCallExpression(e.getSynthesizedDeepClone(n),void 0,R(r)?[r.identifier]:[]);if(w(a,i))return E(d,null===(o=a.typeArguments)||void 0===o?void 0:o[0]);var p=i.checker.getTypeAtLocation(n),f=i.checker.getSignaturesOfType(p,0);if(!f.length)return m();var _=f[0].getReturnType(),g=b(t,e.factory.createAwaitExpression(d),null===(s=a.typeArguments)||void 0===s?void 0:s[0]);return t&&t.types.push(_),g;case 209:case 210:var y=n.body,h=null===(c=x(i.checker.getTypeAtLocation(n),i.checker))||void 0===c?void 0:c.getReturnType();if(e.isBlock(y)){for(var v=[],T=!1,A=0,C=y.statements;A<C.length;A++){var I=C[A];if(e.isReturnStatement(I))if(T=!0,e.isReturnStatementWithFixablePromiseHandler(I,i.checker))v=v.concat(D(i,[I],t));else{var N=h&&I.expression?S(i.checker,h,I.expression):I.expression;v.push.apply(v,E(N,null===(l=a.typeArguments)||void 0===l?void 0:l[0]))}else v.push(I)}return w(a,i)?v.map((function(n){return e.getSynthesizedDeepClone(n)})):L(v,t,i,T)}var k=e.isFixablePromiseHandler(y,i.checker)?[e.factory.createReturnStatement(y)]:e.emptyArray,O=D(i,k,t);if(O.length>0)return O;if(h){N=S(i.checker,h,y);if(w(a,i))return E(N,null===(u=a.typeArguments)||void 0===u?void 0:u[0]);var P=b(t,N,void 0);return t&&t.types.push(h),P}return m();default:return m()}return e.emptyArray}function S(n,t,r){var a=e.getSynthesizedDeepClone(r);return n.getPromisedTypeOfPromise(t)?e.factory.createAwaitExpression(a):a}function x(n,t){var r=t.getSignaturesOfType(n,0);return e.lastOrUndefined(r)}function L(n,t,r,a){for(var i=[],o=0,s=n;o<s.length;o++){var c=s[o];if(e.isReturnStatement(c)){if(c.expression){var l=d(c.expression,r.checker)?e.factory.createAwaitExpression(c.expression):c.expression;void 0===t?i.push(e.factory.createExpressionStatement(l)):i.push(e.factory.createVariableStatement(void 0,e.factory.createVariableDeclarationList([e.factory.createVariableDeclaration(I(t),void 0,void 0,l)],2)))}}else i.push(e.getSynthesizedDeepClone(c))}return a||void 0===t||i.push(e.factory.createVariableStatement(void 0,e.factory.createVariableDeclarationList([e.factory.createVariableDeclaration(I(t),void 0,void 0,e.factory.createIdentifier("undefined"))],2))),i}function D(n,t,r){for(var a=[],i=0,o=t;i<o.length;i++){var s=o[i];e.forEachChild(s,(function t(i){if(e.isCallExpression(i)){var o=_(i,n,r);if(a=a.concat(o),a.length>0)return}else e.isFunctionLike(i)||e.forEachChild(i,t)}))}return a}function A(n,t){var r,a=[];if(e.isFunctionLikeDeclaration(n)){if(n.parameters.length>0){var i=n.parameters[0].name;r=o(i)}}else e.isIdentifier(n)?r=s(n):e.isPropertyAccessExpression(n)&&e.isIdentifier(n.name)&&(r=s(n.name));if(r&&(!("identifier"in r)||"undefined"!==r.identifier.text))return r;function o(n){if(e.isIdentifier(n))return s(n);var t=e.flatMap(n.elements,(function(n){return e.isOmittedExpression(n)?[]:[o(n.name)]}));return k(n,t)}function s(n){var r=l(n),i=c(r);if(!i)return N(n,a);var o=t.synthNamesMap.get(e.getSymbolId(i).toString());return o||N(n,a)}function c(e){return e.symbol?e.symbol:t.checker.getSymbolAtLocation(e)}function l(e){return e.original?e.original:e}}function C(n){return!n||(R(n)?!n.identifier.text:e.every(n.elements,C))}function I(e){return R(e)?e.identifier:e.bindingPattern}function N(e,n){return void 0===n&&(n=[]),{kind:0,identifier:e,types:n,hasBeenDeclared:!1}}function k(n,t,r){return void 0===t&&(t=e.emptyArray),void 0===r&&(r=[]),{kind:1,bindingPattern:n,elements:t,types:r}}function R(e){return 0===e.kind}function O(e){return 1===e.kind}function w(n,t){return!!n.original&&t.setOfExpressionsToReturn.has(e.getNodeId(n.original))}n.registerCodeFix({errorCodes:a,getCodeActions:function(t){o=!0;var a=e.textChanges.ChangeTracker.with(t,(function(e){return s(e,t.sourceFile,t.span.start,t.program.getTypeChecker())}));return o?[n.createCodeFixAction(r,a,e.Diagnostics.Convert_to_async_function,r,e.Diagnostics.Convert_all_to_async_functions)]:[]},fixIds:[r],getAllCodeActions:function(e){return n.codeFixAll(e,a,(function(n,t){return s(n,t.file,t.start,e.program.getTypeChecker())}))}}),function(e){e[e["Identifier"]=0]="Identifier",e[e["BindingPattern"]=1]="BindingPattern"}(t||(t={}))})(e.codefix||(e.codefix={}))}(d||(d={})),function(e){(function(n){function t(n,t,r,a){for(var i=0,o=n.imports;i<o.length;i++){var s=o[i],c=e.getResolvedModule(n,s.text);if(c&&c.resolvedFileName===t.fileName){var l=e.importFromModuleSpecifier(s);switch(l.kind){case 261:r.replaceNode(n,l,e.makeImport(l.name,void 0,s,a));break;case 204:e.isRequireCall(l,!1)&&r.replaceNode(n,l,e.factory.createPropertyAccessExpression(e.getSynthesizedDeepClone(l),"default"));break}}}}function r(n,t,r,o,l){var u={original:T(n),additional:new e.Set},d=a(n,t,u);i(n,d,r);for(var p,f=!1,m=0,_=e.filter(n.statements,e.isVariableStatement);m<_.length;m++){var g=_[m],y=c(n,g,r,t,u,o,l);y&&e.copyEntries(y,null!==p&&void 0!==p?p:p=new e.Map)}for(var h=0,v=e.filter(n.statements,(function(n){return!e.isVariableStatement(n)}));h<v.length;h++){g=v[h];var b=s(n,g,t,r,u,o,d,p,l);f=f||b}return null===p||void 0===p||p.forEach((function(e,t){r.replaceNode(n,t,e)})),f}function a(n,t,r){var a=new e.Map;return o(n,(function(n){var i=n.name,o=i.text,s=i.originalKeywordKind;!a.has(o)&&(void 0!==s&&e.isNonContextualKeyword(s)||t.resolveName(o,n,111551,!0))&&a.set(o,E("_"+o,r))})),a}function i(n,t,r){o(n,(function(a,i){if(!i){var o=a.name.text;r.replaceNode(n,a,e.factory.createIdentifier(t.get(o)||o))}}))}function o(n,t){n.forEachChild((function r(a){if(e.isPropertyAccessExpression(a)&&e.isExportsOrModuleExportsOrAlias(n,a.expression)&&e.isIdentifier(a.name)){var i=a.parent;t(a,e.isBinaryExpression(i)&&i.left===a&&62===i.operatorToken.kind)}a.forEachChild(r)}))}function s(n,t,r,a,i,o,s,l,d){switch(t.kind){case 233:return c(n,t,a,r,i,o,d),!1;case 234:var p=t.expression;switch(p.kind){case 204:return e.isRequireCall(p,!0)&&a.replaceNode(n,t,e.makeImport(void 0,void 0,p.arguments[0],d)),!1;case 217:var f=p.operatorToken;return 62===f.kind&&u(n,r,p,a,s,l)}default:return!1}}function c(n,t,r,a,i,o,s){var c,u=t.declarationList,d=!1,p=e.map(u.declarations,(function(t){var r=t.name,c=t.initializer;if(c){if(e.isExportsOrModuleExportsOrAlias(n,c))return d=!0,k([]);if(e.isRequireCall(c,!0))return d=!0,v(r,c.arguments[0],a,i,o,s);if(e.isPropertyAccessExpression(c)&&e.isRequireCall(c.expression,!0))return d=!0,l(r,c.name.text,c.expression.arguments[0],i,s)}return k([e.factory.createVariableStatement(void 0,e.factory.createVariableDeclarationList([t],u.flags))])}));if(d)return r.replaceNodeWithNodes(n,t,e.flatMap(p,(function(e){return e.newImports}))),e.forEach(p,(function(n){n.useSitesToUnqualify&&e.copyEntries(n.useSitesToUnqualify,null!==c&&void 0!==c?c:c=new e.Map)})),c}function l(n,t,r,a,i){switch(n.kind){case 197:case 198:var o=E(t,a);return k([A(o,t,r,i),I(void 0,n,e.factory.createIdentifier(o))]);case 78:return k([A(n.text,t,r,i)]);default:return e.Debug.assertNever(n,"Convert to ES6 module got invalid syntax form "+n.kind)}}function u(n,t,r,a,i,o){var s=r.left,c=r.right;if(!e.isPropertyAccessExpression(s))return!1;if(e.isExportsOrModuleExportsOrAlias(n,s)){if(!e.isExportsOrModuleExportsOrAlias(n,c)){var l=e.isObjectLiteralExpression(c)?d(c,o):e.isRequireCall(c,!0)?f(c.arguments[0],t):void 0;return l?(a.replaceNodeWithNodes(n,r.parent,l[0]),l[1]):(a.replaceRangeWithText(n,e.createRange(s.getStart(n),c.pos),"export default"),!0)}a.delete(n,r.parent)}else e.isExportsOrModuleExportsOrAlias(n,s.expression)&&p(n,r,a,i);return!1}function d(n,t){var r=e.mapAllOrFail(n.properties,(function(n){switch(n.kind){case 168:case 169:case 290:case 291:return;case 289:return e.isIdentifier(n.name)?y(n.name.text,n.initializer,t):void 0;case 166:return e.isIdentifier(n.name)?L(n.name.text,[e.factory.createToken(92)],n,t):void 0;default:e.Debug.assertNever(n,"Convert to ES6 got invalid prop kind "+n.kind)}}));return r&&[r,!1]}function p(n,t,r,a){var i=t.left.name.text,o=a.get(i);if(void 0!==o){var s=[I(void 0,o,t.right),N([e.factory.createExportSpecifier(o,i)])];r.replaceNodeWithNodes(n,t.parent,s)}else g(t,n,r)}function f(n,t){var r=n.text,a=t.getSymbolAtLocation(n),i=a?a.exports:e.emptyMap;return i.has("export=")?[[_(r)],!0]:i.has("default")?i.size>1?[[m(r),_(r)],!0]:[[_(r)],!0]:[[m(r)],!1]}function m(e){return N(void 0,e)}function _(n){return N([e.factory.createExportSpecifier(void 0,"default")],n)}function g(n,t,r){var a=n.left,i=n.right,o=n.parent,s=a.name.text;if(!(e.isFunctionExpression(i)||e.isArrowFunction(i)||e.isClassExpression(i))||i.name&&i.name.text!==s)r.replaceNodeRangeWithNodes(t,a.expression,e.findChildOfKind(a,24,t),[e.factory.createToken(92),e.factory.createToken(84)],{joiner:" ",suffix:" "});else{r.replaceRange(t,{pos:a.getStart(t),end:i.getStart(t)},e.factory.createToken(92),{suffix:" "}),i.name||r.insertName(t,i,s);var c=e.findChildOfKind(o,26,t);c&&r.delete(t,c)}}function y(n,t,r){var a=[e.factory.createToken(92)];switch(t.kind){case 209:var i=t.name;if(i&&i.text!==n)return o();case 210:return L(n,a,t,r);case 222:return D(n,a,t,r);default:return o()}function o(){return I(a,e.factory.createIdentifier(n),h(t,r))}}function h(n,t){return t&&e.some(e.arrayFrom(t.keys()),(function(t){return e.rangeContainsRange(n,t)}))?e.isArray(n)?e.getSynthesizedDeepClonesWithReplacements(n,!0,r):e.getSynthesizedDeepCloneWithReplacements(n,!0,r):n;function r(e){if(202===e.kind){var n=t.get(e);return t.delete(e),n}}}function v(t,r,a,i,o,s){switch(t.kind){case 197:var c=e.mapAllOrFail(t.elements,(function(n){return n.dotDotDotToken||n.initializer||n.propertyName&&!e.isIdentifier(n.propertyName)||!e.isIdentifier(n.name)?void 0:C(n.propertyName&&n.propertyName.text,n.name.text)}));if(c)return k([e.makeImport(void 0,c,r,s)]);case 198:var l=E(n.moduleSpecifierToValidIdentifier(r.text,o),i);return k([e.makeImport(e.factory.createIdentifier(l),void 0,r,s),I(void 0,e.getSynthesizedDeepClone(t),e.factory.createIdentifier(l))]);case 78:return b(t,r,a,i,s);default:return e.Debug.assertNever(t,"Convert to ES6 module got invalid name kind "+t.kind)}}function b(n,t,r,a,i){for(var o,s=r.getSymbolAtLocation(n),c=new e.Map,l=!1,u=0,d=a.original.get(n.text);u<d.length;u++){var p=d[u];if(r.getSymbolAtLocation(p)===s&&p!==n){var f=p.parent;if(e.isPropertyAccessExpression(f)){var m=f.name.text;if("default"===m){l=!0;var _=p.getText();(null!==o&&void 0!==o?o:o=new e.Map).set(f,e.factory.createIdentifier(_))}else{e.Debug.assert(f.expression===p,"Didn't expect expression === use");var g=c.get(m);void 0===g&&(g=E(m,a),c.set(m,g)),(null!==o&&void 0!==o?o:o=new e.Map).set(f,e.factory.createIdentifier(g))}}else l=!0}}var y=0===c.size?void 0:e.arrayFrom(e.mapIterator(c.entries(),(function(n){var t=n[0],r=n[1];return e.factory.createImportSpecifier(t===r?void 0:e.factory.createIdentifier(t),e.factory.createIdentifier(r))})));return y||(l=!0),k([e.makeImport(l?e.getSynthesizedDeepClone(n):void 0,y,t,i)],o)}function E(e,n){while(n.original.has(e)||n.additional.has(e))e="_"+e;return n.additional.add(e),e}function T(n){var t=e.createMultiMap();return S(n,(function(e){return t.add(e.text,e)})),t}function S(n,t){e.isIdentifier(n)&&x(n)&&t(n),n.forEachChild((function(e){return S(e,t)}))}function x(e){var n=e.parent;switch(n.kind){case 202:return n.name!==e;case 199:return n.propertyName!==e;case 266:return n.propertyName!==e;default:return!0}}function L(n,t,r,a){return e.factory.createFunctionDeclaration(e.getSynthesizedDeepClones(r.decorators),e.concatenate(t,e.getSynthesizedDeepClones(r.modifiers)),e.getSynthesizedDeepClone(r.asteriskToken),n,e.getSynthesizedDeepClones(r.typeParameters),e.getSynthesizedDeepClones(r.parameters),e.getSynthesizedDeepClone(r.type),e.factory.converters.convertToFunctionBlock(h(r.body,a)))}function D(n,t,r,a){return e.factory.createClassDeclaration(e.getSynthesizedDeepClones(r.decorators),e.concatenate(t,e.getSynthesizedDeepClones(r.modifiers)),n,e.getSynthesizedDeepClones(r.typeParameters),e.getSynthesizedDeepClones(r.heritageClauses),h(r.members,a))}function A(n,t,r,a){return"default"===t?e.makeImport(e.factory.createIdentifier(n),void 0,r,a):e.makeImport(void 0,[C(t,n)],r,a)}function C(n,t){return e.factory.createImportSpecifier(void 0!==n&&n!==t?e.factory.createIdentifier(n):void 0,e.factory.createIdentifier(t))}function I(n,t,r){return e.factory.createVariableStatement(n,e.factory.createVariableDeclarationList([e.factory.createVariableDeclaration(t,void 0,void 0,r)],2))}function N(n,t){return e.factory.createExportDeclaration(void 0,void 0,!1,n&&e.factory.createNamedExports(n),void 0===t?void 0:e.factory.createStringLiteral(t))}function k(e,n){return{newImports:e,useSitesToUnqualify:n}}n.registerCodeFix({errorCodes:[e.Diagnostics.File_is_a_CommonJS_module_it_may_be_converted_to_an_ES6_module.code],getCodeActions:function(a){var i=a.sourceFile,o=a.program,s=a.preferences,c=e.textChanges.ChangeTracker.with(a,(function(n){var a=r(i,o.getTypeChecker(),n,o.getCompilerOptions().target,e.getQuotePreference(i,s));if(a)for(var c=0,l=o.getSourceFiles();c<l.length;c++){var u=l[c];t(u,i,n,e.getQuotePreference(u,s))}}));return[n.createCodeFixActionWithoutFixAll("convertToEs6Module",c,e.Diagnostics.Convert_to_ES6_module)]}})})(e.codefix||(e.codefix={}))}(d||(d={})),function(e){(function(n){var t="correctQualifiedNameToIndexedAccessType",r=[e.Diagnostics.Cannot_access_0_1_because_0_is_a_type_but_not_a_namespace_Did_you_mean_to_retrieve_the_type_of_the_property_1_in_0_with_0_1.code];function a(n,t){var r=e.findAncestor(e.getTokenAtPosition(n,t),e.isQualifiedName);return e.Debug.assert(!!r,"Expected position to be owned by a qualified name."),e.isIdentifier(r.left)?r:void 0}function i(n,t,r){var a=r.right.text,i=e.factory.createIndexedAccessTypeNode(e.factory.createTypeReferenceNode(r.left,void 0),e.factory.createLiteralTypeNode(e.factory.createStringLiteral(a)));n.replaceNode(t,r,i)}n.registerCodeFix({errorCodes:r,getCodeActions:function(r){var o=a(r.sourceFile,r.span.start);if(o){var s=e.textChanges.ChangeTracker.with(r,(function(e){return i(e,r.sourceFile,o)})),c=o.left.text+'["'+o.right.text+'"]';return[n.createCodeFixAction(t,s,[e.Diagnostics.Rewrite_as_the_indexed_access_type_0,c],t,e.Diagnostics.Rewrite_all_as_indexed_access_types)]}},fixIds:[t],getAllCodeActions:function(e){return n.codeFixAll(e,r,(function(e,n){var t=a(n.file,n.start);t&&i(e,n.file,t)}))}})})(e.codefix||(e.codefix={}))}(d||(d={})),function(e){(function(n){var t=[e.Diagnostics.Re_exporting_a_type_when_the_isolatedModules_flag_is_provided_requires_using_export_type.code],r="convertToTypeOnlyExport";function a(n,t){return e.tryCast(e.getTokenAtPosition(t,n.start).parent,e.isExportSpecifier)}function i(n,t,r){if(t){var a=t.parent,i=a.parent,s=o(t,r);if(s.length===a.elements.length)n.insertModifierBefore(r.sourceFile,149,a);else{var c=e.factory.updateExportDeclaration(i,i.decorators,i.modifiers,!1,e.factory.updateNamedExports(a,e.filter(a.elements,(function(n){return!e.contains(s,n)}))),i.moduleSpecifier),l=e.factory.createExportDeclaration(void 0,void 0,!0,e.factory.createNamedExports(s),i.moduleSpecifier);n.replaceNode(r.sourceFile,i,c,{leadingTriviaOption:e.textChanges.LeadingTriviaOption.IncludeAll,trailingTriviaOption:e.textChanges.TrailingTriviaOption.Exclude}),n.insertNodeAfter(r.sourceFile,i,l)}}}function o(n,r){var a=n.parent;if(1===a.elements.length)return a.elements;var i=e.getDiagnosticsWithinSpan(e.createTextSpanFromNode(a),r.program.getSemanticDiagnostics(r.sourceFile,r.cancellationToken));return e.filter(a.elements,(function(r){var a;return r===n||(null===(a=e.findDiagnosticForNode(r,i))||void 0===a?void 0:a.code)===t[0]}))}n.registerCodeFix({errorCodes:t,getCodeActions:function(t){var o=e.textChanges.ChangeTracker.with(t,(function(e){return i(e,a(t.span,t.sourceFile),t)}));if(o.length)return[n.createCodeFixAction(r,o,e.Diagnostics.Convert_to_type_only_export,r,e.Diagnostics.Convert_all_re_exported_types_to_type_only_exports)]},fixIds:[r],getAllCodeActions:function(r){var o=new e.Map;return n.codeFixAll(r,t,(function(n,t){var s=a(t,r.sourceFile);s&&e.addToSeen(o,e.getNodeId(s.parent.parent))&&i(n,s,r)}))}})})(e.codefix||(e.codefix={}))}(d||(d={})),function(e){(function(n){var t=[e.Diagnostics.This_import_is_never_used_as_a_value_and_must_use_import_type_because_importsNotUsedAsValues_is_set_to_error.code],r="convertToTypeOnlyImport";function a(n,t){return e.tryCast(e.getTokenAtPosition(t,n.start).parent,e.isImportDeclaration)}function i(n,t,r){if(null===t||void 0===t?void 0:t.importClause){var a=t.importClause;n.insertText(r.sourceFile,t.getStart()+"import".length," type"),a.name&&a.namedBindings&&(n.deleteNodeRangeExcludingEnd(r.sourceFile,a.name,t.importClause.namedBindings),n.insertNodeBefore(r.sourceFile,t,e.factory.updateImportDeclaration(t,void 0,void 0,e.factory.createImportClause(!0,a.name,void 0),t.moduleSpecifier)))}}n.registerCodeFix({errorCodes:t,getCodeActions:function(t){var o=e.textChanges.ChangeTracker.with(t,(function(e){var n=a(t.span,t.sourceFile);i(e,n,t)}));if(o.length)return[n.createCodeFixAction(r,o,e.Diagnostics.Convert_to_type_only_import,r,e.Diagnostics.Convert_all_imports_not_used_as_a_value_to_type_only_imports)]},fixIds:[r],getAllCodeActions:function(e){return n.codeFixAll(e,t,(function(n,t){var r=a(t,e.sourceFile);i(n,r,e)}))}})})(e.codefix||(e.codefix={}))}(d||(d={})),function(e){(function(n){var t="convertLiteralTypeToMappedType",r=[e.Diagnostics._0_only_refers_to_a_type_but_is_being_used_as_a_value_here_Did_you_mean_to_use_1_in_0.code];function a(n,t){var r=e.getTokenAtPosition(n,t);if(e.isIdentifier(r)){var a=e.cast(r.parent.parent,e.isPropertySignature),i=r.getText(n);return{container:e.cast(a.parent,e.isTypeLiteralNode),typeNode:a.type,constraint:i,name:"K"===i?"P":"K"}}}function i(n,t,r){var a=r.container,i=r.typeNode,o=r.constraint,s=r.name;n.replaceNode(t,a,e.factory.createMappedTypeNode(void 0,e.factory.createTypeParameterDeclaration(s,e.factory.createTypeReferenceNode(o)),void 0,void 0,i))}n.registerCodeFix({errorCodes:r,getCodeActions:function(r){var o=r.sourceFile,s=r.span,c=a(o,s.start);if(c){var l=c.name,u=c.constraint,d=e.textChanges.ChangeTracker.with(r,(function(e){return i(e,o,c)}));return[n.createCodeFixAction(t,d,[e.Diagnostics.Convert_0_to_1_in_0,u,l],t,e.Diagnostics.Convert_all_type_literals_to_mapped_type)]}},fixIds:[t],getAllCodeActions:function(e){return n.codeFixAll(e,r,(function(e,n){var t=a(n.file,n.start);t&&i(e,n.file,t)}))}})})(e.codefix||(e.codefix={}))}(d||(d={})),function(e){(function(n){var t=[e.Diagnostics.Class_0_incorrectly_implements_interface_1.code,e.Diagnostics.Class_0_incorrectly_implements_class_1_Did_you_mean_to_extend_1_and_inherit_its_members_as_a_subclass.code],r="fixClassIncorrectlyImplementsInterface";function a(n,t){return e.Debug.checkDefined(e.getContainingClass(e.getTokenAtPosition(n,t)),"There should be a containing class")}function i(n){return!n.valueDeclaration||!(8&e.getEffectiveModifierFlags(n.valueDeclaration))}function o(t,r,a,o,c,l){var u=t.program.getTypeChecker(),d=s(o,u),p=u.getTypeAtLocation(r),f=u.getPropertiesOfType(p),m=f.filter(e.and(i,(function(e){return!d.has(e.escapedName)}))),_=u.getTypeAtLocation(o),g=e.find(o.members,(function(n){return e.isConstructorDeclaration(n)}));_.getNumberIndexType()||h(p,1),_.getStringIndexType()||h(p,0);var y=n.createImportAdder(a,t.program,l,t.host);function h(e,r){var i=u.getIndexInfoOfType(e,r);i&&v(a,o,u.indexInfoToIndexSignatureDeclaration(i,r,o,void 0,n.getNoopSymbolTrackerWithResolver(t)))}function v(e,n,t){g?c.insertNodeAfter(e,g,t):c.insertNodeAtClassStart(e,n,t)}n.createMissingMemberNodes(o,m,a,t,l,y,(function(e){return v(a,o,e)})),y.writeFixes(c)}function s(n,t){var r=e.getEffectiveBaseTypeNode(n);if(!r)return e.createSymbolTable();var a=t.getTypeAtLocation(r),o=t.getPropertiesOfType(a);return e.createSymbolTable(o.filter(i))}n.registerCodeFix({errorCodes:t,getCodeActions:function(t){var i=t.sourceFile,s=t.span,c=a(i,s.start);return e.mapDefined(e.getEffectiveImplementsTypeNodes(c),(function(a){var s=e.textChanges.ChangeTracker.with(t,(function(e){return o(t,a,i,c,e,t.preferences)}));return 0===s.length?void 0:n.createCodeFixAction(r,s,[e.Diagnostics.Implement_interface_0,a.getText(i)],r,e.Diagnostics.Implement_all_unimplemented_interfaces)}))},fixIds:[r],getAllCodeActions:function(r){var i=new e.Map;return n.codeFixAll(r,t,(function(n,t){var s=a(t.file,t.start);if(e.addToSeen(i,e.getNodeId(s)))for(var c=0,l=e.getEffectiveImplementsTypeNodes(s);c<l.length;c++){var u=l[c];o(r,u,t.file,s,n,r.preferences)}}))}})})(e.codefix||(e.codefix={}))}(d||(d={})),function(e){(function(n){n.importFixName="import";var t,r="fixMissingImport",a=[e.Diagnostics.Cannot_find_name_0.code,e.Diagnostics.Cannot_find_name_0_Did_you_mean_1.code,e.Diagnostics.Cannot_find_name_0_Did_you_mean_the_instance_member_this_0.code,e.Diagnostics.Cannot_find_name_0_Did_you_mean_the_static_member_1_0.code,e.Diagnostics.Cannot_find_namespace_0.code,e.Diagnostics._0_refers_to_a_UMD_global_but_the_current_file_is_a_module_Consider_adding_an_import_instead.code,e.Diagnostics._0_only_refers_to_a_type_but_is_being_used_as_a_value_here.code];function s(e,n,t,r){return c(e,n,!1,t,r)}function c(n,t,r,a,i){var o=t.getCompilerOptions(),s=[],c=[],u=new e.Map,p=new e.Map;return{addImportFromDiagnostic:f,addImportFromExportedSymbol:_,writeFixes:y};function f(e,n){var t=I(n,e.code,e.start,r);t&&t.fixes.length&&g(t)}function _(s,c){var l=e.Debug.checkDefined(s.parent),u=e.getNameForExportedSymbol(s,e.getEmitScriptTarget(o)),p=t.getTypeChecker(),f=p.getMergedSymbol(e.skipAlias(s,p)),_=m(n,f,l,u,i,t,r),y=!!c&&2===o.importsNotUsedAsValues,h=L(n,t),v=d(n,_,l,u,t,void 0,y,h,i,a);g({fixes:[v],symbolName:u})}function g(n){var t=n.fixes,r=n.symbolName,a=e.first(t);switch(a.kind){case 0:s.push(a);break;case 1:c.push(a);break;case 2:var i=a.importClauseOrBindingPattern,o=a.importKind,l=a.canUseTypeOnlyImport,d=String(e.getNodeId(i)),f=u.get(d);f||u.set(d,f={importClauseOrBindingPattern:i,defaultImport:void 0,namedImports:[],canUseTypeOnlyImport:l}),0===o?e.pushIfUnique(f.namedImports,r):(e.Debug.assert(void 0===f.defaultImport||f.defaultImport===r,"(Add to Existing) Default import should be missing or match symbolName"),f.defaultImport=r);break;case 3:var m=a.moduleSpecifier,_=(o=a.importKind,a.useRequire),g=a.typeOnly;f=p.get(m);switch(f?f.typeOnly=f.typeOnly&&g:p.set(m,f={namedImports:[],namespaceLikeImport:void 0,typeOnly:g,useRequire:_}),o){case 1:e.Debug.assert(void 0===f.defaultImport||f.defaultImport===r,"(Add new) Default import should be missing or match symbolName"),f.defaultImport=r;break;case 0:e.pushIfUnique(f.namedImports||(f.namedImports=[]),r);break;case 3:case 2:e.Debug.assert(void 0===f.namespaceLikeImport||f.namespaceLikeImport.name===r,"Namespacelike import shoudl be missing or match symbolName"),f.namespaceLikeImport={importKind:o,name:r};break}break;default:e.Debug.assertNever(a,"fix wasn't never - got kind "+a.kind)}}function y(t){for(var r,i=e.getQuotePreference(n,a),o=0,d=s;o<d.length;o++){var f=d[o];J(t,n,f)}for(var m=0,_=c;m<_.length;m++){f=_[m];X(t,n,f,i)}u.forEach((function(e){var r=e.importClauseOrBindingPattern,a=e.defaultImport,i=e.namedImports,o=e.canUseTypeOnlyImport;q(t,n,r,a,i,o)})),p.forEach((function(n,t){var a=n.useRequire,o=l(n,["useRequire"]),s=a?Z:Q;r=e.combine(r,s(t,i,o))})),r&&e.insertImports(t,n,r,!0)}}function u(n,t,r,a,i,o,s,c,l){var u=o.getCompilerOptions(),_=e.pathIsBareSpecifier(e.stripQuotes(t.name))?[f(n,t,o,i)]:m(r,n,t,a,i,o,!0),g=L(r,o),y=2===u.importsNotUsedAsValues&&!e.isSourceFileJS(r)&&e.isValidTypeOnlyAliasUseSite(e.getTokenAtPosition(r,c)),h=d(r,_,t,a,o,c,y,g,i,l);return{moduleSpecifier:h.moduleSpecifier,codeAction:p(W({host:i,formatContext:s,preferences:l},r,a,h,e.getQuotePreference(r,l)))}}function d(n,t,r,a,i,o,s,c,l,u){return e.Debug.assert(t.some((function(e){return e.moduleSymbol===r})),"Some exportInfo should match the specified moduleSymbol"),k(v(t,a,o,s,c,i,n,l,u),n,l)}function p(e){var n=e.description,t=e.changes,r=e.commands;return{description:n,changes:t,commands:r}}function f(n,t,r,a){var i,o,s=r.getCompilerOptions(),c=u(r.getTypeChecker(),!1);if(c)return c;var l=null===(o=null===(i=a.getPackageJsonAutoImportProvider)||void 0===i?void 0:i.call(a))||void 0===o?void 0:o.getTypeChecker();return e.Debug.checkDefined(l&&u(l,!0),"Could not find symbol in specified module for code actions");function u(r,a){var i=U(t,r,s);if(i&&e.skipAlias(i.symbol,r)===n)return{symbol:i.symbol,moduleSymbol:t,exportKind:i.exportKind,exportedSymbolIsTypeOnly:y(n,r),isFromPackageJson:a};var o=r.tryGetMemberInModuleExportsAndProperties(n.name,t);return o&&e.skipAlias(o,r)===n?{symbol:o,moduleSymbol:t,exportKind:0,exportedSymbolIsTypeOnly:y(n,r),isFromPackageJson:a}:void 0}}function m(n,t,r,a,i,o,s){var c=[],l=o.getCompilerOptions(),u=e.memoizeOne((function(n){return e.createModuleSpecifierResolutionHost(n?i.getPackageJsonAutoImportProvider():o,i)}));return ne(o,i,s,(function(i,o,s,u){var p=s.getTypeChecker();if(!o||i===r||!e.startsWith(n.fileName,e.getDirectoryPath(o.fileName))){var f=U(i,p,l);f&&(f.name===a||re(i,l.target)===a)&&e.skipAlias(f.symbol,p)===t&&d(s,o,u)&&c.push({symbol:f.symbol,moduleSymbol:i,exportKind:f.exportKind,exportedSymbolIsTypeOnly:y(f.symbol,p),isFromPackageJson:u});for(var m=0,_=p.getExportsAndPropertiesOfModule(i);m<_.length;m++){var g=_[m];g.name===a&&e.skipAlias(g,p)===t&&d(s,o,u)&&c.push({symbol:g,moduleSymbol:i,exportKind:0,exportedSymbolIsTypeOnly:y(g,p),isFromPackageJson:u})}}})),c;function d(t,r,a){var o;return!r||e.isImportableFile(t,n,r,void 0,u(a),null===(o=i.getModuleSpecifierCache)||void 0===o?void 0:o.call(i))}}function _(e,n,t,r,a){return k(D(t,n,void 0,!1,!1,e,r,a),n,r)}function g(n,t,r){var a,i,o,s,c,l,u,d,p=e.timestamp();null===(a=t.getPackageJsonAutoImportProvider)||void 0===a||a.call(t);var f=null===(i=t.getExportMapCache)||void 0===i?void 0:i.call(t);if(f){var m=f.get(n.path,r.getTypeChecker(),null===(o=t.getProjectVersion)||void 0===o?void 0:o.call(t));if(m)return null===(s=t.log)||void 0===s||s.call(t,"getSymbolToExportInfoMap: cache hit"),m;null===(c=t.log)||void 0===c||c.call(t,"getSymbolToExportInfoMap: cache miss or empty; calculating new results")}var _=e.createMultiMap(),g=r.getCompilerOptions(),h=e.getEmitScriptTarget(g);return ne(r,t,!0,(function(n,t,r,a){var i=r.getTypeChecker(),o=U(n,i,g);if(o){var s=e.getNameForExportedSymbol(e.getLocalSymbolForExportDefault(o.symbol)||o.symbol,h);_.add(v(s,o.symbol,n,i),{symbol:o.symbol,moduleSymbol:n,exportKind:o.exportKind,exportedSymbolIsTypeOnly:y(o.symbol,i),isFromPackageJson:a})}for(var c=new e.Map,l=0,u=i.getExportsAndPropertiesOfModule(n);l<u.length;l++){var d=u[l];d!==(null===o||void 0===o?void 0:o.symbol)&&e.addToSeen(c,d)&&_.add(v(e.getNameForExportedSymbol(d,h),d,n,i),{symbol:d,moduleSymbol:n,exportKind:0,exportedSymbolIsTypeOnly:y(d,i),isFromPackageJson:a})}})),f&&(null===(l=t.log)||void 0===l||l.call(t,"getSymbolToExportInfoMap: caching results"),f.set(_,null===(u=t.getProjectVersion)||void 0===u?void 0:u.call(t))),null===(d=t.log)||void 0===d||d.call(t,"getSymbolToExportInfoMap: done in "+(e.timestamp()-p)+" ms"),_;function v(n,t,r,a){var i=e.stripQuotes(r.name),o=e.isExternalModuleNameRelative(i)?"/":i;return n+"|"+e.getSymbolId(e.skipAlias(t,a))+"|"+o}}function y(n,t){return!(111551&e.skipAlias(n,t).flags)}function h(n,t){return e.isValidTypeOnlyAliasUseSite(e.getTokenAtPosition(n,t))}function v(n,t,r,a,o,s,c,l,u){var d=s.getTypeChecker(),p=e.flatMap(n,(function(e){return x(e,d,c,s.getCompilerOptions())})),f=void 0===r?void 0:b(p,t,r,d),m=S(p,void 0!==r&&h(c,r)),_=m?[m]:A(n,p,s,c,r,a,o,l,u);return i(i([],f?[f]:e.emptyArray),_)}function b(n,t,r,a){return e.firstDefined(n,(function(n){var i=n.declaration,o=T(i),s=e.tryGetModuleSpecifierFromDeclaration(i);if(o&&s){var c=E(i,a);if(c&&c.exports.has(e.escapeLeadingUnderscores(t)))return{kind:0,namespacePrefix:o,position:r,moduleSpecifier:s}}}))}function E(n,t){var r;switch(n.kind){case 250:return t.resolveExternalModuleName(n.initializer.arguments[0]);case 261:return t.getAliasedSymbol(n.symbol);case 262:var a=e.tryCast(null===(r=n.importClause)||void 0===r?void 0:r.namedBindings,e.isNamespaceImport);return a&&t.getAliasedSymbol(a.symbol);default:return e.Debug.assertNever(n)}}function T(n){var t,r,a;switch(n.kind){case 250:return null===(t=e.tryCast(n.name,e.isIdentifier))||void 0===t?void 0:t.text;case 261:return n.name.text;case 262:return null===(a=e.tryCast(null===(r=n.importClause)||void 0===r?void 0:r.namedBindings,e.isNamespaceImport))||void 0===a?void 0:a.name.text;default:return e.Debug.assertNever(n)}}function S(n,t){return e.firstDefined(n,(function(n){var r=n.declaration,a=n.importKind;if(261!==r.kind){if(250===r.kind)return 0!==a&&1!==a||197!==r.name.kind?void 0:{kind:2,importClauseOrBindingPattern:r.name,importKind:a,moduleSpecifier:r.initializer.arguments[0].text,canUseTypeOnlyImport:!1};var i=r.importClause;if(i&&e.isStringLiteralLike(r.moduleSpecifier)){var o=i.name,s=i.namedBindings;if(!i.isTypeOnly||0===a&&s)return 1===a&&!o||0===a&&(!s||265===s.kind)?{kind:2,importClauseOrBindingPattern:i,importKind:a,moduleSpecifier:r.moduleSpecifier.text,canUseTypeOnlyImport:t}:void 0}}}))}function x(n,t,r,a){var i=n.moduleSymbol,o=n.exportKind,s=n.exportedSymbolIsTypeOnly;if(s&&e.isSourceFileJS(r))return e.emptyArray;var c=P(r,o,a);return e.mapDefined(r.imports,(function(n){var r=e.importFromModuleSpecifier(n);return e.isRequireVariableDeclaration(r.parent)?t.resolveExternalModuleName(n)===i?{declaration:r.parent,importKind:c}:void 0:(262===r.kind||261===r.kind)&&t.getSymbolAtLocation(n)===i?{declaration:r,importKind:c}:void 0}))}function L(n,t){if(!e.isSourceFileJS(n))return!1;if(n.commonJsModuleIndicator&&!n.externalModuleIndicator)return!0;if(n.externalModuleIndicator&&!n.commonJsModuleIndicator)return!1;var r=t.getCompilerOptions();if(r.configFile)return e.getEmitModuleKind(r)<e.ModuleKind.ES2015;for(var a=0,i=t.getSourceFiles();a<i.length;a++){var o=i[a];if(o!==n&&e.isSourceFileJS(o)&&!t.isSourceFileFromExternalLibrary(o)){if(o.commonJsModuleIndicator&&!o.externalModuleIndicator)return!0;if(o.externalModuleIndicator&&!o.commonJsModuleIndicator)return!1}}return!0}function D(n,t,r,a,i,o,s,c){var l=e.isSourceFileJS(t),u=n.getCompilerOptions(),d=e.createModuleSpecifierResolutionHost(n,s);return e.flatMap(o,(function(o){return e.moduleSpecifiers.getModuleSpecifiers(o.moduleSymbol,n.getTypeChecker(),u,t,d,c).map((function(e){return o.exportedSymbolIsTypeOnly&&l&&void 0!==r?{kind:1,moduleSpecifier:e,position:r,exportInfo:o}:{kind:3,moduleSpecifier:e,importKind:P(t,o.exportKind,u),useRequire:i,typeOnly:a,exportInfo:o}}))}))}function A(n,t,r,a,i,o,s,c,l){var u=e.firstDefined(t,(function(e){return C(e,o,s)}));return u?[u]:D(r,a,i,o,s,n,c,l)}function C(n,t,r){var a=n.declaration,i=n.importKind,o=e.tryGetModuleSpecifierFromDeclaration(a);return o?{kind:3,moduleSpecifier:o,importKind:i,typeOnly:t,useRequire:r}:void 0}function I(n,t,r,a){var i=e.getTokenAtPosition(n.sourceFile,r),s=t===e.Diagnostics._0_refers_to_a_UMD_global_but_the_current_file_is_a_module_Consider_adding_an_import_instead.code?O(n,i):e.isIdentifier(i)?F(n,i,a):void 0;return s&&o(o({},s),{fixes:N(s.fixes,n.sourceFile,n.host)})}function N(n,t,r){var a=e.createPackageJsonImportFilter(t,r).allowsImportingSpecifier;return e.sort(n,(function(n,t){return e.compareValues(n.kind,t.kind)||R(n,t,a)}))}function k(n,t,r){if(0===n[0].kind||2===n[0].kind)return n[0];var a=e.createPackageJsonImportFilter(t,r).allowsImportingSpecifier;return n.reduce((function(e,n){return-1===R(n,e,a)?n:e}))}function R(n,t,r){return 0!==n.kind&&0!==t.kind?e.compareBooleans(r(n.moduleSpecifier),r(t.moduleSpecifier))||e.compareNumberOfDirectorySeparators(n.moduleSpecifier,t.moduleSpecifier):0}function O(n,t){var r=n.sourceFile,a=n.program,i=n.host,o=n.preferences,s=a.getTypeChecker(),c=w(t,s);if(c){var l=s.getAliasedSymbol(c),u=c.name,d=[{symbol:c,moduleSymbol:l,exportKind:3,exportedSymbolIsTypeOnly:!1,isFromPackageJson:!1}],p=L(r,a),f=v(d,u,e.isIdentifier(t)?t.getStart(r):void 0,!1,p,a,r,i,o);return{fixes:f,symbolName:u}}}function w(n,t){var r=e.isIdentifier(n)?t.getSymbolAtLocation(n):void 0;if(e.isUMDExportSymbol(r))return r;var a=n.parent;return e.isJsxOpeningLikeElement(a)&&a.tagName===n||e.isJsxOpeningFragment(a)?e.tryCast(t.resolveName(t.getJsxNamespace(a),e.isJsxOpeningLikeElement(a)?n:a,111551,!1),e.isUMDExportSymbol):void 0}function P(n,t,r){switch(t){case 0:return 0;case 1:return 1;case 2:return j(n,r);case 3:return M(n,r);default:return e.Debug.assertNever(t)}}function M(n,t){if(e.getAllowSyntheticDefaultImports(t))return 1;var r=e.getEmitModuleKind(t);switch(r){case e.ModuleKind.AMD:case e.ModuleKind.CommonJS:case e.ModuleKind.UMD:return e.isInJSFile(n)&&e.isExternalModule(n)?2:3;case e.ModuleKind.System:case e.ModuleKind.ES2015:case e.ModuleKind.ES2020:case e.ModuleKind.ESNext:case e.ModuleKind.None:return 2;default:return e.Debug.assertNever(r,"Unexpected moduleKind "+r)}}function F(n,t,r){var a=n.sourceFile,i=n.program,o=n.cancellationToken,s=n.host,c=n.preferences,l=i.getTypeChecker(),u=i.getCompilerOptions(),d=G(a,l,t,u);e.Debug.assert("default"!==d,"'default' isn't a legal identifier and couldn't occur here");var p=2===u.importsNotUsedAsValues&&e.isValidTypeOnlyAliasUseSite(t),f=L(a,i),m=B(d,e.getMeaningFromLocation(t),o,a,i,r,s),_=e.arrayFrom(e.flatMapIterator(m.entries(),(function(e){e[0];var n=e[1];return v(n,d,t.getStart(a),p,f,i,a,s,c)})));return{fixes:_,symbolName:d}}function G(n,t,r,a){var i=r.parent;if((e.isJsxOpeningLikeElement(i)||e.isJsxClosingElement(i))&&i.tagName===r&&4!==a.jsx&&5!==a.jsx){var o=t.getJsxNamespace(n);if(e.isIntrinsicJsxName(r.text)||!t.resolveName(o,i,111551,!0))return o}return r.text}function B(n,t,r,a,i,o,s){var c,l=e.createMultiMap(),u=e.createPackageJsonImportFilter(a,s),d=null===(c=s.getModuleSpecifierCache)||void 0===c?void 0:c.call(s),p=e.memoizeOne((function(n){return e.createModuleSpecifierResolutionHost(n?s.getPackageJsonAutoImportProvider():i,s)}));function f(n,t,r,i,o,s){var c=p(s);if(t&&e.isImportableFile(o,a,t,u,c,d)||!t&&u.allowsImportingAmbientModule(n,c)){var f=o.getTypeChecker();l.add(e.getUniqueSymbolId(r,f).toString(),{symbol:r,moduleSymbol:n,exportKind:i,exportedSymbolIsTypeOnly:y(r,f),isFromPackageJson:s})}}return ne(i,s,o,(function(e,a,i,o){var s=i.getTypeChecker();r.throwIfCancellationRequested();var c=i.getCompilerOptions(),l=U(e,s,c);l&&(l.name===n||re(e,c.target)===n)&&ee(l.symbolForMeaning,t)&&f(e,a,l.symbol,l.exportKind,i,o);var u=s.tryGetMemberInModuleExportsAndProperties(n,e);u&&ee(u,t)&&f(e,a,u,0,i,o)})),l}function U(e,n,t){var r=V(e,n);if(r){var a=r.symbol,i=r.exportKind,s=K(a,n,t);return s&&o({symbol:a,exportKind:i},s)}}function V(e,n){var t=n.resolveExternalModuleSymbol(e);if(t!==e)return{symbol:t,exportKind:2};var r=n.tryGetMemberInModuleExports("default",e);return r?{symbol:r,exportKind:1}:void 0}function j(n,t){var r=e.getAllowSyntheticDefaultImports(t);if(e.getEmitModuleKind(t)>=e.ModuleKind.ES2015)return r?1:2;if(e.isInJSFile(n))return e.isExternalModule(n)?1:3;for(var a=0,i=n.statements;a<i.length;a++){var o=i[a];if(e.isImportEqualsDeclaration(o)&&!e.nodeIsMissing(o.moduleReference))return 3}return r?1:3}function K(n,t,r){var a=e.getLocalSymbolForExportDefault(n);if(a)return{symbolForMeaning:a,name:a.name};var i=H(n);if(void 0!==i)return{symbolForMeaning:n,name:i};if(2097152&n.flags){var o=t.getImmediateAliasedSymbol(n);if(o&&o.parent)return K(o,t,r)}return"default"!==n.escapedName&&"export="!==n.escapedName?{symbolForMeaning:n,name:n.getName()}:{symbolForMeaning:n,name:e.getNameForExportedSymbol(n,r.target)}}function H(n){return n.declarations&&e.firstDefined(n.declarations,(function(n){var t;return e.isExportAssignment(n)?null===(t=e.tryCast(e.skipOuterExpressions(n.expression),e.isIdentifier))||void 0===t?void 0:t.text:e.isExportSpecifier(n)?(e.Debug.assert("default"===n.name.text,"Expected the specifier to be a default export"),n.propertyName&&n.propertyName.text):void 0}))}function W(t,a,i,o,s){var c,l=e.textChanges.ChangeTracker.with(t,(function(e){c=z(e,a,i,o,s)}));return n.createCodeFixAction(n.importFixName,l,c,r,e.Diagnostics.Add_all_missing_imports)}function z(n,t,r,a,i){switch(a.kind){case 0:return J(n,t,a),[e.Diagnostics.Change_0_to_1,r,a.namespacePrefix+"."+r];case 1:return X(n,t,a,i),[e.Diagnostics.Change_0_to_1,r,Y(a.moduleSpecifier,i)+r];case 2:var o=a.importClauseOrBindingPattern,s=a.importKind,c=a.canUseTypeOnlyImport,l=a.moduleSpecifier;q(n,t,o,1===s?r:void 0,0===s?[r]:e.emptyArray,c);var u=e.stripQuotes(l);return[1===s?e.Diagnostics.Add_default_import_0_to_existing_import_declaration_from_1:e.Diagnostics.Add_0_to_existing_import_declaration_from_1,r,u];case 3:s=a.importKind,l=a.moduleSpecifier;var d=a.typeOnly,p=a.useRequire,f=p?Z:Q,m=1===s?{defaultImport:r,typeOnly:d}:0===s?{namedImports:[r],typeOnly:d}:{namespaceLikeImport:{importKind:s,name:r},typeOnly:d};return e.insertImports(n,t,f(l,i,m),!0),[1===s?e.Diagnostics.Import_default_0_from_module_1:e.Diagnostics.Import_0_from_module_1,r,l];default:return e.Debug.assertNever(a,"Unexpected fix kind "+a.kind)}}function q(n,t,r,a,i,o){if(197!==r.kind){var s=!o&&r.isTypeOnly;if(a&&(e.Debug.assert(!r.name,"Cannot add a default import to an import clause that already has one"),n.insertNodeAt(t,r.getStart(t),e.factory.createIdentifier(a),{suffix:", "})),i.length){var c=r.namedBindings&&e.cast(r.namedBindings,e.isNamedImports).elements,l=e.stableSort(i.map((function(n){return e.factory.createImportSpecifier(void 0,e.factory.createIdentifier(n))})),e.OrganizeImports.compareImportOrExportSpecifiers);if((null===c||void 0===c?void 0:c.length)&&e.OrganizeImports.importSpecifiersAreSorted(c))for(var u=0,d=l;u<d.length;u++){var p=d[u],f=e.OrganizeImports.getImportSpecifierInsertionIndex(c,p),m=r.namedBindings.elements[f-1];m?n.insertNodeInListAfter(t,m,p):n.insertNodeBefore(t,c[0],p,!e.positionsAreOnSameLine(c[0].getStart(),r.parent.getStart(),t))}else if(null===c||void 0===c?void 0:c.length)for(var _=0,g=l;_<g.length;_++){p=g[_];n.insertNodeInListAfter(t,e.last(c),p,c)}else if(l.length){var y=e.factory.createNamedImports(l);r.namedBindings?n.replaceNode(t,r.namedBindings,y):n.insertNodeAfter(t,e.Debug.checkDefined(r.name,"Import clause must have either named imports or a default import"),y)}}s&&n.delete(t,e.getTypeKeywordOfTypeOnlyImport(r,t))}else{a&&E(r,a,"default");for(var h=0,v=i;h<v.length;h++){var b=v[h];E(r,b,void 0)}}function E(r,a,i){var o=e.factory.createBindingElement(void 0,i,a);r.elements.length?n.insertNodeInListAfter(t,e.last(r.elements),o):n.replaceNode(t,r,e.factory.createObjectBindingPattern([o]))}}function J(e,n,t){var r=t.namespacePrefix,a=t.position;e.insertText(n,a,r+".")}function X(e,n,t,r){var a=t.moduleSpecifier,i=t.position;e.insertText(n,i,Y(a,r))}function Y(n,t){var r=e.getQuoteFromPreference(t);return"import("+r+n+r+")."}function Q(n,t,r){var a,i,o,s=e.makeStringLiteral(n,t);(void 0!==r.defaultImport||(null===(a=r.namedImports)||void 0===a?void 0:a.length))&&(o=e.combine(o,e.makeImport(void 0===r.defaultImport?void 0:e.factory.createIdentifier(r.defaultImport),null===(i=r.namedImports)||void 0===i?void 0:i.map((function(n){return e.factory.createImportSpecifier(void 0,e.factory.createIdentifier(n))})),n,t,r.typeOnly)));var c=r.namespaceLikeImport,l=r.typeOnly;if(c){var u=3===c.importKind?e.factory.createImportEqualsDeclaration(void 0,void 0,l,e.factory.createIdentifier(c.name),e.factory.createExternalModuleReference(s)):e.factory.createImportDeclaration(void 0,void 0,e.factory.createImportClause(l,void 0,e.factory.createNamespaceImport(e.factory.createIdentifier(c.name))),s);o=e.combine(o,u)}return e.Debug.checkDefined(o)}function Z(n,t,r){var a,i,o,s=e.makeStringLiteral(n,t);if(r.defaultImport||(null===(a=r.namedImports)||void 0===a?void 0:a.length)){var c=(null===(i=r.namedImports)||void 0===i?void 0:i.map((function(n){return e.factory.createBindingElement(void 0,void 0,n)})))||[];r.defaultImport&&c.unshift(e.factory.createBindingElement(void 0,"default",r.defaultImport));var l=$(e.factory.createObjectBindingPattern(c),s);o=e.combine(o,l)}if(r.namespaceLikeImport){l=$(r.namespaceLikeImport.name,s);o=e.combine(o,l)}return e.Debug.checkDefined(o)}function $(n,t){return e.factory.createVariableStatement(void 0,e.factory.createVariableDeclarationList([e.factory.createVariableDeclaration("string"===typeof n?e.factory.createIdentifier(n):n,void 0,void 0,e.factory.createCallExpression(e.factory.createIdentifier("require"),void 0,[t]))],2))}function ee(n,t){var r=n.declarations;return e.some(r,(function(n){return!!(e.getMeaningFromDeclaration(n)&t)}))}function ne(n,t,r,a){var i,o;te(n.getTypeChecker(),n.getSourceFiles(),(function(e,t){return a(e,t,n,!1)}));var s=r&&(null===(i=t.getPackageJsonAutoImportProvider)||void 0===i?void 0:i.call(t));if(s){var c=e.timestamp();te(s.getTypeChecker(),s.getSourceFiles(),(function(e,n){return a(e,n,s,!0)})),null===(o=t.log)||void 0===o||o.call(t,"forEachExternalModuleToImportFrom autoImportProvider: "+(e.timestamp()-c))}}function te(n,t,r){for(var a=0,i=n.getAmbientModules();a<i.length;a++){var o=i[a];e.stringContains(o.name,"*")||r(o,void 0)}for(var s=0,c=t;s<c.length;s++){var l=c[s];e.isExternalOrCommonJsModule(l)&&r(n.getMergedSymbol(l.symbol),l)}}function re(n,t){return ae(e.removeFileExtension(e.stripQuotes(n.name)),t)}function ae(n,t){var r=e.getBaseFileName(e.removeSuffix(n,"/index")),a="",i=!0,o=r.charCodeAt(0);e.isIdentifierStart(o,t)?a+=String.fromCharCode(o):i=!1;for(var s=1;s<r.length;s++){var c=r.charCodeAt(s),l=e.isIdentifierPart(c,t);if(l){var u=String.fromCharCode(c);i||(u=u.toUpperCase()),a+=u}i=l}return e.isStringANonContextualKeyword(a)?"_"+a:a||"_"}n.registerCodeFix({errorCodes:a,getCodeActions:function(n){var t=n.errorCode,r=n.preferences,a=n.sourceFile,i=n.span,o=I(n,t,i.start,!0);if(o){var s=o.fixes,c=o.symbolName,l=e.getQuotePreference(a,r);return s.map((function(e){return W(n,a,c,e,l)}))}},fixIds:[r],getAllCodeActions:function(t){var r=t.sourceFile,i=t.program,o=t.preferences,s=t.host,l=c(r,i,!0,o,s);return n.eachDiagnostic(t,a,(function(e){return l.addImportFromDiagnostic(e,t)})),n.createCombinedCodeActions(e.textChanges.ChangeTracker.with(t,l.writeFixes))}}),n.createImportAdder=s,function(e){e[e["UseNamespace"]=0]="UseNamespace",e[e["ImportType"]=1]="ImportType",e[e["AddToExisting"]=2]="AddToExisting",e[e["AddNew"]=3]="AddNew"}(t||(t={})),n.getImportCompletionAction=u,n.getModuleSpecifierForBestExportInfo=_,n.getSymbolToExportInfoMap=g,n.getImportKind=P,n.forEachExternalModuleToImportFrom=ne,n.moduleSymbolToValidIdentifier=re,n.moduleSpecifierToValidIdentifier=ae})(e.codefix||(e.codefix={}))}(d||(d={})),function(e){(function(n){var t,r="fixOverrideModifier",a="fixAddOverrideModifier",i="fixRemoveOverrideModifier",o=[e.Diagnostics.This_member_cannot_have_an_override_modifier_because_it_is_not_declared_in_the_base_class_0.code,e.Diagnostics.This_member_cannot_have_an_override_modifier_because_its_containing_class_0_does_not_extend_another_class.code,e.Diagnostics.This_member_must_have_an_override_modifier_because_it_overrides_an_abstract_method_that_is_declared_in_the_base_class_0.code,e.Diagnostics.This_member_must_have_an_override_modifier_because_it_overrides_a_member_in_the_base_class_0.code,e.Diagnostics.This_parameter_property_must_have_an_override_modifier_because_it_overrides_a_member_in_base_class_0.code],s=(t={},t[e.Diagnostics.This_member_must_have_an_override_modifier_because_it_overrides_a_member_in_the_base_class_0.code]=[e.Diagnostics.Add_override_modifier,a,e.Diagnostics.Add_all_missing_override_modifiers],t[e.Diagnostics.This_member_cannot_have_an_override_modifier_because_its_containing_class_0_does_not_extend_another_class.code]=[e.Diagnostics.Remove_override_modifier,i,e.Diagnostics.Remove_all_unnecessary_override_modifiers],t[e.Diagnostics.This_parameter_property_must_have_an_override_modifier_because_it_overrides_a_member_in_base_class_0.code]=[e.Diagnostics.Add_override_modifier,a,e.Diagnostics.Add_all_missing_override_modifiers],t[e.Diagnostics.This_member_must_have_an_override_modifier_because_it_overrides_an_abstract_method_that_is_declared_in_the_base_class_0.code]=[e.Diagnostics.Add_override_modifier,a,e.Diagnostics.Remove_all_unnecessary_override_modifiers],t[e.Diagnostics.This_member_cannot_have_an_override_modifier_because_it_is_not_declared_in_the_base_class_0.code]=[e.Diagnostics.Remove_override_modifier,i,e.Diagnostics.Remove_all_unnecessary_override_modifiers],t);function c(n,t,r,a){switch(r){case e.Diagnostics.This_member_must_have_an_override_modifier_because_it_overrides_a_member_in_the_base_class_0.code:case e.Diagnostics.This_member_must_have_an_override_modifier_because_it_overrides_an_abstract_method_that_is_declared_in_the_base_class_0.code:case e.Diagnostics.This_parameter_property_must_have_an_override_modifier_because_it_overrides_a_member_in_base_class_0.code:return l(n,t.sourceFile,a);case e.Diagnostics.This_member_cannot_have_an_override_modifier_because_it_is_not_declared_in_the_base_class_0.code:case e.Diagnostics.This_member_cannot_have_an_override_modifier_because_its_containing_class_0_does_not_extend_another_class.code:return u(n,t.sourceFile,a);default:e.Debug.fail("Unexpected error code: "+r)}}function l(n,t,r){var a=p(t,r),i=a.modifiers||e.emptyArray,o=e.find(i,e.isStaticModifier),s=e.find(i,(function(n){return e.isAccessibilityModifier(n.kind)})),c=o?o.end:s?s.end:a.decorators?e.skipTrivia(t.text,a.decorators.end):a.getStart(t),l=s||o?{prefix:" "}:{suffix:" "};n.insertModifierAt(t,c,156,l)}function u(n,t,r){var a=p(t,r),i=a.modifiers&&e.find(a.modifiers,(function(e){return 156===e.kind}));e.Debug.assertIsDefined(i),n.deleteModifier(t,i)}function d(n){switch(n.kind){case 167:case 164:case 166:case 168:case 169:return!0;case 161:return e.isParameterPropertyDeclaration(n,n.parent);default:return!1}}function p(n,t){var r=e.getTokenAtPosition(n,t),a=e.findAncestor(r,(function(n){return e.isClassLike(n)?"quit":d(n)}));return e.Debug.assert(a&&d(a)),a}n.registerCodeFix({errorCodes:o,getCodeActions:function(t){var a=t.errorCode,i=t.span,o=t.sourceFile,l=s[a];if(!l)return e.emptyArray;var u=l[0],d=l[1],p=l[2];if(e.isSourceFileJS(o))return e.emptyArray;var f=e.textChanges.ChangeTracker.with(t,(function(e){return c(e,t,a,i.start)}));return[n.createCodeFixActionMaybeFixAll(r,f,u,d,p)]},fixIds:[r,a,i],getAllCodeActions:function(t){return n.codeFixAll(t,o,(function(n,r){var a=r.code,i=r.start,o=r.file,l=s[a];l&&l[1]===t.fixId&&!e.isSourceFileJS(o)&&c(n,t,a,i)}))}})})(e.codefix||(e.codefix={}))}(d||(d={})),function(e){(function(n){var t="fixNoPropertyAccessFromIndexSignature",r=[e.Diagnostics.Property_0_comes_from_an_index_signature_so_it_must_be_accessed_with_0.code];function a(n,t,r,a){var i=e.getQuotePreference(t,a),o=e.factory.createStringLiteral(r.name.text,0===i);n.replaceNode(t,r,e.isPropertyAccessChain(r)?e.factory.createElementAccessChain(r.expression,r.questionDotToken,o):e.factory.createElementAccessExpression(r.expression,o))}function i(n,t){return e.cast(e.getTokenAtPosition(n,t).parent,e.isPropertyAccessExpression)}n.registerCodeFix({errorCodes:r,fixIds:[t],getCodeActions:function(r){var o=r.sourceFile,s=r.span,c=r.preferences,l=i(o,s.start),u=e.textChanges.ChangeTracker.with(r,(function(e){return a(e,r.sourceFile,l,c)}));return[n.createCodeFixAction(t,u,[e.Diagnostics.Use_element_access_for_0,l.name.text],t,e.Diagnostics.Use_element_access_for_all_undeclared_properties)]},getAllCodeActions:function(e){return n.codeFixAll(e,r,(function(n,t){return a(n,t.file,i(t.file,t.start),e.preferences)}))}})})(e.codefix||(e.codefix={}))}(d||(d={})),function(e){(function(n){var t="fixImplicitThis",r=[e.Diagnostics.this_implicitly_has_type_any_because_it_does_not_have_a_type_annotation.code];function a(n,t,r,a){var i=e.getTokenAtPosition(t,r);e.Debug.assert(107===i.kind);var o=e.getThisContainer(i,!1);if((e.isFunctionDeclaration(o)||e.isFunctionExpression(o))&&!e.isSourceFile(e.getThisContainer(o,!1))){var s=e.Debug.assertDefined(e.findChildOfKind(o,97,t)),c=o.name,l=e.Debug.assertDefined(o.body);if(e.isFunctionExpression(o)){if(c&&e.FindAllReferences.Core.isSymbolReferencedInFile(c,a,t,l))return;return n.delete(t,s),c&&n.delete(t,c),n.insertText(t,l.pos," =>"),[e.Diagnostics.Convert_function_expression_0_to_arrow_function,c?c.text:e.ANONYMOUS]}return n.replaceNode(t,s,e.factory.createToken(84)),n.insertText(t,c.end," = "),n.insertText(t,l.pos," =>"),[e.Diagnostics.Convert_function_declaration_0_to_arrow_function,c.text]}}n.registerCodeFix({errorCodes:r,getCodeActions:function(r){var i,o=r.sourceFile,s=r.program,c=r.span,l=e.textChanges.ChangeTracker.with(r,(function(e){i=a(e,o,c.start,s.getTypeChecker())}));return i?[n.createCodeFixAction(t,l,i,t,e.Diagnostics.Fix_all_implicit_this_errors)]:e.emptyArray},fixIds:[t],getAllCodeActions:function(e){return n.codeFixAll(e,r,(function(n,t){a(n,t.file,t.start,e.program.getTypeChecker())}))}})})(e.codefix||(e.codefix={}))}(d||(d={})),function(e){(function(n){var t="fixIncorrectNamedTupleSyntax",r=[e.Diagnostics.A_labeled_tuple_element_is_declared_as_optional_with_a_question_mark_after_the_name_and_before_the_colon_rather_than_after_the_type.code,e.Diagnostics.A_labeled_tuple_element_is_declared_as_rest_with_a_before_the_name_rather_than_before_the_type.code];function a(n,t){var r=e.getTokenAtPosition(n,t);return e.findAncestor(r,(function(e){return 193===e.kind}))}function i(n,t,r){if(r){var a=r.type,i=!1,o=!1;while(181===a.kind||182===a.kind||187===a.kind)181===a.kind?i=!0:182===a.kind&&(o=!0),a=a.type;var s=e.factory.updateNamedTupleMember(r,r.dotDotDotToken||(o?e.factory.createToken(25):void 0),r.name,r.questionToken||(i?e.factory.createToken(57):void 0),a);s!==r&&n.replaceNode(t,r,s)}}n.registerCodeFix({errorCodes:r,getCodeActions:function(r){var o=r.sourceFile,s=r.span,c=a(o,s.start),l=e.textChanges.ChangeTracker.with(r,(function(e){return i(e,o,c)}));return[n.createCodeFixAction(t,l,e.Diagnostics.Move_labeled_tuple_element_modifiers_to_labels,t,e.Diagnostics.Move_labeled_tuple_element_modifiers_to_labels)]},fixIds:[t]})})(e.codefix||(e.codefix={}))}(d||(d={})),function(e){(function(n){var t="fixSpelling",r=[e.Diagnostics.Property_0_does_not_exist_on_type_1_Did_you_mean_2.code,e.Diagnostics.Cannot_find_name_0_Did_you_mean_1.code,e.Diagnostics.Cannot_find_name_0_Did_you_mean_the_instance_member_this_0.code,e.Diagnostics.Cannot_find_name_0_Did_you_mean_the_static_member_1_0.code,e.Diagnostics._0_has_no_exported_member_named_1_Did_you_mean_2.code,e.Diagnostics.No_overload_matches_this_call.code,e.Diagnostics.Type_0_is_not_assignable_to_type_1.code];function a(n,t,r,a){var i=e.getTokenAtPosition(n,t),c=i.parent;if(a!==e.Diagnostics.No_overload_matches_this_call.code&&a!==e.Diagnostics.Type_0_is_not_assignable_to_type_1.code||e.isJsxAttribute(c)){var l,u=r.program.getTypeChecker();if(e.isPropertyAccessExpression(c)&&c.name===i){e.Debug.assert(e.isMemberName(i),"Expected an identifier for spelling (property access)");var d=u.getTypeAtLocation(c.expression);32&c.flags&&(d=u.getNonNullableType(d)),l=u.getSuggestedSymbolForNonexistentProperty(i,d)}else if(e.isQualifiedName(c)&&c.right===i){var p=u.getSymbolAtLocation(c.left);p&&1536&p.flags&&(l=u.getSuggestedSymbolForNonexistentModule(c.right,p))}else if(e.isImportSpecifier(c)&&c.name===i){e.Debug.assertNode(i,e.isIdentifier,"Expected an identifier for spelling (import)");var f=e.findAncestor(i,e.isImportDeclaration),m=s(n,r,f);m&&m.symbol&&(l=u.getSuggestedSymbolForNonexistentModule(i,m.symbol))}else if(e.isJsxAttribute(c)&&c.name===i){e.Debug.assertNode(i,e.isIdentifier,"Expected an identifier for JSX attribute");var _=e.findAncestor(i,e.isJsxOpeningLikeElement),g=u.getContextualTypeForArgumentAtIndex(_,0);l=u.getSuggestedSymbolForNonexistentJSXAttribute(i,g)}else{var y=e.getMeaningFromLocation(i),h=e.getTextOfNode(i);e.Debug.assert(void 0!==h,"name should be defined"),l=u.getSuggestedSymbolForNonexistentSymbol(i,h,o(y))}return void 0===l?void 0:{node:i,suggestedSymbol:l}}}function i(n,t,r,a,i){var o=e.symbolName(a);if(!e.isIdentifierText(o,i)&&e.isPropertyAccessExpression(r.parent)){var s=a.valueDeclaration;s&&e.isNamedDeclaration(s)&&e.isPrivateIdentifier(s.name)?n.replaceNode(t,r,e.factory.createIdentifier(o)):n.replaceNode(t,r.parent,e.factory.createElementAccessExpression(r.parent.expression,e.factory.createStringLiteral(o)))}else n.replaceNode(t,r,e.factory.createIdentifier(o))}function o(e){var n=0;return 4&e&&(n|=1920),2&e&&(n|=788968),1&e&&(n|=111551),n}function s(n,t,r){if(r&&e.isStringLiteralLike(r.moduleSpecifier)){var a=e.getResolvedModule(n,r.moduleSpecifier.text);if(a)return t.program.getSourceFile(a.resolvedFileName)}}n.registerCodeFix({errorCodes:r,getCodeActions:function(r){var o=r.sourceFile,s=r.errorCode,c=a(o,r.span.start,r,s);if(c){var l=c.node,u=c.suggestedSymbol,d=r.host.getCompilationSettings().target,p=e.textChanges.ChangeTracker.with(r,(function(e){return i(e,o,l,u,d)}));return[n.createCodeFixAction("spelling",p,[e.Diagnostics.Change_spelling_to_0,e.symbolName(u)],t,e.Diagnostics.Fix_all_detected_spelling_errors)]}},fixIds:[t],getAllCodeActions:function(e){return n.codeFixAll(e,r,(function(n,t){var r=a(t.file,t.start,e,t.code),o=e.host.getCompilationSettings().target;r&&i(n,e.sourceFile,r.node,r.suggestedSymbol,o)}))}})})(e.codefix||(e.codefix={}))}(d||(d={})),function(e){(function(n){var t,r="returnValueCorrect",a="fixAddReturnStatement",i="fixRemoveBracesFromArrowFunctionBody",o="fixWrapTheBlockWithParen",s=[e.Diagnostics.A_function_whose_declared_type_is_neither_void_nor_any_must_return_a_value.code,e.Diagnostics.Type_0_is_not_assignable_to_type_1.code,e.Diagnostics.Argument_of_type_0_is_not_assignable_to_parameter_of_type_1.code];function c(n,t,r){var a=n.createSymbol(4,t.escapedText);a.type=n.getTypeAtLocation(r);var i=e.createSymbolTable([a]);return n.createAnonymousType(void 0,i,[],[],void 0,void 0)}function l(n,r,a,i){if(r.body&&e.isBlock(r.body)&&1===e.length(r.body.statements)){var o=e.first(r.body.statements);if(e.isExpressionStatement(o)&&u(n,r,n.getTypeAtLocation(o.expression),a,i))return{declaration:r,kind:t.MissingReturnStatement,expression:o.expression,statement:o,commentSource:o.expression};if(e.isLabeledStatement(o)&&e.isExpressionStatement(o.statement)){var s=e.factory.createObjectLiteralExpression([e.factory.createPropertyAssignment(o.label,o.statement.expression)]),l=c(n,o.label,o.statement.expression);if(u(n,r,l,a,i))return e.isArrowFunction(r)?{declaration:r,kind:t.MissingParentheses,expression:s,statement:o,commentSource:o.statement.expression}:{declaration:r,kind:t.MissingReturnStatement,expression:s,statement:o,commentSource:o.statement.expression}}else if(e.isBlock(o)&&1===e.length(o.statements)){var d=e.first(o.statements);if(e.isLabeledStatement(d)&&e.isExpressionStatement(d.statement)){s=e.factory.createObjectLiteralExpression([e.factory.createPropertyAssignment(d.label,d.statement.expression)]),l=c(n,d.label,d.statement.expression);if(u(n,r,l,a,i))return{declaration:r,kind:t.MissingReturnStatement,expression:s,statement:o,commentSource:d}}}}}function u(n,t,r,a,i){if(i){var o=n.getSignatureFromDeclaration(t);if(o){e.hasSyntacticModifier(t,256)&&(r=n.createPromiseType(r));var s=n.createSignature(t,o.typeParameters,o.thisParameter,o.parameters,r,void 0,o.minArgumentCount,o.flags);r=n.createAnonymousType(void 0,e.createSymbolTable(),[s],[],void 0,void 0)}else r=n.getAnyType()}return n.isTypeAssignableTo(r,a)}function d(n,t,r,a){var i=e.getTokenAtPosition(t,r);if(i.parent){var o=e.findAncestor(i.parent,e.isFunctionLikeDeclaration);switch(a){case e.Diagnostics.A_function_whose_declared_type_is_neither_void_nor_any_must_return_a_value.code:if(!o||!o.body||!o.type||!e.rangeContainsRange(o.type,i))return;return l(n,o,n.getTypeFromTypeNode(o.type),!1);case e.Diagnostics.Argument_of_type_0_is_not_assignable_to_parameter_of_type_1.code:if(!o||!e.isCallExpression(o.parent)||!o.body)return;var s=o.parent.arguments.indexOf(o),c=n.getContextualTypeForArgumentAtIndex(o.parent,s);if(!c)return;return l(n,o,c,!0);case e.Diagnostics.Type_0_is_not_assignable_to_type_1.code:if(!e.isDeclarationName(i)||!e.isVariableLike(i.parent)&&!e.isJsxAttribute(i.parent))return;var u=p(i.parent);if(!u||!e.isFunctionLikeDeclaration(u)||!u.body)return;return l(n,u,n.getTypeAtLocation(i.parent),!0)}}}function p(n){switch(n.kind){case 250:case 161:case 199:case 164:case 289:return n.initializer;case 281:return n.initializer&&(e.isJsxExpression(n.initializer)?n.initializer.expression:void 0);case 290:case 163:case 292:case 337:case 330:return}}function f(n,t,r,a){e.suppressLeadingAndTrailingTrivia(r);var i=e.probablyUsesSemicolons(t);n.replaceNode(t,a,e.factory.createReturnStatement(r),{leadingTriviaOption:e.textChanges.LeadingTriviaOption.Exclude,trailingTriviaOption:e.textChanges.TrailingTriviaOption.Exclude,suffix:i?";":void 0})}function m(n,t,r,a,i,o){var s=o||e.needsParentheses(a)?e.factory.createParenthesizedExpression(a):a;e.suppressLeadingAndTrailingTrivia(i),e.copyComments(i,s),n.replaceNode(t,r.body,s)}function _(n,t,r,a){n.replaceNode(t,r.body,e.factory.createParenthesizedExpression(a))}function g(t,i,o){var s=e.textChanges.ChangeTracker.with(t,(function(e){return f(e,t.sourceFile,i,o)}));return n.createCodeFixAction(r,s,e.Diagnostics.Add_a_return_statement,a,e.Diagnostics.Add_all_missing_return_statement)}function y(t,a,o,s){var c=e.textChanges.ChangeTracker.with(t,(function(e){return m(e,t.sourceFile,a,o,s,!1)}));return n.createCodeFixAction(r,c,e.Diagnostics.Remove_braces_from_arrow_function_body,i,e.Diagnostics.Remove_braces_from_all_arrow_function_bodies_with_relevant_issues)}function h(t,a,i){var s=e.textChanges.ChangeTracker.with(t,(function(e){return _(e,t.sourceFile,a,i)}));return n.createCodeFixAction(r,s,e.Diagnostics.Wrap_the_following_body_with_parentheses_which_should_be_an_object_literal,o,e.Diagnostics.Wrap_all_object_literal_with_parentheses)}(function(e){e[e["MissingReturnStatement"]=0]="MissingReturnStatement",e[e["MissingParentheses"]=1]="MissingParentheses"})(t||(t={})),n.registerCodeFix({errorCodes:s,fixIds:[a,i,o],getCodeActions:function(n){var r=n.program,a=n.sourceFile,i=n.span.start,o=n.errorCode,s=d(r.getTypeChecker(),a,i,o);if(s)return s.kind===t.MissingReturnStatement?e.append([g(n,s.expression,s.statement)],e.isArrowFunction(s.declaration)?y(n,s.declaration,s.expression,s.commentSource):void 0):[h(n,s.declaration,s.expression)]},getAllCodeActions:function(t){return n.codeFixAll(t,s,(function(n,r){var s=d(t.program.getTypeChecker(),r.file,r.start,r.code);if(s)switch(t.fixId){case a:f(n,r.file,s.expression,s.statement);break;case i:if(!e.isArrowFunction(s.declaration))return;m(n,r.file,s.declaration,s.expression,s.commentSource,!1);break;case o:if(!e.isArrowFunction(s.declaration))return;_(n,r.file,s.declaration,s.expression);break;default:e.Debug.fail(JSON.stringify(t.fixId))}}))}})})(e.codefix||(e.codefix={}))}(d||(d={})),function(e){(function(n){var t,r="fixMissingMember",a="fixMissingFunctionDeclaration",i=[e.Diagnostics.Property_0_does_not_exist_on_type_1.code,e.Diagnostics.Property_0_does_not_exist_on_type_1_Did_you_mean_2.code,e.Diagnostics.Property_0_is_missing_in_type_1_but_required_in_type_2.code,e.Diagnostics.Type_0_is_missing_the_following_properties_from_type_1_Colon_2.code,e.Diagnostics.Type_0_is_missing_the_following_properties_from_type_1_Colon_2_and_3_more.code,e.Diagnostics.Cannot_find_name_0.code];function o(n,t,r,a){var i=e.getTokenAtPosition(n,t);if(e.isIdentifier(i)||e.isPrivateIdentifier(i)){var o=i.parent;if(e.isIdentifier(i)&&e.isCallExpression(o))return{kind:2,token:i,call:o,sourceFile:n,modifierFlags:0,parentDeclaration:n};if(e.isPropertyAccessExpression(o)){var s=e.skipConstraint(r.getTypeAtLocation(o.expression)),c=s.symbol;if(c&&c.declarations){if(e.isIdentifier(i)&&e.isCallExpression(o.parent)){var l=e.find(c.declarations,e.isModuleDeclaration),u=null===l||void 0===l?void 0:l.getSourceFile();if(l&&u&&!a.isSourceFileFromExternalLibrary(u))return{kind:2,token:i,call:o.parent,sourceFile:n,modifierFlags:1,parentDeclaration:l};var d=e.find(c.declarations,e.isSourceFile);if(n.commonJsModuleIndicator)return;if(d&&!a.isSourceFileFromExternalLibrary(d))return{kind:2,token:i,call:o.parent,sourceFile:d,modifierFlags:1,parentDeclaration:d}}var p=e.find(c.declarations,e.isClassLike);if(p||!e.isPrivateIdentifier(i)){var f=p||e.find(c.declarations,e.isInterfaceDeclaration);if(f&&!a.isSourceFileFromExternalLibrary(f.getSourceFile())){var m=(s.target||s)!==r.getDeclaredTypeOfSymbol(c);if(m&&(e.isPrivateIdentifier(i)||e.isInterfaceDeclaration(f)))return;var _=f.getSourceFile(),g=(m?32:0)|(e.startsWithUnderscore(i.text)?8:0),y=e.isSourceFileJS(_),h=e.tryCast(o.parent,e.isCallExpression);return{kind:1,token:i,call:h,modifierFlags:g,parentDeclaration:f,declSourceFile:_,isJSFile:y}}var v=e.find(c.declarations,e.isEnumDeclaration);return!v||e.isPrivateIdentifier(i)||a.isSourceFileFromExternalLibrary(v.getSourceFile())?void 0:{kind:0,token:i,parentDeclaration:v}}}}}}function s(n,t){return t.isJSFile?e.singleElementArray(c(n,t)):d(n,t)}function c(t,a){var i=a.parentDeclaration,o=a.declSourceFile,s=a.modifierFlags,c=a.token;if(!e.isInterfaceDeclaration(i)){var u=e.textChanges.ChangeTracker.with(t,(function(e){return l(e,o,i,c,!!(32&s))}));if(0!==u.length){var d=32&s?e.Diagnostics.Initialize_static_property_0:e.isPrivateIdentifier(c)?e.Diagnostics.Declare_a_private_field_named_0:e.Diagnostics.Initialize_property_0_in_the_constructor;return n.createCodeFixAction(r,u,[d,c.text],r,e.Diagnostics.Add_all_missing_members)}}}function l(n,t,r,a,i){var o=a.text;if(i){if(222===r.kind)return;var s=r.name.getText(),c=u(e.factory.createIdentifier(s),o);n.insertNodeAfter(t,r,c)}else if(e.isPrivateIdentifier(a)){var l=e.factory.createPropertyDeclaration(void 0,void 0,o,void 0,void 0,void 0),d=m(r);d?n.insertNodeAfter(t,d,l):n.insertNodeAtClassStart(t,r,l)}else{var p=e.getFirstConstructorWithBody(r);if(!p)return;var f=u(e.factory.createThis(),o);n.insertNodeAtConstructorEnd(t,p,f)}}function u(n,t){return e.factory.createExpressionStatement(e.factory.createAssignment(e.factory.createPropertyAccessExpression(n,t),e.factory.createIdentifier("undefined")))}function d(t,a){var i=a.parentDeclaration,o=a.declSourceFile,s=a.modifierFlags,c=a.token,l=c.text,u=32&s,d=p(t.program.getTypeChecker(),i,c),m=function(n){return e.textChanges.ChangeTracker.with(t,(function(e){return f(e,o,i,l,d,n)}))},g=[n.createCodeFixAction(r,m(32&s),[u?e.Diagnostics.Declare_static_property_0:e.Diagnostics.Declare_property_0,l],r,e.Diagnostics.Add_all_missing_members)];return u||e.isPrivateIdentifier(c)||(8&s&&g.unshift(n.createCodeFixActionWithoutFixAll(r,m(8),[e.Diagnostics.Declare_private_property_0,l])),g.push(_(t,o,i,c.text,d))),g}function p(n,t,r){var a;if(217===r.parent.parent.kind){var i=r.parent.parent,o=r.parent===i.left?i.right:i.left,s=n.getWidenedType(n.getBaseTypeOfLiteralType(n.getTypeAtLocation(o)));a=n.typeToTypeNode(s,t,1)}else{var c=n.getContextualType(r.parent);a=c?n.typeToTypeNode(c,void 0,1):void 0}return a||e.factory.createKeywordTypeNode(128)}function f(n,t,r,a,i,o){var s=e.factory.createPropertyDeclaration(void 0,o?e.factory.createNodeArray(e.factory.createModifiersFromModifierFlags(o)):void 0,a,void 0,i,void 0),c=m(r);c?n.insertNodeAfter(t,c,s):n.insertNodeAtClassStart(t,r,s)}function m(n){for(var t,r=0,a=n.members;r<a.length;r++){var i=a[r];if(!e.isPropertyDeclaration(i))break;t=i}return t}function _(t,a,i,o,s){var c=e.factory.createKeywordTypeNode(147),l=e.factory.createParameterDeclaration(void 0,void 0,void 0,"x",void 0,c,void 0),u=e.factory.createIndexSignature(void 0,void 0,[l],s),d=e.textChanges.ChangeTracker.with(t,(function(e){return e.insertNodeAtClassStart(a,i,u)}));return n.createCodeFixActionWithoutFixAll(r,d,[e.Diagnostics.Add_index_signature_for_property_0,o])}function g(t,a){var i=a.parentDeclaration,o=a.declSourceFile,s=a.modifierFlags,c=a.token,l=a.call;if(void 0!==l&&!e.isPrivateIdentifier(c)){var u=c.text,d=function(n){return e.textChanges.ChangeTracker.with(t,(function(e){return y(t,e,l,c,n,i,o)}))},p=[n.createCodeFixAction(r,d(32&s),[32&s?e.Diagnostics.Declare_static_method_0:e.Diagnostics.Declare_method_0,u],r,e.Diagnostics.Add_all_missing_members)];return 8&s&&p.unshift(n.createCodeFixActionWithoutFixAll(r,d(8),[e.Diagnostics.Declare_private_method_0,u])),p}}function y(t,r,a,i,o,s,c){var l=n.createImportAdder(c,t.program,t.preferences,t.host),u=n.createSignatureDeclarationFromCallExpression(166,t,l,a,i,o,s),d=e.findAncestor(a,(function(n){return e.isMethodDeclaration(n)||e.isConstructorDeclaration(n)}));d&&d.parent===s?r.insertNodeAfter(c,d,u):r.insertNodeAtClassStart(c,s,u),l.writeFixes(r)}function h(n,t,r){var a=r.token,i=r.parentDeclaration,o=e.some(i.members,(function(e){var n=t.getTypeAtLocation(e);return!!(n&&402653316&n.flags)})),s=e.factory.createEnumMember(a,o?e.factory.createStringLiteral(a.text):void 0);n.replaceNode(i.getSourceFile(),i,e.factory.updateEnumDeclaration(i,i.decorators,i.modifiers,i.name,e.concatenate(i.members,e.singleElementArray(s))),{leadingTriviaOption:e.textChanges.LeadingTriviaOption.IncludeAll,trailingTriviaOption:e.textChanges.TrailingTriviaOption.Exclude})}function v(t,r,a){var i=n.createImportAdder(r.sourceFile,r.program,r.preferences,r.host),o=n.createSignatureDeclarationFromCallExpression(252,r,i,a.call,e.idText(a.token),a.modifierFlags,a.parentDeclaration);t.insertNodeAtEndOfScope(a.sourceFile,a.parentDeclaration,o)}n.registerCodeFix({errorCodes:i,getCodeActions:function(t){var i=t.program.getTypeChecker(),c=o(t.sourceFile,t.span.start,i,t.program);if(c){if(2===c.kind){var l=e.textChanges.ChangeTracker.with(t,(function(e){return v(e,t,c)}));return[n.createCodeFixAction(a,l,[e.Diagnostics.Add_missing_function_declaration_0,c.token.text],a,e.Diagnostics.Add_all_missing_function_declarations)]}if(0===c.kind){l=e.textChanges.ChangeTracker.with(t,(function(e){return h(e,t.program.getTypeChecker(),c)}));return[n.createCodeFixAction(r,l,[e.Diagnostics.Add_missing_enum_member_0,c.token.text],r,e.Diagnostics.Add_all_missing_members)]}return e.concatenate(g(t,c),s(t,c))}},fixIds:[r,a],getAllCodeActions:function(t){var r=t.program,s=t.fixId,c=r.getTypeChecker(),u=new e.Map,d=new e.Map;return n.createCombinedCodeActions(e.textChanges.ChangeTracker.with(t,(function(m){n.eachDiagnostic(t,i,(function(n){var r=o(n.file,n.start,c,t.program);if(r&&e.addToSeen(u,e.getNodeId(r.parentDeclaration)+"#"+r.token.text))if(s===a)2===r.kind&&v(m,t,r);else if(0===r.kind&&h(m,c,r),1===r.kind){var i=r.parentDeclaration,l=r.token,p=e.getOrUpdate(d,i,(function(){return[]}));p.some((function(e){return e.token.text===l.text}))||p.push(r)}})),d.forEach((function(a,i){for(var o=n.getAllSupers(i,c),s=function(n){if(o.some((function(e){var t=d.get(e);return!!t&&t.some((function(e){var t=e.token;return t.text===n.token.text}))})))return"continue";var a=n.parentDeclaration,i=n.declSourceFile,s=n.modifierFlags,c=n.token,u=n.call,_=n.isJSFile;if(u&&!e.isPrivateIdentifier(c))y(t,m,u,c,32&s,a,i);else if(_&&!e.isInterfaceDeclaration(a))l(m,i,a,c,!!(32&s));else{var g=p(r.getTypeChecker(),a,c);f(m,i,a,c.text,g,32&s)}},u=0,_=a;u<_.length;u++){var g=_[u];s(g)}}))})))}}),function(e){e[e["Enum"]=0]="Enum",e[e["ClassOrInterface"]=1]="ClassOrInterface",e[e["Function"]=2]="Function"}(t||(t={}))})(e.codefix||(e.codefix={}))}(d||(d={})),function(e){(function(n){var t="addMissingNewOperator",r=[e.Diagnostics.Value_of_type_0_is_not_callable_Did_you_mean_to_include_new.code];function a(n,t,r){var a=e.cast(i(t,r),e.isCallExpression),o=e.factory.createNewExpression(a.expression,a.typeArguments,a.arguments);n.replaceNode(t,a,o)}function i(n,t){var r=e.getTokenAtPosition(n,t.start),a=e.textSpanEnd(t);while(r.end<a)r=r.parent;return r}n.registerCodeFix({errorCodes:r,getCodeActions:function(r){var i=r.sourceFile,o=r.span,s=e.textChanges.ChangeTracker.with(r,(function(e){return a(e,i,o)}));return[n.createCodeFixAction(t,s,e.Diagnostics.Add_missing_new_operator_to_call,t,e.Diagnostics.Add_missing_new_operator_to_all_calls)]},fixIds:[t],getAllCodeActions:function(e){return n.codeFixAll(e,r,(function(n,t){return a(n,e.sourceFile,t)}))}})})(e.codefix||(e.codefix={}))}(d||(d={})),function(e){(function(n){var t="fixCannotFindModule",r="installTypesPackage",a=e.Diagnostics.Cannot_find_module_0_or_its_corresponding_type_declarations.code,i=[a,e.Diagnostics.Could_not_find_a_declaration_file_for_module_0_1_implicitly_has_an_any_type.code];function o(e,n){return{type:"install package",file:e,packageName:n}}function s(n,t){var r=e.tryCast(e.getTokenAtPosition(n,t),e.isStringLiteral);if(r){var a=r.text,i=e.parsePackageName(a).packageName;return e.isExternalModuleNameRelative(i)?void 0:i}}function c(n,t,r){var i;return r===a?e.JsTyping.nodeCoreModules.has(n)?"@types/node":void 0:(null===(i=t.isKnownTypesPackageName)||void 0===i?void 0:i.call(t,n))?e.getTypesPackageName(n):void 0}n.registerCodeFix({errorCodes:i,getCodeActions:function(a){var i=a.host,l=a.sourceFile,u=a.span.start,d=s(l,u);if(void 0!==d){var p=c(d,i,a.errorCode);return void 0===p?[]:[n.createCodeFixAction(t,[],[e.Diagnostics.Install_0,p],r,e.Diagnostics.Install_all_missing_types_packages,o(l.fileName,p))]}},fixIds:[r],getAllCodeActions:function(t){return n.codeFixAll(t,i,(function(n,a,i){var l=s(a.file,a.start);if(void 0!==l)switch(t.fixId){case r:var u=c(l,t.host,a.code);u&&i.push(o(a.file.fileName,u));break;default:e.Debug.fail("Bad fixId: "+t.fixId)}}))}})})(e.codefix||(e.codefix={}))}(d||(d={})),function(e){(function(n){var t=[e.Diagnostics.Non_abstract_class_0_does_not_implement_inherited_abstract_member_1_from_class_2.code,e.Diagnostics.Non_abstract_class_expression_does_not_implement_inherited_abstract_member_0_from_class_1.code],r="fixClassDoesntImplementInheritedAbstractMember";function a(n,t){var r=e.getTokenAtPosition(n,t);return e.cast(r.parent,e.isClassLike)}function i(t,r,a,i,s){var c=e.getEffectiveBaseTypeNode(t),l=a.program.getTypeChecker(),u=l.getTypeAtLocation(c),d=l.getPropertiesOfType(u).filter(o),p=n.createImportAdder(r,a.program,s,a.host);n.createMissingMemberNodes(t,d,r,a,s,p,(function(e){return i.insertNodeAtClassStart(r,t,e)})),p.writeFixes(i)}function o(n){var t=e.getSyntacticModifierFlags(e.first(n.getDeclarations()));return!(8&t)&&!!(128&t)}n.registerCodeFix({errorCodes:t,getCodeActions:function(t){var o=t.sourceFile,s=t.span,c=e.textChanges.ChangeTracker.with(t,(function(e){return i(a(o,s.start),o,t,e,t.preferences)}));return 0===c.length?void 0:[n.createCodeFixAction(r,c,e.Diagnostics.Implement_inherited_abstract_class,r,e.Diagnostics.Implement_all_inherited_abstract_classes)]},fixIds:[r],getAllCodeActions:function(r){var o=new e.Map;return n.codeFixAll(r,t,(function(n,t){var s=a(t.file,t.start);e.addToSeen(o,e.getNodeId(s))&&i(s,r.sourceFile,r,n,r.preferences)}))}})})(e.codefix||(e.codefix={}))}(d||(d={})),function(e){(function(n){var t="classSuperMustPrecedeThisAccess",r=[e.Diagnostics.super_must_be_called_before_accessing_this_in_the_constructor_of_a_derived_class.code];function a(e,n,t,r){e.insertNodeAtConstructorStart(n,t,r),e.delete(n,r)}function i(n,t){var r=e.getTokenAtPosition(n,t);if(107===r.kind){var a=e.getContainingFunction(r),i=o(a.body);return i&&!i.expression.arguments.some((function(n){return e.isPropertyAccessExpression(n)&&n.expression===r}))?{constructor:a,superCall:i}:void 0}}function o(n){return e.isExpressionStatement(n)&&e.isSuperCall(n.expression)?n:e.isFunctionLike(n)?void 0:e.forEachChild(n,o)}n.registerCodeFix({errorCodes:r,getCodeActions:function(r){var o=r.sourceFile,s=r.span,c=i(o,s.start);if(c){var l=c.constructor,u=c.superCall,d=e.textChanges.ChangeTracker.with(r,(function(e){return a(e,o,l,u)}));return[n.createCodeFixAction(t,d,e.Diagnostics.Make_super_call_the_first_statement_in_the_constructor,t,e.Diagnostics.Make_all_super_calls_the_first_statement_in_their_constructor)]}},fixIds:[t],getAllCodeActions:function(t){var o=t.sourceFile,s=new e.Map;return n.codeFixAll(t,r,(function(n,t){var r=i(t.file,t.start);if(r){var c=r.constructor,l=r.superCall;e.addToSeen(s,e.getNodeId(c.parent))&&a(n,o,c,l)}}))}})})(e.codefix||(e.codefix={}))}(d||(d={})),function(e){(function(n){var t="constructorForDerivedNeedSuperCall",r=[e.Diagnostics.Constructors_for_derived_classes_must_contain_a_super_call.code];function a(n,t){var r=e.getTokenAtPosition(n,t);return e.Debug.assert(e.isConstructorDeclaration(r.parent),"token should be at the constructor declaration"),r.parent}function i(n,t,r){var a=e.factory.createExpressionStatement(e.factory.createCallExpression(e.factory.createSuper(),void 0,e.emptyArray));n.insertNodeAtConstructorStart(t,r,a)}n.registerCodeFix({errorCodes:r,getCodeActions:function(r){var o=r.sourceFile,s=r.span,c=a(o,s.start),l=e.textChanges.ChangeTracker.with(r,(function(e){return i(e,o,c)}));return[n.createCodeFixAction(t,l,e.Diagnostics.Add_missing_super_call,t,e.Diagnostics.Add_all_missing_super_calls)]},fixIds:[t],getAllCodeActions:function(e){return n.codeFixAll(e,r,(function(n,t){return i(n,e.sourceFile,a(t.file,t.start))}))}})})(e.codefix||(e.codefix={}))}(d||(d={})),function(e){(function(n){var t="enableExperimentalDecorators",r=[e.Diagnostics.Experimental_support_for_decorators_is_a_feature_that_is_subject_to_change_in_a_future_release_Set_the_experimentalDecorators_option_in_your_tsconfig_or_jsconfig_to_remove_this_warning.code];function a(t,r){n.setJsonCompilerOptionValue(t,r,"experimentalDecorators",e.factory.createTrue())}n.registerCodeFix({errorCodes:r,getCodeActions:function(r){var i=r.program.getCompilerOptions().configFile;if(void 0!==i){var o=e.textChanges.ChangeTracker.with(r,(function(e){return a(e,i)}));return[n.createCodeFixActionWithoutFixAll(t,o,e.Diagnostics.Enable_the_experimentalDecorators_option_in_your_configuration_file)]}},fixIds:[t],getAllCodeActions:function(e){return n.codeFixAll(e,r,(function(n){var t=e.program.getCompilerOptions().configFile;void 0!==t&&a(n,t)}))}})})(e.codefix||(e.codefix={}))}(d||(d={})),function(e){(function(n){var t="fixEnableJsxFlag",r=[e.Diagnostics.Cannot_use_JSX_unless_the_jsx_flag_is_provided.code];function a(t,r){n.setJsonCompilerOptionValue(t,r,"jsx",e.factory.createStringLiteral("react"))}n.registerCodeFix({errorCodes:r,getCodeActions:function(r){var i=r.program.getCompilerOptions().configFile;if(void 0!==i){var o=e.textChanges.ChangeTracker.with(r,(function(e){return a(e,i)}));return[n.createCodeFixActionWithoutFixAll(t,o,e.Diagnostics.Enable_the_jsx_flag_in_your_configuration_file)]}},fixIds:[t],getAllCodeActions:function(e){return n.codeFixAll(e,r,(function(n){var t=e.program.getCompilerOptions().configFile;void 0!==t&&a(n,t)}))}})})(e.codefix||(e.codefix={}))}(d||(d={})),function(e){(function(n){n.registerCodeFix({errorCodes:[e.Diagnostics.Top_level_await_expressions_are_only_allowed_when_the_module_option_is_set_to_esnext_or_system_and_the_target_option_is_set_to_es2017_or_higher.code,e.Diagnostics.Top_level_for_await_loops_are_only_allowed_when_the_module_option_is_set_to_esnext_or_system_and_the_target_option_is_set_to_es2017_or_higher.code],getCodeActions:function(t){var r=t.program.getCompilerOptions(),a=r.configFile;if(void 0!==a){var i=[],o=e.getEmitModuleKind(r),s=o>=e.ModuleKind.ES2015&&o<e.ModuleKind.ESNext;if(s){var c=e.textChanges.ChangeTracker.with(t,(function(t){n.setJsonCompilerOptionValue(t,a,"module",e.factory.createStringLiteral("esnext"))}));i.push(n.createCodeFixActionWithoutFixAll("fixModuleOption",c,[e.Diagnostics.Set_the_module_option_in_your_configuration_file_to_0,"esnext"]))}var l=e.getEmitScriptTarget(r),u=l<4||l>99;if(u){c=e.textChanges.ChangeTracker.with(t,(function(t){var r=e.getTsConfigObjectLiteralExpression(a);if(r){var i=[["target",e.factory.createStringLiteral("es2017")]];o===e.ModuleKind.CommonJS&&i.push(["module",e.factory.createStringLiteral("commonjs")]),n.setJsonCompilerOptionValues(t,a,i)}}));i.push(n.createCodeFixActionWithoutFixAll("fixTargetOption",c,[e.Diagnostics.Set_the_target_option_in_your_configuration_file_to_0,"es2017"]))}return i.length?i:void 0}}})})(e.codefix||(e.codefix={}))}(d||(d={})),function(e){(function(n){var t="fixPropertyAssignment",r=[e.Diagnostics.Did_you_mean_to_use_a_Colon_An_can_only_follow_a_property_name_when_the_containing_object_literal_is_part_of_a_destructuring_pattern.code];function a(n,t,r){n.replaceNode(t,r,e.factory.createPropertyAssignment(r.name,r.objectAssignmentInitializer))}function i(n,t){return e.cast(e.getTokenAtPosition(n,t).parent,e.isShorthandPropertyAssignment)}n.registerCodeFix({errorCodes:r,fixIds:[t],getCodeActions:function(r){var o=r.sourceFile,s=r.span,c=i(o,s.start),l=e.textChanges.ChangeTracker.with(r,(function(e){return a(e,r.sourceFile,c)}));return[n.createCodeFixAction(t,l,[e.Diagnostics.Change_0_to_1,"=",":"],t,[e.Diagnostics.Switch_each_misused_0_to_1,"=",":"])]},getAllCodeActions:function(e){return n.codeFixAll(e,r,(function(e,n){return a(e,n.file,i(n.file,n.start))}))}})})(e.codefix||(e.codefix={}))}(d||(d={})),function(e){(function(n){var t="extendsInterfaceBecomesImplements",r=[e.Diagnostics.Cannot_extend_an_interface_0_Did_you_mean_implements.code];function a(n,t){var r=e.getTokenAtPosition(n,t),a=e.getContainingClass(r).heritageClauses,i=a[0].getFirstToken();return 93===i.kind?{extendsToken:i,heritageClauses:a}:void 0}function i(n,t,r,a){if(n.replaceNode(t,r,e.factory.createToken(116)),2===a.length&&93===a[0].token&&116===a[1].token){var i=a[1].getFirstToken(),o=i.getFullStart();n.replaceRange(t,{pos:o,end:o},e.factory.createToken(27));var s=t.text,c=i.end;while(c<s.length&&e.isWhiteSpaceSingleLine(s.charCodeAt(c)))c++;n.deleteRange(t,{pos:i.getStart(),end:c})}}n.registerCodeFix({errorCodes:r,getCodeActions:function(r){var o=r.sourceFile,s=a(o,r.span.start);if(s){var c=s.extendsToken,l=s.heritageClauses,u=e.textChanges.ChangeTracker.with(r,(function(e){return i(e,o,c,l)}));return[n.createCodeFixAction(t,u,e.Diagnostics.Change_extends_to_implements,t,e.Diagnostics.Change_all_extended_interfaces_to_implements)]}},fixIds:[t],getAllCodeActions:function(e){return n.codeFixAll(e,r,(function(e,n){var t=a(n.file,n.start);t&&i(e,n.file,t.extendsToken,t.heritageClauses)}))}})})(e.codefix||(e.codefix={}))}(d||(d={})),function(e){(function(n){var t="forgottenThisPropertyAccess",r=e.Diagnostics.Cannot_find_name_0_Did_you_mean_the_static_member_1_0.code,a=[e.Diagnostics.Cannot_find_name_0_Did_you_mean_the_instance_member_this_0.code,e.Diagnostics.Private_identifiers_are_not_allowed_outside_class_bodies.code,r];function i(n,t,a){var i=e.getTokenAtPosition(n,t);if(e.isIdentifier(i))return{node:i,className:a===r?e.getContainingClass(i).name.text:void 0}}function o(n,t,r){var a=r.node,i=r.className;e.suppressLeadingAndTrailingTrivia(a),n.replaceNode(t,a,e.factory.createPropertyAccessExpression(i?e.factory.createIdentifier(i):e.factory.createThis(),a))}n.registerCodeFix({errorCodes:a,getCodeActions:function(r){var a=r.sourceFile,s=i(a,r.span.start,r.errorCode);if(s){var c=e.textChanges.ChangeTracker.with(r,(function(e){return o(e,a,s)}));return[n.createCodeFixAction(t,c,[e.Diagnostics.Add_0_to_unresolved_variable,s.className||"this"],t,e.Diagnostics.Add_qualifier_to_all_unresolved_variables_matching_a_member_name)]}},fixIds:[t],getAllCodeActions:function(e){return n.codeFixAll(e,a,(function(n,t){var r=i(t.file,t.start,t.code);r&&o(n,e.sourceFile,r)}))}})})(e.codefix||(e.codefix={}))}(d||(d={})),function(e){(function(n){var t="fixInvalidJsxCharacters_expression",r="fixInvalidJsxCharacters_htmlEntity",a=[e.Diagnostics.Unexpected_token_Did_you_mean_or_gt.code,e.Diagnostics.Unexpected_token_Did_you_mean_or_rbrace.code];n.registerCodeFix({errorCodes:a,fixIds:[t,r],getCodeActions:function(a){var i=a.sourceFile,o=a.preferences,c=a.span,l=e.textChanges.ChangeTracker.with(a,(function(e){return s(e,o,i,c.start,!1)})),u=e.textChanges.ChangeTracker.with(a,(function(e){return s(e,o,i,c.start,!0)}));return[n.createCodeFixAction(t,l,e.Diagnostics.Wrap_invalid_character_in_an_expression_container,t,e.Diagnostics.Wrap_all_invalid_characters_in_an_expression_container),n.createCodeFixAction(r,u,e.Diagnostics.Convert_invalid_character_to_its_html_entity_code,r,e.Diagnostics.Convert_all_invalid_characters_to_HTML_entity_code)]},getAllCodeActions:function(e){return n.codeFixAll(e,a,(function(n,t){return s(n,e.preferences,t.file,t.start,e.fixId===r)}))}});var i={">":"&gt;","}":"&rbrace;"};function o(n){return e.hasProperty(i,n)}function s(n,t,r,a,s){var c=r.getText()[a];if(o(c)){var l=s?i[c]:"{"+e.quote(r,t,c)+"}";n.replaceRangeWithText(r,{pos:a,end:a+1},l)}}})(e.codefix||(e.codefix={}))}(d||(d={})),function(e){(function(n){var t="unusedIdentifier",r="unusedIdentifier_prefix",a="unusedIdentifier_delete",i="unusedIdentifier_deleteImports",o="unusedIdentifier_infer",s=[e.Diagnostics._0_is_declared_but_its_value_is_never_read.code,e.Diagnostics._0_is_declared_but_never_used.code,e.Diagnostics.Property_0_is_declared_but_its_value_is_never_read.code,e.Diagnostics.All_imports_in_import_declaration_are_unused.code,e.Diagnostics.All_destructured_elements_are_unused.code,e.Diagnostics.All_variables_are_unused.code,e.Diagnostics.All_type_parameters_are_unused.code];function c(n,t,r){n.replaceNode(t,r.parent,e.factory.createKeywordTypeNode(152))}function l(r,i){return n.createCodeFixAction(t,r,i,a,e.Diagnostics.Delete_all_unused_declarations)}function u(n,t,r){n.delete(t,e.Debug.checkDefined(e.cast(r.parent,e.isDeclarationWithTypeParameterChildren).typeParameters,"The type parameter to delete should exist"))}function d(e){return 99===e.kind||78===e.kind&&(266===e.parent.kind||263===e.parent.kind)}function p(n){return 99===n.kind?e.tryCast(n.parent,e.isImportDeclaration):void 0}function f(n,t){return e.isVariableDeclarationList(t.parent)&&e.first(t.parent.getChildren(n))===t}function m(e,n,t){e.delete(n,233===t.parent.kind?t.parent:t)}function _(n,t,r){e.forEach(r.elements,(function(e){return n.delete(t,e)}))}function g(n,t,r,a){t!==e.Diagnostics.Property_0_is_declared_but_its_value_is_never_read.code&&(135===a.kind&&(a=e.cast(a.parent,e.isInferTypeNode).typeParameter.name),e.isIdentifier(a)&&y(a)&&(n.replaceNode(r,a,e.factory.createIdentifier("_"+a.text)),e.isParameter(a.parent)&&e.getJSDocParameterTags(a.parent).forEach((function(t){e.isIdentifier(t.name)&&n.replaceNode(r,t.name,e.factory.createIdentifier("_"+t.name.text))}))))}function y(e){switch(e.parent.kind){case 161:case 160:return!0;case 250:var n=e.parent;switch(n.parent.parent.kind){case 240:case 239:return!0}}return!1}function h(n,t,r,a,i,o,s,c){v(t,r,n,a,i,o,s,c),e.isIdentifier(t)&&e.FindAllReferences.Core.eachSymbolReferenceInFile(t,a,n,(function(t){e.isPropertyAccessExpression(t.parent)&&t.parent.name===t&&(t=t.parent),!c&&L(t)&&r.delete(n,t.parent.parent)}))}function v(n,t,r,a,i,o,s,c){var l=n.parent;if(e.isParameter(l))b(t,r,l,a,i,o,s,c);else if(!(c&&e.isIdentifier(n)&&e.FindAllReferences.Core.isSymbolReferencedInFile(n,a,r))){var u=e.isImportClause(l)?n:e.isComputedPropertyName(l)?l.parent:l;e.Debug.assert(u!==r,"should not delete whole source file"),t.delete(r,u)}}function b(n,t,r,a,i,o,s,c){void 0===c&&(c=!1),T(a,t,r,i,o,s,c)&&(r.modifiers&&r.modifiers.length>0&&(!e.isIdentifier(r.name)||e.FindAllReferences.Core.isSymbolReferencedInFile(r.name,a,t))?r.modifiers.forEach((function(e){return n.deleteModifier(t,e)})):!r.initializer&&E(r,a,i)&&n.delete(t,r))}function E(n,t,r){var a=n.parent.parameters.indexOf(n);return!e.FindAllReferences.Core.someSignatureUsage(n.parent,r,t,(function(e,n){return!n||n.arguments.length>a}))}function T(n,t,r,a,i,o,s){var c=r.parent;switch(c.kind){case 166:case 167:var l=c.parameters.indexOf(r),u=e.isMethodDeclaration(c)?c.name:c,d=e.FindAllReferences.Core.getReferencedSymbolsForNode(c.pos,u,i,a,o);if(d)for(var p=0,f=d;p<f.length;p++)for(var m=f[p],_=0,g=m.references;_<g.length;_++){var y=g[_];if(1===y.kind){var h=e.isSuperKeyword(y.node)&&e.isCallExpression(y.node.parent)&&y.node.parent.arguments.length>l,v=e.isPropertyAccessExpression(y.node.parent)&&e.isSuperKeyword(y.node.parent.expression)&&e.isCallExpression(y.node.parent.parent)&&y.node.parent.parent.arguments.length>l,b=(e.isMethodDeclaration(y.node.parent)||e.isMethodSignature(y.node.parent))&&y.node.parent!==r.parent&&y.node.parent.parameters.length>l;if(h||v||b)return!1}}return!0;case 252:return!c.name||!S(n,t,c.name)||x(c,r,s);case 209:case 210:return x(c,r,s);case 169:return!1;default:return e.Debug.failBadSyntaxKind(c)}}function S(n,t,r){return!!e.FindAllReferences.Core.eachSymbolReferenceInFile(r,n,t,(function(n){return e.isIdentifier(n)&&e.isCallExpression(n.parent)&&n.parent.arguments.indexOf(n)>=0}))}function x(n,t,r){var a=n.parameters,i=a.indexOf(t);return e.Debug.assert(-1!==i,"The parameter should already be in the list"),r?a.slice(i+1).every((function(n){return e.isIdentifier(n.name)&&!n.symbol.isReferenced})):i===a.length-1}function L(n){return(e.isBinaryExpression(n.parent)&&n.parent.left===n||(e.isPostfixUnaryExpression(n.parent)||e.isPrefixUnaryExpression(n.parent))&&n.parent.operand===n)&&e.isExpressionStatement(n.parent.parent)}n.registerCodeFix({errorCodes:s,getCodeActions:function(a){var s=a.errorCode,y=a.sourceFile,v=a.program,b=a.cancellationToken,E=v.getTypeChecker(),T=v.getSourceFiles(),S=e.getTokenAtPosition(y,a.span.start);if(e.isJSDocTemplateTag(S))return[l(e.textChanges.ChangeTracker.with(a,(function(e){return e.delete(y,S)})),e.Diagnostics.Remove_template_tag)];if(29===S.kind){var x=e.textChanges.ChangeTracker.with(a,(function(e){return u(e,y,S)}));return[l(x,e.Diagnostics.Remove_type_parameters)]}var L=p(S);if(L){x=e.textChanges.ChangeTracker.with(a,(function(e){return e.delete(y,L)}));return[n.createCodeFixAction(t,x,[e.Diagnostics.Remove_import_from_0,e.showModuleSpecifier(L)],i,e.Diagnostics.Delete_all_unused_imports)]}if(d(S)){var D=e.textChanges.ChangeTracker.with(a,(function(e){return h(y,S,e,E,T,v,b,!1)}));if(D.length)return[n.createCodeFixAction(t,D,[e.Diagnostics.Remove_unused_declaration_for_Colon_0,S.getText(y)],i,e.Diagnostics.Delete_all_unused_imports)]}if(e.isObjectBindingPattern(S.parent)||e.isArrayBindingPattern(S.parent)){if(e.isParameter(S.parent.parent)){var A=S.parent.elements,C=[A.length>1?e.Diagnostics.Remove_unused_declarations_for_Colon_0:e.Diagnostics.Remove_unused_declaration_for_Colon_0,e.map(A,(function(e){return e.getText(y)})).join(", ")];return[l(e.textChanges.ChangeTracker.with(a,(function(e){return _(e,y,S.parent)})),C)]}return[l(e.textChanges.ChangeTracker.with(a,(function(e){return e.delete(y,S.parent.parent)})),e.Diagnostics.Remove_unused_destructuring_declaration)]}if(f(y,S))return[l(e.textChanges.ChangeTracker.with(a,(function(e){return m(e,y,S.parent)})),e.Diagnostics.Remove_variable_statement)];var I=[];if(135===S.kind){x=e.textChanges.ChangeTracker.with(a,(function(e){return c(e,y,S)}));var N=e.cast(S.parent,e.isInferTypeNode).typeParameter.name.text;I.push(n.createCodeFixAction(t,x,[e.Diagnostics.Replace_infer_0_with_unknown,N],o,e.Diagnostics.Replace_all_unused_infer_with_unknown))}else{D=e.textChanges.ChangeTracker.with(a,(function(e){return h(y,S,e,E,T,v,b,!1)}));if(D.length){N=e.isComputedPropertyName(S.parent)?S.parent:S;I.push(l(D,[e.Diagnostics.Remove_unused_declaration_for_Colon_0,N.getText(y)]))}}var k=e.textChanges.ChangeTracker.with(a,(function(e){return g(e,s,y,S)}));return k.length&&I.push(n.createCodeFixAction(t,k,[e.Diagnostics.Prefix_0_with_an_underscore,S.getText(y)],r,e.Diagnostics.Prefix_all_unused_declarations_with_where_possible)),I},fixIds:[r,a,i,o],getAllCodeActions:function(t){var l=t.sourceFile,_=t.program,y=t.cancellationToken,v=_.getTypeChecker(),b=_.getSourceFiles();return n.codeFixAll(t,s,(function(n,s){var T=e.getTokenAtPosition(l,s.start);switch(t.fixId){case r:g(n,s.code,l,T);break;case i:var S=p(T);S?n.delete(l,S):d(T)&&h(l,T,n,v,b,_,y,!0);break;case a:if(135===T.kind||d(T))break;if(e.isJSDocTemplateTag(T))n.delete(l,T);else if(29===T.kind)u(n,l,T);else if(e.isObjectBindingPattern(T.parent)){if(T.parent.parent.initializer)break;e.isParameter(T.parent.parent)&&!E(T.parent.parent,v,b)||n.delete(l,T.parent.parent)}else{if(e.isArrayBindingPattern(T.parent.parent)&&T.parent.parent.parent.initializer)break;f(l,T)?m(n,l,T.parent):h(l,T,n,v,b,_,y,!0)}break;case o:135===T.kind&&c(n,l,T);break;default:e.Debug.fail(JSON.stringify(t.fixId))}}))}})})(e.codefix||(e.codefix={}))}(d||(d={})),function(e){(function(n){var t="fixUnreachableCode",r=[e.Diagnostics.Unreachable_code_detected.code];function a(n,t,r,a,o){var s=e.getTokenAtPosition(t,r),c=e.findAncestor(s,e.isStatement);if(c.getStart(t)!==s.getStart(t)){var l=JSON.stringify({statementKind:e.Debug.formatSyntaxKind(c.kind),tokenKind:e.Debug.formatSyntaxKind(s.kind),errorCode:o,start:r,length:a});e.Debug.fail("Token and statement should start at the same point. "+l)}var u=(e.isBlock(c.parent)?c.parent:c).parent;if(!e.isBlock(c.parent)||c===e.first(c.parent.statements))switch(u.kind){case 235:if(u.elseStatement){if(e.isBlock(c.parent))break;return void n.replaceNode(t,c,e.factory.createBlock(e.emptyArray))}case 237:case 238:return void n.delete(t,u)}if(e.isBlock(c.parent)){var d=r+a,p=e.Debug.checkDefined(i(e.sliceAfter(c.parent.statements,c),(function(e){return e.pos<d})),"Some statement should be last");n.deleteNodeRange(t,c,p)}else n.delete(t,c)}function i(e,n){for(var t,r=0,a=e;r<a.length;r++){var i=a[r];if(!n(i))break;t=i}return t}n.registerCodeFix({errorCodes:r,getCodeActions:function(r){var i=e.textChanges.ChangeTracker.with(r,(function(e){return a(e,r.sourceFile,r.span.start,r.span.length,r.errorCode)}));return[n.createCodeFixAction(t,i,e.Diagnostics.Remove_unreachable_code,t,e.Diagnostics.Remove_all_unreachable_code)]},fixIds:[t],getAllCodeActions:function(e){return n.codeFixAll(e,r,(function(e,n){return a(e,n.file,n.start,n.length,n.code)}))}})})(e.codefix||(e.codefix={}))}(d||(d={})),function(e){(function(n){var t="fixUnusedLabel",r=[e.Diagnostics.Unused_label.code];function a(n,t,r){var a=e.getTokenAtPosition(t,r),i=e.cast(a.parent,e.isLabeledStatement),o=a.getStart(t),s=i.statement.getStart(t),c=e.positionsAreOnSameLine(o,s,t)?s:e.skipTrivia(t.text,e.findChildOfKind(i,58,t).end,!0);n.deleteRange(t,{pos:o,end:c})}n.registerCodeFix({errorCodes:r,getCodeActions:function(r){var i=e.textChanges.ChangeTracker.with(r,(function(e){return a(e,r.sourceFile,r.span.start)}));return[n.createCodeFixAction(t,i,e.Diagnostics.Remove_unused_label,t,e.Diagnostics.Remove_all_unused_labels)]},fixIds:[t],getAllCodeActions:function(e){return n.codeFixAll(e,r,(function(e,n){return a(e,n.file,n.start)}))}})})(e.codefix||(e.codefix={}))}(d||(d={})),function(e){(function(n){var t="fixJSDocTypes_plain",r="fixJSDocTypes_nullable",a=[e.Diagnostics.JSDoc_types_can_only_be_used_inside_documentation_comments.code];function i(e,n,t,r,a){e.replaceNode(n,t,a.typeToTypeNode(r,t,void 0))}function o(n,t,r){var a=e.findAncestor(e.getTokenAtPosition(n,t),s),i=a&&a.type;return i&&{typeNode:i,type:r.getTypeFromTypeNode(i)}}function s(e){switch(e.kind){case 225:case 170:case 171:case 252:case 168:case 172:case 191:case 166:case 165:case 161:case 164:case 163:case 169:case 255:case 207:case 250:return!0;default:return!1}}n.registerCodeFix({errorCodes:a,getCodeActions:function(a){var s=a.sourceFile,c=a.program.getTypeChecker(),l=o(s,a.span.start,c);if(l){var u=l.typeNode,d=l.type,p=u.getText(s),f=[m(d,t,e.Diagnostics.Change_all_jsdoc_style_types_to_TypeScript)];return 306===u.kind&&f.push(m(c.getNullableType(d,32768),r,e.Diagnostics.Change_all_jsdoc_style_types_to_TypeScript_and_add_undefined_to_nullable_types)),f}function m(t,r,o){var l=e.textChanges.ChangeTracker.with(a,(function(e){return i(e,s,u,t,c)}));return n.createCodeFixAction("jdocTypes",l,[e.Diagnostics.Change_0_to_1,p,c.typeToString(t)],r,o)}},fixIds:[t,r],getAllCodeActions:function(e){var t=e.fixId,s=e.program,c=e.sourceFile,l=s.getTypeChecker();return n.codeFixAll(e,a,(function(e,n){var a=o(n.file,n.start,l);if(a){var s=a.typeNode,u=a.type,d=306===s.kind&&t===r?l.getNullableType(u,32768):u;i(e,c,s,d,l)}}))}})})(e.codefix||(e.codefix={}))}(d||(d={})),function(e){(function(n){var t="fixMissingCallParentheses",r=[e.Diagnostics.This_condition_will_always_return_true_since_this_function_is_always_defined_Did_you_mean_to_call_it_instead.code];function a(e,n,t){e.replaceNodeWithText(n,t,t.text+"()")}function i(n,t){var r=e.getTokenAtPosition(n,t);if(e.isPropertyAccessExpression(r.parent)){var a=r.parent;while(e.isPropertyAccessExpression(a.parent))a=a.parent;return a.name}if(e.isIdentifier(r))return r}n.registerCodeFix({errorCodes:r,fixIds:[t],getCodeActions:function(r){var o=r.sourceFile,s=r.span,c=i(o,s.start);if(c){var l=e.textChanges.ChangeTracker.with(r,(function(e){return a(e,r.sourceFile,c)}));return[n.createCodeFixAction(t,l,e.Diagnostics.Add_missing_call_parentheses,t,e.Diagnostics.Add_all_missing_call_parentheses)]}},getAllCodeActions:function(e){return n.codeFixAll(e,r,(function(e,n){var t=i(n.file,n.start);t&&a(e,n.file,t)}))}})})(e.codefix||(e.codefix={}))}(d||(d={})),function(e){(function(n){var t="fixAwaitInSyncFunction",r=[e.Diagnostics.await_expressions_are_only_allowed_within_async_functions_and_at_the_top_levels_of_modules.code,e.Diagnostics.for_await_loops_are_only_allowed_within_async_functions_and_at_the_top_levels_of_modules.code];function a(n){return n.type?n.type:e.isVariableDeclaration(n.parent)&&n.parent.type&&e.isFunctionTypeNode(n.parent.type)?n.parent.type.type:void 0}function i(n,t){var r=e.getTokenAtPosition(n,t),i=e.getContainingFunction(r);if(i){var o;switch(i.kind){case 166:o=i.name;break;case 252:case 209:o=e.findChildOfKind(i,97,n);break;case 210:o=e.findChildOfKind(i,20,n)||e.first(i.parameters);break;default:return}return o&&{insertBefore:o,returnType:a(i)}}}function o(n,t,r){var a=r.insertBefore,i=r.returnType;if(i){var o=e.getEntityNameFromTypeNode(i);o&&78===o.kind&&"Promise"===o.text||n.replaceNode(t,i,e.factory.createTypeReferenceNode("Promise",e.factory.createNodeArray([i])))}n.insertModifierBefore(t,129,a)}n.registerCodeFix({errorCodes:r,getCodeActions:function(r){var a=r.sourceFile,s=r.span,c=i(a,s.start);if(c){var l=e.textChanges.ChangeTracker.with(r,(function(e){return o(e,a,c)}));return[n.createCodeFixAction(t,l,e.Diagnostics.Add_async_modifier_to_containing_function,t,e.Diagnostics.Add_all_missing_async_modifiers)]}},fixIds:[t],getAllCodeActions:function(t){var a=new e.Map;return n.codeFixAll(t,r,(function(n,r){var s=i(r.file,r.start);s&&e.addToSeen(a,e.getNodeId(s.insertBefore))&&o(n,t.sourceFile,s)}))}})})(e.codefix||(e.codefix={}))}(d||(d={})),function(e){(function(n){var t=[e.Diagnostics._0_is_defined_as_an_accessor_in_class_1_but_is_overridden_here_in_2_as_an_instance_property.code,e.Diagnostics._0_is_defined_as_a_property_in_class_1_but_is_overridden_here_in_2_as_an_accessor.code],r="fixPropertyOverrideAccessor";function a(t,r,a,i,o){var s,c;if(i===e.Diagnostics._0_is_defined_as_an_accessor_in_class_1_but_is_overridden_here_in_2_as_an_instance_property.code)s=r,c=r+a;else if(i===e.Diagnostics._0_is_defined_as_a_property_in_class_1_but_is_overridden_here_in_2_as_an_accessor.code){var l=o.program.getTypeChecker(),u=e.getTokenAtPosition(t,r).parent;e.Debug.assert(e.isAccessor(u),"error span of fixPropertyOverrideAccessor should only be on an accessor");var d=u.parent;e.Debug.assert(e.isClassLike(d),"erroneous accessors should only be inside classes");var p=e.singleOrUndefined(n.getAllSupers(d,l));if(!p)return[];var f=e.unescapeLeadingUnderscores(e.getTextOfPropertyName(u.name)),m=l.getPropertyOfType(l.getTypeAtLocation(p),f);if(!m||!m.valueDeclaration)return[];s=m.valueDeclaration.pos,c=m.valueDeclaration.end,t=e.getSourceFileOfNode(m.valueDeclaration)}else e.Debug.fail("fixPropertyOverrideAccessor codefix got unexpected error code "+i);return n.generateAccessorFromProperty(t,o.program,s,c,o,e.Diagnostics.Generate_get_and_set_accessors.message)}n.registerCodeFix({errorCodes:t,getCodeActions:function(t){var i=a(t.sourceFile,t.span.start,t.span.length,t.errorCode,t);if(i)return[n.createCodeFixAction(r,i,e.Diagnostics.Generate_get_and_set_accessors,r,e.Diagnostics.Generate_get_and_set_accessors_for_all_overriding_properties)]},fixIds:[r],getAllCodeActions:function(e){return n.codeFixAll(e,t,(function(n,t){var r=a(t.file,t.start,t.length,t.code,e);if(r)for(var i=0,o=r;i<o.length;i++){var s=o[i];n.pushRaw(e.sourceFile,s)}}))}})})(e.codefix||(e.codefix={}))}(d||(d={})),function(e){(function(n){var t="inferFromUsage",r=[e.Diagnostics.Variable_0_implicitly_has_type_1_in_some_locations_where_its_type_cannot_be_determined.code,e.Diagnostics.Variable_0_implicitly_has_an_1_type.code,e.Diagnostics.Parameter_0_implicitly_has_an_1_type.code,e.Diagnostics.Rest_parameter_0_implicitly_has_an_any_type.code,e.Diagnostics.Property_0_implicitly_has_type_any_because_its_get_accessor_lacks_a_return_type_annotation.code,e.Diagnostics._0_which_lacks_return_type_annotation_implicitly_has_an_1_return_type.code,e.Diagnostics.Property_0_implicitly_has_type_any_because_its_set_accessor_lacks_a_parameter_type_annotation.code,e.Diagnostics.Member_0_implicitly_has_an_1_type.code,e.Diagnostics.Variable_0_implicitly_has_type_1_in_some_locations_but_a_better_type_may_be_inferred_from_usage.code,e.Diagnostics.Variable_0_implicitly_has_an_1_type_but_a_better_type_may_be_inferred_from_usage.code,e.Diagnostics.Parameter_0_implicitly_has_an_1_type_but_a_better_type_may_be_inferred_from_usage.code,e.Diagnostics.Rest_parameter_0_implicitly_has_an_any_type_but_a_better_type_may_be_inferred_from_usage.code,e.Diagnostics.Property_0_implicitly_has_type_any_but_a_better_type_for_its_get_accessor_may_be_inferred_from_usage.code,e.Diagnostics._0_implicitly_has_an_1_return_type_but_a_better_type_may_be_inferred_from_usage.code,e.Diagnostics.Property_0_implicitly_has_type_any_but_a_better_type_for_its_set_accessor_may_be_inferred_from_usage.code,e.Diagnostics.Member_0_implicitly_has_an_1_type_but_a_better_type_may_be_inferred_from_usage.code,e.Diagnostics.this_implicitly_has_type_any_because_it_does_not_have_a_type_annotation.code];function a(n,t){switch(n){case e.Diagnostics.Parameter_0_implicitly_has_an_1_type.code:case e.Diagnostics.Parameter_0_implicitly_has_an_1_type_but_a_better_type_may_be_inferred_from_usage.code:return e.isSetAccessorDeclaration(e.getContainingFunction(t))?e.Diagnostics.Infer_type_of_0_from_usage:e.Diagnostics.Infer_parameter_types_from_usage;case e.Diagnostics.Rest_parameter_0_implicitly_has_an_any_type.code:case e.Diagnostics.Rest_parameter_0_implicitly_has_an_any_type_but_a_better_type_may_be_inferred_from_usage.code:return e.Diagnostics.Infer_parameter_types_from_usage;case e.Diagnostics.this_implicitly_has_type_any_because_it_does_not_have_a_type_annotation.code:return e.Diagnostics.Infer_this_type_of_0_from_usage;default:return e.Diagnostics.Infer_type_of_0_from_usage}}function o(n){switch(n){case e.Diagnostics.Variable_0_implicitly_has_type_1_in_some_locations_but_a_better_type_may_be_inferred_from_usage.code:return e.Diagnostics.Variable_0_implicitly_has_type_1_in_some_locations_where_its_type_cannot_be_determined.code;case e.Diagnostics.Variable_0_implicitly_has_an_1_type_but_a_better_type_may_be_inferred_from_usage.code:return e.Diagnostics.Variable_0_implicitly_has_an_1_type.code;case e.Diagnostics.Parameter_0_implicitly_has_an_1_type_but_a_better_type_may_be_inferred_from_usage.code:return e.Diagnostics.Parameter_0_implicitly_has_an_1_type.code;case e.Diagnostics.Rest_parameter_0_implicitly_has_an_any_type_but_a_better_type_may_be_inferred_from_usage.code:return e.Diagnostics.Rest_parameter_0_implicitly_has_an_any_type.code;case e.Diagnostics.Property_0_implicitly_has_type_any_but_a_better_type_for_its_get_accessor_may_be_inferred_from_usage.code:return e.Diagnostics.Property_0_implicitly_has_type_any_because_its_get_accessor_lacks_a_return_type_annotation.code;case e.Diagnostics._0_implicitly_has_an_1_return_type_but_a_better_type_may_be_inferred_from_usage.code:return e.Diagnostics._0_which_lacks_return_type_annotation_implicitly_has_an_1_return_type.code;case e.Diagnostics.Property_0_implicitly_has_type_any_but_a_better_type_for_its_set_accessor_may_be_inferred_from_usage.code:return e.Diagnostics.Property_0_implicitly_has_type_any_because_its_set_accessor_lacks_a_parameter_type_annotation.code;case e.Diagnostics.Member_0_implicitly_has_an_1_type_but_a_better_type_may_be_inferred_from_usage.code:return e.Diagnostics.Member_0_implicitly_has_an_1_type.code}return n}function s(t,r,a,i,s,d,m,_,y){if(e.isParameterPropertyModifier(a.kind)||78===a.kind||25===a.kind||107===a.kind){var h=a.parent,v=n.createImportAdder(r,s,y,_);switch(i=o(i),i){case e.Diagnostics.Member_0_implicitly_has_an_1_type.code:case e.Diagnostics.Variable_0_implicitly_has_type_1_in_some_locations_where_its_type_cannot_be_determined.code:if(e.isVariableDeclaration(h)&&m(h)||e.isPropertyDeclaration(h)||e.isPropertySignature(h))return c(t,v,r,h,s,_,d),v.writeFixes(t),h;if(e.isPropertyAccessExpression(h)){var E=b(h.name,s,d),T=e.getTypeNodeIfAccessible(E,h,s,_);if(T){var S=e.factory.createJSDocTypeTag(void 0,e.factory.createJSDocTypeExpression(T),void 0);g(t,r,e.cast(h.parent.parent,e.isExpressionStatement),[S])}return v.writeFixes(t),h}return;case e.Diagnostics.Variable_0_implicitly_has_an_1_type.code:var x=s.getTypeChecker().getSymbolAtLocation(a);return x&&x.valueDeclaration&&e.isVariableDeclaration(x.valueDeclaration)&&m(x.valueDeclaration)?(c(t,v,r,x.valueDeclaration,s,_,d),v.writeFixes(t),x.valueDeclaration):void 0}var L=e.getContainingFunction(a);if(void 0!==L){var D;switch(i){case e.Diagnostics.Parameter_0_implicitly_has_an_1_type.code:if(e.isSetAccessorDeclaration(L)){p(t,v,r,L,s,_,d),D=L;break}case e.Diagnostics.Rest_parameter_0_implicitly_has_an_any_type.code:if(m(L)){var A=e.cast(h,e.isParameter);l(t,v,r,A,L,s,_,d),D=A}break;case e.Diagnostics.Property_0_implicitly_has_type_any_because_its_get_accessor_lacks_a_return_type_annotation.code:case e.Diagnostics._0_which_lacks_return_type_annotation_implicitly_has_an_1_return_type.code:e.isGetAccessorDeclaration(L)&&e.isIdentifier(L.name)&&(f(t,v,r,L,b(L.name,s,d),s,_),D=L);break;case e.Diagnostics.Property_0_implicitly_has_type_any_because_its_set_accessor_lacks_a_parameter_type_annotation.code:e.isSetAccessorDeclaration(L)&&(p(t,v,r,L,s,_,d),D=L);break;case e.Diagnostics.this_implicitly_has_type_any_because_it_does_not_have_a_type_annotation.code:e.textChanges.isThisTypeAnnotatable(L)&&m(L)&&(u(t,r,L,s,_,d),D=L);break;default:return e.Debug.fail(String(i))}return v.writeFixes(t),D}}}function c(n,t,r,a,i,o,s){e.isIdentifier(a.name)&&f(n,t,r,a,b(a.name,i,s),i,o)}function l(n,t,r,a,i,o,s,c){if(e.isIdentifier(a.name)){var l=E(i,r,o,c);if(e.Debug.assert(i.parameters.length===l.length,"Parameter count and inference count should match"),e.isInJSFile(i))_(n,r,l,o,s);else{var u=e.isArrowFunction(i)&&!e.findChildOfKind(i,20,r);u&&n.insertNodeBefore(r,e.first(i.parameters),e.factory.createToken(20));for(var d=0,p=l;d<p.length;d++){var m=p[d],g=m.declaration,y=m.type;!g||g.type||g.initializer||f(n,t,r,g,y,o,s)}u&&n.insertNodeAfter(r,e.last(i.parameters),e.factory.createToken(21))}}}function u(n,t,r,a,i,o){var s=T(r,t,a,o);if(s&&s.length){var c=S(a,s,o).thisParameter(),l=e.getTypeNodeIfAccessible(c,r,a,i);l&&(e.isInJSFile(r)?d(n,t,r,l):n.tryInsertThisTypeAnnotation(t,r,l))}}function d(n,t,r,a){g(n,t,r,[e.factory.createJSDocThisTag(void 0,e.factory.createJSDocTypeExpression(a))])}function p(n,t,r,a,i,o,s){var c=e.firstOrUndefined(a.parameters);if(c&&e.isIdentifier(a.name)&&e.isIdentifier(c.name)){var l=b(a.name,i,s);l===i.getTypeChecker().getAnyType()&&(l=b(c.name,i,s)),e.isInJSFile(a)?_(n,r,[{declaration:c,type:l}],i,o):f(n,t,r,c,l,i,o)}}function f(n,t,r,a,i,o,s){var c=e.getTypeNodeIfAccessible(i,a,o,s);if(c)if(e.isInJSFile(r)&&163!==a.kind){var l=e.isVariableDeclaration(a)?e.tryCast(a.parent.parent,e.isVariableStatement):a;if(!l)return;var u=e.factory.createJSDocTypeExpression(c),d=e.isGetAccessorDeclaration(a)?e.factory.createJSDocReturnTag(void 0,u,void 0):e.factory.createJSDocTypeTag(void 0,u,void 0);g(n,r,l,[d])}else m(c,a,r,n,t,e.getEmitScriptTarget(o.getCompilerOptions()))||n.tryInsertTypeAnnotation(r,a,c)}function m(t,r,a,i,o,s){var c=n.tryGetAutoImportableReferenceFromTypeNode(t,s);return!(!c||!i.tryInsertTypeAnnotation(a,r,c.typeNode))&&(e.forEach(c.symbols,(function(e){return o.addImportFromExportedSymbol(e,!0)})),!0)}function _(n,t,r,a,i){var o=r.length&&r[0].declaration.parent;if(o){var s=e.mapDefined(r,(function(n){var t=n.declaration;if(!t.initializer&&!e.getJSDocType(t)&&e.isIdentifier(t.name)){var r=n.type&&e.getTypeNodeIfAccessible(n.type,t,a,i);if(r){var o=e.factory.cloneNode(t.name);return e.setEmitFlags(o,3584),{name:e.factory.cloneNode(t.name),param:t,isOptional:!!n.isOptional,typeNode:r}}}}));if(s.length)if(e.isArrowFunction(o)||e.isFunctionExpression(o)){var c=e.isArrowFunction(o)&&!e.findChildOfKind(o,20,t);c&&n.insertNodeBefore(t,e.first(o.parameters),e.factory.createToken(20)),e.forEach(s,(function(r){var a=r.typeNode,i=r.param,o=e.factory.createJSDocTypeTag(void 0,e.factory.createJSDocTypeExpression(a)),s=e.factory.createJSDocComment(void 0,[o]);n.insertNodeAt(t,i.getStart(t),s,{suffix:" "})})),c&&n.insertNodeAfter(t,e.last(o.parameters),e.factory.createToken(21))}else{var l=e.map(s,(function(n){var t=n.name,r=n.typeNode,a=n.isOptional;return e.factory.createJSDocParameterTag(void 0,t,!!a,e.factory.createJSDocTypeExpression(r),!1,void 0)}));g(n,t,o,l)}}}function g(n,t,r,a){var o=e.flatMap(r.jsDoc,(function(n){return"string"===typeof n.comment?e.factory.createJSDocText(n.comment):n.comment})),s=e.flatMapToMutable(r.jsDoc,(function(e){return e.tags})),c=a.filter((function(e){return!s||!s.some((function(n,t){var r=h(n,e);return r&&(s[t]=r),!!r}))})),l=e.factory.createJSDocComment(e.factory.createNodeArray(e.intersperse(o,e.factory.createJSDocText("\n"))),e.factory.createNodeArray(i(i([],s||e.emptyArray),c))),u=210===r.kind?y(r):r;u.jsDoc=r.jsDoc,u.jsDocCache=r.jsDocCache,n.insertJsdocCommentBefore(t,u,l)}function y(e){return 164===e.parent.kind?e.parent:e.parent.parent}function h(n,t){if(n.kind===t.kind)switch(n.kind){case 330:var r=n,a=t;return e.isIdentifier(r.name)&&e.isIdentifier(a.name)&&r.name.escapedText===a.name.escapedText?e.factory.createJSDocParameterTag(void 0,a.name,!1,a.typeExpression,a.isNameFirst,r.comment):void 0;case 331:return e.factory.createJSDocReturnTag(void 0,t.typeExpression,n.comment)}}function v(n,t,r){return e.mapDefined(e.FindAllReferences.getReferenceEntriesForNode(-1,n,t,t.getSourceFiles(),r),(function(n){return 0!==n.kind?e.tryCast(n.node,e.isIdentifier):void 0}))}function b(e,n,t){var r=v(e,n,t);return S(n,r,t).single()}function E(n,t,r,a){var i=T(n,t,r,a);return i&&S(r,i,a).parameters(n)||n.parameters.map((function(n){return{declaration:n,type:e.isIdentifier(n.name)?b(n.name,r,a):r.getTypeChecker().getAnyType()}}))}function T(n,t,r,a){var i;switch(n.kind){case 167:i=e.findChildOfKind(n,132,t);break;case 210:case 209:var o=n.parent;i=(e.isVariableDeclaration(o)||e.isPropertyDeclaration(o))&&e.isIdentifier(o.name)?o.name:n.name;break;case 252:case 166:case 165:i=n.name;break}if(i)return v(i,r,a)}function S(n,t,r){var a=n.getTypeChecker(),o={string:function(){return a.getStringType()},number:function(){return a.getNumberType()},Array:function(e){return a.createArrayType(e)},Promise:function(e){return a.createPromiseType(e)}},s=[a.getStringType(),a.getNumberType(),a.createArrayType(a.getAnyType()),a.createPromiseType(a.getAnyType())];return{single:u,parameters:d,thisParameter:p};function c(){return{isNumber:void 0,isString:void 0,isNumberOrString:void 0,candidateTypes:void 0,properties:void 0,calls:void 0,constructs:void 0,numberIndex:void 0,stringIndex:void 0,candidateThisTypes:void 0,inferredTypes:void 0}}function l(n){for(var t=new e.Map,r=0,a=n;r<a.length;r++){var i=a[r];i.properties&&i.properties.forEach((function(e,n){t.has(n)||t.set(n,[]),t.get(n).push(e)}))}var o=new e.Map;return t.forEach((function(e,n){o.set(n,l(e))})),{isNumber:n.some((function(e){return e.isNumber})),isString:n.some((function(e){return e.isString})),isNumberOrString:n.some((function(e){return e.isNumberOrString})),candidateTypes:e.flatMap(n,(function(e){return e.candidateTypes})),properties:o,calls:e.flatMap(n,(function(e){return e.calls})),constructs:e.flatMap(n,(function(e){return e.constructs})),numberIndex:e.forEach(n,(function(e){return e.numberIndex})),stringIndex:e.forEach(n,(function(e){return e.stringIndex})),candidateThisTypes:e.flatMap(n,(function(e){return e.candidateThisTypes})),inferredTypes:void 0}}function u(){return C(f(t))}function d(o){if(0!==t.length&&o.parameters){for(var s=c(),l=0,u=t;l<u.length;l++){var d=u[l];r.throwIfCancellationRequested(),m(d,s)}var p=i(i([],s.constructs||[]),s.calls||[]);return o.parameters.map((function(t,i){for(var s=[],c=e.isRestParameter(t),l=!1,u=0,d=p;u<d.length;u++){var m=d[u];if(m.argumentTypes.length<=i)l=e.isInJSFile(o),s.push(a.getUndefinedType());else if(c)for(var _=i;_<m.argumentTypes.length;_++)s.push(a.getBaseTypeOfLiteralType(m.argumentTypes[_]));else s.push(a.getBaseTypeOfLiteralType(m.argumentTypes[i]))}if(e.isIdentifier(t.name)){var g=f(v(t.name,n,r));s.push.apply(s,c?e.mapDefined(g,a.getElementTypeOfArrayType):g)}var y=C(s);return{type:c?a.createArrayType(y):y,isOptional:l&&!c,declaration:t}}))}}function p(){for(var n=c(),a=0,i=t;a<i.length;a++){var o=i[a];r.throwIfCancellationRequested(),m(o,n)}return C(n.candidateThisTypes||e.emptyArray)}function f(e){for(var n=c(),t=0,a=e;t<a.length;t++){var i=a[t];r.throwIfCancellationRequested(),m(i,n)}return N(n)}function m(n,t){while(e.isRightSideOfQualifiedNameOrPropertyAccess(n))n=n.parent;switch(n.parent.kind){case 234:g(n,t);break;case 216:t.isNumber=!0;break;case 215:y(n.parent,t);break;case 217:h(n,n.parent,t);break;case 285:case 286:b(n.parent,t);break;case 204:case 205:n.parent.expression===n?E(n.parent,t):_(n,t);break;case 202:T(n.parent,t);break;case 203:S(n.parent,n,t);break;case 289:case 290:x(n.parent,t);break;case 164:L(n.parent,t);break;case 250:var r=n.parent,i=r.name,o=r.initializer;if(n===i){o&&B(t,a.getTypeAtLocation(o));break}default:return _(n,t)}}function _(n,t){e.isExpressionNode(n)&&B(t,a.getContextualType(n))}function g(n,t){B(t,e.isCallExpression(n)?a.getVoidType():a.getAnyType())}function y(e,n){switch(e.operator){case 45:case 46:case 40:case 54:n.isNumber=!0;break;case 39:n.isNumberOrString=!0;break}}function h(n,t,r){switch(t.operatorToken.kind){case 42:case 41:case 43:case 44:case 47:case 48:case 49:case 50:case 51:case 52:case 64:case 66:case 65:case 67:case 68:case 72:case 73:case 77:case 69:case 71:case 70:case 40:case 29:case 32:case 31:case 33:var i=a.getTypeAtLocation(t.left===n?t.right:t.left);1056&i.flags?B(r,i):r.isNumber=!0;break;case 63:case 39:var o=a.getTypeAtLocation(t.left===n?t.right:t.left);1056&o.flags?B(r,o):296&o.flags?r.isNumber=!0:402653316&o.flags?r.isString=!0:1&o.flags||(r.isNumberOrString=!0);break;case 62:case 34:case 36:case 37:case 35:B(r,a.getTypeAtLocation(t.left===n?t.right:t.left));break;case 100:n===t.left&&(r.isString=!0);break;case 56:case 60:n!==t.left||250!==n.parent.parent.kind&&!e.isAssignmentExpression(n.parent.parent,!0)||B(r,a.getTypeAtLocation(t.right));break;case 55:case 27:case 101:break}}function b(e,n){B(n,a.getTypeAtLocation(e.parent.parent.expression))}function E(e,n){var t={argumentTypes:[],return_:c()};if(e.arguments)for(var r=0,i=e.arguments;r<i.length;r++){var o=i[r];t.argumentTypes.push(a.getTypeAtLocation(o))}m(e,t.return_),204===e.kind?(n.calls||(n.calls=[])).push(t):(n.constructs||(n.constructs=[])).push(t)}function T(n,t){var r=e.escapeLeadingUnderscores(n.name.text);t.properties||(t.properties=new e.Map);var a=t.properties.get(r)||c();m(n,a),t.properties.set(r,a)}function S(e,n,t){if(n!==e.argumentExpression){var r=a.getTypeAtLocation(e.argumentExpression),i=c();m(e,i),296&r.flags?t.numberIndex=i:t.stringIndex=i}else t.isNumberOrString=!0}function x(n,t){var r=e.isVariableDeclaration(n.parent.parent)?n.parent.parent:n.parent;U(t,a.getTypeAtLocation(r))}function L(e,n){U(n,a.getTypeAtLocation(e.parent))}function D(n,t){for(var r=[],a=0,i=n;a<i.length;a++)for(var o=i[a],s=0,c=t;s<c.length;s++){var l=c[s],u=l.high,d=l.low;u(o)&&(e.Debug.assert(!d(o),"Priority can't have both low and high"),r.push(d))}return n.filter((function(e){return r.every((function(n){return!n(e)}))}))}function A(e){return C(N(e))}function C(n){if(!n.length)return a.getAnyType();var t=a.getUnionType([a.getStringType(),a.getNumberType()]),r=[{high:function(e){return e===a.getStringType()||e===a.getNumberType()},low:function(e){return e===t}},{high:function(e){return!(16385&e.flags)},low:function(e){return!!(16385&e.flags)}},{high:function(n){return!(114689&n.flags)&&!(16&e.getObjectFlags(n))},low:function(n){return!!(16&e.getObjectFlags(n))}}],i=D(n,r),o=i.filter((function(n){return 16&e.getObjectFlags(n)}));return o.length&&(i=i.filter((function(n){return!(16&e.getObjectFlags(n))})),i.push(I(o))),a.getWidenedType(a.getUnionType(i.map(a.getBaseTypeOfLiteralType),2))}function I(n){if(1===n.length)return n[0];for(var t=[],r=[],i=[],o=[],s=!1,c=!1,l=e.createMultiMap(),u=0,d=n;u<d.length;u++){for(var p=d[u],f=0,m=a.getPropertiesOfType(p);f<m.length;f++){var _=m[f];l.add(_.name,_.valueDeclaration?a.getTypeOfSymbolAtLocation(_,_.valueDeclaration):a.getAnyType())}t.push.apply(t,a.getSignaturesOfType(p,0)),r.push.apply(r,a.getSignaturesOfType(p,1)),p.stringIndexInfo&&(i.push(p.stringIndexInfo.type),s=s||p.stringIndexInfo.isReadonly),p.numberIndexInfo&&(o.push(p.numberIndexInfo.type),c=c||p.numberIndexInfo.isReadonly)}var g=e.mapEntries(l,(function(e,t){var r=t.length<n.length?16777216:0,i=a.createSymbol(4|r,e);return i.type=a.getUnionType(t),[e,i]}));return a.createAnonymousType(n[0].symbol,g,t,r,i.length?a.createIndexInfo(a.getUnionType(i),s):void 0,o.length?a.createIndexInfo(a.getUnionType(o),c):void 0)}function N(e){var n,t,r,i=[];return e.isNumber&&i.push(a.getNumberType()),e.isString&&i.push(a.getStringType()),e.isNumberOrString&&i.push(a.getUnionType([a.getStringType(),a.getNumberType()])),e.numberIndex&&i.push(a.createArrayType(A(e.numberIndex))),((null===(n=e.properties)||void 0===n?void 0:n.size)||(null===(t=e.calls)||void 0===t?void 0:t.length)||(null===(r=e.constructs)||void 0===r?void 0:r.length)||e.stringIndex)&&i.push(k(e)),i.push.apply(i,(e.candidateTypes||[]).map((function(e){return a.getBaseTypeOfLiteralType(e)}))),i.push.apply(i,R(e)),i}function k(n){var t=new e.Map;n.properties&&n.properties.forEach((function(e,n){var r=a.createSymbol(4,n);r.type=A(e),t.set(n,r)}));var r=n.calls?[G(n.calls)]:[],i=n.constructs?[G(n.constructs)]:[],o=n.stringIndex&&a.createIndexInfo(A(n.stringIndex),!1);return a.createAnonymousType(void 0,t,r,i,o,void 0)}function R(e){if(!e.properties||!e.properties.size)return[];var n=s.filter((function(n){return O(n,e)}));return 0<n.length&&n.length<3?n.map((function(n){return w(n,e)})):[]}function O(n,t){return!!t.properties&&!e.forEachEntry(t.properties,(function(e,t){var r=a.getTypeOfPropertyOfType(n,t);if(!r)return!0;if(e.calls){var i=a.getSignaturesOfType(r,0);return!i.length||!a.isTypeAssignableTo(r,F(e.calls))}return!a.isTypeAssignableTo(r,A(e))}))}function w(n,t){if(!(4&e.getObjectFlags(n))||!t.properties)return n;var r=n.target,i=e.singleOrUndefined(r.typeParameters);if(!i)return n;var s=[];return t.properties.forEach((function(n,t){var o=a.getTypeOfPropertyOfType(r,t);e.Debug.assert(!!o,"generic should have all the properties of its reference."),s.push.apply(s,P(o,A(n),i))})),o[n.symbol.escapedName](C(s))}function P(n,t,r){if(n===r)return[t];if(3145728&n.flags)return e.flatMap(n.types,(function(e){return P(e,t,r)}));if(4&e.getObjectFlags(n)&&4&e.getObjectFlags(t)){var i=a.getTypeArguments(n),o=a.getTypeArguments(t),s=[];if(i&&o)for(var c=0;c<i.length;c++)o[c]&&s.push.apply(s,P(i[c],o[c],r));return s}var l=a.getSignaturesOfType(n,0),u=a.getSignaturesOfType(t,0);return 1===l.length&&1===u.length?M(l[0],u[0],r):[]}function M(n,t,r){for(var i=[],o=0;o<n.parameters.length;o++){var s=n.parameters[o],c=t.parameters[o],l=n.declaration&&e.isRestParameter(n.declaration.parameters[o]);if(!c)break;var u=s.valueDeclaration?a.getTypeOfSymbolAtLocation(s,s.valueDeclaration):a.getAnyType(),d=l&&a.getElementTypeOfArrayType(u);d&&(u=d);var p=c.type||(c.valueDeclaration?a.getTypeOfSymbolAtLocation(c,c.valueDeclaration):a.getAnyType());i.push.apply(i,P(u,p,r))}var f=a.getReturnTypeOfSignature(n),m=a.getReturnTypeOfSignature(t);return i.push.apply(i,P(f,m,r)),i}function F(n){return a.createAnonymousType(void 0,e.createSymbolTable(),[G(n)],e.emptyArray,void 0,void 0)}function G(n){for(var t=[],r=Math.max.apply(Math,n.map((function(e){return e.argumentTypes.length}))),i=function(r){var i=a.createSymbol(1,e.escapeLeadingUnderscores("arg"+r));i.type=C(n.map((function(e){return e.argumentTypes[r]||a.getUndefinedType()}))),n.some((function(e){return void 0===e.argumentTypes[r]}))&&(i.flags|=16777216),t.push(i)},o=0;o<r;o++)i(o);var s=A(l(n.map((function(e){return e.return_}))));return a.createSignature(void 0,void 0,void 0,t,s,void 0,r,0)}function B(e,n){!n||1&n.flags||131072&n.flags||(e.candidateTypes||(e.candidateTypes=[])).push(n)}function U(e,n){!n||1&n.flags||131072&n.flags||(e.candidateThisTypes||(e.candidateThisTypes=[])).push(n)}}n.registerCodeFix({errorCodes:r,getCodeActions:function(r){var i,o=r.sourceFile,c=r.program,l=r.span.start,u=r.errorCode,d=r.cancellationToken,p=r.host,f=r.preferences,m=e.getTokenAtPosition(o,l),_=e.textChanges.ChangeTracker.with(r,(function(n){i=s(n,o,m,u,c,d,e.returnTrue,p,f)})),g=i&&e.getNameOfDeclaration(i);return g&&0!==_.length?[n.createCodeFixAction(t,_,[a(u,m),g.getText(o)],t,e.Diagnostics.Infer_all_types_from_usage)]:void 0},fixIds:[t],getAllCodeActions:function(t){var a=t.sourceFile,i=t.program,o=t.cancellationToken,c=t.host,l=t.preferences,u=e.nodeSeenTracker();return n.codeFixAll(t,r,(function(n,t){s(n,a,e.getTokenAtPosition(t.file,t.start),t.code,i,o,u,c,l)}))}}),n.addJSDocTags=g})(e.codefix||(e.codefix={}))}(d||(d={})),function(e){(function(n){var t="fixReturnTypeInAsyncFunction",r=[e.Diagnostics.The_return_type_of_an_async_function_or_method_must_be_the_global_Promise_T_type_Did_you_mean_to_write_Promise_0.code];function a(n,t,r){if(!e.isInJSFile(n)){var a=e.getTokenAtPosition(n,r),i=e.findAncestor(a,e.isFunctionLikeDeclaration),o=null===i||void 0===i?void 0:i.type;if(o){var s=t.getTypeFromTypeNode(o),c=t.getAwaitedType(s)||t.getVoidType(),l=t.typeToTypeNode(c,o,void 0);return l?{returnTypeNode:o,returnType:s,promisedTypeNode:l,promisedType:c}:void 0}}}function i(n,t,r,a){n.replaceNode(t,r,e.factory.createTypeReferenceNode("Promise",[a]))}n.registerCodeFix({errorCodes:r,fixIds:[t],getCodeActions:function(r){var o=r.sourceFile,s=r.program,c=r.span,l=s.getTypeChecker(),u=a(o,s.getTypeChecker(),c.start);if(u){var d=u.returnTypeNode,p=u.returnType,f=u.promisedTypeNode,m=u.promisedType,_=e.textChanges.ChangeTracker.with(r,(function(e){return i(e,o,d,f)}));return[n.createCodeFixAction(t,_,[e.Diagnostics.Replace_0_with_Promise_1,l.typeToString(p),l.typeToString(m)],t,e.Diagnostics.Fix_all_incorrect_return_type_of_an_async_functions)]}},getAllCodeActions:function(e){return n.codeFixAll(e,r,(function(n,t){var r=a(t.file,e.program.getTypeChecker(),t.start);r&&i(n,t.file,r.returnTypeNode,r.promisedTypeNode)}))}})})(e.codefix||(e.codefix={}))}(d||(d={})),function(e){(function(n){var t="disableJsDiagnostics",r="disableJsDiagnostics",a=e.mapDefined(Object.keys(e.Diagnostics),(function(n){var t=e.Diagnostics[n];return t.category===e.DiagnosticCategory.Error?t.code:void 0}));function i(n,t,r,a){var i=e.getLineAndCharacterOfPosition(t,r).line;a&&!e.tryAddToSet(a,i)||n.insertCommentBeforeLine(t,i,r," @ts-ignore")}n.registerCodeFix({errorCodes:a,getCodeActions:function(a){var o=a.sourceFile,s=a.program,c=a.span,l=a.host,u=a.formatContext;if(e.isInJSFile(o)&&e.isCheckJsEnabledForFile(o,s.getCompilerOptions())){var d=o.checkJsDirective?"":e.getNewLineOrDefaultFromHost(l,u.options),p=[n.createCodeFixActionWithoutFixAll(t,[n.createFileTextChanges(o.fileName,[e.createTextChange(o.checkJsDirective?e.createTextSpanFromBounds(o.checkJsDirective.pos,o.checkJsDirective.end):e.createTextSpan(0,0),"// @ts-nocheck"+d)])],e.Diagnostics.Disable_checking_for_this_file)];return e.textChanges.isValidLocationToAddComment(o,c.start)&&p.unshift(n.createCodeFixAction(t,e.textChanges.ChangeTracker.with(a,(function(e){return i(e,o,c.start)})),e.Diagnostics.Ignore_this_error_message,r,e.Diagnostics.Add_ts_ignore_to_all_error_messages)),p}},fixIds:[r],getAllCodeActions:function(t){var r=new e.Set;return n.codeFixAll(t,a,(function(n,t){e.textChanges.isValidLocationToAddComment(t.file,t.start)&&i(n,t.file,t.start,r)}))}})})(e.codefix||(e.codefix={}))}(d||(d={})),function(e){(function(n){function t(e,n,t,r,i,o,s){for(var c=e.symbol.members,l=0,u=n;l<u.length;l++){var d=u[l];c.has(d.escapedName)||a(d,e,t,r,i,o,s)}}function r(n){return{trackSymbol:e.noop,moduleResolverHost:e.getModuleSpecifierResolverHost(n.program,n.host)}}function a(n,t,a,o,s,u,d){var f=n.getDeclarations();if(f&&f.length){var _=o.program.getTypeChecker(),g=e.getEmitScriptTarget(o.program.getCompilerOptions()),y=f[0],h=e.getSynthesizedDeepClone(e.getNameOfDeclaration(y),!1),b=m(e.getEffectiveModifierFlags(y)),T=b?e.factory.createNodeArray([b]):void 0,S=_.getWidenedType(_.getTypeOfSymbolAtLocation(n,t)),x=!!(16777216&n.flags),L=!!(8388608&t.flags),D=e.getQuotePreference(a,s);switch(y.kind){case 163:case 164:var A=0===D?268435456:void 0,C=_.typeToTypeNode(S,t,A,r(o));if(u){var I=v(C,g);I&&(C=I.typeNode,E(u,I.symbols))}d(e.factory.createPropertyDeclaration(void 0,T,h,x?e.factory.createToken(57):void 0,C,void 0));break;case 168:case 169:var N=_.typeToTypeNode(S,t,void 0,r(o)),k=e.getAllAccessorDeclarations(f,y),R=k.secondAccessor?[k.firstAccessor,k.secondAccessor]:[k.firstAccessor];if(u){I=v(N,g);I&&(N=I.typeNode,E(u,I.symbols))}for(var O=0,w=R;O<w.length;O++){var P=w[O];if(e.isGetAccessorDeclaration(P))d(e.factory.createGetAccessorDeclaration(void 0,T,h,e.emptyArray,N,L?void 0:p(D)));else{e.Debug.assertNode(P,e.isSetAccessorDeclaration,"The counterpart to a getter should be a setter");var M=e.getSetAccessorValueParameter(P),F=M&&e.isIdentifier(M.name)?e.idText(M.name):void 0;d(e.factory.createSetAccessorDeclaration(void 0,T,h,c(1,[F],[N],1,!1),L?void 0:p(D)))}}break;case 165:case 166:var G=_.getSignaturesOfType(S,0);if(!e.some(G))break;if(1===f.length){e.Debug.assert(1===G.length,"One declaration implies one signature");var B=G[0];j(D,B,T,h,L?void 0:p(D));break}for(var U=0,V=G;U<V.length;U++){B=V[U];j(D,B,e.getSynthesizedDeepClones(T,!1),e.getSynthesizedDeepClone(h,!1))}if(!L)if(f.length>G.length){B=_.getSignatureFromDeclaration(f[f.length-1]);j(D,B,T,h,p(D))}else e.Debug.assert(f.length===G.length,"Declarations and signatures should match count"),d(l(_,o,t,G,h,x,T,D));break}}function j(e,n,r,a,s){var c=i(o,e,n,t,r,a,x,s,u);c&&d(c)}}function i(n,t,a,i,o,s,c,l,u){var d=n.program,p=d.getTypeChecker(),f=e.getEmitScriptTarget(d.getCompilerOptions()),m=1073742081|(0===t?268435456:0),_=p.signatureToSignatureDeclaration(a,166,i,m,r(n));if(_){var g=_.typeParameters,y=_.parameters,h=_.type;if(u){if(g){var b=e.sameMap(g,(function(n){var t=n.constraint,r=n.default;if(t){var a=v(t,f);a&&(t=a.typeNode,E(u,a.symbols))}if(r){a=v(r,f);a&&(r=a.typeNode,E(u,a.symbols))}return e.factory.updateTypeParameterDeclaration(n,n.name,t,r)}));g!==b&&(g=e.setTextRange(e.factory.createNodeArray(b,g.hasTrailingComma),g))}var T=e.sameMap(y,(function(n){var t=v(n.type,f),r=n.type;return t&&(r=t.typeNode,E(u,t.symbols)),e.factory.updateParameterDeclaration(n,n.decorators,n.modifiers,n.dotDotDotToken,n.name,n.questionToken,r,n.initializer)}));if(y!==T&&(y=e.setTextRange(e.factory.createNodeArray(T,y.hasTrailingComma),y)),h){var S=v(h,f);S&&(h=S.typeNode,E(u,S.symbols))}}return e.factory.updateMethodDeclaration(_,void 0,o,_.asteriskToken,s,c?e.factory.createToken(57):void 0,g,y,h,l)}}function o(n,t,a,i,o,l,u){var d=e.getQuotePreference(t.sourceFile,t.preferences),m=e.getEmitScriptTarget(t.program.getCompilerOptions()),_=r(t),g=t.program.getTypeChecker(),y=e.isInJSFile(u),h=i.typeArguments,v=i.arguments,b=i.parent,E=y?void 0:g.getContextualType(i),T=e.map(v,(function(n){return e.isIdentifier(n)?n.text:e.isPropertyAccessExpression(n)&&e.isIdentifier(n.name)?n.name.text:void 0})),S=y?[]:e.map(v,(function(e){return s(g,a,g.getBaseTypeOfLiteralType(g.getTypeAtLocation(e)),u,m,void 0,_)})),x=l?e.factory.createNodeArray(e.factory.createModifiersFromModifierFlags(l)):void 0,L=e.isYieldExpression(b)?e.factory.createToken(41):void 0,D=y||void 0===h?void 0:e.map(h,(function(n,t){return e.factory.createTypeParameterDeclaration(84+h.length-1<=90?String.fromCharCode(84+t):"T"+t)})),A=c(v.length,T,S,void 0,y),C=y||void 0===E?void 0:g.typeToTypeNode(E,u,void 0,_);return 166===n?e.factory.createMethodDeclaration(void 0,x,L,o,void 0,D,A,C,e.isInterfaceDeclaration(u)?void 0:p(d)):e.factory.createFunctionDeclaration(void 0,x,L,o,D,A,C,f(e.Diagnostics.Function_not_implemented.message,d))}function s(n,t,r,a,i,o,s){var c=n.typeToTypeNode(r,a,o,s);if(c&&e.isImportTypeNode(c)){var l=v(c,i);if(l)return E(t,l.symbols),l.typeNode}return c}function c(n,t,r,a,i){for(var o=[],s=0;s<n;s++){var c=e.factory.createParameterDeclaration(void 0,void 0,void 0,t&&t[s]||"arg"+s,void 0!==a&&s>=a?e.factory.createToken(57):void 0,i?void 0:r&&r[s]||e.factory.createKeywordTypeNode(128),void 0);o.push(c)}return o}function l(n,t,r,a,i,o,s,l){for(var p=a[0],f=a[0].minArgumentCount,m=!1,_=0,g=a;_<g.length;_++){var y=g[_];f=Math.min(y.minArgumentCount,f),e.signatureHasRestParameter(y)&&(m=!0),y.parameters.length>=p.parameters.length&&(!e.signatureHasRestParameter(y)||e.signatureHasRestParameter(p))&&(p=y)}var h=p.parameters.length-(e.signatureHasRestParameter(p)?1:0),v=p.parameters.map((function(e){return e.name})),b=c(h,v,void 0,f,!1);if(m){var E=e.factory.createArrayTypeNode(e.factory.createKeywordTypeNode(128)),T=e.factory.createParameterDeclaration(void 0,void 0,e.factory.createToken(25),v[h]||"rest",h>=f?e.factory.createToken(57):void 0,E,void 0);b.push(T)}return d(s,i,o,void 0,b,u(a,n,t,r),l)}function u(n,t,a,i){if(e.length(n)){var o=t.getUnionType(e.map(n,t.getReturnTypeOfSignature));return t.typeToTypeNode(o,i,void 0,r(a))}}function d(n,t,r,a,i,o,s){return e.factory.createMethodDeclaration(void 0,n,void 0,t,r?e.factory.createToken(57):void 0,a,i,o,p(s))}function p(n){return f(e.Diagnostics.Method_not_implemented.message,n)}function f(n,t){return e.factory.createBlock([e.factory.createThrowStatement(e.factory.createNewExpression(e.factory.createIdentifier("Error"),void 0,[e.factory.createStringLiteral(n,0===t)]))],!0)}function m(n){return 4&n?e.factory.createToken(122):16&n?e.factory.createToken(121):void 0}function _(n,t,r){var a=e.getTsConfigObjectLiteralExpression(t);if(a){var i=h(a,"compilerOptions");if(void 0!==i){var o=i.initializer;if(e.isObjectLiteralExpression(o))for(var s=0,c=r;s<c.length;s++){var l=c[s],u=l[0],d=l[1],p=h(o,u);void 0===p?n.insertNodeAtObjectStart(t,o,y(u,d)):n.replaceNode(t,p.initializer,d)}}else n.insertNodeAtObjectStart(t,a,y("compilerOptions",e.factory.createObjectLiteralExpression(r.map((function(e){var n=e[0],t=e[1];return y(n,t)})),!0)))}}function g(e,n,t,r){_(e,n,[[t,r]])}function y(n,t){return e.factory.createPropertyAssignment(e.factory.createStringLiteral(n),t)}function h(n,t){return e.find(n.properties,(function(n){return e.isPropertyAssignment(n)&&!!n.name&&e.isStringLiteral(n.name)&&n.name.text===t}))}function v(n,t){var r,a=e.visitNode(n,i);if(r&&a)return{typeNode:a,symbols:r};function i(n){var a;if(e.isLiteralImportTypeNode(n)&&n.qualifier){var o=e.getFirstIdentifier(n.qualifier),s=e.getNameForExportedSymbol(o.symbol,t),c=s!==o.text?b(n.qualifier,e.factory.createIdentifier(s)):n.qualifier;r=e.append(r,o.symbol);var l=null===(a=n.typeArguments)||void 0===a?void 0:a.map(i);return e.factory.createTypeReferenceNode(c,l)}return e.visitEachChild(n,i,e.nullTransformationContext)}}function b(n,t){return 78===n.kind?t:e.factory.createQualifiedName(b(n.left,t),n.right)}function E(e,n){n.forEach((function(n){return e.addImportFromExportedSymbol(n,!0)}))}n.createMissingMemberNodes=t,n.getNoopSymbolTrackerWithResolver=r,n.createSignatureDeclarationFromCallExpression=o,n.typeToAutoImportableTypeNode=s,n.createStubbedBody=f,n.setJsonCompilerOptionValues=_,n.setJsonCompilerOptionValue=g,n.createJsonPropertyAssignment=y,n.findJsonProperty=h,n.tryGetAutoImportableReferenceFromTypeNode=v,n.importSymbols=E})(e.codefix||(e.codefix={}))}(d||(d={})),function(e){(function(n){function t(n,t,r,a,i,o){var s=u(n,t,r,a);if(s&&!e.refactor.isRefactorErrorInfo(s)){var f,m,h=e.textChanges.ChangeTracker.fromContext(i),v=s.isStatic,b=s.isReadonly,E=s.fieldName,T=s.accessorName,S=s.originalName,x=s.type,L=s.container,D=s.declaration;if(e.suppressLeadingAndTrailingTrivia(E),e.suppressLeadingAndTrailingTrivia(T),e.suppressLeadingAndTrailingTrivia(D),e.suppressLeadingAndTrailingTrivia(L),e.isClassLike(L)){var A=e.getEffectiveModifierFlags(D);if(e.isSourceFileJS(n)){var C=e.createModifiers(A);f=C,m=C}else f=e.createModifiers(c(A)),m=e.createModifiers(l(A))}_(h,n,D,x,E,m);var I=d(E,T,x,f,v,L);if(e.suppressLeadingAndTrailingTrivia(I),g(h,n,I,D,L),b){var N=e.getFirstConstructorWithBody(L);N&&y(h,n,N,E.text,S)}else{var k=p(E,T,x,f,v,L);e.suppressLeadingAndTrailingTrivia(k),g(h,n,k,D,L)}return h.getChanges()}}function r(n){return e.isIdentifier(n)||e.isStringLiteral(n)}function a(n){return e.isParameterPropertyDeclaration(n,n.parent)||e.isPropertyDeclaration(n)||e.isPropertyAssignment(n)}function o(n,t){return e.isIdentifier(t)?e.factory.createIdentifier(n):e.factory.createStringLiteral(n)}function s(n,t,r){var a=t?r.name:e.factory.createThis();return e.isIdentifier(n)?e.factory.createPropertyAccessExpression(a,n):e.factory.createElementAccessExpression(a,e.factory.createStringLiteralFromNode(n))}function c(e){return e&=-65,e&=-9,16&e||(e|=4),e}function l(e){return e&=-5,e&=-17,e|=8,e}function u(n,t,i,s,c){void 0===c&&(c=!0);var l=e.getTokenAtPosition(n,i),u=i===s&&c,d=e.findAncestor(l.parent,a),p=124;if(!d||!e.nodeOverlapsWithStartEnd(d.name,n,i,s)&&!u)return{error:e.getLocaleSpecificMessage(e.Diagnostics.Could_not_find_property_for_which_to_generate_accessor)};if(!r(d.name))return{error:e.getLocaleSpecificMessage(e.Diagnostics.Name_is_not_valid)};if((e.getEffectiveModifierFlags(d)|p)!==p)return{error:e.getLocaleSpecificMessage(e.Diagnostics.Can_only_convert_property_with_modifier)};var f=d.name.text,m=e.startsWithUnderscore(f),_=o(m?f:e.getUniqueName("_"+f,n),d.name),g=o(m?e.getUniqueName(f.substring(1),n):f,d.name);return{isStatic:e.hasStaticModifier(d),isReadonly:e.hasEffectiveReadonlyModifier(d),type:h(d,t),container:161===d.kind?d.parent.parent:d.parent,originalName:d.name.text,declaration:d,fieldName:_,accessorName:g,renameAccessor:m}}function d(n,t,r,a,i,o){return e.factory.createGetAccessorDeclaration(void 0,a,t,void 0,r,e.factory.createBlock([e.factory.createReturnStatement(s(n,i,o))],!0))}function p(n,t,r,a,i,o){return e.factory.createSetAccessorDeclaration(void 0,a,t,[e.factory.createParameterDeclaration(void 0,void 0,void 0,e.factory.createIdentifier("value"),void 0,r)],e.factory.createBlock([e.factory.createExpressionStatement(e.factory.createAssignment(s(n,i,o),e.factory.createIdentifier("value")))],!0))}function f(n,t,r,a,i,o){var s=e.factory.updatePropertyDeclaration(r,r.decorators,o,i,r.questionToken||r.exclamationToken,a,r.initializer);n.replaceNode(t,r,s)}function m(n,t,r,a){var i=e.factory.updatePropertyAssignment(r,a,r.initializer);n.replacePropertyAssignment(t,r,i)}function _(n,t,r,a,i,o){e.isPropertyDeclaration(r)?f(n,t,r,a,i,o):e.isPropertyAssignment(r)?m(n,t,r,i):n.replaceNode(t,r,e.factory.updateParameterDeclaration(r,r.decorators,o,r.dotDotDotToken,e.cast(i,e.isIdentifier),r.questionToken,r.type,r.initializer))}function g(n,t,r,a,i){e.isParameterPropertyDeclaration(a,a.parent)?n.insertNodeAtClassStart(t,i,r):e.isPropertyAssignment(a)?n.insertNodeAfterComma(t,a,r):n.insertNodeAfter(t,a,r)}function y(n,t,r,a,i){r.body&&r.body.forEachChild((function r(o){e.isElementAccessExpression(o)&&107===o.expression.kind&&e.isStringLiteral(o.argumentExpression)&&o.argumentExpression.text===i&&e.isWriteAccess(o)&&n.replaceNode(t,o.argumentExpression,e.factory.createStringLiteral(a)),e.isPropertyAccessExpression(o)&&107===o.expression.kind&&o.name.text===i&&e.isWriteAccess(o)&&n.replaceNode(t,o.name,e.factory.createIdentifier(a)),e.isFunctionLike(o)||e.isClassLike(o)||o.forEachChild(r)}))}function h(n,t){var r=e.getTypeAnnotationNode(n);if(e.isPropertyDeclaration(n)&&r&&n.questionToken){var a=t.getTypeChecker(),o=a.getTypeFromTypeNode(r);if(!a.isTypeAssignableTo(a.getUndefinedType(),o)){var s=e.isUnionTypeNode(r)?r.types:[r];return e.factory.createUnionTypeNode(i(i([],s),[e.factory.createKeywordTypeNode(150)]))}}return r}function v(n,t){var r=[];while(n){var a=e.getClassExtendsHeritageElement(n),i=a&&t.getSymbolAtLocation(a.expression);if(!i)break;var o=2097152&i.flags?t.getAliasedSymbol(i):i,s=o.declarations&&e.find(o.declarations,e.isClassLike);if(!s)break;r.push(s),n=s}return r}n.generateAccessorFromProperty=t,n.getAccessorConvertiblePropertyAtPosition=u,n.getAllSupers=v})(e.codefix||(e.codefix={}))}(d||(d={})),function(e){(function(n){var t="invalidImportSyntax";function r(n,t){var r=e.getSourceFileOfNode(t),i=e.getNamespaceDeclarationNode(t),o=n.program.getCompilerOptions(),s=[];return s.push(a(n,r,t,e.makeImport(i.name,void 0,t.moduleSpecifier,e.getQuotePreference(r,n.preferences)))),e.getEmitModuleKind(o)===e.ModuleKind.CommonJS&&s.push(a(n,r,t,e.factory.createImportEqualsDeclaration(void 0,void 0,!1,i.name,e.factory.createExternalModuleReference(t.moduleSpecifier)))),s}function a(r,a,i,o){var s=e.textChanges.ChangeTracker.with(r,(function(e){return e.replaceNode(a,i,o)}));return n.createCodeFixActionWithoutFixAll(t,s,[e.Diagnostics.Replace_import_with_0,s[0].textChanges[0].newText])}function i(n){var t=n.sourceFile,r=e.Diagnostics.This_expression_is_not_callable.code===n.errorCode?204:205,a=e.findAncestor(e.getTokenAtPosition(t,n.span.start),(function(e){return e.kind===r}));if(!a)return[];var i=a.expression;return s(n,i)}function o(n){var t=n.sourceFile,r=e.findAncestor(e.getTokenAtPosition(t,n.span.start),(function(e){return e.getStart()===n.span.start&&e.getEnd()===n.span.start+n.span.length}));return r?s(n,r):[]}function s(a,i){var o=a.program.getTypeChecker().getTypeAtLocation(i);if(!o.symbol||!o.symbol.originatingImport)return[];var s=[],c=o.symbol.originatingImport;if(e.isImportCall(c)||e.addRange(s,r(a,c)),e.isExpression(i)&&(!e.isNamedDeclaration(i.parent)||i.parent.name!==i)){var l=a.sourceFile,u=e.textChanges.ChangeTracker.with(a,(function(n){return n.replaceNode(l,i,e.factory.createPropertyAccessExpression(i,"default"),{})}));s.push(n.createCodeFixActionWithoutFixAll(t,u,e.Diagnostics.Use_synthetic_default_member))}return s}n.registerCodeFix({errorCodes:[e.Diagnostics.This_expression_is_not_callable.code,e.Diagnostics.This_expression_is_not_constructable.code],getCodeActions:i}),n.registerCodeFix({errorCodes:[e.Diagnostics.Argument_of_type_0_is_not_assignable_to_parameter_of_type_1.code,e.Diagnostics.Type_0_does_not_satisfy_the_constraint_1.code,e.Diagnostics.Type_0_is_not_assignable_to_type_1.code,e.Diagnostics.Type_0_is_not_assignable_to_type_1_Two_different_types_with_this_name_exist_but_they_are_unrelated.code,e.Diagnostics.Type_predicate_0_is_not_assignable_to_1.code,e.Diagnostics.Property_0_of_type_1_is_not_assignable_to_string_index_type_2.code,e.Diagnostics.Property_0_of_type_1_is_not_assignable_to_numeric_index_type_2.code,e.Diagnostics.Numeric_index_type_0_is_not_assignable_to_string_index_type_1.code,e.Diagnostics.Property_0_in_type_1_is_not_assignable_to_the_same_property_in_base_type_2.code,e.Diagnostics.Property_0_in_type_1_is_not_assignable_to_type_2.code,e.Diagnostics.Property_0_of_JSX_spread_attribute_is_not_assignable_to_target_property.code,e.Diagnostics.The_this_context_of_type_0_is_not_assignable_to_method_s_this_of_type_1.code],getCodeActions:o})})(e.codefix||(e.codefix={}))}(d||(d={})),function(e){(function(n){var t="strictClassInitialization",r="addMissingPropertyDefiniteAssignmentAssertions",a="addMissingPropertyUndefinedType",i="addMissingPropertyInitializer",o=[e.Diagnostics.Property_0_has_no_initializer_and_is_not_definitely_assigned_in_the_constructor.code];function s(n,t){var r=e.getTokenAtPosition(n,t);return e.isIdentifier(r)?e.cast(r.parent,e.isPropertyDeclaration):void 0}function c(a,i){var o=e.textChanges.ChangeTracker.with(a,(function(e){return l(e,a.sourceFile,i)}));return n.createCodeFixAction(t,o,[e.Diagnostics.Add_definite_assignment_assertion_to_property_0,i.getText()],r,e.Diagnostics.Add_definite_assignment_assertions_to_all_uninitialized_properties)}function l(n,t,r){var a=e.factory.updatePropertyDeclaration(r,r.decorators,r.modifiers,r.name,e.factory.createToken(53),r.type,r.initializer);n.replaceNode(t,r,a)}function u(r,i){var o=e.textChanges.ChangeTracker.with(r,(function(e){return d(e,r.sourceFile,i)}));return n.createCodeFixAction(t,o,[e.Diagnostics.Add_undefined_type_to_property_0,i.name.getText()],a,e.Diagnostics.Add_undefined_type_to_all_uninitialized_properties)}function d(n,t,r){var a=e.factory.createKeywordTypeNode(150),i=r.type,o=e.isUnionTypeNode(i)?i.types.concat(a):[i,a];n.replaceNode(t,i,e.factory.createUnionTypeNode(o))}function p(r,a){var o=r.program.getTypeChecker(),s=m(o,a);if(s){var c=e.textChanges.ChangeTracker.with(r,(function(e){return f(e,r.sourceFile,a,s)}));return n.createCodeFixAction(t,c,[e.Diagnostics.Add_initializer_to_property_0,a.name.getText()],i,e.Diagnostics.Add_initializers_to_all_uninitialized_properties)}}function f(n,t,r,a){var i=e.factory.updatePropertyDeclaration(r,r.decorators,r.modifiers,r.name,r.questionToken,r.type,a);n.replaceNode(t,r,i)}function m(e,n){return _(e,e.getTypeFromTypeNode(n.type))}function _(n,t){if(512&t.flags)return t===n.getFalseType()||t===n.getFalseType(!0)?e.factory.createFalse():e.factory.createTrue();if(t.isStringLiteral())return e.factory.createStringLiteral(t.value);if(t.isNumberLiteral())return e.factory.createNumericLiteral(t.value);if(2048&t.flags)return e.factory.createBigIntLiteral(t.value);if(t.isUnion())return e.firstDefined(t.types,(function(e){return _(n,e)}));if(t.isClass()){var r=e.getClassLikeDeclarationOfSymbol(t.symbol);if(!r||e.hasSyntacticModifier(r,128))return;var a=e.getFirstConstructorWithBody(r);if(a&&a.parameters.length)return;return e.factory.createNewExpression(e.factory.createIdentifier(t.symbol.name),void 0,void 0)}return n.isArrayLikeType(t)?e.factory.createArrayLiteralExpression():void 0}n.registerCodeFix({errorCodes:o,getCodeActions:function(n){var t=s(n.sourceFile,n.span.start);if(t){var r=[u(n,t),c(n,t)];return e.append(r,p(n,t)),r}},fixIds:[r,a,i],getAllCodeActions:function(t){return n.codeFixAll(t,o,(function(n,o){var c=s(o.file,o.start);if(c)switch(t.fixId){case r:l(n,o.file,c);break;case a:d(n,o.file,c);break;case i:var u=t.program.getTypeChecker(),p=m(u,c);if(!p)return;f(n,o.file,c,p);break;default:e.Debug.fail(JSON.stringify(t.fixId))}}))}})})(e.codefix||(e.codefix={}))}(d||(d={})),function(e){(function(n){var t="requireInTs",r=[e.Diagnostics.require_call_may_be_converted_to_an_import.code];function a(n,t,r){var a=r.allowSyntheticDefaults,i=r.defaultImportName,o=r.namedImports,s=r.statement,c=r.required;n.replaceNode(t,s,i&&!a?e.factory.createImportEqualsDeclaration(void 0,void 0,!1,i,e.factory.createExternalModuleReference(c)):e.factory.createImportDeclaration(void 0,void 0,e.factory.createImportClause(!1,i,o),c))}function i(n,t,r){var a=e.getTokenAtPosition(n,r).parent;if(!e.isRequireCall(a,!0))throw e.Debug.failBadSyntaxKind(a);var i=e.cast(a.parent,e.isVariableDeclaration),s=e.tryCast(i.name,e.isIdentifier),c=e.isObjectBindingPattern(i.name)?o(i.name):void 0;if(s||c)return{allowSyntheticDefaults:e.getAllowSyntheticDefaultImports(t.getCompilerOptions()),defaultImportName:s,namedImports:c,statement:e.cast(i.parent.parent,e.isVariableStatement),required:e.first(a.arguments)}}function o(n){for(var t=[],r=0,a=n.elements;r<a.length;r++){var i=a[r];if(!e.isIdentifier(i.name)||i.initializer)return;t.push(e.factory.createImportSpecifier(e.tryCast(i.propertyName,e.isIdentifier),i.name))}if(t.length)return e.factory.createNamedImports(t)}n.registerCodeFix({errorCodes:r,getCodeActions:function(r){var o=i(r.sourceFile,r.program,r.span.start);if(o){var s=e.textChanges.ChangeTracker.with(r,(function(e){return a(e,r.sourceFile,o)}));return[n.createCodeFixAction(t,s,e.Diagnostics.Convert_require_to_import,t,e.Diagnostics.Convert_all_require_to_import)]}},fixIds:[t],getAllCodeActions:function(e){return n.codeFixAll(e,r,(function(n,t){var r=i(t.file,e.program,t.start);r&&a(n,e.sourceFile,r)}))}})})(e.codefix||(e.codefix={}))}(d||(d={})),function(e){(function(n){var t="useDefaultImport",r=[e.Diagnostics.Import_may_be_converted_to_a_default_import.code];function a(n,t){var r=e.getTokenAtPosition(n,t);if(e.isIdentifier(r)){var a=r.parent;if(e.isImportEqualsDeclaration(a)&&e.isExternalModuleReference(a.moduleReference))return{importNode:a,name:r,moduleSpecifier:a.moduleReference.expression};if(e.isNamespaceImport(a)){var i=a.parent.parent;return{importNode:i,name:r,moduleSpecifier:i.moduleSpecifier}}}}function i(n,t,r,a){n.replaceNode(t,r.importNode,e.makeImport(r.name,void 0,r.moduleSpecifier,e.getQuotePreference(t,a)))}n.registerCodeFix({errorCodes:r,getCodeActions:function(r){var o=r.sourceFile,s=r.span.start,c=a(o,s);if(c){var l=e.textChanges.ChangeTracker.with(r,(function(e){return i(e,o,c,r.preferences)}));return[n.createCodeFixAction(t,l,e.Diagnostics.Convert_to_default_import,t,e.Diagnostics.Convert_all_to_default_imports)]}},fixIds:[t],getAllCodeActions:function(e){return n.codeFixAll(e,r,(function(n,t){var r=a(t.file,t.start);r&&i(n,t.file,r,e.preferences)}))}})})(e.codefix||(e.codefix={}))}(d||(d={})),function(e){(function(n){var t="useBigintLiteral",r=[e.Diagnostics.Numeric_literals_with_absolute_values_equal_to_2_53_or_greater_are_too_large_to_be_represented_accurately_as_integers.code];function a(n,t,r){var a=e.tryCast(e.getTokenAtPosition(t,r.start),e.isNumericLiteral);if(a){var i=a.getText(t)+"n";n.replaceNode(t,a,e.factory.createBigIntLiteral(i))}}n.registerCodeFix({errorCodes:r,getCodeActions:function(r){var i=e.textChanges.ChangeTracker.with(r,(function(e){return a(e,r.sourceFile,r.span)}));if(i.length>0)return[n.createCodeFixAction(t,i,e.Diagnostics.Convert_to_a_bigint_numeric_literal,t,e.Diagnostics.Convert_all_to_bigint_numeric_literals)]},fixIds:[t],getAllCodeActions:function(e){return n.codeFixAll(e,r,(function(e,n){return a(e,n.file,n)}))}})})(e.codefix||(e.codefix={}))}(d||(d={})),function(e){(function(n){var t="fixAddModuleReferTypeMissingTypeof",r=t,a=[e.Diagnostics.Module_0_does_not_refer_to_a_type_but_is_used_as_a_type_here_Did_you_mean_typeof_import_0.code];function i(n,t){var r=e.getTokenAtPosition(n,t);return e.Debug.assert(99===r.kind,"This token should be an ImportKeyword"),e.Debug.assert(196===r.parent.kind,"Token parent should be an ImportType"),r.parent}function o(n,t,r){var a=e.factory.updateImportTypeNode(r,r.argument,r.qualifier,r.typeArguments,!0);n.replaceNode(t,r,a)}n.registerCodeFix({errorCodes:a,getCodeActions:function(t){var a=t.sourceFile,s=t.span,c=i(a,s.start),l=e.textChanges.ChangeTracker.with(t,(function(e){return o(e,a,c)}));return[n.createCodeFixAction(r,l,e.Diagnostics.Add_missing_typeof,r,e.Diagnostics.Add_missing_typeof)]},fixIds:[r],getAllCodeActions:function(e){return n.codeFixAll(e,a,(function(n,t){return o(n,e.sourceFile,i(t.file,t.start))}))}})})(e.codefix||(e.codefix={}))}(d||(d={})),function(e){(function(n){var t="wrapJsxInFragment",r=[e.Diagnostics.JSX_expressions_must_have_one_parent_element.code];function a(n,t){var r=e.getTokenAtPosition(n,t),a=r.parent,i=a.parent;if((e.isBinaryExpression(i)||(i=i.parent,e.isBinaryExpression(i)))&&e.nodeIsMissing(i.operatorToken))return i}function i(n,t,r){var a=o(r);a&&n.replaceNode(t,r,e.factory.createJsxFragment(e.factory.createJsxOpeningFragment(),a,e.factory.createJsxJsxClosingFragment()))}function o(n){var t=[],r=n;while(1){if(e.isBinaryExpression(r)&&e.nodeIsMissing(r.operatorToken)&&27===r.operatorToken.kind){if(t.push(r.left),e.isJsxChild(r.right))return t.push(r.right),t;if(e.isBinaryExpression(r.right)){r=r.right;continue}return}return}}n.registerCodeFix({errorCodes:r,getCodeActions:function(r){var o=r.program.getCompilerOptions().jsx;if(2===o||3===o){var s=r.sourceFile,c=r.span,l=a(s,c.start);if(l){var u=e.textChanges.ChangeTracker.with(r,(function(e){return i(e,s,l)}));return[n.createCodeFixAction(t,u,e.Diagnostics.Wrap_in_JSX_fragment,t,e.Diagnostics.Wrap_all_unparented_JSX_in_JSX_fragment)]}}},fixIds:[t],getAllCodeActions:function(e){return n.codeFixAll(e,r,(function(n,t){var r=a(e.sourceFile,t.start);r&&i(n,e.sourceFile,r)}))}})})(e.codefix||(e.codefix={}))}(d||(d={})),function(e){(function(n){var t="fixConvertToMappedObjectType",r=t,a=[e.Diagnostics.An_index_signature_parameter_type_cannot_be_a_union_type_Consider_using_a_mapped_object_type_instead.code];function o(n,t){var r=e.getTokenAtPosition(n,t),a=e.cast(r.parent.parent,e.isIndexSignatureDeclaration);if(!e.isClassDeclaration(a.parent)){var i=e.isInterfaceDeclaration(a.parent)?a.parent:e.cast(a.parent.parent,e.isTypeAliasDeclaration);return{indexSignature:a,container:i}}}function s(n,t){return e.factory.createTypeAliasDeclaration(n.decorators,n.modifiers,n.name,n.typeParameters,t)}function c(n,t,r){var a=r.indexSignature,o=r.container,c=e.isInterfaceDeclaration(o)?o.members:o.type.members,l=c.filter((function(n){return!e.isIndexSignatureDeclaration(n)})),u=e.first(a.parameters),d=e.factory.createTypeParameterDeclaration(e.cast(u.name,e.isIdentifier),u.type),p=e.factory.createMappedTypeNode(e.hasEffectiveReadonlyModifier(a)?e.factory.createModifier(142):void 0,d,void 0,a.questionToken,a.type),f=e.factory.createIntersectionTypeNode(i(i(i([],e.getAllSuperTypeNodes(o)),[p]),l.length?[e.factory.createTypeLiteralNode(l)]:e.emptyArray));n.replaceNode(t,o,s(o,f))}n.registerCodeFix({errorCodes:a,getCodeActions:function(t){var a=t.sourceFile,i=t.span,s=o(a,i.start);if(s){var l=e.textChanges.ChangeTracker.with(t,(function(e){return c(e,a,s)})),u=e.idText(s.container.name);return[n.createCodeFixAction(r,l,[e.Diagnostics.Convert_0_to_mapped_object_type,u],r,[e.Diagnostics.Convert_0_to_mapped_object_type,u])]}},fixIds:[r],getAllCodeActions:function(e){return n.codeFixAll(e,a,(function(e,n){var t=o(n.file,n.start);t&&c(e,n.file,t)}))}})})(e.codefix||(e.codefix={}))}(d||(d={})),function(e){(function(n){var t="removeAccidentalCallParentheses",r=[e.Diagnostics.This_expression_is_not_callable_because_it_is_a_get_accessor_Did_you_mean_to_use_it_without.code];n.registerCodeFix({errorCodes:r,getCodeActions:function(r){var a=e.findAncestor(e.getTokenAtPosition(r.sourceFile,r.span.start),e.isCallExpression);if(a){var i=e.textChanges.ChangeTracker.with(r,(function(e){e.deleteRange(r.sourceFile,{pos:a.expression.end,end:a.end})}));return[n.createCodeFixActionWithoutFixAll(t,i,e.Diagnostics.Remove_parentheses)]}},fixIds:[t]})})(e.codefix||(e.codefix={}))}(d||(d={})),function(e){(function(n){var t="removeUnnecessaryAwait",r=[e.Diagnostics.await_has_no_effect_on_the_type_of_this_expression.code];function a(n,t,r){var a=e.tryCast(e.getTokenAtPosition(t,r.start),(function(e){return 130===e.kind})),i=a&&e.tryCast(a.parent,e.isAwaitExpression);if(i){var o=i,s=e.isParenthesizedExpression(i.parent);if(s){var c=e.getLeftmostExpression(i.expression,!1);if(e.isIdentifier(c)){var l=e.findPrecedingToken(i.parent.pos,t);l&&102!==l.kind&&(o=i.parent)}}n.replaceNode(t,o,i.expression)}}n.registerCodeFix({errorCodes:r,getCodeActions:function(r){var i=e.textChanges.ChangeTracker.with(r,(function(e){return a(e,r.sourceFile,r.span)}));if(i.length>0)return[n.createCodeFixAction(t,i,e.Diagnostics.Remove_unnecessary_await,t,e.Diagnostics.Remove_all_unnecessary_uses_of_await)]},fixIds:[t],getAllCodeActions:function(e){return n.codeFixAll(e,r,(function(e,n){return a(e,n.file,n)}))}})})(e.codefix||(e.codefix={}))}(d||(d={})),function(e){(function(n){var t=[e.Diagnostics.A_type_only_import_can_specify_a_default_import_or_named_bindings_but_not_both.code],r="splitTypeOnlyImport";function a(n,t){return e.findAncestor(e.getTokenAtPosition(n,t.start),e.isImportDeclaration)}function i(n,t,r){if(t){var a=e.Debug.checkDefined(t.importClause);n.replaceNode(r.sourceFile,t,e.factory.updateImportDeclaration(t,t.decorators,t.modifiers,e.factory.updateImportClause(a,a.isTypeOnly,a.name,void 0),t.moduleSpecifier)),n.insertNodeAfter(r.sourceFile,t,e.factory.createImportDeclaration(void 0,void 0,e.factory.updateImportClause(a,a.isTypeOnly,void 0,a.namedBindings),t.moduleSpecifier))}}n.registerCodeFix({errorCodes:t,fixIds:[r],getCodeActions:function(t){var o=e.textChanges.ChangeTracker.with(t,(function(e){return i(e,a(t.sourceFile,t.span),t)}));if(o.length)return[n.createCodeFixAction(r,o,e.Diagnostics.Split_into_two_separate_import_declarations,r,e.Diagnostics.Split_all_invalid_type_only_imports)]},getAllCodeActions:function(e){return n.codeFixAll(e,t,(function(n,t){i(n,a(e.sourceFile,t),e)}))}})})(e.codefix||(e.codefix={}))}(d||(d={})),function(e){(function(n){var t="fixConvertConstToLet",r=[e.Diagnostics.Cannot_assign_to_0_because_it_is_a_constant.code];function a(n,t,r){var a=e.getTokenAtPosition(n,t),i=r.getTypeChecker(),o=i.getSymbolAtLocation(a);if(null===o||void 0===o?void 0:o.valueDeclaration)return o.valueDeclaration.parent.parent}function i(e,n,t){if(t){var r=t.getStart();e.replaceRangeWithText(n,{pos:r,end:r+5},"let")}}n.registerCodeFix({errorCodes:r,getCodeActions:function(r){var o=r.sourceFile,s=r.span,c=r.program,l=a(o,s.start,c),u=e.textChanges.ChangeTracker.with(r,(function(e){return i(e,o,l)}));return[n.createCodeFixAction(t,u,e.Diagnostics.Convert_const_to_let,t,e.Diagnostics.Convert_const_to_let)]},fixIds:[t]})})(e.codefix||(e.codefix={}))}(d||(d={})),function(e){(function(n){var t="fixExpectedComma",r=e.Diagnostics._0_expected.code,a=[r];function i(n,t,r){var a=e.getTokenAtPosition(n,t);return 26===a.kind&&a.parent&&(e.isObjectLiteralExpression(a.parent)||e.isArrayLiteralExpression(a.parent))?{node:a}:void 0}function o(n,t,r){var a=r.node,i=e.factory.createToken(27);n.replaceNode(t,a,i)}n.registerCodeFix({errorCodes:a,getCodeActions:function(r){var a=r.sourceFile,s=i(a,r.span.start,r.errorCode);if(s){var c=e.textChanges.ChangeTracker.with(r,(function(e){return o(e,a,s)}));return[n.createCodeFixAction(t,c,[e.Diagnostics.Change_0_to_1,";",","],t,[e.Diagnostics.Change_0_to_1,";",","])]}},fixIds:[t],getAllCodeActions:function(e){return n.codeFixAll(e,a,(function(n,t){var r=i(t.file,t.start,t.code);r&&o(n,e.sourceFile,r)}))}})})(e.codefix||(e.codefix={}))}(d||(d={})),function(e){(function(n){var t="addVoidToPromise",r="addVoidToPromise",a=[e.Diagnostics.Expected_0_arguments_but_got_1_Did_you_forget_to_include_void_in_your_type_argument_to_Promise.code];function i(n,t,r,a,i){var s=e.getTokenAtPosition(t,r.start);if(e.isIdentifier(s)&&e.isCallExpression(s.parent)&&s.parent.expression===s&&0===s.parent.arguments.length){var c=a.getTypeChecker(),l=c.getSymbolAtLocation(s),u=null===l||void 0===l?void 0:l.valueDeclaration;if(u&&e.isParameter(u)&&e.isNewExpression(u.parent.parent)&&!(null===i||void 0===i?void 0:i.has(u))){null===i||void 0===i||i.add(u);var d=o(u.parent.parent);if(e.some(d)){var p=d[0],f=!e.isUnionTypeNode(p)&&!e.isParenthesizedTypeNode(p)&&e.isParenthesizedTypeNode(e.factory.createUnionTypeNode([p,e.factory.createKeywordTypeNode(113)]).types[0]);f&&n.insertText(t,p.pos,"("),n.insertText(t,p.end,f?") | void":" | void")}else{var m=c.getResolvedSignature(s.parent),_=null===m||void 0===m?void 0:m.parameters[0],g=_&&c.getTypeOfSymbolAtLocation(_,u.parent.parent);e.isInJSFile(u)?(!g||3&g.flags)&&(n.insertText(t,u.parent.parent.end,")"),n.insertText(t,e.skipTrivia(t.text,u.parent.parent.pos),"/** @type {Promise<void>} */(")):(!g||2&g.flags)&&n.insertText(t,u.parent.parent.expression.end,"<void>")}}}}function o(n){var t;if(!e.isInJSFile(n))return n.typeArguments;if(e.isParenthesizedExpression(n.parent)){var r=null===(t=e.getJSDocTypeTag(n.parent))||void 0===t?void 0:t.typeExpression.type;if(r&&e.isTypeReferenceNode(r)&&e.isIdentifier(r.typeName)&&"Promise"===e.idText(r.typeName))return r.typeArguments}}n.registerCodeFix({errorCodes:a,fixIds:[r],getCodeActions:function(a){var o=e.textChanges.ChangeTracker.with(a,(function(e){return i(e,a.sourceFile,a.span,a.program)}));if(o.length>0)return[n.createCodeFixAction(t,o,e.Diagnostics.Add_void_to_Promise_resolved_without_a_value,r,e.Diagnostics.Add_void_to_all_Promises_resolved_without_a_value)]},getAllCodeActions:function(t){return n.codeFixAll(t,a,(function(n,r){return i(n,r.file,r,t.program,new e.Set)}))}})})(e.codefix||(e.codefix={}))}(d||(d={})),function(e){(function(n){var t="Convert export",r={name:"Convert default export to named export",description:e.Diagnostics.Convert_default_export_to_named_export.message,kind:"refactor.rewrite.export.named"},a={name:"Convert named export to default export",description:e.Diagnostics.Convert_named_export_to_default_export.message,kind:"refactor.rewrite.export.default"};function i(n,t){void 0===t&&(t=!0);var r=n.file,a=e.getRefactorContextSpan(n),i=e.getTokenAtPosition(r,a.start),o=i.parent&&1&e.getSyntacticModifierFlags(i.parent)&&t?i.parent:e.getParentNodeInSpan(i,r,a);if(!o||!e.isSourceFile(o.parent)&&(!e.isModuleBlock(o.parent)||!e.isAmbientModule(o.parent.parent)))return{error:e.getLocaleSpecificMessage(e.Diagnostics.Could_not_find_export_statement)};var s=e.isSourceFile(o.parent)?o.parent.symbol:o.parent.parent.symbol,c=e.getSyntacticModifierFlags(o)||(e.isExportAssignment(o)&&!o.isExportEquals?513:0),l=!!(512&c);if(!(1&c)||!l&&s.exports.has("default"))return{error:e.getLocaleSpecificMessage(e.Diagnostics.This_file_already_has_a_default_export)};switch(o.kind){case 252:case 253:case 254:case 256:case 255:case 257:var u=o;return u.name&&e.isIdentifier(u.name)?{exportNode:u,exportName:u.name,wasDefault:l,exportingModuleSymbol:s}:void 0;case 233:var d=o;if(!(2&d.declarationList.flags)||1!==d.declarationList.declarations.length)return;var p=e.first(d.declarationList.declarations);if(!p.initializer)return;return e.Debug.assert(!l,"Can't have a default flag here"),e.isIdentifier(p.name)?{exportNode:d,exportName:p.name,wasDefault:l,exportingModuleSymbol:s}:void 0;case 267:u=o;var f=u.expression;return u.isExportEquals?void 0:{exportNode:u,exportName:f,wasDefault:l,exportingModuleSymbol:s};default:return}}function s(e,n,t,r,a){c(e,t,r,n.getTypeChecker()),l(n,t,r,a)}function c(n,t,r,a){var i=t.wasDefault,o=t.exportNode,s=t.exportName;if(i)if(e.isExportAssignment(o)&&!o.isExportEquals){var c=o.expression,l=f(c.text,c.text);r.replaceNode(n,o,e.factory.createExportDeclaration(void 0,void 0,!1,e.factory.createNamedExports([l])))}else r.delete(n,e.Debug.checkDefined(e.findModifier(o,87),"Should find a default keyword in modifier list"));else{var u=e.Debug.checkDefined(e.findModifier(o,92),"Should find an export keyword in modifier list");switch(o.kind){case 252:case 253:case 254:r.insertNodeAfter(n,u,e.factory.createToken(87));break;case 233:var d=e.first(o.declarationList.declarations);if(!e.FindAllReferences.Core.isSymbolReferencedInFile(s,a,n)&&!d.type){r.replaceNode(n,o,e.factory.createExportDefault(e.Debug.checkDefined(d.initializer,"Initializer was previously known to be present")));break}case 256:case 255:case 257:r.deleteModifier(n,u),r.insertNodeAfter(n,o,e.factory.createExportDefault(e.factory.createIdentifier(s.text)));break;default:e.Debug.fail("Unexpected exportNode kind "+o.kind)}}}function l(n,t,r,a){var i=t.wasDefault,o=t.exportName,s=t.exportingModuleSymbol,c=n.getTypeChecker(),l=e.Debug.checkDefined(c.getSymbolAtLocation(o),"Export name should resolve to a symbol");e.FindAllReferences.Core.eachExportReference(n.getSourceFiles(),c,a,l,s,o.text,i,(function(e){var n=e.getSourceFile();i?u(n,e,r,o.text):d(n,e,r)}))}function u(n,t,r,a){var i=t.parent;switch(i.kind){case 202:r.replaceNode(n,t,e.factory.createIdentifier(a));break;case 266:case 271:var o=i;r.replaceNode(n,o,p(a,o.name.text));break;case 263:var s=i;e.Debug.assert(s.name===t,"Import clause name should match provided ref");o=p(a,t.text);var c=s.namedBindings;if(c)if(264===c.kind){r.deleteRange(n,{pos:t.getStart(n),end:c.getStart(n)});var l=e.isStringLiteral(s.parent.moduleSpecifier)?e.quotePreferenceFromString(s.parent.moduleSpecifier,n):1,u=e.makeImport(void 0,[p(a,t.text)],s.parent.moduleSpecifier,l);r.insertNodeAfter(n,s.parent,u)}else r.delete(n,t),r.insertNodeAtEndOfList(n,c.elements,o);else r.replaceNode(n,t,e.factory.createNamedImports([o]));break;default:e.Debug.failBadSyntaxKind(i)}}function d(n,t,r){var a=t.parent;switch(a.kind){case 202:r.replaceNode(n,t,e.factory.createIdentifier("default"));break;case 266:var i=e.factory.createIdentifier(a.name.text);1===a.parent.elements.length?r.replaceNode(n,a.parent,i):(r.delete(n,a),r.insertNodeBefore(n,a.parent,i));break;case 271:r.replaceNode(n,a,f("default",a.name.text));break;default:e.Debug.assertNever(a,"Unexpected parent kind "+a.kind)}}function p(n,t){return e.factory.createImportSpecifier(n===t?void 0:e.factory.createIdentifier(n),e.factory.createIdentifier(t))}function f(n,t){return e.factory.createExportSpecifier(n===t?void 0:e.factory.createIdentifier(n),e.factory.createIdentifier(t))}n.registerRefactor(t,{kinds:[r.kind,a.kind],getAvailableActions:function(s){var c=i(s,"invoked"===s.triggerReason);if(!c)return e.emptyArray;if(!n.isRefactorErrorInfo(c)){var l=c.wasDefault?r:a;return[{name:t,description:l.description,actions:[l]}]}return s.preferences.provideRefactorNotApplicableReason?[{name:t,description:e.Diagnostics.Convert_default_export_to_named_export.message,actions:[o(o({},r),{notApplicableReason:c.error}),o(o({},a),{notApplicableReason:c.error})]}]:e.emptyArray},getEditsForAction:function(t,o){e.Debug.assert(o===r.name||o===a.name,"Unexpected action name");var c=i(t);e.Debug.assert(c&&!n.isRefactorErrorInfo(c),"Expected applicable refactor info");var l=e.textChanges.ChangeTracker.with(t,(function(e){return s(t.file,t.program,c,e,t.cancellationToken)}));return{edits:l,renameFilename:void 0,renameLocation:void 0}}})})(e.refactor||(e.refactor={}))}(d||(d={})),function(e){(function(n){var t="Convert import",r={name:"Convert namespace import to named imports",description:e.Diagnostics.Convert_namespace_import_to_named_imports.message,kind:"refactor.rewrite.import.named"},a={name:"Convert named imports to namespace import",description:e.Diagnostics.Convert_named_imports_to_namespace_import.message,kind:"refactor.rewrite.import.namespace"};function i(n,t){void 0===t&&(t=!0);var r=n.file,a=e.getRefactorContextSpan(n),i=e.getTokenAtPosition(r,a.start),o=t?e.findAncestor(i,e.isImportDeclaration):e.getParentNodeInSpan(i,r,a);if(!o||!e.isImportDeclaration(o))return{error:"Selection is not an import declaration."};if(!(o.getEnd()<a.start+a.length)){var s=o.importClause;return s?s.namedBindings?s.namedBindings:{error:e.getLocaleSpecificMessage(e.Diagnostics.Could_not_find_namespace_import_or_named_imports)}:{error:e.getLocaleSpecificMessage(e.Diagnostics.Could_not_find_import_clause)}}}function s(n,t,r,a){var i=t.getTypeChecker();264===a.kind?c(n,i,r,a,e.getAllowSyntheticDefaultImports(t.getCompilerOptions())):d(n,i,r,a)}function c(n,t,r,a,i){var o=!1,s=[],c=new e.Map;e.FindAllReferences.Core.eachSymbolReferenceInFile(a.name,t,n,(function(n){if(e.isPropertyAccessOrQualifiedName(n.parent)){var r=l(n.parent).text;t.resolveName(r,n,67108863,!0)&&c.set(r,!0),e.Debug.assert(u(n.parent)===n,"Parent expression should match id"),s.push(n.parent)}else o=!0}));for(var d=new e.Map,f=0,m=s;f<m.length;f++){var _=m[f],g=l(_).text,y=d.get(g);void 0===y&&d.set(g,y=c.has(g)?e.getUniqueName(g,n):g),r.replaceNode(n,_,e.factory.createIdentifier(y))}var h=[];d.forEach((function(n,t){h.push(e.factory.createImportSpecifier(n===t?void 0:e.factory.createIdentifier(t),e.factory.createIdentifier(n)))}));var v=a.parent.parent;o&&!i?r.insertNodeAfter(n,v,p(v,void 0,h)):r.replaceNode(n,v,p(v,o?e.factory.createIdentifier(a.name.text):void 0,h))}function l(n){return e.isPropertyAccessExpression(n)?n.name:n.right}function u(n){return e.isPropertyAccessExpression(n)?n.expression:n.left}function d(n,t,r,a){for(var i=a.parent.parent,o=i.moduleSpecifier,s=o&&e.isStringLiteral(o)?e.codefix.moduleSpecifierToValidIdentifier(o.text,99):"module",c=a.elements.some((function(r){return e.FindAllReferences.Core.eachSymbolReferenceInFile(r.name,t,n,(function(e){return!!t.resolveName(s,e,67108863,!0)}))||!1})),l=c?e.getUniqueName(s,n):s,u=[],d=function(a){var i=(a.propertyName||a.name).text;e.FindAllReferences.Core.eachSymbolReferenceInFile(a.name,t,n,(function(t){var o=e.factory.createPropertyAccessExpression(e.factory.createIdentifier(l),i);e.isShorthandPropertyAssignment(t.parent)?r.replaceNode(n,t.parent,e.factory.createPropertyAssignment(t.text,o)):e.isExportSpecifier(t.parent)&&!t.parent.propertyName?u.some((function(e){return e.name===a.name}))||u.push(e.factory.createImportSpecifier(a.propertyName&&e.factory.createIdentifier(a.propertyName.text),e.factory.createIdentifier(a.name.text))):r.replaceNode(n,t,o)}))},f=0,m=a.elements;f<m.length;f++){var _=m[f];d(_)}r.replaceNode(n,a,e.factory.createNamespaceImport(e.factory.createIdentifier(l))),u.length&&r.insertNodeAfter(n,a.parent.parent,p(i,void 0,u))}function p(n,t,r){return e.factory.createImportDeclaration(void 0,void 0,e.factory.createImportClause(!1,t,r&&r.length?e.factory.createNamedImports(r):void 0),n.moduleSpecifier)}n.registerRefactor(t,{kinds:[r.kind,a.kind],getAvailableActions:function(s){var c=i(s,"invoked"===s.triggerReason);if(!c)return e.emptyArray;if(!n.isRefactorErrorInfo(c)){var l=264===c.kind,u=l?r:a;return[{name:t,description:u.description,actions:[u]}]}return s.preferences.provideRefactorNotApplicableReason?[{name:t,description:r.description,actions:[o(o({},r),{notApplicableReason:c.error})]},{name:t,description:a.description,actions:[o(o({},a),{notApplicableReason:c.error})]}]:e.emptyArray},getEditsForAction:function(t,o){e.Debug.assert(o===r.name||o===a.name,"Unexpected action name");var c=i(t);e.Debug.assert(c&&!n.isRefactorErrorInfo(c),"Expected applicable refactor info");var l=e.textChanges.ChangeTracker.with(t,(function(e){return s(t.file,t.program,e,c)}));return{edits:l,renameFilename:void 0,renameLocation:void 0}}})})(e.refactor||(e.refactor={}))}(d||(d={})),function(e){(function(n){(function(t){var r="Convert to optional chain expression",a=e.getLocaleSpecificMessage(e.Diagnostics.Convert_to_optional_chain_expression),i={name:r,description:a,kind:"refactor.rewrite.expression.optionalChain"};function s(t){var s=p(t,"invoked"===t.triggerReason);return s?n.isRefactorErrorInfo(s)?t.preferences.provideRefactorNotApplicableReason?[{name:r,description:a,actions:[o(o({},i),{notApplicableReason:s.error})]}]:e.emptyArray:[{name:r,description:a,actions:[i]}]:e.emptyArray}function c(t,r){var a=p(t);e.Debug.assert(a&&!n.isRefactorErrorInfo(a),"Expected applicable refactor info");var i=e.textChanges.ChangeTracker.with(t,(function(e){return x(t.file,t.program.getTypeChecker(),e,a,r)}));return{edits:i,renameFilename:void 0,renameLocation:void 0}}function l(n){return e.isBinaryExpression(n)||e.isConditionalExpression(n)}function u(n){return e.isExpressionStatement(n)||e.isReturnStatement(n)||e.isVariableStatement(n)}function d(e){return l(e)||u(e)}function p(n,t){void 0===t&&(t=!0);var r=n.file,a=n.program,i=e.getRefactorContextSpan(n),o=0===i.length;if(!o||t){var s=e.getTokenAtPosition(r,i.start),c=e.findTokenOnLeftOfPosition(r,i.start+i.length),l=e.createTextSpanFromBounds(s.pos,c&&c.end>=s.pos?c.getEnd():s.getEnd()),u=o?b(s):v(s,l),p=u&&d(u)?E(u):void 0;if(!p)return{error:e.getLocaleSpecificMessage(e.Diagnostics.Could_not_find_convertible_access_expression)};var _=a.getTypeChecker();return e.isConditionalExpression(p)?f(p,_):m(p)}}function f(n,t){var r=n.condition,a=T(n.whenTrue);if(!a||t.isNullableType(t.getTypeAtLocation(a)))return{error:e.getLocaleSpecificMessage(e.Diagnostics.Could_not_find_convertible_access_expression)};if((e.isPropertyAccessExpression(r)||e.isIdentifier(r))&&g(r,a.expression))return{finalExpression:a,occurrences:[r],expression:n};if(e.isBinaryExpression(r)){var i=_(a.expression,r);return i?{finalExpression:a,occurrences:i,expression:n}:{error:e.getLocaleSpecificMessage(e.Diagnostics.Could_not_find_matching_access_expressions)}}}function m(n){if(55!==n.operatorToken.kind)return{error:e.getLocaleSpecificMessage(e.Diagnostics.Can_only_convert_logical_AND_access_chains)};var t=T(n.right);if(!t)return{error:e.getLocaleSpecificMessage(e.Diagnostics.Could_not_find_convertible_access_expression)};var r=_(t.expression,n.left);return r?{finalExpression:t,occurrences:r,expression:n}:{error:e.getLocaleSpecificMessage(e.Diagnostics.Could_not_find_matching_access_expressions)}}function _(n,t){var r=[];while(e.isBinaryExpression(t)&&55===t.operatorToken.kind){var a=g(e.skipParentheses(n),e.skipParentheses(t.right));if(!a)break;r.push(a),n=a,t=t.left}var i=g(n,t);return i&&r.push(i),r.length>0?r:void 0}function g(n,t){if(e.isIdentifier(t)||e.isPropertyAccessExpression(t)||e.isElementAccessExpression(t))return y(n,t)?t:void 0}function y(n,t){while(e.isCallExpression(n)||e.isPropertyAccessExpression(n)||e.isElementAccessExpression(n)){if(h(n)===h(t))break;n=n.expression}while(e.isPropertyAccessExpression(n)&&e.isPropertyAccessExpression(t)||e.isElementAccessExpression(n)&&e.isElementAccessExpression(t)){if(h(n)!==h(t))return!1;n=n.expression,t=t.expression}return e.isIdentifier(n)&&e.isIdentifier(t)&&n.getText()===t.getText()}function h(n){return e.isIdentifier(n)||e.isStringOrNumericLiteralLike(n)?n.getText():e.isPropertyAccessExpression(n)?h(n.name):e.isElementAccessExpression(n)?h(n.argumentExpression):void 0}function v(e,n){while(e.parent){if(d(e)&&0!==n.length&&e.end>=n.start+n.length)return e;e=e.parent}}function b(e){while(e.parent){if(d(e)&&!d(e.parent))return e;e=e.parent}}function E(n){if(l(n))return n;if(e.isVariableStatement(n)){var t=e.getSingleVariableOfVariableStatement(n),r=null===t||void 0===t?void 0:t.initializer;return r&&l(r)?r:void 0}return n.expression&&l(n.expression)?n.expression:void 0}function T(n){return n=e.skipParentheses(n),e.isBinaryExpression(n)?T(n.left):(e.isPropertyAccessExpression(n)||e.isElementAccessExpression(n)||e.isCallExpression(n))&&!e.isOptionalChain(n)?n:void 0}function S(n,t,r){if(e.isPropertyAccessExpression(t)||e.isElementAccessExpression(t)||e.isCallExpression(t)){var a=S(n,t.expression,r),i=r.length>0?r[r.length-1]:void 0,o=(null===i||void 0===i?void 0:i.getText())===t.expression.getText();if(o&&r.pop(),e.isCallExpression(t))return o?e.factory.createCallChain(a,e.factory.createToken(28),t.typeArguments,t.arguments):e.factory.createCallChain(a,t.questionDotToken,t.typeArguments,t.arguments);if(e.isPropertyAccessExpression(t))return o?e.factory.createPropertyAccessChain(a,e.factory.createToken(28),t.name):e.factory.createPropertyAccessChain(a,t.questionDotToken,t.name);if(e.isElementAccessExpression(t))return o?e.factory.createElementAccessChain(a,e.factory.createToken(28),t.argumentExpression):e.factory.createElementAccessChain(a,t.questionDotToken,t.argumentExpression)}return t}function x(n,t,r,a,i){var o=a.finalExpression,s=a.occurrences,c=a.expression,l=s[s.length-1],u=S(t,o,s);u&&(e.isPropertyAccessExpression(u)||e.isElementAccessExpression(u)||e.isCallExpression(u))&&(e.isBinaryExpression(c)?r.replaceNodeRange(n,l,o,u):e.isConditionalExpression(c)&&r.replaceNode(n,c,e.factory.createBinaryExpression(u,e.factory.createToken(60),c.whenFalse)))}n.registerRefactor(r,{kinds:[i.kind],getAvailableActions:s,getEditsForAction:c})})(n.convertToOptionalChainExpression||(n.convertToOptionalChainExpression={}))})(e.refactor||(e.refactor={}))}(d||(d={})),function(e){(function(n){(function(t){var r="Convert overload list to single signature",a=e.Diagnostics.Convert_overload_list_to_single_signature.message,i={name:r,description:a,kind:"refactor.rewrite.function.overloadList"};function o(n){var t=n.file,o=n.startPosition,s=n.program,c=l(t,o,s);return c?[{name:r,description:a,actions:[i]}]:e.emptyArray}function s(n){var t=n.file,r=n.startPosition,a=n.program,i=l(t,r,a);if(i){var o=a.getTypeChecker(),s=i[i.length-1],c=s;switch(s.kind){case 165:c=e.factory.updateMethodSignature(s,s.modifiers,s.name,s.questionToken,s.typeParameters,d(i),s.type);break;case 166:c=e.factory.updateMethodDeclaration(s,s.decorators,s.modifiers,s.asteriskToken,s.name,s.questionToken,s.typeParameters,d(i),s.type,s.body);break;case 170:c=e.factory.updateCallSignature(s,s.typeParameters,d(i),s.type);break;case 167:c=e.factory.updateConstructorDeclaration(s,s.decorators,s.modifiers,d(i),s.body);break;case 171:c=e.factory.updateConstructSignature(s,s.typeParameters,d(i),s.type);break;case 252:c=e.factory.updateFunctionDeclaration(s,s.decorators,s.modifiers,s.asteriskToken,s.name,s.typeParameters,d(i),s.type,s.body);break;default:return e.Debug.failBadSyntaxKind(s,"Unhandled signature kind in overload list conversion refactoring")}if(c!==s){var u=e.textChanges.ChangeTracker.with(n,(function(e){e.replaceNodeRange(t,i[0],i[i.length-1],c)}));return{renameFilename:void 0,renameLocation:void 0,edits:u}}}function d(n){var t=n[n.length-1];return e.isFunctionLikeDeclaration(t)&&t.body&&(n=n.slice(0,n.length-1)),e.factory.createNodeArray([e.factory.createParameterDeclaration(void 0,void 0,e.factory.createToken(25),"args",void 0,e.factory.createUnionTypeNode(e.map(n,p)))])}function p(n){var t=e.map(n.parameters,f);return e.setEmitFlags(e.factory.createTupleTypeNode(t),e.some(t,(function(n){return!!e.length(e.getSyntheticLeadingComments(n))}))?0:1)}function f(n){e.Debug.assert(e.isIdentifier(n.name));var t=e.setTextRange(e.factory.createNamedTupleMember(n.dotDotDotToken,n.name,n.questionToken,n.type||e.factory.createKeywordTypeNode(128)),n),r=n.symbol&&n.symbol.getDocumentationComment(o);if(r){var a=e.displayPartsToString(r);a.length&&e.setSyntheticLeadingComments(t,[{text:"*\n"+a.split("\n").map((function(e){return" * "+e})).join("\n")+"\n ",kind:3,pos:-1,end:-1,hasTrailingNewLine:!0,hasLeadingNewline:!0}])}return t}}function c(e){switch(e.kind){case 165:case 166:case 170:case 167:case 171:case 252:return!0}return!1}function l(n,t,r){var a=e.getTokenAtPosition(n,t),i=e.findAncestor(a,c);if(i){var o=r.getTypeChecker(),s=i.symbol;if(s){var l=s.declarations;if(!(e.length(l)<=1)&&e.every(l,(function(t){return e.getSourceFileOfNode(t)===n}))&&c(l[0])){var u=l[0].kind;if(e.every(l,(function(e){return e.kind===u}))){var d=l;if(!e.some(d,(function(n){return!!n.typeParameters||e.some(n.parameters,(function(n){return!!n.decorators||!!n.modifiers||!e.isIdentifier(n.name)}))}))){var p=e.mapDefined(d,(function(e){return o.getSignatureFromDeclaration(e)}));if(e.length(p)===e.length(l)){var f=o.getReturnTypeOfSignature(p[0]);if(e.every(p,(function(e){return o.getReturnTypeOfSignature(e)===f})))return d}}}}}}}n.registerRefactor(r,{kinds:[i.kind],getEditsForAction:s,getAvailableActions:o})})(n.addOrRemoveBracesToArrowFunction||(n.addOrRemoveBracesToArrowFunction={}))})(e.refactor||(e.refactor={}))}(d||(d={})),function(e){(function(n){(function(t){var r,a,i,s,c="Extract Symbol",l={name:"Extract Constant",description:e.getLocaleSpecificMessage(e.Diagnostics.Extract_constant),kind:"refactor.extract.constant"},u={name:"Extract Function",description:e.getLocaleSpecificMessage(e.Diagnostics.Extract_function),kind:"refactor.extract.function"};function d(t){var r=t.kind,a=f(t.file,e.getRefactorContextSpan(t),"invoked"===t.triggerReason),i=a.targetRange;if(void 0===i){if(!a.errors||0===a.errors.length||!t.preferences.provideRefactorNotApplicableReason)return e.emptyArray;var s=[];return n.refactorKindBeginsWith(u.kind,r)&&s.push({name:c,description:u.description,actions:[o(o({},u),{notApplicableReason:I(a.errors)})]}),n.refactorKindBeginsWith(l.kind,r)&&s.push({name:c,description:l.description,actions:[o(o({},l),{notApplicableReason:I(a.errors)})]}),s}var d=b(i,t);if(void 0===d)return e.emptyArray;for(var p,m,_=[],g=new e.Map,y=[],h=new e.Map,v=0,E=0,T=d;E<T.length;E++){var S=T[E],x=S.functionExtraction,L=S.constantExtraction,D=x.description;if(n.refactorKindBeginsWith(u.kind,r)&&(0===x.errors.length?g.has(D)||(g.set(D,!0),_.push({description:D,name:"function_scope_"+v,kind:u.kind})):p||(p={description:D,name:"function_scope_"+v,notApplicableReason:I(x.errors),kind:u.kind})),n.refactorKindBeginsWith(l.kind,r))if(0===L.errors.length){var A=L.description;h.has(A)||(h.set(A,!0),y.push({description:A,name:"constant_scope_"+v,kind:l.kind}))}else m||(m={description:D,name:"constant_scope_"+v,notApplicableReason:I(L.errors),kind:l.kind});v++}var C=[];return _.length?C.push({name:c,description:e.getLocaleSpecificMessage(e.Diagnostics.Extract_function),actions:_}):t.preferences.provideRefactorNotApplicableReason&&p&&C.push({name:c,description:e.getLocaleSpecificMessage(e.Diagnostics.Extract_function),actions:[p]}),y.length?C.push({name:c,description:e.getLocaleSpecificMessage(e.Diagnostics.Extract_constant),actions:y}):t.preferences.provideRefactorNotApplicableReason&&m&&C.push({name:c,description:e.getLocaleSpecificMessage(e.Diagnostics.Extract_constant),actions:[m]}),C.length?C:e.emptyArray;function I(e){var n=e[0].messageText;return"string"!==typeof n&&(n=n.messageText),n}}function p(n,t){var r=f(n.file,e.getRefactorContextSpan(n)),a=r.targetRange,i=/^function_scope_(\d+)$/.exec(t);if(i){var o=+i[1];return e.Debug.assert(isFinite(o),"Expected to parse a finite number from the function scope index"),h(a,n,o)}var s=/^constant_scope_(\d+)$/.exec(t);if(s){o=+s[1];return e.Debug.assert(isFinite(o),"Expected to parse a finite number from the constant scope index"),v(a,n,o)}e.Debug.fail("Unrecognized action name")}function f(n,t,i){void 0===i&&(i=!0);var o=t.length;if(0===o&&!i)return{errors:[e.createFileDiagnostic(n,t.start,o,r.cannotExtractEmpty)]};var s=0===o&&i,c=e.findFirstNonJsxWhitespaceToken(n,t.start),l=e.findTokenOnLeftOfPosition(n,e.textSpanEnd(t)),u=c&&l&&i?m(c,l,n):t,d=s?K(c):e.getParentNodeInSpan(c,n,u),p=s?d:e.getParentNodeInSpan(l,n,u),f=[],g=a.None;if(!d||!p)return{errors:[e.createFileDiagnostic(n,t.start,o,r.cannotExtractRange)]};if(e.isJSDoc(d))return{errors:[e.createFileDiagnostic(n,t.start,o,r.cannotExtractJSDoc)]};if(d.parent!==p.parent)return{errors:[e.createFileDiagnostic(n,t.start,o,r.cannotExtractRange)]};if(d!==p){if(!W(d.parent))return{errors:[e.createFileDiagnostic(n,t.start,o,r.cannotExtractRange)]};for(var y=[],h=d,v=0,b=h.parent.statements;v<b.length;v++){var E=b[v];if(E===d||y.length){var T=C(E);if(T)return{errors:T};y.push(E)}if(E===p)break}return y.length?{targetRange:{range:y,facts:g,declarations:f}}:{errors:[e.createFileDiagnostic(n,t.start,o,r.cannotExtractRange)]}}if(e.isReturnStatement(d)&&!d.expression)return{errors:[e.createFileDiagnostic(n,t.start,o,r.cannotExtractRange)]};var S=L(d),x=D(S)||C(S);return x?{errors:x}:{targetRange:{range:_(S),facts:g,declarations:f}};function L(n){if(e.isReturnStatement(n)){if(n.expression)return n.expression}else if(e.isVariableStatement(n)){for(var t=0,r=void 0,a=0,i=n.declarationList.declarations;a<i.length;a++){var o=i[a];o.initializer&&(t++,r=o.initializer)}if(1===t)return r}else if(e.isVariableDeclaration(n)&&n.initializer)return n.initializer;return n}function D(n){if(e.isIdentifier(e.isExpressionStatement(n)?n.expression:n))return[e.createDiagnosticForNode(n,r.cannotExtractIdentifier)]}function A(n,t){var r=n;while(r!==t){if(164===r.kind){e.hasSyntacticModifier(r,32)&&(g|=a.InStaticRegion);break}if(161===r.kind){var i=e.getContainingFunction(r);167===i.kind&&(g|=a.InStaticRegion);break}166===r.kind&&e.hasSyntacticModifier(r,32)&&(g|=a.InStaticRegion),r=r.parent}}function C(n){var i;if(function(e){e[e["None"]=0]="None",e[e["Break"]=1]="Break",e[e["Continue"]=2]="Continue",e[e["Return"]=4]="Return"}(i||(i={})),e.Debug.assert(n.pos<=n.end,"This failure could trigger https://github.com/Microsoft/TypeScript/issues/20809 (1)"),e.Debug.assert(!e.positionIsSynthesized(n.pos),"This failure could trigger https://github.com/Microsoft/TypeScript/issues/20809 (2)"),!e.isStatement(n)&&(!e.isExpressionNode(n)||!H(n)))return[e.createDiagnosticForNode(n,r.statementOrExpressionExpected)];if(8388608&n.flags)return[e.createDiagnosticForNode(n,r.cannotExtractAmbientBlock)];var o,s=e.getContainingClass(n);s&&A(n,s);var c,l=4;return u(n),o;function u(n){if(o)return!0;if(e.isDeclaration(n)){var i=250===n.kind?n.parent.parent:n;if(e.hasSyntacticModifier(i,1))return(o||(o=[])).push(e.createDiagnosticForNode(n,r.cannotExtractExportedEntity)),!0;f.push(n.symbol)}switch(n.kind){case 262:return(o||(o=[])).push(e.createDiagnosticForNode(n,r.cannotExtractImport)),!0;case 267:return(o||(o=[])).push(e.createDiagnosticForNode(n,r.cannotExtractExportedEntity)),!0;case 105:if(204===n.parent.kind){var s=e.getContainingClass(n);if(s.pos<t.start||s.end>=t.start+t.length)return(o||(o=[])).push(e.createDiagnosticForNode(n,r.cannotExtractSuper)),!0}else g|=a.UsesThis;break;case 210:e.forEachChild(n,(function n(t){if(e.isThis(t))g|=a.UsesThis;else{if(e.isClassLike(t)||e.isFunctionLike(t)&&!e.isArrowFunction(t))return!1;e.forEachChild(t,n)}}));case 253:case 252:e.isSourceFile(n.parent)&&void 0===n.parent.externalModuleIndicator&&(o||(o=[])).push(e.createDiagnosticForNode(n,r.functionWillNotBeVisibleInTheNewScope));case 222:case 209:case 166:case 167:case 168:case 169:return!1}var d=l;switch(n.kind){case 235:l=0;break;case 248:l=0;break;case 231:n.parent&&248===n.parent.kind&&n.parent.finallyBlock===n&&(l=4);break;case 286:case 285:l|=1;break;default:e.isIterationStatement(n,!1)&&(l|=3);break}switch(n.kind){case 188:case 107:g|=a.UsesThis;break;case 246:var p=n.label;(c||(c=[])).push(p.escapedText),e.forEachChild(n,u),c.pop();break;case 242:case 241:p=n.label;p?e.contains(c,p.escapedText)||(o||(o=[])).push(e.createDiagnosticForNode(n,r.cannotExtractRangeContainingLabeledBreakOrContinueStatementWithTargetOutsideOfTheRange)):l&(242===n.kind?1:2)||(o||(o=[])).push(e.createDiagnosticForNode(n,r.cannotExtractRangeContainingConditionalBreakOrContinueStatements));break;case 214:g|=a.IsAsyncFunction;break;case 220:g|=a.IsGenerator;break;case 243:4&l?g|=a.HasReturn:(o||(o=[])).push(e.createDiagnosticForNode(n,r.cannotExtractRangeContainingConditionalReturnStatement));break;default:e.forEachChild(n,u);break}l=d}}}function m(e,n,t){var r=e.getStart(t),a=n.getEnd();return 59===t.text.charCodeAt(a)&&a++,{start:r,length:a-r}}function _(n){return e.isStatement(n)?[n]:e.isExpressionNode(n)?e.isExpressionStatement(n.parent)?[n.parent]:n:void 0}function g(n){return e.isFunctionLikeDeclaration(n)||e.isSourceFile(n)||e.isModuleBlock(n)||e.isClassLike(n)}function y(n){var t=U(n.range)?e.first(n.range):n.range;if(n.facts&a.UsesThis){var r=e.getContainingClass(t);if(r){var i=e.findAncestor(t,e.isFunctionLikeDeclaration);return i?[i,r]:[r]}}var o=[];while(1)if(t=t.parent,161===t.kind&&(t=e.findAncestor(t,(function(n){return e.isFunctionLikeDeclaration(n)})).parent),g(t)&&(o.push(t),298===t.kind))return o}function h(n,t,r){var a=E(n,t),i=a.scopes,o=a.readsAndWrites,s=o.target,c=o.usagesPerScope,l=o.functionErrorsPerScope,u=o.exposedVariableDeclarations;return e.Debug.assert(!l[r].length,"The extraction went missing? How?"),t.cancellationToken.throwIfCancellationRequested(),A(s,i[r],c[r],u,n,t)}function v(n,t,r){var a=E(n,t),i=a.scopes,o=a.readsAndWrites,s=o.target,c=o.usagesPerScope,l=o.constantErrorsPerScope,u=o.exposedVariableDeclarations;e.Debug.assert(!l[r].length,"The extraction went missing? How?"),e.Debug.assert(0===u.length,"Extract constant accepted a range containing a variable declaration?"),t.cancellationToken.throwIfCancellationRequested();var d=e.isExpression(s)?s:s.statements[0].expression;return C(d,i[r],c[r],n.facts,t)}function b(n,t){var r=E(n,t),a=r.scopes,i=r.readsAndWrites,o=i.functionErrorsPerScope,s=i.constantErrorsPerScope,c=a.map((function(n,t){var r,a,i=T(n),c=S(n),l=e.isFunctionLikeDeclaration(n)?x(n):e.isClassLike(n)?L(n):D(n);return 1===l?(r=e.formatStringFromArgs(e.getLocaleSpecificMessage(e.Diagnostics.Extract_to_0_in_1_scope),[i,"global"]),a=e.formatStringFromArgs(e.getLocaleSpecificMessage(e.Diagnostics.Extract_to_0_in_1_scope),[c,"global"])):0===l?(r=e.formatStringFromArgs(e.getLocaleSpecificMessage(e.Diagnostics.Extract_to_0_in_1_scope),[i,"module"]),a=e.formatStringFromArgs(e.getLocaleSpecificMessage(e.Diagnostics.Extract_to_0_in_1_scope),[c,"module"])):(r=e.formatStringFromArgs(e.getLocaleSpecificMessage(e.Diagnostics.Extract_to_0_in_1),[i,l]),a=e.formatStringFromArgs(e.getLocaleSpecificMessage(e.Diagnostics.Extract_to_0_in_1),[c,l])),0!==t||e.isClassLike(n)||(a=e.formatStringFromArgs(e.getLocaleSpecificMessage(e.Diagnostics.Extract_to_0_in_enclosing_scope),[c])),{functionExtraction:{description:r,errors:o[t]},constantExtraction:{description:a,errors:s[t]}}}));return c}function E(e,n){var t=n.file,r=y(e),a=V(e,t),i=j(e,r,a,t,n.program.getTypeChecker(),n.cancellationToken);return{scopes:r,readsAndWrites:i}}function T(n){return e.isFunctionLikeDeclaration(n)?"inner function":e.isClassLike(n)?"method":"function"}function S(n){return e.isClassLike(n)?"readonly field":"constant"}function x(n){switch(n.kind){case 167:return"constructor";case 209:case 252:return n.name?"function '"+n.name.text+"'":e.ANONYMOUS;case 210:return"arrow function";case 166:return"method '"+n.name.getText()+"'";case 168:return"'get "+n.name.getText()+"'";case 169:return"'set "+n.name.getText()+"'";default:throw e.Debug.assertNever(n,"Unexpected scope kind "+n.kind)}}function L(e){return 253===e.kind?e.name?"class '"+e.name.text+"'":"anonymous class declaration":e.name?"class expression '"+e.name.text+"'":"anonymous class expression"}function D(e){return 258===e.kind?"namespace '"+e.parent.name.getText()+"'":e.externalModuleIndicator?0:1}function A(n,t,r,i,o,s){var c,l,u=r.usages,d=r.typeParameterUsages,p=r.substitutions,f=s.program.getTypeChecker(),m=e.getEmitScriptTarget(s.program.getCompilerOptions()),_=e.codefix.createImportAdder(s.file,s.program,s.preferences,s.host),g=t.getSourceFile(),y=e.getUniqueName(e.isClassLike(t)?"newMethod":"newFunction",g),h=e.isInJSFile(t),v=e.factory.createIdentifier(y),b=[],E=[];u.forEach((function(n,r){var a;if(!h){var i=f.getTypeOfSymbolAtLocation(n.symbol,n.node);i=f.getBaseTypeOfLiteralType(i),a=e.codefix.typeToAutoImportableTypeNode(f,_,i,t,m,1)}var o=e.factory.createParameterDeclaration(void 0,void 0,void 0,r,void 0,a);b.push(o),2===n.usage&&(l||(l=[])).push(n),E.push(e.factory.createIdentifier(r))}));var T=e.arrayFrom(d.values()).map((function(e){return{type:e,declaration:N(e)}})),S=T.sort(k),x=0===S.length?void 0:S.map((function(e){return e.declaration})),L=void 0!==x?x.map((function(n){return e.factory.createTypeReferenceNode(n.name,void 0)})):void 0;if(e.isExpression(n)&&!h){var D=f.getContextualType(n);c=f.typeToTypeNode(D,t,1)}var A,C=O(n,i,l,p,!!(o.facts&a.HasReturn)),I=C.body,w=C.returnValueProperty;if(e.suppressLeadingAndTrailingTrivia(I),e.isClassLike(t)){var P=h?[]:[e.factory.createModifier(120)];o.facts&a.InStaticRegion&&P.push(e.factory.createModifier(123)),o.facts&a.IsAsyncFunction&&P.push(e.factory.createModifier(129)),A=e.factory.createMethodDeclaration(void 0,P.length?P:void 0,o.facts&a.IsGenerator?e.factory.createToken(41):void 0,v,void 0,x,b,c,I)}else A=e.factory.createFunctionDeclaration(void 0,o.facts&a.IsAsyncFunction?[e.factory.createToken(129)]:void 0,o.facts&a.IsGenerator?e.factory.createToken(41):void 0,v,x,b,c,I);var F=e.textChanges.ChangeTracker.fromContext(s),G=(U(o.range)?e.last(o.range):o.range).end,V=M(G,t);V?F.insertNodeBefore(s.file,V,A,!0):F.insertNodeAtEndOfScope(s.file,t,A),_.writeFixes(F);var j=[],K=R(t,o,y),H=e.factory.createCallExpression(K,L,E);if(o.facts&a.IsGenerator&&(H=e.factory.createYieldExpression(e.factory.createToken(41),H)),o.facts&a.IsAsyncFunction&&(H=e.factory.createAwaitExpression(H)),z(n)&&(H=e.factory.createJsxExpression(void 0,H)),i.length&&!l)if(e.Debug.assert(!w,"Expected no returnValueProperty"),e.Debug.assert(!(o.facts&a.HasReturn),"Expected RangeFacts.HasReturn flag to be unset"),1===i.length){var W=i[0];j.push(e.factory.createVariableStatement(void 0,e.factory.createVariableDeclarationList([e.factory.createVariableDeclaration(e.getSynthesizedDeepClone(W.name),void 0,e.getSynthesizedDeepClone(W.type),H)],W.parent.flags)))}else{for(var q=[],J=[],X=i[0].parent.flags,Y=!1,Q=0,Z=i;Q<Z.length;Q++){W=Z[Q];q.push(e.factory.createBindingElement(void 0,void 0,e.getSynthesizedDeepClone(W.name)));var $=f.typeToTypeNode(f.getBaseTypeOfLiteralType(f.getTypeAtLocation(W)),t,1);J.push(e.factory.createPropertySignature(void 0,W.symbol.name,void 0,$)),Y=Y||void 0!==W.type,X&=W.parent.flags}var ee=Y?e.factory.createTypeLiteralNode(J):void 0;ee&&e.setEmitFlags(ee,1),j.push(e.factory.createVariableStatement(void 0,e.factory.createVariableDeclarationList([e.factory.createVariableDeclaration(e.factory.createObjectBindingPattern(q),void 0,ee,H)],X)))}else if(i.length||l){if(i.length)for(var ne=0,te=i;ne<te.length;ne++){W=te[ne];var re=W.parent.flags;2&re&&(re=-3&re|1),j.push(e.factory.createVariableStatement(void 0,e.factory.createVariableDeclarationList([e.factory.createVariableDeclaration(W.symbol.name,void 0,le(W.type))],re)))}w&&j.push(e.factory.createVariableStatement(void 0,e.factory.createVariableDeclarationList([e.factory.createVariableDeclaration(w,void 0,le(c))],1)));var ae=B(i,l);w&&ae.unshift(e.factory.createShorthandPropertyAssignment(w)),1===ae.length?(e.Debug.assert(!w,"Shouldn't have returnValueProperty here"),j.push(e.factory.createExpressionStatement(e.factory.createAssignment(ae[0].name,H))),o.facts&a.HasReturn&&j.push(e.factory.createReturnStatement())):(j.push(e.factory.createExpressionStatement(e.factory.createAssignment(e.factory.createObjectLiteralExpression(ae),H))),w&&j.push(e.factory.createReturnStatement(e.factory.createIdentifier(w))))}else o.facts&a.HasReturn?j.push(e.factory.createReturnStatement(H)):U(o.range)?j.push(e.factory.createExpressionStatement(H)):j.push(H);U(o.range)?F.replaceNodeRangeWithNodes(s.file,e.first(o.range),e.last(o.range),j):F.replaceNodeWithNodes(s.file,o.range,j);var ie=F.getChanges(),oe=U(o.range)?e.first(o.range):o.range,se=oe.getSourceFile().fileName,ce=e.getRenameLocation(ie,se,y,!1);return{renameFilename:se,renameLocation:ce,edits:ie};function le(n){if(void 0!==n){var t=e.getSynthesizedDeepClone(n),r=t;while(e.isParenthesizedTypeNode(r))r=r.type;return e.isUnionTypeNode(r)&&e.find(r.types,(function(e){return 150===e.kind}))?t:e.factory.createUnionTypeNode([t,e.factory.createKeywordTypeNode(150)])}}}function C(n,t,r,i,o){var s,c=r.substitutions,l=o.program.getTypeChecker(),u=t.getSourceFile(),d=e.getUniqueName(e.isClassLike(t)?"newProperty":"newLocal",u),p=e.isInJSFile(t),f=p||!l.isContextSensitive(n)?void 0:l.typeToTypeNode(l.getContextualType(n),t,1),m=w(n,c);s=C(f,m),f=s.variableType,m=s.initializer,e.suppressLeadingAndTrailingTrivia(m);var _=e.textChanges.ChangeTracker.fromContext(o);if(e.isClassLike(t)){e.Debug.assert(!p,"Cannot extract to a JS class");var y=[];y.push(e.factory.createModifier(120)),i&a.InStaticRegion&&y.push(e.factory.createModifier(123)),y.push(e.factory.createModifier(142));var h=e.factory.createPropertyDeclaration(void 0,y,d,void 0,f,m),v=e.factory.createPropertyAccessExpression(i&a.InStaticRegion?e.factory.createIdentifier(t.name.getText()):e.factory.createThis(),e.factory.createIdentifier(d));z(n)&&(v=e.factory.createJsxExpression(void 0,v));var b=n.pos,E=F(b,t);_.insertNodeBefore(o.file,E,h,!0),_.replaceNode(o.file,n,v)}else{var T=e.factory.createVariableDeclaration(d,void 0,f,m),S=I(n,t);if(S){_.insertNodeBefore(o.file,S,T);v=e.factory.createIdentifier(d);_.replaceNode(o.file,n,v)}else if(234===n.parent.kind&&t===e.findAncestor(n,g)){var x=e.factory.createVariableStatement(void 0,e.factory.createVariableDeclarationList([T],2));_.replaceNode(o.file,n.parent,x)}else{x=e.factory.createVariableStatement(void 0,e.factory.createVariableDeclarationList([T],2)),E=G(n,t);if(0===E.pos?_.insertNodeAtTopOfFile(o.file,x,!1):_.insertNodeBefore(o.file,E,x,!1),234===n.parent.kind)_.delete(o.file,n.parent);else{v=e.factory.createIdentifier(d);z(n)&&(v=e.factory.createJsxExpression(void 0,v)),_.replaceNode(o.file,n,v)}}}var L=_.getChanges(),D=n.getSourceFile().fileName,A=e.getRenameLocation(L,D,d,!0);return{renameFilename:D,renameLocation:A,edits:L};function C(r,a){if(void 0===r)return{variableType:r,initializer:a};if(!e.isFunctionExpression(a)&&!e.isArrowFunction(a)||a.typeParameters)return{variableType:r,initializer:a};var i=l.getTypeAtLocation(n),o=e.singleOrUndefined(l.getSignaturesOfType(i,0));if(!o)return{variableType:r,initializer:a};if(o.getTypeParameters())return{variableType:r,initializer:a};for(var s=[],c=!1,u=0,d=a.parameters;u<d.length;u++){var p=d[u];if(p.type)s.push(p);else{var f=l.getTypeAtLocation(p);f===l.getAnyType()&&(c=!0),s.push(e.factory.updateParameterDeclaration(p,p.decorators,p.modifiers,p.dotDotDotToken,p.name,p.questionToken,p.type||l.typeToTypeNode(f,t,1),p.initializer))}}if(c)return{variableType:r,initializer:a};if(r=void 0,e.isArrowFunction(a))a=e.factory.updateArrowFunction(a,n.modifiers,a.typeParameters,s,a.type||l.typeToTypeNode(o.getReturnType(),t,1),a.equalsGreaterThanToken,a.body);else{if(o&&o.thisParameter){var m=e.firstOrUndefined(s);if(!m||e.isIdentifier(m.name)&&"this"!==m.name.escapedText){var _=l.getTypeOfSymbolAtLocation(o.thisParameter,n);s.splice(0,0,e.factory.createParameterDeclaration(void 0,void 0,void 0,"this",void 0,l.typeToTypeNode(_,t,1)))}}a=e.factory.updateFunctionExpression(a,n.modifiers,a.asteriskToken,a.name,a.typeParameters,s,a.type||l.typeToTypeNode(o.getReturnType(),t,1),a.body)}return{variableType:r,initializer:a}}}function I(n,t){var r;while(void 0!==n&&n!==t){if(e.isVariableDeclaration(n)&&n.initializer===r&&e.isVariableDeclarationList(n.parent)&&n.parent.declarations.length>1)return n;r=n,n=n.parent}}function N(e){var n,t=e.symbol;if(t&&t.declarations)for(var r=0,a=t.declarations;r<a.length;r++){var i=a[r];(void 0===n||i.pos<n.pos)&&(n=i)}return n}function k(n,t){var r=n.type,a=n.declaration,i=t.type,o=t.declaration;return e.compareProperties(a,o,"pos",e.compareValues)||e.compareStringsCaseSensitive(r.symbol?r.symbol.getName():"",i.symbol?i.symbol.getName():"")||e.compareValues(r.id,i.id)}function R(n,t,r){var i=e.factory.createIdentifier(r);if(e.isClassLike(n)){var o=t.facts&a.InStaticRegion?e.factory.createIdentifier(n.name.text):e.factory.createThis();return e.factory.createPropertyAccessExpression(o,i)}return i}function O(n,t,r,a,i){var o,s=void 0!==r||t.length>0;if(e.isBlock(n)&&!s&&0===a.size)return{body:e.factory.createBlock(n.statements,!0),returnValueProperty:void 0};var c=!1,l=e.factory.createNodeArray(e.isBlock(n)?n.statements.slice(0):[e.isStatement(n)?n:e.factory.createReturnStatement(n)]);if(s||a.size){var u=e.visitNodes(l,p).slice();if(s&&!i&&e.isStatement(n)){var d=B(t,r);1===d.length?u.push(e.factory.createReturnStatement(d[0].name)):u.push(e.factory.createReturnStatement(e.factory.createObjectLiteralExpression(d)))}return{body:e.factory.createBlock(u,!0),returnValueProperty:o}}return{body:e.factory.createBlock(l,!0),returnValueProperty:void 0};function p(n){if(!c&&e.isReturnStatement(n)&&s){var i=B(t,r);return n.expression&&(o||(o="__return"),i.unshift(e.factory.createPropertyAssignment(o,e.visitNode(n.expression,p)))),1===i.length?e.factory.createReturnStatement(i[0].name):e.factory.createReturnStatement(e.factory.createObjectLiteralExpression(i))}var l=c;c=c||e.isFunctionLikeDeclaration(n)||e.isClassLike(n);var u=a.get(e.getNodeId(n).toString()),d=u?e.getSynthesizedDeepClone(u):e.visitEachChild(n,p,e.nullTransformationContext);return c=l,d}}function w(n,t){return t.size?r(n):n;function r(n){var a=t.get(e.getNodeId(n).toString());return a?e.getSynthesizedDeepClone(a):e.visitEachChild(n,r,e.nullTransformationContext)}}function P(n){if(e.isFunctionLikeDeclaration(n)){var t=n.body;if(e.isBlock(t))return t.statements}else{if(e.isModuleBlock(n)||e.isSourceFile(n))return n.statements;if(e.isClassLike(n))return n.members;e.assertType(n)}return e.emptyArray}function M(n,t){return e.find(P(t),(function(t){return t.pos>=n&&e.isFunctionLikeDeclaration(t)&&!e.isConstructorDeclaration(t)}))}function F(n,t){var r,a=t.members;e.Debug.assert(a.length>0,"Found no members");for(var i=!0,o=0,s=a;o<s.length;o++){var c=s[o];if(c.pos>n)return r||a[0];if(i&&!e.isPropertyDeclaration(c)){if(void 0!==r)return c;i=!1}r=c}return void 0===r?e.Debug.fail():r}function G(n,t){var r;e.Debug.assert(!e.isClassLike(t));for(var a=n;a!==t;a=a.parent)g(a)&&(r=a);for(a=(r||n).parent;;a=a.parent){if(W(a)){for(var i=void 0,o=0,s=a.statements;o<s.length;o++){var c=s[o];if(c.pos>n.pos)break;i=c}return!i&&e.isCaseClause(a)?(e.Debug.assert(e.isSwitchStatement(a.parent.parent),"Grandparent isn't a switch statement"),a.parent.parent):e.Debug.checkDefined(i,"prevStatement failed to get set")}e.Debug.assert(a!==t,"Didn't encounter a block-like before encountering scope")}}function B(n,t){var r=e.map(n,(function(n){return e.factory.createShorthandPropertyAssignment(n.symbol.name)})),a=e.map(t,(function(n){return e.factory.createShorthandPropertyAssignment(n.symbol.name)}));return void 0===r?a:void 0===a?r:r.concat(a)}function U(n){return e.isArray(n)}function V(n,t){return U(n.range)?{pos:e.first(n.range).getStart(t),end:e.last(n.range).getEnd()}:n.range}function j(n,t,i,o,s,c){var l,u,d=new e.Map,p=[],f=[],m=[],_=[],g=[],y=new e.Map,h=[],v=U(n.range)?1===n.range.length&&e.isExpressionStatement(n.range[0])?n.range[0].expression:void 0:n.range;if(void 0===v){var b=n.range,E=e.first(b).getStart(),T=e.last(b).end;u=e.createFileDiagnostic(o,E,T-E,r.expressionExpected)}else 147456&s.getTypeAtLocation(v).flags&&(u=e.createDiagnosticForNode(v,r.uselessConstantType));for(var S=0,x=t;S<x.length;S++){var L=x[S];p.push({usages:new e.Map,typeParameterUsages:new e.Map,substitutions:new e.Map}),f.push(new e.Map),m.push(e.isFunctionLikeDeclaration(L)&&252!==L.kind?[e.createDiagnosticForNode(L,r.cannotExtractToOtherFunctionLike)]:[]);var D=[];u&&D.push(u),e.isClassLike(L)&&e.isInJSFile(L)&&D.push(e.createDiagnosticForNode(L,r.cannotExtractToJSClass)),e.isArrowFunction(L)&&!e.isBlock(L.body)&&D.push(e.createDiagnosticForNode(L,r.cannotExtractToExpressionArrowFunction)),_.push(D)}var A=new e.Map,C=U(n.range)?e.factory.createBlock(n.range):n.range,I=U(n.range)?e.first(n.range):n.range,N=K(I);if(W(C),N&&!U(n.range)){var k=s.getContextualType(n.range);H(k)}if(d.size>0){for(var R=new e.Map,O=0,w=I;void 0!==w&&O<t.length;w=w.parent)if(w===t[O]&&(R.forEach((function(e,n){p[O].typeParameterUsages.set(n,e)})),O++),e.isDeclarationWithTypeParameters(w))for(var P=0,M=e.getEffectiveTypeParameterDeclarations(w);P<M.length;P++){var F=M[P],G=s.getTypeAtLocation(F);d.has(G.id.toString())&&R.set(G.id.toString(),G)}e.Debug.assert(O===t.length,"Should have iterated all scopes")}if(g.length){var B=e.isBlockScope(t[0],t[0].parent)?t[0]:e.getEnclosingBlockScopeContainer(t[0]);e.forEachChild(B,J)}for(var V=function(t){var a=p[t];if(t>0&&(a.usages.size>0||a.typeParameterUsages.size>0)){var i=U(n.range)?n.range[0]:n.range;_[t].push(e.createDiagnosticForNode(i,r.cannotAccessVariablesFromNestedScopes))}var o,s=!1;if(p[t].usages.forEach((function(n){2===n.usage&&(s=!0,106500&n.symbol.flags&&n.symbol.valueDeclaration&&e.hasEffectiveModifier(n.symbol.valueDeclaration,64)&&(o=n.symbol.valueDeclaration))})),e.Debug.assert(U(n.range)||0===h.length,"No variable declarations expected if something was extracted"),s&&!U(n.range)){var c=e.createDiagnosticForNode(n.range,r.cannotWriteInExpression);m[t].push(c),_[t].push(c)}else if(o&&t>0){c=e.createDiagnosticForNode(o,r.cannotExtractReadonlyPropertyInitializerOutsideConstructor);m[t].push(c),_[t].push(c)}else if(l){c=e.createDiagnosticForNode(l,r.cannotExtractExportedEntity);m[t].push(c),_[t].push(c)}},j=0;j<t.length;j++)V(j);return{target:C,usagesPerScope:p,functionErrorsPerScope:m,constantErrorsPerScope:_,exposedVariableDeclarations:h};function K(n){return!!e.findAncestor(n,(function(n){return e.isDeclarationWithTypeParameters(n)&&0!==e.getEffectiveTypeParameterDeclarations(n).length}))}function H(e){for(var n=s.getSymbolWalker((function(){return c.throwIfCancellationRequested(),!0})),t=n.walkType(e).visitedTypes,r=0,a=t;r<a.length;r++){var i=a[r];i.isTypeParameter()&&d.set(i.id.toString(),i)}}function W(n,t){if(void 0===t&&(t=1),N){var r=s.getTypeAtLocation(n);H(r)}if(e.isDeclaration(n)&&n.symbol&&g.push(n),e.isAssignmentExpression(n))W(n.left,2),W(n.right);else if(e.isUnaryExpressionWithWrite(n))W(n.operand,2);else if(e.isPropertyAccessExpression(n)||e.isElementAccessExpression(n))e.forEachChild(n,W);else if(e.isIdentifier(n)){if(!n.parent)return;if(e.isQualifiedName(n.parent)&&n!==n.parent.left)return;if(e.isPropertyAccessExpression(n.parent)&&n!==n.parent.expression)return;z(n,t,e.isPartOfTypeNode(n))}else e.forEachChild(n,W)}function z(n,r,a){var i=q(n,r,a);if(i)for(var o=0;o<t.length;o++){var s=f[o].get(i);s&&p[o].substitutions.set(e.getNodeId(n).toString(),s)}}function q(c,l,u){var d=X(c);if(d){var g=e.getSymbolId(d).toString(),y=A.get(g);if(y&&y>=l)return g;if(A.set(g,l),y){for(var h=0,v=p;h<v.length;h++){var b=v[h],E=b.usages.get(c.text);E&&b.usages.set(c.text,{usage:l,symbol:d,node:c})}return g}var T=d.getDeclarations(),S=T&&e.find(T,(function(e){return e.getSourceFile()===o}));if(S&&!e.rangeContainsStartEnd(i,S.getStart(),S.end)){if(n.facts&a.IsGenerator&&2===l){for(var x=e.createDiagnosticForNode(c,r.cannotExtractRangeThatContainsWritesToReferencesLocatedOutsideOfTheTargetRangeInGenerators),L=0,D=m;L<D.length;L++){var C=D[L];C.push(x)}for(var I=0,N=_;I<N.length;I++){C=N[I];C.push(x)}}for(var k=0;k<t.length;k++){var R=t[k],O=s.resolveName(d.name,R,d.flags,!1);if(O!==d&&!f[k].has(g)){var w=Y(d.exportSymbol||d,R,u);if(w)f[k].set(g,w);else if(u){if(!(262144&d.flags)){x=e.createDiagnosticForNode(c,r.typeWillNotBeVisibleInTheNewScope);m[k].push(x),_[k].push(x)}}else p[k].usages.set(c.text,{usage:l,symbol:d,node:c})}}return g}}}function J(t){if(!(t===n.range||U(n.range)&&n.range.indexOf(t)>=0)){var r=e.isIdentifier(t)?X(t):s.getSymbolAtLocation(t);if(r){var a=e.find(g,(function(e){return e.symbol===r}));if(a)if(e.isVariableDeclaration(a)){var i=a.symbol.id.toString();y.has(i)||(h.push(a),y.set(i,!0))}else l=l||a}e.forEachChild(t,J)}}function X(n){return n.parent&&e.isShorthandPropertyAssignment(n.parent)&&n.parent.name===n?s.getShorthandAssignmentValueSymbol(n.parent):s.getSymbolAtLocation(n)}function Y(n,t,r){if(n){var a=n.getDeclarations();if(a&&a.some((function(e){return e.parent===t})))return e.factory.createIdentifier(n.name);var i=Y(n.parent,t,r);if(void 0!==i)return r?e.factory.createQualifiedName(i,e.factory.createIdentifier(n.name)):e.factory.createPropertyAccessExpression(i,n.name)}}}function K(n){return e.findAncestor(n,(function(n){return n.parent&&H(n)&&!e.isBinaryExpression(n.parent)}))}function H(e){var n=e.parent;switch(n.kind){case 292:return!1}switch(e.kind){case 10:return 262!==n.kind&&266!==n.kind;case 221:case 197:case 199:return!1;case 78:return 199!==n.kind&&266!==n.kind&&271!==n.kind}return!0}function W(e){switch(e.kind){case 231:case 298:case 258:case 285:return!0;default:return!1}}function z(n){return(e.isJsxElement(n)||e.isJsxSelfClosingElement(n)||e.isJsxFragment(n))&&e.isJsxElement(n.parent)}n.registerRefactor(c,{kinds:[l.kind,u.kind],getAvailableActions:d,getEditsForAction:p}),t.getAvailableActions=d,t.getEditsForAction=p,function(n){function t(n){return{message:n,code:0,category:e.DiagnosticCategory.Message,key:n}}n.cannotExtractRange=t("Cannot extract range."),n.cannotExtractImport=t("Cannot extract import statement."),n.cannotExtractSuper=t("Cannot extract super call."),n.cannotExtractJSDoc=t("Cannot extract JSDoc."),n.cannotExtractEmpty=t("Cannot extract empty range."),n.expressionExpected=t("expression expected."),n.uselessConstantType=t("No reason to extract constant of type."),n.statementOrExpressionExpected=t("Statement or expression expected."),n.cannotExtractRangeContainingConditionalBreakOrContinueStatements=t("Cannot extract range containing conditional break or continue statements."),n.cannotExtractRangeContainingConditionalReturnStatement=t("Cannot extract range containing conditional return statement."),n.cannotExtractRangeContainingLabeledBreakOrContinueStatementWithTargetOutsideOfTheRange=t("Cannot extract range containing labeled break or continue with target outside of the range."),n.cannotExtractRangeThatContainsWritesToReferencesLocatedOutsideOfTheTargetRangeInGenerators=t("Cannot extract range containing writes to references located outside of the target range in generators."),n.typeWillNotBeVisibleInTheNewScope=t("Type will not visible in the new scope."),n.functionWillNotBeVisibleInTheNewScope=t("Function will not visible in the new scope."),n.cannotExtractIdentifier=t("Select more than a single identifier."),n.cannotExtractExportedEntity=t("Cannot extract exported declaration"),n.cannotWriteInExpression=t("Cannot write back side-effects when extracting an expression"),n.cannotExtractReadonlyPropertyInitializerOutsideConstructor=t("Cannot move initialization of read-only class property outside of the constructor"),n.cannotExtractAmbientBlock=t("Cannot extract code from ambient contexts"),n.cannotAccessVariablesFromNestedScopes=t("Cannot access variables from nested scopes"),n.cannotExtractToOtherFunctionLike=t("Cannot extract method to a function-like scope that is not a function"),n.cannotExtractToJSClass=t("Cannot extract constant to a class scope in JS"),n.cannotExtractToExpressionArrowFunction=t("Cannot extract constant to an arrow function without a block")}(r=t.Messages||(t.Messages={})),function(e){e[e["None"]=0]="None",e[e["HasReturn"]=1]="HasReturn",e[e["IsGenerator"]=2]="IsGenerator",e[e["IsAsyncFunction"]=4]="IsAsyncFunction",e[e["UsesThis"]=8]="UsesThis",e[e["InStaticRegion"]=16]="InStaticRegion"}(a||(a={})),t.getRangeToExtract=f,function(e){e[e["Module"]=0]="Module",e[e["Global"]=1]="Global"}(i||(i={})),function(e){e[e["Read"]=1]="Read",e[e["Write"]=2]="Write"}(s||(s={}))})(n.extractSymbol||(n.extractSymbol={}))})(e.refactor||(e.refactor={}))}(d||(d={})),function(e){(function(n){var t="Extract type",r={name:"Extract to type alias",description:e.getLocaleSpecificMessage(e.Diagnostics.Extract_to_type_alias),kind:"refactor.extract.type"},a={name:"Extract to interface",description:e.getLocaleSpecificMessage(e.Diagnostics.Extract_to_interface),kind:"refactor.extract.interface"},i={name:"Extract to typedef",description:e.getLocaleSpecificMessage(e.Diagnostics.Extract_to_typedef),kind:"refactor.extract.typedef"};function s(n,t){void 0===t&&(t=!0);var r=n.file,a=n.startPosition,i=e.isSourceFileJS(r),o=e.getTokenAtPosition(r,a),s=e.createTextRangeFromSpan(e.getRefactorContextSpan(n)),d=s.pos===s.end&&t,p=e.findAncestor(o,(function(n){return n.parent&&e.isTypeNode(n)&&!l(s,n.parent,r)&&(d||e.nodeOverlapsWithStartEnd(o,r,s.pos,s.end))}));if(!p||!e.isTypeNode(p))return{error:e.getLocaleSpecificMessage(e.Diagnostics.Selection_is_not_a_valid_type_node)};var f=n.program.getTypeChecker(),m=e.Debug.checkDefined(e.findAncestor(p,e.isStatement),"Should find a statement"),_=u(f,p,m,r);if(!_)return{error:e.getLocaleSpecificMessage(e.Diagnostics.No_type_could_be_extracted_from_this_type_node)};var g=c(f,p);return{isJS:i,selection:p,firstStatement:m,typeParameters:_,typeElements:g}}function c(n,t){if(t){if(e.isIntersectionTypeNode(t)){for(var r=[],a=new e.Map,i=0,o=t.types;i<o.length;i++){var s=o[i],l=c(n,s);if(!l||!l.every((function(n){return n.name&&e.addToSeen(a,e.getNameFromPropertyName(n.name))})))return;e.addRange(r,l)}return r}return e.isParenthesizedTypeNode(t)?c(n,t.type):e.isTypeLiteralNode(t)?t.members:void 0}}function l(n,t,r){return e.rangeContainsStartEnd(n,e.skipTrivia(r.text,t.pos),t.end)}function u(n,t,r,a){var i=[];return o(t)?void 0:i;function o(s){if(e.isTypeReferenceNode(s)){if(e.isIdentifier(s.typeName)){var c=n.resolveName(s.typeName.text,s.typeName,262144,!0);if(null===c||void 0===c?void 0:c.declarations){var u=e.cast(e.first(c.declarations),e.isTypeParameterDeclaration);l(r,u,a)&&!l(t,u,a)&&e.pushIfUnique(i,u)}}}else if(e.isInferTypeNode(s)){var d=e.findAncestor(s,(function(n){return e.isConditionalTypeNode(n)&&l(n.extendsType,s,a)}));if(!d||!l(t,d,a))return!0}else if(e.isTypePredicateNode(s)||e.isThisTypeNode(s)){var p=e.findAncestor(s.parent,e.isFunctionLike);if(p&&p.type&&l(p.type,s,a)&&!l(t,p,a))return!0}else if(e.isTypeQueryNode(s))if(e.isIdentifier(s.exprName)){c=n.resolveName(s.exprName.text,s.exprName,111551,!1);if((null===c||void 0===c?void 0:c.valueDeclaration)&&l(r,c.valueDeclaration,a)&&!l(t,c.valueDeclaration,a))return!0}else if(e.isThisIdentifier(s.exprName.left)&&!l(t,s.parent,a))return!0;return a&&e.isTupleTypeNode(s)&&e.getLineAndCharacterOfPosition(a,s.pos).line===e.getLineAndCharacterOfPosition(a,s.end).line&&e.setEmitFlags(s,1),e.forEachChild(s,o)}}function d(n,t,r,a){var i=a.firstStatement,o=a.selection,s=a.typeParameters,c=e.factory.createTypeAliasDeclaration(void 0,void 0,r,s.map((function(n){return e.factory.updateTypeParameterDeclaration(n,n.name,n.constraint,void 0)})),o);n.insertNodeBefore(t,i,e.ignoreSourceNewlines(c),!0),n.replaceNode(t,o,e.factory.createTypeReferenceNode(r,s.map((function(n){return e.factory.createTypeReferenceNode(n.name,void 0)}))),{leadingTriviaOption:e.textChanges.LeadingTriviaOption.Exclude,trailingTriviaOption:e.textChanges.TrailingTriviaOption.ExcludeWhitespace})}function p(n,t,r,a){var i,o=a.firstStatement,s=a.selection,c=a.typeParameters,l=a.typeElements,u=e.factory.createInterfaceDeclaration(void 0,void 0,r,c,void 0,l);e.setTextRange(u,null===(i=l[0])||void 0===i?void 0:i.parent),n.insertNodeBefore(t,o,e.ignoreSourceNewlines(u),!0),n.replaceNode(t,s,e.factory.createTypeReferenceNode(r,c.map((function(n){return e.factory.createTypeReferenceNode(n.name,void 0)}))),{leadingTriviaOption:e.textChanges.LeadingTriviaOption.Exclude,trailingTriviaOption:e.textChanges.TrailingTriviaOption.ExcludeWhitespace})}function f(n,t,r,a){var i=a.firstStatement,o=a.selection,s=a.typeParameters,c=e.factory.createJSDocTypedefTag(e.factory.createIdentifier("typedef"),e.factory.createJSDocTypeExpression(o),e.factory.createIdentifier(r)),l=[];e.forEach(s,(function(n){var t=e.getEffectiveConstraintOfTypeParameter(n),r=e.factory.createTypeParameterDeclaration(n.name),a=e.factory.createJSDocTemplateTag(e.factory.createIdentifier("template"),t&&e.cast(t,e.isJSDocTypeExpression),[r]);l.push(a)})),n.insertNodeBefore(t,i,e.factory.createJSDocComment(void 0,e.factory.createNodeArray(e.concatenate(l,[c]))),!0),n.replaceNode(t,o,e.factory.createTypeReferenceNode(r,s.map((function(n){return e.factory.createTypeReferenceNode(n.name,void 0)}))))}n.registerRefactor(t,{kinds:[r.kind,a.kind,i.kind],getAvailableActions:function(c){var l=s(c,"invoked"===c.triggerReason);return l?n.isRefactorErrorInfo(l)?c.preferences.provideRefactorNotApplicableReason?[{name:t,description:e.getLocaleSpecificMessage(e.Diagnostics.Extract_type),actions:[o(o({},i),{notApplicableReason:l.error}),o(o({},r),{notApplicableReason:l.error}),o(o({},a),{notApplicableReason:l.error})]}]:e.emptyArray:[{name:t,description:e.getLocaleSpecificMessage(e.Diagnostics.Extract_type),actions:l.isJS?[i]:e.append([r],l.typeElements&&a)}]:e.emptyArray},getEditsForAction:function(t,o){var c=t.file,l=s(t);e.Debug.assert(l&&!n.isRefactorErrorInfo(l),"Expected to find a range to extract");var u=e.getUniqueName("NewType",c),m=e.textChanges.ChangeTracker.with(t,(function(n){switch(o){case r.name:return e.Debug.assert(!l.isJS,"Invalid actionName/JS combo"),d(n,c,u,l);case i.name:return e.Debug.assert(l.isJS,"Invalid actionName/JS combo"),f(n,c,u,l);case a.name:return e.Debug.assert(!l.isJS&&!!l.typeElements,"Invalid actionName/JS combo"),p(n,c,u,l);default:e.Debug.fail("Unexpected action name")}})),_=c.fileName,g=e.getRenameLocation(m,_,u,!1);return{edits:m,renameFilename:_,renameLocation:g}}})})(e.refactor||(e.refactor={}))}(d||(d={})),function(e){(function(n){(function(t){var r="Generate 'get' and 'set' accessors",a=e.Diagnostics.Generate_get_and_set_accessors.message,i={name:r,description:a,kind:"refactor.rewrite.property.generateAccessors"};n.registerRefactor(r,{kinds:[i.kind],getEditsForAction:function(t,r){if(t.endPosition){var a=e.codefix.getAccessorConvertiblePropertyAtPosition(t.file,t.program,t.startPosition,t.endPosition);e.Debug.assert(a&&!n.isRefactorErrorInfo(a),"Expected applicable refactor info");var i=e.codefix.generateAccessorFromProperty(t.file,t.program,t.startPosition,t.endPosition,t,r);if(i){var o=t.file.fileName,s=a.renameAccessor?a.accessorName:a.fieldName,c=e.isIdentifier(s)?0:-1,l=c+e.getRenameLocation(i,o,s.text,e.isParameter(a.declaration));return{renameFilename:o,renameLocation:l,edits:i}}}},getAvailableActions:function(t){if(!t.endPosition)return e.emptyArray;var s=e.codefix.getAccessorConvertiblePropertyAtPosition(t.file,t.program,t.startPosition,t.endPosition,"invoked"===t.triggerReason);return s?n.isRefactorErrorInfo(s)?t.preferences.provideRefactorNotApplicableReason?[{name:r,description:a,actions:[o(o({},i),{notApplicableReason:s.error})]}]:e.emptyArray:[{name:r,description:a,actions:[i]}]:e.emptyArray}})})(n.generateGetAccessorAndSetAccessor||(n.generateGetAccessorAndSetAccessor={}))})(e.refactor||(e.refactor={}))}(d||(d={})),function(e){(function(e){function n(e){return void 0!==e.error}function t(e,n){return!n||e.substr(0,n.length)===n}e.isRefactorErrorInfo=n,e.refactorKindBeginsWith=t})(e.refactor||(e.refactor={}))}(d||(d={})),function(e){(function(n){var t="Move to a new file",r=e.getLocaleSpecificMessage(e.Diagnostics.Move_to_a_new_file),a={name:t,description:r,kind:"refactor.move.newFile"};function s(n){var t=n.file,r=e.createTextRangeFromSpan(e.getRefactorContextSpan(n)),a=t.statements,i=e.findIndex(a,(function(e){return e.end>r.pos}));if(-1!==i){var o=a[i];if(e.isNamedDeclaration(o)&&o.name&&e.rangeContainsRange(o.name,r))return{toMove:[a[i]],afterLast:a[i+1]};if(!(r.pos>o.getStart(t))){var s=e.findIndex(a,(function(e){return e.end>r.end}),i);if(-1===s||!(0===s||a[s].getStart(t)<r.end))return{toMove:a.slice(i,-1===s?a.length:s),afterLast:-1===s?void 0:a[s]}}}}function c(n,t,r,a,i,o){var s=t.getTypeChecker(),c=O(n,r.all,s),l=e.getDirectoryPath(n.fileName),u=e.extensionFromPath(n.fileName),d=k(R(c.movedSymbols),u,l,i),m=d+u;a.createNewFile(n,e.combinePaths(l,m),f(n,c,a,r,t,d,o)),p(t,a,n.fileName,m,e.hostGetCanonicalFileName(i))}function l(n){var t=s(n);if(void 0!==t){var r=[],a=[],i=t.toMove,o=t.afterLast;return e.getRangesWhere(i,u,(function(e,n){for(var t=e;t<n;t++)r.push(i[t]);a.push({first:i[e],afterLast:o})})),0===r.length?void 0:{all:r,ranges:a}}}function u(n){return!d(n)&&!e.isPrologueDirective(n)}function d(n){switch(n.kind){case 262:return!0;case 261:return!e.hasSyntacticModifier(n,1);case 233:return n.declarationList.declarations.every((function(n){return!!n.initializer&&e.isRequireCall(n.initializer,!0)}));default:return!1}}function p(n,t,r,a,i){var o=n.getCompilerOptions().configFile;if(o){var s=e.normalizePath(e.combinePaths(r,"..",a)),c=e.getRelativePathFromFile(o.fileName,s,i),l=o.statements[0]&&e.tryCast(o.statements[0].expression,e.isObjectLiteralExpression),u=l&&e.find(l.properties,(function(n){return e.isPropertyAssignment(n)&&e.isStringLiteral(n.name)&&"files"===n.name.text}));u&&e.isArrayLiteralExpression(u.initializer)&&t.insertNodeInListAfter(o,e.last(u.initializer.elements),e.factory.createStringLiteral(c),u.initializer.elements)}}function f(n,t,r,a,o,s,c){var l=o.getTypeChecker(),u=e.takeWhile(n.statements,e.isPrologueDirective);if(!n.externalModuleIndicator&&!n.commonJsModuleIndicator)return m(n,a.ranges,r),i(i([],u),a.all);var d=!!n.externalModuleIndicator,p=e.getQuotePreference(n,c),f=T(t.oldFileImportsFromNewFile,s,d,p);f&&e.insertImports(r,n,f,!0),_(n,a.all,r,t.unusedImportsFromOldFile,l),m(n,a.ranges,r),g(r,o,n,t.movedSymbols,s);var y=N(n,t.oldImportsNeededByNewFile,t.newFileImportsFromOldFile,r,l,d,p),h=D(n,a.all,t.oldFileImportsFromNewFile,d);return y.length&&h.length?i(i(i(i([],u),y),[4]),h):i(i(i([],u),y),h)}function m(e,n,t){for(var r=0,a=n;r<a.length;r++){var i=a[r],o=i.first,s=i.afterLast;t.deleteNodeRangeExcludingEnd(e,o,s)}}function _(n,t,r,a,i){for(var o=0,s=n.statements;o<s.length;o++){var c=s[o];e.contains(t,c)||E(c,(function(e){return A(n,e,r,(function(e){return a.has(i.getSymbolAtLocation(e))}))}))}}function g(n,t,r,a,i){for(var o=t.getTypeChecker(),s=function(t){if(t===r)return"continue";for(var s=function(s){E(s,(function(c){if(o.getSymbolAtLocation(b(c))===r.symbol){var l=function(n){var t=e.isBindingElement(n.parent)?e.getPropertySymbolFromBindingElement(o,n.parent):e.skipAlias(o.getSymbolAtLocation(n),o);return!!t&&a.has(t)};A(t,c,n,l);var u=e.combinePaths(e.getDirectoryPath(b(c).text),i),d=M(c,e.factory.createStringLiteral(u),l);d&&n.insertNodeAfter(t,s,d);var p=y(c);p&&h(n,t,o,a,i,u,p,c)}}))},c=0,l=t.statements;c<l.length;c++){var u=l[c];s(u)}},c=0,l=t.getSourceFiles();c<l.length;c++){var u=l[c];s(u)}}function y(n){switch(n.kind){case 262:return n.importClause&&n.importClause.namedBindings&&264===n.importClause.namedBindings.kind?n.importClause.namedBindings.name:void 0;case 261:return n.name;case 250:return e.tryCast(n.name,e.isIdentifier);default:return e.Debug.assertNever(n,"Unexpected node kind "+n.kind)}}function h(n,t,r,a,i,o,s,c){var l=e.codefix.moduleSpecifierToValidIdentifier(i,99),u=!1,d=[];if(e.FindAllReferences.Core.eachSymbolReferenceInFile(s,r,t,(function(n){e.isPropertyAccessExpression(n.parent)&&(u=u||!!r.resolveName(l,n,67108863,!0),a.has(r.getSymbolAtLocation(n.parent.name))&&d.push(n))})),d.length){for(var p=u?e.getUniqueName(l,t):l,f=0,m=d;f<m.length;f++){var _=m[f];n.replaceNode(t,_,e.factory.createIdentifier(p))}n.insertNodeAfter(t,c,v(c,i,o))}}function v(n,t,r){var a=e.factory.createIdentifier(t),i=e.factory.createStringLiteral(r);switch(n.kind){case 262:return e.factory.createImportDeclaration(void 0,void 0,e.factory.createImportClause(!1,void 0,e.factory.createNamespaceImport(a)),i);case 261:return e.factory.createImportEqualsDeclaration(void 0,void 0,!1,a,e.factory.createExternalModuleReference(i));case 250:return e.factory.createVariableDeclaration(a,void 0,void 0,L(i));default:return e.Debug.assertNever(n,"Unexpected node kind "+n.kind)}}function b(e){return 262===e.kind?e.moduleSpecifier:261===e.kind?e.moduleReference.expression:e.initializer.arguments[0]}function E(n,t){if(e.isImportDeclaration(n))e.isStringLiteral(n.moduleSpecifier)&&t(n);else if(e.isImportEqualsDeclaration(n))e.isExternalModuleReference(n.moduleReference)&&e.isStringLiteralLike(n.moduleReference.expression)&&t(n);else if(e.isVariableStatement(n))for(var r=0,a=n.declarationList.declarations;r<a.length;r++){var i=a[r];i.initializer&&e.isRequireCall(i.initializer,!0)&&t(i)}}function T(n,t,r,a){var i,o=[];return n.forEach((function(n){"default"===n.escapedName?i=e.factory.createIdentifier(e.symbolNameNoDefault(n)):o.push(n.name)})),S(i,o,t,r,a)}function S(n,t,r,a,i){if(r=e.ensurePathIsNonModuleName(r),a){var o=t.map((function(n){return e.factory.createImportSpecifier(void 0,e.factory.createIdentifier(n))}));return e.makeImportIfNecessary(n,o,r,i)}e.Debug.assert(!n,"No default import should exist");var s=t.map((function(n){return e.factory.createBindingElement(void 0,void 0,n)}));return s.length?x(e.factory.createObjectBindingPattern(s),void 0,L(e.factory.createStringLiteral(r))):void 0}function x(n,t,r,a){return void 0===a&&(a=2),e.factory.createVariableStatement(void 0,e.factory.createVariableDeclarationList([e.factory.createVariableDeclaration(n,void 0,t,r)],a))}function L(n){return e.factory.createCallExpression(e.factory.createIdentifier("require"),void 0,[n])}function D(n,t,r,a){return e.flatMap(t,(function(t){if(K(t)&&!Y(n,t,a)&&W(t,(function(n){return r.has(e.Debug.checkDefined(n.symbol))}))){var i=Q(t,a);if(i)return i}return t}))}function A(n,t,r,a){switch(t.kind){case 262:C(n,t,r,a);break;case 261:a(t.name)&&r.delete(n,t);break;case 250:I(n,t,r,a);break;default:e.Debug.assertNever(t,"Unexpected import decl kind "+t.kind)}}function C(n,t,r,a){if(t.importClause){var i=t.importClause,o=i.name,s=i.namedBindings,c=!o||a(o),l=!s||(264===s.kind?a(s.name):0!==s.elements.length&&s.elements.every((function(e){return a(e.name)})));if(c&&l)r.delete(n,t);else if(o&&c&&r.delete(n,o),s)if(l)r.replaceNode(n,t.importClause,e.factory.updateImportClause(t.importClause,t.importClause.isTypeOnly,o,void 0));else if(265===s.kind)for(var u=0,d=s.elements;u<d.length;u++){var p=d[u];a(p.name)&&r.delete(n,p)}}}function I(n,t,r,a){var i=t.name;switch(i.kind){case 78:a(i)&&r.delete(n,i);break;case 198:break;case 197:if(i.elements.every((function(n){return e.isIdentifier(n.name)&&a(n.name)})))r.delete(n,e.isVariableDeclarationList(t.parent)&&1===t.parent.declarations.length?t.parent.parent:t);else for(var o=0,s=i.elements;o<s.length;o++){var c=s[o];e.isIdentifier(c.name)&&a(c.name)&&r.delete(n,c.name)}break}}function N(n,t,r,a,i,o,s){for(var c,l=[],u=0,d=n.statements;u<d.length;u++){var p=d[u];E(p,(function(n){e.append(l,M(n,b(n),(function(e){return t.has(i.getSymbolAtLocation(e))})))}))}var f=[],m=e.nodeSeenTracker();return r.forEach((function(t){if(t.declarations)for(var r=0,i=t.declarations;r<i.length;r++){var s=i[r];if(V(s)){var l=q(s);if(l){var u=J(s);m(u)&&X(n,u,a,o),e.hasSyntacticModifier(s,512)?c=l:f.push(l.text)}}}})),e.append(l,S(c,f,e.removeFileExtension(e.getBaseFileName(n.fileName)),o,s)),l}function k(n,t,r,a){for(var i=n,o=1;;o++){var s=e.combinePaths(r,i+t);if(!a.fileExists(s))return i;i=n+"."+o}}function R(n){return n.forEachEntry(e.symbolNameNoDefault)||"newFile"}function O(n,t,r){var a=new U,i=new U,o=new U,s=e.find(t,(function(e){return!!(2&e.transformFlags)})),c=h(s);c&&i.add(c);for(var l=0,u=t;l<u.length;l++){var d=u[l];W(d,(function(n){a.add(e.Debug.checkDefined(e.isExpressionStatement(n)?r.getSymbolAtLocation(n.expression.left):n.symbol,"Need a symbol here"))}))}for(var p=0,f=t;p<f.length;p++){d=f[p];B(d,r,(function(e){if(e.declarations)for(var t=0,r=e.declarations;t<r.length;t++){var s=r[t];w(s)?i.add(e):V(s)&&j(s)===n&&!a.has(e)&&o.add(e)}}))}for(var m=i.clone(),_=new U,g=0,y=n.statements;g<y.length;g++){d=y[g];e.contains(t,d)||(c&&2&d.transformFlags&&m.delete(c),B(d,r,(function(e){a.has(e)&&_.add(e),m.delete(e)})))}return{movedSymbols:a,newFileImportsFromOldFile:o,oldFileImportsFromNewFile:_,oldImportsNeededByNewFile:i,unusedImportsFromOldFile:m};function h(n){if(void 0!==n){var t=r.getJsxNamespace(n),a=r.resolveName(t,n,1920,!0);return a&&e.some(a.declarations,w)?a:void 0}}}function w(n){switch(n.kind){case 261:case 266:case 263:case 264:return!0;case 250:return P(n);case 199:return e.isVariableDeclaration(n.parent.parent)&&P(n.parent.parent);default:return!1}}function P(n){return e.isSourceFile(n.parent.parent.parent)&&!!n.initializer&&e.isRequireCall(n.initializer,!0)}function M(n,t,r){switch(n.kind){case 262:var a=n.importClause;if(!a)return;var i=a.name&&r(a.name)?a.name:void 0,o=a.namedBindings&&F(a.namedBindings,r);return i||o?e.factory.createImportDeclaration(void 0,void 0,e.factory.createImportClause(!1,i,o),t):void 0;case 261:return r(n.name)?n:void 0;case 250:var s=G(n.name,r);return s?x(s,n.type,L(t),n.parent.flags):void 0;default:return e.Debug.assertNever(n,"Unexpected import kind "+n.kind)}}function F(n,t){if(264===n.kind)return t(n.name)?n:void 0;var r=n.elements.filter((function(e){return t(e.name)}));return r.length?e.factory.createNamedImports(r):void 0}function G(n,t){switch(n.kind){case 78:return t(n)?n:void 0;case 198:return n;case 197:var r=n.elements.filter((function(n){return n.propertyName||!e.isIdentifier(n.name)||t(n.name)}));return r.length?e.factory.createObjectBindingPattern(r):void 0}}function B(n,t,r){n.forEachChild((function n(a){if(e.isIdentifier(a)&&!e.isDeclarationName(a)){var i=t.getSymbolAtLocation(a);i&&r(i)}else a.forEachChild(n)}))}n.registerRefactor(t,{kinds:[a.kind],getAvailableActions:function(n){var i=l(n);return n.preferences.allowTextChangesInNewFiles&&i?[{name:t,description:r,actions:[a]}]:n.preferences.provideRefactorNotApplicableReason?[{name:t,description:r,actions:[o(o({},a),{notApplicableReason:e.getLocaleSpecificMessage(e.Diagnostics.Selection_is_not_a_valid_statement_or_statements)})]}]:e.emptyArray},getEditsForAction:function(n,r){e.Debug.assert(r===t,"Wrong refactor invoked");var a=e.Debug.checkDefined(l(n)),i=e.textChanges.ChangeTracker.with(n,(function(e){return c(n.file,n.program,a,e,n.host,n.preferences)}));return{edits:i,renameFilename:void 0,renameLocation:void 0}}});var U=function(){function n(){this.map=new e.Map}return n.prototype.add=function(n){this.map.set(String(e.getSymbolId(n)),n)},n.prototype.has=function(n){return this.map.has(String(e.getSymbolId(n)))},n.prototype.delete=function(n){this.map.delete(String(e.getSymbolId(n)))},n.prototype.forEach=function(e){this.map.forEach(e)},n.prototype.forEachEntry=function(n){return e.forEachEntry(this.map,n)},n.prototype.clone=function(){var t=new n;return e.copyEntries(this.map,t.map),t},n}();function V(n){return H(n)&&e.isSourceFile(n.parent)||e.isVariableDeclaration(n)&&e.isSourceFile(n.parent.parent.parent)}function j(n){return e.isVariableDeclaration(n)?n.parent.parent.parent:n.parent}function K(n){return e.Debug.assert(e.isSourceFile(n.parent),"Node parent should be a SourceFile"),H(n)||e.isVariableStatement(n)}function H(e){switch(e.kind){case 252:case 253:case 257:case 256:case 255:case 254:case 261:return!0;default:return!1}}function W(n,t){switch(n.kind){case 252:case 253:case 257:case 256:case 255:case 254:case 261:return t(n);case 233:return e.firstDefined(n.declarationList.declarations,(function(e){return z(e.name,t)}));case 234:var r=n.expression;return e.isBinaryExpression(r)&&1===e.getAssignmentDeclarationKind(r)?t(n):void 0}}function z(n,t){switch(n.kind){case 78:return t(e.cast(n.parent,(function(n){return e.isVariableDeclaration(n)||e.isBindingElement(n)})));case 198:case 197:return e.firstDefined(n.elements,(function(n){return e.isOmittedExpression(n)?void 0:z(n.name,t)}));default:return e.Debug.assertNever(n,"Unexpected name kind "+n.kind)}}function q(n){return e.isExpressionStatement(n)?e.tryCast(n.expression.left.name,e.isIdentifier):e.tryCast(n.name,e.isIdentifier)}function J(n){switch(n.kind){case 250:return n.parent.parent;case 199:return J(e.cast(n.parent.parent,(function(n){return e.isVariableDeclaration(n)||e.isBindingElement(n)})));default:return n}}function X(n,t,r,a){if(!Y(n,t,a))if(a)e.isExpressionStatement(t)||r.insertExportModifier(n,t);else{var i=ee(t);0!==i.length&&r.insertNodesAfter(n,t,i.map(ne))}}function Y(n,t,r){return r?!e.isExpressionStatement(t)&&e.hasSyntacticModifier(t,1):ee(t).some((function(t){return n.symbol.exports.has(e.escapeLeadingUnderscores(t))}))}function Q(e,n){return n?[Z(e)]:$(e)}function Z(n){var t=e.concatenate([e.factory.createModifier(92)],n.modifiers);switch(n.kind){case 252:return e.factory.updateFunctionDeclaration(n,n.decorators,t,n.asteriskToken,n.name,n.typeParameters,n.parameters,n.type,n.body);case 253:return e.factory.updateClassDeclaration(n,n.decorators,t,n.name,n.typeParameters,n.heritageClauses,n.members);case 233:return e.factory.updateVariableStatement(n,t,n.declarationList);case 257:return e.factory.updateModuleDeclaration(n,n.decorators,t,n.name,n.body);case 256:return e.factory.updateEnumDeclaration(n,n.decorators,t,n.name,n.members);case 255:return e.factory.updateTypeAliasDeclaration(n,n.decorators,t,n.name,n.typeParameters,n.type);case 254:return e.factory.updateInterfaceDeclaration(n,n.decorators,t,n.name,n.typeParameters,n.heritageClauses,n.members);case 261:return e.factory.updateImportEqualsDeclaration(n,n.decorators,t,n.isTypeOnly,n.name,n.moduleReference);case 234:return e.Debug.fail();default:return e.Debug.assertNever(n,"Unexpected declaration kind "+n.kind)}}function $(e){return i([e],ee(e).map(ne))}function ee(n){switch(n.kind){case 252:case 253:return[n.name.text];case 233:return e.mapDefined(n.declarationList.declarations,(function(n){return e.isIdentifier(n.name)?n.name.text:void 0}));case 257:case 256:case 255:case 254:case 261:return e.emptyArray;case 234:return e.Debug.fail("Can't export an ExpressionStatement");default:return e.Debug.assertNever(n,"Unexpected decl kind "+n.kind)}}function ne(n){return e.factory.createExpressionStatement(e.factory.createBinaryExpression(e.factory.createPropertyAccessExpression(e.factory.createIdentifier("exports"),e.factory.createIdentifier(n)),62,e.factory.createIdentifier(n)))}})(e.refactor||(e.refactor={}))}(d||(d={})),function(e){(function(n){(function(t){var r="Add or remove braces in an arrow function",a=e.Diagnostics.Add_or_remove_braces_in_an_arrow_function.message,i={name:"Add braces to arrow function",description:e.Diagnostics.Add_braces_to_arrow_function.message,kind:"refactor.rewrite.arrow.braces.add"},s={name:"Remove braces from arrow function",description:e.Diagnostics.Remove_braces_from_arrow_function.message,kind:"refactor.rewrite.arrow.braces.remove"};function c(t){var c=t.file,l=t.startPosition,d=t.triggerReason,p=u(c,l,"invoked"===d);return p?n.isRefactorErrorInfo(p)?t.preferences.provideRefactorNotApplicableReason?[{name:r,description:a,actions:[o(o({},i),{notApplicableReason:p.error}),o(o({},s),{notApplicableReason:p.error})]}]:e.emptyArray:[{name:r,description:a,actions:[p.addBraces?i:s]}]:e.emptyArray}function l(t,r){var a=t.file,o=t.startPosition,c=u(a,o);e.Debug.assert(c&&!n.isRefactorErrorInfo(c),"Expected applicable refactor info");var l,d=c.expression,p=c.returnStatement,f=c.func;if(r===i.name){var m=e.factory.createReturnStatement(d);l=e.factory.createBlock([m],!0),e.suppressLeadingAndTrailingTrivia(l),e.copyLeadingComments(d,m,a,3,!0)}else if(r===s.name&&p){var _=d||e.factory.createVoidZero();l=e.needsParentheses(_)?e.factory.createParenthesizedExpression(_):_,e.suppressLeadingAndTrailingTrivia(l),e.copyTrailingAsLeadingComments(p,l,a,3,!1),e.copyLeadingComments(p,l,a,3,!1),e.copyTrailingComments(p,l,a,3,!1)}else e.Debug.fail("invalid action");var g=e.textChanges.ChangeTracker.with(t,(function(e){e.replaceNode(a,f.body,l)}));return{renameFilename:void 0,renameLocation:void 0,edits:g}}function u(t,r,a,o){void 0===a&&(a=!0);var c=e.getTokenAtPosition(t,r),l=e.getContainingFunction(c);if(!l)return{error:e.getLocaleSpecificMessage(e.Diagnostics.Could_not_find_a_containing_arrow_function)};if(!e.isArrowFunction(l))return{error:e.getLocaleSpecificMessage(e.Diagnostics.Containing_function_is_not_an_arrow_function)};if(e.rangeContainsRange(l,c)&&(!e.rangeContainsRange(l.body,c)||a)){if(n.refactorKindBeginsWith(i.kind,o)&&e.isExpression(l.body))return{func:l,addBraces:!0,expression:l.body};if(n.refactorKindBeginsWith(s.kind,o)&&e.isBlock(l.body)&&1===l.body.statements.length){var u=e.first(l.body.statements);if(e.isReturnStatement(u))return{func:l,addBraces:!1,expression:u.expression,returnStatement:u}}}}n.registerRefactor(r,{kinds:[s.kind],getEditsForAction:l,getAvailableActions:c})})(n.addOrRemoveBracesToArrowFunction||(n.addOrRemoveBracesToArrowFunction={}))})(e.refactor||(e.refactor={}))}(d||(d={})),function(e){(function(n){(function(t){var r="Convert parameters to destructured object",a=2,o=e.getLocaleSpecificMessage(e.Diagnostics.Convert_parameters_to_destructured_object),s={name:r,description:o,kind:"refactor.rewrite.parameters.toDestructured"};function c(n){var t=n.file,a=n.startPosition,i=e.isSourceFileJS(t);if(i)return e.emptyArray;var c=h(t,a,n.program.getTypeChecker());return c?[{name:r,description:o,actions:[s]}]:e.emptyArray}function l(n,t){e.Debug.assert(t===r,"Unexpected action name");var a=n.file,i=n.startPosition,o=n.program,s=n.cancellationToken,c=n.host,l=h(a,i,o.getTypeChecker());if(l&&s){var p=d(l,o,s);if(p.valid){var f=e.textChanges.ChangeTracker.with(n,(function(e){return u(a,o,c,e,l,p)}));return{renameFilename:void 0,renameLocation:void 0,edits:f}}return{edits:[]}}}function u(n,t,r,a,i,o){var s=o.signature,c=e.map(R(i,t,r),(function(n){return e.getSynthesizedDeepClone(n)}));if(s){var l=e.map(R(s,t,r),(function(n){return e.getSynthesizedDeepClone(n)}));_(s,l)}_(i,c);for(var u=e.sortAndDeduplicate(o.functionCalls,(function(n,t){return e.compareValues(n.pos,t.pos)})),d=0,p=u;d<p.length;d++){var f=p[d];if(f.arguments&&f.arguments.length){var m=e.getSynthesizedDeepClone(k(i,f.arguments),!0);a.replaceNodeRange(e.getSourceFileOfNode(f),e.first(f.arguments),e.last(f.arguments),m,{leadingTriviaOption:e.textChanges.LeadingTriviaOption.IncludeAll,trailingTriviaOption:e.textChanges.TrailingTriviaOption.Include})}}function _(t,r){a.replaceNodeRangeWithNodes(n,e.first(t.parameters),e.last(t.parameters),r,{joiner:", ",indentation:0,leadingTriviaOption:e.textChanges.LeadingTriviaOption.IncludeAll,trailingTriviaOption:e.textChanges.TrailingTriviaOption.Include})}}function d(n,t,r){var a=P(n),o=e.isConstructorDeclaration(n)?w(n):[],s=e.deduplicate(i(i([],a),o),e.equateValues),c=t.getTypeChecker(),l=e.flatMap(s,(function(n){return e.FindAllReferences.getReferenceEntriesForNode(-1,n,t,t.getSourceFiles(),r)})),u=d(l);return e.every(u.declarations,(function(n){return e.contains(s,n)}))||(u.valid=!1),u;function d(t){for(var r={accessExpressions:[],typeUsages:[]},i={functionCalls:[],declarations:[],classReferences:r,valid:!0},s=e.map(a,h),l=e.map(o,h),u=e.isConstructorDeclaration(n),d=e.map(a,(function(e){return p(e,c)})),v=0,E=t;v<E.length;v++){var T=E[v];if(0!==T.kind){if(e.contains(d,h(T.node))){if(b(T.node.parent)){i.signature=T.node.parent;continue}var S=_(T);if(S){i.functionCalls.push(S);continue}}var x=p(T.node,c);if(x&&e.contains(d,x)){var L=m(T);if(L){i.declarations.push(L);continue}}if(e.contains(s,h(T.node))||e.isNewExpressionTarget(T.node)){var D=f(T);if(D)continue;L=m(T);if(L){i.declarations.push(L);continue}S=_(T);if(S){i.functionCalls.push(S);continue}}if(u&&e.contains(l,h(T.node))){D=f(T);if(D)continue;L=m(T);if(L){i.declarations.push(L);continue}var A=g(T);if(A){r.accessExpressions.push(A);continue}if(e.isClassDeclaration(n.parent)){var C=y(T);if(C){r.typeUsages.push(C);continue}}}i.valid=!1}else i.valid=!1}return i}function h(n){var t=c.getSymbolAtLocation(n);return t&&e.getSymbolTarget(t,c)}}function p(n,t){var r=e.getContainingObjectLiteralElement(n);if(r){var a=t.getContextualTypeForObjectLiteralElement(r),i=null===a||void 0===a?void 0:a.getSymbol();if(i&&!(6&e.getCheckFlags(i)))return i}}function f(n){var t=n.node;return e.isImportSpecifier(t.parent)||e.isImportClause(t.parent)||e.isImportEqualsDeclaration(t.parent)||e.isNamespaceImport(t.parent)||e.isExportSpecifier(t.parent)||e.isExportAssignment(t.parent)?t:void 0}function m(n){if(e.isDeclaration(n.node.parent))return n.node}function _(n){if(n.node.parent){var t=n.node,r=t.parent;switch(r.kind){case 204:case 205:var a=e.tryCast(r,e.isCallOrNewExpression);if(a&&a.expression===t)return a;break;case 202:var i=e.tryCast(r,e.isPropertyAccessExpression);if(i&&i.parent&&i.name===t){var o=e.tryCast(i.parent,e.isCallOrNewExpression);if(o&&o.expression===i)return o}break;case 203:var s=e.tryCast(r,e.isElementAccessExpression);if(s&&s.parent&&s.argumentExpression===t){var c=e.tryCast(s.parent,e.isCallOrNewExpression);if(c&&c.expression===s)return c}break}}}function g(n){if(n.node.parent){var t=n.node,r=t.parent;switch(r.kind){case 202:var a=e.tryCast(r,e.isPropertyAccessExpression);if(a&&a.expression===t)return a;break;case 203:var i=e.tryCast(r,e.isElementAccessExpression);if(i&&i.expression===t)return i;break}}}function y(n){var t=n.node;if(2===e.getMeaningFromLocation(t)||e.isExpressionWithTypeArgumentsInClassExtendsClause(t.parent))return t}function h(n,t,r){var a=e.getTouchingToken(n,t),i=e.getContainingFunctionDeclaration(a);if(!v(a))return!(i&&E(i,r)&&e.rangeContainsRange(i,a))||i.body&&e.rangeContainsRange(i.body,a)?void 0:i}function v(n){var t=e.findAncestor(n,e.isJSDocNode);if(t){var r=e.findAncestor(t,(function(n){return!e.isJSDocNode(n)}));return!!r&&e.isFunctionLikeDeclaration(r)}return!1}function b(n){return e.isMethodSignature(n)&&(e.isInterfaceDeclaration(n.parent)||e.isTypeLiteralNode(n.parent))}function E(n,t){var r;if(!x(n.parameters,t))return!1;switch(n.kind){case 252:return S(n)&&T(n,t);case 166:if(e.isObjectLiteralExpression(n.parent)){var a=p(n.name,t);return 1===(null===(r=null===a||void 0===a?void 0:a.declarations)||void 0===r?void 0:r.length)&&T(n,t)}return T(n,t);case 167:return e.isClassDeclaration(n.parent)?S(n.parent)&&T(n,t):D(n.parent.parent)&&T(n,t);case 209:case 210:return D(n.parent)}return!1}function T(e,n){return!!e.body&&!n.isImplementationOfOverload(e)}function S(n){if(!n.name){var t=e.findModifier(n,87);return!!t}return!0}function x(n,t){return C(n)>=a&&e.every(n,(function(e){return L(e,t)}))}function L(n,t){if(e.isRestParameter(n)){var r=t.getTypeAtLocation(n);if(!t.isArrayType(r)&&!t.isTupleType(r))return!1}return!n.modifiers&&!n.decorators&&e.isIdentifier(n.name)}function D(n){return e.isVariableDeclaration(n)&&e.isVarConst(n)&&e.isIdentifier(n.name)&&!n.type}function A(n){return n.length>0&&e.isThis(n[0].name)}function C(e){return A(e)?e.length-1:e.length}function I(n){return A(n)&&(n=e.factory.createNodeArray(n.slice(1),n.hasTrailingComma)),n}function N(n,t){return e.isIdentifier(t)&&e.getTextOfIdentifierOrLiteral(t)===n?e.factory.createShorthandPropertyAssignment(n):e.factory.createPropertyAssignment(n,t)}function k(n,t){var r=I(n.parameters),a=e.isRestParameter(e.last(r)),i=a?t.slice(0,r.length-1):t,o=e.map(i,(function(n,t){var a=O(r[t]),i=N(a,n);return e.suppressLeadingAndTrailingTrivia(i.name),e.isPropertyAssignment(i)&&e.suppressLeadingAndTrailingTrivia(i.initializer),e.copyComments(n,i),i}));if(a&&t.length>=r.length){var s=t.slice(r.length-1),c=e.factory.createPropertyAssignment(O(e.last(r)),e.factory.createArrayLiteralExpression(s));o.push(c)}var l=e.factory.createObjectLiteralExpression(o,!1);return l}function R(n,t,r){var a,i=t.getTypeChecker(),o=I(n.parameters),s=e.map(o,f),c=e.factory.createObjectBindingPattern(s),l=m(o);e.every(o,y)&&(a=e.factory.createObjectLiteralExpression());var u=e.factory.createParameterDeclaration(void 0,void 0,void 0,c,void 0,l,a);if(A(n.parameters)){var d=n.parameters[0],p=e.factory.createParameterDeclaration(void 0,void 0,void 0,d.name,void 0,d.type);return e.suppressLeadingAndTrailingTrivia(p.name),e.copyComments(d.name,p.name),d.type&&(e.suppressLeadingAndTrailingTrivia(p.type),e.copyComments(d.type,p.type)),e.factory.createNodeArray([p,u])}return e.factory.createNodeArray([u]);function f(n){var t=e.factory.createBindingElement(void 0,void 0,O(n),e.isRestParameter(n)&&y(n)?e.factory.createArrayLiteralExpression():n.initializer);return e.suppressLeadingAndTrailingTrivia(t),n.initializer&&t.initializer&&e.copyComments(n.initializer,t.initializer),t}function m(n){var t=e.map(n,_),r=e.addEmitFlags(e.factory.createTypeLiteralNode(t),1);return r}function _(n){var t=n.type;t||!n.initializer&&!e.isRestParameter(n)||(t=g(n));var r=e.factory.createPropertySignature(void 0,O(n),y(n)?e.factory.createToken(57):n.questionToken,t);return e.suppressLeadingAndTrailingTrivia(r),e.copyComments(n.name,r.name),n.type&&r.type&&e.copyComments(n.type,r.type),r}function g(n){var a=i.getTypeAtLocation(n);return e.getTypeNodeIfAccessible(a,n,t,r)}function y(n){if(e.isRestParameter(n)){var t=i.getTypeAtLocation(n);return!i.isTupleType(t)}return i.isOptionalParameter(n)}}function O(n){return e.getTextOfIdentifierOrLiteral(n.name)}function w(n){switch(n.parent.kind){case 253:var t=n.parent;if(t.name)return[t.name];var r=e.Debug.checkDefined(e.findModifier(t,87),"Nameless class declaration should be a default export");return[r];case 222:var a=n.parent,i=n.parent.parent,o=a.name;return o?[o,i.name]:[i.name]}}function P(n){switch(n.kind){case 252:if(n.name)return[n.name];var t=e.Debug.checkDefined(e.findModifier(n,87),"Nameless function declaration should be a default export");return[t];case 166:return[n.name];case 167:var r=e.Debug.checkDefined(e.findChildOfKind(n,132,n.getSourceFile()),"Constructor declaration should have constructor keyword");if(222===n.parent.kind){var a=n.parent.parent;return[a.name,r]}return[r];case 210:return[n.parent.name];case 209:return n.name?[n.name,n.parent.name]:[n.parent.name];default:return e.Debug.assertNever(n,"Unexpected function declaration kind "+n.kind)}}n.registerRefactor(r,{kinds:[s.kind],getEditsForAction:l,getAvailableActions:c})})(n.convertParamsToDestructuredObject||(n.convertParamsToDestructuredObject={}))})(e.refactor||(e.refactor={}))}(d||(d={})),function(e){(function(n){(function(t){var r="Convert to template string",a=e.getLocaleSpecificMessage(e.Diagnostics.Convert_to_template_string),i={name:r,description:a,kind:"refactor.rewrite.string"};function s(n){var t=n.file,s=n.startPosition,l=c(t,s),u=p(l),d={name:r,description:a,actions:[]};return e.isBinaryExpression(u)&&f(u)?(d.actions.push(i),[d]):n.preferences.provideRefactorNotApplicableReason?(d.actions.push(o(o({},i),{notApplicableReason:e.getLocaleSpecificMessage(e.Diagnostics.Can_only_convert_string_concatenation)})),[d]):e.emptyArray}function c(n,t){var r=e.getTokenAtPosition(n,t),a=p(r),i=!f(a);return i&&e.isParenthesizedExpression(a.parent)&&e.isBinaryExpression(a.parent.parent)?a.parent.parent:r}function l(n,t){var r=n.file,i=n.startPosition,o=c(r,i);switch(t){case a:return{edits:u(n,o)};default:return e.Debug.fail("invalid action")}}function u(n,t){var r=p(t),a=n.file,i=h(m(r),a),o=e.getTrailingCommentRanges(a.text,r.end);if(o){var s=o[o.length-1],c={pos:o[0].pos,end:s.end};return e.textChanges.ChangeTracker.with(n,(function(e){e.deleteRange(a,c),e.replaceNode(a,r,i)}))}return e.textChanges.ChangeTracker.with(n,(function(e){return e.replaceNode(a,r,i)}))}function d(e){return 62!==e.operatorToken.kind}function p(n){var t=e.findAncestor(n.parent,(function(n){switch(n.kind){case 202:case 203:return!1;case 219:case 217:return!(e.isBinaryExpression(n.parent)&&d(n.parent));default:return"quit"}}));return t||n}function f(e){var n=m(e),t=n.containsString,r=n.areOperatorsValid;return t&&r}function m(n){if(e.isBinaryExpression(n)){var t=m(n.left),r=t.nodes,a=t.operators,i=t.containsString,o=t.areOperatorsValid;if(!i&&!e.isStringLiteral(n.right)&&!e.isTemplateExpression(n.right))return{nodes:[n],operators:[],containsString:!1,areOperatorsValid:!0};var s=39===n.operatorToken.kind,c=o&&s;return r.push(n.right),a.push(n.operatorToken),{nodes:r,operators:a,containsString:!0,areOperatorsValid:c}}return{nodes:[n],operators:[],containsString:e.isStringLiteral(n),areOperatorsValid:!0}}n.registerRefactor(r,{kinds:[i.kind],getEditsForAction:l,getAvailableActions:s});var _=function(n,t){return function(r,a){r<n.length&&e.copyTrailingComments(n[r],a,t,3,!1)}},g=function(n,t,r){return function(a,i){while(a.length>0){var o=a.shift();e.copyTrailingComments(n[o],i,t,3,!1),r(o,i)}}};function y(n,t){var r=[],a="";while(n<t.length){var i=t[n];if(!e.isStringLiteralLike(i)){if(e.isTemplateExpression(i)){a+=i.head.text;break}break}a+=i.text,r.push(n),n++}return[n,a,r]}function h(n,t){var r=n.nodes,a=n.operators,i=_(a,t),o=g(r,t,i),s=y(0,r),c=s[0],l=s[1],u=s[2];if(c===r.length){var d=e.factory.createNoSubstitutionTemplateLiteral(l);return o(u,d),d}var p=[],f=e.factory.createTemplateHead(l);o(u,f);for(var m,h=function(n){var t=b(r[n]);i(n,t);var a=y(n+1,r),s=a[0],c=a[1],l=a[2];n=s-1;var u=n===r.length-1;if(e.isTemplateExpression(t)){var d=e.map(t.templateSpans,(function(n,r){v(n);var a=t.templateSpans[r+1],i=n.literal.text+(a?"":c);return e.factory.createTemplateSpan(n.expression,u?e.factory.createTemplateTail(i):e.factory.createTemplateMiddle(i))}));p.push.apply(p,d)}else{var f=u?e.factory.createTemplateTail(c):e.factory.createTemplateMiddle(c);o(l,f),p.push(e.factory.createTemplateSpan(t,f))}m=n},E=c;E<r.length;E++)h(E),E=m;return e.factory.createTemplateExpression(f,p)}function v(n){var t=n.getSourceFile();e.copyTrailingComments(n,n.expression,t,3,!1),e.copyTrailingAsLeadingComments(n.expression,n.expression,t,3,!1)}function b(n){return e.isParenthesizedExpression(n)&&(v(n),n=n.expression),n}})(n.convertStringOrTemplateLiteral||(n.convertStringOrTemplateLiteral={}))})(e.refactor||(e.refactor={}))}(d||(d={})),function(e){(function(n){(function(t){var r="Convert arrow function or function expression",a=e.getLocaleSpecificMessage(e.Diagnostics.Convert_arrow_function_or_function_expression),i={name:"Convert to anonymous function",description:e.getLocaleSpecificMessage(e.Diagnostics.Convert_to_anonymous_function),kind:"refactor.rewrite.function.anonymous"},s={name:"Convert to named function",description:e.getLocaleSpecificMessage(e.Diagnostics.Convert_to_named_function),kind:"refactor.rewrite.function.named"},c={name:"Convert to arrow function",description:e.getLocaleSpecificMessage(e.Diagnostics.Convert_to_arrow_function),kind:"refactor.rewrite.function.arrow"};function l(t){var l=t.file,u=t.startPosition,d=t.program,f=t.kind,m=p(l,u,d);if(!m)return e.emptyArray;var _=m.selectedVariableDeclaration,g=m.func,y=[],h=[];if(n.refactorKindBeginsWith(s.kind,f)){var v=_||e.isArrowFunction(g)&&e.isVariableDeclaration(g.parent)?void 0:e.getLocaleSpecificMessage(e.Diagnostics.Could_not_convert_to_named_function);v?h.push(o(o({},s),{notApplicableReason:v})):y.push(s)}if(n.refactorKindBeginsWith(i.kind,f)){v=!_&&e.isArrowFunction(g)?void 0:e.getLocaleSpecificMessage(e.Diagnostics.Could_not_convert_to_anonymous_function);v?h.push(o(o({},i),{notApplicableReason:v})):y.push(i)}if(n.refactorKindBeginsWith(c.kind,f)){v=e.isFunctionExpression(g)?void 0:e.getLocaleSpecificMessage(e.Diagnostics.Could_not_convert_to_arrow_function);v?h.push(o(o({},c),{notApplicableReason:v})):y.push(c)}return[{name:r,description:a,actions:0===y.length&&t.preferences.provideRefactorNotApplicableReason?h:y}]}function u(n,t){var r=n.file,a=n.startPosition,o=n.program,l=p(r,a,o);if(l){var u=l.func,d=[];switch(t){case i.name:d.push.apply(d,y(n,u));break;case s.name:var f=g(u);if(!f)return;d.push.apply(d,h(n,u,f));break;case c.name:if(!e.isFunctionExpression(u))return;d.push.apply(d,v(n,u));break;default:return e.Debug.fail("invalid action")}return{renameFilename:void 0,renameLocation:void 0,edits:d}}}function d(n){var t=!1;return n.forEachChild((function n(r){e.isThis(r)?t=!0:e.isClassLike(r)||e.isFunctionDeclaration(r)||e.isFunctionExpression(r)||e.forEachChild(r,n)})),t}function p(n,t,r){var a=e.getTokenAtPosition(n,t),i=r.getTypeChecker(),o=m(n,i,a.parent);if(o&&!d(o.body))return{selectedVariableDeclaration:!0,func:o};var s=e.getContainingFunction(a);if(s&&(e.isFunctionExpression(s)||e.isArrowFunction(s))&&!e.rangeContainsRange(s.body,a)&&!d(s.body)){if(e.isFunctionExpression(s)&&E(n,i,s))return;return{selectedVariableDeclaration:!1,func:s}}}function f(n){return e.isVariableDeclaration(n)||e.isVariableDeclarationList(n)&&1===n.declarations.length}function m(n,t,r){if(f(r)){var a=e.isVariableDeclaration(r)?r:e.first(r.declarations),i=a.initializer;return i&&(e.isArrowFunction(i)||e.isFunctionExpression(i)&&!E(n,t,i))?i:void 0}}function _(n){return e.isExpression(n)?e.factory.createBlock([e.factory.createReturnStatement(n)],!0):n}function g(n){var t=n.parent;if(e.isVariableDeclaration(t)&&e.isVariableDeclarationInVariableStatement(t)){var r=t.parent,a=r.parent;if(e.isVariableDeclarationList(r)&&e.isVariableStatement(a)&&e.isIdentifier(t.name))return{variableDeclaration:t,variableDeclarationList:r,statement:a,name:t.name}}}function y(n,t){var r=n.file,a=_(t.body),i=e.factory.createFunctionExpression(t.modifiers,t.asteriskToken,void 0,t.typeParameters,t.parameters,t.type,a);return e.textChanges.ChangeTracker.with(n,(function(e){return e.replaceNode(r,t,i)}))}function h(n,t,r){var a=n.file,i=_(t.body),o=r.variableDeclaration,s=r.variableDeclarationList,c=r.statement,l=r.name;e.suppressLeadingTrivia(c);var u=1&e.getCombinedModifierFlags(o)|e.getEffectiveModifierFlags(t),d=e.factory.createModifiersFromModifierFlags(u),p=e.factory.createFunctionDeclaration(t.decorators,e.length(d)?d:void 0,t.asteriskToken,l,t.typeParameters,t.parameters,t.type,i);return 1===s.declarations.length?e.textChanges.ChangeTracker.with(n,(function(e){return e.replaceNode(a,c,p)})):e.textChanges.ChangeTracker.with(n,(function(e){e.delete(a,o),e.insertNodeAfter(a,c,p)}))}function v(n,t){var r,a=n.file,i=t.body.statements,o=i[0];b(t.body,o)?(r=o.expression,e.suppressLeadingAndTrailingTrivia(r),e.copyComments(o,r)):r=t.body;var s=e.factory.createArrowFunction(t.modifiers,t.typeParameters,t.parameters,t.type,e.factory.createToken(38),r);return e.textChanges.ChangeTracker.with(n,(function(e){return e.replaceNode(a,t,s)}))}function b(n,t){return 1===n.statements.length&&e.isReturnStatement(t)&&!!t.expression}function E(n,t,r){return!!r.name&&e.FindAllReferences.Core.isSymbolReferencedInFile(r.name,t,n)}n.registerRefactor(r,{kinds:[i.kind,s.kind,c.kind],getEditsForAction:u,getAvailableActions:l})})(n.convertArrowFunctionOrFunctionExpression||(n.convertArrowFunctionOrFunctionExpression={}))})(e.refactor||(e.refactor={}))}(d||(d={})),function(e){(function(n){(function(t){var r="Infer function return type",a=e.Diagnostics.Infer_function_return_type.message,i={name:r,description:a,kind:"refactor.rewrite.function.returnType"};function s(t){var r=u(t);if(r&&!n.isRefactorErrorInfo(r)){var a=e.textChanges.ChangeTracker.with(t,(function(e){return l(t.file,e,r.declaration,r.returnTypeNode)}));return{renameFilename:void 0,renameLocation:void 0,edits:a}}}function c(t){var s=u(t);return s?n.isRefactorErrorInfo(s)?t.preferences.provideRefactorNotApplicableReason?[{name:r,description:a,actions:[o(o({},i),{notApplicableReason:s.error})]}]:e.emptyArray:[{name:r,description:a,actions:[i]}]:e.emptyArray}function l(n,t,r,a){var i=e.findChildOfKind(r,21,n),o=e.isArrowFunction(r)&&void 0===i,s=o?e.first(r.parameters):i;s&&(o&&(t.insertNodeBefore(n,s,e.factory.createToken(20)),t.insertNodeAfter(n,s,e.factory.createToken(21))),t.insertNodeAt(n,s.end,a,{prefix:": "}))}function u(t){if(!e.isInJSFile(t.file)&&n.refactorKindBeginsWith(i.kind,t.kind)){var r=e.getTokenAtPosition(t.file,t.startPosition),a=e.findAncestor(r,(function(n){return e.isBlock(n)||n.parent&&e.isArrowFunction(n.parent)&&(38===n.kind||n.parent.body===n)?"quit":d(n)}));if(!a||!a.body||a.type)return{error:e.getLocaleSpecificMessage(e.Diagnostics.Return_type_must_be_inferred_from_a_function)};var o=t.program.getTypeChecker(),s=p(o,a);if(!s)return{error:e.getLocaleSpecificMessage(e.Diagnostics.Could_not_determine_function_return_type)};var c=o.typeToTypeNode(s,a,1);return c?{declaration:a,returnTypeNode:c}:void 0}}function d(e){switch(e.kind){case 252:case 209:case 210:case 166:return!0;default:return!1}}function p(n,t){if(n.isImplementationOfOverload(t)){var r=n.getTypeAtLocation(t).getCallSignatures();if(r.length>1)return n.getUnionType(e.mapDefined(r,(function(e){return e.getReturnType()})))}var a=n.getSignatureFromDeclaration(t);if(a)return n.getReturnTypeOfSignature(a)}n.registerRefactor(r,{kinds:[i.kind],getEditsForAction:s,getAvailableActions:c})})(n.inferFunctionReturnType||(n.inferFunctionReturnType={}))})(e.refactor||(e.refactor={}))}(d||(d={})),function(e){function n(n,r,a,i){var o=e.isNodeKind(n)?new t(n,r,a):78===n?new f(78,r,a):79===n?new m(79,r,a):new p(n,r,a);return o.parent=i,o.flags=25358336&i.flags,o}e.servicesVersion="0.8";var t=function(){function n(e,n,t){this.pos=n,this.end=t,this.flags=0,this.modifierFlagsCache=0,this.transformFlags=0,this.parent=void 0,this.kind=e}return n.prototype.assertHasRealPosition=function(n){e.Debug.assert(!e.positionIsSynthesized(this.pos)&&!e.positionIsSynthesized(this.end),n||"Node must have a real position for this operation")},n.prototype.getSourceFile=function(){return e.getSourceFileOfNode(this)},n.prototype.getStart=function(n,t){return this.assertHasRealPosition(),e.getTokenPosOfNode(this,n,t)},n.prototype.getFullStart=function(){return this.assertHasRealPosition(),this.pos},n.prototype.getEnd=function(){return this.assertHasRealPosition(),this.end},n.prototype.getWidth=function(e){return this.assertHasRealPosition(),this.getEnd()-this.getStart(e)},n.prototype.getFullWidth=function(){return this.assertHasRealPosition(),this.end-this.pos},n.prototype.getLeadingTriviaWidth=function(e){return this.assertHasRealPosition(),this.getStart(e)-this.pos},n.prototype.getFullText=function(e){return this.assertHasRealPosition(),(e||this.getSourceFile()).text.substring(this.pos,this.end)},n.prototype.getText=function(e){return this.assertHasRealPosition(),e||(e=this.getSourceFile()),e.text.substring(this.getStart(e),this.getEnd())},n.prototype.getChildCount=function(e){return this.getChildren(e).length},n.prototype.getChildAt=function(e,n){return this.getChildren(n)[e]},n.prototype.getChildren=function(e){return this.assertHasRealPosition("Node without a real position cannot be scanned and thus has no token nodes - use forEachChild and collect the result if that's fine"),this._children||(this._children=a(this,e))},n.prototype.getFirstToken=function(n){this.assertHasRealPosition();var t=this.getChildren(n);if(t.length){var r=e.find(t,(function(e){return e.kind<302||e.kind>337}));return r.kind<158?r:r.getFirstToken(n)}},n.prototype.getLastToken=function(n){this.assertHasRealPosition();var t=this.getChildren(n),r=e.lastOrUndefined(t);if(r)return r.kind<158?r:r.getLastToken(n)},n.prototype.forEachChild=function(n,t){return e.forEachChild(this,n,t)},n}();function a(n,t){if(!e.isNodeKind(n.kind))return e.emptyArray;var r=[];if(e.isJSDocCommentContainingNode(n))return n.forEachChild((function(e){r.push(e)})),r;e.scanner.setText((t||n.getSourceFile()).text);var a=n.pos,i=function(e){s(r,a,e.pos,n),r.push(e),a=e.end},o=function(e){s(r,a,e.pos,n),r.push(c(e,n)),a=e.end};return e.forEach(n.jsDoc,i),a=n.pos,n.forEachChild(i,o),s(r,a,n.end,n),e.scanner.setText(void 0),r}function s(t,r,a,i){e.scanner.setTextPos(r);while(r<a){var o=e.scanner.scan(),s=e.scanner.getTextPos();if(s<=a&&(78===o&&e.Debug.fail("Did not expect "+e.Debug.formatSyntaxKind(i.kind)+" to have an Identifier in its trivia"),t.push(n(o,r,s,i))),r=s,1===o)break}}function c(e,t){var r=n(338,e.pos,e.end,t);r._children=[];for(var a=e.pos,i=0,o=e;i<o.length;i++){var c=o[i];s(r._children,a,c.pos,t),r._children.push(c),a=c.end}return s(r._children,a,e.end,t),r}var l=function(){function n(e,n){this.pos=e,this.end=n,this.flags=0,this.modifierFlagsCache=0,this.transformFlags=0,this.parent=void 0}return n.prototype.getSourceFile=function(){return e.getSourceFileOfNode(this)},n.prototype.getStart=function(n,t){return e.getTokenPosOfNode(this,n,t)},n.prototype.getFullStart=function(){return this.pos},n.prototype.getEnd=function(){return this.end},n.prototype.getWidth=function(e){return this.getEnd()-this.getStart(e)},n.prototype.getFullWidth=function(){return this.end-this.pos},n.prototype.getLeadingTriviaWidth=function(e){return this.getStart(e)-this.pos},n.prototype.getFullText=function(e){return(e||this.getSourceFile()).text.substring(this.pos,this.end)},n.prototype.getText=function(e){return e||(e=this.getSourceFile()),e.text.substring(this.getStart(e),this.getEnd())},n.prototype.getChildCount=function(){return 0},n.prototype.getChildAt=function(){},n.prototype.getChildren=function(){return 1===this.kind&&this.jsDoc||e.emptyArray},n.prototype.getFirstToken=function(){},n.prototype.getLastToken=function(){},n.prototype.forEachChild=function(){},n}(),d=function(){function n(e,n){this.flags=e,this.escapedName=n}return n.prototype.getFlags=function(){return this.flags},Object.defineProperty(n.prototype,"name",{get:function(){return e.symbolName(this)},enumerable:!1,configurable:!0}),n.prototype.getEscapedName=function(){return this.escapedName},n.prototype.getName=function(){return this.name},n.prototype.getDeclarations=function(){return this.declarations},n.prototype.getDocumentationComment=function(n){if(!this.documentationComment)if(this.documentationComment=e.emptyArray,!this.declarations&&this.target&&this.target.tupleLabelDeclaration){var t=this.target.tupleLabelDeclaration;this.documentationComment=v([t],n)}else this.documentationComment=v(this.declarations,n);return this.documentationComment},n.prototype.getContextualDocumentationComment=function(n,t){switch(null===n||void 0===n?void 0:n.kind){case 168:return this.contextualGetAccessorDocumentationComment||(this.contextualGetAccessorDocumentationComment=e.emptyArray,this.contextualGetAccessorDocumentationComment=v(e.filter(this.declarations,e.isGetAccessor),t)),this.contextualGetAccessorDocumentationComment;case 169:return this.contextualSetAccessorDocumentationComment||(this.contextualSetAccessorDocumentationComment=e.emptyArray,this.contextualSetAccessorDocumentationComment=v(e.filter(this.declarations,e.isSetAccessor),t)),this.contextualSetAccessorDocumentationComment;default:return this.getDocumentationComment(t)}},n.prototype.getJsDocTags=function(n){return void 0===this.tags&&(this.tags=e.JsDoc.getJsDocTagsFromDeclarations(this.declarations,n)),this.tags},n}(),p=function(e){function n(n,t,r){var a=e.call(this,t,r)||this;return a.kind=n,a}return u(n,e),n}(l),f=function(n){function t(e,t,r){var a=n.call(this,t,r)||this;return a.kind=78,a}return u(t,n),Object.defineProperty(t.prototype,"text",{get:function(){return e.idText(this)},enumerable:!1,configurable:!0}),t}(l);f.prototype.kind=78;var m=function(n){function t(e,t,r){return n.call(this,t,r)||this}return u(t,n),Object.defineProperty(t.prototype,"text",{get:function(){return e.idText(this)},enumerable:!1,configurable:!0}),t}(l);m.prototype.kind=79;var _=function(){function n(e,n){this.checker=e,this.flags=n}return n.prototype.getFlags=function(){return this.flags},n.prototype.getSymbol=function(){return this.symbol},n.prototype.getProperties=function(){return this.checker.getPropertiesOfType(this)},n.prototype.getProperty=function(e){return this.checker.getPropertyOfType(this,e)},n.prototype.getApparentProperties=function(){return this.checker.getAugmentedPropertiesOfType(this)},n.prototype.getCallSignatures=function(){return this.checker.getSignaturesOfType(this,0)},n.prototype.getConstructSignatures=function(){return this.checker.getSignaturesOfType(this,1)},n.prototype.getStringIndexType=function(){return this.checker.getIndexTypeOfType(this,0)},n.prototype.getNumberIndexType=function(){return this.checker.getIndexTypeOfType(this,1)},n.prototype.getBaseTypes=function(){return this.isClassOrInterface()?this.checker.getBaseTypes(this):void 0},n.prototype.isNullableType=function(){return this.checker.isNullableType(this)},n.prototype.getNonNullableType=function(){return this.checker.getNonNullableType(this)},n.prototype.getNonOptionalType=function(){return this.checker.getNonOptionalType(this)},n.prototype.getConstraint=function(){return this.checker.getBaseConstraintOfType(this)},n.prototype.getDefault=function(){return this.checker.getDefaultFromTypeParameter(this)},n.prototype.isUnion=function(){return!!(1048576&this.flags)},n.prototype.isIntersection=function(){return!!(2097152&this.flags)},n.prototype.isUnionOrIntersection=function(){return!!(3145728&this.flags)},n.prototype.isLiteral=function(){return!!(384&this.flags)},n.prototype.isStringLiteral=function(){return!!(128&this.flags)},n.prototype.isNumberLiteral=function(){return!!(256&this.flags)},n.prototype.isTypeParameter=function(){return!!(262144&this.flags)},n.prototype.isClassOrInterface=function(){return!!(3&e.getObjectFlags(this))},n.prototype.isClass=function(){return!!(1&e.getObjectFlags(this))},Object.defineProperty(n.prototype,"typeArguments",{get:function(){if(4&e.getObjectFlags(this))return this.checker.getTypeArguments(this)},enumerable:!1,configurable:!0}),n}(),g=function(){function n(e,n){this.checker=e,this.flags=n}return n.prototype.getDeclaration=function(){return this.declaration},n.prototype.getTypeParameters=function(){return this.typeParameters},n.prototype.getParameters=function(){return this.parameters},n.prototype.getReturnType=function(){return this.checker.getReturnTypeOfSignature(this)},n.prototype.getDocumentationComment=function(){return this.documentationComment||(this.documentationComment=v(e.singleElementArray(this.declaration),this.checker))},n.prototype.getJsDocTags=function(){return void 0===this.jsDocTags&&(this.jsDocTags=this.declaration?h(this.declaration,this.checker):[]),this.jsDocTags},n}();function y(n){return e.getJSDocTags(n).some((function(e){return"inheritDoc"===e.tagName.text}))}function h(n,t){var r=e.JsDoc.getJsDocTagsFromDeclarations([n],t);if(0===r.length||y(n)){var a=b(t,n,(function(e){var n;return 1===(null===(n=e.declarations)||void 0===n?void 0:n.length)?e.getJsDocTags():void 0}));a&&(r=i(i([],a),r))}return r}function v(n,t){if(!n)return e.emptyArray;var r=e.JsDoc.getJsDocCommentsFromDeclarations(n,t);if(t&&(0===r.length||n.some(y)))for(var a=new e.Set,i=0,o=n;i<o.length;i++){var s=o[i],c=b(t,s,(function(e){if(!a.has(e))return a.add(e),e.getDocumentationComment(t)}));c&&(r=0===r.length?c.slice():c.concat(e.lineBreakPart(),r))}return r}function b(n,t,r){return e.firstDefined(t.parent?e.getAllSuperTypeNodes(t.parent):e.emptyArray,(function(e){var a=n.getPropertyOfType(n.getTypeAtLocation(e),t.symbol.name);return a?r(a):void 0}))}var E=function(n){function t(e,t,r){var a=n.call(this,e,t,r)||this;return a.kind=298,a}return u(t,n),t.prototype.update=function(n,t){return e.updateSourceFile(this,n,t)},t.prototype.getLineAndCharacterOfPosition=function(n){return e.getLineAndCharacterOfPosition(this,n)},t.prototype.getLineStarts=function(){return e.getLineStarts(this)},t.prototype.getPositionOfLineAndCharacter=function(n,t,r){return e.computePositionOfLineAndCharacter(e.getLineStarts(this),n,t,this.text,r)},t.prototype.getLineEndOfPosition=function(e){var n,t=this.getLineAndCharacterOfPosition(e).line,r=this.getLineStarts();t+1>=r.length&&(n=this.getEnd()),n||(n=r[t+1]-1);var a=this.getFullText();return"\n"===a[n]&&"\r"===a[n-1]?n-1:n},t.prototype.getNamedDeclarations=function(){return this.namedDeclarations||(this.namedDeclarations=this.computeNamedDeclarations()),this.namedDeclarations},t.prototype.computeNamedDeclarations=function(){var n=e.createMultiMap();return this.forEachChild(i),n;function t(e){var t=a(e);t&&n.add(t,e)}function r(e){var t=n.get(e);return t||n.set(e,t=[]),t}function a(n){var t=e.getNonAssignedNameOfDeclaration(n);return t&&(e.isComputedPropertyName(t)&&e.isPropertyAccessExpression(t.expression)?t.expression.name.text:e.isPropertyName(t)?e.getNameFromPropertyName(t):void 0)}function i(n){switch(n.kind){case 252:case 209:case 166:case 165:var o=n,s=a(o);if(s){var c=r(s),l=e.lastOrUndefined(c);l&&o.parent===l.parent&&o.symbol===l.symbol?o.body&&!l.body&&(c[c.length-1]=o):c.push(o)}e.forEachChild(n,i);break;case 253:case 222:case 254:case 255:case 256:case 257:case 261:case 271:case 266:case 263:case 264:case 168:case 169:case 178:t(n),e.forEachChild(n,i);break;case 161:if(!e.hasSyntacticModifier(n,16476))break;case 250:case 199:var u=n;if(e.isBindingPattern(u.name)){e.forEachChild(u.name,i);break}u.initializer&&i(u.initializer);case 292:case 164:case 163:t(n);break;case 268:var d=n;d.exportClause&&(e.isNamedExports(d.exportClause)?e.forEach(d.exportClause.elements,i):i(d.exportClause.name));break;case 262:var p=n.importClause;p&&(p.name&&t(p.name),p.namedBindings&&(264===p.namedBindings.kind?t(p.namedBindings):e.forEach(p.namedBindings.elements,i)));break;case 217:0!==e.getAssignmentDeclarationKind(n)&&t(n);default:e.forEachChild(n,i)}}},t}(t),T=function(){function n(e,n,t){this.fileName=e,this.text=n,this.skipTrivia=t}return n.prototype.getLineAndCharacterOfPosition=function(n){return e.getLineAndCharacterOfPosition(this,n)},n}();function S(){return{getNodeConstructor:function(){return t},getTokenConstructor:function(){return p},getIdentifierConstructor:function(){return f},getPrivateIdentifierConstructor:function(){return m},getSourceFileConstructor:function(){return E},getSymbolConstructor:function(){return d},getTypeConstructor:function(){return _},getSignatureConstructor:function(){return g},getSourceMapSourceConstructor:function(){return T}}}function x(n){var t=!0;for(var r in n)if(e.hasProperty(n,r)&&!L(r)){t=!1;break}if(t)return n;var a={};for(var r in n)if(e.hasProperty(n,r)){var i=L(r)?r:r.charAt(0).toLowerCase()+r.substr(1);a[i]=n[r]}return a}function L(e){return!e.length||e.charAt(0)===e.charAt(0).toLowerCase()}function D(n){return n?e.map(n,(function(e){return e.text})).join(""):""}function A(){return{target:1,jsx:1}}function C(){return e.codefix.getSupportedErrorCodes()}e.toEditorSettings=x,e.displayPartsToString=D,e.getDefaultCompilerOptions=A,e.getSupportedCodeFixes=C;var I=function(){function n(n,t){this.host=n,this.currentDirectory=n.getCurrentDirectory(),this.fileNameToEntry=new e.Map;for(var r=n.getScriptFileNames(),a=0,i=r;a<i.length;a++){var o=i[a];this.createEntry(o,e.toPath(o,this.currentDirectory,t))}}return n.prototype.createEntry=function(n,t){var r,a=this.host.getScriptSnapshot(n);return r=a?{hostFileName:n,version:this.host.getScriptVersion(n),scriptSnapshot:a,scriptKind:e.getScriptKind(n,this.host)}:n,this.fileNameToEntry.set(t,r),r},n.prototype.getEntryByPath=function(e){return this.fileNameToEntry.get(e)},n.prototype.getHostFileInformation=function(n){var t=this.fileNameToEntry.get(n);return e.isString(t)?void 0:t},n.prototype.getOrCreateEntryByPath=function(n,t){var r=this.getEntryByPath(t)||this.createEntry(n,t);return e.isString(r)?void 0:r},n.prototype.getRootFileNames=function(){var n=[];return this.fileNameToEntry.forEach((function(t){e.isString(t)?n.push(t):n.push(t.hostFileName)})),n},n.prototype.getScriptSnapshot=function(e){var n=this.getHostFileInformation(e);return n&&n.scriptSnapshot},n}(),N=function(){function n(e){this.host=e}return n.prototype.getCurrentSourceFile=function(n){var t=this.host.getScriptSnapshot(n);if(!t)throw new Error("Could not find file: '"+n+"'.");var r,a=e.getScriptKind(n,this.host),i=this.host.getScriptVersion(n);if(this.currentFileName!==n)r=R(n,t,99,i,!0,a);else if(this.currentFileVersion!==i){var o=t.getChangeRange(this.currentFileScriptSnapshot);r=O(this.currentSourceFile,t,i,o)}return r&&(this.currentFileVersion=i,this.currentFileName=n,this.currentFileScriptSnapshot=t,this.currentSourceFile=r),this.currentSourceFile},n}();function k(e,n,t){e.version=t,e.scriptSnapshot=n}function R(n,t,r,a,i,o){var s=e.createSourceFile(n,e.getSnapshotText(t),r,i,o);return k(s,t,a),s}function O(n,t,r,a,i){if(a&&r!==n.version){var o=void 0,s=0!==a.span.start?n.text.substr(0,a.span.start):"",c=e.textSpanEnd(a.span)!==n.text.length?n.text.substr(e.textSpanEnd(a.span)):"";if(0===a.newLength)o=s&&c?s+c:s||c;else{var l=t.getText(a.span.start,a.span.start+a.newLength);o=s&&c?s+l+c:s?s+l:l+c}var u=e.updateSourceFile(n,o,a,i);return k(u,t,r),u.nameTable=void 0,n!==u&&n.scriptSnapshot&&(n.scriptSnapshot.dispose&&n.scriptSnapshot.dispose(),n.scriptSnapshot=void 0),u}return R(n.fileName,t,n.languageVersion,r,!0,n.scriptKind)}e.createLanguageServiceSourceFile=R,e.updateLanguageServiceSourceFile=O;var w={isCancellationRequested:e.returnFalse,throwIfCancellationRequested:e.noop},P=function(){function n(e){this.cancellationToken=e}return n.prototype.isCancellationRequested=function(){return this.cancellationToken.isCancellationRequested()},n.prototype.throwIfCancellationRequested=function(){if(this.isCancellationRequested())throw null===e.tracing||void 0===e.tracing||e.tracing.instant("session","cancellationThrown",{kind:"CancellationTokenObject"}),new e.OperationCanceledException},n}(),M=function(){function n(e,n){void 0===n&&(n=20),this.hostCancellationToken=e,this.throttleWaitMilliseconds=n,this.lastCancellationCheckTime=0}return n.prototype.isCancellationRequested=function(){var n=e.timestamp(),t=Math.abs(n-this.lastCancellationCheckTime);return t>=this.throttleWaitMilliseconds&&(this.lastCancellationCheckTime=n,this.hostCancellationToken.isCancellationRequested())},n.prototype.throwIfCancellationRequested=function(){if(this.isCancellationRequested())throw null===e.tracing||void 0===e.tracing||e.tracing.instant("session","cancellationThrown",{kind:"ThrottledCancellationToken"}),new e.OperationCanceledException},n}();e.ThrottledCancellationToken=M;var F=["getSyntacticDiagnostics","getSemanticDiagnostics","getSuggestionDiagnostics","getCompilerOptionsDiagnostics","getSemanticClassifications","getEncodedSemanticClassifications","getCodeFixesAtPosition","getCombinedCodeFix","applyCodeActionCommand","organizeImports","getEditsForFileRename","getEmitOutput","getApplicableRefactors","getEditsForRefactor","prepareCallHierarchy","provideCallHierarchyIncomingCalls","provideCallHierarchyOutgoingCalls"],G=i(i([],F),["getCompletionsAtPosition","getCompletionEntryDetails","getCompletionEntrySymbol","getSignatureHelpItems","getQuickInfoAtPosition","getDefinitionAtPosition","getDefinitionAndBoundSpan","getImplementationAtPosition","getTypeDefinitionAtPosition","getReferencesAtPosition","findReferences","getOccurrencesAtPosition","getDocumentHighlights","getNavigateToItems","getRenameInfo","findRenameLocations","getApplicableRefactors"]);function B(n,t,r){var a,s;void 0===t&&(t=e.createDocumentRegistry(n.useCaseSensitiveFileNames&&n.useCaseSensitiveFileNames(),n.getCurrentDirectory())),s=void 0===r?e.LanguageServiceMode.Semantic:"boolean"===typeof r?r?e.LanguageServiceMode.Syntactic:e.LanguageServiceMode.Semantic:r;var c,l,u=new N(n),d=0,p=n.getCancellationToken?new P(n.getCancellationToken()):w,f=n.getCurrentDirectory();function m(e){n.log&&n.log(e)}!e.localizedDiagnosticMessages&&n.getLocalizedDiagnosticMessages&&e.setLocalizedDiagnosticMessages(n.getLocalizedDiagnosticMessages());var _=e.hostUsesCaseSensitiveFileNames(n),g=e.createGetCanonicalFileName(_),y=e.getSourceMapper({useCaseSensitiveFileNames:function(){return _},getCurrentDirectory:function(){return f},getProgram:b,fileExists:e.maybeBind(n,n.fileExists),readFile:e.maybeBind(n,n.readFile),getDocumentPositionMapper:e.maybeBind(n,n.getDocumentPositionMapper),getSourceFileLike:e.maybeBind(n,n.getSourceFileLike),log:m});function h(e){var n=c.getSourceFile(e);if(!n){var t=new Error("Could not find source file: '"+e+"'.");throw t.ProgramFiles=c.getSourceFiles().map((function(e){return e.fileName})),t}return n}function v(){var r,a,i;if(e.Debug.assert(s!==e.LanguageServiceMode.Syntactic),n.getProjectVersion){var o=n.getProjectVersion();if(o){if(l===o&&!(null===(r=n.hasChangedAutomaticTypeDirectiveNames)||void 0===r?void 0:r.call(n)))return;l=o}}var u=n.getTypeRootsVersion?n.getTypeRootsVersion():0;d!==u&&(m("TypeRoots version has changed; provide new program"),c=void 0,d=u);var h,v=new I(n,g),b=v.getRootFileNames(),E=n.getCompilationSettings()||A(),T=n.hasInvalidatedResolution||e.returnFalse,S=e.maybeBind(n,n.hasChangedAutomaticTypeDirectiveNames),x=null===(a=n.getProjectReferences)||void 0===a?void 0:a.call(n),L={useCaseSensitiveFileNames:_,fileExists:w,readFile:P,readDirectory:M,trace:e.maybeBind(n,n.trace),getCurrentDirectory:function(){return f},onUnRecoverableConfigFileDiagnostic:e.noop};if(!e.isProgramUptoDate(c,b,E,(function(e,t){return n.getScriptVersion(t)}),w,T,S,k,x)){var D={getSourceFile:G,getSourceFileByPath:B,getCancellationToken:function(){return p},getCanonicalFileName:g,useCaseSensitiveFileNames:function(){return _},getNewLine:function(){return e.getNewLineCharacter(E,(function(){return e.getNewLineOrDefaultFromHost(n)}))},getDefaultLibFileName:function(e){return n.getDefaultLibFileName(e)},writeFile:e.noop,getCurrentDirectory:function(){return f},fileExists:w,readFile:P,getSymlinkCache:e.maybeBind(n,n.getSymlinkCache),realpath:e.maybeBind(n,n.realpath),directoryExists:function(t){return e.directoryProbablyExists(t,n)},getDirectories:function(e){return n.getDirectories?n.getDirectories(e):[]},readDirectory:M,onReleaseOldSourceFile:F,onReleaseParsedCommandLine:O,hasInvalidatedResolution:T,hasChangedAutomaticTypeDirectiveNames:S,trace:L.trace,resolveModuleNames:e.maybeBind(n,n.resolveModuleNames),resolveTypeReferenceDirectives:e.maybeBind(n,n.resolveTypeReferenceDirectives),useSourceOfProjectReferenceRedirect:e.maybeBind(n,n.useSourceOfProjectReferenceRedirect),getParsedCommandLine:k};null===(i=n.setCompilerHost)||void 0===i||i.call(n,D);var C=t.getKeyForCompilationSettings(E),N={rootNames:b,options:E,host:D,oldProgram:c,projectReferences:x};return c=e.createProgram(N),v=void 0,h=void 0,y.clearCache(),void c.getTypeChecker()}function k(t){var r=e.toPath(t,f,g),a=null===h||void 0===h?void 0:h.get(r);if(void 0!==a)return a||void 0;var i=n.getParsedCommandLine?n.getParsedCommandLine(t):R(t);return(h||(h=new e.Map)).set(r,i||!1),i}function R(n){var t=G(n,100);if(t)return t.path=e.toPath(n,f,g),t.resolvedPath=t.path,t.originalFileName=t.fileName,e.parseJsonSourceFileConfigFileContent(t,L,e.getNormalizedAbsolutePath(e.getDirectoryPath(n),f),void 0,e.getNormalizedAbsolutePath(n,f))}function O(e,t,r){var a;n.getParsedCommandLine?null===(a=n.onReleaseParsedCommandLine)||void 0===a||a.call(n,e,t,r):t&&F(t.sourceFile,r)}function w(t){var r=e.toPath(t,f,g),a=v&&v.getEntryByPath(r);return a?!e.isString(a):!!n.fileExists&&n.fileExists(t)}function P(t){var r=e.toPath(t,f,g),a=v&&v.getEntryByPath(r);return a?e.isString(a)?void 0:e.getSnapshotText(a.scriptSnapshot):n.readFile&&n.readFile(t)}function M(t,r,a,i,o){return e.Debug.checkDefined(n.readDirectory,"'LanguageServiceHost.readDirectory' must be implemented to correctly process 'projectReferences'"),n.readDirectory(t,r,a,i,o)}function F(e,n){var r=t.getKeyForCompilationSettings(n);t.releaseDocumentWithKey(e.resolvedPath,r,e.scriptKind)}function G(n,t,r,a){return B(n,e.toPath(n,f,g),t,r,a)}function B(n,r,a,i,o){e.Debug.assert(void 0!==v,"getOrCreateSourceFileByPath called after typical CompilerHost lifetime, check the callstack something with a reference to an old host.");var s=v&&v.getOrCreateEntryByPath(n,r);if(s){if(!o){var l=c&&c.getSourceFileByPath(r);if(l){if(s.scriptKind===l.scriptKind)return t.updateDocumentWithKey(n,r,E,C,s.scriptSnapshot,s.version,s.scriptKind);t.releaseDocumentWithKey(l.resolvedPath,t.getKeyForCompilationSettings(c.getCompilerOptions()),l.scriptKind)}}return t.acquireDocumentWithKey(n,r,E,C,s.scriptSnapshot,s.version,s.scriptKind)}}}function b(){if(s!==e.LanguageServiceMode.Syntactic)return v(),c;e.Debug.assert(void 0===c)}function E(){var e;return null===(e=n.getPackageJsonAutoImportProvider)||void 0===e?void 0:e.call(n)}function T(){c=void 0}function S(){if(c){var r=t.getKeyForCompilationSettings(c.getCompilerOptions());e.forEach(c.getSourceFiles(),(function(e){return t.releaseDocumentWithKey(e.resolvedPath,r,e.scriptKind)})),c=void 0}n=void 0}function L(e){return v(),c.getSyntacticDiagnostics(h(e),p).slice()}function D(n){v();var t=h(n),r=c.getSemanticDiagnostics(t,p);if(!e.getEmitDeclarations(c.getCompilerOptions()))return r.slice();var a=c.getDeclarationDiagnostics(t,p);return i(i([],r),a)}function C(n){return v(),e.computeSuggestionDiagnostics(h(n),c,p)}function k(){return v(),i(i([],c.getOptionsDiagnostics(p)),c.getGlobalDiagnostics(p))}function R(t,r,a){void 0===a&&(a=e.emptyOptions);var i=o(o({},e.identity(a)),{includeCompletionsForModuleExports:a.includeCompletionsForModuleExports||a.includeExternalModuleExports,includeCompletionsWithInsertText:a.includeCompletionsWithInsertText||a.includeInsertTextCompletions});return v(),e.Completions.getCompletionsAtPosition(n,c,m,h(t),r,i,a.triggerCharacter)}function O(t,r,a,i,o,s,l){return void 0===s&&(s=e.emptyOptions),v(),e.Completions.getCompletionEntryDetails(c,m,h(t),r,{name:a,source:o,data:l},n,i&&e.formatting.getFormatContext(i,n),s,p)}function M(t,r,a,i,o){return void 0===o&&(o=e.emptyOptions),v(),e.Completions.getCompletionEntrySymbol(c,m,h(t),r,{name:a,source:i},n,o)}function B(n,t){v();var r=h(n),a=e.getTouchingPropertyName(r,t);if(a!==r){var i=c.getTypeChecker(),o=U(a),s=W(o,i);if(!s||i.isUnknownSymbol(s)){var l=V(r,o,t)?i.getTypeAtLocation(o):void 0;return l&&{kind:"",kindModifiers:"",textSpan:e.createTextSpanFromNode(o,r),displayParts:i.runWithCancellationToken(p,(function(n){return e.typeToDisplayParts(n,l,e.getContainerNode(o))})),documentation:l.symbol?l.symbol.getDocumentationComment(i):void 0,tags:l.symbol?l.symbol.getJsDocTags(i):void 0}}var u=i.runWithCancellationToken(p,(function(n){return e.SymbolDisplay.getSymbolDisplayPartsDocumentationAndSymbolKind(n,s,r,e.getContainerNode(o),o)})),d=u.symbolKind,f=u.displayParts,m=u.documentation,_=u.tags;return{kind:d,kindModifiers:e.SymbolDisplay.getSymbolModifiers(i,s),textSpan:e.createTextSpanFromNode(o,r),displayParts:f,documentation:m,tags:_}}}function U(n){return e.isNewExpression(n.parent)&&n.pos===n.parent.pos?n.parent.expression:e.isNamedTupleMember(n.parent)&&n.pos===n.parent.pos?n.parent:n}function V(n,t,r){switch(t.kind){case 78:return!e.isLabelName(t)&&!e.isTagName(t)&&!e.isConstTypeReference(t.parent);case 202:case 158:return!e.isInComment(n,r);case 107:case 188:case 105:case 193:return!0;default:return!1}}function j(n,t){return v(),e.GoToDefinition.getDefinitionAtPosition(c,h(n),t)}function K(n,t){return v(),e.GoToDefinition.getDefinitionAndBoundSpan(c,h(n),t)}function H(n,t){return v(),e.GoToDefinition.getTypeDefinitionAtPosition(c.getTypeChecker(),h(n),t)}function z(n,t){return v(),e.FindAllReferences.getImplementationsAtPosition(c,p,c.getSourceFiles(),h(n),t)}function q(n,t){return e.flatMap(J(n,t,[n]),(function(e){return e.highlightSpans.map((function(n){return o(o({fileName:e.fileName,textSpan:n.textSpan,isWriteAccess:"writtenReference"===n.kind,isDefinition:!1},n.isInString&&{isInString:!0}),n.contextSpan&&{contextSpan:n.contextSpan})}))}))}function J(n,t,r){var a=e.normalizePath(n);e.Debug.assert(r.some((function(n){return e.normalizePath(n)===a}))),v();var i=e.mapDefined(r,(function(e){return c.getSourceFile(e)})),o=h(n);return e.DocumentHighlights.getDocumentHighlights(c,p,o,t,i)}function X(n,t,r,a,i){v();var s=h(n),c=e.getAdjustedRenameLocation(e.getTouchingPropertyName(s,t));if(e.isIdentifier(c)&&(e.isJsxOpeningElement(c.parent)||e.isJsxClosingElement(c.parent))&&e.isIntrinsicJsxName(c.escapedText)){var l=c.parent.parent,u=l.openingElement,d=l.closingElement;return[u,d].map((function(n){var t=e.createTextSpanFromNode(n.tagName,s);return o({fileName:s.fileName,textSpan:t},e.FindAllReferences.toContextSpan(t,s,n.parent))}))}return Q(c,t,{findInStrings:r,findInComments:a,providePrefixAndSuffixTextForRename:i,use:2},(function(n,t,r){return e.FindAllReferences.toRenameLocation(n,t,r,i||!1)}))}function Y(n,t){return v(),Q(e.getTouchingPropertyName(h(n),t),t,{use:1},e.FindAllReferences.toReferenceEntry)}function Q(n,t,r,a){v();var i=r&&2===r.use?c.getSourceFiles().filter((function(e){return!c.isSourceFileDefaultLibrary(e)})):c.getSourceFiles();return e.FindAllReferences.findReferenceOrRenameEntries(c,p,i,n,t,r,a)}function Z(n,t){return v(),e.FindAllReferences.findReferencedSymbols(c,p,c.getSourceFiles(),h(n),t)}function $(n){return v(),e.FindAllReferences.Core.getReferencesForFileName(n,c,c.getSourceFiles()).map(e.FindAllReferences.toReferenceEntry)}function ee(n,t,r,a){void 0===a&&(a=!1),v();var i=r?[h(r)]:c.getSourceFiles();return e.NavigateTo.getNavigateToItems(i,c.getTypeChecker(),p,n,t,a)}function ne(t,r,a){v();var i=h(t),o=n.getCustomTransformers&&n.getCustomTransformers();return e.getFileEmitOutput(c,i,!!r,p,o,a)}function te(n,t,r){var a=void 0===r?e.emptyOptions:r,i=a.triggerReason;v();var o=h(n);return e.SignatureHelp.getSignatureHelpItems(c,o,t,i,p)}function re(e){return u.getCurrentSourceFile(e)}function ae(n,t,r){var a=u.getCurrentSourceFile(n),i=e.getTouchingPropertyName(a,t);if(i!==a){switch(i.kind){case 202:case 158:case 10:case 94:case 109:case 103:case 105:case 107:case 188:case 78:break;default:return}var o=i;while(1)if(e.isRightSideOfPropertyAccess(o)||e.isRightSideOfQualifiedName(o))o=o.parent;else{if(!e.isNameOfModuleDeclaration(o))break;if(257!==o.parent.parent.kind||o.parent.parent.body!==o.parent)break;o=o.parent.parent.name}return e.createTextSpanFromBounds(o.getStart(),i.getEnd())}}function ie(n,t){var r=u.getCurrentSourceFile(n);return e.BreakpointResolver.spanInSourceFileAtLocation(r,t)}function oe(n){return e.NavigationBar.getNavigationBarItems(u.getCurrentSourceFile(n),p)}function se(n){return e.NavigationBar.getNavigationTree(u.getCurrentSourceFile(n),p)}function ce(n,t,r){v();var a=r||"original";return"2020"===a?e.classifier.v2020.getSemanticClassifications(c,p,h(n),t):e.getSemanticClassifications(c.getTypeChecker(),p,h(n),c.getClassifiableNames(),t)}function le(n,t,r){v();var a=r||"original";return"original"===a?e.getEncodedSemanticClassifications(c.getTypeChecker(),p,h(n),c.getClassifiableNames(),t):e.classifier.v2020.getEncodedSemanticClassifications(c,p,h(n),t)}function ue(n,t){return e.getSyntacticClassifications(p,u.getCurrentSourceFile(n),t)}function de(n,t){return e.getEncodedSyntacticClassifications(p,u.getCurrentSourceFile(n),t)}function pe(n){var t=u.getCurrentSourceFile(n);return e.OutliningElementsCollector.collectElements(t,p)}var fe=new e.Map(e.getEntries((a={},a[18]=19,a[20]=21,a[22]=23,a[31]=29,a)));function me(n,t){var r=u.getCurrentSourceFile(n),a=e.getTouchingToken(r,t),i=a.getStart(r)===t?fe.get(a.kind.toString()):void 0,o=i&&e.findChildOfKind(a.parent,i,r);return o?[e.createTextSpanFromNode(a,r),e.createTextSpanFromNode(o,r)].sort((function(e,n){return e.start-n.start})):e.emptyArray}function _e(n,t,r){var a=e.timestamp(),i=x(r),o=u.getCurrentSourceFile(n);m("getIndentationAtPosition: getCurrentSourceFile: "+(e.timestamp()-a)),a=e.timestamp();var s=e.formatting.SmartIndenter.getIndentation(t,o,i);return m("getIndentationAtPosition: computeIndentation  : "+(e.timestamp()-a)),s}function ge(t,r,a,i){var o=u.getCurrentSourceFile(t);return e.formatting.formatSelection(r,a,o,e.formatting.getFormatContext(x(i),n))}function ye(t,r){return e.formatting.formatDocument(u.getCurrentSourceFile(t),e.formatting.getFormatContext(x(r),n))}function he(t,r,a,i){var o=u.getCurrentSourceFile(t),s=e.formatting.getFormatContext(x(i),n);if(!e.isInComment(o,r))switch(a){case"{":return e.formatting.formatOnOpeningCurly(r,o,s);case"}":return e.formatting.formatOnClosingCurly(r,o,s);case";":return e.formatting.formatOnSemicolon(r,o,s);case"\n":return e.formatting.formatOnEnter(r,o,s)}return[]}function ve(t,r,a,i,o,s){void 0===s&&(s=e.emptyOptions),v();var l=h(t),u=e.createTextSpanFromBounds(r,a),d=e.formatting.getFormatContext(o,n);return e.flatMap(e.deduplicate(i,e.equateValues,e.compareValues),(function(t){return p.throwIfCancellationRequested(),e.codefix.getFixes({errorCode:t,sourceFile:l,span:u,program:c,host:n,cancellationToken:p,formatContext:d,preferences:s})}))}function be(t,r,a,i){void 0===i&&(i=e.emptyOptions),v(),e.Debug.assert("file"===t.type);var o=h(t.fileName),s=e.formatting.getFormatContext(a,n);return e.codefix.getAllFixes({fixId:r,sourceFile:o,program:c,host:n,cancellationToken:p,formatContext:s,preferences:i})}function Ee(t,r,a){void 0===a&&(a=e.emptyOptions),v(),e.Debug.assert("file"===t.type);var i=h(t.fileName),o=e.formatting.getFormatContext(r,n);return e.OrganizeImports.organizeImports(i,o,n,c,a,t.skipDestructiveCodeActions)}function Te(t,r,a,i){return void 0===i&&(i=e.emptyOptions),e.getEditsForFileRename(b(),t,r,n,e.formatting.getFormatContext(a,n),i,y)}function Se(n,t){var r="string"===typeof n?t:n;return e.isArray(r)?Promise.all(r.map((function(e){return xe(e)}))):xe(r)}function xe(t){var r=function(n){return e.toPath(n,f,g)};return e.Debug.assertEqual(t.type,"install package"),n.installPackage?n.installPackage({fileName:r(t.file),packageName:t.packageName}):Promise.reject("Host does not implement `installPackage`")}function Le(t,r,a){return e.JsDoc.getDocCommentTemplateAtPosition(e.getNewLineOrDefaultFromHost(n),u.getCurrentSourceFile(t),r,a)}function De(n,t,r){if(60===r)return!1;var a=u.getCurrentSourceFile(n);if(e.isInString(a,t))return!1;if(e.isInsideJsxElementOrAttribute(a,t))return 123===r;if(e.isInTemplateString(a,t))return!1;switch(r){case 39:case 34:case 96:return!e.isInComment(a,t)}return!0}function Ae(n,t){var r=u.getCurrentSourceFile(n),a=e.findPrecedingToken(t,r);if(a){var i=31===a.kind&&e.isJsxOpeningElement(a.parent)?a.parent.parent:e.isJsxText(a)?a.parent:void 0;return i&&Oe(i)?{newText:"</"+i.openingElement.tagName.getText(r)+">"}:void 0}}function Ce(e,n){return{lineStarts:e.getLineStarts(),firstLine:e.getLineAndCharacterOfPosition(n.pos).line,lastLine:e.getLineAndCharacterOfPosition(n.end).line}}function Ie(n,t,r){for(var a=u.getCurrentSourceFile(n),i=[],o=Ce(a,t),s=o.lineStarts,c=o.firstLine,l=o.lastLine,d=r||!1,p=Number.MAX_VALUE,f=new e.Map,m=new RegExp(/\S/),_=e.isInsideJsxElement(a,s[c]),g=_?"{/*":"//",y=c;y<=l;y++){var h=a.text.substring(s[y],a.getLineEndOfPosition(s[y])),v=m.exec(h);v&&(p=Math.min(p,v.index),f.set(y.toString(),v.index),h.substr(v.index,g.length)!==g&&(d=void 0===r||r))}for(y=c;y<=l;y++)if(c===l||s[y]!==t.end){var b=f.get(y.toString());void 0!==b&&(_?i.push.apply(i,Ne(n,{pos:s[y]+p,end:a.getLineEndOfPosition(s[y])},d,_)):d?i.push({newText:g,span:{length:0,start:s[y]+p}}):a.text.substr(s[y]+b,g.length)===g&&i.push({newText:"",span:{length:g.length,start:s[y]+b}}))}return i}function Ne(n,t,r,a){var i,o=u.getCurrentSourceFile(n),s=[],c=o.text,l=!1,d=r||!1,p=[],f=t.pos,m=void 0!==a?a:e.isInsideJsxElement(o,f),_=m?"{/*":"/*",g=m?"*/}":"*/",y=m?"\\{\\/\\*":"\\/\\*",h=m?"\\*\\/\\}":"\\*\\/";while(f<=t.end){var v=c.substr(f,_.length)===_?_.length:0,b=e.isInComment(o,f+v);if(b)m&&(b.pos--,b.end++),p.push(b.pos),3===b.kind&&p.push(b.end),l=!0,f=b.end+1;else{var E=c.substring(f,t.end).search("("+y+")|("+h+")");d=void 0!==r?r:d||!e.isTextWhiteSpaceLike(c,f,-1===E?t.end:f+E),f=-1===E?t.end+1:f+E+g.length}}if(d||!l){2!==(null===(i=e.isInComment(o,t.pos))||void 0===i?void 0:i.kind)&&e.insertSorted(p,t.pos,e.compareValues),e.insertSorted(p,t.end,e.compareValues);var T=p[0];c.substr(T,_.length)!==_&&s.push({newText:_,span:{length:0,start:T}});for(var S=1;S<p.length-1;S++)c.substr(p[S]-g.length,g.length)!==g&&s.push({newText:g,span:{length:0,start:p[S]}}),c.substr(p[S],_.length)!==_&&s.push({newText:_,span:{length:0,start:p[S]}});s.length%2!==0&&s.push({newText:g,span:{length:0,start:p[p.length-1]}})}else for(var x=0,L=p;x<L.length;x++){var D=L[x],A=D-g.length>0?D-g.length:0;v=c.substr(A,g.length)===g?g.length:0;s.push({newText:"",span:{length:_.length,start:D-v}})}return s}function ke(e,n){var t=u.getCurrentSourceFile(e),r=Ce(t,n),a=r.firstLine,i=r.lastLine;return a===i&&n.pos!==n.end?Ne(e,n,!0):Ie(e,n,!0)}function Re(n,t){var r=u.getCurrentSourceFile(n),a=[],i=t.pos,o=t.end;i===o&&(o+=e.isInsideJsxElement(r,i)?2:1);for(var s=i;s<=o;s++){var c=e.isInComment(r,s);if(c){switch(c.kind){case 2:a.push.apply(a,Ie(n,{end:c.end,pos:c.pos+1},!1));break;case 3:a.push.apply(a,Ne(n,{end:c.end,pos:c.pos+1},!1))}s=c.end+1}}return a}function Oe(n){var t=n.openingElement,r=n.closingElement,a=n.parent;return!e.tagNamesAreEquivalent(t.tagName,r.tagName)||e.isJsxElement(a)&&e.tagNamesAreEquivalent(t.tagName,a.openingElement.tagName)&&Oe(a)}function we(n,t,r){var a=u.getCurrentSourceFile(n),i=e.formatting.getRangeOfEnclosingComment(a,t);return!i||r&&3!==i.kind?void 0:e.createTextSpanFromRange(i)}function Pe(n,t){v();var r=h(n);p.throwIfCancellationRequested();var a=r.text,i=[];if(t.length>0&&!b(r.fileName)){var o=g(),s=void 0;while(s=o.exec(a)){p.throwIfCancellationRequested();var c=3;e.Debug.assert(s.length===t.length+c);var l=s[1],u=s.index+l.length;if(e.isInComment(r,u)){for(var d=void 0,f=0;f<t.length;f++)s[f+c]&&(d=t[f]);if(void 0===d)return e.Debug.fail();if(!y(a.charCodeAt(u+d.text.length))){var m=s[2];i.push({descriptor:d,message:m,position:u})}}}}return i;function _(e){return e.replace(/[\-\[\]\/\{\}\(\)\*\+\?\.\\\^\$\|]/g,"\\$&")}function g(){var n=/(?:\/\/+\s*)/.source,r=/(?:\/\*+\s*)/.source,a=/(?:^(?:\s|\*)*)/.source,i="("+a+"|"+n+"|"+r+")",o="(?:"+e.map(t,(function(e){return"("+_(e.text)+")"})).join("|")+")",s=/(?:$|\*\/)/.source,c=/(?:.*?)/.source,l="("+o+c+")",u=i+l+s;return new RegExp(u,"gim")}function y(e){return e>=97&&e<=122||e>=65&&e<=90||e>=48&&e<=57}function b(n){return e.stringContains(n,"/node_modules/")}}function Me(n,t,r){return v(),e.Rename.getRenameInfo(c,h(n),t,r)}function Fe(t,r,a,i,o,s){var c="number"===typeof r?[r,void 0]:[r.pos,r.end],l=c[0],u=c[1];return{file:t,startPosition:l,endPosition:u,program:b(),host:n,formatContext:e.formatting.getFormatContext(i,n),cancellationToken:p,preferences:a,triggerReason:o,kind:s}}function Ge(n,t){return e.SmartSelectionRange.getSmartSelectionRange(t,u.getCurrentSourceFile(n))}function Be(n,t,r,a,i){void 0===r&&(r=e.emptyOptions),v();var o=h(n);return e.refactor.getApplicableRefactors(Fe(o,t,r,e.emptyOptions,a,i))}function Ue(n,t,r,a,i,o){void 0===o&&(o=e.emptyOptions),v();var s=h(n);return e.refactor.getEditsForRefactor(Fe(s,r,o,t),a,i)}function Ve(e,n){return 0===n?{line:0,character:0}:y.toLineColumnOffset(e,n)}function je(n,t){v();var r=e.CallHierarchy.resolveCallHierarchyDeclaration(c,e.getTouchingPropertyName(h(n),t));return r&&e.mapOneOrMany(r,(function(n){return e.CallHierarchy.createCallHierarchyItem(c,n)}))}function Ke(n,t){v();var r=h(n),a=e.firstOrOnly(e.CallHierarchy.resolveCallHierarchyDeclaration(c,0===t?r:e.getTouchingPropertyName(r,t)));return a?e.CallHierarchy.getIncomingCalls(c,a,p):[]}function He(n,t){v();var r=h(n),a=e.firstOrOnly(e.CallHierarchy.resolveCallHierarchyDeclaration(c,0===t?r:e.getTouchingPropertyName(r,t)));return a?e.CallHierarchy.getOutgoingCalls(c,a):[]}fe.forEach((function(e,n){return fe.set(e.toString(),Number(n))}));var We={dispose:S,cleanupSemanticCache:T,getSyntacticDiagnostics:L,getSemanticDiagnostics:D,getSuggestionDiagnostics:C,getCompilerOptionsDiagnostics:k,getSyntacticClassifications:ue,getSemanticClassifications:ce,getEncodedSyntacticClassifications:de,getEncodedSemanticClassifications:le,getCompletionsAtPosition:R,getCompletionEntryDetails:O,getCompletionEntrySymbol:M,getSignatureHelpItems:te,getQuickInfoAtPosition:B,getDefinitionAtPosition:j,getDefinitionAndBoundSpan:K,getImplementationAtPosition:z,getTypeDefinitionAtPosition:H,getReferencesAtPosition:Y,findReferences:Z,getFileReferences:$,getOccurrencesAtPosition:q,getDocumentHighlights:J,getNameOrDottedNameSpan:ae,getBreakpointStatementAtPosition:ie,getNavigateToItems:ee,getRenameInfo:Me,getSmartSelectionRange:Ge,findRenameLocations:X,getNavigationBarItems:oe,getNavigationTree:se,getOutliningSpans:pe,getTodoComments:Pe,getBraceMatchingAtPosition:me,getIndentationAtPosition:_e,getFormattingEditsForRange:ge,getFormattingEditsForDocument:ye,getFormattingEditsAfterKeystroke:he,getDocCommentTemplateAtPosition:Le,isValidBraceCompletionAtPosition:De,getJsxClosingTagAtPosition:Ae,getSpanOfEnclosingComment:we,getCodeFixesAtPosition:ve,getCombinedCodeFix:be,applyCodeActionCommand:Se,organizeImports:Ee,getEditsForFileRename:Te,getEmitOutput:ne,getNonBoundSourceFile:re,getProgram:b,getAutoImportProvider:E,getApplicableRefactors:Be,getEditsForRefactor:Ue,toLineColumnOffset:Ve,getSourceMapper:function(){return y},clearSourceMapperCache:function(){return y.clearCache()},prepareCallHierarchy:je,provideCallHierarchyIncomingCalls:Ke,provideCallHierarchyOutgoingCalls:He,toggleLineComment:Ie,toggleMultilineComment:Ne,commentSelection:ke,uncommentSelection:Re};switch(s){case e.LanguageServiceMode.Semantic:break;case e.LanguageServiceMode.PartialSemantic:F.forEach((function(e){return We[e]=function(){throw new Error("LanguageService Operation: "+e+" not allowed in LanguageServiceMode.PartialSemantic")}}));break;case e.LanguageServiceMode.Syntactic:G.forEach((function(e){return We[e]=function(){throw new Error("LanguageService Operation: "+e+" not allowed in LanguageServiceMode.Syntactic")}}));break;default:e.Debug.assertNever(s)}return We}function U(e){return e.nameTable||V(e),e.nameTable}function V(n){var t=n.nameTable=new e.Map;n.forEachChild((function n(r){if(e.isIdentifier(r)&&!e.isTagName(r)&&r.escapedText||e.isStringOrNumericLiteralLike(r)&&j(r)){var a=e.getEscapedTextOfIdentifierOrLiteral(r);t.set(a,void 0===t.get(a)?r.pos:-1)}else if(e.isPrivateIdentifier(r)){a=r.escapedText;t.set(a,void 0===t.get(a)?r.pos:-1)}if(e.forEachChild(r,n),e.hasJSDocNodes(r))for(var i=0,o=r.jsDoc;i<o.length;i++){var s=o[i];e.forEachChild(s,n)}}))}function j(n){return e.isDeclarationName(n)||273===n.parent.kind||q(n)||e.isLiteralComputedPropertyDeclarationName(n)}function K(n){var t=H(n);return t&&(e.isObjectLiteralExpression(t.parent)||e.isJsxAttributes(t.parent))?t:void 0}function H(n){switch(n.kind){case 10:case 14:case 8:if(159===n.parent.kind)return e.isObjectLiteralElement(n.parent.parent)?n.parent.parent:void 0;case 78:return!e.isObjectLiteralElement(n.parent)||201!==n.parent.parent.kind&&282!==n.parent.parent.kind||n.parent.name!==n?void 0:n.parent}}function W(n,t){var r=K(n);if(r){var a=t.getContextualType(r.parent),i=a&&z(r,t,a,!1);if(i&&1===i.length)return e.first(i)}return t.getSymbolAtLocation(n)}function z(n,t,r,a){var i=e.getNameFromPropertyName(n.name);if(!i)return e.emptyArray;if(!r.isUnion()){var o=r.getProperty(i);return o?[o]:e.emptyArray}var s=e.mapDefined(r.types,(function(r){return(e.isObjectLiteralExpression(n.parent)||e.isJsxAttributes(n.parent))&&t.isTypeInvalidDueToUnionDiscriminant(r,n.parent)?void 0:r.getProperty(i)}));if(a&&(0===s.length||s.length===r.types.length)){o=r.getProperty(i);if(o)return[o]}return 0===s.length?e.mapDefined(r.types,(function(e){return e.getProperty(i)})):s}function q(e){return e&&e.parent&&203===e.parent.kind&&e.parent.argumentExpression===e}function J(n){return r+e.directorySeparator+e.getDefaultLibFileName(n)}e.createLanguageService=B,e.getNameTable=U,e.getContainingObjectLiteralElement=K,e.getPropertySymbolsFromContextualType=z,e.getDefaultLibFilePath=J,e.setObjectAllocator(S())}(d||(d={})),function(e){(function(n){function t(n,t){if(!n.isDeclarationFile){var r=e.getTokenAtPosition(n,t),a=n.getLineAndCharacterOfPosition(t).line;if(n.getLineAndCharacterOfPosition(r.getStart(n)).line>a){var i=e.findPrecedingToken(r.pos,n);if(!i||n.getLineAndCharacterOfPosition(i.getEnd()).line!==a)return;r=i}if(!(8388608&r.flags))return p(r)}function o(t,r){var a=t.decorators?e.skipTrivia(n.text,t.decorators.end):t.getStart(n);return e.createTextSpanFromBounds(a,(r||t).getEnd())}function s(t,r){return o(t,e.findNextToken(r,r.parent,n))}function c(e,t){return e&&a===n.getLineAndCharacterOfPosition(e.getStart(n)).line?p(e):p(t)}function l(t){return e.createTextSpanFromBounds(e.skipTrivia(n.text,t.pos),t.end)}function u(t){return p(e.findPrecedingToken(t.pos,n))}function d(t){return p(e.findNextToken(t,t.parent,n))}function p(t){if(t){var r=t.parent;switch(t.kind){case 233:return h(t.declarationList.declarations[0]);case 250:case 164:case 163:return h(t);case 161:return b(t);case 252:case 166:case 165:case 168:case 169:case 167:case 209:case 210:return T(t);case 231:if(e.isFunctionBlock(t))return S(t);case 258:return x(t);case 288:return x(t.block);case 234:return o(t.expression);case 243:return o(t.getChildAt(0),t.expression);case 237:return s(t,t.expression);case 236:return p(t.statement);case 249:return o(t.getChildAt(0));case 235:return s(t,t.expression);case 246:return p(t.statement);case 242:case 241:return o(t.getChildAt(0),t.label);case 238:return D(t);case 239:return s(t,t.expression);case 240:return L(t);case 245:return s(t,t.expression);case 285:case 286:return p(t.statements[0]);case 248:return x(t.tryBlock);case 247:return o(t,t.expression);case 267:return o(t,t.expression);case 261:return o(t,t.moduleReference);case 262:return o(t,t.moduleSpecifier);case 268:return o(t,t.moduleSpecifier);case 257:if(1!==e.getModuleInstanceState(t))return;case 253:case 256:case 292:case 199:return o(t);case 244:return p(t.statement);case 162:return l(r.decorators);case 197:case 198:return A(t);case 254:case 255:return;case 26:case 1:return c(e.findPrecedingToken(t.pos,n));case 27:return u(t);case 18:return I(t);case 19:return N(t);case 23:return k(t);case 20:return R(t);case 21:return O(t);case 58:return w(t);case 31:case 29:return P(t);case 114:return M(t);case 90:case 82:case 95:return d(t);case 157:return F(t);default:if(e.isArrayLiteralOrObjectLiteralDestructuringPattern(t))return C(t);if((78===t.kind||221===t.kind||289===t.kind||290===t.kind)&&e.isArrayLiteralOrObjectLiteralDestructuringPattern(r))return o(t);if(217===t.kind){var a=t,i=a.left,f=a.operatorToken;if(e.isArrayLiteralOrObjectLiteralDestructuringPattern(i))return C(i);if(62===f.kind&&e.isArrayLiteralOrObjectLiteralDestructuringPattern(t.parent))return o(t);if(27===f.kind)return p(i)}if(e.isExpressionNode(t))switch(r.kind){case 236:return u(t);case 162:return p(t.parent);case 238:case 240:return o(t);case 217:if(27===t.parent.operatorToken.kind)return o(t);break;case 210:if(t.parent.body===t)return o(t);break}switch(t.parent.kind){case 289:if(t.parent.name===t&&!e.isArrayLiteralOrObjectLiteralDestructuringPattern(t.parent.parent))return p(t.parent.initializer);break;case 207:if(t.parent.type===t)return d(t.parent.type);break;case 250:case 161:var m=t.parent,_=m.initializer,g=m.type;if(_===t||g===t||e.isAssignmentOperator(t.kind))return u(t);break;case 217:i=t.parent.left;if(e.isArrayLiteralOrObjectLiteralDestructuringPattern(i)&&t!==i)return u(t);break;default:if(e.isFunctionLike(t.parent)&&t.parent.type===t)return u(t)}return p(t.parent)}}function y(t){return e.isVariableDeclarationList(t.parent)&&t.parent.declarations[0]===t?o(e.findPrecedingToken(t.pos,n,t.parent),t):o(t)}function h(t){if(239===t.parent.parent.kind)return p(t.parent.parent);var r=t.parent;return e.isBindingPattern(t.name)?A(t.name):t.initializer||e.hasSyntacticModifier(t,1)||240===r.parent.kind?y(t):e.isVariableDeclarationList(t.parent)&&t.parent.declarations[0]!==t?p(e.findPrecedingToken(t.pos,n,t.parent)):void 0}function v(n){return!!n.initializer||void 0!==n.dotDotDotToken||e.hasSyntacticModifier(n,12)}function b(n){if(e.isBindingPattern(n.name))return A(n.name);if(v(n))return o(n);var t=n.parent,r=t.parameters.indexOf(n);return e.Debug.assert(-1!==r),0!==r?b(t.parameters[r-1]):p(t.body)}function E(n){return e.hasSyntacticModifier(n,1)||253===n.parent.kind&&167!==n.kind}function T(e){if(e.body)return E(e)?o(e):p(e.body)}function S(e){var n=e.statements.length?e.statements[0]:e.getLastToken();return E(e.parent)?c(e.parent,n):p(n)}function x(t){switch(t.parent.kind){case 257:if(1!==e.getModuleInstanceState(t.parent))return;case 237:case 235:case 239:return c(t.parent,t.statements[0]);case 238:case 240:return c(e.findPrecedingToken(t.pos,n,t.parent),t.statements[0])}return p(t.statements[0])}function L(e){if(251!==e.initializer.kind)return p(e.initializer);var n=e.initializer;return n.declarations.length>0?p(n.declarations[0]):void 0}function D(e){return e.initializer?L(e):e.condition?o(e.condition):e.incrementor?o(e.incrementor):void 0}function A(n){var t=e.forEach(n.elements,(function(e){return 223!==e.kind?e:void 0}));return t?p(t):199===n.parent.kind?o(n.parent):y(n.parent)}function C(n){e.Debug.assert(198!==n.kind&&197!==n.kind);var t=200===n.kind?n.elements:n.properties,r=e.forEach(t,(function(e){return 223!==e.kind?e:void 0}));return r?p(r):o(217===n.parent.kind?n.parent:n)}function I(t){switch(t.parent.kind){case 256:var r=t.parent;return c(e.findPrecedingToken(t.pos,n,t.parent),r.members.length?r.members[0]:r.getLastToken(n));case 253:var a=t.parent;return c(e.findPrecedingToken(t.pos,n,t.parent),a.members.length?a.members[0]:a.getLastToken(n));case 259:return c(t.parent.parent,t.parent.clauses[0])}return p(t.parent)}function N(n){switch(n.parent.kind){case 258:if(1!==e.getModuleInstanceState(n.parent.parent))return;case 256:case 253:return o(n);case 231:if(e.isFunctionBlock(n.parent))return o(n);case 288:return p(e.lastOrUndefined(n.parent.statements));case 259:var t=n.parent,r=e.lastOrUndefined(t.clauses);return r?p(e.lastOrUndefined(r.statements)):void 0;case 197:var a=n.parent;return p(e.lastOrUndefined(a.elements)||a);default:if(e.isArrayLiteralOrObjectLiteralDestructuringPattern(n.parent)){var i=n.parent;return o(e.lastOrUndefined(i.properties)||i)}return p(n.parent)}}function k(n){switch(n.parent.kind){case 198:var t=n.parent;return o(e.lastOrUndefined(t.elements)||t);default:if(e.isArrayLiteralOrObjectLiteralDestructuringPattern(n.parent)){var r=n.parent;return o(e.lastOrUndefined(r.elements)||r)}return p(n.parent)}}function R(e){return 236===e.parent.kind||204===e.parent.kind||205===e.parent.kind?u(e):208===e.parent.kind?d(e):p(e.parent)}function O(e){switch(e.parent.kind){case 209:case 252:case 210:case 166:case 165:case 168:case 169:case 167:case 237:case 236:case 238:case 240:case 204:case 205:case 208:return u(e);default:return p(e.parent)}}function w(n){return e.isFunctionLike(n.parent)||289===n.parent.kind||161===n.parent.kind?u(n):p(n.parent)}function P(e){return 207===e.parent.kind?d(e):p(e.parent)}function M(e){return 236===e.parent.kind?s(e,e.parent.expression):p(e.parent)}function F(e){return 240===e.parent.kind?d(e):p(e.parent)}}}n.spanInSourceFileAtLocation=t})(e.BreakpointResolver||(e.BreakpointResolver={}))}(d||(d={})),function(e){function n(n,t,r){var a=[];r=e.fixupCompilerOptions(r,a);var i=e.isArray(n)?n:[n],o=e.transformNodes(void 0,void 0,e.factory,r,i,t,!0);return o.diagnostics=e.concatenate(o.diagnostics,a),o}e.transform=n}(d||(d={}));var d,p=function(){return this}();(function(e){function n(e,n){e&&e.log("*INTERNAL ERROR* - Exception in typescript services: "+n.message)}var t=function(){function n(e){this.scriptSnapshotShim=e}return n.prototype.getText=function(e,n){return this.scriptSnapshotShim.getText(e,n)},n.prototype.getLength=function(){return this.scriptSnapshotShim.getLength()},n.prototype.getChangeRange=function(n){var t=n,r=this.scriptSnapshotShim.getChangeRange(t.scriptSnapshotShim);if(null===r)return null;var a=JSON.parse(r);return e.createTextChangeRange(e.createTextSpan(a.span.start,a.span.length),a.newLength)},n.prototype.dispose=function(){"dispose"in this.scriptSnapshotShim&&this.scriptSnapshotShim.dispose()},n}(),r=function(){function n(n){var t=this;this.shimHost=n,this.loggingEnabled=!1,this.tracingEnabled=!1,"getModuleResolutionsForFile"in this.shimHost&&(this.resolveModuleNames=function(n,r){var a=JSON.parse(t.shimHost.getModuleResolutionsForFile(r));return e.map(n,(function(n){var t=e.getProperty(a,n);return t?{resolvedFileName:t,extension:e.extensionFromPath(t),isExternalLibraryImport:!1}:void 0}))}),"directoryExists"in this.shimHost&&(this.directoryExists=function(e){return t.shimHost.directoryExists(e)}),"getTypeReferenceDirectiveResolutionsForFile"in this.shimHost&&(this.resolveTypeReferenceDirectives=function(n,r){var a=JSON.parse(t.shimHost.getTypeReferenceDirectiveResolutionsForFile(r));return e.map(n,(function(n){return e.getProperty(a,n)}))})}return n.prototype.log=function(e){this.loggingEnabled&&this.shimHost.log(e)},n.prototype.trace=function(e){this.tracingEnabled&&this.shimHost.trace(e)},n.prototype.error=function(e){this.shimHost.error(e)},n.prototype.getProjectVersion=function(){if(this.shimHost.getProjectVersion)return this.shimHost.getProjectVersion()},n.prototype.getTypeRootsVersion=function(){return this.shimHost.getTypeRootsVersion?this.shimHost.getTypeRootsVersion():0},n.prototype.useCaseSensitiveFileNames=function(){return!!this.shimHost.useCaseSensitiveFileNames&&this.shimHost.useCaseSensitiveFileNames()},n.prototype.getCompilationSettings=function(){var e=this.shimHost.getCompilationSettings();if(null===e||""===e)throw Error("LanguageServiceShimHostAdapter.getCompilationSettings: empty compilationSettings");var n=JSON.parse(e);return n.allowNonTsExtensions=!0,n},n.prototype.getScriptFileNames=function(){var e=this.shimHost.getScriptFileNames();return JSON.parse(e)},n.prototype.getScriptSnapshot=function(e){var n=this.shimHost.getScriptSnapshot(e);return n&&new t(n)},n.prototype.getScriptKind=function(e){return"getScriptKind"in this.shimHost?this.shimHost.getScriptKind(e):0},n.prototype.getScriptVersion=function(e){return this.shimHost.getScriptVersion(e)},n.prototype.getLocalizedDiagnosticMessages=function(){var e=this.shimHost.getLocalizedDiagnosticMessages();if(null===e||""===e)return null;try{return JSON.parse(e)}catch(n){return this.log(n.description||"diagnosticMessages.generated.json has invalid JSON format"),null}},n.prototype.getCancellationToken=function(){var n=this.shimHost.getCancellationToken();return new e.ThrottledCancellationToken(n)},n.prototype.getCurrentDirectory=function(){return this.shimHost.getCurrentDirectory()},n.prototype.getDirectories=function(e){return JSON.parse(this.shimHost.getDirectories(e))},n.prototype.getDefaultLibFileName=function(e){return this.shimHost.getDefaultLibFileName(JSON.stringify(e))},n.prototype.readDirectory=function(n,t,r,a,i){var o=e.getFileMatcherPatterns(n,r,a,this.shimHost.useCaseSensitiveFileNames(),this.shimHost.getCurrentDirectory());return JSON.parse(this.shimHost.readDirectory(n,JSON.stringify(t),JSON.stringify(o.basePaths),o.excludePattern,o.includeFilePattern,o.includeDirectoryPattern,i))},n.prototype.readFile=function(e,n){return this.shimHost.readFile(e,n)},n.prototype.fileExists=function(e){return this.shimHost.fileExists(e)},n}();e.LanguageServiceShimHostAdapter=r;var a=function(){function n(e){var n=this;this.shimHost=e,this.useCaseSensitiveFileNames=!!this.shimHost.useCaseSensitiveFileNames&&this.shimHost.useCaseSensitiveFileNames(),"directoryExists"in this.shimHost?this.directoryExists=function(e){return n.shimHost.directoryExists(e)}:this.directoryExists=void 0,"realpath"in this.shimHost?this.realpath=function(e){return n.shimHost.realpath(e)}:this.realpath=void 0}return n.prototype.readDirectory=function(n,t,r,a,i){var o=e.getFileMatcherPatterns(n,r,a,this.shimHost.useCaseSensitiveFileNames(),this.shimHost.getCurrentDirectory());return JSON.parse(this.shimHost.readDirectory(n,JSON.stringify(t),JSON.stringify(o.basePaths),o.excludePattern,o.includeFilePattern,o.includeDirectoryPattern,i))},n.prototype.fileExists=function(e){return this.shimHost.fileExists(e)},n.prototype.readFile=function(e){return this.shimHost.readFile(e)},n.prototype.getDirectories=function(e){return JSON.parse(this.shimHost.getDirectories(e))},n}();function s(n,t,r,a){var i;a&&(n.log(t),i=e.timestamp());var o=r();if(a){var s=e.timestamp();if(n.log(t+" completed in "+(s-i)+" msec"),e.isString(o)){var c=o;c.length>128&&(c=c.substring(0,128)+"..."),n.log("  result.length="+c.length+", result='"+JSON.stringify(c)+"'")}}return o}function c(e,n,t,r){return d(e,n,!0,t,r)}function d(t,r,a,i,o){try{var c=s(t,r,i,o);return a?JSON.stringify({result:c}):c}catch(l){return l instanceof e.OperationCanceledException?JSON.stringify({canceled:!0}):(n(t,l),l.description=r,JSON.stringify({error:l}))}}e.CoreServicesShimHostAdapter=a;var f=function(){function e(e){this.factory=e,e.registerShim(this)}return e.prototype.dispose=function(e){this.factory.unregisterShim(this)},e}();function m(e,n){return e.map((function(e){return _(e,n)}))}function _(n,t){return{message:e.flattenDiagnosticMessageText(n.messageText,t),start:n.start,length:n.length,category:e.diagnosticCategoryName(n),code:n.code,reportsUnnecessary:n.reportsUnnecessary,reportsDeprecated:n.reportsDeprecated}}e.realizeDiagnostics=m;var g=function(n){function t(e,t,r){var a=n.call(this,e)||this;return a.host=t,a.languageService=r,a.logPerformance=!1,a.logger=a.host,a}return u(t,n),t.prototype.forwardJSONCall=function(e,n){return c(this.logger,e,n,this.logPerformance)},t.prototype.dispose=function(e){this.logger.log("dispose()"),this.languageService.dispose(),this.languageService=null,p&&p.CollectGarbage&&(p.CollectGarbage(),this.logger.log("CollectGarbage()")),this.logger=null,n.prototype.dispose.call(this,e)},t.prototype.refresh=function(e){this.forwardJSONCall("refresh("+e+")",(function(){return null}))},t.prototype.cleanupSemanticCache=function(){var e=this;this.forwardJSONCall("cleanupSemanticCache()",(function(){return e.languageService.cleanupSemanticCache(),null}))},t.prototype.realizeDiagnostics=function(n){var t=e.getNewLineOrDefaultFromHost(this.host);return m(n,t)},t.prototype.getSyntacticClassifications=function(n,t,r){var a=this;return this.forwardJSONCall("getSyntacticClassifications('"+n+"', "+t+", "+r+")",(function(){return a.languageService.getSyntacticClassifications(n,e.createTextSpan(t,r))}))},t.prototype.getSemanticClassifications=function(n,t,r){var a=this;return this.forwardJSONCall("getSemanticClassifications('"+n+"', "+t+", "+r+")",(function(){return a.languageService.getSemanticClassifications(n,e.createTextSpan(t,r))}))},t.prototype.getEncodedSyntacticClassifications=function(n,t,r){var a=this;return this.forwardJSONCall("getEncodedSyntacticClassifications('"+n+"', "+t+", "+r+")",(function(){return y(a.languageService.getEncodedSyntacticClassifications(n,e.createTextSpan(t,r)))}))},t.prototype.getEncodedSemanticClassifications=function(n,t,r){var a=this;return this.forwardJSONCall("getEncodedSemanticClassifications('"+n+"', "+t+", "+r+")",(function(){return y(a.languageService.getEncodedSemanticClassifications(n,e.createTextSpan(t,r)))}))},t.prototype.getSyntacticDiagnostics=function(e){var n=this;return this.forwardJSONCall("getSyntacticDiagnostics('"+e+"')",(function(){var t=n.languageService.getSyntacticDiagnostics(e);return n.realizeDiagnostics(t)}))},t.prototype.getSemanticDiagnostics=function(e){var n=this;return this.forwardJSONCall("getSemanticDiagnostics('"+e+"')",(function(){var t=n.languageService.getSemanticDiagnostics(e);return n.realizeDiagnostics(t)}))},t.prototype.getSuggestionDiagnostics=function(e){var n=this;return this.forwardJSONCall("getSuggestionDiagnostics('"+e+"')",(function(){return n.realizeDiagnostics(n.languageService.getSuggestionDiagnostics(e))}))},t.prototype.getCompilerOptionsDiagnostics=function(){var e=this;return this.forwardJSONCall("getCompilerOptionsDiagnostics()",(function(){var n=e.languageService.getCompilerOptionsDiagnostics();return e.realizeDiagnostics(n)}))},t.prototype.getQuickInfoAtPosition=function(e,n){var t=this;return this.forwardJSONCall("getQuickInfoAtPosition('"+e+"', "+n+")",(function(){return t.languageService.getQuickInfoAtPosition(e,n)}))},t.prototype.getNameOrDottedNameSpan=function(e,n,t){var r=this;return this.forwardJSONCall("getNameOrDottedNameSpan('"+e+"', "+n+", "+t+")",(function(){return r.languageService.getNameOrDottedNameSpan(e,n,t)}))},t.prototype.getBreakpointStatementAtPosition=function(e,n){var t=this;return this.forwardJSONCall("getBreakpointStatementAtPosition('"+e+"', "+n+")",(function(){return t.languageService.getBreakpointStatementAtPosition(e,n)}))},t.prototype.getSignatureHelpItems=function(e,n,t){var r=this;return this.forwardJSONCall("getSignatureHelpItems('"+e+"', "+n+")",(function(){return r.languageService.getSignatureHelpItems(e,n,t)}))},t.prototype.getDefinitionAtPosition=function(e,n){var t=this;return this.forwardJSONCall("getDefinitionAtPosition('"+e+"', "+n+")",(function(){return t.languageService.getDefinitionAtPosition(e,n)}))},t.prototype.getDefinitionAndBoundSpan=function(e,n){var t=this;return this.forwardJSONCall("getDefinitionAndBoundSpan('"+e+"', "+n+")",(function(){return t.languageService.getDefinitionAndBoundSpan(e,n)}))},t.prototype.getTypeDefinitionAtPosition=function(e,n){var t=this;return this.forwardJSONCall("getTypeDefinitionAtPosition('"+e+"', "+n+")",(function(){return t.languageService.getTypeDefinitionAtPosition(e,n)}))},t.prototype.getImplementationAtPosition=function(e,n){var t=this;return this.forwardJSONCall("getImplementationAtPosition('"+e+"', "+n+")",(function(){return t.languageService.getImplementationAtPosition(e,n)}))},t.prototype.getRenameInfo=function(e,n,t){var r=this;return this.forwardJSONCall("getRenameInfo('"+e+"', "+n+")",(function(){return r.languageService.getRenameInfo(e,n,t)}))},t.prototype.getSmartSelectionRange=function(e,n){var t=this;return this.forwardJSONCall("getSmartSelectionRange('"+e+"', "+n+")",(function(){return t.languageService.getSmartSelectionRange(e,n)}))},t.prototype.findRenameLocations=function(e,n,t,r,a){var i=this;return this.forwardJSONCall("findRenameLocations('"+e+"', "+n+", "+t+", "+r+", "+a+")",(function(){return i.languageService.findRenameLocations(e,n,t,r,a)}))},t.prototype.getBraceMatchingAtPosition=function(e,n){var t=this;return this.forwardJSONCall("getBraceMatchingAtPosition('"+e+"', "+n+")",(function(){return t.languageService.getBraceMatchingAtPosition(e,n)}))},t.prototype.isValidBraceCompletionAtPosition=function(e,n,t){var r=this;return this.forwardJSONCall("isValidBraceCompletionAtPosition('"+e+"', "+n+", "+t+")",(function(){return r.languageService.isValidBraceCompletionAtPosition(e,n,t)}))},t.prototype.getSpanOfEnclosingComment=function(e,n,t){var r=this;return this.forwardJSONCall("getSpanOfEnclosingComment('"+e+"', "+n+")",(function(){return r.languageService.getSpanOfEnclosingComment(e,n,t)}))},t.prototype.getIndentationAtPosition=function(e,n,t){var r=this;return this.forwardJSONCall("getIndentationAtPosition('"+e+"', "+n+")",(function(){var a=JSON.parse(t);return r.languageService.getIndentationAtPosition(e,n,a)}))},t.prototype.getReferencesAtPosition=function(e,n){var t=this;return this.forwardJSONCall("getReferencesAtPosition('"+e+"', "+n+")",(function(){return t.languageService.getReferencesAtPosition(e,n)}))},t.prototype.findReferences=function(e,n){var t=this;return this.forwardJSONCall("findReferences('"+e+"', "+n+")",(function(){return t.languageService.findReferences(e,n)}))},t.prototype.getFileReferences=function(e){var n=this;return this.forwardJSONCall("getFileReferences('"+e+")",(function(){return n.languageService.getFileReferences(e)}))},t.prototype.getOccurrencesAtPosition=function(e,n){var t=this;return this.forwardJSONCall("getOccurrencesAtPosition('"+e+"', "+n+")",(function(){return t.languageService.getOccurrencesAtPosition(e,n)}))},t.prototype.getDocumentHighlights=function(n,t,r){var a=this;return this.forwardJSONCall("getDocumentHighlights('"+n+"', "+t+")",(function(){var i=a.languageService.getDocumentHighlights(n,t,JSON.parse(r)),o=e.toFileNameLowerCase(e.normalizeSlashes(n));return e.filter(i,(function(n){return e.toFileNameLowerCase(e.normalizeSlashes(n.fileName))===o}))}))},t.prototype.getCompletionsAtPosition=function(e,n,t){var r=this;return this.forwardJSONCall("getCompletionsAtPosition('"+e+"', "+n+", "+t+")",(function(){return r.languageService.getCompletionsAtPosition(e,n,t)}))},t.prototype.getCompletionEntryDetails=function(e,n,t,r,a,i,o){var s=this;return this.forwardJSONCall("getCompletionEntryDetails('"+e+"', "+n+", '"+t+"')",(function(){var c=void 0===r?void 0:JSON.parse(r);return s.languageService.getCompletionEntryDetails(e,n,t,c,a,i,o)}))},t.prototype.getFormattingEditsForRange=function(e,n,t,r){var a=this;return this.forwardJSONCall("getFormattingEditsForRange('"+e+"', "+n+", "+t+")",(function(){var i=JSON.parse(r);return a.languageService.getFormattingEditsForRange(e,n,t,i)}))},t.prototype.getFormattingEditsForDocument=function(e,n){var t=this;return this.forwardJSONCall("getFormattingEditsForDocument('"+e+"')",(function(){var r=JSON.parse(n);return t.languageService.getFormattingEditsForDocument(e,r)}))},t.prototype.getFormattingEditsAfterKeystroke=function(e,n,t,r){var a=this;return this.forwardJSONCall("getFormattingEditsAfterKeystroke('"+e+"', "+n+", '"+t+"')",(function(){var i=JSON.parse(r);return a.languageService.getFormattingEditsAfterKeystroke(e,n,t,i)}))},t.prototype.getDocCommentTemplateAtPosition=function(e,n,t){var r=this;return this.forwardJSONCall("getDocCommentTemplateAtPosition('"+e+"', "+n+")",(function(){return r.languageService.getDocCommentTemplateAtPosition(e,n,t)}))},t.prototype.getNavigateToItems=function(e,n,t){var r=this;return this.forwardJSONCall("getNavigateToItems('"+e+"', "+n+", "+t+")",(function(){return r.languageService.getNavigateToItems(e,n,t)}))},t.prototype.getNavigationBarItems=function(e){var n=this;return this.forwardJSONCall("getNavigationBarItems('"+e+"')",(function(){return n.languageService.getNavigationBarItems(e)}))},t.prototype.getNavigationTree=function(e){var n=this;return this.forwardJSONCall("getNavigationTree('"+e+"')",(function(){return n.languageService.getNavigationTree(e)}))},t.prototype.getOutliningSpans=function(e){var n=this;return this.forwardJSONCall("getOutliningSpans('"+e+"')",(function(){return n.languageService.getOutliningSpans(e)}))},t.prototype.getTodoComments=function(e,n){var t=this;return this.forwardJSONCall("getTodoComments('"+e+"')",(function(){return t.languageService.getTodoComments(e,JSON.parse(n))}))},t.prototype.prepareCallHierarchy=function(e,n){var t=this;return this.forwardJSONCall("prepareCallHierarchy('"+e+"', "+n+")",(function(){return t.languageService.prepareCallHierarchy(e,n)}))},t.prototype.provideCallHierarchyIncomingCalls=function(e,n){var t=this;return this.forwardJSONCall("provideCallHierarchyIncomingCalls('"+e+"', "+n+")",(function(){return t.languageService.provideCallHierarchyIncomingCalls(e,n)}))},t.prototype.provideCallHierarchyOutgoingCalls=function(e,n){var t=this;return this.forwardJSONCall("provideCallHierarchyOutgoingCalls('"+e+"', "+n+")",(function(){return t.languageService.provideCallHierarchyOutgoingCalls(e,n)}))},t.prototype.getEmitOutput=function(e){var n=this;return this.forwardJSONCall("getEmitOutput('"+e+"')",(function(){var t=n.languageService.getEmitOutput(e),r=t.diagnostics,a=l(t,["diagnostics"]);return o(o({},a),{diagnostics:n.realizeDiagnostics(r)})}))},t.prototype.getEmitOutputObject=function(e){var n=this;return d(this.logger,"getEmitOutput('"+e+"')",!1,(function(){return n.languageService.getEmitOutput(e)}),this.logPerformance)},t.prototype.toggleLineComment=function(e,n){var t=this;return this.forwardJSONCall("toggleLineComment('"+e+"', '"+JSON.stringify(n)+"')",(function(){return t.languageService.toggleLineComment(e,n)}))},t.prototype.toggleMultilineComment=function(e,n){var t=this;return this.forwardJSONCall("toggleMultilineComment('"+e+"', '"+JSON.stringify(n)+"')",(function(){return t.languageService.toggleMultilineComment(e,n)}))},t.prototype.commentSelection=function(e,n){var t=this;return this.forwardJSONCall("commentSelection('"+e+"', '"+JSON.stringify(n)+"')",(function(){return t.languageService.commentSelection(e,n)}))},t.prototype.uncommentSelection=function(e,n){var t=this;return this.forwardJSONCall("uncommentSelection('"+e+"', '"+JSON.stringify(n)+"')",(function(){return t.languageService.uncommentSelection(e,n)}))},t}(f);function y(e){return{spans:e.spans.join(","),endOfLineState:e.endOfLineState}}var h=function(n){function t(t,r){var a=n.call(this,t)||this;return a.logger=r,a.logPerformance=!1,a.classifier=e.createClassifier(),a}return u(t,n),t.prototype.getEncodedLexicalClassifications=function(e,n,t){var r=this;return void 0===t&&(t=!1),c(this.logger,"getEncodedLexicalClassifications",(function(){return y(r.classifier.getEncodedLexicalClassifications(e,n,t))}),this.logPerformance)},t.prototype.getClassificationsForLine=function(e,n,t){void 0===t&&(t=!1);for(var r=this.classifier.getClassificationsForLine(e,n,t),a="",i=0,o=r.entries;i<o.length;i++){var s=o[i];a+=s.length+"\n",a+=s.classification+"\n"}return a+=r.finalLexState,a},t}(f),v=function(n){function t(e,t,r){var a=n.call(this,e)||this;return a.logger=t,a.host=r,a.logPerformance=!1,a}return u(t,n),t.prototype.forwardJSONCall=function(e,n){return c(this.logger,e,n,this.logPerformance)},t.prototype.resolveModuleName=function(n,t,r){var a=this;return this.forwardJSONCall("resolveModuleName('"+n+"')",(function(){var i=JSON.parse(r),o=e.resolveModuleName(t,e.normalizeSlashes(n),i,a.host),s=o.resolvedModule?o.resolvedModule.resolvedFileName:void 0;return o.resolvedModule&&".ts"!==o.resolvedModule.extension&&".tsx"!==o.resolvedModule.extension&&".d.ts"!==o.resolvedModule.extension&&(s=void 0),{resolvedFileName:s,failedLookupLocations:o.failedLookupLocations}}))},t.prototype.resolveTypeReferenceDirective=function(n,t,r){var a=this;return this.forwardJSONCall("resolveTypeReferenceDirective("+n+")",(function(){var i=JSON.parse(r),o=e.resolveTypeReferenceDirective(t,e.normalizeSlashes(n),i,a.host);return{resolvedFileName:o.resolvedTypeReferenceDirective?o.resolvedTypeReferenceDirective.resolvedFileName:void 0,primary:!o.resolvedTypeReferenceDirective||o.resolvedTypeReferenceDirective.primary,failedLookupLocations:o.failedLookupLocations}}))},t.prototype.getPreProcessedFileInfo=function(n,t){var r=this;return this.forwardJSONCall("getPreProcessedFileInfo('"+n+"')",(function(){var n=e.preProcessFile(e.getSnapshotText(t),!0,!0);return{referencedFiles:r.convertFileReferences(n.referencedFiles),importedFiles:r.convertFileReferences(n.importedFiles),ambientExternalModules:n.ambientExternalModules,isLibFile:n.isLibFile,typeReferenceDirectives:r.convertFileReferences(n.typeReferenceDirectives),libReferenceDirectives:r.convertFileReferences(n.libReferenceDirectives)}}))},t.prototype.getAutomaticTypeDirectiveNames=function(n){var t=this;return this.forwardJSONCall("getAutomaticTypeDirectiveNames('"+n+"')",(function(){var r=JSON.parse(n);return e.getAutomaticTypeDirectiveNames(r,t.host)}))},t.prototype.convertFileReferences=function(n){if(n){for(var t=[],r=0,a=n;r<a.length;r++){var i=a[r];t.push({path:e.normalizeSlashes(i.fileName),position:i.pos,length:i.end-i.pos})}return t}},t.prototype.getTSConfigFileInfo=function(n,t){var r=this;return this.forwardJSONCall("getTSConfigFileInfo('"+n+"')",(function(){var a=e.parseJsonText(n,e.getSnapshotText(t)),o=e.normalizeSlashes(n),s=e.parseJsonSourceFileConfigFileContent(a,r.host,e.getDirectoryPath(o),{},o);return{options:s.options,typeAcquisition:s.typeAcquisition,files:s.fileNames,raw:s.raw,errors:m(i(i([],a.parseDiagnostics),s.errors),"\r\n")}}))},t.prototype.getDefaultCompilationSettings=function(){return this.forwardJSONCall("getDefaultCompilationSettings()",(function(){return e.getDefaultCompilerOptions()}))},t.prototype.discoverTypings=function(n){var t=this,r=e.createGetCanonicalFileName(!1);return this.forwardJSONCall("discoverTypings()",(function(){var a=JSON.parse(n);return void 0===t.safeList&&(t.safeList=e.JsTyping.loadSafeList(t.host,e.toPath(a.safeListPath,a.safeListPath,r))),e.JsTyping.discoverTypings(t.host,(function(e){return t.logger.log(e)}),a.fileNames,e.toPath(a.projectRootPath,a.projectRootPath,r),t.safeList,a.packageNameToTypingLocation,a.typeAcquisition,a.unresolvedImports,a.typesRegistry)}))},t}(f),b=function(){function t(){this._shims=[]}return t.prototype.getServicesVersion=function(){return e.servicesVersion},t.prototype.createLanguageServiceShim=function(t){try{void 0===this.documentRegistry&&(this.documentRegistry=e.createDocumentRegistry(t.useCaseSensitiveFileNames&&t.useCaseSensitiveFileNames(),t.getCurrentDirectory()));var a=new r(t),i=e.createLanguageService(a,this.documentRegistry,!1);return new g(this,t,i)}catch(o){throw n(t,o),o}},t.prototype.createClassifierShim=function(e){try{return new h(this,e)}catch(t){throw n(e,t),t}},t.prototype.createCoreServicesShim=function(e){try{var t=new a(e);return new v(this,e,t)}catch(r){throw n(e,r),r}},t.prototype.close=function(){e.clear(this._shims),this.documentRegistry=void 0},t.prototype.registerShim=function(e){this._shims.push(e)},t.prototype.unregisterShim=function(e){for(var n=0;n<this._shims.length;n++)if(this._shims[n]===e)return void delete this._shims[n];throw new Error("Invalid operation")},t}();e.TypeScriptServicesFactory=b})(d||(d={})),function(){if("object"!==typeof globalThis)try{Object.defineProperty(Object.prototype,"__magic__",{get:function(){return this},configurable:!0}),__magic__.globalThis=__magic__,"undefined"===typeof globalThis&&(window.globalThis=window),delete Object.prototype.__magic__}catch(e){window.globalThis=window}}(),("undefined"===typeof e||e.browser)&&(globalThis.TypeScript=globalThis.TypeScript||{},globalThis.TypeScript.Services=globalThis.TypeScript.Services||{},globalThis.TypeScript.Services.TypeScriptServicesFactory=d.TypeScriptServicesFactory,globalThis.toolsVersion=d.versionMajorMinor),a.exports&&(a.exports=d),function(e){var n={since:"4.0",warnAfter:"4.1",message:"Use the appropriate method on 'ts.factory' or the 'factory' supplied by your transformation context instead."};e.createNodeArray=e.Debug.deprecate(e.factory.createNodeArray,n),e.createNumericLiteral=e.Debug.deprecate(e.factory.createNumericLiteral,n),e.createBigIntLiteral=e.Debug.deprecate(e.factory.createBigIntLiteral,n),e.createStringLiteral=e.Debug.deprecate(e.factory.createStringLiteral,n),e.createStringLiteralFromNode=e.Debug.deprecate(e.factory.createStringLiteralFromNode,n),e.createRegularExpressionLiteral=e.Debug.deprecate(e.factory.createRegularExpressionLiteral,n),e.createLoopVariable=e.Debug.deprecate(e.factory.createLoopVariable,n),e.createUniqueName=e.Debug.deprecate(e.factory.createUniqueName,n),e.createPrivateIdentifier=e.Debug.deprecate(e.factory.createPrivateIdentifier,n),e.createSuper=e.Debug.deprecate(e.factory.createSuper,n),e.createThis=e.Debug.deprecate(e.factory.createThis,n),e.createNull=e.Debug.deprecate(e.factory.createNull,n),e.createTrue=e.Debug.deprecate(e.factory.createTrue,n),e.createFalse=e.Debug.deprecate(e.factory.createFalse,n),e.createModifier=e.Debug.deprecate(e.factory.createModifier,n),e.createModifiersFromModifierFlags=e.Debug.deprecate(e.factory.createModifiersFromModifierFlags,n),e.createQualifiedName=e.Debug.deprecate(e.factory.createQualifiedName,n),e.updateQualifiedName=e.Debug.deprecate(e.factory.updateQualifiedName,n),e.createComputedPropertyName=e.Debug.deprecate(e.factory.createComputedPropertyName,n),e.updateComputedPropertyName=e.Debug.deprecate(e.factory.updateComputedPropertyName,n),e.createTypeParameterDeclaration=e.Debug.deprecate(e.factory.createTypeParameterDeclaration,n),e.updateTypeParameterDeclaration=e.Debug.deprecate(e.factory.updateTypeParameterDeclaration,n),e.createParameter=e.Debug.deprecate(e.factory.createParameterDeclaration,n),e.updateParameter=e.Debug.deprecate(e.factory.updateParameterDeclaration,n),e.createDecorator=e.Debug.deprecate(e.factory.createDecorator,n),e.updateDecorator=e.Debug.deprecate(e.factory.updateDecorator,n),e.createProperty=e.Debug.deprecate(e.factory.createPropertyDeclaration,n),e.updateProperty=e.Debug.deprecate(e.factory.updatePropertyDeclaration,n),e.createMethod=e.Debug.deprecate(e.factory.createMethodDeclaration,n),e.updateMethod=e.Debug.deprecate(e.factory.updateMethodDeclaration,n),e.createConstructor=e.Debug.deprecate(e.factory.createConstructorDeclaration,n),e.updateConstructor=e.Debug.deprecate(e.factory.updateConstructorDeclaration,n),e.createGetAccessor=e.Debug.deprecate(e.factory.createGetAccessorDeclaration,n),e.updateGetAccessor=e.Debug.deprecate(e.factory.updateGetAccessorDeclaration,n),e.createSetAccessor=e.Debug.deprecate(e.factory.createSetAccessorDeclaration,n),e.updateSetAccessor=e.Debug.deprecate(e.factory.updateSetAccessorDeclaration,n),e.createCallSignature=e.Debug.deprecate(e.factory.createCallSignature,n),e.updateCallSignature=e.Debug.deprecate(e.factory.updateCallSignature,n),e.createConstructSignature=e.Debug.deprecate(e.factory.createConstructSignature,n),e.updateConstructSignature=e.Debug.deprecate(e.factory.updateConstructSignature,n),e.updateIndexSignature=e.Debug.deprecate(e.factory.updateIndexSignature,n),e.createKeywordTypeNode=e.Debug.deprecate(e.factory.createKeywordTypeNode,n),e.createTypePredicateNodeWithModifier=e.Debug.deprecate(e.factory.createTypePredicateNode,n),e.updateTypePredicateNodeWithModifier=e.Debug.deprecate(e.factory.updateTypePredicateNode,n),e.createTypeReferenceNode=e.Debug.deprecate(e.factory.createTypeReferenceNode,n),e.updateTypeReferenceNode=e.Debug.deprecate(e.factory.updateTypeReferenceNode,n),e.createFunctionTypeNode=e.Debug.deprecate(e.factory.createFunctionTypeNode,n),e.updateFunctionTypeNode=e.Debug.deprecate(e.factory.updateFunctionTypeNode,n),e.createConstructorTypeNode=e.Debug.deprecate((function(n,t,r){return e.factory.createConstructorTypeNode(void 0,n,t,r)}),n),e.updateConstructorTypeNode=e.Debug.deprecate((function(n,t,r,a){return e.factory.updateConstructorTypeNode(n,n.modifiers,t,r,a)}),n),e.createTypeQueryNode=e.Debug.deprecate(e.factory.createTypeQueryNode,n),e.updateTypeQueryNode=e.Debug.deprecate(e.factory.updateTypeQueryNode,n),e.createTypeLiteralNode=e.Debug.deprecate(e.factory.createTypeLiteralNode,n),e.updateTypeLiteralNode=e.Debug.deprecate(e.factory.updateTypeLiteralNode,n),e.createArrayTypeNode=e.Debug.deprecate(e.factory.createArrayTypeNode,n),e.updateArrayTypeNode=e.Debug.deprecate(e.factory.updateArrayTypeNode,n),e.createTupleTypeNode=e.Debug.deprecate(e.factory.createTupleTypeNode,n),e.updateTupleTypeNode=e.Debug.deprecate(e.factory.updateTupleTypeNode,n),e.createOptionalTypeNode=e.Debug.deprecate(e.factory.createOptionalTypeNode,n),e.updateOptionalTypeNode=e.Debug.deprecate(e.factory.updateOptionalTypeNode,n),e.createRestTypeNode=e.Debug.deprecate(e.factory.createRestTypeNode,n),e.updateRestTypeNode=e.Debug.deprecate(e.factory.updateRestTypeNode,n),e.createUnionTypeNode=e.Debug.deprecate(e.factory.createUnionTypeNode,n),e.updateUnionTypeNode=e.Debug.deprecate(e.factory.updateUnionTypeNode,n),e.createIntersectionTypeNode=e.Debug.deprecate(e.factory.createIntersectionTypeNode,n),e.updateIntersectionTypeNode=e.Debug.deprecate(e.factory.updateIntersectionTypeNode,n),e.createConditionalTypeNode=e.Debug.deprecate(e.factory.createConditionalTypeNode,n),e.updateConditionalTypeNode=e.Debug.deprecate(e.factory.updateConditionalTypeNode,n),e.createInferTypeNode=e.Debug.deprecate(e.factory.createInferTypeNode,n),e.updateInferTypeNode=e.Debug.deprecate(e.factory.updateInferTypeNode,n),e.createImportTypeNode=e.Debug.deprecate(e.factory.createImportTypeNode,n),e.updateImportTypeNode=e.Debug.deprecate(e.factory.updateImportTypeNode,n),e.createParenthesizedType=e.Debug.deprecate(e.factory.createParenthesizedType,n),e.updateParenthesizedType=e.Debug.deprecate(e.factory.updateParenthesizedType,n),e.createThisTypeNode=e.Debug.deprecate(e.factory.createThisTypeNode,n),e.updateTypeOperatorNode=e.Debug.deprecate(e.factory.updateTypeOperatorNode,n),e.createIndexedAccessTypeNode=e.Debug.deprecate(e.factory.createIndexedAccessTypeNode,n),e.updateIndexedAccessTypeNode=e.Debug.deprecate(e.factory.updateIndexedAccessTypeNode,n),e.createMappedTypeNode=e.Debug.deprecate(e.factory.createMappedTypeNode,n),e.updateMappedTypeNode=e.Debug.deprecate(e.factory.updateMappedTypeNode,n),e.createLiteralTypeNode=e.Debug.deprecate(e.factory.createLiteralTypeNode,n),e.updateLiteralTypeNode=e.Debug.deprecate(e.factory.updateLiteralTypeNode,n),e.createObjectBindingPattern=e.Debug.deprecate(e.factory.createObjectBindingPattern,n),e.updateObjectBindingPattern=e.Debug.deprecate(e.factory.updateObjectBindingPattern,n),e.createArrayBindingPattern=e.Debug.deprecate(e.factory.createArrayBindingPattern,n),e.updateArrayBindingPattern=e.Debug.deprecate(e.factory.updateArrayBindingPattern,n),e.createBindingElement=e.Debug.deprecate(e.factory.createBindingElement,n),e.updateBindingElement=e.Debug.deprecate(e.factory.updateBindingElement,n),e.createArrayLiteral=e.Debug.deprecate(e.factory.createArrayLiteralExpression,n),e.updateArrayLiteral=e.Debug.deprecate(e.factory.updateArrayLiteralExpression,n),e.createObjectLiteral=e.Debug.deprecate(e.factory.createObjectLiteralExpression,n),e.updateObjectLiteral=e.Debug.deprecate(e.factory.updateObjectLiteralExpression,n),e.createPropertyAccess=e.Debug.deprecate(e.factory.createPropertyAccessExpression,n),e.updatePropertyAccess=e.Debug.deprecate(e.factory.updatePropertyAccessExpression,n),e.createPropertyAccessChain=e.Debug.deprecate(e.factory.createPropertyAccessChain,n),e.updatePropertyAccessChain=e.Debug.deprecate(e.factory.updatePropertyAccessChain,n),e.createElementAccess=e.Debug.deprecate(e.factory.createElementAccessExpression,n),e.updateElementAccess=e.Debug.deprecate(e.factory.updateElementAccessExpression,n),e.createElementAccessChain=e.Debug.deprecate(e.factory.createElementAccessChain,n),e.updateElementAccessChain=e.Debug.deprecate(e.factory.updateElementAccessChain,n),e.createCall=e.Debug.deprecate(e.factory.createCallExpression,n),e.updateCall=e.Debug.deprecate(e.factory.updateCallExpression,n),e.createCallChain=e.Debug.deprecate(e.factory.createCallChain,n),e.updateCallChain=e.Debug.deprecate(e.factory.updateCallChain,n),e.createNew=e.Debug.deprecate(e.factory.createNewExpression,n),e.updateNew=e.Debug.deprecate(e.factory.updateNewExpression,n),e.createTypeAssertion=e.Debug.deprecate(e.factory.createTypeAssertion,n),e.updateTypeAssertion=e.Debug.deprecate(e.factory.updateTypeAssertion,n),e.createParen=e.Debug.deprecate(e.factory.createParenthesizedExpression,n),e.updateParen=e.Debug.deprecate(e.factory.updateParenthesizedExpression,n),e.createFunctionExpression=e.Debug.deprecate(e.factory.createFunctionExpression,n),e.updateFunctionExpression=e.Debug.deprecate(e.factory.updateFunctionExpression,n),e.createDelete=e.Debug.deprecate(e.factory.createDeleteExpression,n),e.updateDelete=e.Debug.deprecate(e.factory.updateDeleteExpression,n),e.createTypeOf=e.Debug.deprecate(e.factory.createTypeOfExpression,n),e.updateTypeOf=e.Debug.deprecate(e.factory.updateTypeOfExpression,n),e.createVoid=e.Debug.deprecate(e.factory.createVoidExpression,n),e.updateVoid=e.Debug.deprecate(e.factory.updateVoidExpression,n),e.createAwait=e.Debug.deprecate(e.factory.createAwaitExpression,n),e.updateAwait=e.Debug.deprecate(e.factory.updateAwaitExpression,n),e.createPrefix=e.Debug.deprecate(e.factory.createPrefixUnaryExpression,n),e.updatePrefix=e.Debug.deprecate(e.factory.updatePrefixUnaryExpression,n),e.createPostfix=e.Debug.deprecate(e.factory.createPostfixUnaryExpression,n),e.updatePostfix=e.Debug.deprecate(e.factory.updatePostfixUnaryExpression,n),e.createBinary=e.Debug.deprecate(e.factory.createBinaryExpression,n),e.updateConditional=e.Debug.deprecate(e.factory.updateConditionalExpression,n),e.createTemplateExpression=e.Debug.deprecate(e.factory.createTemplateExpression,n),e.updateTemplateExpression=e.Debug.deprecate(e.factory.updateTemplateExpression,n),e.createTemplateHead=e.Debug.deprecate(e.factory.createTemplateHead,n),e.createTemplateMiddle=e.Debug.deprecate(e.factory.createTemplateMiddle,n),e.createTemplateTail=e.Debug.deprecate(e.factory.createTemplateTail,n),e.createNoSubstitutionTemplateLiteral=e.Debug.deprecate(e.factory.createNoSubstitutionTemplateLiteral,n),e.updateYield=e.Debug.deprecate(e.factory.updateYieldExpression,n),e.createSpread=e.Debug.deprecate(e.factory.createSpreadElement,n),e.updateSpread=e.Debug.deprecate(e.factory.updateSpreadElement,n),e.createOmittedExpression=e.Debug.deprecate(e.factory.createOmittedExpression,n),e.createAsExpression=e.Debug.deprecate(e.factory.createAsExpression,n),e.updateAsExpression=e.Debug.deprecate(e.factory.updateAsExpression,n),e.createNonNullExpression=e.Debug.deprecate(e.factory.createNonNullExpression,n),e.updateNonNullExpression=e.Debug.deprecate(e.factory.updateNonNullExpression,n),e.createNonNullChain=e.Debug.deprecate(e.factory.createNonNullChain,n),e.updateNonNullChain=e.Debug.deprecate(e.factory.updateNonNullChain,n),e.createMetaProperty=e.Debug.deprecate(e.factory.createMetaProperty,n),e.updateMetaProperty=e.Debug.deprecate(e.factory.updateMetaProperty,n),e.createTemplateSpan=e.Debug.deprecate(e.factory.createTemplateSpan,n),e.updateTemplateSpan=e.Debug.deprecate(e.factory.updateTemplateSpan,n),e.createSemicolonClassElement=e.Debug.deprecate(e.factory.createSemicolonClassElement,n),e.createBlock=e.Debug.deprecate(e.factory.createBlock,n),e.updateBlock=e.Debug.deprecate(e.factory.updateBlock,n),e.createVariableStatement=e.Debug.deprecate(e.factory.createVariableStatement,n),e.updateVariableStatement=e.Debug.deprecate(e.factory.updateVariableStatement,n),e.createEmptyStatement=e.Debug.deprecate(e.factory.createEmptyStatement,n),e.createExpressionStatement=e.Debug.deprecate(e.factory.createExpressionStatement,n),e.updateExpressionStatement=e.Debug.deprecate(e.factory.updateExpressionStatement,n),e.createStatement=e.Debug.deprecate(e.factory.createExpressionStatement,n),e.updateStatement=e.Debug.deprecate(e.factory.updateExpressionStatement,n),e.createIf=e.Debug.deprecate(e.factory.createIfStatement,n),e.updateIf=e.Debug.deprecate(e.factory.updateIfStatement,n),e.createDo=e.Debug.deprecate(e.factory.createDoStatement,n),e.updateDo=e.Debug.deprecate(e.factory.updateDoStatement,n),e.createWhile=e.Debug.deprecate(e.factory.createWhileStatement,n),e.updateWhile=e.Debug.deprecate(e.factory.updateWhileStatement,n),e.createFor=e.Debug.deprecate(e.factory.createForStatement,n),e.updateFor=e.Debug.deprecate(e.factory.updateForStatement,n),e.createForIn=e.Debug.deprecate(e.factory.createForInStatement,n),e.updateForIn=e.Debug.deprecate(e.factory.updateForInStatement,n),e.createForOf=e.Debug.deprecate(e.factory.createForOfStatement,n),e.updateForOf=e.Debug.deprecate(e.factory.updateForOfStatement,n),e.createContinue=e.Debug.deprecate(e.factory.createContinueStatement,n),e.updateContinue=e.Debug.deprecate(e.factory.updateContinueStatement,n),e.createBreak=e.Debug.deprecate(e.factory.createBreakStatement,n),e.updateBreak=e.Debug.deprecate(e.factory.updateBreakStatement,n),e.createReturn=e.Debug.deprecate(e.factory.createReturnStatement,n),e.updateReturn=e.Debug.deprecate(e.factory.updateReturnStatement,n),e.createWith=e.Debug.deprecate(e.factory.createWithStatement,n),e.updateWith=e.Debug.deprecate(e.factory.updateWithStatement,n),e.createSwitch=e.Debug.deprecate(e.factory.createSwitchStatement,n),e.updateSwitch=e.Debug.deprecate(e.factory.updateSwitchStatement,n),e.createLabel=e.Debug.deprecate(e.factory.createLabeledStatement,n),e.updateLabel=e.Debug.deprecate(e.factory.updateLabeledStatement,n),e.createThrow=e.Debug.deprecate(e.factory.createThrowStatement,n),e.updateThrow=e.Debug.deprecate(e.factory.updateThrowStatement,n),e.createTry=e.Debug.deprecate(e.factory.createTryStatement,n),e.updateTry=e.Debug.deprecate(e.factory.updateTryStatement,n),e.createDebuggerStatement=e.Debug.deprecate(e.factory.createDebuggerStatement,n),e.createVariableDeclarationList=e.Debug.deprecate(e.factory.createVariableDeclarationList,n),e.updateVariableDeclarationList=e.Debug.deprecate(e.factory.updateVariableDeclarationList,n),e.createFunctionDeclaration=e.Debug.deprecate(e.factory.createFunctionDeclaration,n),e.updateFunctionDeclaration=e.Debug.deprecate(e.factory.updateFunctionDeclaration,n),e.createClassDeclaration=e.Debug.deprecate(e.factory.createClassDeclaration,n),e.updateClassDeclaration=e.Debug.deprecate(e.factory.updateClassDeclaration,n),e.createInterfaceDeclaration=e.Debug.deprecate(e.factory.createInterfaceDeclaration,n),e.updateInterfaceDeclaration=e.Debug.deprecate(e.factory.updateInterfaceDeclaration,n),e.createTypeAliasDeclaration=e.Debug.deprecate(e.factory.createTypeAliasDeclaration,n),e.updateTypeAliasDeclaration=e.Debug.deprecate(e.factory.updateTypeAliasDeclaration,n),e.createEnumDeclaration=e.Debug.deprecate(e.factory.createEnumDeclaration,n),e.updateEnumDeclaration=e.Debug.deprecate(e.factory.updateEnumDeclaration,n),e.createModuleDeclaration=e.Debug.deprecate(e.factory.createModuleDeclaration,n),e.updateModuleDeclaration=e.Debug.deprecate(e.factory.updateModuleDeclaration,n),e.createModuleBlock=e.Debug.deprecate(e.factory.createModuleBlock,n),e.updateModuleBlock=e.Debug.deprecate(e.factory.updateModuleBlock,n),e.createCaseBlock=e.Debug.deprecate(e.factory.createCaseBlock,n),e.updateCaseBlock=e.Debug.deprecate(e.factory.updateCaseBlock,n),e.createNamespaceExportDeclaration=e.Debug.deprecate(e.factory.createNamespaceExportDeclaration,n),e.updateNamespaceExportDeclaration=e.Debug.deprecate(e.factory.updateNamespaceExportDeclaration,n),e.createImportEqualsDeclaration=e.Debug.deprecate(e.factory.createImportEqualsDeclaration,n),e.updateImportEqualsDeclaration=e.Debug.deprecate(e.factory.updateImportEqualsDeclaration,n),e.createImportDeclaration=e.Debug.deprecate(e.factory.createImportDeclaration,n),e.updateImportDeclaration=e.Debug.deprecate(e.factory.updateImportDeclaration,n),e.createNamespaceImport=e.Debug.deprecate(e.factory.createNamespaceImport,n),e.updateNamespaceImport=e.Debug.deprecate(e.factory.updateNamespaceImport,n),e.createNamedImports=e.Debug.deprecate(e.factory.createNamedImports,n),e.updateNamedImports=e.Debug.deprecate(e.factory.updateNamedImports,n),e.createImportSpecifier=e.Debug.deprecate(e.factory.createImportSpecifier,n),e.updateImportSpecifier=e.Debug.deprecate(e.factory.updateImportSpecifier,n),e.createExportAssignment=e.Debug.deprecate(e.factory.createExportAssignment,n),e.updateExportAssignment=e.Debug.deprecate(e.factory.updateExportAssignment,n),e.createNamedExports=e.Debug.deprecate(e.factory.createNamedExports,n),e.updateNamedExports=e.Debug.deprecate(e.factory.updateNamedExports,n),e.createExportSpecifier=e.Debug.deprecate(e.factory.createExportSpecifier,n),e.updateExportSpecifier=e.Debug.deprecate(e.factory.updateExportSpecifier,n),e.createExternalModuleReference=e.Debug.deprecate(e.factory.createExternalModuleReference,n),e.updateExternalModuleReference=e.Debug.deprecate(e.factory.updateExternalModuleReference,n),e.createJSDocTypeExpression=e.Debug.deprecate(e.factory.createJSDocTypeExpression,n),e.createJSDocTypeTag=e.Debug.deprecate(e.factory.createJSDocTypeTag,n),e.createJSDocReturnTag=e.Debug.deprecate(e.factory.createJSDocReturnTag,n),e.createJSDocThisTag=e.Debug.deprecate(e.factory.createJSDocThisTag,n),e.createJSDocComment=e.Debug.deprecate(e.factory.createJSDocComment,n),e.createJSDocParameterTag=e.Debug.deprecate(e.factory.createJSDocParameterTag,n),e.createJSDocClassTag=e.Debug.deprecate(e.factory.createJSDocClassTag,n),e.createJSDocAugmentsTag=e.Debug.deprecate(e.factory.createJSDocAugmentsTag,n),e.createJSDocEnumTag=e.Debug.deprecate(e.factory.createJSDocEnumTag,n),e.createJSDocTemplateTag=e.Debug.deprecate(e.factory.createJSDocTemplateTag,n),e.createJSDocTypedefTag=e.Debug.deprecate(e.factory.createJSDocTypedefTag,n),e.createJSDocCallbackTag=e.Debug.deprecate(e.factory.createJSDocCallbackTag,n),e.createJSDocSignature=e.Debug.deprecate(e.factory.createJSDocSignature,n),e.createJSDocPropertyTag=e.Debug.deprecate(e.factory.createJSDocPropertyTag,n),e.createJSDocTypeLiteral=e.Debug.deprecate(e.factory.createJSDocTypeLiteral,n),e.createJSDocImplementsTag=e.Debug.deprecate(e.factory.createJSDocImplementsTag,n),e.createJSDocAuthorTag=e.Debug.deprecate(e.factory.createJSDocAuthorTag,n),e.createJSDocPublicTag=e.Debug.deprecate(e.factory.createJSDocPublicTag,n),e.createJSDocPrivateTag=e.Debug.deprecate(e.factory.createJSDocPrivateTag,n),e.createJSDocProtectedTag=e.Debug.deprecate(e.factory.createJSDocProtectedTag,n),e.createJSDocReadonlyTag=e.Debug.deprecate(e.factory.createJSDocReadonlyTag,n),e.createJSDocTag=e.Debug.deprecate(e.factory.createJSDocUnknownTag,n),e.createJsxElement=e.Debug.deprecate(e.factory.createJsxElement,n),e.updateJsxElement=e.Debug.deprecate(e.factory.updateJsxElement,n),e.createJsxSelfClosingElement=e.Debug.deprecate(e.factory.createJsxSelfClosingElement,n),e.updateJsxSelfClosingElement=e.Debug.deprecate(e.factory.updateJsxSelfClosingElement,n),e.createJsxOpeningElement=e.Debug.deprecate(e.factory.createJsxOpeningElement,n),e.updateJsxOpeningElement=e.Debug.deprecate(e.factory.updateJsxOpeningElement,n),e.createJsxClosingElement=e.Debug.deprecate(e.factory.createJsxClosingElement,n),e.updateJsxClosingElement=e.Debug.deprecate(e.factory.updateJsxClosingElement,n),e.createJsxFragment=e.Debug.deprecate(e.factory.createJsxFragment,n),e.createJsxText=e.Debug.deprecate(e.factory.createJsxText,n),e.updateJsxText=e.Debug.deprecate(e.factory.updateJsxText,n),e.createJsxOpeningFragment=e.Debug.deprecate(e.factory.createJsxOpeningFragment,n),e.createJsxJsxClosingFragment=e.Debug.deprecate(e.factory.createJsxJsxClosingFragment,n),e.updateJsxFragment=e.Debug.deprecate(e.factory.updateJsxFragment,n),e.createJsxAttribute=e.Debug.deprecate(e.factory.createJsxAttribute,n),e.updateJsxAttribute=e.Debug.deprecate(e.factory.updateJsxAttribute,n),e.createJsxAttributes=e.Debug.deprecate(e.factory.createJsxAttributes,n),e.updateJsxAttributes=e.Debug.deprecate(e.factory.updateJsxAttributes,n),e.createJsxSpreadAttribute=e.Debug.deprecate(e.factory.createJsxSpreadAttribute,n),e.updateJsxSpreadAttribute=e.Debug.deprecate(e.factory.updateJsxSpreadAttribute,n),e.createJsxExpression=e.Debug.deprecate(e.factory.createJsxExpression,n),e.updateJsxExpression=e.Debug.deprecate(e.factory.updateJsxExpression,n),e.createCaseClause=e.Debug.deprecate(e.factory.createCaseClause,n),e.updateCaseClause=e.Debug.deprecate(e.factory.updateCaseClause,n),e.createDefaultClause=e.Debug.deprecate(e.factory.createDefaultClause,n),e.updateDefaultClause=e.Debug.deprecate(e.factory.updateDefaultClause,n),e.createHeritageClause=e.Debug.deprecate(e.factory.createHeritageClause,n),e.updateHeritageClause=e.Debug.deprecate(e.factory.updateHeritageClause,n),e.createCatchClause=e.Debug.deprecate(e.factory.createCatchClause,n),e.updateCatchClause=e.Debug.deprecate(e.factory.updateCatchClause,n),e.createPropertyAssignment=e.Debug.deprecate(e.factory.createPropertyAssignment,n),e.updatePropertyAssignment=e.Debug.deprecate(e.factory.updatePropertyAssignment,n),e.createShorthandPropertyAssignment=e.Debug.deprecate(e.factory.createShorthandPropertyAssignment,n),e.updateShorthandPropertyAssignment=e.Debug.deprecate(e.factory.updateShorthandPropertyAssignment,n),e.createSpreadAssignment=e.Debug.deprecate(e.factory.createSpreadAssignment,n),e.updateSpreadAssignment=e.Debug.deprecate(e.factory.updateSpreadAssignment,n),e.createEnumMember=e.Debug.deprecate(e.factory.createEnumMember,n),e.updateEnumMember=e.Debug.deprecate(e.factory.updateEnumMember,n),e.updateSourceFileNode=e.Debug.deprecate(e.factory.updateSourceFile,n),e.createNotEmittedStatement=e.Debug.deprecate(e.factory.createNotEmittedStatement,n),e.createPartiallyEmittedExpression=e.Debug.deprecate(e.factory.createPartiallyEmittedExpression,n),e.updatePartiallyEmittedExpression=e.Debug.deprecate(e.factory.updatePartiallyEmittedExpression,n),e.createCommaList=e.Debug.deprecate(e.factory.createCommaListExpression,n),e.updateCommaList=e.Debug.deprecate(e.factory.updateCommaListExpression,n),e.createBundle=e.Debug.deprecate(e.factory.createBundle,n),e.updateBundle=e.Debug.deprecate(e.factory.updateBundle,n),e.createImmediatelyInvokedFunctionExpression=e.Debug.deprecate(e.factory.createImmediatelyInvokedFunctionExpression,n),e.createImmediatelyInvokedArrowFunction=e.Debug.deprecate(e.factory.createImmediatelyInvokedArrowFunction,n),e.createVoidZero=e.Debug.deprecate(e.factory.createVoidZero,n),e.createExportDefault=e.Debug.deprecate(e.factory.createExportDefault,n),e.createExternalModuleExport=e.Debug.deprecate(e.factory.createExternalModuleExport,n),e.createNamespaceExport=e.Debug.deprecate(e.factory.createNamespaceExport,n),e.updateNamespaceExport=e.Debug.deprecate(e.factory.updateNamespaceExport,n),e.createToken=e.Debug.deprecate((function(n){return e.factory.createToken(n)}),n),e.createIdentifier=e.Debug.deprecate((function(n){return e.factory.createIdentifier(n,void 0,void 0)}),n),e.createTempVariable=e.Debug.deprecate((function(n){return e.factory.createTempVariable(n,void 0)}),n),e.getGeneratedNameForNode=e.Debug.deprecate((function(n){return e.factory.getGeneratedNameForNode(n,void 0)}),n),e.createOptimisticUniqueName=e.Debug.deprecate((function(n){return e.factory.createUniqueName(n,16)}),n),e.createFileLevelUniqueName=e.Debug.deprecate((function(n){return e.factory.createUniqueName(n,48)}),n),e.createIndexSignature=e.Debug.deprecate((function(n,t,r,a){return e.factory.createIndexSignature(n,t,r,a)}),n),e.createTypePredicateNode=e.Debug.deprecate((function(n,t){return e.factory.createTypePredicateNode(void 0,n,t)}),n),e.updateTypePredicateNode=e.Debug.deprecate((function(n,t,r){return e.factory.updateTypePredicateNode(n,void 0,t,r)}),n),e.createLiteral=e.Debug.deprecate((function(n){return"number"===typeof n?e.factory.createNumericLiteral(n):"object"===typeof n&&"base10Value"in n?e.factory.createBigIntLiteral(n):"boolean"===typeof n?n?e.factory.createTrue():e.factory.createFalse():"string"===typeof n?e.factory.createStringLiteral(n,void 0):e.factory.createStringLiteralFromNode(n)}),{since:"4.0",warnAfter:"4.1",message:"Use `factory.createStringLiteral`, `factory.createStringLiteralFromNode`, `factory.createNumericLiteral`, `factory.createBigIntLiteral`, `factory.createTrue`, `factory.createFalse`, or the factory supplied by your transformation context instead."}),e.createMethodSignature=e.Debug.deprecate((function(n,t,r,a,i){return e.factory.createMethodSignature(void 0,a,i,n,t,r)}),n),e.updateMethodSignature=e.Debug.deprecate((function(n,t,r,a,i,o){return e.factory.updateMethodSignature(n,n.modifiers,i,o,t,r,a)}),n),e.createTypeOperatorNode=e.Debug.deprecate((function(n,t){var r;return t?r=n:(t=n,r=138),e.factory.createTypeOperatorNode(r,t)}),n),e.createTaggedTemplate=e.Debug.deprecate((function(n,t,r){var a;return r?a=t:r=t,e.factory.createTaggedTemplateExpression(n,a,r)}),n),e.updateTaggedTemplate=e.Debug.deprecate((function(n,t,r,a){var i;return a?i=r:a=r,e.factory.updateTaggedTemplateExpression(n,t,i,a)}),n),e.updateBinary=e.Debug.deprecate((function(n,t,r,a){return void 0===a&&(a=n.operatorToken),"number"===typeof a&&(a=a===n.operatorToken.kind?n.operatorToken:e.factory.createToken(a)),e.factory.updateBinaryExpression(n,t,a,r)}),n),e.createConditional=e.Debug.deprecate((function(n,t,r,a,i){return 5===arguments.length?e.factory.createConditionalExpression(n,t,r,a,i):3===arguments.length?e.factory.createConditionalExpression(n,e.factory.createToken(57),t,e.factory.createToken(58),r):e.Debug.fail("Argument count mismatch")}),n),e.createYield=e.Debug.deprecate((function(n,t){var r;return t?r=n:t=n,e.factory.createYieldExpression(r,t)}),n),e.createClassExpression=e.Debug.deprecate((function(n,t,r,a,i){return e.factory.createClassExpression(void 0,n,t,r,a,i)}),n),e.updateClassExpression=e.Debug.deprecate((function(n,t,r,a,i,o){return e.factory.updateClassExpression(n,void 0,t,r,a,i,o)}),n),e.createPropertySignature=e.Debug.deprecate((function(n,t,r,a,i){var o=e.factory.createPropertySignature(n,t,r,a);return o.initializer=i,o}),n),e.updatePropertySignature=e.Debug.deprecate((function(n,t,r,a,i,o){var s=e.factory.updatePropertySignature(n,t,r,a,i);return n.initializer!==o&&(s===n&&(s=e.factory.cloneNode(n)),s.initializer=o),s}),n),e.createExpressionWithTypeArguments=e.Debug.deprecate((function(n,t){return e.factory.createExpressionWithTypeArguments(t,n)}),n),e.updateExpressionWithTypeArguments=e.Debug.deprecate((function(n,t,r){return e.factory.updateExpressionWithTypeArguments(n,r,t)}),n),e.createArrowFunction=e.Debug.deprecate((function(n,t,r,a,i,o){return 6===arguments.length?e.factory.createArrowFunction(n,t,r,a,i,o):5===arguments.length?e.factory.createArrowFunction(n,t,r,a,void 0,i):e.Debug.fail("Argument count mismatch")}),n),e.updateArrowFunction=e.Debug.deprecate((function(n,t,r,a,i,o,s){return 7===arguments.length?e.factory.updateArrowFunction(n,t,r,a,i,o,s):6===arguments.length?e.factory.updateArrowFunction(n,t,r,a,i,n.equalsGreaterThanToken,o):e.Debug.fail("Argument count mismatch")}),n),e.createVariableDeclaration=e.Debug.deprecate((function(n,t,r,a){return 4===arguments.length?e.factory.createVariableDeclaration(n,t,r,a):arguments.length>=1&&arguments.length<=3?e.factory.createVariableDeclaration(n,void 0,t,r):e.Debug.fail("Argument count mismatch")}),n),e.updateVariableDeclaration=e.Debug.deprecate((function(n,t,r,a,i){return 5===arguments.length?e.factory.updateVariableDeclaration(n,t,r,a,i):4===arguments.length?e.factory.updateVariableDeclaration(n,t,n.exclamationToken,r,a):e.Debug.fail("Argument count mismatch")}),n),e.createImportClause=e.Debug.deprecate((function(n,t,r){return void 0===r&&(r=!1),e.factory.createImportClause(r,n,t)}),n),e.updateImportClause=e.Debug.deprecate((function(n,t,r,a){return e.factory.updateImportClause(n,a,t,r)}),n),e.createExportDeclaration=e.Debug.deprecate((function(n,t,r,a,i){return void 0===i&&(i=!1),e.factory.createExportDeclaration(n,t,i,r,a)}),n),e.updateExportDeclaration=e.Debug.deprecate((function(n,t,r,a,i,o){return e.factory.updateExportDeclaration(n,t,r,o,a,i)}),n),e.createJSDocParamTag=e.Debug.deprecate((function(n,t,r,a){return e.factory.createJSDocParameterTag(void 0,n,t,r,!1,a?e.factory.createNodeArray([e.factory.createJSDocText(a)]):void 0)}),n),e.createComma=e.Debug.deprecate((function(n,t){return e.factory.createComma(n,t)}),n),e.createLessThan=e.Debug.deprecate((function(n,t){return e.factory.createLessThan(n,t)}),n),e.createAssignment=e.Debug.deprecate((function(n,t){return e.factory.createAssignment(n,t)}),n),e.createStrictEquality=e.Debug.deprecate((function(n,t){return e.factory.createStrictEquality(n,t)}),n),e.createStrictInequality=e.Debug.deprecate((function(n,t){return e.factory.createStrictInequality(n,t)}),n),e.createAdd=e.Debug.deprecate((function(n,t){return e.factory.createAdd(n,t)}),n),e.createSubtract=e.Debug.deprecate((function(n,t){return e.factory.createSubtract(n,t)}),n),e.createLogicalAnd=e.Debug.deprecate((function(n,t){return e.factory.createLogicalAnd(n,t)}),n),e.createLogicalOr=e.Debug.deprecate((function(n,t){return e.factory.createLogicalOr(n,t)}),n),e.createPostfixIncrement=e.Debug.deprecate((function(n){return e.factory.createPostfixIncrement(n)}),n),e.createLogicalNot=e.Debug.deprecate((function(n){return e.factory.createLogicalNot(n)}),n),e.createNode=e.Debug.deprecate((function(n,t,r){return void 0===t&&(t=0),void 0===r&&(r=0),e.setTextRangePosEnd(298===n?e.parseBaseNodeFactory.createBaseSourceFileNode(n):78===n?e.parseBaseNodeFactory.createBaseIdentifierNode(n):79===n?e.parseBaseNodeFactory.createBasePrivateIdentifierNode(n):e.isNodeKind(n)?e.parseBaseNodeFactory.createBaseNode(n):e.parseBaseNodeFactory.createBaseTokenNode(n),t,r)}),{since:"4.0",warnAfter:"4.1",message:"Use an appropriate `factory` method instead."}),e.getMutableClone=e.Debug.deprecate((function(n){var t=e.factory.cloneNode(n);return e.setTextRange(t,n),e.setParent(t,n.parent),t}),{since:"4.0",warnAfter:"4.1",message:"Use an appropriate `factory.update...` method instead, use `setCommentRange` or `setSourceMapRange`, and avoid setting `parent`."}),e.isTypeAssertion=e.Debug.deprecate((function(e){return 207===e.kind}),{since:"4.0",warnAfter:"4.1",message:"Use `isTypeAssertionExpression` instead."}),e.isIdentifierOrPrivateIdentifier=e.Debug.deprecate((function(n){return e.isMemberName(n)}),{since:"4.2",warnAfter:"4.3",message:"Use `isMemberName` instead."})}(d||(d={}));var f=d.createClassifier,m=d.createLanguageService,_=d.displayPartsToString,g=d.EndOfLineState,y=d.flattenDiagnosticMessageText,h=d.IndentStyle,v=d.ScriptKind,b=d.ScriptTarget,E=d.TokenClass}.call(this,t("f28c"),"/",t("dd40")(e))},c317:function(e,n,t){"use strict";(function(e){t.d(n,"a",(function(){return i})),t.d(n,"b",(function(){return o})),t.d(n,"c",(function(){return s}));var r=t("30db");let a;if("undefined"!==typeof r["a"].vscode&&"undefined"!==typeof r["a"].vscode.process){const e=r["a"].vscode.process;a={get platform(){return e.platform},get env(){return e.env},cwd(){return e.cwd()},nextTick(e){return Object(r["e"])(e)}}}else a="undefined"!==typeof e?{get platform(){return e.platform},get env(){return Object({NODE_ENV:"production",BASE_URL:"dist/"})},cwd(){return Object({NODE_ENV:"production",BASE_URL:"dist/"})["VSCODE_CWD"]||e.cwd()},nextTick(n){return e.nextTick(n)}}:{get platform(){return r["d"]?"win32":r["b"]?"darwin":"linux"},nextTick(e){return Object(r["e"])(e)},get env(){return{}},cwd(){return"/"}};const i=a.cwd,o=a.env,s=a.platform}).call(this,t("f28c"))},c8ba:function(e,n){var t;t=function(){return this}();try{t=t||new Function("return this")()}catch(r){"object"===typeof window&&(t=window)}e.exports=t},d0c7:function(e,n,t){"use strict";t.r(n);class r{constructor(){this.listeners=[],this.unexpectedErrorHandler=function(e){setTimeout(()=>{if(e.stack)throw new Error(e.message+"\n\n"+e.stack);throw e},0)}}emit(e){this.listeners.forEach(n=>{n(e)})}onUnexpectedError(e){this.unexpectedErrorHandler(e),this.emit(e)}onUnexpectedExternalError(e){this.unexpectedErrorHandler(e)}}const a=new r;function i(e){c(e)||a.onUnexpectedError(e)}function o(e){if(e instanceof Error){let{name:n,message:t}=e;const r=e.stacktrace||e.stack;return{$isError:!0,name:n,message:t,stack:r}}return e}const s="Canceled";function c(e){return e instanceof Error&&e.name===s&&e.message===s}var l;(function(e){function n(e){return e&&"object"===typeof e&&"function"===typeof e[Symbol.iterator]}e.is=n;const t=Object.freeze([]);function r(){return t}function*a(e){yield e}function i(e){return e||t}function o(e){return!e||!0===e[Symbol.iterator]().next().done}function s(e){return e[Symbol.iterator]().next().value}function c(e,n){for(const t of e)if(n(t))return!0;return!1}function l(e,n){for(const t of e)if(n(t))return t}function*u(e,n){for(const t of e)n(t)&&(yield t)}function*d(e,n){let t=0;for(const r of e)yield n(r,t++)}function*p(...e){for(const n of e)for(const e of n)yield e}function*f(e){for(const n of e)for(const e of n)yield e}function m(e,n,t){let r=t;for(const a of e)r=n(r,a);return r}function*_(e,n,t=e.length){for(n<0&&(n+=e.length),t<0?t+=e.length:t>e.length&&(t=e.length);n<t;n++)yield e[n]}function g(n,t=Number.POSITIVE_INFINITY){const r=[];if(0===t)return[r,n];const a=n[Symbol.iterator]();for(let i=0;i<t;i++){const n=a.next();if(n.done)return[r,e.empty()];r.push(n.value)}return[r,{[Symbol.iterator](){return a}}]}function y(e,n,t=((e,n)=>e===n)){const r=e[Symbol.iterator](),a=n[Symbol.iterator]();while(1){const e=r.next(),n=a.next();if(e.done!==n.done)return!1;if(e.done)return!0;if(!t(e.value,n.value))return!1}}e.empty=r,e.single=a,e.from=i,e.isEmpty=o,e.first=s,e.some=c,e.find=l,e.filter=u,e.map=d,e.concat=p,e.concatNested=f,e.reduce=m,e.slice=_,e.consume=g,e.equals=y})(l||(l={}));const u=!1;let d=null;if(u){const e="__is_disposable_tracked__";d=new class{trackDisposable(n){const t=new Error("Potentially leaked disposable").stack;setTimeout(()=>{n[e]||console.log(t)},3e3)}markTracked(n){if(n&&n!==v.None)try{n[e]=!0}catch(t){}}}}function p(e){d&&d.markTracked(e)}function f(e){return d?(d.trackDisposable(e),e):e}class m extends Error{constructor(e){super(`Encountered errors while disposing of store. Errors: [${e.join(", ")}]`),this.errors=e}}function _(e){if(l.is(e)){let t=[];for(const r of e)if(r){p(r);try{r.dispose()}catch(n){t.push(n)}}if(1===t.length)throw t[0];if(t.length>1)throw new m(t);return Array.isArray(e)?[]:e}if(e)return p(e),e.dispose(),e}function g(...e){return e.forEach(p),y(()=>_(e))}function y(e){const n=f({dispose:()=>{p(n),e()}});return n}class h{constructor(){this._toDispose=new Set,this._isDisposed=!1}dispose(){this._isDisposed||(p(this),this._isDisposed=!0,this.clear())}clear(){try{_(this._toDispose.values())}finally{this._toDispose.clear()}}add(e){if(!e)return e;if(e===this)throw new Error("Cannot register a disposable on itself!");return p(e),this._isDisposed?h.DISABLE_DISPOSED_WARNING||console.warn(new Error("Trying to add a disposable to a DisposableStore that has already been disposed of. The added object will be leaked!").stack):this._toDispose.add(e),e}}h.DISABLE_DISPOSED_WARNING=!1;class v{constructor(){this._store=new h,f(this)}dispose(){p(this),this._store.dispose()}_register(e){if(e===this)throw new Error("Cannot register a disposable on itself!");return this._store.add(e)}}v.None=Object.freeze({dispose(){}});var b=t("30db");function E(e){let n=[],t=Object.getPrototypeOf(e);while(Object.prototype!==t)n=n.concat(Object.getOwnPropertyNames(t)),t=Object.getPrototypeOf(t);return n}function T(e){const n=[];for(const t of E(e))"function"===typeof e[t]&&n.push(t);return n}function S(e,n){const t=e=>function(){const t=Array.prototype.slice.call(arguments,0);return n(e,t)};let r={};for(const a of e)r[a]=t(a);return r}const x="$initialize";class L{constructor(e){this._workerId=-1,this._handler=e,this._lastSentReq=0,this._pendingReplies=Object.create(null)}setWorkerId(e){this._workerId=e}sendMessage(e,n){let t=String(++this._lastSentReq);return new Promise((r,a)=>{this._pendingReplies[t]={resolve:r,reject:a},this._send({vsWorker:this._workerId,req:t,method:e,args:n})})}handleMessage(e){e&&e.vsWorker&&(-1!==this._workerId&&e.vsWorker!==this._workerId||this._handleMessage(e))}_handleMessage(e){if(e.seq){let n=e;if(!this._pendingReplies[n.seq])return void console.warn("Got reply to unknown seq");let t=this._pendingReplies[n.seq];if(delete this._pendingReplies[n.seq],n.err){let e=n.err;return n.err.$isError&&(e=new Error,e.name=n.err.name,e.message=n.err.message,e.stack=n.err.stack),void t.reject(e)}return void t.resolve(n.res)}let n=e,t=n.req,r=this._handler.handleMessage(n.method,n.args);r.then(e=>{this._send({vsWorker:this._workerId,seq:t,res:e,err:void 0})},e=>{e.detail instanceof Error&&(e.detail=o(e.detail)),this._send({vsWorker:this._workerId,seq:t,res:void 0,err:o(e)})})}_send(e){let n=[];if(e.req){const t=e;for(let e=0;e<t.args.length;e++)t.args[e]instanceof ArrayBuffer&&n.push(t.args[e])}else{const t=e;t.res instanceof ArrayBuffer&&n.push(t.res)}this._handler.sendMessage(e,n)}}class D{constructor(e,n){this._requestHandlerFactory=n,this._requestHandler=null,this._protocol=new L({sendMessage:(n,t)=>{e(n,t)},handleMessage:(e,n)=>this._handleMessage(e,n)})}onmessage(e){this._protocol.handleMessage(e)}_handleMessage(e,n){if(e===x)return this.initialize(n[0],n[1],n[2],n[3]);if(!this._requestHandler||"function"!==typeof this._requestHandler[e])return Promise.reject(new Error("Missing requestHandler or method: "+e));try{return Promise.resolve(this._requestHandler[e].apply(this._requestHandler,n))}catch(t){return Promise.reject(t)}}initialize(e,n,t,r){this._protocol.setWorkerId(e);const a=(e,n)=>this._protocol.sendMessage(e,n),i=S(r,a);return this._requestHandlerFactory?(this._requestHandler=this._requestHandlerFactory(i),Promise.resolve(T(this._requestHandler))):(n&&("undefined"!==typeof n.baseUrl&&delete n["baseUrl"],"undefined"!==typeof n.paths&&"undefined"!==typeof n.paths.vs&&delete n.paths["vs"],void 0!==typeof n.trustedTypesPolicy&&delete n["trustedTypesPolicy"],n.catchError=!0,self.require.config(n)),new Promise((e,n)=>{self.require([t],t=>{this._requestHandler=t.create(i),this._requestHandler?e(T(this._requestHandler)):n(new Error("No RequestHandler!"))},n)}))}}class A{constructor(e,n,t,r){this.originalStart=e,this.originalLength=n,this.modifiedStart=t,this.modifiedLength=r}getOriginalEnd(){return this.originalStart+this.originalLength}getModifiedEnd(){return this.modifiedStart+this.modifiedLength}}function C(e){return e.split(/\r\n|\r|\n/)}function I(e){for(let n=0,t=e.length;n<t;n++){const t=e.charCodeAt(n);if(32!==t&&9!==t)return n}return-1}function N(e,n=e.length-1){for(let t=n;t>=0;t--){const n=e.charCodeAt(t);if(32!==n&&9!==n)return t}return-1}function k(e){return 55296<=e&&e<=56319}function R(e){return 56320<=e&&e<=57343}function O(e,n){return n-56320+(e-55296<<10)+65536}String.fromCharCode(65279);class w{constructor(){this._data=P()}static getInstance(){return w._INSTANCE||(w._INSTANCE=new w),w._INSTANCE}getGraphemeBreakType(e){if(e<32)return 10===e?3:13===e?2:4;if(e<127)return 0;const n=this._data,t=n.length/3;let r=1;while(r<=t)if(e<n[3*r])r*=2;else{if(!(e>n[3*r+1]))return n[3*r+2];r=2*r+1}return 0}}function P(){return JSON.parse("[0,0,0,51592,51592,11,44424,44424,11,72251,72254,5,7150,7150,7,48008,48008,11,55176,55176,11,128420,128420,14,3276,3277,5,9979,9980,14,46216,46216,11,49800,49800,11,53384,53384,11,70726,70726,5,122915,122916,5,129320,129327,14,2558,2558,5,5906,5908,5,9762,9763,14,43360,43388,8,45320,45320,11,47112,47112,11,48904,48904,11,50696,50696,11,52488,52488,11,54280,54280,11,70082,70083,1,71350,71350,7,73111,73111,5,127892,127893,14,128726,128727,14,129473,129474,14,2027,2035,5,2901,2902,5,3784,3789,5,6754,6754,5,8418,8420,5,9877,9877,14,11088,11088,14,44008,44008,5,44872,44872,11,45768,45768,11,46664,46664,11,47560,47560,11,48456,48456,11,49352,49352,11,50248,50248,11,51144,51144,11,52040,52040,11,52936,52936,11,53832,53832,11,54728,54728,11,69811,69814,5,70459,70460,5,71096,71099,7,71998,71998,5,72874,72880,5,119149,119149,7,127374,127374,14,128335,128335,14,128482,128482,14,128765,128767,14,129399,129400,14,129680,129685,14,1476,1477,5,2377,2380,7,2759,2760,5,3137,3140,7,3458,3459,7,4153,4154,5,6432,6434,5,6978,6978,5,7675,7679,5,9723,9726,14,9823,9823,14,9919,9923,14,10035,10036,14,42736,42737,5,43596,43596,5,44200,44200,11,44648,44648,11,45096,45096,11,45544,45544,11,45992,45992,11,46440,46440,11,46888,46888,11,47336,47336,11,47784,47784,11,48232,48232,11,48680,48680,11,49128,49128,11,49576,49576,11,50024,50024,11,50472,50472,11,50920,50920,11,51368,51368,11,51816,51816,11,52264,52264,11,52712,52712,11,53160,53160,11,53608,53608,11,54056,54056,11,54504,54504,11,54952,54952,11,68108,68111,5,69933,69940,5,70197,70197,7,70498,70499,7,70845,70845,5,71229,71229,5,71727,71735,5,72154,72155,5,72344,72345,5,73023,73029,5,94095,94098,5,121403,121452,5,126981,127182,14,127538,127546,14,127990,127990,14,128391,128391,14,128445,128449,14,128500,128505,14,128752,128752,14,129160,129167,14,129356,129356,14,129432,129442,14,129648,129651,14,129751,131069,14,173,173,4,1757,1757,1,2274,2274,1,2494,2494,5,2641,2641,5,2876,2876,5,3014,3016,7,3262,3262,7,3393,3396,5,3570,3571,7,3968,3972,5,4228,4228,7,6086,6086,5,6679,6680,5,6912,6915,5,7080,7081,5,7380,7392,5,8252,8252,14,9096,9096,14,9748,9749,14,9784,9786,14,9833,9850,14,9890,9894,14,9938,9938,14,9999,9999,14,10085,10087,14,12349,12349,14,43136,43137,7,43454,43456,7,43755,43755,7,44088,44088,11,44312,44312,11,44536,44536,11,44760,44760,11,44984,44984,11,45208,45208,11,45432,45432,11,45656,45656,11,45880,45880,11,46104,46104,11,46328,46328,11,46552,46552,11,46776,46776,11,47000,47000,11,47224,47224,11,47448,47448,11,47672,47672,11,47896,47896,11,48120,48120,11,48344,48344,11,48568,48568,11,48792,48792,11,49016,49016,11,49240,49240,11,49464,49464,11,49688,49688,11,49912,49912,11,50136,50136,11,50360,50360,11,50584,50584,11,50808,50808,11,51032,51032,11,51256,51256,11,51480,51480,11,51704,51704,11,51928,51928,11,52152,52152,11,52376,52376,11,52600,52600,11,52824,52824,11,53048,53048,11,53272,53272,11,53496,53496,11,53720,53720,11,53944,53944,11,54168,54168,11,54392,54392,11,54616,54616,11,54840,54840,11,55064,55064,11,65438,65439,5,69633,69633,5,69837,69837,1,70018,70018,7,70188,70190,7,70368,70370,7,70465,70468,7,70712,70719,5,70835,70840,5,70850,70851,5,71132,71133,5,71340,71340,7,71458,71461,5,71985,71989,7,72002,72002,7,72193,72202,5,72281,72283,5,72766,72766,7,72885,72886,5,73104,73105,5,92912,92916,5,113824,113827,4,119173,119179,5,121505,121519,5,125136,125142,5,127279,127279,14,127489,127490,14,127570,127743,14,127900,127901,14,128254,128254,14,128369,128370,14,128400,128400,14,128425,128432,14,128468,128475,14,128489,128494,14,128715,128720,14,128745,128745,14,128759,128760,14,129004,129023,14,129296,129304,14,129340,129342,14,129388,129392,14,129404,129407,14,129454,129455,14,129485,129487,14,129659,129663,14,129719,129727,14,917536,917631,5,13,13,2,1160,1161,5,1564,1564,4,1807,1807,1,2085,2087,5,2363,2363,7,2402,2403,5,2507,2508,7,2622,2624,7,2691,2691,7,2786,2787,5,2881,2884,5,3006,3006,5,3072,3072,5,3170,3171,5,3267,3268,7,3330,3331,7,3406,3406,1,3538,3540,5,3655,3662,5,3897,3897,5,4038,4038,5,4184,4185,5,4352,4447,8,6068,6069,5,6155,6157,5,6448,6449,7,6742,6742,5,6783,6783,5,6966,6970,5,7042,7042,7,7143,7143,7,7212,7219,5,7412,7412,5,8206,8207,4,8294,8303,4,8596,8601,14,9410,9410,14,9742,9742,14,9757,9757,14,9770,9770,14,9794,9794,14,9828,9828,14,9855,9855,14,9882,9882,14,9900,9903,14,9929,9933,14,9963,9967,14,9987,9988,14,10006,10006,14,10062,10062,14,10175,10175,14,11744,11775,5,42607,42607,5,43043,43044,7,43263,43263,5,43444,43445,7,43569,43570,5,43698,43700,5,43766,43766,5,44032,44032,11,44144,44144,11,44256,44256,11,44368,44368,11,44480,44480,11,44592,44592,11,44704,44704,11,44816,44816,11,44928,44928,11,45040,45040,11,45152,45152,11,45264,45264,11,45376,45376,11,45488,45488,11,45600,45600,11,45712,45712,11,45824,45824,11,45936,45936,11,46048,46048,11,46160,46160,11,46272,46272,11,46384,46384,11,46496,46496,11,46608,46608,11,46720,46720,11,46832,46832,11,46944,46944,11,47056,47056,11,47168,47168,11,47280,47280,11,47392,47392,11,47504,47504,11,47616,47616,11,47728,47728,11,47840,47840,11,47952,47952,11,48064,48064,11,48176,48176,11,48288,48288,11,48400,48400,11,48512,48512,11,48624,48624,11,48736,48736,11,48848,48848,11,48960,48960,11,49072,49072,11,49184,49184,11,49296,49296,11,49408,49408,11,49520,49520,11,49632,49632,11,49744,49744,11,49856,49856,11,49968,49968,11,50080,50080,11,50192,50192,11,50304,50304,11,50416,50416,11,50528,50528,11,50640,50640,11,50752,50752,11,50864,50864,11,50976,50976,11,51088,51088,11,51200,51200,11,51312,51312,11,51424,51424,11,51536,51536,11,51648,51648,11,51760,51760,11,51872,51872,11,51984,51984,11,52096,52096,11,52208,52208,11,52320,52320,11,52432,52432,11,52544,52544,11,52656,52656,11,52768,52768,11,52880,52880,11,52992,52992,11,53104,53104,11,53216,53216,11,53328,53328,11,53440,53440,11,53552,53552,11,53664,53664,11,53776,53776,11,53888,53888,11,54000,54000,11,54112,54112,11,54224,54224,11,54336,54336,11,54448,54448,11,54560,54560,11,54672,54672,11,54784,54784,11,54896,54896,11,55008,55008,11,55120,55120,11,64286,64286,5,66272,66272,5,68900,68903,5,69762,69762,7,69817,69818,5,69927,69931,5,70003,70003,5,70070,70078,5,70094,70094,7,70194,70195,7,70206,70206,5,70400,70401,5,70463,70463,7,70475,70477,7,70512,70516,5,70722,70724,5,70832,70832,5,70842,70842,5,70847,70848,5,71088,71089,7,71102,71102,7,71219,71226,5,71231,71232,5,71342,71343,7,71453,71455,5,71463,71467,5,71737,71738,5,71995,71996,5,72000,72000,7,72145,72147,7,72160,72160,5,72249,72249,7,72273,72278,5,72330,72342,5,72752,72758,5,72850,72871,5,72882,72883,5,73018,73018,5,73031,73031,5,73109,73109,5,73461,73462,7,94031,94031,5,94192,94193,7,119142,119142,7,119155,119162,4,119362,119364,5,121476,121476,5,122888,122904,5,123184,123190,5,126976,126979,14,127184,127231,14,127344,127345,14,127405,127461,14,127514,127514,14,127561,127567,14,127778,127779,14,127896,127896,14,127985,127986,14,127995,127999,5,128326,128328,14,128360,128366,14,128378,128378,14,128394,128397,14,128405,128406,14,128422,128423,14,128435,128443,14,128453,128464,14,128479,128480,14,128484,128487,14,128496,128498,14,128640,128709,14,128723,128724,14,128736,128741,14,128747,128748,14,128755,128755,14,128762,128762,14,128981,128991,14,129096,129103,14,129292,129292,14,129311,129311,14,129329,129330,14,129344,129349,14,129360,129374,14,129394,129394,14,129402,129402,14,129413,129425,14,129445,129450,14,129466,129471,14,129483,129483,14,129511,129535,14,129653,129655,14,129667,129670,14,129705,129711,14,129731,129743,14,917505,917505,4,917760,917999,5,10,10,3,127,159,4,768,879,5,1471,1471,5,1536,1541,1,1648,1648,5,1767,1768,5,1840,1866,5,2070,2073,5,2137,2139,5,2307,2307,7,2366,2368,7,2382,2383,7,2434,2435,7,2497,2500,5,2519,2519,5,2563,2563,7,2631,2632,5,2677,2677,5,2750,2752,7,2763,2764,7,2817,2817,5,2879,2879,5,2891,2892,7,2914,2915,5,3008,3008,5,3021,3021,5,3076,3076,5,3146,3149,5,3202,3203,7,3264,3265,7,3271,3272,7,3298,3299,5,3390,3390,5,3402,3404,7,3426,3427,5,3535,3535,5,3544,3550,7,3635,3635,7,3763,3763,7,3893,3893,5,3953,3966,5,3981,3991,5,4145,4145,7,4157,4158,5,4209,4212,5,4237,4237,5,4520,4607,10,5970,5971,5,6071,6077,5,6089,6099,5,6277,6278,5,6439,6440,5,6451,6456,7,6683,6683,5,6744,6750,5,6765,6770,7,6846,6846,5,6964,6964,5,6972,6972,5,7019,7027,5,7074,7077,5,7083,7085,5,7146,7148,7,7154,7155,7,7222,7223,5,7394,7400,5,7416,7417,5,8204,8204,5,8233,8233,4,8288,8292,4,8413,8416,5,8482,8482,14,8986,8987,14,9193,9203,14,9654,9654,14,9733,9733,14,9745,9745,14,9752,9752,14,9760,9760,14,9766,9766,14,9774,9775,14,9792,9792,14,9800,9811,14,9825,9826,14,9831,9831,14,9852,9853,14,9872,9873,14,9880,9880,14,9885,9887,14,9896,9897,14,9906,9916,14,9926,9927,14,9936,9936,14,9941,9960,14,9974,9974,14,9982,9985,14,9992,9997,14,10002,10002,14,10017,10017,14,10055,10055,14,10071,10071,14,10145,10145,14,11013,11015,14,11503,11505,5,12334,12335,5,12951,12951,14,42612,42621,5,43014,43014,5,43047,43047,7,43204,43205,5,43335,43345,5,43395,43395,7,43450,43451,7,43561,43566,5,43573,43574,5,43644,43644,5,43710,43711,5,43758,43759,7,44005,44005,5,44012,44012,7,44060,44060,11,44116,44116,11,44172,44172,11,44228,44228,11,44284,44284,11,44340,44340,11,44396,44396,11,44452,44452,11,44508,44508,11,44564,44564,11,44620,44620,11,44676,44676,11,44732,44732,11,44788,44788,11,44844,44844,11,44900,44900,11,44956,44956,11,45012,45012,11,45068,45068,11,45124,45124,11,45180,45180,11,45236,45236,11,45292,45292,11,45348,45348,11,45404,45404,11,45460,45460,11,45516,45516,11,45572,45572,11,45628,45628,11,45684,45684,11,45740,45740,11,45796,45796,11,45852,45852,11,45908,45908,11,45964,45964,11,46020,46020,11,46076,46076,11,46132,46132,11,46188,46188,11,46244,46244,11,46300,46300,11,46356,46356,11,46412,46412,11,46468,46468,11,46524,46524,11,46580,46580,11,46636,46636,11,46692,46692,11,46748,46748,11,46804,46804,11,46860,46860,11,46916,46916,11,46972,46972,11,47028,47028,11,47084,47084,11,47140,47140,11,47196,47196,11,47252,47252,11,47308,47308,11,47364,47364,11,47420,47420,11,47476,47476,11,47532,47532,11,47588,47588,11,47644,47644,11,47700,47700,11,47756,47756,11,47812,47812,11,47868,47868,11,47924,47924,11,47980,47980,11,48036,48036,11,48092,48092,11,48148,48148,11,48204,48204,11,48260,48260,11,48316,48316,11,48372,48372,11,48428,48428,11,48484,48484,11,48540,48540,11,48596,48596,11,48652,48652,11,48708,48708,11,48764,48764,11,48820,48820,11,48876,48876,11,48932,48932,11,48988,48988,11,49044,49044,11,49100,49100,11,49156,49156,11,49212,49212,11,49268,49268,11,49324,49324,11,49380,49380,11,49436,49436,11,49492,49492,11,49548,49548,11,49604,49604,11,49660,49660,11,49716,49716,11,49772,49772,11,49828,49828,11,49884,49884,11,49940,49940,11,49996,49996,11,50052,50052,11,50108,50108,11,50164,50164,11,50220,50220,11,50276,50276,11,50332,50332,11,50388,50388,11,50444,50444,11,50500,50500,11,50556,50556,11,50612,50612,11,50668,50668,11,50724,50724,11,50780,50780,11,50836,50836,11,50892,50892,11,50948,50948,11,51004,51004,11,51060,51060,11,51116,51116,11,51172,51172,11,51228,51228,11,51284,51284,11,51340,51340,11,51396,51396,11,51452,51452,11,51508,51508,11,51564,51564,11,51620,51620,11,51676,51676,11,51732,51732,11,51788,51788,11,51844,51844,11,51900,51900,11,51956,51956,11,52012,52012,11,52068,52068,11,52124,52124,11,52180,52180,11,52236,52236,11,52292,52292,11,52348,52348,11,52404,52404,11,52460,52460,11,52516,52516,11,52572,52572,11,52628,52628,11,52684,52684,11,52740,52740,11,52796,52796,11,52852,52852,11,52908,52908,11,52964,52964,11,53020,53020,11,53076,53076,11,53132,53132,11,53188,53188,11,53244,53244,11,53300,53300,11,53356,53356,11,53412,53412,11,53468,53468,11,53524,53524,11,53580,53580,11,53636,53636,11,53692,53692,11,53748,53748,11,53804,53804,11,53860,53860,11,53916,53916,11,53972,53972,11,54028,54028,11,54084,54084,11,54140,54140,11,54196,54196,11,54252,54252,11,54308,54308,11,54364,54364,11,54420,54420,11,54476,54476,11,54532,54532,11,54588,54588,11,54644,54644,11,54700,54700,11,54756,54756,11,54812,54812,11,54868,54868,11,54924,54924,11,54980,54980,11,55036,55036,11,55092,55092,11,55148,55148,11,55216,55238,9,65056,65071,5,65529,65531,4,68097,68099,5,68159,68159,5,69446,69456,5,69688,69702,5,69808,69810,7,69815,69816,7,69821,69821,1,69888,69890,5,69932,69932,7,69957,69958,7,70016,70017,5,70067,70069,7,70079,70080,7,70089,70092,5,70095,70095,5,70191,70193,5,70196,70196,5,70198,70199,5,70367,70367,5,70371,70378,5,70402,70403,7,70462,70462,5,70464,70464,5,70471,70472,7,70487,70487,5,70502,70508,5,70709,70711,7,70720,70721,7,70725,70725,7,70750,70750,5,70833,70834,7,70841,70841,7,70843,70844,7,70846,70846,7,70849,70849,7,71087,71087,5,71090,71093,5,71100,71101,5,71103,71104,5,71216,71218,7,71227,71228,7,71230,71230,7,71339,71339,5,71341,71341,5,71344,71349,5,71351,71351,5,71456,71457,7,71462,71462,7,71724,71726,7,71736,71736,7,71984,71984,5,71991,71992,7,71997,71997,7,71999,71999,1,72001,72001,1,72003,72003,5,72148,72151,5,72156,72159,7,72164,72164,7,72243,72248,5,72250,72250,1,72263,72263,5,72279,72280,7,72324,72329,1,72343,72343,7,72751,72751,7,72760,72765,5,72767,72767,5,72873,72873,7,72881,72881,7,72884,72884,7,73009,73014,5,73020,73021,5,73030,73030,1,73098,73102,7,73107,73108,7,73110,73110,7,73459,73460,5,78896,78904,4,92976,92982,5,94033,94087,7,94180,94180,5,113821,113822,5,119141,119141,5,119143,119145,5,119150,119154,5,119163,119170,5,119210,119213,5,121344,121398,5,121461,121461,5,121499,121503,5,122880,122886,5,122907,122913,5,122918,122922,5,123628,123631,5,125252,125258,5,126980,126980,14,127183,127183,14,127245,127247,14,127340,127343,14,127358,127359,14,127377,127386,14,127462,127487,6,127491,127503,14,127535,127535,14,127548,127551,14,127568,127569,14,127744,127777,14,127780,127891,14,127894,127895,14,127897,127899,14,127902,127984,14,127987,127989,14,127991,127994,14,128000,128253,14,128255,128317,14,128329,128334,14,128336,128359,14,128367,128368,14,128371,128377,14,128379,128390,14,128392,128393,14,128398,128399,14,128401,128404,14,128407,128419,14,128421,128421,14,128424,128424,14,128433,128434,14,128444,128444,14,128450,128452,14,128465,128467,14,128476,128478,14,128481,128481,14,128483,128483,14,128488,128488,14,128495,128495,14,128499,128499,14,128506,128591,14,128710,128714,14,128721,128722,14,128725,128725,14,128728,128735,14,128742,128744,14,128746,128746,14,128749,128751,14,128753,128754,14,128756,128758,14,128761,128761,14,128763,128764,14,128884,128895,14,128992,129003,14,129036,129039,14,129114,129119,14,129198,129279,14,129293,129295,14,129305,129310,14,129312,129319,14,129328,129328,14,129331,129338,14,129343,129343,14,129351,129355,14,129357,129359,14,129375,129387,14,129393,129393,14,129395,129398,14,129401,129401,14,129403,129403,14,129408,129412,14,129426,129431,14,129443,129444,14,129451,129453,14,129456,129465,14,129472,129472,14,129475,129482,14,129484,129484,14,129488,129510,14,129536,129647,14,129652,129652,14,129656,129658,14,129664,129666,14,129671,129679,14,129686,129704,14,129712,129718,14,129728,129730,14,129744,129750,14,917504,917504,4,917506,917535,4,917632,917759,4,918000,921599,4,0,9,4,11,12,4,14,31,4,169,169,14,174,174,14,1155,1159,5,1425,1469,5,1473,1474,5,1479,1479,5,1552,1562,5,1611,1631,5,1750,1756,5,1759,1764,5,1770,1773,5,1809,1809,5,1958,1968,5,2045,2045,5,2075,2083,5,2089,2093,5,2259,2273,5,2275,2306,5,2362,2362,5,2364,2364,5,2369,2376,5,2381,2381,5,2385,2391,5,2433,2433,5,2492,2492,5,2495,2496,7,2503,2504,7,2509,2509,5,2530,2531,5,2561,2562,5,2620,2620,5,2625,2626,5,2635,2637,5,2672,2673,5,2689,2690,5,2748,2748,5,2753,2757,5,2761,2761,7,2765,2765,5,2810,2815,5,2818,2819,7,2878,2878,5,2880,2880,7,2887,2888,7,2893,2893,5,2903,2903,5,2946,2946,5,3007,3007,7,3009,3010,7,3018,3020,7,3031,3031,5,3073,3075,7,3134,3136,5,3142,3144,5,3157,3158,5,3201,3201,5,3260,3260,5,3263,3263,5,3266,3266,5,3270,3270,5,3274,3275,7,3285,3286,5,3328,3329,5,3387,3388,5,3391,3392,7,3398,3400,7,3405,3405,5,3415,3415,5,3457,3457,5,3530,3530,5,3536,3537,7,3542,3542,5,3551,3551,5,3633,3633,5,3636,3642,5,3761,3761,5,3764,3772,5,3864,3865,5,3895,3895,5,3902,3903,7,3967,3967,7,3974,3975,5,3993,4028,5,4141,4144,5,4146,4151,5,4155,4156,7,4182,4183,7,4190,4192,5,4226,4226,5,4229,4230,5,4253,4253,5,4448,4519,9,4957,4959,5,5938,5940,5,6002,6003,5,6070,6070,7,6078,6085,7,6087,6088,7,6109,6109,5,6158,6158,4,6313,6313,5,6435,6438,7,6441,6443,7,6450,6450,5,6457,6459,5,6681,6682,7,6741,6741,7,6743,6743,7,6752,6752,5,6757,6764,5,6771,6780,5,6832,6845,5,6847,6848,5,6916,6916,7,6965,6965,5,6971,6971,7,6973,6977,7,6979,6980,7,7040,7041,5,7073,7073,7,7078,7079,7,7082,7082,7,7142,7142,5,7144,7145,5,7149,7149,5,7151,7153,5,7204,7211,7,7220,7221,7,7376,7378,5,7393,7393,7,7405,7405,5,7415,7415,7,7616,7673,5,8203,8203,4,8205,8205,13,8232,8232,4,8234,8238,4,8265,8265,14,8293,8293,4,8400,8412,5,8417,8417,5,8421,8432,5,8505,8505,14,8617,8618,14,9000,9000,14,9167,9167,14,9208,9210,14,9642,9643,14,9664,9664,14,9728,9732,14,9735,9741,14,9743,9744,14,9746,9746,14,9750,9751,14,9753,9756,14,9758,9759,14,9761,9761,14,9764,9765,14,9767,9769,14,9771,9773,14,9776,9783,14,9787,9791,14,9793,9793,14,9795,9799,14,9812,9822,14,9824,9824,14,9827,9827,14,9829,9830,14,9832,9832,14,9851,9851,14,9854,9854,14,9856,9861,14,9874,9876,14,9878,9879,14,9881,9881,14,9883,9884,14,9888,9889,14,9895,9895,14,9898,9899,14,9904,9905,14,9917,9918,14,9924,9925,14,9928,9928,14,9934,9935,14,9937,9937,14,9939,9940,14,9961,9962,14,9968,9973,14,9975,9978,14,9981,9981,14,9986,9986,14,9989,9989,14,9998,9998,14,10000,10001,14,10004,10004,14,10013,10013,14,10024,10024,14,10052,10052,14,10060,10060,14,10067,10069,14,10083,10084,14,10133,10135,14,10160,10160,14,10548,10549,14,11035,11036,14,11093,11093,14,11647,11647,5,12330,12333,5,12336,12336,14,12441,12442,5,12953,12953,14,42608,42610,5,42654,42655,5,43010,43010,5,43019,43019,5,43045,43046,5,43052,43052,5,43188,43203,7,43232,43249,5,43302,43309,5,43346,43347,7,43392,43394,5,43443,43443,5,43446,43449,5,43452,43453,5,43493,43493,5,43567,43568,7,43571,43572,7,43587,43587,5,43597,43597,7,43696,43696,5,43703,43704,5,43713,43713,5,43756,43757,5,43765,43765,7,44003,44004,7,44006,44007,7,44009,44010,7,44013,44013,5,44033,44059,12,44061,44087,12,44089,44115,12,44117,44143,12,44145,44171,12,44173,44199,12,44201,44227,12,44229,44255,12,44257,44283,12,44285,44311,12,44313,44339,12,44341,44367,12,44369,44395,12,44397,44423,12,44425,44451,12,44453,44479,12,44481,44507,12,44509,44535,12,44537,44563,12,44565,44591,12,44593,44619,12,44621,44647,12,44649,44675,12,44677,44703,12,44705,44731,12,44733,44759,12,44761,44787,12,44789,44815,12,44817,44843,12,44845,44871,12,44873,44899,12,44901,44927,12,44929,44955,12,44957,44983,12,44985,45011,12,45013,45039,12,45041,45067,12,45069,45095,12,45097,45123,12,45125,45151,12,45153,45179,12,45181,45207,12,45209,45235,12,45237,45263,12,45265,45291,12,45293,45319,12,45321,45347,12,45349,45375,12,45377,45403,12,45405,45431,12,45433,45459,12,45461,45487,12,45489,45515,12,45517,45543,12,45545,45571,12,45573,45599,12,45601,45627,12,45629,45655,12,45657,45683,12,45685,45711,12,45713,45739,12,45741,45767,12,45769,45795,12,45797,45823,12,45825,45851,12,45853,45879,12,45881,45907,12,45909,45935,12,45937,45963,12,45965,45991,12,45993,46019,12,46021,46047,12,46049,46075,12,46077,46103,12,46105,46131,12,46133,46159,12,46161,46187,12,46189,46215,12,46217,46243,12,46245,46271,12,46273,46299,12,46301,46327,12,46329,46355,12,46357,46383,12,46385,46411,12,46413,46439,12,46441,46467,12,46469,46495,12,46497,46523,12,46525,46551,12,46553,46579,12,46581,46607,12,46609,46635,12,46637,46663,12,46665,46691,12,46693,46719,12,46721,46747,12,46749,46775,12,46777,46803,12,46805,46831,12,46833,46859,12,46861,46887,12,46889,46915,12,46917,46943,12,46945,46971,12,46973,46999,12,47001,47027,12,47029,47055,12,47057,47083,12,47085,47111,12,47113,47139,12,47141,47167,12,47169,47195,12,47197,47223,12,47225,47251,12,47253,47279,12,47281,47307,12,47309,47335,12,47337,47363,12,47365,47391,12,47393,47419,12,47421,47447,12,47449,47475,12,47477,47503,12,47505,47531,12,47533,47559,12,47561,47587,12,47589,47615,12,47617,47643,12,47645,47671,12,47673,47699,12,47701,47727,12,47729,47755,12,47757,47783,12,47785,47811,12,47813,47839,12,47841,47867,12,47869,47895,12,47897,47923,12,47925,47951,12,47953,47979,12,47981,48007,12,48009,48035,12,48037,48063,12,48065,48091,12,48093,48119,12,48121,48147,12,48149,48175,12,48177,48203,12,48205,48231,12,48233,48259,12,48261,48287,12,48289,48315,12,48317,48343,12,48345,48371,12,48373,48399,12,48401,48427,12,48429,48455,12,48457,48483,12,48485,48511,12,48513,48539,12,48541,48567,12,48569,48595,12,48597,48623,12,48625,48651,12,48653,48679,12,48681,48707,12,48709,48735,12,48737,48763,12,48765,48791,12,48793,48819,12,48821,48847,12,48849,48875,12,48877,48903,12,48905,48931,12,48933,48959,12,48961,48987,12,48989,49015,12,49017,49043,12,49045,49071,12,49073,49099,12,49101,49127,12,49129,49155,12,49157,49183,12,49185,49211,12,49213,49239,12,49241,49267,12,49269,49295,12,49297,49323,12,49325,49351,12,49353,49379,12,49381,49407,12,49409,49435,12,49437,49463,12,49465,49491,12,49493,49519,12,49521,49547,12,49549,49575,12,49577,49603,12,49605,49631,12,49633,49659,12,49661,49687,12,49689,49715,12,49717,49743,12,49745,49771,12,49773,49799,12,49801,49827,12,49829,49855,12,49857,49883,12,49885,49911,12,49913,49939,12,49941,49967,12,49969,49995,12,49997,50023,12,50025,50051,12,50053,50079,12,50081,50107,12,50109,50135,12,50137,50163,12,50165,50191,12,50193,50219,12,50221,50247,12,50249,50275,12,50277,50303,12,50305,50331,12,50333,50359,12,50361,50387,12,50389,50415,12,50417,50443,12,50445,50471,12,50473,50499,12,50501,50527,12,50529,50555,12,50557,50583,12,50585,50611,12,50613,50639,12,50641,50667,12,50669,50695,12,50697,50723,12,50725,50751,12,50753,50779,12,50781,50807,12,50809,50835,12,50837,50863,12,50865,50891,12,50893,50919,12,50921,50947,12,50949,50975,12,50977,51003,12,51005,51031,12,51033,51059,12,51061,51087,12,51089,51115,12,51117,51143,12,51145,51171,12,51173,51199,12,51201,51227,12,51229,51255,12,51257,51283,12,51285,51311,12,51313,51339,12,51341,51367,12,51369,51395,12,51397,51423,12,51425,51451,12,51453,51479,12,51481,51507,12,51509,51535,12,51537,51563,12,51565,51591,12,51593,51619,12,51621,51647,12,51649,51675,12,51677,51703,12,51705,51731,12,51733,51759,12,51761,51787,12,51789,51815,12,51817,51843,12,51845,51871,12,51873,51899,12,51901,51927,12,51929,51955,12,51957,51983,12,51985,52011,12,52013,52039,12,52041,52067,12,52069,52095,12,52097,52123,12,52125,52151,12,52153,52179,12,52181,52207,12,52209,52235,12,52237,52263,12,52265,52291,12,52293,52319,12,52321,52347,12,52349,52375,12,52377,52403,12,52405,52431,12,52433,52459,12,52461,52487,12,52489,52515,12,52517,52543,12,52545,52571,12,52573,52599,12,52601,52627,12,52629,52655,12,52657,52683,12,52685,52711,12,52713,52739,12,52741,52767,12,52769,52795,12,52797,52823,12,52825,52851,12,52853,52879,12,52881,52907,12,52909,52935,12,52937,52963,12,52965,52991,12,52993,53019,12,53021,53047,12,53049,53075,12,53077,53103,12,53105,53131,12,53133,53159,12,53161,53187,12,53189,53215,12,53217,53243,12,53245,53271,12,53273,53299,12,53301,53327,12,53329,53355,12,53357,53383,12,53385,53411,12,53413,53439,12,53441,53467,12,53469,53495,12,53497,53523,12,53525,53551,12,53553,53579,12,53581,53607,12,53609,53635,12,53637,53663,12,53665,53691,12,53693,53719,12,53721,53747,12,53749,53775,12,53777,53803,12,53805,53831,12,53833,53859,12,53861,53887,12,53889,53915,12,53917,53943,12,53945,53971,12,53973,53999,12,54001,54027,12,54029,54055,12,54057,54083,12,54085,54111,12,54113,54139,12,54141,54167,12,54169,54195,12,54197,54223,12,54225,54251,12,54253,54279,12,54281,54307,12,54309,54335,12,54337,54363,12,54365,54391,12,54393,54419,12,54421,54447,12,54449,54475,12,54477,54503,12,54505,54531,12,54533,54559,12,54561,54587,12,54589,54615,12,54617,54643,12,54645,54671,12,54673,54699,12,54701,54727,12,54729,54755,12,54757,54783,12,54785,54811,12,54813,54839,12,54841,54867,12,54869,54895,12,54897,54923,12,54925,54951,12,54953,54979,12,54981,55007,12,55009,55035,12,55037,55063,12,55065,55091,12,55093,55119,12,55121,55147,12,55149,55175,12,55177,55203,12,55243,55291,10,65024,65039,5,65279,65279,4,65520,65528,4,66045,66045,5,66422,66426,5,68101,68102,5,68152,68154,5,68325,68326,5,69291,69292,5,69632,69632,7,69634,69634,7,69759,69761,5]")}function M(e,n){return(n<<5)-n+e|0}function F(e,n){n=M(149417,n);for(let t=0,r=e.length;t<r;t++)n=M(e.charCodeAt(t),n);return n}function G(e,n,t=32){const r=t-n,a=~((1<<r)-1);return(e<<n|(a&e)>>>r)>>>0}function B(e,n=0,t=e.byteLength,r=0){for(let a=0;a<t;a++)e[n+a]=r}function U(e,n,t="0"){while(e.length<n)e=t+e;return e}function V(e,n=32){return e instanceof ArrayBuffer?Array.from(new Uint8Array(e)).map(e=>e.toString(16).padStart(2,"0")).join(""):U((e>>>0).toString(16),n/4)}w._INSTANCE=null;class j{constructor(){this._h0=1732584193,this._h1=4023233417,this._h2=2562383102,this._h3=271733878,this._h4=3285377520,this._buff=new Uint8Array(67),this._buffDV=new DataView(this._buff.buffer),this._buffLen=0,this._totalLen=0,this._leftoverHighSurrogate=0,this._finished=!1}update(e){const n=e.length;if(0===n)return;const t=this._buff;let r,a,i=this._buffLen,o=this._leftoverHighSurrogate;0!==o?(r=o,a=-1,o=0):(r=e.charCodeAt(0),a=0);while(1){let s=r;if(k(r)){if(!(a+1<n)){o=r;break}{const n=e.charCodeAt(a+1);R(n)?(a++,s=O(r,n)):s=65533}}else R(r)&&(s=65533);if(i=this._push(t,i,s),a++,!(a<n))break;r=e.charCodeAt(a)}this._buffLen=i,this._leftoverHighSurrogate=o}_push(e,n,t){return t<128?e[n++]=t:t<2048?(e[n++]=192|(1984&t)>>>6,e[n++]=128|(63&t)>>>0):t<65536?(e[n++]=224|(61440&t)>>>12,e[n++]=128|(4032&t)>>>6,e[n++]=128|(63&t)>>>0):(e[n++]=240|(1835008&t)>>>18,e[n++]=128|(258048&t)>>>12,e[n++]=128|(4032&t)>>>6,e[n++]=128|(63&t)>>>0),n>=64&&(this._step(),n-=64,this._totalLen+=64,e[0]=e[64],e[1]=e[65],e[2]=e[66]),n}digest(){return this._finished||(this._finished=!0,this._leftoverHighSurrogate&&(this._leftoverHighSurrogate=0,this._buffLen=this._push(this._buff,this._buffLen,65533)),this._totalLen+=this._buffLen,this._wrapUp()),V(this._h0)+V(this._h1)+V(this._h2)+V(this._h3)+V(this._h4)}_wrapUp(){this._buff[this._buffLen++]=128,B(this._buff,this._buffLen),this._buffLen>56&&(this._step(),B(this._buff));const e=8*this._totalLen;this._buffDV.setUint32(56,Math.floor(e/4294967296),!1),this._buffDV.setUint32(60,e%4294967296,!1),this._step()}_step(){const e=j._bigBlock32,n=this._buffDV;for(let u=0;u<64;u+=4)e.setUint32(u,n.getUint32(u,!1),!1);for(let u=64;u<320;u+=4)e.setUint32(u,G(e.getUint32(u-12,!1)^e.getUint32(u-32,!1)^e.getUint32(u-56,!1)^e.getUint32(u-64,!1),1),!1);let t,r,a,i=this._h0,o=this._h1,s=this._h2,c=this._h3,l=this._h4;for(let u=0;u<80;u++)u<20?(t=o&s|~o&c,r=1518500249):u<40?(t=o^s^c,r=1859775393):u<60?(t=o&s|o&c|s&c,r=2400959708):(t=o^s^c,r=3395469782),a=G(i,5)+t+l+r+e.getUint32(4*u,!1)&4294967295,l=c,c=s,s=G(o,30),o=i,i=a;this._h0=this._h0+i&4294967295,this._h1=this._h1+o&4294967295,this._h2=this._h2+s&4294967295,this._h3=this._h3+c&4294967295,this._h4=this._h4+l&4294967295}}j._bigBlock32=new DataView(new ArrayBuffer(320));class K{constructor(e){this.source=e}getElements(){const e=this.source,n=new Int32Array(e.length);for(let t=0,r=e.length;t<r;t++)n[t]=e.charCodeAt(t);return n}}function H(e,n,t){return new J(new K(e),new K(n)).ComputeDiff(t).changes}class W{static Assert(e,n){if(!e)throw new Error(n)}}class z{static Copy(e,n,t,r,a){for(let i=0;i<a;i++)t[r+i]=e[n+i]}static Copy2(e,n,t,r,a){for(let i=0;i<a;i++)t[r+i]=e[n+i]}}class q{constructor(){this.m_changes=[],this.m_originalStart=1073741824,this.m_modifiedStart=1073741824,this.m_originalCount=0,this.m_modifiedCount=0}MarkNextChange(){(this.m_originalCount>0||this.m_modifiedCount>0)&&this.m_changes.push(new A(this.m_originalStart,this.m_originalCount,this.m_modifiedStart,this.m_modifiedCount)),this.m_originalCount=0,this.m_modifiedCount=0,this.m_originalStart=1073741824,this.m_modifiedStart=1073741824}AddOriginalElement(e,n){this.m_originalStart=Math.min(this.m_originalStart,e),this.m_modifiedStart=Math.min(this.m_modifiedStart,n),this.m_originalCount++}AddModifiedElement(e,n){this.m_originalStart=Math.min(this.m_originalStart,e),this.m_modifiedStart=Math.min(this.m_modifiedStart,n),this.m_modifiedCount++}getChanges(){return(this.m_originalCount>0||this.m_modifiedCount>0)&&this.MarkNextChange(),this.m_changes}getReverseChanges(){return(this.m_originalCount>0||this.m_modifiedCount>0)&&this.MarkNextChange(),this.m_changes.reverse(),this.m_changes}}class J{constructor(e,n,t=null){this.ContinueProcessingPredicate=t,this._originalSequence=e,this._modifiedSequence=n;const[r,a,i]=J._getElements(e),[o,s,c]=J._getElements(n);this._hasStrings=i&&c,this._originalStringElements=r,this._originalElementsOrHash=a,this._modifiedStringElements=o,this._modifiedElementsOrHash=s,this.m_forwardHistory=[],this.m_reverseHistory=[]}static _isStringArray(e){return e.length>0&&"string"===typeof e[0]}static _getElements(e){const n=e.getElements();if(J._isStringArray(n)){const e=new Int32Array(n.length);for(let t=0,r=n.length;t<r;t++)e[t]=F(n[t],0);return[n,e,!0]}return n instanceof Int32Array?[[],n,!1]:[[],new Int32Array(n),!1]}ElementsAreEqual(e,n){return this._originalElementsOrHash[e]===this._modifiedElementsOrHash[n]&&(!this._hasStrings||this._originalStringElements[e]===this._modifiedStringElements[n])}ElementsAreStrictEqual(e,n){if(!this.ElementsAreEqual(e,n))return!1;const t=J._getStrictElement(this._originalSequence,e),r=J._getStrictElement(this._modifiedSequence,n);return t===r}static _getStrictElement(e,n){return"function"===typeof e.getStrictElement?e.getStrictElement(n):null}OriginalElementsAreEqual(e,n){return this._originalElementsOrHash[e]===this._originalElementsOrHash[n]&&(!this._hasStrings||this._originalStringElements[e]===this._originalStringElements[n])}ModifiedElementsAreEqual(e,n){return this._modifiedElementsOrHash[e]===this._modifiedElementsOrHash[n]&&(!this._hasStrings||this._modifiedStringElements[e]===this._modifiedStringElements[n])}ComputeDiff(e){return this._ComputeDiff(0,this._originalElementsOrHash.length-1,0,this._modifiedElementsOrHash.length-1,e)}_ComputeDiff(e,n,t,r,a){const i=[!1];let o=this.ComputeDiffRecursive(e,n,t,r,i);return a&&(o=this.PrettifyChanges(o)),{quitEarly:i[0],changes:o}}ComputeDiffRecursive(e,n,t,r,a){a[0]=!1;while(e<=n&&t<=r&&this.ElementsAreEqual(e,t))e++,t++;while(n>=e&&r>=t&&this.ElementsAreEqual(n,r))n--,r--;if(e>n||t>r){let a;return t<=r?(W.Assert(e===n+1,"originalStart should only be one more than originalEnd"),a=[new A(e,0,t,r-t+1)]):e<=n?(W.Assert(t===r+1,"modifiedStart should only be one more than modifiedEnd"),a=[new A(e,n-e+1,t,0)]):(W.Assert(e===n+1,"originalStart should only be one more than originalEnd"),W.Assert(t===r+1,"modifiedStart should only be one more than modifiedEnd"),a=[]),a}const i=[0],o=[0],s=this.ComputeRecursionPoint(e,n,t,r,i,o,a),c=i[0],l=o[0];if(null!==s)return s;if(!a[0]){const i=this.ComputeDiffRecursive(e,c,t,l,a);let o=[];return o=a[0]?[new A(c+1,n-(c+1)+1,l+1,r-(l+1)+1)]:this.ComputeDiffRecursive(c+1,n,l+1,r,a),this.ConcatenateChanges(i,o)}return[new A(e,n-e+1,t,r-t+1)]}WALKTRACE(e,n,t,r,a,i,o,s,c,l,u,d,p,f,m,_,g,y){let h=null,v=null,b=new q,E=n,T=t,S=p[0]-_[0]-r,x=-1073741824,L=this.m_forwardHistory.length-1;do{const n=S+e;n===E||n<T&&c[n-1]<c[n+1]?(u=c[n+1],f=u-S-r,u<x&&b.MarkNextChange(),x=u,b.AddModifiedElement(u+1,f),S=n+1-e):(u=c[n-1]+1,f=u-S-r,u<x&&b.MarkNextChange(),x=u-1,b.AddOriginalElement(u,f+1),S=n-1-e),L>=0&&(c=this.m_forwardHistory[L],e=c[0],E=1,T=c.length-1)}while(--L>=-1);if(h=b.getReverseChanges(),y[0]){let e=p[0]+1,n=_[0]+1;if(null!==h&&h.length>0){const t=h[h.length-1];e=Math.max(e,t.getOriginalEnd()),n=Math.max(n,t.getModifiedEnd())}v=[new A(e,d-e+1,n,m-n+1)]}else{b=new q,E=i,T=o,S=p[0]-_[0]-s,x=1073741824,L=g?this.m_reverseHistory.length-1:this.m_reverseHistory.length-2;do{const e=S+a;e===E||e<T&&l[e-1]>=l[e+1]?(u=l[e+1]-1,f=u-S-s,u>x&&b.MarkNextChange(),x=u+1,b.AddOriginalElement(u+1,f+1),S=e+1-a):(u=l[e-1],f=u-S-s,u>x&&b.MarkNextChange(),x=u,b.AddModifiedElement(u+1,f+1),S=e-1-a),L>=0&&(l=this.m_reverseHistory[L],a=l[0],E=1,T=l.length-1)}while(--L>=-1);v=b.getChanges()}return this.ConcatenateChanges(h,v)}ComputeRecursionPoint(e,n,t,r,a,i,o){let s=0,c=0,l=0,u=0,d=0,p=0;e--,t--,a[0]=0,i[0]=0,this.m_forwardHistory=[],this.m_reverseHistory=[];const f=n-e+(r-t),m=f+1,_=new Int32Array(m),g=new Int32Array(m),y=r-t,h=n-e,v=e-t,b=n-r,E=h-y,T=E%2===0;_[y]=e,g[h]=n,o[0]=!1;for(let S=1;S<=f/2+1;S++){let f=0,E=0;l=this.ClipDiagonalBound(y-S,S,y,m),u=this.ClipDiagonalBound(y+S,S,y,m);for(let e=l;e<=u;e+=2){s=e===l||e<u&&_[e-1]<_[e+1]?_[e+1]:_[e-1]+1,c=s-(e-y)-v;const t=s;while(s<n&&c<r&&this.ElementsAreEqual(s+1,c+1))s++,c++;if(_[e]=s,s+c>f+E&&(f=s,E=c),!T&&Math.abs(e-h)<=S-1&&s>=g[e])return a[0]=s,i[0]=c,t<=g[e]&&S<=1448?this.WALKTRACE(y,l,u,v,h,d,p,b,_,g,s,n,a,c,r,i,T,o):null}const x=(f-e+(E-t)-S)/2;if(null!==this.ContinueProcessingPredicate&&!this.ContinueProcessingPredicate(f,x))return o[0]=!0,a[0]=f,i[0]=E,x>0&&S<=1448?this.WALKTRACE(y,l,u,v,h,d,p,b,_,g,s,n,a,c,r,i,T,o):(e++,t++,[new A(e,n-e+1,t,r-t+1)]);d=this.ClipDiagonalBound(h-S,S,h,m),p=this.ClipDiagonalBound(h+S,S,h,m);for(let m=d;m<=p;m+=2){s=m===d||m<p&&g[m-1]>=g[m+1]?g[m+1]-1:g[m-1],c=s-(m-h)-b;const f=s;while(s>e&&c>t&&this.ElementsAreEqual(s,c))s--,c--;if(g[m]=s,T&&Math.abs(m-y)<=S&&s<=_[m])return a[0]=s,i[0]=c,f>=_[m]&&S<=1448?this.WALKTRACE(y,l,u,v,h,d,p,b,_,g,s,n,a,c,r,i,T,o):null}if(S<=1447){let e=new Int32Array(u-l+2);e[0]=y-l+1,z.Copy2(_,l,e,1,u-l+1),this.m_forwardHistory.push(e),e=new Int32Array(p-d+2),e[0]=h-d+1,z.Copy2(g,d,e,1,p-d+1),this.m_reverseHistory.push(e)}}return this.WALKTRACE(y,l,u,v,h,d,p,b,_,g,s,n,a,c,r,i,T,o)}PrettifyChanges(e){for(let n=0;n<e.length;n++){const t=e[n],r=n<e.length-1?e[n+1].originalStart:this._originalElementsOrHash.length,a=n<e.length-1?e[n+1].modifiedStart:this._modifiedElementsOrHash.length,i=t.originalLength>0,o=t.modifiedLength>0;while(t.originalStart+t.originalLength<r&&t.modifiedStart+t.modifiedLength<a&&(!i||this.OriginalElementsAreEqual(t.originalStart,t.originalStart+t.originalLength))&&(!o||this.ModifiedElementsAreEqual(t.modifiedStart,t.modifiedStart+t.modifiedLength))){const e=this.ElementsAreStrictEqual(t.originalStart,t.modifiedStart),n=this.ElementsAreStrictEqual(t.originalStart+t.originalLength,t.modifiedStart+t.modifiedLength);if(n&&!e)break;t.originalStart++,t.modifiedStart++}let s=[null];n<e.length-1&&this.ChangesOverlap(e[n],e[n+1],s)&&(e[n]=s[0],e.splice(n+1,1),n--)}for(let n=e.length-1;n>=0;n--){const t=e[n];let r=0,a=0;if(n>0){const t=e[n-1];r=t.originalStart+t.originalLength,a=t.modifiedStart+t.modifiedLength}const i=t.originalLength>0,o=t.modifiedLength>0;let s=0,c=this._boundaryScore(t.originalStart,t.originalLength,t.modifiedStart,t.modifiedLength);for(let e=1;;e++){const n=t.originalStart-e,l=t.modifiedStart-e;if(n<r||l<a)break;if(i&&!this.OriginalElementsAreEqual(n,n+t.originalLength))break;if(o&&!this.ModifiedElementsAreEqual(l,l+t.modifiedLength))break;const u=n===r&&l===a,d=(u?5:0)+this._boundaryScore(n,t.originalLength,l,t.modifiedLength);d>c&&(c=d,s=e)}t.originalStart-=s,t.modifiedStart-=s;const l=[null];n>0&&this.ChangesOverlap(e[n-1],e[n],l)&&(e[n-1]=l[0],e.splice(n,1),n++)}if(this._hasStrings)for(let n=1,t=e.length;n<t;n++){const t=e[n-1],r=e[n],a=r.originalStart-t.originalStart-t.originalLength,i=t.originalStart,o=r.originalStart+r.originalLength,s=o-i,c=t.modifiedStart,l=r.modifiedStart+r.modifiedLength,u=l-c;if(a<5&&s<20&&u<20){const e=this._findBetterContiguousSequence(i,s,c,u,a);if(e){const[n,i]=e;n===t.originalStart+t.originalLength&&i===t.modifiedStart+t.modifiedLength||(t.originalLength=n-t.originalStart,t.modifiedLength=i-t.modifiedStart,r.originalStart=n+a,r.modifiedStart=i+a,r.originalLength=o-r.originalStart,r.modifiedLength=l-r.modifiedStart)}}}return e}_findBetterContiguousSequence(e,n,t,r,a){if(n<a||r<a)return null;const i=e+n-a+1,o=t+r-a+1;let s=0,c=0,l=0;for(let u=e;u<i;u++)for(let e=t;e<o;e++){const n=this._contiguousSequenceScore(u,e,a);n>0&&n>s&&(s=n,c=u,l=e)}return s>0?[c,l]:null}_contiguousSequenceScore(e,n,t){let r=0;for(let a=0;a<t;a++){if(!this.ElementsAreEqual(e+a,n+a))return 0;r+=this._originalStringElements[e+a].length}return r}_OriginalIsBoundary(e){return e<=0||e>=this._originalElementsOrHash.length-1||this._hasStrings&&/^\s*$/.test(this._originalStringElements[e])}_OriginalRegionIsBoundary(e,n){if(this._OriginalIsBoundary(e)||this._OriginalIsBoundary(e-1))return!0;if(n>0){const t=e+n;if(this._OriginalIsBoundary(t-1)||this._OriginalIsBoundary(t))return!0}return!1}_ModifiedIsBoundary(e){return e<=0||e>=this._modifiedElementsOrHash.length-1||this._hasStrings&&/^\s*$/.test(this._modifiedStringElements[e])}_ModifiedRegionIsBoundary(e,n){if(this._ModifiedIsBoundary(e)||this._ModifiedIsBoundary(e-1))return!0;if(n>0){const t=e+n;if(this._ModifiedIsBoundary(t-1)||this._ModifiedIsBoundary(t))return!0}return!1}_boundaryScore(e,n,t,r){const a=this._OriginalRegionIsBoundary(e,n)?1:0,i=this._ModifiedRegionIsBoundary(t,r)?1:0;return a+i}ConcatenateChanges(e,n){let t=[];if(0===e.length||0===n.length)return n.length>0?n:e;if(this.ChangesOverlap(e[e.length-1],n[0],t)){const r=new Array(e.length+n.length-1);return z.Copy(e,0,r,0,e.length-1),r[e.length-1]=t[0],z.Copy(n,1,r,e.length,n.length-1),r}{const t=new Array(e.length+n.length);return z.Copy(e,0,t,0,e.length),z.Copy(n,0,t,e.length,n.length),t}}ChangesOverlap(e,n,t){if(W.Assert(e.originalStart<=n.originalStart,"Left change is not less than or equal to right change"),W.Assert(e.modifiedStart<=n.modifiedStart,"Left change is not less than or equal to right change"),e.originalStart+e.originalLength>=n.originalStart||e.modifiedStart+e.modifiedLength>=n.modifiedStart){const r=e.originalStart;let a=e.originalLength;const i=e.modifiedStart;let o=e.modifiedLength;return e.originalStart+e.originalLength>=n.originalStart&&(a=n.originalStart+n.originalLength-e.originalStart),e.modifiedStart+e.modifiedLength>=n.modifiedStart&&(o=n.modifiedStart+n.modifiedLength-e.modifiedStart),t[0]=new A(r,a,i,o),!0}return t[0]=null,!1}ClipDiagonalBound(e,n,t,r){if(e>=0&&e<r)return e;const a=t,i=r-t-1,o=n%2===0;if(e<0){const e=a%2===0;return o===e?0:1}{const e=i%2===0;return o===e?r-1:r-2}}}var X=t("c317");const Y=65,Q=97,Z=90,$=122,ee=46,ne=47,te=92,re=58,ae=63;class ie extends Error{constructor(e,n,t){let r;"string"===typeof n&&0===n.indexOf("not ")?(r="must not be",n=n.replace(/^not /,"")):r="must be";const a=-1!==e.indexOf(".")?"property":"argument";let i=`The "${e}" ${a} ${r} of type ${n}`;i+=". Received type "+typeof t,super(i),this.code="ERR_INVALID_ARG_TYPE"}}function oe(e,n){if("string"!==typeof e)throw new ie(n,"string",e)}function se(e){return e===ne||e===te}function ce(e){return e===ne}function le(e){return e>=Y&&e<=Z||e>=Q&&e<=$}function ue(e,n,t,r){let a="",i=0,o=-1,s=0,c=0;for(let l=0;l<=e.length;++l){if(l<e.length)c=e.charCodeAt(l);else{if(r(c))break;c=ne}if(r(c)){if(o===l-1||1===s);else if(2===s){if(a.length<2||2!==i||a.charCodeAt(a.length-1)!==ee||a.charCodeAt(a.length-2)!==ee){if(a.length>2){const e=a.lastIndexOf(t);-1===e?(a="",i=0):(a=a.slice(0,e),i=a.length-1-a.lastIndexOf(t)),o=l,s=0;continue}if(0!==a.length){a="",i=0,o=l,s=0;continue}}n&&(a+=a.length>0?t+"..":"..",i=2)}else a.length>0?a+=`${t}${e.slice(o+1,l)}`:a=e.slice(o+1,l),i=l-o-1;o=l,s=0}else c===ee&&-1!==s?++s:s=-1}return a}function de(e,n){if(null===n||"object"!==typeof n)throw new ie("pathObject","Object",n);const t=n.dir||n.root,r=n.base||`${n.name||""}${n.ext||""}`;return t?t===n.root?`${t}${r}`:`${t}${e}${r}`:r}const pe={resolve(...e){let n="",t="",r=!1;for(let a=e.length-1;a>=-1;a--){let i;if(a>=0){if(i=e[a],oe(i,"path"),0===i.length)continue}else 0===n.length?i=X["a"]():(i=X["b"]["="+n]||X["a"](),(void 0===i||i.slice(0,2).toLowerCase()!==n.toLowerCase()&&i.charCodeAt(2)===te)&&(i=n+"\\"));const o=i.length;let s=0,c="",l=!1;const u=i.charCodeAt(0);if(1===o)se(u)&&(s=1,l=!0);else if(se(u))if(l=!0,se(i.charCodeAt(1))){let e=2,n=e;while(e<o&&!se(i.charCodeAt(e)))e++;if(e<o&&e!==n){const t=i.slice(n,e);n=e;while(e<o&&se(i.charCodeAt(e)))e++;if(e<o&&e!==n){n=e;while(e<o&&!se(i.charCodeAt(e)))e++;e!==o&&e===n||(c=`\\\\${t}\\${i.slice(n,e)}`,s=e)}}}else s=1;else le(u)&&i.charCodeAt(1)===re&&(c=i.slice(0,2),s=2,o>2&&se(i.charCodeAt(2))&&(l=!0,s=3));if(c.length>0)if(n.length>0){if(c.toLowerCase()!==n.toLowerCase())continue}else n=c;if(r){if(n.length>0)break}else if(t=`${i.slice(s)}\\${t}`,r=l,l&&n.length>0)break}return t=ue(t,!r,"\\",se),r?`${n}\\${t}`:`${n}${t}`||"."},normalize(e){oe(e,"path");const n=e.length;if(0===n)return".";let t,r=0,a=!1;const i=e.charCodeAt(0);if(1===n)return ce(i)?"\\":e;if(se(i))if(a=!0,se(e.charCodeAt(1))){let a=2,i=a;while(a<n&&!se(e.charCodeAt(a)))a++;if(a<n&&a!==i){const o=e.slice(i,a);i=a;while(a<n&&se(e.charCodeAt(a)))a++;if(a<n&&a!==i){i=a;while(a<n&&!se(e.charCodeAt(a)))a++;if(a===n)return`\\\\${o}\\${e.slice(i)}\\`;a!==i&&(t=`\\\\${o}\\${e.slice(i,a)}`,r=a)}}}else r=1;else le(i)&&e.charCodeAt(1)===re&&(t=e.slice(0,2),r=2,n>2&&se(e.charCodeAt(2))&&(a=!0,r=3));let o=r<n?ue(e.slice(r),!a,"\\",se):"";return 0!==o.length||a||(o="."),o.length>0&&se(e.charCodeAt(n-1))&&(o+="\\"),void 0===t?a?"\\"+o:o:a?`${t}\\${o}`:`${t}${o}`},isAbsolute(e){oe(e,"path");const n=e.length;if(0===n)return!1;const t=e.charCodeAt(0);return se(t)||n>2&&le(t)&&e.charCodeAt(1)===re&&se(e.charCodeAt(2))},join(...e){if(0===e.length)return".";let n,t;for(let i=0;i<e.length;++i){const r=e[i];oe(r,"path"),r.length>0&&(void 0===n?n=t=r:n+="\\"+r)}if(void 0===n)return".";let r=!0,a=0;if("string"===typeof t&&se(t.charCodeAt(0))){++a;const e=t.length;e>1&&se(t.charCodeAt(1))&&(++a,e>2&&(se(t.charCodeAt(2))?++a:r=!1))}if(r){while(a<n.length&&se(n.charCodeAt(a)))a++;a>=2&&(n="\\"+n.slice(a))}return pe.normalize(n)},relative(e,n){if(oe(e,"from"),oe(n,"to"),e===n)return"";const t=pe.resolve(e),r=pe.resolve(n);if(t===r)return"";if(e=t.toLowerCase(),n=r.toLowerCase(),e===n)return"";let a=0;while(a<e.length&&e.charCodeAt(a)===te)a++;let i=e.length;while(i-1>a&&e.charCodeAt(i-1)===te)i--;const o=i-a;let s=0;while(s<n.length&&n.charCodeAt(s)===te)s++;let c=n.length;while(c-1>s&&n.charCodeAt(c-1)===te)c--;const l=c-s,u=o<l?o:l;let d=-1,p=0;for(;p<u;p++){const t=e.charCodeAt(a+p);if(t!==n.charCodeAt(s+p))break;t===te&&(d=p)}if(p!==u){if(-1===d)return r}else{if(l>u){if(n.charCodeAt(s+p)===te)return r.slice(s+p+1);if(2===p)return r.slice(s+p)}o>u&&(e.charCodeAt(a+p)===te?d=p:2===p&&(d=3)),-1===d&&(d=0)}let f="";for(p=a+d+1;p<=i;++p)p!==i&&e.charCodeAt(p)!==te||(f+=0===f.length?"..":"\\..");return s+=d,f.length>0?`${f}${r.slice(s,c)}`:(r.charCodeAt(s)===te&&++s,r.slice(s,c))},toNamespacedPath(e){if("string"!==typeof e)return e;if(0===e.length)return"";const n=pe.resolve(e);if(n.length<=2)return e;if(n.charCodeAt(0)===te){if(n.charCodeAt(1)===te){const e=n.charCodeAt(2);if(e!==ae&&e!==ee)return"\\\\?\\UNC\\"+n.slice(2)}}else if(le(n.charCodeAt(0))&&n.charCodeAt(1)===re&&n.charCodeAt(2)===te)return"\\\\?\\"+n;return e},dirname(e){oe(e,"path");const n=e.length;if(0===n)return".";let t=-1,r=0;const a=e.charCodeAt(0);if(1===n)return se(a)?e:".";if(se(a)){if(t=r=1,se(e.charCodeAt(1))){let a=2,i=a;while(a<n&&!se(e.charCodeAt(a)))a++;if(a<n&&a!==i){i=a;while(a<n&&se(e.charCodeAt(a)))a++;if(a<n&&a!==i){i=a;while(a<n&&!se(e.charCodeAt(a)))a++;if(a===n)return e;a!==i&&(t=r=a+1)}}}}else le(a)&&e.charCodeAt(1)===re&&(t=n>2&&se(e.charCodeAt(2))?3:2,r=t);let i=-1,o=!0;for(let s=n-1;s>=r;--s)if(se(e.charCodeAt(s))){if(!o){i=s;break}}else o=!1;if(-1===i){if(-1===t)return".";i=t}return e.slice(0,i)},basename(e,n){void 0!==n&&oe(n,"ext"),oe(e,"path");let t,r=0,a=-1,i=!0;if(e.length>=2&&le(e.charCodeAt(0))&&e.charCodeAt(1)===re&&(r=2),void 0!==n&&n.length>0&&n.length<=e.length){if(n===e)return"";let o=n.length-1,s=-1;for(t=e.length-1;t>=r;--t){const c=e.charCodeAt(t);if(se(c)){if(!i){r=t+1;break}}else-1===s&&(i=!1,s=t+1),o>=0&&(c===n.charCodeAt(o)?-1===--o&&(a=t):(o=-1,a=s))}return r===a?a=s:-1===a&&(a=e.length),e.slice(r,a)}for(t=e.length-1;t>=r;--t)if(se(e.charCodeAt(t))){if(!i){r=t+1;break}}else-1===a&&(i=!1,a=t+1);return-1===a?"":e.slice(r,a)},extname(e){oe(e,"path");let n=0,t=-1,r=0,a=-1,i=!0,o=0;e.length>=2&&e.charCodeAt(1)===re&&le(e.charCodeAt(0))&&(n=r=2);for(let s=e.length-1;s>=n;--s){const n=e.charCodeAt(s);if(se(n)){if(!i){r=s+1;break}}else-1===a&&(i=!1,a=s+1),n===ee?-1===t?t=s:1!==o&&(o=1):-1!==t&&(o=-1)}return-1===t||-1===a||0===o||1===o&&t===a-1&&t===r+1?"":e.slice(t,a)},format:de.bind(null,"\\"),parse(e){oe(e,"path");const n={root:"",dir:"",base:"",ext:"",name:""};if(0===e.length)return n;const t=e.length;let r=0,a=e.charCodeAt(0);if(1===t)return se(a)?(n.root=n.dir=e,n):(n.base=n.name=e,n);if(se(a)){if(r=1,se(e.charCodeAt(1))){let n=2,a=n;while(n<t&&!se(e.charCodeAt(n)))n++;if(n<t&&n!==a){a=n;while(n<t&&se(e.charCodeAt(n)))n++;if(n<t&&n!==a){a=n;while(n<t&&!se(e.charCodeAt(n)))n++;n===t?r=n:n!==a&&(r=n+1)}}}}else if(le(a)&&e.charCodeAt(1)===re){if(t<=2)return n.root=n.dir=e,n;if(r=2,se(e.charCodeAt(2))){if(3===t)return n.root=n.dir=e,n;r=3}}r>0&&(n.root=e.slice(0,r));let i=-1,o=r,s=-1,c=!0,l=e.length-1,u=0;for(;l>=r;--l)if(a=e.charCodeAt(l),se(a)){if(!c){o=l+1;break}}else-1===s&&(c=!1,s=l+1),a===ee?-1===i?i=l:1!==u&&(u=1):-1!==i&&(u=-1);return-1!==s&&(-1===i||0===u||1===u&&i===s-1&&i===o+1?n.base=n.name=e.slice(o,s):(n.name=e.slice(o,i),n.base=e.slice(o,s),n.ext=e.slice(i,s))),n.dir=o>0&&o!==r?e.slice(0,o-1):n.root,n},sep:"\\",delimiter:";",win32:null,posix:null},fe={resolve(...e){let n="",t=!1;for(let r=e.length-1;r>=-1&&!t;r--){const a=r>=0?e[r]:X["a"]();oe(a,"path"),0!==a.length&&(n=`${a}/${n}`,t=a.charCodeAt(0)===ne)}return n=ue(n,!t,"/",ce),t?"/"+n:n.length>0?n:"."},normalize(e){if(oe(e,"path"),0===e.length)return".";const n=e.charCodeAt(0)===ne,t=e.charCodeAt(e.length-1)===ne;return e=ue(e,!n,"/",ce),0===e.length?n?"/":t?"./":".":(t&&(e+="/"),n?"/"+e:e)},isAbsolute(e){return oe(e,"path"),e.length>0&&e.charCodeAt(0)===ne},join(...e){if(0===e.length)return".";let n;for(let t=0;t<e.length;++t){const r=e[t];oe(r,"path"),r.length>0&&(void 0===n?n=r:n+="/"+r)}return void 0===n?".":fe.normalize(n)},relative(e,n){if(oe(e,"from"),oe(n,"to"),e===n)return"";if(e=fe.resolve(e),n=fe.resolve(n),e===n)return"";const t=1,r=e.length,a=r-t,i=1,o=n.length-i,s=a<o?a:o;let c=-1,l=0;for(;l<s;l++){const r=e.charCodeAt(t+l);if(r!==n.charCodeAt(i+l))break;r===ne&&(c=l)}if(l===s)if(o>s){if(n.charCodeAt(i+l)===ne)return n.slice(i+l+1);if(0===l)return n.slice(i+l)}else a>s&&(e.charCodeAt(t+l)===ne?c=l:0===l&&(c=0));let u="";for(l=t+c+1;l<=r;++l)l!==r&&e.charCodeAt(l)!==ne||(u+=0===u.length?"..":"/..");return`${u}${n.slice(i+c)}`},toNamespacedPath(e){return e},dirname(e){if(oe(e,"path"),0===e.length)return".";const n=e.charCodeAt(0)===ne;let t=-1,r=!0;for(let a=e.length-1;a>=1;--a)if(e.charCodeAt(a)===ne){if(!r){t=a;break}}else r=!1;return-1===t?n?"/":".":n&&1===t?"//":e.slice(0,t)},basename(e,n){void 0!==n&&oe(n,"ext"),oe(e,"path");let t,r=0,a=-1,i=!0;if(void 0!==n&&n.length>0&&n.length<=e.length){if(n===e)return"";let o=n.length-1,s=-1;for(t=e.length-1;t>=0;--t){const c=e.charCodeAt(t);if(c===ne){if(!i){r=t+1;break}}else-1===s&&(i=!1,s=t+1),o>=0&&(c===n.charCodeAt(o)?-1===--o&&(a=t):(o=-1,a=s))}return r===a?a=s:-1===a&&(a=e.length),e.slice(r,a)}for(t=e.length-1;t>=0;--t)if(e.charCodeAt(t)===ne){if(!i){r=t+1;break}}else-1===a&&(i=!1,a=t+1);return-1===a?"":e.slice(r,a)},extname(e){oe(e,"path");let n=-1,t=0,r=-1,a=!0,i=0;for(let o=e.length-1;o>=0;--o){const s=e.charCodeAt(o);if(s!==ne)-1===r&&(a=!1,r=o+1),s===ee?-1===n?n=o:1!==i&&(i=1):-1!==n&&(i=-1);else if(!a){t=o+1;break}}return-1===n||-1===r||0===i||1===i&&n===r-1&&n===t+1?"":e.slice(n,r)},format:de.bind(null,"/"),parse(e){oe(e,"path");const n={root:"",dir:"",base:"",ext:"",name:""};if(0===e.length)return n;const t=e.charCodeAt(0)===ne;let r;t?(n.root="/",r=1):r=0;let a=-1,i=0,o=-1,s=!0,c=e.length-1,l=0;for(;c>=r;--c){const n=e.charCodeAt(c);if(n!==ne)-1===o&&(s=!1,o=c+1),n===ee?-1===a?a=c:1!==l&&(l=1):-1!==a&&(l=-1);else if(!s){i=c+1;break}}if(-1!==o){const r=0===i&&t?1:i;-1===a||0===l||1===l&&a===o-1&&a===i+1?n.base=n.name=e.slice(r,o):(n.name=e.slice(r,a),n.base=e.slice(r,o),n.ext=e.slice(a,o))}return i>0?n.dir=e.slice(0,i-1):t&&(n.dir="/"),n},sep:"/",delimiter:":",win32:null,posix:null};fe.win32=pe.win32=pe,fe.posix=pe.posix=fe;"win32"===X["c"]?pe.normalize:fe.normalize,"win32"===X["c"]?pe.resolve:fe.resolve,"win32"===X["c"]?pe.relative:fe.relative,"win32"===X["c"]?pe.dirname:fe.dirname,"win32"===X["c"]?pe.basename:fe.basename,"win32"===X["c"]?pe.extname:fe.extname,"win32"===X["c"]?pe.sep:fe.sep;const me=/^\w[\w\d+.-]*$/,_e=/^\//,ge=/^\/\//;function ye(e,n){if(!e.scheme&&n)throw new Error(`[UriError]: Scheme is missing: {scheme: "", authority: "${e.authority}", path: "${e.path}", query: "${e.query}", fragment: "${e.fragment}"}`);if(e.scheme&&!me.test(e.scheme))throw new Error("[UriError]: Scheme contains illegal characters.");if(e.path)if(e.authority){if(!_e.test(e.path))throw new Error('[UriError]: If a URI contains an authority component, then the path component must either be empty or begin with a slash ("/") character')}else if(ge.test(e.path))throw new Error('[UriError]: If a URI does not contain an authority component, then the path cannot begin with two slash characters ("//")')}function he(e,n){return e||n?e:"file"}function ve(e,n){switch(e){case"https":case"http":case"file":n?n[0]!==Ee&&(n=Ee+n):n=Ee;break}return n}const be="",Ee="/",Te=/^(([^:/?#]+?):)?(\/\/([^/?#]*))?([^?#]*)(\?([^#]*))?(#(.*))?/;class Se{constructor(e,n,t,r,a,i=!1){"object"===typeof e?(this.scheme=e.scheme||be,this.authority=e.authority||be,this.path=e.path||be,this.query=e.query||be,this.fragment=e.fragment||be):(this.scheme=he(e,i),this.authority=n||be,this.path=ve(this.scheme,t||be),this.query=r||be,this.fragment=a||be,ye(this,i))}static isUri(e){return e instanceof Se||!!e&&("string"===typeof e.authority&&"string"===typeof e.fragment&&"string"===typeof e.path&&"string"===typeof e.query&&"string"===typeof e.scheme&&"string"===typeof e.fsPath&&"function"===typeof e.with&&"function"===typeof e.toString)}get fsPath(){return Ie(this,!1)}with(e){if(!e)return this;let{scheme:n,authority:t,path:r,query:a,fragment:i}=e;return void 0===n?n=this.scheme:null===n&&(n=be),void 0===t?t=this.authority:null===t&&(t=be),void 0===r?r=this.path:null===r&&(r=be),void 0===a?a=this.query:null===a&&(a=be),void 0===i?i=this.fragment:null===i&&(i=be),n===this.scheme&&t===this.authority&&r===this.path&&a===this.query&&i===this.fragment?this:new Le(n,t,r,a,i)}static parse(e,n=!1){const t=Te.exec(e);return t?new Le(t[2]||be,Oe(t[4]||be),Oe(t[5]||be),Oe(t[7]||be),Oe(t[9]||be),n):new Le(be,be,be,be,be)}static file(e){let n=be;if(b["d"]&&(e=e.replace(/\\/g,Ee)),e[0]===Ee&&e[1]===Ee){const t=e.indexOf(Ee,2);-1===t?(n=e.substring(2),e=Ee):(n=e.substring(2,t),e=e.substring(t)||Ee)}return new Le("file",n,e,be,be)}static from(e){const n=new Le(e.scheme,e.authority,e.path,e.query,e.fragment);return ye(n,!0),n}static joinPath(e,...n){if(!e.path)throw new Error("[UriError]: cannot call joinPath on URI without path");let t;return t=b["d"]&&"file"===e.scheme?Se.file(pe.join(Ie(e,!0),...n)).path:fe.join(e.path,...n),e.with({path:t})}toString(e=!1){return Ne(this,e)}toJSON(){return this}static revive(e){if(e){if(e instanceof Se)return e;{const n=new Le(e);return n._formatted=e.external,n._fsPath=e._sep===xe?e.fsPath:null,n}}return e}}const xe=b["d"]?1:void 0;class Le extends Se{constructor(){super(...arguments),this._formatted=null,this._fsPath=null}get fsPath(){return this._fsPath||(this._fsPath=Ie(this,!1)),this._fsPath}toString(e=!1){return e?Ne(this,!0):(this._formatted||(this._formatted=Ne(this,!1)),this._formatted)}toJSON(){const e={$mid:1};return this._fsPath&&(e.fsPath=this._fsPath,e._sep=xe),this._formatted&&(e.external=this._formatted),this.path&&(e.path=this.path),this.scheme&&(e.scheme=this.scheme),this.authority&&(e.authority=this.authority),this.query&&(e.query=this.query),this.fragment&&(e.fragment=this.fragment),e}}const De={[58]:"%3A",[47]:"%2F",[63]:"%3F",[35]:"%23",[91]:"%5B",[93]:"%5D",[64]:"%40",[33]:"%21",[36]:"%24",[38]:"%26",[39]:"%27",[40]:"%28",[41]:"%29",[42]:"%2A",[43]:"%2B",[44]:"%2C",[59]:"%3B",[61]:"%3D",[32]:"%20"};function Ae(e,n){let t=void 0,r=-1;for(let a=0;a<e.length;a++){const i=e.charCodeAt(a);if(i>=97&&i<=122||i>=65&&i<=90||i>=48&&i<=57||45===i||46===i||95===i||126===i||n&&47===i)-1!==r&&(t+=encodeURIComponent(e.substring(r,a)),r=-1),void 0!==t&&(t+=e.charAt(a));else{void 0===t&&(t=e.substr(0,a));const n=De[i];void 0!==n?(-1!==r&&(t+=encodeURIComponent(e.substring(r,a)),r=-1),t+=n):-1===r&&(r=a)}}return-1!==r&&(t+=encodeURIComponent(e.substring(r))),void 0!==t?t:e}function Ce(e){let n=void 0;for(let t=0;t<e.length;t++){const r=e.charCodeAt(t);35===r||63===r?(void 0===n&&(n=e.substr(0,t)),n+=De[r]):void 0!==n&&(n+=e[t])}return void 0!==n?n:e}function Ie(e,n){let t;return t=e.authority&&e.path.length>1&&"file"===e.scheme?`//${e.authority}${e.path}`:47===e.path.charCodeAt(0)&&(e.path.charCodeAt(1)>=65&&e.path.charCodeAt(1)<=90||e.path.charCodeAt(1)>=97&&e.path.charCodeAt(1)<=122)&&58===e.path.charCodeAt(2)?n?e.path.substr(1):e.path[1].toLowerCase()+e.path.substr(2):e.path,b["d"]&&(t=t.replace(/\//g,"\\")),t}function Ne(e,n){const t=n?Ce:Ae;let r="",{scheme:a,authority:i,path:o,query:s,fragment:c}=e;if(a&&(r+=a,r+=":"),(i||"file"===a)&&(r+=Ee,r+=Ee),i){let e=i.indexOf("@");if(-1!==e){const n=i.substr(0,e);i=i.substr(e+1),e=n.indexOf(":"),-1===e?r+=t(n,!1):(r+=t(n.substr(0,e),!1),r+=":",r+=t(n.substr(e+1),!1)),r+="@"}i=i.toLowerCase(),e=i.indexOf(":"),-1===e?r+=t(i,!1):(r+=t(i.substr(0,e),!1),r+=i.substr(e))}if(o){if(o.length>=3&&47===o.charCodeAt(0)&&58===o.charCodeAt(2)){const e=o.charCodeAt(1);e>=65&&e<=90&&(o=`/${String.fromCharCode(e+32)}:${o.substr(3)}`)}else if(o.length>=2&&58===o.charCodeAt(1)){const e=o.charCodeAt(0);e>=65&&e<=90&&(o=`${String.fromCharCode(e+32)}:${o.substr(2)}`)}r+=t(o,!0)}return s&&(r+="?",r+=t(s,!1)),c&&(r+="#",r+=n?c:Ae(c,!1)),r}function ke(e){try{return decodeURIComponent(e)}catch(n){return e.length>3?e.substr(0,3)+ke(e.substr(3)):e}}const Re=/(%[0-9A-Za-z][0-9A-Za-z])+/g;function Oe(e){return e.match(Re)?e.replace(Re,e=>ke(e)):e}class we{constructor(e,n){this.lineNumber=e,this.column=n}with(e=this.lineNumber,n=this.column){return e===this.lineNumber&&n===this.column?this:new we(e,n)}delta(e=0,n=0){return this.with(this.lineNumber+e,this.column+n)}equals(e){return we.equals(this,e)}static equals(e,n){return!e&&!n||!!e&&!!n&&e.lineNumber===n.lineNumber&&e.column===n.column}isBefore(e){return we.isBefore(this,e)}static isBefore(e,n){return e.lineNumber<n.lineNumber||!(n.lineNumber<e.lineNumber)&&e.column<n.column}isBeforeOrEqual(e){return we.isBeforeOrEqual(this,e)}static isBeforeOrEqual(e,n){return e.lineNumber<n.lineNumber||!(n.lineNumber<e.lineNumber)&&e.column<=n.column}static compare(e,n){let t=0|e.lineNumber,r=0|n.lineNumber;if(t===r){let t=0|e.column,r=0|n.column;return t-r}return t-r}clone(){return new we(this.lineNumber,this.column)}toString(){return"("+this.lineNumber+","+this.column+")"}static lift(e){return new we(e.lineNumber,e.column)}static isIPosition(e){return e&&"number"===typeof e.lineNumber&&"number"===typeof e.column}}class Pe{constructor(e,n,t,r){e>t||e===t&&n>r?(this.startLineNumber=t,this.startColumn=r,this.endLineNumber=e,this.endColumn=n):(this.startLineNumber=e,this.startColumn=n,this.endLineNumber=t,this.endColumn=r)}isEmpty(){return Pe.isEmpty(this)}static isEmpty(e){return e.startLineNumber===e.endLineNumber&&e.startColumn===e.endColumn}containsPosition(e){return Pe.containsPosition(this,e)}static containsPosition(e,n){return!(n.lineNumber<e.startLineNumber||n.lineNumber>e.endLineNumber)&&(!(n.lineNumber===e.startLineNumber&&n.column<e.startColumn)&&!(n.lineNumber===e.endLineNumber&&n.column>e.endColumn))}containsRange(e){return Pe.containsRange(this,e)}static containsRange(e,n){return!(n.startLineNumber<e.startLineNumber||n.endLineNumber<e.startLineNumber)&&(!(n.startLineNumber>e.endLineNumber||n.endLineNumber>e.endLineNumber)&&(!(n.startLineNumber===e.startLineNumber&&n.startColumn<e.startColumn)&&!(n.endLineNumber===e.endLineNumber&&n.endColumn>e.endColumn)))}strictContainsRange(e){return Pe.strictContainsRange(this,e)}static strictContainsRange(e,n){return!(n.startLineNumber<e.startLineNumber||n.endLineNumber<e.startLineNumber)&&(!(n.startLineNumber>e.endLineNumber||n.endLineNumber>e.endLineNumber)&&(!(n.startLineNumber===e.startLineNumber&&n.startColumn<=e.startColumn)&&!(n.endLineNumber===e.endLineNumber&&n.endColumn>=e.endColumn)))}plusRange(e){return Pe.plusRange(this,e)}static plusRange(e,n){let t,r,a,i;return n.startLineNumber<e.startLineNumber?(t=n.startLineNumber,r=n.startColumn):n.startLineNumber===e.startLineNumber?(t=n.startLineNumber,r=Math.min(n.startColumn,e.startColumn)):(t=e.startLineNumber,r=e.startColumn),n.endLineNumber>e.endLineNumber?(a=n.endLineNumber,i=n.endColumn):n.endLineNumber===e.endLineNumber?(a=n.endLineNumber,i=Math.max(n.endColumn,e.endColumn)):(a=e.endLineNumber,i=e.endColumn),new Pe(t,r,a,i)}intersectRanges(e){return Pe.intersectRanges(this,e)}static intersectRanges(e,n){let t=e.startLineNumber,r=e.startColumn,a=e.endLineNumber,i=e.endColumn,o=n.startLineNumber,s=n.startColumn,c=n.endLineNumber,l=n.endColumn;return t<o?(t=o,r=s):t===o&&(r=Math.max(r,s)),a>c?(a=c,i=l):a===c&&(i=Math.min(i,l)),t>a||t===a&&r>i?null:new Pe(t,r,a,i)}equalsRange(e){return Pe.equalsRange(this,e)}static equalsRange(e,n){return!!e&&!!n&&e.startLineNumber===n.startLineNumber&&e.startColumn===n.startColumn&&e.endLineNumber===n.endLineNumber&&e.endColumn===n.endColumn}getEndPosition(){return Pe.getEndPosition(this)}static getEndPosition(e){return new we(e.endLineNumber,e.endColumn)}getStartPosition(){return Pe.getStartPosition(this)}static getStartPosition(e){return new we(e.startLineNumber,e.startColumn)}toString(){return"["+this.startLineNumber+","+this.startColumn+" -> "+this.endLineNumber+","+this.endColumn+"]"}setEndPosition(e,n){return new Pe(this.startLineNumber,this.startColumn,e,n)}setStartPosition(e,n){return new Pe(e,n,this.endLineNumber,this.endColumn)}collapseToStart(){return Pe.collapseToStart(this)}static collapseToStart(e){return new Pe(e.startLineNumber,e.startColumn,e.startLineNumber,e.startColumn)}static fromPositions(e,n=e){return new Pe(e.lineNumber,e.column,n.lineNumber,n.column)}static lift(e){return e?new Pe(e.startLineNumber,e.startColumn,e.endLineNumber,e.endColumn):null}static isIRange(e){return e&&"number"===typeof e.startLineNumber&&"number"===typeof e.startColumn&&"number"===typeof e.endLineNumber&&"number"===typeof e.endColumn}static areIntersectingOrTouching(e,n){return!(e.endLineNumber<n.startLineNumber||e.endLineNumber===n.startLineNumber&&e.endColumn<n.startColumn)&&!(n.endLineNumber<e.startLineNumber||n.endLineNumber===e.startLineNumber&&n.endColumn<e.startColumn)}static areIntersecting(e,n){return!(e.endLineNumber<n.startLineNumber||e.endLineNumber===n.startLineNumber&&e.endColumn<=n.startColumn)&&!(n.endLineNumber<e.startLineNumber||n.endLineNumber===e.startLineNumber&&n.endColumn<=e.startColumn)}static compareRangesUsingStarts(e,n){if(e&&n){const t=0|e.startLineNumber,r=0|n.startLineNumber;if(t===r){const t=0|e.startColumn,r=0|n.startColumn;if(t===r){const t=0|e.endLineNumber,r=0|n.endLineNumber;if(t===r){const t=0|e.endColumn,r=0|n.endColumn;return t-r}return t-r}return t-r}return t-r}const t=e?1:0,r=n?1:0;return t-r}static compareRangesUsingEnds(e,n){return e.endLineNumber===n.endLineNumber?e.endColumn===n.endColumn?e.startLineNumber===n.startLineNumber?e.startColumn-n.startColumn:e.startLineNumber-n.startLineNumber:e.endColumn-n.endColumn:e.endLineNumber-n.endLineNumber}static spansMultipleLines(e){return e.endLineNumber>e.startLineNumber}}const Me=3;function Fe(e,n,t,r){const a=new J(e,n,t);return a.ComputeDiff(r)}class Ge{constructor(e){const n=[],t=[];for(let r=0,a=e.length;r<a;r++)n[r]=He(e[r],1),t[r]=We(e[r],1);this.lines=e,this._startColumns=n,this._endColumns=t}getElements(){const e=[];for(let n=0,t=this.lines.length;n<t;n++)e[n]=this.lines[n].substring(this._startColumns[n]-1,this._endColumns[n]-1);return e}getStrictElement(e){return this.lines[e]}getStartLineNumber(e){return e+1}getEndLineNumber(e){return e+1}createCharSequence(e,n,t){const r=[],a=[],i=[];let o=0;for(let s=n;s<=t;s++){const n=this.lines[s],t=e?this._startColumns[s]:1,c=e?this._endColumns[s]:n.length+1;for(let e=t;e<c;e++)r[o]=n.charCodeAt(e-1),a[o]=s+1,i[o]=e,o++}return new Be(r,a,i)}}class Be{constructor(e,n,t){this._charCodes=e,this._lineNumbers=n,this._columns=t}getElements(){return this._charCodes}getStartLineNumber(e){return this._lineNumbers[e]}getStartColumn(e){return this._columns[e]}getEndLineNumber(e){return this._lineNumbers[e]}getEndColumn(e){return this._columns[e]+1}}class Ue{constructor(e,n,t,r,a,i,o,s){this.originalStartLineNumber=e,this.originalStartColumn=n,this.originalEndLineNumber=t,this.originalEndColumn=r,this.modifiedStartLineNumber=a,this.modifiedStartColumn=i,this.modifiedEndLineNumber=o,this.modifiedEndColumn=s}static createFromDiffChange(e,n,t){let r,a,i,o,s,c,l,u;return 0===e.originalLength?(r=0,a=0,i=0,o=0):(r=n.getStartLineNumber(e.originalStart),a=n.getStartColumn(e.originalStart),i=n.getEndLineNumber(e.originalStart+e.originalLength-1),o=n.getEndColumn(e.originalStart+e.originalLength-1)),0===e.modifiedLength?(s=0,c=0,l=0,u=0):(s=t.getStartLineNumber(e.modifiedStart),c=t.getStartColumn(e.modifiedStart),l=t.getEndLineNumber(e.modifiedStart+e.modifiedLength-1),u=t.getEndColumn(e.modifiedStart+e.modifiedLength-1)),new Ue(r,a,i,o,s,c,l,u)}}function Ve(e){if(e.length<=1)return e;const n=[e[0]];let t=n[0];for(let r=1,a=e.length;r<a;r++){const a=e[r],i=a.originalStart-(t.originalStart+t.originalLength),o=a.modifiedStart-(t.modifiedStart+t.modifiedLength),s=Math.min(i,o);s<Me?(t.originalLength=a.originalStart+a.originalLength-t.originalStart,t.modifiedLength=a.modifiedStart+a.modifiedLength-t.modifiedStart):(n.push(a),t=a)}return n}class je{constructor(e,n,t,r,a){this.originalStartLineNumber=e,this.originalEndLineNumber=n,this.modifiedStartLineNumber=t,this.modifiedEndLineNumber=r,this.charChanges=a}static createFromDiffResult(e,n,t,r,a,i,o){let s,c,l,u,d=void 0;if(0===n.originalLength?(s=t.getStartLineNumber(n.originalStart)-1,c=0):(s=t.getStartLineNumber(n.originalStart),c=t.getEndLineNumber(n.originalStart+n.originalLength-1)),0===n.modifiedLength?(l=r.getStartLineNumber(n.modifiedStart)-1,u=0):(l=r.getStartLineNumber(n.modifiedStart),u=r.getEndLineNumber(n.modifiedStart+n.modifiedLength-1)),i&&n.originalLength>0&&n.originalLength<20&&n.modifiedLength>0&&n.modifiedLength<20&&a()){const i=t.createCharSequence(e,n.originalStart,n.originalStart+n.originalLength-1),s=r.createCharSequence(e,n.modifiedStart,n.modifiedStart+n.modifiedLength-1);let c=Fe(i,s,a,!0).changes;o&&(c=Ve(c)),d=[];for(let e=0,n=c.length;e<n;e++)d.push(Ue.createFromDiffChange(c[e],i,s))}return new je(s,c,l,u,d)}}class Ke{constructor(e,n,t){this.shouldComputeCharChanges=t.shouldComputeCharChanges,this.shouldPostProcessCharChanges=t.shouldPostProcessCharChanges,this.shouldIgnoreTrimWhitespace=t.shouldIgnoreTrimWhitespace,this.shouldMakePrettyDiff=t.shouldMakePrettyDiff,this.originalLines=e,this.modifiedLines=n,this.original=new Ge(e),this.modified=new Ge(n),this.continueLineDiff=ze(t.maxComputationTime),this.continueCharDiff=ze(0===t.maxComputationTime?0:Math.min(t.maxComputationTime,5e3))}computeDiff(){if(1===this.original.lines.length&&0===this.original.lines[0].length)return 1===this.modified.lines.length&&0===this.modified.lines[0].length?{quitEarly:!1,changes:[]}:{quitEarly:!1,changes:[{originalStartLineNumber:1,originalEndLineNumber:1,modifiedStartLineNumber:1,modifiedEndLineNumber:this.modified.lines.length,charChanges:[{modifiedEndColumn:0,modifiedEndLineNumber:0,modifiedStartColumn:0,modifiedStartLineNumber:0,originalEndColumn:0,originalEndLineNumber:0,originalStartColumn:0,originalStartLineNumber:0}]}]};if(1===this.modified.lines.length&&0===this.modified.lines[0].length)return{quitEarly:!1,changes:[{originalStartLineNumber:1,originalEndLineNumber:this.original.lines.length,modifiedStartLineNumber:1,modifiedEndLineNumber:1,charChanges:[{modifiedEndColumn:0,modifiedEndLineNumber:0,modifiedStartColumn:0,modifiedStartLineNumber:0,originalEndColumn:0,originalEndLineNumber:0,originalStartColumn:0,originalStartLineNumber:0}]}]};const e=Fe(this.original,this.modified,this.continueLineDiff,this.shouldMakePrettyDiff),n=e.changes,t=e.quitEarly;if(this.shouldIgnoreTrimWhitespace){const e=[];for(let t=0,r=n.length;t<r;t++)e.push(je.createFromDiffResult(this.shouldIgnoreTrimWhitespace,n[t],this.original,this.modified,this.continueCharDiff,this.shouldComputeCharChanges,this.shouldPostProcessCharChanges));return{quitEarly:t,changes:e}}const r=[];let a=0,i=0;for(let o=-1,s=n.length;o<s;o++){const e=o+1<s?n[o+1]:null,t=e?e.originalStart:this.originalLines.length,c=e?e.modifiedStart:this.modifiedLines.length;while(a<t&&i<c){const e=this.originalLines[a],n=this.modifiedLines[i];if(e!==n){{let t=He(e,1),o=He(n,1);while(t>1&&o>1){const r=e.charCodeAt(t-2),a=n.charCodeAt(o-2);if(r!==a)break;t--,o--}(t>1||o>1)&&this._pushTrimWhitespaceCharChange(r,a+1,1,t,i+1,1,o)}{let t=We(e,1),o=We(n,1);const s=e.length+1,c=n.length+1;while(t<s&&o<c){const n=e.charCodeAt(t-1),r=e.charCodeAt(o-1);if(n!==r)break;t++,o++}(t<s||o<c)&&this._pushTrimWhitespaceCharChange(r,a+1,t,s,i+1,o,c)}}a++,i++}e&&(r.push(je.createFromDiffResult(this.shouldIgnoreTrimWhitespace,e,this.original,this.modified,this.continueCharDiff,this.shouldComputeCharChanges,this.shouldPostProcessCharChanges)),a+=e.originalLength,i+=e.modifiedLength)}return{quitEarly:t,changes:r}}_pushTrimWhitespaceCharChange(e,n,t,r,a,i,o){if(this._mergeTrimWhitespaceCharChange(e,n,t,r,a,i,o))return;let s=void 0;this.shouldComputeCharChanges&&(s=[new Ue(n,t,n,r,a,i,a,o)]),e.push(new je(n,n,a,a,s))}_mergeTrimWhitespaceCharChange(e,n,t,r,a,i,o){const s=e.length;if(0===s)return!1;const c=e[s-1];return 0!==c.originalEndLineNumber&&0!==c.modifiedEndLineNumber&&(c.originalEndLineNumber+1===n&&c.modifiedEndLineNumber+1===a&&(c.originalEndLineNumber=n,c.modifiedEndLineNumber=a,this.shouldComputeCharChanges&&c.charChanges&&c.charChanges.push(new Ue(n,t,n,r,a,i,a,o)),!0))}}function He(e,n){const t=I(e);return-1===t?n:t+1}function We(e,n){const t=N(e);return-1===t?n:t+2}function ze(e){if(0===e)return()=>!0;const n=Date.now();return()=>Date.now()-n<e}function qe(e){return e<0?0:e>255?255:0|e}function Je(e){return e<0?0:e>4294967295?4294967295:0|e}class Xe{constructor(e,n){this._prefixSumIndexOfResultBrand=void 0,this.index=e,this.remainder=n}}class Ye{constructor(e){this.values=e,this.prefixSum=new Uint32Array(e.length),this.prefixSumValidIndex=new Int32Array(1),this.prefixSumValidIndex[0]=-1}insertValues(e,n){e=Je(e);const t=this.values,r=this.prefixSum,a=n.length;return 0!==a&&(this.values=new Uint32Array(t.length+a),this.values.set(t.subarray(0,e),0),this.values.set(t.subarray(e),e+a),this.values.set(n,e),e-1<this.prefixSumValidIndex[0]&&(this.prefixSumValidIndex[0]=e-1),this.prefixSum=new Uint32Array(this.values.length),this.prefixSumValidIndex[0]>=0&&this.prefixSum.set(r.subarray(0,this.prefixSumValidIndex[0]+1)),!0)}changeValue(e,n){return e=Je(e),n=Je(n),this.values[e]!==n&&(this.values[e]=n,e-1<this.prefixSumValidIndex[0]&&(this.prefixSumValidIndex[0]=e-1),!0)}removeValues(e,n){e=Je(e),n=Je(n);const t=this.values,r=this.prefixSum;if(e>=t.length)return!1;let a=t.length-e;return n>=a&&(n=a),0!==n&&(this.values=new Uint32Array(t.length-n),this.values.set(t.subarray(0,e),0),this.values.set(t.subarray(e+n),e),this.prefixSum=new Uint32Array(this.values.length),e-1<this.prefixSumValidIndex[0]&&(this.prefixSumValidIndex[0]=e-1),this.prefixSumValidIndex[0]>=0&&this.prefixSum.set(r.subarray(0,this.prefixSumValidIndex[0]+1)),!0)}getTotalSum(){return 0===this.values.length?0:this._getPrefixSum(this.values.length-1)}getPrefixSum(e){return e<0?0:(e=Je(e),this._getPrefixSum(e))}_getPrefixSum(e){if(e<=this.prefixSumValidIndex[0])return this.prefixSum[e];let n=this.prefixSumValidIndex[0]+1;0===n&&(this.prefixSum[0]=this.values[0],n++),e>=this.values.length&&(e=this.values.length-1);for(let t=n;t<=e;t++)this.prefixSum[t]=this.prefixSum[t-1]+this.values[t];return this.prefixSumValidIndex[0]=Math.max(this.prefixSumValidIndex[0],e),this.prefixSum[e]}getIndexOf(e){e=Math.floor(e),this.getTotalSum();let n=0,t=this.values.length-1,r=0,a=0,i=0;while(n<=t)if(r=n+(t-n)/2|0,a=this.prefixSum[r],i=a-this.values[r],e<i)t=r-1;else{if(!(e>=a))break;n=r+1}return new Xe(r,e-i)}}class Qe{constructor(e,n,t,r){this._uri=e,this._lines=n,this._eol=t,this._versionId=r,this._lineStarts=null,this._cachedTextValue=null}dispose(){this._lines.length=0}get version(){return this._versionId}getText(){return null===this._cachedTextValue&&(this._cachedTextValue=this._lines.join(this._eol)),this._cachedTextValue}onEvents(e){e.eol&&e.eol!==this._eol&&(this._eol=e.eol,this._lineStarts=null);const n=e.changes;for(const t of n)this._acceptDeleteRange(t.range),this._acceptInsertText(new we(t.range.startLineNumber,t.range.startColumn),t.text);this._versionId=e.versionId,this._cachedTextValue=null}_ensureLineStarts(){if(!this._lineStarts){const e=this._eol.length,n=this._lines.length,t=new Uint32Array(n);for(let r=0;r<n;r++)t[r]=this._lines[r].length+e;this._lineStarts=new Ye(t)}}_setLineText(e,n){this._lines[e]=n,this._lineStarts&&this._lineStarts.changeValue(e,this._lines[e].length+this._eol.length)}_acceptDeleteRange(e){if(e.startLineNumber!==e.endLineNumber)this._setLineText(e.startLineNumber-1,this._lines[e.startLineNumber-1].substring(0,e.startColumn-1)+this._lines[e.endLineNumber-1].substring(e.endColumn-1)),this._lines.splice(e.startLineNumber,e.endLineNumber-e.startLineNumber),this._lineStarts&&this._lineStarts.removeValues(e.startLineNumber,e.endLineNumber-e.startLineNumber);else{if(e.startColumn===e.endColumn)return;this._setLineText(e.startLineNumber-1,this._lines[e.startLineNumber-1].substring(0,e.startColumn-1)+this._lines[e.startLineNumber-1].substring(e.endColumn-1))}}_acceptInsertText(e,n){if(0===n.length)return;let t=C(n);if(1===t.length)return void this._setLineText(e.lineNumber-1,this._lines[e.lineNumber-1].substring(0,e.column-1)+t[0]+this._lines[e.lineNumber-1].substring(e.column-1));t[t.length-1]+=this._lines[e.lineNumber-1].substring(e.column-1),this._setLineText(e.lineNumber-1,this._lines[e.lineNumber-1].substring(0,e.column-1)+t[0]);let r=new Uint32Array(t.length-1);for(let a=1;a<t.length;a++)this._lines.splice(e.lineNumber+a-1,0,t[a]),r[a-1]=t[a].length+this._eol.length;this._lineStarts&&this._lineStarts.insertValues(e.lineNumber,r)}}const Ze="`~!@#$%^&*()-=+[{]}\\|;:'\",.<>/?";function $e(e=""){let n="(-?\\d*\\.\\d\\w*)|([^";for(const t of Ze)e.indexOf(t)>=0||(n+="\\"+t);return n+="\\s]+)",new RegExp(n,"g")}const en=$e();function nn(e){let n=en;if(e&&e instanceof RegExp)if(e.global)n=e;else{let t="g";e.ignoreCase&&(t+="i"),e.multiline&&(t+="m"),e.unicode&&(t+="u"),n=new RegExp(e.source,t)}return n.lastIndex=0,n}const tn={maxLen:1e3,windowSize:15,timeBudget:150};function rn(e,n,t,r,a=tn){if(t.length>a.maxLen){let i=e-a.maxLen/2;return i<0?i=0:r+=i,t=t.substring(i,e+a.maxLen/2),rn(e,n,t,r,a)}const i=Date.now(),o=e-1-r;let s=-1,c=null;for(let l=1;;l++){if(Date.now()-i>=a.timeBudget)break;const e=o-a.windowSize*l;n.lastIndex=Math.max(0,e);const r=an(n,t,o,s);if(!r&&c)break;if(c=r,e<=0)break;s=e}if(c){let e={word:c[0],startColumn:r+1+c.index,endColumn:r+1+c.index+c[0].length};return n.lastIndex=0,e}return null}function an(e,n,t,r){let a;while(a=e.exec(n)){const n=a.index||0;if(n<=t&&e.lastIndex>=t)return a;if(r>0&&n>r)return null}return null}class on{constructor(e){let n=qe(e);this._defaultValue=n,this._asciiMap=on._createAsciiMap(n),this._map=new Map}static _createAsciiMap(e){let n=new Uint8Array(256);for(let t=0;t<256;t++)n[t]=e;return n}set(e,n){let t=qe(n);e>=0&&e<256?this._asciiMap[e]=t:this._map.set(e,t)}get(e){return e>=0&&e<256?this._asciiMap[e]:this._map.get(e)||this._defaultValue}}class sn{constructor(e,n,t){const r=new Uint8Array(e*n);for(let a=0,i=e*n;a<i;a++)r[a]=t;this._data=r,this.rows=e,this.cols=n}get(e,n){return this._data[e*this.cols+n]}set(e,n,t){this._data[e*this.cols+n]=t}}class cn{constructor(e){let n=0,t=0;for(let a=0,i=e.length;a<i;a++){let[r,i,o]=e[a];i>n&&(n=i),r>t&&(t=r),o>t&&(t=o)}n++,t++;let r=new sn(t,n,0);for(let a=0,i=e.length;a<i;a++){let[n,t,i]=e[a];r.set(n,t,i)}this._states=r,this._maxCharCode=n}nextState(e,n){return n<0||n>=this._maxCharCode?0:this._states.get(e,n)}}let ln=null;function un(){return null===ln&&(ln=new cn([[1,104,2],[1,72,2],[1,102,6],[1,70,6],[2,116,3],[2,84,3],[3,116,4],[3,84,4],[4,112,5],[4,80,5],[5,115,9],[5,83,9],[5,58,10],[6,105,7],[6,73,7],[7,108,8],[7,76,8],[8,101,9],[8,69,9],[9,58,10],[10,47,11],[11,47,12]])),ln}let dn=null;function pn(){if(null===dn){dn=new on(0);const e=" \t<>'\"、。｡､，．：；‘〈「『〔（［｛｢｣｝］）〕』」〉’｀～…";for(let t=0;t<e.length;t++)dn.set(e.charCodeAt(t),1);const n=".,;";for(let t=0;t<n.length;t++)dn.set(n.charCodeAt(t),2)}return dn}class fn{static _createLink(e,n,t,r,a){let i=a-1;do{const t=n.charCodeAt(i),r=e.get(t);if(2!==r)break;i--}while(i>r);if(r>0){const e=n.charCodeAt(r-1),t=n.charCodeAt(i);(40===e&&41===t||91===e&&93===t||123===e&&125===t)&&i--}return{range:{startLineNumber:t,startColumn:r+1,endLineNumber:t,endColumn:i+2},url:n.substring(r,i+1)}}static computeLinks(e,n=un()){const t=pn();let r=[];for(let a=1,i=e.getLineCount();a<=i;a++){const i=e.getLineContent(a),o=i.length;let s=0,c=0,l=0,u=1,d=!1,p=!1,f=!1,m=!1;while(s<o){let e=!1;const o=i.charCodeAt(s);if(13===u){let n;switch(o){case 40:d=!0,n=0;break;case 41:n=d?0:1;break;case 91:f=!0,p=!0,n=0;break;case 93:f=!1,n=p?0:1;break;case 123:m=!0,n=0;break;case 125:n=m?0:1;break;case 39:n=34===l||96===l?0:1;break;case 34:n=39===l||96===l?0:1;break;case 96:n=39===l||34===l?0:1;break;case 42:n=42===l?1:0;break;case 124:n=124===l?1:0;break;case 32:n=f?0:1;break;default:n=t.get(o)}1===n&&(r.push(fn._createLink(t,i,a,c,s)),e=!0)}else if(12===u){let n;91===o?(p=!0,n=0):n=t.get(o),1===n?e=!0:u=13}else u=n.nextState(u,o),0===u&&(e=!0);e&&(u=1,d=!1,p=!1,m=!1,c=s+1,l=o),s++}13===u&&r.push(fn._createLink(t,i,a,c,o))}return r}}function mn(e){return e&&"function"===typeof e.getLineCount&&"function"===typeof e.getLineContent?fn.computeLinks(e):[]}class _n{constructor(){this._defaultValueSet=[["true","false"],["True","False"],["Private","Public","Friend","ReadOnly","Partial","Protected","WriteOnly"],["public","protected","private"]]}navigateValueSet(e,n,t,r,a){if(e&&n){let t=this.doNavigateValueSet(n,a);if(t)return{range:e,value:t}}if(t&&r){let e=this.doNavigateValueSet(r,a);if(e)return{range:t,value:e}}return null}doNavigateValueSet(e,n){let t=this.numberReplace(e,n);return null!==t?t:this.textReplace(e,n)}numberReplace(e,n){let t=Math.pow(10,e.length-(e.lastIndexOf(".")+1)),r=Number(e),a=parseFloat(e);return isNaN(r)||isNaN(a)||r!==a?null:0!==r||n?(r=Math.floor(r*t),r+=n?t:-t,String(r/t)):null}textReplace(e,n){return this.valueSetsReplace(this._defaultValueSet,e,n)}valueSetsReplace(e,n,t){let r=null;for(let a=0,i=e.length;null===r&&a<i;a++)r=this.valueSetReplace(e[a],n,t);return r}valueSetReplace(e,n,t){let r=e.indexOf(n);return r>=0?(r+=t?1:-1,r<0?r=e.length-1:r%=e.length,e[r]):null}}_n.INSTANCE=new _n;class gn{constructor(e){this.element=e,this.next=gn.Undefined,this.prev=gn.Undefined}}gn.Undefined=new gn(void 0);class yn{constructor(){this._first=gn.Undefined,this._last=gn.Undefined,this._size=0}get size(){return this._size}isEmpty(){return this._first===gn.Undefined}clear(){let e=this._first;while(e!==gn.Undefined){const n=e.next;e.prev=gn.Undefined,e.next=gn.Undefined,e=n}this._first=gn.Undefined,this._last=gn.Undefined,this._size=0}unshift(e){return this._insert(e,!1)}push(e){return this._insert(e,!0)}_insert(e,n){const t=new gn(e);if(this._first===gn.Undefined)this._first=t,this._last=t;else if(n){const e=this._last;this._last=t,t.prev=e,e.next=t}else{const e=this._first;this._first=t,t.next=e,e.prev=t}this._size+=1;let r=!1;return()=>{r||(r=!0,this._remove(t))}}shift(){if(this._first!==gn.Undefined){const e=this._first.element;return this._remove(this._first),e}}pop(){if(this._last!==gn.Undefined){const e=this._last.element;return this._remove(this._last),e}}_remove(e){if(e.prev!==gn.Undefined&&e.next!==gn.Undefined){const n=e.prev;n.next=e.next,e.next.prev=n}else e.prev===gn.Undefined&&e.next===gn.Undefined?(this._first=gn.Undefined,this._last=gn.Undefined):e.next===gn.Undefined?(this._last=this._last.prev,this._last.next=gn.Undefined):e.prev===gn.Undefined&&(this._first=this._first.next,this._first.prev=gn.Undefined);this._size-=1}*[Symbol.iterator](){let e=this._first;while(e!==gn.Undefined)yield e.element,e=e.next}}const hn=b["a"].performance&&"function"===typeof b["a"].performance.now;class vn{constructor(e){this._highResolution=hn&&e,this._startTime=this._now(),this._stopTime=-1}static create(e=!0){return new vn(e)}stop(){this._stopTime=this._now()}elapsed(){return-1!==this._stopTime?this._stopTime-this._startTime:this._now()-this._startTime}_now(){return this._highResolution?b["a"].performance.now():Date.now()}}var bn;(function(e){function n(e){return(n,t=null,r)=>{let a,i=!1;return a=e(e=>{if(!i)return a?a.dispose():i=!0,n.call(t,e)},null,r),i&&a.dispose(),a}}function t(e,n){return c((t,r=null,a)=>e(e=>t.call(r,n(e)),null,a))}function r(e,n){return c((t,r=null,a)=>e(e=>{n(e),t.call(r,e)},null,a))}function a(e,n){return c((t,r=null,a)=>e(e=>n(e)&&t.call(r,e),null,a))}function i(e){return e}function o(...e){return(n,t=null,r)=>g(...e.map(e=>e(e=>n.call(t,e),null,r)))}function s(e,n,r){let a=r;return t(e,e=>(a=n(a,e),a))}function c(e){let n;const t=new xn({onFirstListenerAdd(){n=e(t.fire,t)},onLastListenerRemove(){n.dispose()}});return t.event}function l(e,n,t=100,r=!1,a){let i,o=void 0,s=void 0,c=0;const l=new xn({leakWarningThreshold:a,onFirstListenerAdd(){i=e(e=>{c++,o=n(o,e),r&&!s&&(l.fire(o),o=void 0),clearTimeout(s),s=setTimeout(()=>{const e=o;o=void 0,s=void 0,(!r||c>1)&&l.fire(e),c=0},t)})},onLastListenerRemove(){i.dispose()}});return l.event}function u(e,n=((e,n)=>e===n)){let t,r=!0;return a(e,e=>{const a=r||!n(e,t);return r=!1,t=e,a})}function d(n,t){return[e.filter(n,t),e.filter(n,e=>!t(e))]}function p(e,n=!1,t=[]){let r=t.slice(),a=e(e=>{r?r.push(e):o.fire(e)});const i=()=>{r&&r.forEach(e=>o.fire(e)),r=null},o=new xn({onFirstListenerAdd(){a||(a=e(e=>o.fire(e)))},onFirstListenerDidAdd(){r&&(n?setTimeout(i):i())},onLastListenerRemove(){a&&a.dispose(),a=null}});return o.event}e.None=()=>v.None,e.once=n,e.map=t,e.forEach=r,e.filter=a,e.signal=i,e.any=o,e.reduce=s,e.debounce=l,e.latch=u,e.split=d,e.buffer=p;class f{constructor(e){this.event=e}map(e){return new f(t(this.event,e))}forEach(e){return new f(r(this.event,e))}filter(e){return new f(a(this.event,e))}reduce(e,n){return new f(s(this.event,e,n))}latch(){return new f(u(this.event))}debounce(e,n=100,t=!1,r){return new f(l(this.event,e,n,t,r))}on(e,n,t){return this.event(e,n,t)}once(e,t,r){return n(this.event)(e,t,r)}}function m(e){return new f(e)}function _(e,n,t=(e=>e)){const r=(...e)=>o.fire(t(...e)),a=()=>e.on(n,r),i=()=>e.removeListener(n,r),o=new xn({onFirstListenerAdd:a,onLastListenerRemove:i});return o.event}function y(e,n,t=(e=>e)){const r=(...e)=>o.fire(t(...e)),a=()=>e.addEventListener(n,r),i=()=>e.removeEventListener(n,r),o=new xn({onFirstListenerAdd:a,onLastListenerRemove:i});return o.event}function h(e){return new Promise(t=>n(e)(t))}e.chain=m,e.fromNodeEventEmitter=_,e.fromDOMEventEmitter=y,e.toPromise=h})(bn||(bn={}));class En{constructor(e){this._listenerCount=0,this._invocationCount=0,this._elapsedOverall=0,this._name=`${e}_${En._idPool++}`}start(e){this._stopWatch=new vn(!0),this._listenerCount=e}stop(){if(this._stopWatch){const e=this._stopWatch.elapsed();this._elapsedOverall+=e,this._invocationCount+=1,console.info(`did FIRE ${this._name}: elapsed_ms: ${e.toFixed(5)}, listener: ${this._listenerCount} (elapsed_overall: ${this._elapsedOverall.toFixed(2)}, invocations: ${this._invocationCount})`),this._stopWatch=void 0}}}En._idPool=0;let Tn=-1;class Sn{constructor(e,n=Math.random().toString(18).slice(2,5)){this.customThreshold=e,this.name=n,this._warnCountdown=0}dispose(){this._stacks&&this._stacks.clear()}check(e){let n=Tn;if("number"===typeof this.customThreshold&&(n=this.customThreshold),n<=0||e<n)return;this._stacks||(this._stacks=new Map);const t=(new Error).stack.split("\n").slice(3).join("\n"),r=this._stacks.get(t)||0;if(this._stacks.set(t,r+1),this._warnCountdown-=1,this._warnCountdown<=0){let t;this._warnCountdown=.5*n;let r=0;for(const[e,n]of this._stacks)(!t||r<n)&&(t=e,r=n);console.warn(`[${this.name}] potential listener LEAK detected, having ${e} listeners already. MOST frequent listener (${r}):`),console.warn(t)}return()=>{const e=this._stacks.get(t)||0;this._stacks.set(t,e-1)}}}class xn{constructor(e){var n;this._disposed=!1,this._options=e,this._leakageMon=Tn>0?new Sn(this._options&&this._options.leakWarningThreshold):void 0,this._perfMon=(null===(n=this._options)||void 0===n?void 0:n._profName)?new En(this._options._profName):void 0}get event(){return this._event||(this._event=(e,n,t)=>{var r;this._listeners||(this._listeners=new yn);const a=this._listeners.isEmpty();a&&this._options&&this._options.onFirstListenerAdd&&this._options.onFirstListenerAdd(this);const i=this._listeners.push(n?[e,n]:e);a&&this._options&&this._options.onFirstListenerDidAdd&&this._options.onFirstListenerDidAdd(this),this._options&&this._options.onListenerDidAdd&&this._options.onListenerDidAdd(this,e,n);const o=null===(r=this._leakageMon)||void 0===r?void 0:r.check(this._listeners.size);let s;return s={dispose:()=>{if(o&&o(),s.dispose=xn._noop,!this._disposed&&(i(),this._options&&this._options.onLastListenerRemove)){const e=this._listeners&&!this._listeners.isEmpty();e||this._options.onLastListenerRemove(this)}}},t instanceof h?t.add(s):Array.isArray(t)&&t.push(s),s}),this._event}fire(e){var n,t;if(this._listeners){this._deliveryQueue||(this._deliveryQueue=new yn);for(let n of this._listeners)this._deliveryQueue.push([n,e]);null===(n=this._perfMon)||void 0===n||n.start(this._deliveryQueue.size);while(this._deliveryQueue.size>0){const[e,n]=this._deliveryQueue.shift();try{"function"===typeof e?e.call(void 0,n):e[0].call(e[1],n)}catch(r){i(r)}}null===(t=this._perfMon)||void 0===t||t.stop()}}dispose(){var e,n,t,r,a;this._disposed||(this._disposed=!0,null===(e=this._listeners)||void 0===e||e.clear(),null===(n=this._deliveryQueue)||void 0===n||n.clear(),null===(r=null===(t=this._options)||void 0===t?void 0:t.onLastListenerRemove)||void 0===r||r.call(t),null===(a=this._leakageMon)||void 0===a||a.dispose())}}xn._noop=function(){};const Ln=Object.freeze((function(e,n){const t=setTimeout(e.bind(n),0);return{dispose(){clearTimeout(t)}}}));var Dn;(function(e){function n(n){return n===e.None||n===e.Cancelled||(n instanceof An||!(!n||"object"!==typeof n)&&("boolean"===typeof n.isCancellationRequested&&"function"===typeof n.onCancellationRequested))}e.isCancellationToken=n,e.None=Object.freeze({isCancellationRequested:!1,onCancellationRequested:bn.None}),e.Cancelled=Object.freeze({isCancellationRequested:!0,onCancellationRequested:Ln})})(Dn||(Dn={}));class An{constructor(){this._isCancelled=!1,this._emitter=null}cancel(){this._isCancelled||(this._isCancelled=!0,this._emitter&&(this._emitter.fire(void 0),this.dispose()))}get isCancellationRequested(){return this._isCancelled}get onCancellationRequested(){return this._isCancelled?Ln:(this._emitter||(this._emitter=new xn),this._emitter.event)}dispose(){this._emitter&&(this._emitter.dispose(),this._emitter=null)}}class Cn{constructor(e){this._token=void 0,this._parentListener=void 0,this._parentListener=e&&e.onCancellationRequested(this.cancel,this)}get token(){return this._token||(this._token=new An),this._token}cancel(){this._token?this._token instanceof An&&this._token.cancel():this._token=Dn.Cancelled}dispose(e=!1){e&&this.cancel(),this._parentListener&&this._parentListener.dispose(),this._token?this._token instanceof An&&this._token.dispose():this._token=Dn.None}}class In{constructor(){this._keyCodeToStr=[],this._strToKeyCode=Object.create(null)}define(e,n){this._keyCodeToStr[e]=n,this._strToKeyCode[n.toLowerCase()]=e}keyCodeToStr(e){return this._keyCodeToStr[e]}strToKeyCode(e){return this._strToKeyCode[e.toLowerCase()]||0}}const Nn=new In,kn=new In,Rn=new In;var On,wn,Pn,Mn,Fn,Gn,Bn,Un,Vn,jn,Kn,Hn,Wn,zn,qn,Jn,Xn,Yn,Qn,Zn,$n,et,nt,tt,rt,at,it,ot,st,ct,lt,ut,dt,pt,ft,mt;function _t(e,n){const t=(65535&n)<<16>>>0;return(e|t)>>>0}(function(){function e(e,n,t=n,r=t){Nn.define(e,n),kn.define(e,t),Rn.define(e,r)}e(0,"unknown"),e(1,"Backspace"),e(2,"Tab"),e(3,"Enter"),e(4,"Shift"),e(5,"Ctrl"),e(6,"Alt"),e(7,"PauseBreak"),e(8,"CapsLock"),e(9,"Escape"),e(10,"Space"),e(11,"PageUp"),e(12,"PageDown"),e(13,"End"),e(14,"Home"),e(15,"LeftArrow","Left"),e(16,"UpArrow","Up"),e(17,"RightArrow","Right"),e(18,"DownArrow","Down"),e(19,"Insert"),e(20,"Delete"),e(21,"0"),e(22,"1"),e(23,"2"),e(24,"3"),e(25,"4"),e(26,"5"),e(27,"6"),e(28,"7"),e(29,"8"),e(30,"9"),e(31,"A"),e(32,"B"),e(33,"C"),e(34,"D"),e(35,"E"),e(36,"F"),e(37,"G"),e(38,"H"),e(39,"I"),e(40,"J"),e(41,"K"),e(42,"L"),e(43,"M"),e(44,"N"),e(45,"O"),e(46,"P"),e(47,"Q"),e(48,"R"),e(49,"S"),e(50,"T"),e(51,"U"),e(52,"V"),e(53,"W"),e(54,"X"),e(55,"Y"),e(56,"Z"),e(57,"Meta"),e(58,"ContextMenu"),e(59,"F1"),e(60,"F2"),e(61,"F3"),e(62,"F4"),e(63,"F5"),e(64,"F6"),e(65,"F7"),e(66,"F8"),e(67,"F9"),e(68,"F10"),e(69,"F11"),e(70,"F12"),e(71,"F13"),e(72,"F14"),e(73,"F15"),e(74,"F16"),e(75,"F17"),e(76,"F18"),e(77,"F19"),e(78,"NumLock"),e(79,"ScrollLock"),e(80,";",";","OEM_1"),e(81,"=","=","OEM_PLUS"),e(82,",",",","OEM_COMMA"),e(83,"-","-","OEM_MINUS"),e(84,".",".","OEM_PERIOD"),e(85,"/","/","OEM_2"),e(86,"`","`","OEM_3"),e(110,"ABNT_C1"),e(111,"ABNT_C2"),e(87,"[","[","OEM_4"),e(88,"\\","\\","OEM_5"),e(89,"]","]","OEM_6"),e(90,"'","'","OEM_7"),e(91,"OEM_8"),e(92,"OEM_102"),e(93,"NumPad0"),e(94,"NumPad1"),e(95,"NumPad2"),e(96,"NumPad3"),e(97,"NumPad4"),e(98,"NumPad5"),e(99,"NumPad6"),e(100,"NumPad7"),e(101,"NumPad8"),e(102,"NumPad9"),e(103,"NumPad_Multiply"),e(104,"NumPad_Add"),e(105,"NumPad_Separator"),e(106,"NumPad_Subtract"),e(107,"NumPad_Decimal"),e(108,"NumPad_Divide")})(),function(e){function n(e){return Nn.keyCodeToStr(e)}function t(e){return Nn.strToKeyCode(e)}function r(e){return kn.keyCodeToStr(e)}function a(e){return Rn.keyCodeToStr(e)}function i(e){return kn.strToKeyCode(e)||Rn.strToKeyCode(e)}e.toString=n,e.fromString=t,e.toUserSettingsUS=r,e.toUserSettingsGeneral=a,e.fromUserSettings=i}(On||(On={}));class gt extends Pe{constructor(e,n,t,r){super(e,n,t,r),this.selectionStartLineNumber=e,this.selectionStartColumn=n,this.positionLineNumber=t,this.positionColumn=r}toString(){return"["+this.selectionStartLineNumber+","+this.selectionStartColumn+" -> "+this.positionLineNumber+","+this.positionColumn+"]"}equalsSelection(e){return gt.selectionsEqual(this,e)}static selectionsEqual(e,n){return e.selectionStartLineNumber===n.selectionStartLineNumber&&e.selectionStartColumn===n.selectionStartColumn&&e.positionLineNumber===n.positionLineNumber&&e.positionColumn===n.positionColumn}getDirection(){return this.selectionStartLineNumber===this.startLineNumber&&this.selectionStartColumn===this.startColumn?0:1}setEndPosition(e,n){return 0===this.getDirection()?new gt(this.startLineNumber,this.startColumn,e,n):new gt(e,n,this.startLineNumber,this.startColumn)}getPosition(){return new we(this.positionLineNumber,this.positionColumn)}setStartPosition(e,n){return 0===this.getDirection()?new gt(e,n,this.endLineNumber,this.endColumn):new gt(this.endLineNumber,this.endColumn,e,n)}static fromPositions(e,n=e){return new gt(e.lineNumber,e.column,n.lineNumber,n.column)}static liftSelection(e){return new gt(e.selectionStartLineNumber,e.selectionStartColumn,e.positionLineNumber,e.positionColumn)}static selectionsArrEqual(e,n){if(e&&!n||!e&&n)return!1;if(!e&&!n)return!0;if(e.length!==n.length)return!1;for(let t=0,r=e.length;t<r;t++)if(!this.selectionsEqual(e[t],n[t]))return!1;return!0}static isISelection(e){return e&&"number"===typeof e.selectionStartLineNumber&&"number"===typeof e.selectionStartColumn&&"number"===typeof e.positionLineNumber&&"number"===typeof e.positionColumn}static createWithDirection(e,n,t,r,a){return 0===a?new gt(e,n,t,r):new gt(t,r,e,n)}}class yt{constructor(e,n,t){this._tokenBrand=void 0,this.offset=0|e,this.type=n,this.language=t}toString(){return"("+this.offset+", "+this.type+")"}}(function(e){e[e["Unknown"]=0]="Unknown",e[e["Disabled"]=1]="Disabled",e[e["Enabled"]=2]="Enabled"})(wn||(wn={})),function(e){e[e["KeepWhitespace"]=1]="KeepWhitespace",e[e["InsertAsSnippet"]=4]="InsertAsSnippet"}(Pn||(Pn={})),function(e){e[e["Method"]=0]="Method",e[e["Function"]=1]="Function",e[e["Constructor"]=2]="Constructor",e[e["Field"]=3]="Field",e[e["Variable"]=4]="Variable",e[e["Class"]=5]="Class",e[e["Struct"]=6]="Struct",e[e["Interface"]=7]="Interface",e[e["Module"]=8]="Module",e[e["Property"]=9]="Property",e[e["Event"]=10]="Event",e[e["Operator"]=11]="Operator",e[e["Unit"]=12]="Unit",e[e["Value"]=13]="Value",e[e["Constant"]=14]="Constant",e[e["Enum"]=15]="Enum",e[e["EnumMember"]=16]="EnumMember",e[e["Keyword"]=17]="Keyword",e[e["Text"]=18]="Text",e[e["Color"]=19]="Color",e[e["File"]=20]="File",e[e["Reference"]=21]="Reference",e[e["Customcolor"]=22]="Customcolor",e[e["Folder"]=23]="Folder",e[e["TypeParameter"]=24]="TypeParameter",e[e["User"]=25]="User",e[e["Issue"]=26]="Issue",e[e["Snippet"]=27]="Snippet"}(Mn||(Mn={})),function(e){e[e["Deprecated"]=1]="Deprecated"}(Fn||(Fn={})),function(e){e[e["Invoke"]=0]="Invoke",e[e["TriggerCharacter"]=1]="TriggerCharacter",e[e["TriggerForIncompleteCompletions"]=2]="TriggerForIncompleteCompletions"}(Gn||(Gn={})),function(e){e[e["EXACT"]=0]="EXACT",e[e["ABOVE"]=1]="ABOVE",e[e["BELOW"]=2]="BELOW"}(Bn||(Bn={})),function(e){e[e["NotSet"]=0]="NotSet",e[e["ContentFlush"]=1]="ContentFlush",e[e["RecoverFromMarkers"]=2]="RecoverFromMarkers",e[e["Explicit"]=3]="Explicit",e[e["Paste"]=4]="Paste",e[e["Undo"]=5]="Undo",e[e["Redo"]=6]="Redo"}(Un||(Un={})),function(e){e[e["LF"]=1]="LF",e[e["CRLF"]=2]="CRLF"}(Vn||(Vn={})),function(e){e[e["Text"]=0]="Text",e[e["Read"]=1]="Read",e[e["Write"]=2]="Write"}(jn||(jn={})),function(e){e[e["None"]=0]="None",e[e["Keep"]=1]="Keep",e[e["Brackets"]=2]="Brackets",e[e["Advanced"]=3]="Advanced",e[e["Full"]=4]="Full"}(Kn||(Kn={})),function(e){e[e["acceptSuggestionOnCommitCharacter"]=0]="acceptSuggestionOnCommitCharacter",e[e["acceptSuggestionOnEnter"]=1]="acceptSuggestionOnEnter",e[e["accessibilitySupport"]=2]="accessibilitySupport",e[e["accessibilityPageSize"]=3]="accessibilityPageSize",e[e["ariaLabel"]=4]="ariaLabel",e[e["autoClosingBrackets"]=5]="autoClosingBrackets",e[e["autoClosingDelete"]=6]="autoClosingDelete",e[e["autoClosingOvertype"]=7]="autoClosingOvertype",e[e["autoClosingQuotes"]=8]="autoClosingQuotes",e[e["autoIndent"]=9]="autoIndent",e[e["automaticLayout"]=10]="automaticLayout",e[e["autoSurround"]=11]="autoSurround",e[e["codeLens"]=12]="codeLens",e[e["codeLensFontFamily"]=13]="codeLensFontFamily",e[e["codeLensFontSize"]=14]="codeLensFontSize",e[e["colorDecorators"]=15]="colorDecorators",e[e["columnSelection"]=16]="columnSelection",e[e["comments"]=17]="comments",e[e["contextmenu"]=18]="contextmenu",e[e["copyWithSyntaxHighlighting"]=19]="copyWithSyntaxHighlighting",e[e["cursorBlinking"]=20]="cursorBlinking",e[e["cursorSmoothCaretAnimation"]=21]="cursorSmoothCaretAnimation",e[e["cursorStyle"]=22]="cursorStyle",e[e["cursorSurroundingLines"]=23]="cursorSurroundingLines",e[e["cursorSurroundingLinesStyle"]=24]="cursorSurroundingLinesStyle",e[e["cursorWidth"]=25]="cursorWidth",e[e["disableLayerHinting"]=26]="disableLayerHinting",e[e["disableMonospaceOptimizations"]=27]="disableMonospaceOptimizations",e[e["domReadOnly"]=28]="domReadOnly",e[e["dragAndDrop"]=29]="dragAndDrop",e[e["emptySelectionClipboard"]=30]="emptySelectionClipboard",e[e["extraEditorClassName"]=31]="extraEditorClassName",e[e["fastScrollSensitivity"]=32]="fastScrollSensitivity",e[e["find"]=33]="find",e[e["fixedOverflowWidgets"]=34]="fixedOverflowWidgets",e[e["folding"]=35]="folding",e[e["foldingStrategy"]=36]="foldingStrategy",e[e["foldingHighlight"]=37]="foldingHighlight",e[e["unfoldOnClickAfterEndOfLine"]=38]="unfoldOnClickAfterEndOfLine",e[e["fontFamily"]=39]="fontFamily",e[e["fontInfo"]=40]="fontInfo",e[e["fontLigatures"]=41]="fontLigatures",e[e["fontSize"]=42]="fontSize",e[e["fontWeight"]=43]="fontWeight",e[e["formatOnPaste"]=44]="formatOnPaste",e[e["formatOnType"]=45]="formatOnType",e[e["glyphMargin"]=46]="glyphMargin",e[e["gotoLocation"]=47]="gotoLocation",e[e["hideCursorInOverviewRuler"]=48]="hideCursorInOverviewRuler",e[e["highlightActiveIndentGuide"]=49]="highlightActiveIndentGuide",e[e["hover"]=50]="hover",e[e["inDiffEditor"]=51]="inDiffEditor",e[e["inlineSuggest"]=52]="inlineSuggest",e[e["letterSpacing"]=53]="letterSpacing",e[e["lightbulb"]=54]="lightbulb",e[e["lineDecorationsWidth"]=55]="lineDecorationsWidth",e[e["lineHeight"]=56]="lineHeight",e[e["lineNumbers"]=57]="lineNumbers",e[e["lineNumbersMinChars"]=58]="lineNumbersMinChars",e[e["linkedEditing"]=59]="linkedEditing",e[e["links"]=60]="links",e[e["matchBrackets"]=61]="matchBrackets",e[e["minimap"]=62]="minimap",e[e["mouseStyle"]=63]="mouseStyle",e[e["mouseWheelScrollSensitivity"]=64]="mouseWheelScrollSensitivity",e[e["mouseWheelZoom"]=65]="mouseWheelZoom",e[e["multiCursorMergeOverlapping"]=66]="multiCursorMergeOverlapping",e[e["multiCursorModifier"]=67]="multiCursorModifier",e[e["multiCursorPaste"]=68]="multiCursorPaste",e[e["occurrencesHighlight"]=69]="occurrencesHighlight",e[e["overviewRulerBorder"]=70]="overviewRulerBorder",e[e["overviewRulerLanes"]=71]="overviewRulerLanes",e[e["padding"]=72]="padding",e[e["parameterHints"]=73]="parameterHints",e[e["peekWidgetDefaultFocus"]=74]="peekWidgetDefaultFocus",e[e["definitionLinkOpensInPeek"]=75]="definitionLinkOpensInPeek",e[e["quickSuggestions"]=76]="quickSuggestions",e[e["quickSuggestionsDelay"]=77]="quickSuggestionsDelay",e[e["readOnly"]=78]="readOnly",e[e["renameOnType"]=79]="renameOnType",e[e["renderControlCharacters"]=80]="renderControlCharacters",e[e["renderIndentGuides"]=81]="renderIndentGuides",e[e["renderFinalNewline"]=82]="renderFinalNewline",e[e["renderLineHighlight"]=83]="renderLineHighlight",e[e["renderLineHighlightOnlyWhenFocus"]=84]="renderLineHighlightOnlyWhenFocus",e[e["renderValidationDecorations"]=85]="renderValidationDecorations",e[e["renderWhitespace"]=86]="renderWhitespace",e[e["revealHorizontalRightPadding"]=87]="revealHorizontalRightPadding",e[e["roundedSelection"]=88]="roundedSelection",e[e["rulers"]=89]="rulers",e[e["scrollbar"]=90]="scrollbar",e[e["scrollBeyondLastColumn"]=91]="scrollBeyondLastColumn",e[e["scrollBeyondLastLine"]=92]="scrollBeyondLastLine",e[e["scrollPredominantAxis"]=93]="scrollPredominantAxis",e[e["selectionClipboard"]=94]="selectionClipboard",e[e["selectionHighlight"]=95]="selectionHighlight",e[e["selectOnLineNumbers"]=96]="selectOnLineNumbers",e[e["showFoldingControls"]=97]="showFoldingControls",e[e["showUnused"]=98]="showUnused",e[e["snippetSuggestions"]=99]="snippetSuggestions",e[e["smartSelect"]=100]="smartSelect",e[e["smoothScrolling"]=101]="smoothScrolling",e[e["stickyTabStops"]=102]="stickyTabStops",e[e["stopRenderingLineAfter"]=103]="stopRenderingLineAfter",e[e["suggest"]=104]="suggest",e[e["suggestFontSize"]=105]="suggestFontSize",e[e["suggestLineHeight"]=106]="suggestLineHeight",e[e["suggestOnTriggerCharacters"]=107]="suggestOnTriggerCharacters",e[e["suggestSelection"]=108]="suggestSelection",e[e["tabCompletion"]=109]="tabCompletion",e[e["tabIndex"]=110]="tabIndex",e[e["unusualLineTerminators"]=111]="unusualLineTerminators",e[e["useShadowDOM"]=112]="useShadowDOM",e[e["useTabStops"]=113]="useTabStops",e[e["wordSeparators"]=114]="wordSeparators",e[e["wordWrap"]=115]="wordWrap",e[e["wordWrapBreakAfterCharacters"]=116]="wordWrapBreakAfterCharacters",e[e["wordWrapBreakBeforeCharacters"]=117]="wordWrapBreakBeforeCharacters",e[e["wordWrapColumn"]=118]="wordWrapColumn",e[e["wordWrapOverride1"]=119]="wordWrapOverride1",e[e["wordWrapOverride2"]=120]="wordWrapOverride2",e[e["wrappingIndent"]=121]="wrappingIndent",e[e["wrappingStrategy"]=122]="wrappingStrategy",e[e["showDeprecated"]=123]="showDeprecated",e[e["inlayHints"]=124]="inlayHints",e[e["editorClassName"]=125]="editorClassName",e[e["pixelRatio"]=126]="pixelRatio",e[e["tabFocusMode"]=127]="tabFocusMode",e[e["layoutInfo"]=128]="layoutInfo",e[e["wrappingInfo"]=129]="wrappingInfo"}(Hn||(Hn={})),function(e){e[e["TextDefined"]=0]="TextDefined",e[e["LF"]=1]="LF",e[e["CRLF"]=2]="CRLF"}(Wn||(Wn={})),function(e){e[e["LF"]=0]="LF",e[e["CRLF"]=1]="CRLF"}(zn||(zn={})),function(e){e[e["None"]=0]="None",e[e["Indent"]=1]="Indent",e[e["IndentOutdent"]=2]="IndentOutdent",e[e["Outdent"]=3]="Outdent"}(qn||(qn={})),function(e){e[e["Other"]=0]="Other",e[e["Type"]=1]="Type",e[e["Parameter"]=2]="Parameter"}(Jn||(Jn={})),function(e){e[e["Automatic"]=0]="Automatic",e[e["Explicit"]=1]="Explicit"}(Xn||(Xn={})),function(e){e[e["DependsOnKbLayout"]=-1]="DependsOnKbLayout",e[e["Unknown"]=0]="Unknown",e[e["Backspace"]=1]="Backspace",e[e["Tab"]=2]="Tab",e[e["Enter"]=3]="Enter",e[e["Shift"]=4]="Shift",e[e["Ctrl"]=5]="Ctrl",e[e["Alt"]=6]="Alt",e[e["PauseBreak"]=7]="PauseBreak",e[e["CapsLock"]=8]="CapsLock",e[e["Escape"]=9]="Escape",e[e["Space"]=10]="Space",e[e["PageUp"]=11]="PageUp",e[e["PageDown"]=12]="PageDown",e[e["End"]=13]="End",e[e["Home"]=14]="Home",e[e["LeftArrow"]=15]="LeftArrow",e[e["UpArrow"]=16]="UpArrow",e[e["RightArrow"]=17]="RightArrow",e[e["DownArrow"]=18]="DownArrow",e[e["Insert"]=19]="Insert",e[e["Delete"]=20]="Delete",e[e["KEY_0"]=21]="KEY_0",e[e["KEY_1"]=22]="KEY_1",e[e["KEY_2"]=23]="KEY_2",e[e["KEY_3"]=24]="KEY_3",e[e["KEY_4"]=25]="KEY_4",e[e["KEY_5"]=26]="KEY_5",e[e["KEY_6"]=27]="KEY_6",e[e["KEY_7"]=28]="KEY_7",e[e["KEY_8"]=29]="KEY_8",e[e["KEY_9"]=30]="KEY_9",e[e["KEY_A"]=31]="KEY_A",e[e["KEY_B"]=32]="KEY_B",e[e["KEY_C"]=33]="KEY_C",e[e["KEY_D"]=34]="KEY_D",e[e["KEY_E"]=35]="KEY_E",e[e["KEY_F"]=36]="KEY_F",e[e["KEY_G"]=37]="KEY_G",e[e["KEY_H"]=38]="KEY_H",e[e["KEY_I"]=39]="KEY_I",e[e["KEY_J"]=40]="KEY_J",e[e["KEY_K"]=41]="KEY_K",e[e["KEY_L"]=42]="KEY_L",e[e["KEY_M"]=43]="KEY_M",e[e["KEY_N"]=44]="KEY_N",e[e["KEY_O"]=45]="KEY_O",e[e["KEY_P"]=46]="KEY_P",e[e["KEY_Q"]=47]="KEY_Q",e[e["KEY_R"]=48]="KEY_R",e[e["KEY_S"]=49]="KEY_S",e[e["KEY_T"]=50]="KEY_T",e[e["KEY_U"]=51]="KEY_U",e[e["KEY_V"]=52]="KEY_V",e[e["KEY_W"]=53]="KEY_W",e[e["KEY_X"]=54]="KEY_X",e[e["KEY_Y"]=55]="KEY_Y",e[e["KEY_Z"]=56]="KEY_Z",e[e["Meta"]=57]="Meta",e[e["ContextMenu"]=58]="ContextMenu",e[e["F1"]=59]="F1",e[e["F2"]=60]="F2",e[e["F3"]=61]="F3",e[e["F4"]=62]="F4",e[e["F5"]=63]="F5",e[e["F6"]=64]="F6",e[e["F7"]=65]="F7",e[e["F8"]=66]="F8",e[e["F9"]=67]="F9",e[e["F10"]=68]="F10",e[e["F11"]=69]="F11",e[e["F12"]=70]="F12",e[e["F13"]=71]="F13",e[e["F14"]=72]="F14",e[e["F15"]=73]="F15",e[e["F16"]=74]="F16",e[e["F17"]=75]="F17",e[e["F18"]=76]="F18",e[e["F19"]=77]="F19",e[e["NumLock"]=78]="NumLock",e[e["ScrollLock"]=79]="ScrollLock",e[e["US_SEMICOLON"]=80]="US_SEMICOLON",e[e["US_EQUAL"]=81]="US_EQUAL",e[e["US_COMMA"]=82]="US_COMMA",e[e["US_MINUS"]=83]="US_MINUS",e[e["US_DOT"]=84]="US_DOT",e[e["US_SLASH"]=85]="US_SLASH",e[e["US_BACKTICK"]=86]="US_BACKTICK",e[e["US_OPEN_SQUARE_BRACKET"]=87]="US_OPEN_SQUARE_BRACKET",e[e["US_BACKSLASH"]=88]="US_BACKSLASH",e[e["US_CLOSE_SQUARE_BRACKET"]=89]="US_CLOSE_SQUARE_BRACKET",e[e["US_QUOTE"]=90]="US_QUOTE",e[e["OEM_8"]=91]="OEM_8",e[e["OEM_102"]=92]="OEM_102",e[e["NUMPAD_0"]=93]="NUMPAD_0",e[e["NUMPAD_1"]=94]="NUMPAD_1",e[e["NUMPAD_2"]=95]="NUMPAD_2",e[e["NUMPAD_3"]=96]="NUMPAD_3",e[e["NUMPAD_4"]=97]="NUMPAD_4",e[e["NUMPAD_5"]=98]="NUMPAD_5",e[e["NUMPAD_6"]=99]="NUMPAD_6",e[e["NUMPAD_7"]=100]="NUMPAD_7",e[e["NUMPAD_8"]=101]="NUMPAD_8",e[e["NUMPAD_9"]=102]="NUMPAD_9",e[e["NUMPAD_MULTIPLY"]=103]="NUMPAD_MULTIPLY",e[e["NUMPAD_ADD"]=104]="NUMPAD_ADD",e[e["NUMPAD_SEPARATOR"]=105]="NUMPAD_SEPARATOR",e[e["NUMPAD_SUBTRACT"]=106]="NUMPAD_SUBTRACT",e[e["NUMPAD_DECIMAL"]=107]="NUMPAD_DECIMAL",e[e["NUMPAD_DIVIDE"]=108]="NUMPAD_DIVIDE",e[e["KEY_IN_COMPOSITION"]=109]="KEY_IN_COMPOSITION",e[e["ABNT_C1"]=110]="ABNT_C1",e[e["ABNT_C2"]=111]="ABNT_C2",e[e["MAX_VALUE"]=112]="MAX_VALUE"}(Yn||(Yn={})),function(e){e[e["Hint"]=1]="Hint",e[e["Info"]=2]="Info",e[e["Warning"]=4]="Warning",e[e["Error"]=8]="Error"}(Qn||(Qn={})),function(e){e[e["Unnecessary"]=1]="Unnecessary",e[e["Deprecated"]=2]="Deprecated"}(Zn||(Zn={})),function(e){e[e["Inline"]=1]="Inline",e[e["Gutter"]=2]="Gutter"}($n||($n={})),function(e){e[e["UNKNOWN"]=0]="UNKNOWN",e[e["TEXTAREA"]=1]="TEXTAREA",e[e["GUTTER_GLYPH_MARGIN"]=2]="GUTTER_GLYPH_MARGIN",e[e["GUTTER_LINE_NUMBERS"]=3]="GUTTER_LINE_NUMBERS",e[e["GUTTER_LINE_DECORATIONS"]=4]="GUTTER_LINE_DECORATIONS",e[e["GUTTER_VIEW_ZONE"]=5]="GUTTER_VIEW_ZONE",e[e["CONTENT_TEXT"]=6]="CONTENT_TEXT",e[e["CONTENT_EMPTY"]=7]="CONTENT_EMPTY",e[e["CONTENT_VIEW_ZONE"]=8]="CONTENT_VIEW_ZONE",e[e["CONTENT_WIDGET"]=9]="CONTENT_WIDGET",e[e["OVERVIEW_RULER"]=10]="OVERVIEW_RULER",e[e["SCROLLBAR"]=11]="SCROLLBAR",e[e["OVERLAY_WIDGET"]=12]="OVERLAY_WIDGET",e[e["OUTSIDE_EDITOR"]=13]="OUTSIDE_EDITOR"}(et||(et={})),function(e){e[e["TOP_RIGHT_CORNER"]=0]="TOP_RIGHT_CORNER",e[e["BOTTOM_RIGHT_CORNER"]=1]="BOTTOM_RIGHT_CORNER",e[e["TOP_CENTER"]=2]="TOP_CENTER"}(nt||(nt={})),function(e){e[e["Left"]=1]="Left",e[e["Center"]=2]="Center",e[e["Right"]=4]="Right",e[e["Full"]=7]="Full"}(tt||(tt={})),function(e){e[e["Off"]=0]="Off",e[e["On"]=1]="On",e[e["Relative"]=2]="Relative",e[e["Interval"]=3]="Interval",e[e["Custom"]=4]="Custom"}(rt||(rt={})),function(e){e[e["None"]=0]="None",e[e["Text"]=1]="Text",e[e["Blocks"]=2]="Blocks"}(at||(at={})),function(e){e[e["Smooth"]=0]="Smooth",e[e["Immediate"]=1]="Immediate"}(it||(it={})),function(e){e[e["Auto"]=1]="Auto",e[e["Hidden"]=2]="Hidden",e[e["Visible"]=3]="Visible"}(ot||(ot={})),function(e){e[e["LTR"]=0]="LTR",e[e["RTL"]=1]="RTL"}(st||(st={})),function(e){e[e["Invoke"]=1]="Invoke",e[e["TriggerCharacter"]=2]="TriggerCharacter",e[e["ContentChange"]=3]="ContentChange"}(ct||(ct={})),function(e){e[e["File"]=0]="File",e[e["Module"]=1]="Module",e[e["Namespace"]=2]="Namespace",e[e["Package"]=3]="Package",e[e["Class"]=4]="Class",e[e["Method"]=5]="Method",e[e["Property"]=6]="Property",e[e["Field"]=7]="Field",e[e["Constructor"]=8]="Constructor",e[e["Enum"]=9]="Enum",e[e["Interface"]=10]="Interface",e[e["Function"]=11]="Function",e[e["Variable"]=12]="Variable",e[e["Constant"]=13]="Constant",e[e["String"]=14]="String",e[e["Number"]=15]="Number",e[e["Boolean"]=16]="Boolean",e[e["Array"]=17]="Array",e[e["Object"]=18]="Object",e[e["Key"]=19]="Key",e[e["Null"]=20]="Null",e[e["EnumMember"]=21]="EnumMember",e[e["Struct"]=22]="Struct",e[e["Event"]=23]="Event",e[e["Operator"]=24]="Operator",e[e["TypeParameter"]=25]="TypeParameter"}(lt||(lt={})),function(e){e[e["Deprecated"]=1]="Deprecated"}(ut||(ut={})),function(e){e[e["Hidden"]=0]="Hidden",e[e["Blink"]=1]="Blink",e[e["Smooth"]=2]="Smooth",e[e["Phase"]=3]="Phase",e[e["Expand"]=4]="Expand",e[e["Solid"]=5]="Solid"}(dt||(dt={})),function(e){e[e["Line"]=1]="Line",e[e["Block"]=2]="Block",e[e["Underline"]=3]="Underline",e[e["LineThin"]=4]="LineThin",e[e["BlockOutline"]=5]="BlockOutline",e[e["UnderlineThin"]=6]="UnderlineThin"}(pt||(pt={})),function(e){e[e["AlwaysGrowsWhenTypingAtEdges"]=0]="AlwaysGrowsWhenTypingAtEdges",e[e["NeverGrowsWhenTypingAtEdges"]=1]="NeverGrowsWhenTypingAtEdges",e[e["GrowsOnlyWhenTypingBefore"]=2]="GrowsOnlyWhenTypingBefore",e[e["GrowsOnlyWhenTypingAfter"]=3]="GrowsOnlyWhenTypingAfter"}(ft||(ft={})),function(e){e[e["None"]=0]="None",e[e["Same"]=1]="Same",e[e["Indent"]=2]="Indent",e[e["DeepIndent"]=3]="DeepIndent"}(mt||(mt={}));class ht{static chord(e,n){return _t(e,n)}}function vt(){return{editor:void 0,languages:void 0,CancellationTokenSource:Cn,Emitter:xn,KeyCode:Yn,KeyMod:ht,Position:we,Range:Pe,Selection:gt,SelectionDirection:st,MarkerSeverity:Qn,MarkerTag:Zn,Uri:Se,Token:yt}}ht.CtrlCmd=2048,ht.Shift=1024,ht.Alt=512,ht.WinCtrl=256;var bt=function(e,n,t,r){function a(e){return e instanceof t?e:new t((function(n){n(e)}))}return new(t||(t=Promise))((function(t,i){function o(e){try{c(r.next(e))}catch(n){i(n)}}function s(e){try{c(r["throw"](e))}catch(n){i(n)}}function c(e){e.done?t(e.value):a(e.value).then(o,s)}c((r=r.apply(e,n||[])).next())}))};class Et extends Qe{get uri(){return this._uri}get eol(){return this._eol}getValue(){return this.getText()}getLinesContent(){return this._lines.slice(0)}getLineCount(){return this._lines.length}getLineContent(e){return this._lines[e-1]}getWordAtPosition(e,n){let t=rn(e.column,nn(n),this._lines[e.lineNumber-1],0);return t?new Pe(e.lineNumber,t.startColumn,e.lineNumber,t.endColumn):null}words(e){const n=this._lines,t=this._wordenize.bind(this);let r=0,a="",i=0,o=[];return{*[Symbol.iterator](){while(1)if(i<o.length){const e=a.substring(o[i].start,o[i].end);i+=1,yield e}else{if(!(r<n.length))break;a=n[r],o=t(a,e),i=0,r+=1}}}}getLineWords(e,n){let t=this._lines[e-1],r=this._wordenize(t,n),a=[];for(const i of r)a.push({word:t.substring(i.start,i.end),startColumn:i.start+1,endColumn:i.end+1});return a}_wordenize(e,n){const t=[];let r;n.lastIndex=0;while(r=n.exec(e)){if(0===r[0].length)break;t.push({start:r.index,end:r.index+r[0].length})}return t}getValueInRange(e){if(e=this._validateRange(e),e.startLineNumber===e.endLineNumber)return this._lines[e.startLineNumber-1].substring(e.startColumn-1,e.endColumn-1);let n=this._eol,t=e.startLineNumber-1,r=e.endLineNumber-1,a=[];a.push(this._lines[t].substring(e.startColumn-1));for(let i=t+1;i<r;i++)a.push(this._lines[i]);return a.push(this._lines[r].substring(0,e.endColumn-1)),a.join(n)}offsetAt(e){return e=this._validatePosition(e),this._ensureLineStarts(),this._lineStarts.getPrefixSum(e.lineNumber-2)+(e.column-1)}positionAt(e){e=Math.floor(e),e=Math.max(0,e),this._ensureLineStarts();let n=this._lineStarts.getIndexOf(e),t=this._lines[n.index].length;return{lineNumber:1+n.index,column:1+Math.min(n.remainder,t)}}_validateRange(e){const n=this._validatePosition({lineNumber:e.startLineNumber,column:e.startColumn}),t=this._validatePosition({lineNumber:e.endLineNumber,column:e.endColumn});return n.lineNumber!==e.startLineNumber||n.column!==e.startColumn||t.lineNumber!==e.endLineNumber||t.column!==e.endColumn?{startLineNumber:n.lineNumber,startColumn:n.column,endLineNumber:t.lineNumber,endColumn:t.column}:e}_validatePosition(e){if(!we.isIPosition(e))throw new Error("bad position");let{lineNumber:n,column:t}=e,r=!1;if(n<1)n=1,t=1,r=!0;else if(n>this._lines.length)n=this._lines.length,t=this._lines[n-1].length+1,r=!0;else{let e=this._lines[n-1].length+1;t<1?(t=1,r=!0):t>e&&(t=e,r=!0)}return r?{lineNumber:n,column:t}:e}}class Tt{constructor(e,n){this._host=e,this._models=Object.create(null),this._foreignModuleFactory=n,this._foreignModule=null}dispose(){this._models=Object.create(null)}_getModel(e){return this._models[e]}_getModels(){let e=[];return Object.keys(this._models).forEach(n=>e.push(this._models[n])),e}acceptNewModel(e){this._models[e.url]=new Et(Se.parse(e.url),e.lines,e.EOL,e.versionId)}acceptModelChanged(e,n){if(!this._models[e])return;let t=this._models[e];t.onEvents(n)}acceptRemovedModel(e){this._models[e]&&delete this._models[e]}computeDiff(e,n,t,r){return bt(this,void 0,void 0,(function*(){const a=this._getModel(e),i=this._getModel(n);if(!a||!i)return null;const o=a.getLinesContent(),s=i.getLinesContent(),c=new Ke(o,s,{shouldComputeCharChanges:!0,shouldPostProcessCharChanges:!0,shouldIgnoreTrimWhitespace:t,shouldMakePrettyDiff:!0,maxComputationTime:r}),l=c.computeDiff(),u=!(l.changes.length>0)&&this._modelsAreIdentical(a,i);return{quitEarly:l.quitEarly,identical:u,changes:l.changes}}))}_modelsAreIdentical(e,n){const t=e.getLineCount(),r=n.getLineCount();if(t!==r)return!1;for(let a=1;a<=t;a++){const t=e.getLineContent(a),r=n.getLineContent(a);if(t!==r)return!1}return!0}computeMoreMinimalEdits(e,n){return bt(this,void 0,void 0,(function*(){const t=this._getModel(e);if(!t)return n;const r=[];let a=void 0;n=n.slice(0).sort((e,n)=>{if(e.range&&n.range)return Pe.compareRangesUsingStarts(e.range,n.range);let t=e.range?0:1,r=n.range?0:1;return t-r});for(let{range:e,text:i,eol:o}of n){if("number"===typeof o&&(a=o),Pe.isEmpty(e)&&!i)continue;const n=t.getValueInRange(e);if(i=i.replace(/\r\n|\n|\r/g,t.eol),n===i)continue;if(Math.max(i.length,n.length)>Tt._diffLimit){r.push({range:e,text:i});continue}const s=H(n,i,!1),c=t.offsetAt(Pe.lift(e).getStartPosition());for(const e of s){const n=t.positionAt(c+e.originalStart),a=t.positionAt(c+e.originalStart+e.originalLength),o={text:i.substr(e.modifiedStart,e.modifiedLength),range:{startLineNumber:n.lineNumber,startColumn:n.column,endLineNumber:a.lineNumber,endColumn:a.column}};t.getValueInRange(o.range)!==o.text&&r.push(o)}}return"number"===typeof a&&r.push({eol:a,text:"",range:{startLineNumber:0,startColumn:0,endLineNumber:0,endColumn:0}}),r}))}computeLinks(e){return bt(this,void 0,void 0,(function*(){let n=this._getModel(e);return n?mn(n):null}))}textualSuggest(e,n,t,r){return bt(this,void 0,void 0,(function*(){const a=new vn(!0),i=new RegExp(t,r),o=new Set;e:for(let t of e){const e=this._getModel(t);if(e)for(let t of e.words(i))if(t!==n&&isNaN(Number(t))&&(o.add(t),o.size>Tt._suggestionsLimit))break e}return{words:Array.from(o),duration:a.elapsed()}}))}computeWordRanges(e,n,t,r){return bt(this,void 0,void 0,(function*(){let a=this._getModel(e);if(!a)return Object.create(null);const i=new RegExp(t,r),o=Object.create(null);for(let e=n.startLineNumber;e<n.endLineNumber;e++){let n=a.getLineWords(e,i);for(const t of n){if(!isNaN(Number(t.word)))continue;let n=o[t.word];n||(n=[],o[t.word]=n),n.push({startLineNumber:e,startColumn:t.startColumn,endLineNumber:e,endColumn:t.endColumn})}}return o}))}navigateValueSet(e,n,t,r,a){return bt(this,void 0,void 0,(function*(){let i=this._getModel(e);if(!i)return null;let o=new RegExp(r,a);n.startColumn===n.endColumn&&(n={startLineNumber:n.startLineNumber,startColumn:n.startColumn,endLineNumber:n.endLineNumber,endColumn:n.endColumn+1});let s=i.getValueInRange(n),c=i.getWordAtPosition({lineNumber:n.startLineNumber,column:n.startColumn},o);if(!c)return null;let l=i.getValueInRange(c),u=_n.INSTANCE.navigateValueSet(n,s,c,l,t);return u}))}loadForeignModule(e,n,t){const r=(e,n)=>this._host.fhr(e,n),a=S(t,r);let i={host:a,getMirrorModels:()=>this._getModels()};return this._foreignModuleFactory?(this._foreignModule=this._foreignModuleFactory(i,n),Promise.resolve(T(this._foreignModule))):Promise.reject(new Error("Unexpected usage"))}fmr(e,n){if(!this._foreignModule||"function"!==typeof this._foreignModule[e])return Promise.reject(new Error("Missing requestHandler or method: "+e));try{return Promise.resolve(this._foreignModule[e].apply(this._foreignModule,n))}catch(t){return Promise.reject(t)}}}Tt._diffLimit=1e5,Tt._suggestionsLimit=1e4,"function"===typeof importScripts&&(b["a"].monaco=vt());let St=!1;function xt(e){if(St)return;St=!0;const n=new D(e=>{self.postMessage(e)},n=>new Tt(n,e));self.onmessage=e=>{n.onmessage(e.data)}}self.onmessage=e=>{St||xt(null)};var Lt=t("973d"),Dt={"lib.d.ts":'/*! *****************************************************************************\nCopyright (c) Microsoft Corporation. All rights reserved.\nLicensed under the Apache License, Version 2.0 (the "License"); you may not use\nthis file except in compliance with the License. You may obtain a copy of the\nLicense at http://www.apache.org/licenses/LICENSE-2.0\n\nTHIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\nKIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED\nWARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,\nMERCHANTABLITY OR NON-INFRINGEMENT.\n\nSee the Apache Version 2.0 License for specific language governing permissions\nand limitations under the License.\n***************************************************************************** */\n\n\n\n/// <reference no-default-lib="true"/>\n\n\n/// <reference lib="es5" />\n/// <reference lib="dom" />\n/// <reference lib="webworker.importscripts" />\n/// <reference lib="scripthost" />\n',"lib.dom.d.ts":'/*! *****************************************************************************\nCopyright (c) Microsoft Corporation. All rights reserved.\nLicensed under the Apache License, Version 2.0 (the "License"); you may not use\nthis file except in compliance with the License. You may obtain a copy of the\nLicense at http://www.apache.org/licenses/LICENSE-2.0\n\nTHIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\nKIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED\nWARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,\nMERCHANTABLITY OR NON-INFRINGEMENT.\n\nSee the Apache Version 2.0 License for specific language governing permissions\nand limitations under the License.\n***************************************************************************** */\n\n\n\n/// <reference no-default-lib="true"/>\n\n\n/////////////////////////////\n/// DOM APIs\n/////////////////////////////\n\ninterface AddEventListenerOptions extends EventListenerOptions {\n    once?: boolean;\n    passive?: boolean;\n}\n\ninterface AddressErrors {\n    addressLine?: string;\n    city?: string;\n    country?: string;\n    dependentLocality?: string;\n    organization?: string;\n    phone?: string;\n    postalCode?: string;\n    recipient?: string;\n    region?: string;\n    sortingCode?: string;\n}\n\ninterface AesCbcParams extends Algorithm {\n    iv: Int8Array | Int16Array | Int32Array | Uint8Array | Uint16Array | Uint32Array | Uint8ClampedArray | Float32Array | Float64Array | DataView | ArrayBuffer;\n}\n\ninterface AesCtrParams extends Algorithm {\n    counter: Int8Array | Int16Array | Int32Array | Uint8Array | Uint16Array | Uint32Array | Uint8ClampedArray | Float32Array | Float64Array | DataView | ArrayBuffer;\n    length: number;\n}\n\ninterface AesDerivedKeyParams extends Algorithm {\n    length: number;\n}\n\ninterface AesGcmParams extends Algorithm {\n    additionalData?: Int8Array | Int16Array | Int32Array | Uint8Array | Uint16Array | Uint32Array | Uint8ClampedArray | Float32Array | Float64Array | DataView | ArrayBuffer;\n    iv: Int8Array | Int16Array | Int32Array | Uint8Array | Uint16Array | Uint32Array | Uint8ClampedArray | Float32Array | Float64Array | DataView | ArrayBuffer;\n    tagLength?: number;\n}\n\ninterface AesKeyAlgorithm extends KeyAlgorithm {\n    length: number;\n}\n\ninterface AesKeyGenParams extends Algorithm {\n    length: number;\n}\n\ninterface Algorithm {\n    name: string;\n}\n\ninterface AnalyserOptions extends AudioNodeOptions {\n    fftSize?: number;\n    maxDecibels?: number;\n    minDecibels?: number;\n    smoothingTimeConstant?: number;\n}\n\ninterface AnimationEventInit extends EventInit {\n    animationName?: string;\n    elapsedTime?: number;\n    pseudoElement?: string;\n}\n\ninterface AnimationPlaybackEventInit extends EventInit {\n    currentTime?: number | null;\n    timelineTime?: number | null;\n}\n\ninterface AssignedNodesOptions {\n    flatten?: boolean;\n}\n\ninterface AudioBufferOptions {\n    length: number;\n    numberOfChannels?: number;\n    sampleRate: number;\n}\n\ninterface AudioBufferSourceOptions {\n    buffer?: AudioBuffer | null;\n    detune?: number;\n    loop?: boolean;\n    loopEnd?: number;\n    loopStart?: number;\n    playbackRate?: number;\n}\n\ninterface AudioContextInfo {\n    currentTime?: number;\n    sampleRate?: number;\n}\n\ninterface AudioContextOptions {\n    latencyHint?: AudioContextLatencyCategory | number;\n    sampleRate?: number;\n}\n\ninterface AudioNodeOptions {\n    channelCount?: number;\n    channelCountMode?: ChannelCountMode;\n    channelInterpretation?: ChannelInterpretation;\n}\n\ninterface AudioParamDescriptor {\n    automationRate?: AutomationRate;\n    defaultValue?: number;\n    maxValue?: number;\n    minValue?: number;\n    name: string;\n}\n\ninterface AudioProcessingEventInit extends EventInit {\n    inputBuffer: AudioBuffer;\n    outputBuffer: AudioBuffer;\n    playbackTime: number;\n}\n\ninterface AudioTimestamp {\n    contextTime?: number;\n    performanceTime?: number;\n}\n\ninterface AudioWorkletNodeOptions extends AudioNodeOptions {\n    numberOfInputs?: number;\n    numberOfOutputs?: number;\n    outputChannelCount?: number[];\n    parameterData?: Record<string, number>;\n    processorOptions?: any;\n}\n\ninterface AuthenticationExtensionsClientInputs {\n    appid?: string;\n    appidExclude?: string;\n    credProps?: boolean;\n    uvm?: boolean;\n}\n\ninterface AuthenticationExtensionsClientOutputs {\n    appid?: boolean;\n    credProps?: CredentialPropertiesOutput;\n    uvm?: UvmEntries;\n}\n\ninterface AuthenticatorSelectionCriteria {\n    authenticatorAttachment?: AuthenticatorAttachment;\n    requireResidentKey?: boolean;\n    residentKey?: ResidentKeyRequirement;\n    userVerification?: UserVerificationRequirement;\n}\n\ninterface BiquadFilterOptions extends AudioNodeOptions {\n    Q?: number;\n    detune?: number;\n    frequency?: number;\n    gain?: number;\n    type?: BiquadFilterType;\n}\n\ninterface BlobPropertyBag {\n    endings?: EndingType;\n    type?: string;\n}\n\ninterface ByteLengthChunk {\n    byteLength?: number;\n}\n\ninterface CacheQueryOptions {\n    ignoreMethod?: boolean;\n    ignoreSearch?: boolean;\n    ignoreVary?: boolean;\n}\n\ninterface CanvasRenderingContext2DSettings {\n    alpha?: boolean;\n    desynchronized?: boolean;\n}\n\ninterface ChannelMergerOptions extends AudioNodeOptions {\n    numberOfInputs?: number;\n}\n\ninterface ChannelSplitterOptions extends AudioNodeOptions {\n    numberOfOutputs?: number;\n}\n\ninterface ClientQueryOptions {\n    includeUncontrolled?: boolean;\n    type?: ClientTypes;\n}\n\ninterface ClipboardEventInit extends EventInit {\n    clipboardData?: DataTransfer | null;\n}\n\ninterface CloseEventInit extends EventInit {\n    code?: number;\n    reason?: string;\n    wasClean?: boolean;\n}\n\ninterface CompositionEventInit extends UIEventInit {\n    data?: string;\n}\n\ninterface ComputedEffectTiming extends EffectTiming {\n    activeDuration?: number;\n    currentIteration?: number | null;\n    endTime?: number;\n    localTime?: number | null;\n    progress?: number | null;\n}\n\ninterface ComputedKeyframe {\n    composite: CompositeOperationOrAuto;\n    computedOffset: number;\n    easing: string;\n    offset: number | null;\n    [property: string]: string | number | null | undefined;\n}\n\ninterface ConfirmSiteSpecificExceptionsInformation extends ExceptionInformation {\n    arrayOfDomainStrings?: string[];\n}\n\ninterface ConstantSourceOptions {\n    offset?: number;\n}\n\ninterface ConstrainBooleanParameters {\n    exact?: boolean;\n    ideal?: boolean;\n}\n\ninterface ConstrainDOMStringParameters {\n    exact?: string | string[];\n    ideal?: string | string[];\n}\n\ninterface ConstrainDoubleRange extends DoubleRange {\n    exact?: number;\n    ideal?: number;\n}\n\ninterface ConstrainULongRange extends ULongRange {\n    exact?: number;\n    ideal?: number;\n}\n\ninterface ConstrainVideoFacingModeParameters {\n    exact?: VideoFacingModeEnum | VideoFacingModeEnum[];\n    ideal?: VideoFacingModeEnum | VideoFacingModeEnum[];\n}\n\ninterface ConvolverOptions extends AudioNodeOptions {\n    buffer?: AudioBuffer | null;\n    disableNormalization?: boolean;\n}\n\ninterface CredentialCreationOptions {\n    publicKey?: PublicKeyCredentialCreationOptions;\n    signal?: AbortSignal;\n}\n\ninterface CredentialPropertiesOutput {\n    rk?: boolean;\n}\n\ninterface CredentialRequestOptions {\n    mediation?: CredentialMediationRequirement;\n    publicKey?: PublicKeyCredentialRequestOptions;\n    signal?: AbortSignal;\n}\n\ninterface CustomEventInit<T = any> extends EventInit {\n    detail?: T;\n}\n\ninterface DOMMatrix2DInit {\n    a?: number;\n    b?: number;\n    c?: number;\n    d?: number;\n    e?: number;\n    f?: number;\n    m11?: number;\n    m12?: number;\n    m21?: number;\n    m22?: number;\n    m41?: number;\n    m42?: number;\n}\n\ninterface DOMMatrixInit extends DOMMatrix2DInit {\n    is2D?: boolean;\n    m13?: number;\n    m14?: number;\n    m23?: number;\n    m24?: number;\n    m31?: number;\n    m32?: number;\n    m33?: number;\n    m34?: number;\n    m43?: number;\n    m44?: number;\n}\n\ninterface DOMPointInit {\n    w?: number;\n    x?: number;\n    y?: number;\n    z?: number;\n}\n\ninterface DOMQuadInit {\n    p1?: DOMPointInit;\n    p2?: DOMPointInit;\n    p3?: DOMPointInit;\n    p4?: DOMPointInit;\n}\n\ninterface DOMRectInit {\n    height?: number;\n    width?: number;\n    x?: number;\n    y?: number;\n}\n\ninterface DelayOptions extends AudioNodeOptions {\n    delayTime?: number;\n    maxDelayTime?: number;\n}\n\ninterface DeviceMotionEventAccelerationInit {\n    x?: number | null;\n    y?: number | null;\n    z?: number | null;\n}\n\ninterface DeviceMotionEventInit extends EventInit {\n    acceleration?: DeviceMotionEventAccelerationInit;\n    accelerationIncludingGravity?: DeviceMotionEventAccelerationInit;\n    interval?: number;\n    rotationRate?: DeviceMotionEventRotationRateInit;\n}\n\ninterface DeviceMotionEventRotationRateInit {\n    alpha?: number | null;\n    beta?: number | null;\n    gamma?: number | null;\n}\n\ninterface DeviceOrientationEventInit extends EventInit {\n    absolute?: boolean;\n    alpha?: number | null;\n    beta?: number | null;\n    gamma?: number | null;\n}\n\ninterface DevicePermissionDescriptor extends PermissionDescriptor {\n    deviceId?: string;\n    name: "camera" | "microphone" | "speaker";\n}\n\ninterface DocumentTimelineOptions {\n    originTime?: number;\n}\n\ninterface DoubleRange {\n    max?: number;\n    min?: number;\n}\n\ninterface DragEventInit extends MouseEventInit {\n    dataTransfer?: DataTransfer | null;\n}\n\ninterface DynamicsCompressorOptions extends AudioNodeOptions {\n    attack?: number;\n    knee?: number;\n    ratio?: number;\n    release?: number;\n    threshold?: number;\n}\n\ninterface EcKeyAlgorithm extends KeyAlgorithm {\n    namedCurve: NamedCurve;\n}\n\ninterface EcKeyGenParams extends Algorithm {\n    namedCurve: NamedCurve;\n}\n\ninterface EcKeyImportParams extends Algorithm {\n    namedCurve: NamedCurve;\n}\n\ninterface EcdhKeyDeriveParams extends Algorithm {\n    public: CryptoKey;\n}\n\ninterface EcdsaParams extends Algorithm {\n    hash: HashAlgorithmIdentifier;\n}\n\ninterface EffectTiming {\n    delay?: number;\n    direction?: PlaybackDirection;\n    duration?: number | string;\n    easing?: string;\n    endDelay?: number;\n    fill?: FillMode;\n    iterationStart?: number;\n    iterations?: number;\n}\n\ninterface ElementCreationOptions {\n    is?: string;\n}\n\ninterface ElementDefinitionOptions {\n    extends?: string;\n}\n\ninterface ErrorEventInit extends EventInit {\n    colno?: number;\n    error?: any;\n    filename?: string;\n    lineno?: number;\n    message?: string;\n}\n\ninterface EventInit {\n    bubbles?: boolean;\n    cancelable?: boolean;\n    composed?: boolean;\n}\n\ninterface EventListenerOptions {\n    capture?: boolean;\n}\n\ninterface EventModifierInit extends UIEventInit {\n    altKey?: boolean;\n    ctrlKey?: boolean;\n    metaKey?: boolean;\n    modifierAltGraph?: boolean;\n    modifierCapsLock?: boolean;\n    modifierFn?: boolean;\n    modifierFnLock?: boolean;\n    modifierHyper?: boolean;\n    modifierNumLock?: boolean;\n    modifierScrollLock?: boolean;\n    modifierSuper?: boolean;\n    modifierSymbol?: boolean;\n    modifierSymbolLock?: boolean;\n    shiftKey?: boolean;\n}\n\ninterface EventSourceInit {\n    withCredentials?: boolean;\n}\n\ninterface ExceptionInformation {\n    domain?: string | null;\n}\n\ninterface FilePropertyBag extends BlobPropertyBag {\n    lastModified?: number;\n}\n\ninterface FocusEventInit extends UIEventInit {\n    relatedTarget?: EventTarget | null;\n}\n\ninterface FocusNavigationEventInit extends EventInit {\n    navigationReason?: string | null;\n    originHeight?: number;\n    originLeft?: number;\n    originTop?: number;\n    originWidth?: number;\n}\n\ninterface FocusNavigationOrigin {\n    originHeight?: number;\n    originLeft?: number;\n    originTop?: number;\n    originWidth?: number;\n}\n\ninterface FocusOptions {\n    preventScroll?: boolean;\n}\n\ninterface FullscreenOptions {\n    navigationUI?: FullscreenNavigationUI;\n}\n\ninterface GainOptions extends AudioNodeOptions {\n    gain?: number;\n}\n\ninterface GamepadEventInit extends EventInit {\n    gamepad: Gamepad;\n}\n\ninterface GetNotificationOptions {\n    tag?: string;\n}\n\ninterface GetRootNodeOptions {\n    composed?: boolean;\n}\n\ninterface HashChangeEventInit extends EventInit {\n    newURL?: string;\n    oldURL?: string;\n}\n\ninterface HkdfParams extends Algorithm {\n    hash: HashAlgorithmIdentifier;\n    info: Int8Array | Int16Array | Int32Array | Uint8Array | Uint16Array | Uint32Array | Uint8ClampedArray | Float32Array | Float64Array | DataView | ArrayBuffer;\n    salt: Int8Array | Int16Array | Int32Array | Uint8Array | Uint16Array | Uint32Array | Uint8ClampedArray | Float32Array | Float64Array | DataView | ArrayBuffer;\n}\n\ninterface HmacImportParams extends Algorithm {\n    hash: HashAlgorithmIdentifier;\n    length?: number;\n}\n\ninterface HmacKeyAlgorithm extends KeyAlgorithm {\n    hash: KeyAlgorithm;\n    length: number;\n}\n\ninterface HmacKeyGenParams extends Algorithm {\n    hash: HashAlgorithmIdentifier;\n    length?: number;\n}\n\ninterface IDBIndexParameters {\n    multiEntry?: boolean;\n    unique?: boolean;\n}\n\ninterface IDBObjectStoreParameters {\n    autoIncrement?: boolean;\n    keyPath?: string | string[] | null;\n}\n\ninterface IDBVersionChangeEventInit extends EventInit {\n    newVersion?: number | null;\n    oldVersion?: number;\n}\n\ninterface IIRFilterOptions extends AudioNodeOptions {\n    feedback: number[];\n    feedforward: number[];\n}\n\ninterface ImageBitmapOptions {\n    colorSpaceConversion?: ColorSpaceConversion;\n    imageOrientation?: ImageOrientation;\n    premultiplyAlpha?: PremultiplyAlpha;\n    resizeHeight?: number;\n    resizeQuality?: ResizeQuality;\n    resizeWidth?: number;\n}\n\ninterface ImageBitmapRenderingContextSettings {\n    alpha?: boolean;\n}\n\ninterface ImageEncodeOptions {\n    quality?: number;\n    type?: string;\n}\n\ninterface ImportMeta {\n    url: string;\n}\n\ninterface InputEventInit extends UIEventInit {\n    data?: string | null;\n    inputType?: string;\n    isComposing?: boolean;\n}\n\ninterface IntersectionObserverEntryInit {\n    boundingClientRect: DOMRectInit;\n    intersectionRatio: number;\n    intersectionRect: DOMRectInit;\n    isIntersecting: boolean;\n    rootBounds: DOMRectInit | null;\n    target: Element;\n    time: number;\n}\n\ninterface IntersectionObserverInit {\n    root?: Element | Document | null;\n    rootMargin?: string;\n    threshold?: number | number[];\n}\n\ninterface JsonWebKey {\n    alg?: string;\n    crv?: string;\n    d?: string;\n    dp?: string;\n    dq?: string;\n    e?: string;\n    ext?: boolean;\n    k?: string;\n    key_ops?: string[];\n    kty?: string;\n    n?: string;\n    oth?: RsaOtherPrimesInfo[];\n    p?: string;\n    q?: string;\n    qi?: string;\n    use?: string;\n    x?: string;\n    y?: string;\n}\n\ninterface KeyAlgorithm {\n    name: string;\n}\n\ninterface KeyboardEventInit extends EventModifierInit {\n    /** @deprecated */\n    charCode?: number;\n    code?: string;\n    isComposing?: boolean;\n    key?: string;\n    /** @deprecated */\n    keyCode?: number;\n    location?: number;\n    repeat?: boolean;\n}\n\ninterface Keyframe {\n    composite?: CompositeOperationOrAuto;\n    easing?: string;\n    offset?: number | null;\n    [property: string]: string | number | null | undefined;\n}\n\ninterface KeyframeAnimationOptions extends KeyframeEffectOptions {\n    id?: string;\n}\n\ninterface KeyframeEffectOptions extends EffectTiming {\n    composite?: CompositeOperation;\n    iterationComposite?: IterationCompositeOperation;\n}\n\ninterface MediaElementAudioSourceOptions {\n    mediaElement: HTMLMediaElement;\n}\n\ninterface MediaEncryptedEventInit extends EventInit {\n    initData?: ArrayBuffer | null;\n    initDataType?: string;\n}\n\ninterface MediaKeyMessageEventInit extends EventInit {\n    message: ArrayBuffer;\n    messageType: MediaKeyMessageType;\n}\n\ninterface MediaKeySystemConfiguration {\n    audioCapabilities?: MediaKeySystemMediaCapability[];\n    distinctiveIdentifier?: MediaKeysRequirement;\n    initDataTypes?: string[];\n    label?: string;\n    persistentState?: MediaKeysRequirement;\n    sessionTypes?: string[];\n    videoCapabilities?: MediaKeySystemMediaCapability[];\n}\n\ninterface MediaKeySystemMediaCapability {\n    contentType?: string;\n    robustness?: string;\n}\n\ninterface MediaQueryListEventInit extends EventInit {\n    matches?: boolean;\n    media?: string;\n}\n\ninterface MediaStreamAudioSourceOptions {\n    mediaStream: MediaStream;\n}\n\ninterface MediaStreamConstraints {\n    audio?: boolean | MediaTrackConstraints;\n    peerIdentity?: string;\n    video?: boolean | MediaTrackConstraints;\n}\n\ninterface MediaStreamErrorEventInit extends EventInit {\n    error?: MediaStreamError | null;\n}\n\ninterface MediaStreamEventInit extends EventInit {\n    stream?: MediaStream;\n}\n\ninterface MediaStreamTrackAudioSourceOptions {\n    mediaStreamTrack: MediaStreamTrack;\n}\n\ninterface MediaStreamTrackEventInit extends EventInit {\n    track: MediaStreamTrack;\n}\n\ninterface MediaTrackCapabilities {\n    aspectRatio?: DoubleRange;\n    autoGainControl?: boolean[];\n    channelCount?: ULongRange;\n    deviceId?: string;\n    echoCancellation?: boolean[];\n    facingMode?: string[];\n    frameRate?: DoubleRange;\n    groupId?: string;\n    height?: ULongRange;\n    latency?: DoubleRange;\n    noiseSuppression?: boolean[];\n    resizeMode?: string[];\n    sampleRate?: ULongRange;\n    sampleSize?: ULongRange;\n    width?: ULongRange;\n}\n\ninterface MediaTrackConstraintSet {\n    aspectRatio?: ConstrainDouble;\n    autoGainControl?: ConstrainBoolean;\n    channelCount?: ConstrainULong;\n    deviceId?: ConstrainDOMString;\n    echoCancellation?: ConstrainBoolean;\n    facingMode?: ConstrainDOMString;\n    frameRate?: ConstrainDouble;\n    groupId?: ConstrainDOMString;\n    height?: ConstrainULong;\n    latency?: ConstrainDouble;\n    noiseSuppression?: ConstrainBoolean;\n    resizeMode?: ConstrainDOMString;\n    sampleRate?: ConstrainULong;\n    sampleSize?: ConstrainULong;\n    width?: ConstrainULong;\n}\n\ninterface MediaTrackConstraints extends MediaTrackConstraintSet {\n    advanced?: MediaTrackConstraintSet[];\n}\n\ninterface MediaTrackSettings {\n    aspectRatio?: number;\n    autoGainControl?: boolean;\n    channelCount?: number;\n    deviceId?: string;\n    echoCancellation?: boolean;\n    facingMode?: string;\n    frameRate?: number;\n    groupId?: string;\n    height?: number;\n    latency?: number;\n    noiseSuppression?: boolean;\n    resizeMode?: string;\n    sampleRate?: number;\n    sampleSize?: number;\n    width?: number;\n}\n\ninterface MediaTrackSupportedConstraints {\n    aspectRatio?: boolean;\n    autoGainControl?: boolean;\n    channelCount?: boolean;\n    deviceId?: boolean;\n    echoCancellation?: boolean;\n    facingMode?: boolean;\n    frameRate?: boolean;\n    groupId?: boolean;\n    height?: boolean;\n    latency?: boolean;\n    noiseSuppression?: boolean;\n    resizeMode?: boolean;\n    sampleRate?: boolean;\n    sampleSize?: boolean;\n    width?: boolean;\n}\n\ninterface MessageEventInit<T = any> extends EventInit {\n    data?: T;\n    lastEventId?: string;\n    origin?: string;\n    ports?: MessagePort[];\n    source?: MessageEventSource | null;\n}\n\ninterface MidiPermissionDescriptor extends PermissionDescriptor {\n    name: "midi";\n    sysex?: boolean;\n}\n\ninterface MouseEventInit extends EventModifierInit {\n    button?: number;\n    buttons?: number;\n    clientX?: number;\n    clientY?: number;\n    movementX?: number;\n    movementY?: number;\n    relatedTarget?: EventTarget | null;\n    screenX?: number;\n    screenY?: number;\n}\n\ninterface MultiCacheQueryOptions extends CacheQueryOptions {\n    cacheName?: string;\n}\n\ninterface MutationObserverInit {\n    /**\n     * Set to a list of attribute local names (without namespace) if not all attribute mutations need to be observed and attributes is true or omitted.\n     */\n    attributeFilter?: string[];\n    /**\n     * Set to true if attributes is true or omitted and target\'s attribute value before the mutation needs to be recorded.\n     */\n    attributeOldValue?: boolean;\n    /**\n     * Set to true if mutations to target\'s attributes are to be observed. Can be omitted if attributeOldValue or attributeFilter is specified.\n     */\n    attributes?: boolean;\n    /**\n     * Set to true if mutations to target\'s data are to be observed. Can be omitted if characterDataOldValue is specified.\n     */\n    characterData?: boolean;\n    /**\n     * Set to true if characterData is set to true or omitted and target\'s data before the mutation needs to be recorded.\n     */\n    characterDataOldValue?: boolean;\n    /**\n     * Set to true if mutations to target\'s children are to be observed.\n     */\n    childList?: boolean;\n    /**\n     * Set to true if mutations to not just target, but also target\'s descendants are to be observed.\n     */\n    subtree?: boolean;\n}\n\ninterface NavigationPreloadState {\n    enabled?: boolean;\n    headerValue?: string;\n}\n\ninterface NotificationAction {\n    action: string;\n    icon?: string;\n    title: string;\n}\n\ninterface NotificationOptions {\n    actions?: NotificationAction[];\n    badge?: string;\n    body?: string;\n    data?: any;\n    dir?: NotificationDirection;\n    icon?: string;\n    image?: string;\n    lang?: string;\n    renotify?: boolean;\n    requireInteraction?: boolean;\n    silent?: boolean;\n    tag?: string;\n    timestamp?: number;\n    vibrate?: VibratePattern;\n}\n\ninterface OfflineAudioCompletionEventInit extends EventInit {\n    renderedBuffer: AudioBuffer;\n}\n\ninterface OfflineAudioContextOptions {\n    length: number;\n    numberOfChannels?: number;\n    sampleRate: number;\n}\n\ninterface OptionalEffectTiming {\n    delay?: number;\n    direction?: PlaybackDirection;\n    duration?: number | string;\n    easing?: string;\n    endDelay?: number;\n    fill?: FillMode;\n    iterationStart?: number;\n    iterations?: number;\n}\n\ninterface OscillatorOptions extends AudioNodeOptions {\n    detune?: number;\n    frequency?: number;\n    periodicWave?: PeriodicWave;\n    type?: OscillatorType;\n}\n\ninterface PageTransitionEventInit extends EventInit {\n    persisted?: boolean;\n}\n\ninterface PannerOptions extends AudioNodeOptions {\n    coneInnerAngle?: number;\n    coneOuterAngle?: number;\n    coneOuterGain?: number;\n    distanceModel?: DistanceModelType;\n    maxDistance?: number;\n    orientationX?: number;\n    orientationY?: number;\n    orientationZ?: number;\n    panningModel?: PanningModelType;\n    positionX?: number;\n    positionY?: number;\n    positionZ?: number;\n    refDistance?: number;\n    rolloffFactor?: number;\n}\n\ninterface PayerErrors {\n    email?: string;\n    name?: string;\n    phone?: string;\n}\n\ninterface PaymentCurrencyAmount {\n    currency: string;\n    value: string;\n}\n\ninterface PaymentDetailsBase {\n    displayItems?: PaymentItem[];\n    modifiers?: PaymentDetailsModifier[];\n    shippingOptions?: PaymentShippingOption[];\n}\n\ninterface PaymentDetailsInit extends PaymentDetailsBase {\n    id?: string;\n    total: PaymentItem;\n}\n\ninterface PaymentDetailsModifier {\n    additionalDisplayItems?: PaymentItem[];\n    data?: any;\n    supportedMethods: string | string[];\n    total?: PaymentItem;\n}\n\ninterface PaymentDetailsUpdate extends PaymentDetailsBase {\n    error?: string;\n    payerErrors?: PayerErrors;\n    paymentMethodErrors?: any;\n    shippingAddressErrors?: AddressErrors;\n    total?: PaymentItem;\n}\n\ninterface PaymentItem {\n    amount: PaymentCurrencyAmount;\n    label: string;\n    pending?: boolean;\n}\n\ninterface PaymentMethodChangeEventInit extends PaymentRequestUpdateEventInit {\n    methodDetails?: any;\n    methodName?: string;\n}\n\ninterface PaymentMethodData {\n    data?: any;\n    supportedMethods: string | string[];\n}\n\ninterface PaymentOptions {\n    requestBillingAddress?: boolean;\n    requestPayerEmail?: boolean;\n    requestPayerName?: boolean;\n    requestPayerPhone?: boolean;\n    requestShipping?: boolean;\n    shippingType?: PaymentShippingType;\n}\n\ninterface PaymentRequestUpdateEventInit extends EventInit {\n}\n\ninterface PaymentShippingOption {\n    amount: PaymentCurrencyAmount;\n    id: string;\n    label: string;\n    selected?: boolean;\n}\n\ninterface PaymentValidationErrors {\n    error?: string;\n    payer?: PayerErrors;\n    paymentMethod?: any;\n    shippingAddress?: AddressErrors;\n}\n\ninterface Pbkdf2Params extends Algorithm {\n    hash: HashAlgorithmIdentifier;\n    iterations: number;\n    salt: Int8Array | Int16Array | Int32Array | Uint8Array | Uint16Array | Uint32Array | Uint8ClampedArray | Float32Array | Float64Array | DataView | ArrayBuffer;\n}\n\ninterface PerformanceObserverInit {\n    buffered?: boolean;\n    entryTypes?: string[];\n    type?: string;\n}\n\ninterface PeriodicWaveConstraints {\n    disableNormalization?: boolean;\n}\n\ninterface PeriodicWaveOptions extends PeriodicWaveConstraints {\n    imag?: number[] | Float32Array;\n    real?: number[] | Float32Array;\n}\n\ninterface PermissionDescriptor {\n    name: PermissionName;\n}\n\ninterface PointerEventInit extends MouseEventInit {\n    coalescedEvents?: PointerEvent[];\n    height?: number;\n    isPrimary?: boolean;\n    pointerId?: number;\n    pointerType?: string;\n    predictedEvents?: PointerEvent[];\n    pressure?: number;\n    tangentialPressure?: number;\n    tiltX?: number;\n    tiltY?: number;\n    twist?: number;\n    width?: number;\n}\n\ninterface PopStateEventInit extends EventInit {\n    state?: any;\n}\n\ninterface PositionOptions {\n    enableHighAccuracy?: boolean;\n    maximumAge?: number;\n    timeout?: number;\n}\n\ninterface PostMessageOptions {\n    transfer?: any[];\n}\n\ninterface ProgressEventInit extends EventInit {\n    lengthComputable?: boolean;\n    loaded?: number;\n    total?: number;\n}\n\ninterface PromiseRejectionEventInit extends EventInit {\n    promise: Promise<any>;\n    reason?: any;\n}\n\ninterface PropertyIndexedKeyframes {\n    composite?: CompositeOperationOrAuto | CompositeOperationOrAuto[];\n    easing?: string | string[];\n    offset?: number | (number | null)[];\n    [property: string]: string | string[] | number | null | (number | null)[] | undefined;\n}\n\ninterface PublicKeyCredentialCreationOptions {\n    attestation?: AttestationConveyancePreference;\n    authenticatorSelection?: AuthenticatorSelectionCriteria;\n    challenge: BufferSource;\n    excludeCredentials?: PublicKeyCredentialDescriptor[];\n    extensions?: AuthenticationExtensionsClientInputs;\n    pubKeyCredParams: PublicKeyCredentialParameters[];\n    rp: PublicKeyCredentialRpEntity;\n    timeout?: number;\n    user: PublicKeyCredentialUserEntity;\n}\n\ninterface PublicKeyCredentialDescriptor {\n    id: BufferSource;\n    transports?: AuthenticatorTransport[];\n    type: PublicKeyCredentialType;\n}\n\ninterface PublicKeyCredentialEntity {\n    name: string;\n}\n\ninterface PublicKeyCredentialParameters {\n    alg: COSEAlgorithmIdentifier;\n    type: PublicKeyCredentialType;\n}\n\ninterface PublicKeyCredentialRequestOptions {\n    allowCredentials?: PublicKeyCredentialDescriptor[];\n    challenge: BufferSource;\n    extensions?: AuthenticationExtensionsClientInputs;\n    rpId?: string;\n    timeout?: number;\n    userVerification?: UserVerificationRequirement;\n}\n\ninterface PublicKeyCredentialRpEntity extends PublicKeyCredentialEntity {\n    id?: string;\n}\n\ninterface PublicKeyCredentialUserEntity extends PublicKeyCredentialEntity {\n    displayName: string;\n    id: BufferSource;\n}\n\ninterface PushPermissionDescriptor extends PermissionDescriptor {\n    name: "push";\n    userVisibleOnly?: boolean;\n}\n\ninterface PushSubscriptionJSON {\n    endpoint?: string;\n    expirationTime?: number | null;\n    keys?: Record<string, string>;\n}\n\ninterface PushSubscriptionOptionsInit {\n    applicationServerKey?: BufferSource | string | null;\n    userVisibleOnly?: boolean;\n}\n\ninterface QueuingStrategy<T = any> {\n    highWaterMark?: number;\n    size?: QueuingStrategySize<T>;\n}\n\ninterface QueuingStrategyInit {\n    /**\n     * Creates a new ByteLengthQueuingStrategy with the provided high water mark.\n     *\n     * Note that the provided high water mark will not be validated ahead of time. Instead, if it is negative, NaN, or not a number, the resulting ByteLengthQueuingStrategy will cause the corresponding stream constructor to throw.\n     */\n    highWaterMark: number;\n}\n\ninterface RTCAnswerOptions extends RTCOfferAnswerOptions {\n}\n\ninterface RTCCertificateExpiration {\n    expires?: number;\n}\n\ninterface RTCConfiguration {\n    bundlePolicy?: RTCBundlePolicy;\n    certificates?: RTCCertificate[];\n    iceCandidatePoolSize?: number;\n    iceServers?: RTCIceServer[];\n    iceTransportPolicy?: RTCIceTransportPolicy;\n    rtcpMuxPolicy?: RTCRtcpMuxPolicy;\n}\n\ninterface RTCDTMFToneChangeEventInit extends EventInit {\n    tone?: string;\n}\n\ninterface RTCDataChannelEventInit extends EventInit {\n    channel: RTCDataChannel;\n}\n\ninterface RTCDataChannelInit {\n    id?: number;\n    maxPacketLifeTime?: number;\n    maxRetransmits?: number;\n    negotiated?: boolean;\n    ordered?: boolean;\n    protocol?: string;\n}\n\ninterface RTCDtlsFingerprint {\n    algorithm?: string;\n    value?: string;\n}\n\ninterface RTCDtlsParameters {\n    fingerprints?: RTCDtlsFingerprint[];\n    role?: RTCDtlsRole;\n}\n\ninterface RTCErrorEventInit extends EventInit {\n    error: RTCError;\n}\n\ninterface RTCErrorInit {\n    errorDetail: RTCErrorDetailType;\n    receivedAlert?: number;\n    sctpCauseCode?: number;\n    sdpLineNumber?: number;\n    sentAlert?: number;\n}\n\ninterface RTCIceCandidateAttributes extends RTCStats {\n    addressSourceUrl?: string;\n    candidateType?: RTCStatsIceCandidateType;\n    ipAddress?: string;\n    portNumber?: number;\n    priority?: number;\n    transport?: string;\n}\n\ninterface RTCIceCandidateComplete {\n}\n\ninterface RTCIceCandidateDictionary {\n    foundation?: string;\n    ip?: string;\n    msMTurnSessionId?: string;\n    port?: number;\n    priority?: number;\n    protocol?: RTCIceProtocol;\n    relatedAddress?: string;\n    relatedPort?: number;\n    tcpType?: RTCIceTcpCandidateType;\n    type?: RTCIceCandidateType;\n}\n\ninterface RTCIceCandidateInit {\n    candidate?: string;\n    sdpMLineIndex?: number | null;\n    sdpMid?: string | null;\n    usernameFragment?: string | null;\n}\n\ninterface RTCIceCandidatePair {\n    local?: RTCIceCandidate;\n    remote?: RTCIceCandidate;\n}\n\ninterface RTCIceCandidatePairStats extends RTCStats {\n    availableIncomingBitrate?: number;\n    availableOutgoingBitrate?: number;\n    bytesDiscardedOnSend?: number;\n    bytesReceived?: number;\n    bytesSent?: number;\n    circuitBreakerTriggerCount?: number;\n    consentExpiredTimestamp?: number;\n    consentRequestsSent?: number;\n    currentRoundTripTime?: number;\n    currentRtt?: number;\n    firstRequestTimestamp?: number;\n    lastPacketReceivedTimestamp?: number;\n    lastPacketSentTimestamp?: number;\n    lastRequestTimestamp?: number;\n    lastResponseTimestamp?: number;\n    localCandidateId?: string;\n    nominated?: boolean;\n    packetsDiscardedOnSend?: number;\n    packetsReceived?: number;\n    packetsSent?: number;\n    priority?: number;\n    remoteCandidateId?: string;\n    requestsReceived?: number;\n    requestsSent?: number;\n    responsesReceived?: number;\n    responsesSent?: number;\n    retransmissionsReceived?: number;\n    retransmissionsSent?: number;\n    state?: RTCStatsIceCandidatePairState;\n    totalRoundTripTime?: number;\n    totalRtt?: number;\n    transportId?: string;\n}\n\ninterface RTCIceGatherOptions {\n    gatherPolicy?: RTCIceGatherPolicy;\n    iceservers?: RTCIceServer[];\n}\n\ninterface RTCIceParameters {\n    password?: string;\n    usernameFragment?: string;\n}\n\ninterface RTCIceServer {\n    credential?: string;\n    credentialType?: RTCIceCredentialType;\n    urls: string | string[];\n    username?: string;\n}\n\ninterface RTCIdentityProviderOptions {\n    peerIdentity?: string;\n    protocol?: string;\n    usernameHint?: string;\n}\n\ninterface RTCInboundRTPStreamStats extends RTCRTPStreamStats {\n    bytesReceived?: number;\n    fractionLost?: number;\n    jitter?: number;\n    packetsLost?: number;\n    packetsReceived?: number;\n}\n\ninterface RTCLocalSessionDescriptionInit {\n    sdp?: string;\n    type?: RTCSdpType;\n}\n\ninterface RTCMediaStreamTrackStats extends RTCStats {\n    audioLevel?: number;\n    echoReturnLoss?: number;\n    echoReturnLossEnhancement?: number;\n    frameHeight?: number;\n    frameWidth?: number;\n    framesCorrupted?: number;\n    framesDecoded?: number;\n    framesDropped?: number;\n    framesPerSecond?: number;\n    framesReceived?: number;\n    framesSent?: number;\n    remoteSource?: boolean;\n    ssrcIds?: string[];\n    trackIdentifier?: string;\n}\n\ninterface RTCOfferAnswerOptions {\n}\n\ninterface RTCOfferOptions extends RTCOfferAnswerOptions {\n    iceRestart?: boolean;\n    offerToReceiveAudio?: boolean;\n    offerToReceiveVideo?: boolean;\n}\n\ninterface RTCOutboundRTPStreamStats extends RTCRTPStreamStats {\n    bytesSent?: number;\n    packetsSent?: number;\n    roundTripTime?: number;\n    targetBitrate?: number;\n}\n\ninterface RTCPeerConnectionIceErrorEventInit extends EventInit {\n    address?: string | null;\n    errorCode: number;\n    port?: number | null;\n    statusText?: string;\n    url?: string;\n}\n\ninterface RTCPeerConnectionIceEventInit extends EventInit {\n    candidate?: RTCIceCandidate | null;\n    url?: string | null;\n}\n\ninterface RTCRTPStreamStats extends RTCStats {\n    associateStatsId?: string;\n    codecId?: string;\n    firCount?: number;\n    isRemote?: boolean;\n    mediaTrackId?: string;\n    mediaType?: string;\n    nackCount?: number;\n    pliCount?: number;\n    sliCount?: number;\n    ssrc?: string;\n    transportId?: string;\n}\n\ninterface RTCRtcpFeedback {\n    parameter?: string;\n    type?: string;\n}\n\ninterface RTCRtcpParameters {\n    cname?: string;\n    reducedSize?: boolean;\n}\n\ninterface RTCRtpCapabilities {\n    codecs: RTCRtpCodecCapability[];\n    headerExtensions: RTCRtpHeaderExtensionCapability[];\n}\n\ninterface RTCRtpCodecCapability {\n    channels?: number;\n    clockRate: number;\n    mimeType: string;\n    sdpFmtpLine?: string;\n}\n\ninterface RTCRtpCodecParameters {\n    channels?: number;\n    clockRate: number;\n    mimeType: string;\n    payloadType: number;\n    sdpFmtpLine?: string;\n}\n\ninterface RTCRtpCodingParameters {\n    rid?: string;\n}\n\ninterface RTCRtpContributingSource {\n    audioLevel?: number;\n    rtpTimestamp: number;\n    source: number;\n    timestamp: number;\n}\n\ninterface RTCRtpEncodingParameters extends RTCRtpCodingParameters {\n    active?: boolean;\n    maxBitrate?: number;\n    scaleResolutionDownBy?: number;\n}\n\ninterface RTCRtpFecParameters {\n    mechanism?: string;\n    ssrc?: number;\n}\n\ninterface RTCRtpHeaderExtension {\n    kind?: string;\n    preferredEncrypt?: boolean;\n    preferredId?: number;\n    uri?: string;\n}\n\ninterface RTCRtpHeaderExtensionCapability {\n    uri?: string;\n}\n\ninterface RTCRtpHeaderExtensionParameters {\n    encrypted?: boolean;\n    id: number;\n    uri: string;\n}\n\ninterface RTCRtpParameters {\n    codecs: RTCRtpCodecParameters[];\n    headerExtensions: RTCRtpHeaderExtensionParameters[];\n    rtcp: RTCRtcpParameters;\n}\n\ninterface RTCRtpReceiveParameters extends RTCRtpParameters {\n}\n\ninterface RTCRtpRtxParameters {\n    ssrc?: number;\n}\n\ninterface RTCRtpSendParameters extends RTCRtpParameters {\n    encodings: RTCRtpEncodingParameters[];\n    transactionId: string;\n}\n\ninterface RTCRtpSynchronizationSource extends RTCRtpContributingSource {\n    voiceActivityFlag?: boolean;\n}\n\ninterface RTCRtpTransceiverInit {\n    direction?: RTCRtpTransceiverDirection;\n    sendEncodings?: RTCRtpEncodingParameters[];\n    streams?: MediaStream[];\n}\n\ninterface RTCRtpUnhandled {\n    muxId?: string;\n    payloadType?: number;\n    ssrc?: number;\n}\n\ninterface RTCSessionDescriptionInit {\n    sdp?: string;\n    type: RTCSdpType;\n}\n\ninterface RTCSrtpKeyParam {\n    keyMethod?: string;\n    keySalt?: string;\n    lifetime?: string;\n    mkiLength?: number;\n    mkiValue?: number;\n}\n\ninterface RTCSrtpSdesParameters {\n    cryptoSuite?: string;\n    keyParams?: RTCSrtpKeyParam[];\n    sessionParams?: string[];\n    tag?: number;\n}\n\ninterface RTCSsrcRange {\n    max?: number;\n    min?: number;\n}\n\ninterface RTCStats {\n    id?: string;\n    timestamp?: number;\n    type?: RTCStatsType;\n}\n\ninterface RTCStatsReport {\n}\n\ninterface RTCTrackEventInit extends EventInit {\n    receiver: RTCRtpReceiver;\n    streams?: MediaStream[];\n    track: MediaStreamTrack;\n    transceiver: RTCRtpTransceiver;\n}\n\ninterface RTCTransportStats extends RTCStats {\n    bytesReceived?: number;\n    bytesSent?: number;\n    dtlsCipher?: string;\n    dtlsState?: RTCDtlsTransportState;\n    iceRole?: RTCIceRole;\n    localCertificateId?: string;\n    packetsReceived?: number;\n    packetsSent?: number;\n    remoteCertificateId?: string;\n    rtcpTransportStatsId?: string;\n    selectedCandidatePairChanges?: number;\n    selectedCandidatePairId?: string;\n    srtpCipher?: string;\n    tlsGroup?: string;\n    tlsVersion?: string;\n}\n\ninterface ReadableStreamDefaultReadDoneResult {\n    done: true;\n    value?: undefined;\n}\n\ninterface ReadableStreamDefaultReadValueResult<T> {\n    done: false;\n    value: T;\n}\n\ninterface ReadableWritablePair<R = any, W = any> {\n    readable: ReadableStream<R>;\n    /**\n     * Provides a convenient, chainable way of piping this readable stream through a transform stream (or any other { writable, readable } pair). It simply pipes the stream into the writable side of the supplied pair, and returns the readable side for further use.\n     *\n     * Piping a stream will lock it for the duration of the pipe, preventing any other consumer from acquiring a reader.\n     */\n    writable: WritableStream<W>;\n}\n\ninterface RegistrationOptions {\n    scope?: string;\n    type?: WorkerType;\n    updateViaCache?: ServiceWorkerUpdateViaCache;\n}\n\ninterface RequestInit {\n    /**\n     * A BodyInit object or null to set request\'s body.\n     */\n    body?: BodyInit | null;\n    /**\n     * A string indicating how the request will interact with the browser\'s cache to set request\'s cache.\n     */\n    cache?: RequestCache;\n    /**\n     * A string indicating whether credentials will be sent with the request always, never, or only when sent to a same-origin URL. Sets request\'s credentials.\n     */\n    credentials?: RequestCredentials;\n    /**\n     * A Headers object, an object literal, or an array of two-item arrays to set request\'s headers.\n     */\n    headers?: HeadersInit;\n    /**\n     * A cryptographic hash of the resource to be fetched by request. Sets request\'s integrity.\n     */\n    integrity?: string;\n    /**\n     * A boolean to set request\'s keepalive.\n     */\n    keepalive?: boolean;\n    /**\n     * A string to set request\'s method.\n     */\n    method?: string;\n    /**\n     * A string to indicate whether the request will use CORS, or will be restricted to same-origin URLs. Sets request\'s mode.\n     */\n    mode?: RequestMode;\n    /**\n     * A string indicating whether request follows redirects, results in an error upon encountering a redirect, or returns the redirect (in an opaque fashion). Sets request\'s redirect.\n     */\n    redirect?: RequestRedirect;\n    /**\n     * A string whose value is a same-origin URL, "about:client", or the empty string, to set request\'s referrer.\n     */\n    referrer?: string;\n    /**\n     * A referrer policy to set request\'s referrerPolicy.\n     */\n    referrerPolicy?: ReferrerPolicy;\n    /**\n     * An AbortSignal to set request\'s signal.\n     */\n    signal?: AbortSignal | null;\n    /**\n     * Can only be null. Used to disassociate request from any Window.\n     */\n    window?: any;\n}\n\ninterface ResizeObserverOptions {\n    box?: ResizeObserverBoxOptions;\n}\n\ninterface ResponseInit {\n    headers?: HeadersInit;\n    status?: number;\n    statusText?: string;\n}\n\ninterface RsaHashedImportParams extends Algorithm {\n    hash: HashAlgorithmIdentifier;\n}\n\ninterface RsaHashedKeyAlgorithm extends RsaKeyAlgorithm {\n    hash: KeyAlgorithm;\n}\n\ninterface RsaHashedKeyGenParams extends RsaKeyGenParams {\n    hash: HashAlgorithmIdentifier;\n}\n\ninterface RsaKeyAlgorithm extends KeyAlgorithm {\n    modulusLength: number;\n    publicExponent: BigInteger;\n}\n\ninterface RsaKeyGenParams extends Algorithm {\n    modulusLength: number;\n    publicExponent: BigInteger;\n}\n\ninterface RsaOaepParams extends Algorithm {\n    label?: Int8Array | Int16Array | Int32Array | Uint8Array | Uint16Array | Uint32Array | Uint8ClampedArray | Float32Array | Float64Array | DataView | ArrayBuffer;\n}\n\ninterface RsaOtherPrimesInfo {\n    d?: string;\n    r?: string;\n    t?: string;\n}\n\ninterface RsaPssParams extends Algorithm {\n    saltLength: number;\n}\n\ninterface SVGBoundingBoxOptions {\n    clipped?: boolean;\n    fill?: boolean;\n    markers?: boolean;\n    stroke?: boolean;\n}\n\ninterface ScrollIntoViewOptions extends ScrollOptions {\n    block?: ScrollLogicalPosition;\n    inline?: ScrollLogicalPosition;\n}\n\ninterface ScrollOptions {\n    behavior?: ScrollBehavior;\n}\n\ninterface ScrollToOptions extends ScrollOptions {\n    left?: number;\n    top?: number;\n}\n\ninterface SecurityPolicyViolationEventInit extends EventInit {\n    blockedURI?: string;\n    columnNumber?: number;\n    documentURI?: string;\n    effectiveDirective?: string;\n    lineNumber?: number;\n    originalPolicy?: string;\n    referrer?: string;\n    sourceFile?: string;\n    statusCode?: number;\n    violatedDirective?: string;\n}\n\ninterface ShadowRootInit {\n    delegatesFocus?: boolean;\n    mode: ShadowRootMode;\n}\n\ninterface ShareData {\n    text?: string;\n    title?: string;\n    url?: string;\n}\n\ninterface SpeechRecognitionErrorEventInit extends EventInit {\n    error: SpeechRecognitionErrorCode;\n    message?: string;\n}\n\ninterface SpeechRecognitionEventInit extends EventInit {\n    resultIndex?: number;\n    results: SpeechRecognitionResultList;\n}\n\ninterface SpeechSynthesisErrorEventInit extends SpeechSynthesisEventInit {\n    error: SpeechSynthesisErrorCode;\n}\n\ninterface SpeechSynthesisEventInit extends EventInit {\n    charIndex?: number;\n    charLength?: number;\n    elapsedTime?: number;\n    name?: string;\n    utterance: SpeechSynthesisUtterance;\n}\n\ninterface StaticRangeInit {\n    endContainer: Node;\n    endOffset: number;\n    startContainer: Node;\n    startOffset: number;\n}\n\ninterface StereoPannerOptions extends AudioNodeOptions {\n    pan?: number;\n}\n\ninterface StorageEstimate {\n    quota?: number;\n    usage?: number;\n}\n\ninterface StorageEventInit extends EventInit {\n    key?: string | null;\n    newValue?: string | null;\n    oldValue?: string | null;\n    storageArea?: Storage | null;\n    url?: string;\n}\n\ninterface StoreExceptionsInformation extends ExceptionInformation {\n    detailURI?: string | null;\n    explanationString?: string | null;\n    siteName?: string | null;\n}\n\ninterface StoreSiteSpecificExceptionsInformation extends StoreExceptionsInformation {\n    arrayOfDomainStrings?: string[];\n}\n\ninterface StreamPipeOptions {\n    preventAbort?: boolean;\n    preventCancel?: boolean;\n    /**\n     * Pipes this readable stream to a given writable stream destination. The way in which the piping process behaves under various error conditions can be customized with a number of passed options. It returns a promise that fulfills when the piping process completes successfully, or rejects if any errors were encountered.\n     *\n     * Piping a stream will lock it for the duration of the pipe, preventing any other consumer from acquiring a reader.\n     *\n     * Errors and closures of the source and destination streams propagate as follows:\n     *\n     * An error in this source readable stream will abort destination, unless preventAbort is truthy. The returned promise will be rejected with the source\'s error, or with any error that occurs during aborting the destination.\n     *\n     * An error in destination will cancel this source readable stream, unless preventCancel is truthy. The returned promise will be rejected with the destination\'s error, or with any error that occurs during canceling the source.\n     *\n     * When this source readable stream closes, destination will be closed, unless preventClose is truthy. The returned promise will be fulfilled once this process completes, unless an error is encountered while closing the destination, in which case it will be rejected with that error.\n     *\n     * If destination starts out closed or closing, this source readable stream will be canceled, unless preventCancel is true. The returned promise will be rejected with an error indicating piping to a closed stream failed, or with any error that occurs during canceling the source.\n     *\n     * The signal option can be set to an AbortSignal to allow aborting an ongoing pipe operation via the corresponding AbortController. In this case, this source readable stream will be canceled, and destination aborted, unless the respective options preventCancel or preventAbort are set.\n     */\n    preventClose?: boolean;\n    signal?: AbortSignal;\n}\n\ninterface TextDecodeOptions {\n    stream?: boolean;\n}\n\ninterface TextDecoderOptions {\n    fatal?: boolean;\n    ignoreBOM?: boolean;\n}\n\ninterface TextEncoderEncodeIntoResult {\n    read?: number;\n    written?: number;\n}\n\ninterface TouchEventInit extends EventModifierInit {\n    changedTouches?: Touch[];\n    targetTouches?: Touch[];\n    touches?: Touch[];\n}\n\ninterface TouchInit {\n    altitudeAngle?: number;\n    azimuthAngle?: number;\n    clientX?: number;\n    clientY?: number;\n    force?: number;\n    identifier: number;\n    pageX?: number;\n    pageY?: number;\n    radiusX?: number;\n    radiusY?: number;\n    rotationAngle?: number;\n    screenX?: number;\n    screenY?: number;\n    target: EventTarget;\n    touchType?: TouchType;\n}\n\ninterface TrackEventInit extends EventInit {\n    track?: TextTrack | null;\n}\n\ninterface Transformer<I = any, O = any> {\n    flush?: TransformerFlushCallback<O>;\n    readableType?: undefined;\n    start?: TransformerStartCallback<O>;\n    transform?: TransformerTransformCallback<I, O>;\n    writableType?: undefined;\n}\n\ninterface TransitionEventInit extends EventInit {\n    elapsedTime?: number;\n    propertyName?: string;\n    pseudoElement?: string;\n}\n\ninterface UIEventInit extends EventInit {\n    detail?: number;\n    view?: Window | null;\n}\n\ninterface ULongRange {\n    max?: number;\n    min?: number;\n}\n\ninterface UnderlyingSink<W = any> {\n    abort?: UnderlyingSinkAbortCallback;\n    close?: UnderlyingSinkCloseCallback;\n    start?: UnderlyingSinkStartCallback;\n    type?: undefined;\n    write?: UnderlyingSinkWriteCallback<W>;\n}\n\ninterface UnderlyingSource<R = any> {\n    cancel?: UnderlyingSourceCancelCallback;\n    pull?: UnderlyingSourcePullCallback<R>;\n    start?: UnderlyingSourceStartCallback<R>;\n    type?: undefined;\n}\n\ninterface VRDisplayEventInit extends EventInit {\n    display: VRDisplay;\n    reason?: VRDisplayEventReason;\n}\n\ninterface VRLayer {\n    leftBounds?: number[] | Float32Array | null;\n    rightBounds?: number[] | Float32Array | null;\n    source?: HTMLCanvasElement | null;\n}\n\ninterface VRStageParameters {\n    sittingToStandingTransform?: Float32Array;\n    sizeX?: number;\n    sizeY?: number;\n}\n\ninterface WaveShaperOptions extends AudioNodeOptions {\n    curve?: number[] | Float32Array;\n    oversample?: OverSampleType;\n}\n\ninterface WebGLContextAttributes {\n    alpha?: boolean;\n    antialias?: boolean;\n    depth?: boolean;\n    desynchronized?: boolean;\n    failIfMajorPerformanceCaveat?: boolean;\n    powerPreference?: WebGLPowerPreference;\n    premultipliedAlpha?: boolean;\n    preserveDrawingBuffer?: boolean;\n    stencil?: boolean;\n}\n\ninterface WebGLContextEventInit extends EventInit {\n    statusMessage?: string;\n}\n\ninterface WheelEventInit extends MouseEventInit {\n    deltaMode?: number;\n    deltaX?: number;\n    deltaY?: number;\n    deltaZ?: number;\n}\n\ninterface WorkerOptions {\n    credentials?: RequestCredentials;\n    name?: string;\n    type?: WorkerType;\n}\n\ninterface WorkletOptions {\n    credentials?: RequestCredentials;\n}\n\ninterface EventListener {\n    (evt: Event): void;\n}\n\ntype XPathNSResolver = ((prefix: string | null) => string | null) | { lookupNamespaceURI(prefix: string | null): string | null; };\n\n/** The ANGLE_instanced_arrays extension is part of the WebGL API and allows to draw the same object, or groups of similar objects multiple times, if they share the same vertex data, primitive count and type. */\ninterface ANGLE_instanced_arrays {\n    drawArraysInstancedANGLE(mode: GLenum, first: GLint, count: GLsizei, primcount: GLsizei): void;\n    drawElementsInstancedANGLE(mode: GLenum, count: GLsizei, type: GLenum, offset: GLintptr, primcount: GLsizei): void;\n    vertexAttribDivisorANGLE(index: GLuint, divisor: GLuint): void;\n    readonly VERTEX_ATTRIB_ARRAY_DIVISOR_ANGLE: GLenum;\n}\n\n/** A controller object that allows you to abort one or more DOM requests as and when desired. */\ninterface AbortController {\n    /**\n     * Returns the AbortSignal object associated with this object.\n     */\n    readonly signal: AbortSignal;\n    /**\n     * Invoking this method will set this object\'s AbortSignal\'s aborted flag and signal to any observers that the associated activity is to be aborted.\n     */\n    abort(): void;\n}\n\ndeclare var AbortController: {\n    prototype: AbortController;\n    new(): AbortController;\n};\n\ninterface AbortSignalEventMap {\n    "abort": Event;\n}\n\n/** A signal object that allows you to communicate with a DOM request (such as a Fetch) and abort it if required via an AbortController object. */\ninterface AbortSignal extends EventTarget {\n    /**\n     * Returns true if this AbortSignal\'s AbortController has signaled to abort, and false otherwise.\n     */\n    readonly aborted: boolean;\n    onabort: ((this: AbortSignal, ev: Event) => any) | null;\n    addEventListener<K extends keyof AbortSignalEventMap>(type: K, listener: (this: AbortSignal, ev: AbortSignalEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof AbortSignalEventMap>(type: K, listener: (this: AbortSignal, ev: AbortSignalEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var AbortSignal: {\n    prototype: AbortSignal;\n    new(): AbortSignal;\n};\n\ninterface AbstractRange {\n    /**\n     * Returns true if range is collapsed, and false otherwise.\n     */\n    readonly collapsed: boolean;\n    /**\n     * Returns range\'s end node.\n     */\n    readonly endContainer: Node;\n    /**\n     * Returns range\'s end offset.\n     */\n    readonly endOffset: number;\n    /**\n     * Returns range\'s start node.\n     */\n    readonly startContainer: Node;\n    /**\n     * Returns range\'s start offset.\n     */\n    readonly startOffset: number;\n}\n\ndeclare var AbstractRange: {\n    prototype: AbstractRange;\n    new(): AbstractRange;\n};\n\ninterface AbstractWorkerEventMap {\n    "error": ErrorEvent;\n}\n\ninterface AbstractWorker {\n    onerror: ((this: AbstractWorker, ev: ErrorEvent) => any) | null;\n    addEventListener<K extends keyof AbstractWorkerEventMap>(type: K, listener: (this: AbstractWorker, ev: AbstractWorkerEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof AbstractWorkerEventMap>(type: K, listener: (this: AbstractWorker, ev: AbstractWorkerEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ninterface AesCfbParams extends Algorithm {\n    iv: Int8Array | Int16Array | Int32Array | Uint8Array | Uint16Array | Uint32Array | Uint8ClampedArray | Float32Array | Float64Array | DataView | ArrayBuffer;\n}\n\ninterface AesCmacParams extends Algorithm {\n    length: number;\n}\n\n/** A node able to provide real-time frequency and time-domain analysis information. It is an AudioNode that passes the audio stream unchanged from the input to the output, but allows you to take the generated data, process it, and create audio visualizations. */\ninterface AnalyserNode extends AudioNode {\n    fftSize: number;\n    readonly frequencyBinCount: number;\n    maxDecibels: number;\n    minDecibels: number;\n    smoothingTimeConstant: number;\n    getByteFrequencyData(array: Uint8Array): void;\n    getByteTimeDomainData(array: Uint8Array): void;\n    getFloatFrequencyData(array: Float32Array): void;\n    getFloatTimeDomainData(array: Float32Array): void;\n}\n\ndeclare var AnalyserNode: {\n    prototype: AnalyserNode;\n    new(context: BaseAudioContext, options?: AnalyserOptions): AnalyserNode;\n};\n\ninterface Animatable {\n    animate(keyframes: Keyframe[] | PropertyIndexedKeyframes | null, options?: number | KeyframeAnimationOptions): Animation;\n    getAnimations(): Animation[];\n}\n\ninterface AnimationEventMap {\n    "cancel": AnimationPlaybackEvent;\n    "finish": AnimationPlaybackEvent;\n}\n\ninterface Animation extends EventTarget {\n    currentTime: number | null;\n    effect: AnimationEffect | null;\n    readonly finished: Promise<Animation>;\n    id: string;\n    oncancel: ((this: Animation, ev: AnimationPlaybackEvent) => any) | null;\n    onfinish: ((this: Animation, ev: AnimationPlaybackEvent) => any) | null;\n    readonly pending: boolean;\n    readonly playState: AnimationPlayState;\n    playbackRate: number;\n    readonly ready: Promise<Animation>;\n    startTime: number | null;\n    timeline: AnimationTimeline | null;\n    cancel(): void;\n    finish(): void;\n    pause(): void;\n    play(): void;\n    reverse(): void;\n    updatePlaybackRate(playbackRate: number): void;\n    addEventListener<K extends keyof AnimationEventMap>(type: K, listener: (this: Animation, ev: AnimationEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof AnimationEventMap>(type: K, listener: (this: Animation, ev: AnimationEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var Animation: {\n    prototype: Animation;\n    new(effect?: AnimationEffect | null, timeline?: AnimationTimeline | null): Animation;\n};\n\ninterface AnimationEffect {\n    getComputedTiming(): ComputedEffectTiming;\n    getTiming(): EffectTiming;\n    updateTiming(timing?: OptionalEffectTiming): void;\n}\n\ndeclare var AnimationEffect: {\n    prototype: AnimationEffect;\n    new(): AnimationEffect;\n};\n\n/** Events providing information related to animations. */\ninterface AnimationEvent extends Event {\n    readonly animationName: string;\n    readonly elapsedTime: number;\n    readonly pseudoElement: string;\n}\n\ndeclare var AnimationEvent: {\n    prototype: AnimationEvent;\n    new(type: string, animationEventInitDict?: AnimationEventInit): AnimationEvent;\n};\n\ninterface AnimationFrameProvider {\n    cancelAnimationFrame(handle: number): void;\n    requestAnimationFrame(callback: FrameRequestCallback): number;\n}\n\ninterface AnimationPlaybackEvent extends Event {\n    readonly currentTime: number | null;\n    readonly timelineTime: number | null;\n}\n\ndeclare var AnimationPlaybackEvent: {\n    prototype: AnimationPlaybackEvent;\n    new(type: string, eventInitDict?: AnimationPlaybackEventInit): AnimationPlaybackEvent;\n};\n\ninterface AnimationTimeline {\n    readonly currentTime: number | null;\n}\n\ndeclare var AnimationTimeline: {\n    prototype: AnimationTimeline;\n    new(): AnimationTimeline;\n};\n\ninterface ApplicationCacheEventMap {\n    "cached": Event;\n    "checking": Event;\n    "downloading": Event;\n    "error": Event;\n    "noupdate": Event;\n    "obsolete": Event;\n    "progress": ProgressEvent<ApplicationCache>;\n    "updateready": Event;\n}\n\ninterface ApplicationCache extends EventTarget {\n    /** @deprecated */\n    oncached: ((this: ApplicationCache, ev: Event) => any) | null;\n    /** @deprecated */\n    onchecking: ((this: ApplicationCache, ev: Event) => any) | null;\n    /** @deprecated */\n    ondownloading: ((this: ApplicationCache, ev: Event) => any) | null;\n    /** @deprecated */\n    onerror: ((this: ApplicationCache, ev: Event) => any) | null;\n    /** @deprecated */\n    onnoupdate: ((this: ApplicationCache, ev: Event) => any) | null;\n    /** @deprecated */\n    onobsolete: ((this: ApplicationCache, ev: Event) => any) | null;\n    /** @deprecated */\n    onprogress: ((this: ApplicationCache, ev: ProgressEvent<ApplicationCache>) => any) | null;\n    /** @deprecated */\n    onupdateready: ((this: ApplicationCache, ev: Event) => any) | null;\n    /** @deprecated */\n    readonly status: number;\n    /** @deprecated */\n    abort(): void;\n    /** @deprecated */\n    swapCache(): void;\n    /** @deprecated */\n    update(): void;\n    readonly CHECKING: number;\n    readonly DOWNLOADING: number;\n    readonly IDLE: number;\n    readonly OBSOLETE: number;\n    readonly UNCACHED: number;\n    readonly UPDATEREADY: number;\n    addEventListener<K extends keyof ApplicationCacheEventMap>(type: K, listener: (this: ApplicationCache, ev: ApplicationCacheEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof ApplicationCacheEventMap>(type: K, listener: (this: ApplicationCache, ev: ApplicationCacheEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var ApplicationCache: {\n    prototype: ApplicationCache;\n    new(): ApplicationCache;\n    readonly CHECKING: number;\n    readonly DOWNLOADING: number;\n    readonly IDLE: number;\n    readonly OBSOLETE: number;\n    readonly UNCACHED: number;\n    readonly UPDATEREADY: number;\n};\n\n/** A DOM element\'s attribute as an object. In most DOM methods, you will probably directly retrieve the attribute as a string (e.g., Element.getAttribute(), but certain functions (e.g., Element.getAttributeNode()) or means of iterating give Attr types. */\ninterface Attr extends Node {\n    readonly localName: string;\n    readonly name: string;\n    readonly namespaceURI: string | null;\n    readonly ownerDocument: Document;\n    readonly ownerElement: Element | null;\n    readonly prefix: string | null;\n    readonly specified: boolean;\n    value: string;\n}\n\ndeclare var Attr: {\n    prototype: Attr;\n    new(): Attr;\n};\n\n/** A short audio asset residing in memory, created from an audio file using the AudioContext.decodeAudioData() method, or from raw data using AudioContext.createBuffer(). Once put into an AudioBuffer, the audio can then be played by being passed into an AudioBufferSourceNode. */\ninterface AudioBuffer {\n    readonly duration: number;\n    readonly length: number;\n    readonly numberOfChannels: number;\n    readonly sampleRate: number;\n    copyFromChannel(destination: Float32Array, channelNumber: number, bufferOffset?: number): void;\n    copyToChannel(source: Float32Array, channelNumber: number, bufferOffset?: number): void;\n    getChannelData(channel: number): Float32Array;\n}\n\ndeclare var AudioBuffer: {\n    prototype: AudioBuffer;\n    new(options: AudioBufferOptions): AudioBuffer;\n};\n\n/** An AudioScheduledSourceNode which represents an audio source consisting of in-memory audio data, stored in an AudioBuffer. It\'s especially useful for playing back audio which has particularly stringent timing accuracy requirements, such as for sounds that must match a specific rhythm and can be kept in memory rather than being played from disk or the network. */\ninterface AudioBufferSourceNode extends AudioScheduledSourceNode {\n    buffer: AudioBuffer | null;\n    readonly detune: AudioParam;\n    loop: boolean;\n    loopEnd: number;\n    loopStart: number;\n    readonly playbackRate: AudioParam;\n    start(when?: number, offset?: number, duration?: number): void;\n    addEventListener<K extends keyof AudioScheduledSourceNodeEventMap>(type: K, listener: (this: AudioBufferSourceNode, ev: AudioScheduledSourceNodeEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof AudioScheduledSourceNodeEventMap>(type: K, listener: (this: AudioBufferSourceNode, ev: AudioScheduledSourceNodeEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var AudioBufferSourceNode: {\n    prototype: AudioBufferSourceNode;\n    new(context: BaseAudioContext, options?: AudioBufferSourceOptions): AudioBufferSourceNode;\n};\n\n/** An audio-processing graph built from audio modules linked together, each represented by an AudioNode. */\ninterface AudioContext extends BaseAudioContext {\n    readonly baseLatency: number;\n    readonly outputLatency: number;\n    close(): Promise<void>;\n    createMediaElementSource(mediaElement: HTMLMediaElement): MediaElementAudioSourceNode;\n    createMediaStreamDestination(): MediaStreamAudioDestinationNode;\n    createMediaStreamSource(mediaStream: MediaStream): MediaStreamAudioSourceNode;\n    createMediaStreamTrackSource(mediaStreamTrack: MediaStreamTrack): MediaStreamTrackAudioSourceNode;\n    getOutputTimestamp(): AudioTimestamp;\n    resume(): Promise<void>;\n    suspend(): Promise<void>;\n    addEventListener<K extends keyof BaseAudioContextEventMap>(type: K, listener: (this: AudioContext, ev: BaseAudioContextEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof BaseAudioContextEventMap>(type: K, listener: (this: AudioContext, ev: BaseAudioContextEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var AudioContext: {\n    prototype: AudioContext;\n    new(contextOptions?: AudioContextOptions): AudioContext;\n};\n\n/** AudioDestinationNode has no output (as it is the output, no more AudioNode can be linked after it in the audio graph) and one input. The number of channels in the input must be between 0 and the maxChannelCount value or an exception is raised. */\ninterface AudioDestinationNode extends AudioNode {\n    readonly maxChannelCount: number;\n}\n\ndeclare var AudioDestinationNode: {\n    prototype: AudioDestinationNode;\n    new(): AudioDestinationNode;\n};\n\n/** The position and orientation of the unique person listening to the audio scene, and is used in audio spatialization. All PannerNodes spatialize in relation to the AudioListener stored in the BaseAudioContext.listener attribute. */\ninterface AudioListener {\n    readonly forwardX: AudioParam;\n    readonly forwardY: AudioParam;\n    readonly forwardZ: AudioParam;\n    readonly positionX: AudioParam;\n    readonly positionY: AudioParam;\n    readonly positionZ: AudioParam;\n    readonly upX: AudioParam;\n    readonly upY: AudioParam;\n    readonly upZ: AudioParam;\n    /** @deprecated */\n    setOrientation(x: number, y: number, z: number, xUp: number, yUp: number, zUp: number): void;\n    /** @deprecated */\n    setPosition(x: number, y: number, z: number): void;\n}\n\ndeclare var AudioListener: {\n    prototype: AudioListener;\n    new(): AudioListener;\n};\n\n/** A generic interface for representing an audio processing module. Examples include: */\ninterface AudioNode extends EventTarget {\n    channelCount: number;\n    channelCountMode: ChannelCountMode;\n    channelInterpretation: ChannelInterpretation;\n    readonly context: BaseAudioContext;\n    readonly numberOfInputs: number;\n    readonly numberOfOutputs: number;\n    connect(destinationNode: AudioNode, output?: number, input?: number): AudioNode;\n    connect(destinationParam: AudioParam, output?: number): void;\n    disconnect(): void;\n    disconnect(output: number): void;\n    disconnect(destinationNode: AudioNode): void;\n    disconnect(destinationNode: AudioNode, output: number): void;\n    disconnect(destinationNode: AudioNode, output: number, input: number): void;\n    disconnect(destinationParam: AudioParam): void;\n    disconnect(destinationParam: AudioParam, output: number): void;\n}\n\ndeclare var AudioNode: {\n    prototype: AudioNode;\n    new(): AudioNode;\n};\n\n/** The Web Audio API\'s AudioParam interface represents an audio-related parameter, usually a parameter of an AudioNode (such as GainNode.gain). */\ninterface AudioParam {\n    automationRate: AutomationRate;\n    readonly defaultValue: number;\n    readonly maxValue: number;\n    readonly minValue: number;\n    value: number;\n    cancelAndHoldAtTime(cancelTime: number): AudioParam;\n    cancelScheduledValues(cancelTime: number): AudioParam;\n    exponentialRampToValueAtTime(value: number, endTime: number): AudioParam;\n    linearRampToValueAtTime(value: number, endTime: number): AudioParam;\n    setTargetAtTime(target: number, startTime: number, timeConstant: number): AudioParam;\n    setValueAtTime(value: number, startTime: number): AudioParam;\n    setValueCurveAtTime(values: number[] | Float32Array, startTime: number, duration: number): AudioParam;\n}\n\ndeclare var AudioParam: {\n    prototype: AudioParam;\n    new(): AudioParam;\n};\n\ninterface AudioParamMap {\n    forEach(callbackfn: (value: AudioParam, key: string, parent: AudioParamMap) => void, thisArg?: any): void;\n}\n\ndeclare var AudioParamMap: {\n    prototype: AudioParamMap;\n    new(): AudioParamMap;\n};\n\n/** The Web Audio API events that occur when a ScriptProcessorNode input buffer is ready to be processed.\n * @deprecated As of the August 29 2014 Web Audio API spec publication, this feature has been marked as deprecated, and is soon to be replaced by AudioWorklet.\n */\ninterface AudioProcessingEvent extends Event {\n    readonly inputBuffer: AudioBuffer;\n    readonly outputBuffer: AudioBuffer;\n    readonly playbackTime: number;\n}\n\ndeclare var AudioProcessingEvent: {\n    prototype: AudioProcessingEvent;\n    new(type: string, eventInitDict: AudioProcessingEventInit): AudioProcessingEvent;\n};\n\ninterface AudioScheduledSourceNodeEventMap {\n    "ended": Event;\n}\n\ninterface AudioScheduledSourceNode extends AudioNode {\n    onended: ((this: AudioScheduledSourceNode, ev: Event) => any) | null;\n    start(when?: number): void;\n    stop(when?: number): void;\n    addEventListener<K extends keyof AudioScheduledSourceNodeEventMap>(type: K, listener: (this: AudioScheduledSourceNode, ev: AudioScheduledSourceNodeEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof AudioScheduledSourceNodeEventMap>(type: K, listener: (this: AudioScheduledSourceNode, ev: AudioScheduledSourceNodeEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var AudioScheduledSourceNode: {\n    prototype: AudioScheduledSourceNode;\n    new(): AudioScheduledSourceNode;\n};\n\ninterface AudioWorklet extends Worklet {\n}\n\ndeclare var AudioWorklet: {\n    prototype: AudioWorklet;\n    new(): AudioWorklet;\n};\n\ninterface AudioWorkletNodeEventMap {\n    "processorerror": Event;\n}\n\ninterface AudioWorkletNode extends AudioNode {\n    onprocessorerror: ((this: AudioWorkletNode, ev: Event) => any) | null;\n    readonly parameters: AudioParamMap;\n    readonly port: MessagePort;\n    addEventListener<K extends keyof AudioWorkletNodeEventMap>(type: K, listener: (this: AudioWorkletNode, ev: AudioWorkletNodeEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof AudioWorkletNodeEventMap>(type: K, listener: (this: AudioWorkletNode, ev: AudioWorkletNodeEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var AudioWorkletNode: {\n    prototype: AudioWorkletNode;\n    new(context: BaseAudioContext, name: string, options?: AudioWorkletNodeOptions): AudioWorkletNode;\n};\n\ninterface AuthenticatorAssertionResponse extends AuthenticatorResponse {\n    readonly authenticatorData: ArrayBuffer;\n    readonly signature: ArrayBuffer;\n    readonly userHandle: ArrayBuffer | null;\n}\n\ndeclare var AuthenticatorAssertionResponse: {\n    prototype: AuthenticatorAssertionResponse;\n    new(): AuthenticatorAssertionResponse;\n};\n\ninterface AuthenticatorAttestationResponse extends AuthenticatorResponse {\n    readonly attestationObject: ArrayBuffer;\n}\n\ndeclare var AuthenticatorAttestationResponse: {\n    prototype: AuthenticatorAttestationResponse;\n    new(): AuthenticatorAttestationResponse;\n};\n\ninterface AuthenticatorResponse {\n    readonly clientDataJSON: ArrayBuffer;\n}\n\ndeclare var AuthenticatorResponse: {\n    prototype: AuthenticatorResponse;\n    new(): AuthenticatorResponse;\n};\n\ninterface BarProp {\n    readonly visible: boolean;\n}\n\ndeclare var BarProp: {\n    prototype: BarProp;\n    new(): BarProp;\n};\n\ninterface BaseAudioContextEventMap {\n    "statechange": Event;\n}\n\ninterface BaseAudioContext extends EventTarget {\n    readonly audioWorklet: AudioWorklet;\n    readonly currentTime: number;\n    readonly destination: AudioDestinationNode;\n    readonly listener: AudioListener;\n    onstatechange: ((this: BaseAudioContext, ev: Event) => any) | null;\n    readonly sampleRate: number;\n    readonly state: AudioContextState;\n    createAnalyser(): AnalyserNode;\n    createBiquadFilter(): BiquadFilterNode;\n    createBuffer(numberOfChannels: number, length: number, sampleRate: number): AudioBuffer;\n    createBufferSource(): AudioBufferSourceNode;\n    createChannelMerger(numberOfInputs?: number): ChannelMergerNode;\n    createChannelSplitter(numberOfOutputs?: number): ChannelSplitterNode;\n    createConstantSource(): ConstantSourceNode;\n    createConvolver(): ConvolverNode;\n    createDelay(maxDelayTime?: number): DelayNode;\n    createDynamicsCompressor(): DynamicsCompressorNode;\n    createGain(): GainNode;\n    createIIRFilter(feedforward: number[], feedback: number[]): IIRFilterNode;\n    createOscillator(): OscillatorNode;\n    createPanner(): PannerNode;\n    createPeriodicWave(real: number[] | Float32Array, imag: number[] | Float32Array, constraints?: PeriodicWaveConstraints): PeriodicWave;\n    createScriptProcessor(bufferSize?: number, numberOfInputChannels?: number, numberOfOutputChannels?: number): ScriptProcessorNode;\n    createStereoPanner(): StereoPannerNode;\n    createWaveShaper(): WaveShaperNode;\n    decodeAudioData(audioData: ArrayBuffer, successCallback?: DecodeSuccessCallback | null, errorCallback?: DecodeErrorCallback | null): Promise<AudioBuffer>;\n    addEventListener<K extends keyof BaseAudioContextEventMap>(type: K, listener: (this: BaseAudioContext, ev: BaseAudioContextEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof BaseAudioContextEventMap>(type: K, listener: (this: BaseAudioContext, ev: BaseAudioContextEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var BaseAudioContext: {\n    prototype: BaseAudioContext;\n    new(): BaseAudioContext;\n};\n\n/** The beforeunload event is fired when the window, the document and its resources are about to be unloaded. */\ninterface BeforeUnloadEvent extends Event {\n    returnValue: any;\n}\n\ndeclare var BeforeUnloadEvent: {\n    prototype: BeforeUnloadEvent;\n    new(): BeforeUnloadEvent;\n};\n\ninterface BhxBrowser {\n    readonly lastError: DOMException;\n    checkMatchesGlobExpression(pattern: string, value: string): boolean;\n    checkMatchesUriExpression(pattern: string, value: string): boolean;\n    clearLastError(): void;\n    currentWindowId(): number;\n    fireExtensionApiTelemetry(functionName: string, isSucceeded: boolean, isSupported: boolean, errorString: string): void;\n    genericFunction(functionId: number, destination: any, parameters?: string, callbackId?: number): void;\n    genericSynchronousFunction(functionId: number, parameters?: string): string;\n    getExtensionId(): string;\n    getThisAddress(): any;\n    registerGenericFunctionCallbackHandler(callbackHandler: Function): void;\n    registerGenericListenerHandler(eventHandler: Function): void;\n    setLastError(parameters: string): void;\n    webPlatformGenericFunction(destination: any, parameters?: string, callbackId?: number): void;\n}\n\ndeclare var BhxBrowser: {\n    prototype: BhxBrowser;\n    new(): BhxBrowser;\n};\n\n/** A simple low-order filter, and is created using the AudioContext.createBiquadFilter() method. It is an AudioNode that can represent different kinds of filters, tone control devices, and graphic equalizers. */\ninterface BiquadFilterNode extends AudioNode {\n    readonly Q: AudioParam;\n    readonly detune: AudioParam;\n    readonly frequency: AudioParam;\n    readonly gain: AudioParam;\n    type: BiquadFilterType;\n    getFrequencyResponse(frequencyHz: Float32Array, magResponse: Float32Array, phaseResponse: Float32Array): void;\n}\n\ndeclare var BiquadFilterNode: {\n    prototype: BiquadFilterNode;\n    new(context: BaseAudioContext, options?: BiquadFilterOptions): BiquadFilterNode;\n};\n\n/** A file-like object of immutable, raw data. Blobs represent data that isn\'t necessarily in a JavaScript-native format. The File interface is based on Blob, inheriting blob functionality and expanding it to support files on the user\'s system. */\ninterface Blob {\n    readonly size: number;\n    readonly type: string;\n    arrayBuffer(): Promise<ArrayBuffer>;\n    slice(start?: number, end?: number, contentType?: string): Blob;\n    stream(): ReadableStream;\n    text(): Promise<string>;\n}\n\ndeclare var Blob: {\n    prototype: Blob;\n    new(blobParts?: BlobPart[], options?: BlobPropertyBag): Blob;\n};\n\ninterface Body {\n    readonly body: ReadableStream<Uint8Array> | null;\n    readonly bodyUsed: boolean;\n    arrayBuffer(): Promise<ArrayBuffer>;\n    blob(): Promise<Blob>;\n    formData(): Promise<FormData>;\n    json(): Promise<any>;\n    text(): Promise<string>;\n}\n\ninterface BroadcastChannelEventMap {\n    "message": MessageEvent;\n    "messageerror": MessageEvent;\n}\n\ninterface BroadcastChannel extends EventTarget {\n    /**\n     * Returns the channel name (as passed to the constructor).\n     */\n    readonly name: string;\n    onmessage: ((this: BroadcastChannel, ev: MessageEvent) => any) | null;\n    onmessageerror: ((this: BroadcastChannel, ev: MessageEvent) => any) | null;\n    /**\n     * Closes the BroadcastChannel object, opening it up to garbage collection.\n     */\n    close(): void;\n    /**\n     * Sends the given message to other BroadcastChannel objects set up for this channel. Messages can be structured objects, e.g. nested objects and arrays.\n     */\n    postMessage(message: any): void;\n    addEventListener<K extends keyof BroadcastChannelEventMap>(type: K, listener: (this: BroadcastChannel, ev: BroadcastChannelEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof BroadcastChannelEventMap>(type: K, listener: (this: BroadcastChannel, ev: BroadcastChannelEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var BroadcastChannel: {\n    prototype: BroadcastChannel;\n    new(name: string): BroadcastChannel;\n};\n\n/** This Streams API interface provides a built-in byte length queuing strategy that can be used when constructing streams. */\ninterface ByteLengthQueuingStrategy extends QueuingStrategy<ArrayBufferView> {\n    readonly highWaterMark: number;\n    readonly size: QueuingStrategySize<ArrayBufferView>;\n}\n\ndeclare var ByteLengthQueuingStrategy: {\n    prototype: ByteLengthQueuingStrategy;\n    new(init: QueuingStrategyInit): ByteLengthQueuingStrategy;\n};\n\n/** A CDATA section that can be used within XML to include extended portions of unescaped text. The symbols < and & don’t need escaping as they normally do when inside a CDATA section. */\ninterface CDATASection extends Text {\n}\n\ndeclare var CDATASection: {\n    prototype: CDATASection;\n    new(): CDATASection;\n};\n\n/** A single condition CSS at-rule, which consists of a condition and a statement block. It is a child of CSSGroupingRule. */\ninterface CSSConditionRule extends CSSGroupingRule {\n    conditionText: string;\n}\n\ndeclare var CSSConditionRule: {\n    prototype: CSSConditionRule;\n    new(): CSSConditionRule;\n};\n\ninterface CSSFontFaceRule extends CSSRule {\n    readonly style: CSSStyleDeclaration;\n}\n\ndeclare var CSSFontFaceRule: {\n    prototype: CSSFontFaceRule;\n    new(): CSSFontFaceRule;\n};\n\n/** Any CSS at-rule that contains other rules nested within it. */\ninterface CSSGroupingRule extends CSSRule {\n    readonly cssRules: CSSRuleList;\n    deleteRule(index: number): void;\n    insertRule(rule: string, index?: number): number;\n}\n\ndeclare var CSSGroupingRule: {\n    prototype: CSSGroupingRule;\n    new(): CSSGroupingRule;\n};\n\ninterface CSSImportRule extends CSSRule {\n    readonly href: string;\n    readonly media: MediaList;\n    readonly styleSheet: CSSStyleSheet;\n}\n\ndeclare var CSSImportRule: {\n    prototype: CSSImportRule;\n    new(): CSSImportRule;\n};\n\n/** An object representing a set of style for a given keyframe. It corresponds to the contains of a single keyframe of a @keyframes at-rule. It implements the CSSRule interface with a type value of 8 (CSSRule.KEYFRAME_RULE). */\ninterface CSSKeyframeRule extends CSSRule {\n    keyText: string;\n    readonly style: CSSStyleDeclaration;\n}\n\ndeclare var CSSKeyframeRule: {\n    prototype: CSSKeyframeRule;\n    new(): CSSKeyframeRule;\n};\n\n/** An object representing a complete set of keyframes for a CSS animation. It corresponds to the contains of a whole @keyframes at-rule. It implements the CSSRule interface with a type value of 7 (CSSRule.KEYFRAMES_RULE). */\ninterface CSSKeyframesRule extends CSSRule {\n    readonly cssRules: CSSRuleList;\n    name: string;\n    appendRule(rule: string): void;\n    deleteRule(select: string): void;\n    findRule(select: string): CSSKeyframeRule | null;\n}\n\ndeclare var CSSKeyframesRule: {\n    prototype: CSSKeyframesRule;\n    new(): CSSKeyframesRule;\n};\n\n/** A single CSS @media rule. It implements the CSSConditionRule interface, and therefore the CSSGroupingRule and the CSSRule interface with a type value of 4 (CSSRule.MEDIA_RULE). */\ninterface CSSMediaRule extends CSSConditionRule {\n    readonly media: MediaList;\n}\n\ndeclare var CSSMediaRule: {\n    prototype: CSSMediaRule;\n    new(): CSSMediaRule;\n};\n\n/** An object representing a single CSS @namespace at-rule. It implements the CSSRule interface, with a type value of 10 (CSSRule.NAMESPACE_RULE). */\ninterface CSSNamespaceRule extends CSSRule {\n    readonly namespaceURI: string;\n    readonly prefix: string;\n}\n\ndeclare var CSSNamespaceRule: {\n    prototype: CSSNamespaceRule;\n    new(): CSSNamespaceRule;\n};\n\n/** CSSPageRule is an interface representing a single CSS @page rule. It implements the CSSRule interface with a type value of 6 (CSSRule.PAGE_RULE). */\ninterface CSSPageRule extends CSSGroupingRule {\n    selectorText: string;\n    readonly style: CSSStyleDeclaration;\n}\n\ndeclare var CSSPageRule: {\n    prototype: CSSPageRule;\n    new(): CSSPageRule;\n};\n\n/** A single CSS rule. There are several types of rules, listed in the Type constants section below. */\ninterface CSSRule {\n    cssText: string;\n    readonly parentRule: CSSRule | null;\n    readonly parentStyleSheet: CSSStyleSheet | null;\n    readonly type: number;\n    readonly CHARSET_RULE: number;\n    readonly FONT_FACE_RULE: number;\n    readonly IMPORT_RULE: number;\n    readonly KEYFRAMES_RULE: number;\n    readonly KEYFRAME_RULE: number;\n    readonly MEDIA_RULE: number;\n    readonly NAMESPACE_RULE: number;\n    readonly PAGE_RULE: number;\n    readonly STYLE_RULE: number;\n    readonly SUPPORTS_RULE: number;\n}\n\ndeclare var CSSRule: {\n    prototype: CSSRule;\n    new(): CSSRule;\n    readonly CHARSET_RULE: number;\n    readonly FONT_FACE_RULE: number;\n    readonly IMPORT_RULE: number;\n    readonly KEYFRAMES_RULE: number;\n    readonly KEYFRAME_RULE: number;\n    readonly MEDIA_RULE: number;\n    readonly NAMESPACE_RULE: number;\n    readonly PAGE_RULE: number;\n    readonly STYLE_RULE: number;\n    readonly SUPPORTS_RULE: number;\n};\n\n/** A CSSRuleList is an (indirect-modify only) array-like object containing an ordered collection of CSSRule objects. */\ninterface CSSRuleList {\n    readonly length: number;\n    item(index: number): CSSRule | null;\n    [index: number]: CSSRule;\n}\n\ndeclare var CSSRuleList: {\n    prototype: CSSRuleList;\n    new(): CSSRuleList;\n};\n\n/** An object that is a CSS declaration block, and exposes style information and various style-related methods and properties. */\ninterface CSSStyleDeclaration {\n    alignContent: string;\n    alignItems: string;\n    alignSelf: string;\n    alignmentBaseline: string;\n    all: string;\n    animation: string;\n    animationDelay: string;\n    animationDirection: string;\n    animationDuration: string;\n    animationFillMode: string;\n    animationIterationCount: string;\n    animationName: string;\n    animationPlayState: string;\n    animationTimingFunction: string;\n    backfaceVisibility: string;\n    background: string;\n    backgroundAttachment: string;\n    backgroundClip: string;\n    backgroundColor: string;\n    backgroundImage: string;\n    backgroundOrigin: string;\n    backgroundPosition: string;\n    backgroundPositionX: string;\n    backgroundPositionY: string;\n    backgroundRepeat: string;\n    backgroundSize: string;\n    baselineShift: string;\n    blockSize: string;\n    border: string;\n    borderBlockEnd: string;\n    borderBlockEndColor: string;\n    borderBlockEndStyle: string;\n    borderBlockEndWidth: string;\n    borderBlockStart: string;\n    borderBlockStartColor: string;\n    borderBlockStartStyle: string;\n    borderBlockStartWidth: string;\n    borderBottom: string;\n    borderBottomColor: string;\n    borderBottomLeftRadius: string;\n    borderBottomRightRadius: string;\n    borderBottomStyle: string;\n    borderBottomWidth: string;\n    borderCollapse: string;\n    borderColor: string;\n    borderImage: string;\n    borderImageOutset: string;\n    borderImageRepeat: string;\n    borderImageSlice: string;\n    borderImageSource: string;\n    borderImageWidth: string;\n    borderInlineEnd: string;\n    borderInlineEndColor: string;\n    borderInlineEndStyle: string;\n    borderInlineEndWidth: string;\n    borderInlineStart: string;\n    borderInlineStartColor: string;\n    borderInlineStartStyle: string;\n    borderInlineStartWidth: string;\n    borderLeft: string;\n    borderLeftColor: string;\n    borderLeftStyle: string;\n    borderLeftWidth: string;\n    borderRadius: string;\n    borderRight: string;\n    borderRightColor: string;\n    borderRightStyle: string;\n    borderRightWidth: string;\n    borderSpacing: string;\n    borderStyle: string;\n    borderTop: string;\n    borderTopColor: string;\n    borderTopLeftRadius: string;\n    borderTopRightRadius: string;\n    borderTopStyle: string;\n    borderTopWidth: string;\n    borderWidth: string;\n    bottom: string;\n    boxShadow: string;\n    boxSizing: string;\n    breakAfter: string;\n    breakBefore: string;\n    breakInside: string;\n    captionSide: string;\n    caretColor: string;\n    clear: string;\n    clip: string;\n    clipPath: string;\n    clipRule: string;\n    color: string;\n    colorInterpolation: string;\n    colorInterpolationFilters: string;\n    columnCount: string;\n    columnFill: string;\n    columnGap: string;\n    columnRule: string;\n    columnRuleColor: string;\n    columnRuleStyle: string;\n    columnRuleWidth: string;\n    columnSpan: string;\n    columnWidth: string;\n    columns: string;\n    content: string;\n    counterIncrement: string;\n    counterReset: string;\n    cssFloat: string;\n    cssText: string;\n    cursor: string;\n    direction: string;\n    display: string;\n    dominantBaseline: string;\n    emptyCells: string;\n    fill: string;\n    fillOpacity: string;\n    fillRule: string;\n    filter: string;\n    flex: string;\n    flexBasis: string;\n    flexDirection: string;\n    flexFlow: string;\n    flexGrow: string;\n    flexShrink: string;\n    flexWrap: string;\n    float: string;\n    floodColor: string;\n    floodOpacity: string;\n    font: string;\n    fontFamily: string;\n    fontFeatureSettings: string;\n    fontKerning: string;\n    fontSize: string;\n    fontSizeAdjust: string;\n    fontStretch: string;\n    fontStyle: string;\n    fontSynthesis: string;\n    fontVariant: string;\n    fontVariantCaps: string;\n    fontVariantEastAsian: string;\n    fontVariantLigatures: string;\n    fontVariantNumeric: string;\n    fontVariantPosition: string;\n    fontWeight: string;\n    gap: string;\n    glyphOrientationVertical: string;\n    grid: string;\n    gridArea: string;\n    gridAutoColumns: string;\n    gridAutoFlow: string;\n    gridAutoRows: string;\n    gridColumn: string;\n    gridColumnEnd: string;\n    gridColumnGap: string;\n    gridColumnStart: string;\n    gridGap: string;\n    gridRow: string;\n    gridRowEnd: string;\n    gridRowGap: string;\n    gridRowStart: string;\n    gridTemplate: string;\n    gridTemplateAreas: string;\n    gridTemplateColumns: string;\n    gridTemplateRows: string;\n    height: string;\n    hyphens: string;\n    imageOrientation: string;\n    imageRendering: string;\n    inlineSize: string;\n    justifyContent: string;\n    justifyItems: string;\n    justifySelf: string;\n    left: string;\n    readonly length: number;\n    letterSpacing: string;\n    lightingColor: string;\n    lineBreak: string;\n    lineHeight: string;\n    listStyle: string;\n    listStyleImage: string;\n    listStylePosition: string;\n    listStyleType: string;\n    margin: string;\n    marginBlockEnd: string;\n    marginBlockStart: string;\n    marginBottom: string;\n    marginInlineEnd: string;\n    marginInlineStart: string;\n    marginLeft: string;\n    marginRight: string;\n    marginTop: string;\n    marker: string;\n    markerEnd: string;\n    markerMid: string;\n    markerStart: string;\n    mask: string;\n    maskComposite: string;\n    maskImage: string;\n    maskPosition: string;\n    maskRepeat: string;\n    maskSize: string;\n    maskType: string;\n    maxBlockSize: string;\n    maxHeight: string;\n    maxInlineSize: string;\n    maxWidth: string;\n    minBlockSize: string;\n    minHeight: string;\n    minInlineSize: string;\n    minWidth: string;\n    objectFit: string;\n    objectPosition: string;\n    opacity: string;\n    order: string;\n    orphans: string;\n    outline: string;\n    outlineColor: string;\n    outlineOffset: string;\n    outlineStyle: string;\n    outlineWidth: string;\n    overflow: string;\n    overflowAnchor: string;\n    overflowWrap: string;\n    overflowX: string;\n    overflowY: string;\n    overscrollBehavior: string;\n    overscrollBehaviorBlock: string;\n    overscrollBehaviorInline: string;\n    overscrollBehaviorX: string;\n    overscrollBehaviorY: string;\n    padding: string;\n    paddingBlockEnd: string;\n    paddingBlockStart: string;\n    paddingBottom: string;\n    paddingInlineEnd: string;\n    paddingInlineStart: string;\n    paddingLeft: string;\n    paddingRight: string;\n    paddingTop: string;\n    pageBreakAfter: string;\n    pageBreakBefore: string;\n    pageBreakInside: string;\n    paintOrder: string;\n    readonly parentRule: CSSRule | null;\n    perspective: string;\n    perspectiveOrigin: string;\n    placeContent: string;\n    placeItems: string;\n    placeSelf: string;\n    pointerEvents: string;\n    position: string;\n    quotes: string;\n    resize: string;\n    right: string;\n    rotate: string;\n    rowGap: string;\n    rubyAlign: string;\n    rubyPosition: string;\n    scale: string;\n    scrollBehavior: string;\n    shapeRendering: string;\n    stopColor: string;\n    stopOpacity: string;\n    stroke: string;\n    strokeDasharray: string;\n    strokeDashoffset: string;\n    strokeLinecap: string;\n    strokeLinejoin: string;\n    strokeMiterlimit: string;\n    strokeOpacity: string;\n    strokeWidth: string;\n    tabSize: string;\n    tableLayout: string;\n    textAlign: string;\n    textAlignLast: string;\n    textAnchor: string;\n    textCombineUpright: string;\n    textDecoration: string;\n    textDecorationColor: string;\n    textDecorationLine: string;\n    textDecorationStyle: string;\n    textEmphasis: string;\n    textEmphasisColor: string;\n    textEmphasisPosition: string;\n    textEmphasisStyle: string;\n    textIndent: string;\n    textJustify: string;\n    textOrientation: string;\n    textOverflow: string;\n    textRendering: string;\n    textShadow: string;\n    textTransform: string;\n    textUnderlinePosition: string;\n    top: string;\n    touchAction: string;\n    transform: string;\n    transformBox: string;\n    transformOrigin: string;\n    transformStyle: string;\n    transition: string;\n    transitionDelay: string;\n    transitionDuration: string;\n    transitionProperty: string;\n    transitionTimingFunction: string;\n    translate: string;\n    unicodeBidi: string;\n    userSelect: string;\n    verticalAlign: string;\n    visibility: string;\n    /** @deprecated */\n    webkitAlignContent: string;\n    /** @deprecated */\n    webkitAlignItems: string;\n    /** @deprecated */\n    webkitAlignSelf: string;\n    /** @deprecated */\n    webkitAnimation: string;\n    /** @deprecated */\n    webkitAnimationDelay: string;\n    /** @deprecated */\n    webkitAnimationDirection: string;\n    /** @deprecated */\n    webkitAnimationDuration: string;\n    /** @deprecated */\n    webkitAnimationFillMode: string;\n    /** @deprecated */\n    webkitAnimationIterationCount: string;\n    /** @deprecated */\n    webkitAnimationName: string;\n    /** @deprecated */\n    webkitAnimationPlayState: string;\n    /** @deprecated */\n    webkitAnimationTimingFunction: string;\n    /** @deprecated */\n    webkitAppearance: string;\n    /** @deprecated */\n    webkitBackfaceVisibility: string;\n    /** @deprecated */\n    webkitBackgroundClip: string;\n    /** @deprecated */\n    webkitBackgroundOrigin: string;\n    /** @deprecated */\n    webkitBackgroundSize: string;\n    /** @deprecated */\n    webkitBorderBottomLeftRadius: string;\n    /** @deprecated */\n    webkitBorderBottomRightRadius: string;\n    /** @deprecated */\n    webkitBorderRadius: string;\n    /** @deprecated */\n    webkitBorderTopLeftRadius: string;\n    /** @deprecated */\n    webkitBorderTopRightRadius: string;\n    /** @deprecated */\n    webkitBoxAlign: string;\n    /** @deprecated */\n    webkitBoxFlex: string;\n    /** @deprecated */\n    webkitBoxOrdinalGroup: string;\n    /** @deprecated */\n    webkitBoxOrient: string;\n    /** @deprecated */\n    webkitBoxPack: string;\n    /** @deprecated */\n    webkitBoxShadow: string;\n    /** @deprecated */\n    webkitBoxSizing: string;\n    /** @deprecated */\n    webkitFilter: string;\n    /** @deprecated */\n    webkitFlex: string;\n    /** @deprecated */\n    webkitFlexBasis: string;\n    /** @deprecated */\n    webkitFlexDirection: string;\n    /** @deprecated */\n    webkitFlexFlow: string;\n    /** @deprecated */\n    webkitFlexGrow: string;\n    /** @deprecated */\n    webkitFlexShrink: string;\n    /** @deprecated */\n    webkitFlexWrap: string;\n    /** @deprecated */\n    webkitJustifyContent: string;\n    webkitLineClamp: string;\n    /** @deprecated */\n    webkitMask: string;\n    /** @deprecated */\n    webkitMaskBoxImage: string;\n    /** @deprecated */\n    webkitMaskBoxImageOutset: string;\n    /** @deprecated */\n    webkitMaskBoxImageRepeat: string;\n    /** @deprecated */\n    webkitMaskBoxImageSlice: string;\n    /** @deprecated */\n    webkitMaskBoxImageSource: string;\n    /** @deprecated */\n    webkitMaskBoxImageWidth: string;\n    /** @deprecated */\n    webkitMaskClip: string;\n    /** @deprecated */\n    webkitMaskComposite: string;\n    /** @deprecated */\n    webkitMaskImage: string;\n    /** @deprecated */\n    webkitMaskOrigin: string;\n    /** @deprecated */\n    webkitMaskPosition: string;\n    /** @deprecated */\n    webkitMaskRepeat: string;\n    /** @deprecated */\n    webkitMaskSize: string;\n    /** @deprecated */\n    webkitOrder: string;\n    /** @deprecated */\n    webkitPerspective: string;\n    /** @deprecated */\n    webkitPerspectiveOrigin: string;\n    webkitTapHighlightColor: string;\n    /** @deprecated */\n    webkitTextFillColor: string;\n    /** @deprecated */\n    webkitTextSizeAdjust: string;\n    /** @deprecated */\n    webkitTextStroke: string;\n    /** @deprecated */\n    webkitTextStrokeColor: string;\n    /** @deprecated */\n    webkitTextStrokeWidth: string;\n    /** @deprecated */\n    webkitTransform: string;\n    /** @deprecated */\n    webkitTransformOrigin: string;\n    /** @deprecated */\n    webkitTransformStyle: string;\n    /** @deprecated */\n    webkitTransition: string;\n    /** @deprecated */\n    webkitTransitionDelay: string;\n    /** @deprecated */\n    webkitTransitionDuration: string;\n    /** @deprecated */\n    webkitTransitionProperty: string;\n    /** @deprecated */\n    webkitTransitionTimingFunction: string;\n    /** @deprecated */\n    webkitUserSelect: string;\n    whiteSpace: string;\n    widows: string;\n    width: string;\n    willChange: string;\n    wordBreak: string;\n    wordSpacing: string;\n    wordWrap: string;\n    writingMode: string;\n    zIndex: string;\n    /** @deprecated */\n    zoom: string;\n    getPropertyPriority(property: string): string;\n    getPropertyValue(property: string): string;\n    item(index: number): string;\n    removeProperty(property: string): string;\n    setProperty(property: string, value: string | null, priority?: string): void;\n    [index: number]: string;\n}\n\ndeclare var CSSStyleDeclaration: {\n    prototype: CSSStyleDeclaration;\n    new(): CSSStyleDeclaration;\n};\n\n/** CSSStyleRule represents a single CSS style rule. It implements the CSSRule interface with a type value of 1 (CSSRule.STYLE_RULE). */\ninterface CSSStyleRule extends CSSRule {\n    selectorText: string;\n    readonly style: CSSStyleDeclaration;\n}\n\ndeclare var CSSStyleRule: {\n    prototype: CSSStyleRule;\n    new(): CSSStyleRule;\n};\n\n/** A single CSS style sheet. It inherits properties and methods from its parent, StyleSheet. */\ninterface CSSStyleSheet extends StyleSheet {\n    readonly cssRules: CSSRuleList;\n    readonly ownerRule: CSSRule | null;\n    readonly rules: CSSRuleList;\n    addRule(selector?: string, style?: string, index?: number): number;\n    deleteRule(index: number): void;\n    insertRule(rule: string, index?: number): number;\n    removeRule(index?: number): void;\n}\n\ndeclare var CSSStyleSheet: {\n    prototype: CSSStyleSheet;\n    new(): CSSStyleSheet;\n};\n\n/** An object representing a single CSS @supports at-rule. It implements the CSSConditionRule interface, and therefore the CSSRule and CSSGroupingRule interfaces with a type value of 12 (CSSRule.SUPPORTS_RULE). */\ninterface CSSSupportsRule extends CSSConditionRule {\n}\n\ndeclare var CSSSupportsRule: {\n    prototype: CSSSupportsRule;\n    new(): CSSSupportsRule;\n};\n\n/** Provides a storage mechanism for Request / Response object pairs that are cached, for example as part of the ServiceWorker life cycle. Note that the Cache interface is exposed to windowed scopes as well as workers. You don\'t have to use it in conjunction with service workers, even though it is defined in the service worker spec. */\ninterface Cache {\n    add(request: RequestInfo): Promise<void>;\n    addAll(requests: RequestInfo[]): Promise<void>;\n    delete(request: RequestInfo, options?: CacheQueryOptions): Promise<boolean>;\n    keys(request?: RequestInfo, options?: CacheQueryOptions): Promise<ReadonlyArray<Request>>;\n    match(request: RequestInfo, options?: CacheQueryOptions): Promise<Response | undefined>;\n    matchAll(request?: RequestInfo, options?: CacheQueryOptions): Promise<ReadonlyArray<Response>>;\n    put(request: RequestInfo, response: Response): Promise<void>;\n}\n\ndeclare var Cache: {\n    prototype: Cache;\n    new(): Cache;\n};\n\n/** The storage for Cache objects. */\ninterface CacheStorage {\n    delete(cacheName: string): Promise<boolean>;\n    has(cacheName: string): Promise<boolean>;\n    keys(): Promise<string[]>;\n    match(request: RequestInfo, options?: MultiCacheQueryOptions): Promise<Response | undefined>;\n    open(cacheName: string): Promise<Cache>;\n}\n\ndeclare var CacheStorage: {\n    prototype: CacheStorage;\n    new(): CacheStorage;\n};\n\ninterface CanvasCompositing {\n    globalAlpha: number;\n    globalCompositeOperation: string;\n}\n\ninterface CanvasDrawImage {\n    drawImage(image: CanvasImageSource, dx: number, dy: number): void;\n    drawImage(image: CanvasImageSource, dx: number, dy: number, dw: number, dh: number): void;\n    drawImage(image: CanvasImageSource, sx: number, sy: number, sw: number, sh: number, dx: number, dy: number, dw: number, dh: number): void;\n}\n\ninterface CanvasDrawPath {\n    beginPath(): void;\n    clip(fillRule?: CanvasFillRule): void;\n    clip(path: Path2D, fillRule?: CanvasFillRule): void;\n    fill(fillRule?: CanvasFillRule): void;\n    fill(path: Path2D, fillRule?: CanvasFillRule): void;\n    isPointInPath(x: number, y: number, fillRule?: CanvasFillRule): boolean;\n    isPointInPath(path: Path2D, x: number, y: number, fillRule?: CanvasFillRule): boolean;\n    isPointInStroke(x: number, y: number): boolean;\n    isPointInStroke(path: Path2D, x: number, y: number): boolean;\n    stroke(): void;\n    stroke(path: Path2D): void;\n}\n\ninterface CanvasFillStrokeStyles {\n    fillStyle: string | CanvasGradient | CanvasPattern;\n    strokeStyle: string | CanvasGradient | CanvasPattern;\n    createLinearGradient(x0: number, y0: number, x1: number, y1: number): CanvasGradient;\n    createPattern(image: CanvasImageSource, repetition: string | null): CanvasPattern | null;\n    createRadialGradient(x0: number, y0: number, r0: number, x1: number, y1: number, r1: number): CanvasGradient;\n}\n\ninterface CanvasFilters {\n    filter: string;\n}\n\n/** An opaque object describing a gradient. It is returned by the methods CanvasRenderingContext2D.createLinearGradient() or CanvasRenderingContext2D.createRadialGradient(). */\ninterface CanvasGradient {\n    /**\n     * Adds a color stop with the given color to the gradient at the given offset. 0.0 is the offset at one end of the gradient, 1.0 is the offset at the other end.\n     *\n     * Throws an "IndexSizeError" DOMException if the offset is out of range. Throws a "SyntaxError" DOMException if the color cannot be parsed.\n     */\n    addColorStop(offset: number, color: string): void;\n}\n\ndeclare var CanvasGradient: {\n    prototype: CanvasGradient;\n    new(): CanvasGradient;\n};\n\ninterface CanvasImageData {\n    createImageData(sw: number, sh: number): ImageData;\n    createImageData(imagedata: ImageData): ImageData;\n    getImageData(sx: number, sy: number, sw: number, sh: number): ImageData;\n    putImageData(imagedata: ImageData, dx: number, dy: number): void;\n    putImageData(imagedata: ImageData, dx: number, dy: number, dirtyX: number, dirtyY: number, dirtyWidth: number, dirtyHeight: number): void;\n}\n\ninterface CanvasImageSmoothing {\n    imageSmoothingEnabled: boolean;\n    imageSmoothingQuality: ImageSmoothingQuality;\n}\n\ninterface CanvasPath {\n    arc(x: number, y: number, radius: number, startAngle: number, endAngle: number, anticlockwise?: boolean): void;\n    arcTo(x1: number, y1: number, x2: number, y2: number, radius: number): void;\n    bezierCurveTo(cp1x: number, cp1y: number, cp2x: number, cp2y: number, x: number, y: number): void;\n    closePath(): void;\n    ellipse(x: number, y: number, radiusX: number, radiusY: number, rotation: number, startAngle: number, endAngle: number, anticlockwise?: boolean): void;\n    lineTo(x: number, y: number): void;\n    moveTo(x: number, y: number): void;\n    quadraticCurveTo(cpx: number, cpy: number, x: number, y: number): void;\n    rect(x: number, y: number, w: number, h: number): void;\n}\n\ninterface CanvasPathDrawingStyles {\n    lineCap: CanvasLineCap;\n    lineDashOffset: number;\n    lineJoin: CanvasLineJoin;\n    lineWidth: number;\n    miterLimit: number;\n    getLineDash(): number[];\n    setLineDash(segments: number[]): void;\n}\n\n/** An opaque object describing a pattern, based on an image, a canvas, or a video, created by the CanvasRenderingContext2D.createPattern() method. */\ninterface CanvasPattern {\n    /**\n     * Sets the transformation matrix that will be used when rendering the pattern during a fill or stroke painting operation.\n     */\n    setTransform(transform?: DOMMatrix2DInit): void;\n}\n\ndeclare var CanvasPattern: {\n    prototype: CanvasPattern;\n    new(): CanvasPattern;\n};\n\ninterface CanvasRect {\n    clearRect(x: number, y: number, w: number, h: number): void;\n    fillRect(x: number, y: number, w: number, h: number): void;\n    strokeRect(x: number, y: number, w: number, h: number): void;\n}\n\n/** The CanvasRenderingContext2D interface, part of the Canvas API, provides the 2D rendering context for the drawing surface of a <canvas> element. It is used for drawing shapes, text, images, and other objects. */\ninterface CanvasRenderingContext2D extends CanvasCompositing, CanvasDrawImage, CanvasDrawPath, CanvasFillStrokeStyles, CanvasFilters, CanvasImageData, CanvasImageSmoothing, CanvasPath, CanvasPathDrawingStyles, CanvasRect, CanvasShadowStyles, CanvasState, CanvasText, CanvasTextDrawingStyles, CanvasTransform, CanvasUserInterface {\n    readonly canvas: HTMLCanvasElement;\n}\n\ndeclare var CanvasRenderingContext2D: {\n    prototype: CanvasRenderingContext2D;\n    new(): CanvasRenderingContext2D;\n};\n\ninterface CanvasShadowStyles {\n    shadowBlur: number;\n    shadowColor: string;\n    shadowOffsetX: number;\n    shadowOffsetY: number;\n}\n\ninterface CanvasState {\n    restore(): void;\n    save(): void;\n}\n\ninterface CanvasText {\n    fillText(text: string, x: number, y: number, maxWidth?: number): void;\n    measureText(text: string): TextMetrics;\n    strokeText(text: string, x: number, y: number, maxWidth?: number): void;\n}\n\ninterface CanvasTextDrawingStyles {\n    direction: CanvasDirection;\n    font: string;\n    textAlign: CanvasTextAlign;\n    textBaseline: CanvasTextBaseline;\n}\n\ninterface CanvasTransform {\n    getTransform(): DOMMatrix;\n    resetTransform(): void;\n    rotate(angle: number): void;\n    scale(x: number, y: number): void;\n    setTransform(a: number, b: number, c: number, d: number, e: number, f: number): void;\n    setTransform(transform?: DOMMatrix2DInit): void;\n    transform(a: number, b: number, c: number, d: number, e: number, f: number): void;\n    translate(x: number, y: number): void;\n}\n\ninterface CanvasUserInterface {\n    drawFocusIfNeeded(element: Element): void;\n    drawFocusIfNeeded(path: Path2D, element: Element): void;\n    scrollPathIntoView(): void;\n    scrollPathIntoView(path: Path2D): void;\n}\n\ninterface CaretPosition {\n    readonly offset: number;\n    readonly offsetNode: Node;\n    getClientRect(): DOMRect | null;\n}\n\ndeclare var CaretPosition: {\n    prototype: CaretPosition;\n    new(): CaretPosition;\n};\n\n/** The ChannelMergerNode interface, often used in conjunction with its opposite, ChannelSplitterNode, reunites different mono inputs into a single output. Each input is used to fill a channel of the output. This is useful for accessing each channels separately, e.g. for performing channel mixing where gain must be separately controlled on each channel. */\ninterface ChannelMergerNode extends AudioNode {\n}\n\ndeclare var ChannelMergerNode: {\n    prototype: ChannelMergerNode;\n    new(context: BaseAudioContext, options?: ChannelMergerOptions): ChannelMergerNode;\n};\n\n/** The ChannelSplitterNode interface, often used in conjunction with its opposite, ChannelMergerNode, separates the different channels of an audio source into a set of mono outputs. This is useful for accessing each channel separately, e.g. for performing channel mixing where gain must be separately controlled on each channel. */\ninterface ChannelSplitterNode extends AudioNode {\n}\n\ndeclare var ChannelSplitterNode: {\n    prototype: ChannelSplitterNode;\n    new(context: BaseAudioContext, options?: ChannelSplitterOptions): ChannelSplitterNode;\n};\n\n/** The CharacterData abstract interface represents a Node object that contains characters. This is an abstract interface, meaning there aren\'t any object of type CharacterData: it is implemented by other interfaces, like Text, Comment, or ProcessingInstruction which aren\'t abstract. */\ninterface CharacterData extends Node, ChildNode, NonDocumentTypeChildNode {\n    data: string;\n    readonly length: number;\n    readonly ownerDocument: Document;\n    appendData(data: string): void;\n    deleteData(offset: number, count: number): void;\n    insertData(offset: number, data: string): void;\n    replaceData(offset: number, count: number, data: string): void;\n    substringData(offset: number, count: number): string;\n}\n\ndeclare var CharacterData: {\n    prototype: CharacterData;\n    new(): CharacterData;\n};\n\ninterface ChildNode extends Node {\n    /**\n     * Inserts nodes just after node, while replacing strings in nodes with equivalent Text nodes.\n     *\n     * Throws a "HierarchyRequestError" DOMException if the constraints of the node tree are violated.\n     */\n    after(...nodes: (Node | string)[]): void;\n    /**\n     * Inserts nodes just before node, while replacing strings in nodes with equivalent Text nodes.\n     *\n     * Throws a "HierarchyRequestError" DOMException if the constraints of the node tree are violated.\n     */\n    before(...nodes: (Node | string)[]): void;\n    /**\n     * Removes node.\n     */\n    remove(): void;\n    /**\n     * Replaces node with nodes, while replacing strings in nodes with equivalent Text nodes.\n     *\n     * Throws a "HierarchyRequestError" DOMException if the constraints of the node tree are violated.\n     */\n    replaceWith(...nodes: (Node | string)[]): void;\n}\n\ninterface ClientRect {\n    bottom: number;\n    readonly height: number;\n    left: number;\n    right: number;\n    top: number;\n    readonly width: number;\n}\n\ndeclare var ClientRect: {\n    prototype: ClientRect;\n    new(): ClientRect;\n};\n\ninterface ClientRectList {\n    readonly length: number;\n    item(index: number): ClientRect;\n    [index: number]: ClientRect;\n}\n\ndeclare var ClientRectList: {\n    prototype: ClientRectList;\n    new(): ClientRectList;\n};\n\ninterface Clipboard extends EventTarget {\n    readText(): Promise<string>;\n    writeText(data: string): Promise<void>;\n}\n\ndeclare var Clipboard: {\n    prototype: Clipboard;\n    new(): Clipboard;\n};\n\n/** Events providing information related to modification of the clipboard, that is cut, copy, and paste events. */\ninterface ClipboardEvent extends Event {\n    readonly clipboardData: DataTransfer | null;\n}\n\ndeclare var ClipboardEvent: {\n    prototype: ClipboardEvent;\n    new(type: string, eventInitDict?: ClipboardEventInit): ClipboardEvent;\n};\n\n/** A CloseEvent is sent to clients using WebSockets when the connection is closed. This is delivered to the listener indicated by the WebSocket object\'s onclose attribute. */\ninterface CloseEvent extends Event {\n    /**\n     * Returns the WebSocket connection close code provided by the server.\n     */\n    readonly code: number;\n    /**\n     * Returns the WebSocket connection close reason provided by the server.\n     */\n    readonly reason: string;\n    /**\n     * Returns true if the connection closed cleanly; false otherwise.\n     */\n    readonly wasClean: boolean;\n}\n\ndeclare var CloseEvent: {\n    prototype: CloseEvent;\n    new(type: string, eventInitDict?: CloseEventInit): CloseEvent;\n};\n\n/** Textual notations within markup; although it is generally not visually shown, such comments are available to be read in the source view. */\ninterface Comment extends CharacterData {\n}\n\ndeclare var Comment: {\n    prototype: Comment;\n    new(data?: string): Comment;\n};\n\n/** The DOM CompositionEvent represents events that occur due to the user indirectly entering text. */\ninterface CompositionEvent extends UIEvent {\n    readonly data: string;\n}\n\ndeclare var CompositionEvent: {\n    prototype: CompositionEvent;\n    new(type: string, eventInitDict?: CompositionEventInit): CompositionEvent;\n};\n\ninterface ConcatParams extends Algorithm {\n    algorithmId: Uint8Array;\n    hash?: string | Algorithm;\n    partyUInfo: Uint8Array;\n    partyVInfo: Uint8Array;\n    privateInfo?: Uint8Array;\n    publicInfo?: Uint8Array;\n}\n\ninterface ConstantSourceNode extends AudioScheduledSourceNode {\n    readonly offset: AudioParam;\n    addEventListener<K extends keyof AudioScheduledSourceNodeEventMap>(type: K, listener: (this: ConstantSourceNode, ev: AudioScheduledSourceNodeEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof AudioScheduledSourceNodeEventMap>(type: K, listener: (this: ConstantSourceNode, ev: AudioScheduledSourceNodeEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var ConstantSourceNode: {\n    prototype: ConstantSourceNode;\n    new(context: BaseAudioContext, options?: ConstantSourceOptions): ConstantSourceNode;\n};\n\n/** An AudioNode that performs a Linear Convolution on a given AudioBuffer, often used to achieve a reverb effect. A ConvolverNode always has exactly one input and one output. */\ninterface ConvolverNode extends AudioNode {\n    buffer: AudioBuffer | null;\n    normalize: boolean;\n}\n\ndeclare var ConvolverNode: {\n    prototype: ConvolverNode;\n    new(context: BaseAudioContext, options?: ConvolverOptions): ConvolverNode;\n};\n\n/** This Streams API interface provides a built-in byte length queuing strategy that can be used when constructing streams. */\ninterface CountQueuingStrategy extends QueuingStrategy {\n    readonly highWaterMark: number;\n    readonly size: QueuingStrategySize;\n}\n\ndeclare var CountQueuingStrategy: {\n    prototype: CountQueuingStrategy;\n    new(init: QueuingStrategyInit): CountQueuingStrategy;\n};\n\ninterface Credential {\n    readonly id: string;\n    readonly type: string;\n}\n\ndeclare var Credential: {\n    prototype: Credential;\n    new(): Credential;\n};\n\ninterface CredentialsContainer {\n    create(options?: CredentialCreationOptions): Promise<Credential | null>;\n    get(options?: CredentialRequestOptions): Promise<Credential | null>;\n    preventSilentAccess(): Promise<void>;\n    store(credential: Credential): Promise<Credential>;\n}\n\ndeclare var CredentialsContainer: {\n    prototype: CredentialsContainer;\n    new(): CredentialsContainer;\n};\n\n/** Basic cryptography features available in the current context. It allows access to a cryptographically strong random number generator and to cryptographic primitives. */\ninterface Crypto {\n    readonly subtle: SubtleCrypto;\n    getRandomValues<T extends Int8Array | Int16Array | Int32Array | Uint8Array | Uint16Array | Uint32Array | Uint8ClampedArray | Float32Array | Float64Array | DataView | null>(array: T): T;\n}\n\ndeclare var Crypto: {\n    prototype: Crypto;\n    new(): Crypto;\n};\n\n/** The CryptoKey dictionary of the Web Crypto API represents a cryptographic key. */\ninterface CryptoKey {\n    readonly algorithm: KeyAlgorithm;\n    readonly extractable: boolean;\n    readonly type: KeyType;\n    readonly usages: KeyUsage[];\n}\n\ndeclare var CryptoKey: {\n    prototype: CryptoKey;\n    new(): CryptoKey;\n};\n\n/** The CryptoKeyPair dictionary of the Web Crypto API represents a key pair for an asymmetric cryptography algorithm, also known as a public-key algorithm. */\ninterface CryptoKeyPair {\n    privateKey: CryptoKey;\n    publicKey: CryptoKey;\n}\n\ndeclare var CryptoKeyPair: {\n    prototype: CryptoKeyPair;\n    new(): CryptoKeyPair;\n};\n\ninterface CustomElementRegistry {\n    define(name: string, constructor: CustomElementConstructor, options?: ElementDefinitionOptions): void;\n    get(name: string): any;\n    upgrade(root: Node): void;\n    whenDefined(name: string): Promise<void>;\n}\n\ndeclare var CustomElementRegistry: {\n    prototype: CustomElementRegistry;\n    new(): CustomElementRegistry;\n};\n\ninterface CustomEvent<T = any> extends Event {\n    /**\n     * Returns any custom data event was created with. Typically used for synthetic events.\n     */\n    readonly detail: T;\n    initCustomEvent(typeArg: string, canBubbleArg: boolean, cancelableArg: boolean, detailArg: T): void;\n}\n\ndeclare var CustomEvent: {\n    prototype: CustomEvent;\n    new<T>(typeArg: string, eventInitDict?: CustomEventInit<T>): CustomEvent<T>;\n};\n\n/** An error object that contains an error name. */\ninterface DOMError {\n    readonly name: string;\n    toString(): string;\n}\n\ndeclare var DOMError: {\n    prototype: DOMError;\n    new(): DOMError;\n};\n\n/** An abnormal event (called an exception) which occurs as a result of calling a method or accessing a property of a web API. */\ninterface DOMException {\n    readonly code: number;\n    readonly message: string;\n    readonly name: string;\n    readonly ABORT_ERR: number;\n    readonly DATA_CLONE_ERR: number;\n    readonly DOMSTRING_SIZE_ERR: number;\n    readonly HIERARCHY_REQUEST_ERR: number;\n    readonly INDEX_SIZE_ERR: number;\n    readonly INUSE_ATTRIBUTE_ERR: number;\n    readonly INVALID_ACCESS_ERR: number;\n    readonly INVALID_CHARACTER_ERR: number;\n    readonly INVALID_MODIFICATION_ERR: number;\n    readonly INVALID_NODE_TYPE_ERR: number;\n    readonly INVALID_STATE_ERR: number;\n    readonly NAMESPACE_ERR: number;\n    readonly NETWORK_ERR: number;\n    readonly NOT_FOUND_ERR: number;\n    readonly NOT_SUPPORTED_ERR: number;\n    readonly NO_DATA_ALLOWED_ERR: number;\n    readonly NO_MODIFICATION_ALLOWED_ERR: number;\n    readonly QUOTA_EXCEEDED_ERR: number;\n    readonly SECURITY_ERR: number;\n    readonly SYNTAX_ERR: number;\n    readonly TIMEOUT_ERR: number;\n    readonly TYPE_MISMATCH_ERR: number;\n    readonly URL_MISMATCH_ERR: number;\n    readonly VALIDATION_ERR: number;\n    readonly WRONG_DOCUMENT_ERR: number;\n}\n\ndeclare var DOMException: {\n    prototype: DOMException;\n    new(message?: string, name?: string): DOMException;\n    readonly ABORT_ERR: number;\n    readonly DATA_CLONE_ERR: number;\n    readonly DOMSTRING_SIZE_ERR: number;\n    readonly HIERARCHY_REQUEST_ERR: number;\n    readonly INDEX_SIZE_ERR: number;\n    readonly INUSE_ATTRIBUTE_ERR: number;\n    readonly INVALID_ACCESS_ERR: number;\n    readonly INVALID_CHARACTER_ERR: number;\n    readonly INVALID_MODIFICATION_ERR: number;\n    readonly INVALID_NODE_TYPE_ERR: number;\n    readonly INVALID_STATE_ERR: number;\n    readonly NAMESPACE_ERR: number;\n    readonly NETWORK_ERR: number;\n    readonly NOT_FOUND_ERR: number;\n    readonly NOT_SUPPORTED_ERR: number;\n    readonly NO_DATA_ALLOWED_ERR: number;\n    readonly NO_MODIFICATION_ALLOWED_ERR: number;\n    readonly QUOTA_EXCEEDED_ERR: number;\n    readonly SECURITY_ERR: number;\n    readonly SYNTAX_ERR: number;\n    readonly TIMEOUT_ERR: number;\n    readonly TYPE_MISMATCH_ERR: number;\n    readonly URL_MISMATCH_ERR: number;\n    readonly VALIDATION_ERR: number;\n    readonly WRONG_DOCUMENT_ERR: number;\n};\n\n/** An object providing methods which are not dependent on any particular document. Such an object is returned by the Document.implementation property. */\ninterface DOMImplementation {\n    createDocument(namespace: string | null, qualifiedName: string | null, doctype?: DocumentType | null): XMLDocument;\n    createDocumentType(qualifiedName: string, publicId: string, systemId: string): DocumentType;\n    createHTMLDocument(title?: string): Document;\n    /** @deprecated */\n    hasFeature(...args: any[]): true;\n}\n\ndeclare var DOMImplementation: {\n    prototype: DOMImplementation;\n    new(): DOMImplementation;\n};\n\ninterface DOMMatrix extends DOMMatrixReadOnly {\n    a: number;\n    b: number;\n    c: number;\n    d: number;\n    e: number;\n    f: number;\n    m11: number;\n    m12: number;\n    m13: number;\n    m14: number;\n    m21: number;\n    m22: number;\n    m23: number;\n    m24: number;\n    m31: number;\n    m32: number;\n    m33: number;\n    m34: number;\n    m41: number;\n    m42: number;\n    m43: number;\n    m44: number;\n    invertSelf(): DOMMatrix;\n    multiplySelf(other?: DOMMatrixInit): DOMMatrix;\n    preMultiplySelf(other?: DOMMatrixInit): DOMMatrix;\n    rotateAxisAngleSelf(x?: number, y?: number, z?: number, angle?: number): DOMMatrix;\n    rotateFromVectorSelf(x?: number, y?: number): DOMMatrix;\n    rotateSelf(rotX?: number, rotY?: number, rotZ?: number): DOMMatrix;\n    scale3dSelf(scale?: number, originX?: number, originY?: number, originZ?: number): DOMMatrix;\n    scaleSelf(scaleX?: number, scaleY?: number, scaleZ?: number, originX?: number, originY?: number, originZ?: number): DOMMatrix;\n    setMatrixValue(transformList: string): DOMMatrix;\n    skewXSelf(sx?: number): DOMMatrix;\n    skewYSelf(sy?: number): DOMMatrix;\n    translateSelf(tx?: number, ty?: number, tz?: number): DOMMatrix;\n}\n\ndeclare var DOMMatrix: {\n    prototype: DOMMatrix;\n    new(init?: string | number[]): DOMMatrix;\n    fromFloat32Array(array32: Float32Array): DOMMatrix;\n    fromFloat64Array(array64: Float64Array): DOMMatrix;\n    fromMatrix(other?: DOMMatrixInit): DOMMatrix;\n};\n\ntype SVGMatrix = DOMMatrix;\ndeclare var SVGMatrix: typeof DOMMatrix;\n\ntype WebKitCSSMatrix = DOMMatrix;\ndeclare var WebKitCSSMatrix: typeof DOMMatrix;\n\ninterface DOMMatrixReadOnly {\n    readonly a: number;\n    readonly b: number;\n    readonly c: number;\n    readonly d: number;\n    readonly e: number;\n    readonly f: number;\n    readonly is2D: boolean;\n    readonly isIdentity: boolean;\n    readonly m11: number;\n    readonly m12: number;\n    readonly m13: number;\n    readonly m14: number;\n    readonly m21: number;\n    readonly m22: number;\n    readonly m23: number;\n    readonly m24: number;\n    readonly m31: number;\n    readonly m32: number;\n    readonly m33: number;\n    readonly m34: number;\n    readonly m41: number;\n    readonly m42: number;\n    readonly m43: number;\n    readonly m44: number;\n    flipX(): DOMMatrix;\n    flipY(): DOMMatrix;\n    inverse(): DOMMatrix;\n    multiply(other?: DOMMatrixInit): DOMMatrix;\n    rotate(rotX?: number, rotY?: number, rotZ?: number): DOMMatrix;\n    rotateAxisAngle(x?: number, y?: number, z?: number, angle?: number): DOMMatrix;\n    rotateFromVector(x?: number, y?: number): DOMMatrix;\n    scale(scaleX?: number, scaleY?: number, scaleZ?: number, originX?: number, originY?: number, originZ?: number): DOMMatrix;\n    scale3d(scale?: number, originX?: number, originY?: number, originZ?: number): DOMMatrix;\n    /** @deprecated */\n    scaleNonUniform(scaleX?: number, scaleY?: number): DOMMatrix;\n    skewX(sx?: number): DOMMatrix;\n    skewY(sy?: number): DOMMatrix;\n    toFloat32Array(): Float32Array;\n    toFloat64Array(): Float64Array;\n    toJSON(): any;\n    transformPoint(point?: DOMPointInit): DOMPoint;\n    translate(tx?: number, ty?: number, tz?: number): DOMMatrix;\n    toString(): string;\n}\n\ndeclare var DOMMatrixReadOnly: {\n    prototype: DOMMatrixReadOnly;\n    new(init?: string | number[]): DOMMatrixReadOnly;\n    fromFloat32Array(array32: Float32Array): DOMMatrixReadOnly;\n    fromFloat64Array(array64: Float64Array): DOMMatrixReadOnly;\n    fromMatrix(other?: DOMMatrixInit): DOMMatrixReadOnly;\n    toString(): string;\n};\n\n/** Provides the ability to parse XML or HTML source code from a string into a DOM Document. */\ninterface DOMParser {\n    /**\n     * Parses string using either the HTML or XML parser, according to type, and returns the resulting Document. type can be "text/html" (which will invoke the HTML parser), or any of "text/xml", "application/xml", "application/xhtml+xml", or "image/svg+xml" (which will invoke the XML parser).\n     *\n     * For the XML parser, if string cannot be parsed, then the returned Document will contain elements describing the resulting error.\n     *\n     * Note that script elements are not evaluated during parsing, and the resulting document\'s encoding will always be UTF-8.\n     *\n     * Values other than the above for type will cause a TypeError exception to be thrown.\n     */\n    parseFromString(string: string, type: DOMParserSupportedType): Document;\n}\n\ndeclare var DOMParser: {\n    prototype: DOMParser;\n    new(): DOMParser;\n};\n\ninterface DOMPoint extends DOMPointReadOnly {\n    w: number;\n    x: number;\n    y: number;\n    z: number;\n}\n\ndeclare var DOMPoint: {\n    prototype: DOMPoint;\n    new(x?: number, y?: number, z?: number, w?: number): DOMPoint;\n    fromPoint(other?: DOMPointInit): DOMPoint;\n};\n\ntype SVGPoint = DOMPoint;\ndeclare var SVGPoint: typeof DOMPoint;\n\ninterface DOMPointReadOnly {\n    readonly w: number;\n    readonly x: number;\n    readonly y: number;\n    readonly z: number;\n    matrixTransform(matrix?: DOMMatrixInit): DOMPoint;\n    toJSON(): any;\n}\n\ndeclare var DOMPointReadOnly: {\n    prototype: DOMPointReadOnly;\n    new(x?: number, y?: number, z?: number, w?: number): DOMPointReadOnly;\n    fromPoint(other?: DOMPointInit): DOMPointReadOnly;\n};\n\ninterface DOMQuad {\n    readonly p1: DOMPoint;\n    readonly p2: DOMPoint;\n    readonly p3: DOMPoint;\n    readonly p4: DOMPoint;\n    getBounds(): DOMRect;\n    toJSON(): any;\n}\n\ndeclare var DOMQuad: {\n    prototype: DOMQuad;\n    new(p1?: DOMPointInit, p2?: DOMPointInit, p3?: DOMPointInit, p4?: DOMPointInit): DOMQuad;\n    fromQuad(other?: DOMQuadInit): DOMQuad;\n    fromRect(other?: DOMRectInit): DOMQuad;\n};\n\ninterface DOMRect extends DOMRectReadOnly {\n    height: number;\n    width: number;\n    x: number;\n    y: number;\n}\n\ndeclare var DOMRect: {\n    prototype: DOMRect;\n    new(x?: number, y?: number, width?: number, height?: number): DOMRect;\n    fromRect(other?: DOMRectInit): DOMRect;\n};\n\ntype SVGRect = DOMRect;\ndeclare var SVGRect: typeof DOMRect;\n\ninterface DOMRectList {\n    readonly length: number;\n    item(index: number): DOMRect | null;\n    [index: number]: DOMRect;\n}\n\ndeclare var DOMRectList: {\n    prototype: DOMRectList;\n    new(): DOMRectList;\n};\n\ninterface DOMRectReadOnly {\n    readonly bottom: number;\n    readonly height: number;\n    readonly left: number;\n    readonly right: number;\n    readonly top: number;\n    readonly width: number;\n    readonly x: number;\n    readonly y: number;\n    toJSON(): any;\n}\n\ndeclare var DOMRectReadOnly: {\n    prototype: DOMRectReadOnly;\n    new(x?: number, y?: number, width?: number, height?: number): DOMRectReadOnly;\n    fromRect(other?: DOMRectInit): DOMRectReadOnly;\n};\n\ninterface DOMSettableTokenList extends DOMTokenList {\n    value: string;\n}\n\ndeclare var DOMSettableTokenList: {\n    prototype: DOMSettableTokenList;\n    new(): DOMSettableTokenList;\n};\n\n/** A type returned by some APIs which contains a list of DOMString (strings). */\ninterface DOMStringList {\n    /**\n     * Returns the number of strings in strings.\n     */\n    readonly length: number;\n    /**\n     * Returns true if strings contains string, and false otherwise.\n     */\n    contains(string: string): boolean;\n    /**\n     * Returns the string with index index from strings.\n     */\n    item(index: number): string | null;\n    [index: number]: string;\n}\n\ndeclare var DOMStringList: {\n    prototype: DOMStringList;\n    new(): DOMStringList;\n};\n\n/** Used by the dataset HTML attribute to represent data for custom attributes added to elements. */\ninterface DOMStringMap {\n    [name: string]: string | undefined;\n}\n\ndeclare var DOMStringMap: {\n    prototype: DOMStringMap;\n    new(): DOMStringMap;\n};\n\n/** A set of space-separated tokens. Such a set is returned by Element.classList, HTMLLinkElement.relList, HTMLAnchorElement.relList, HTMLAreaElement.relList, HTMLIframeElement.sandbox, or HTMLOutputElement.htmlFor. It is indexed beginning with 0 as with JavaScript Array objects. DOMTokenList is always case-sensitive. */\ninterface DOMTokenList {\n    /**\n     * Returns the number of tokens.\n     */\n    readonly length: number;\n    /**\n     * Returns the associated set as string.\n     *\n     * Can be set, to change the associated attribute.\n     */\n    value: string;\n    toString(): string;\n    /**\n     * Adds all arguments passed, except those already present.\n     *\n     * Throws a "SyntaxError" DOMException if one of the arguments is the empty string.\n     *\n     * Throws an "InvalidCharacterError" DOMException if one of the arguments contains any ASCII whitespace.\n     */\n    add(...tokens: string[]): void;\n    /**\n     * Returns true if token is present, and false otherwise.\n     */\n    contains(token: string): boolean;\n    /**\n     * Returns the token with index index.\n     */\n    item(index: number): string | null;\n    /**\n     * Removes arguments passed, if they are present.\n     *\n     * Throws a "SyntaxError" DOMException if one of the arguments is the empty string.\n     *\n     * Throws an "InvalidCharacterError" DOMException if one of the arguments contains any ASCII whitespace.\n     */\n    remove(...tokens: string[]): void;\n    /**\n     * Replaces token with newToken.\n     *\n     * Returns true if token was replaced with newToken, and false otherwise.\n     *\n     * Throws a "SyntaxError" DOMException if one of the arguments is the empty string.\n     *\n     * Throws an "InvalidCharacterError" DOMException if one of the arguments contains any ASCII whitespace.\n     */\n    replace(oldToken: string, newToken: string): void;\n    /**\n     * Returns true if token is in the associated attribute\'s supported tokens. Returns false otherwise.\n     *\n     * Throws a TypeError if the associated attribute has no supported tokens defined.\n     */\n    supports(token: string): boolean;\n    /**\n     * If force is not given, "toggles" token, removing it if it\'s present and adding it if it\'s not present. If force is true, adds token (same as add()). If force is false, removes token (same as remove()).\n     *\n     * Returns true if token is now present, and false otherwise.\n     *\n     * Throws a "SyntaxError" DOMException if token is empty.\n     *\n     * Throws an "InvalidCharacterError" DOMException if token contains any spaces.\n     */\n    toggle(token: string, force?: boolean): boolean;\n    forEach(callbackfn: (value: string, key: number, parent: DOMTokenList) => void, thisArg?: any): void;\n    [index: number]: string;\n}\n\ndeclare var DOMTokenList: {\n    prototype: DOMTokenList;\n    new(): DOMTokenList;\n};\n\ninterface DataCue extends TextTrackCue {\n    data: ArrayBuffer;\n    addEventListener<K extends keyof TextTrackCueEventMap>(type: K, listener: (this: DataCue, ev: TextTrackCueEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof TextTrackCueEventMap>(type: K, listener: (this: DataCue, ev: TextTrackCueEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var DataCue: {\n    prototype: DataCue;\n    new(): DataCue;\n};\n\n/** Used to hold the data that is being dragged during a drag and drop operation. It may hold one or more data items, each of one or more data types. For more information about drag and drop, see HTML Drag and Drop API. */\ninterface DataTransfer {\n    /**\n     * Returns the kind of operation that is currently selected. If the kind of operation isn\'t one of those that is allowed by the effectAllowed attribute, then the operation will fail.\n     *\n     * Can be set, to change the selected operation.\n     *\n     * The possible values are "none", "copy", "link", and "move".\n     */\n    dropEffect: "none" | "copy" | "link" | "move";\n    /**\n     * Returns the kinds of operations that are to be allowed.\n     *\n     * Can be set (during the dragstart event), to change the allowed operations.\n     *\n     * The possible values are "none", "copy", "copyLink", "copyMove", "link", "linkMove", "move", "all", and "uninitialized",\n     */\n    effectAllowed: "none" | "copy" | "copyLink" | "copyMove" | "link" | "linkMove" | "move" | "all" | "uninitialized";\n    /**\n     * Returns a FileList of the files being dragged, if any.\n     */\n    readonly files: FileList;\n    /**\n     * Returns a DataTransferItemList object, with the drag data.\n     */\n    readonly items: DataTransferItemList;\n    /**\n     * Returns a frozen array listing the formats that were set in the dragstart event. In addition, if any files are being dragged, then one of the types will be the string "Files".\n     */\n    readonly types: ReadonlyArray<string>;\n    /**\n     * Removes the data of the specified formats. Removes all data if the argument is omitted.\n     */\n    clearData(format?: string): void;\n    /**\n     * Returns the specified data. If there is no such data, returns the empty string.\n     */\n    getData(format: string): string;\n    /**\n     * Adds the specified data.\n     */\n    setData(format: string, data: string): void;\n    /**\n     * Uses the given element to update the drag feedback, replacing any previously specified feedback.\n     */\n    setDragImage(image: Element, x: number, y: number): void;\n}\n\ndeclare var DataTransfer: {\n    prototype: DataTransfer;\n    new(): DataTransfer;\n};\n\n/** One drag data item. During a drag operation, each drag event has a dataTransfer property which contains a list of drag data items. Each item in the list is a DataTransferItem object. */\ninterface DataTransferItem {\n    /**\n     * Returns the drag data item kind, one of: "string", "file".\n     */\n    readonly kind: string;\n    /**\n     * Returns the drag data item type string.\n     */\n    readonly type: string;\n    /**\n     * Returns a File object, if the drag data item kind is File.\n     */\n    getAsFile(): File | null;\n    /**\n     * Invokes the callback with the string data as the argument, if the drag data item kind is text.\n     */\n    getAsString(callback: FunctionStringCallback | null): void;\n    webkitGetAsEntry(): any;\n}\n\ndeclare var DataTransferItem: {\n    prototype: DataTransferItem;\n    new(): DataTransferItem;\n};\n\n/** A list of DataTransferItem objects representing items being dragged. During a drag operation, each DragEvent has a dataTransfer property and that property is a DataTransferItemList. */\ninterface DataTransferItemList {\n    /**\n     * Returns the number of items in the drag data store.\n     */\n    readonly length: number;\n    /**\n     * Adds a new entry for the given data to the drag data store. If the data is plain text then a type string has to be provided also.\n     */\n    add(data: string, type: string): DataTransferItem | null;\n    add(data: File): DataTransferItem | null;\n    /**\n     * Removes all the entries in the drag data store.\n     */\n    clear(): void;\n    item(index: number): DataTransferItem;\n    /**\n     * Removes the indexth entry in the drag data store.\n     */\n    remove(index: number): void;\n    [name: number]: DataTransferItem;\n}\n\ndeclare var DataTransferItemList: {\n    prototype: DataTransferItemList;\n    new(): DataTransferItemList;\n};\n\ninterface DeferredPermissionRequest {\n    readonly id: number;\n    readonly type: MSWebViewPermissionType;\n    readonly uri: string;\n    allow(): void;\n    deny(): void;\n}\n\ndeclare var DeferredPermissionRequest: {\n    prototype: DeferredPermissionRequest;\n    new(): DeferredPermissionRequest;\n};\n\n/** A delay-line; an AudioNode audio-processing module that causes a delay between the arrival of an input data and its propagation to the output. */\ninterface DelayNode extends AudioNode {\n    readonly delayTime: AudioParam;\n}\n\ndeclare var DelayNode: {\n    prototype: DelayNode;\n    new(context: BaseAudioContext, options?: DelayOptions): DelayNode;\n};\n\n/** Provides information about the amount of acceleration the device is experiencing along all three axes. */\ninterface DeviceAcceleration {\n    readonly x: number | null;\n    readonly y: number | null;\n    readonly z: number | null;\n}\n\ndeclare var DeviceAcceleration: {\n    prototype: DeviceAcceleration;\n    new(): DeviceAcceleration;\n};\n\n/** The DeviceMotionEvent provides web developers with information about the speed of changes for the device\'s position and orientation. */\ninterface DeviceMotionEvent extends Event {\n    readonly acceleration: DeviceMotionEventAcceleration | null;\n    readonly accelerationIncludingGravity: DeviceMotionEventAcceleration | null;\n    readonly interval: number;\n    readonly rotationRate: DeviceMotionEventRotationRate | null;\n}\n\ndeclare var DeviceMotionEvent: {\n    prototype: DeviceMotionEvent;\n    new(type: string, eventInitDict?: DeviceMotionEventInit): DeviceMotionEvent;\n    requestPermission(): Promise<PermissionState>;\n};\n\ninterface DeviceMotionEventAcceleration {\n    readonly x: number | null;\n    readonly y: number | null;\n    readonly z: number | null;\n}\n\ninterface DeviceMotionEventRotationRate {\n    readonly alpha: number | null;\n    readonly beta: number | null;\n    readonly gamma: number | null;\n}\n\n/** The DeviceOrientationEvent provides web developers with information from the physical orientation of the device running the web page. */\ninterface DeviceOrientationEvent extends Event {\n    readonly absolute: boolean;\n    readonly alpha: number | null;\n    readonly beta: number | null;\n    readonly gamma: number | null;\n}\n\ndeclare var DeviceOrientationEvent: {\n    prototype: DeviceOrientationEvent;\n    new(type: string, eventInitDict?: DeviceOrientationEventInit): DeviceOrientationEvent;\n    requestPermission(): Promise<PermissionState>;\n};\n\n/** Provides information about the rate at which the device is rotating around all three axes. */\ninterface DeviceRotationRate {\n    readonly alpha: number | null;\n    readonly beta: number | null;\n    readonly gamma: number | null;\n}\n\ndeclare var DeviceRotationRate: {\n    prototype: DeviceRotationRate;\n    new(): DeviceRotationRate;\n};\n\ninterface DhImportKeyParams extends Algorithm {\n    generator: Uint8Array;\n    prime: Uint8Array;\n}\n\ninterface DhKeyAlgorithm extends KeyAlgorithm {\n    generator: Uint8Array;\n    prime: Uint8Array;\n}\n\ninterface DhKeyDeriveParams extends Algorithm {\n    public: CryptoKey;\n}\n\ninterface DhKeyGenParams extends Algorithm {\n    generator: Uint8Array;\n    prime: Uint8Array;\n}\n\ninterface DocumentEventMap extends GlobalEventHandlersEventMap, DocumentAndElementEventHandlersEventMap {\n    "fullscreenchange": Event;\n    "fullscreenerror": Event;\n    "pointerlockchange": Event;\n    "pointerlockerror": Event;\n    "readystatechange": Event;\n    "visibilitychange": Event;\n}\n\n/** Any web page loaded in the browser and serves as an entry point into the web page\'s content, which is the DOM tree. */\ninterface Document extends Node, DocumentAndElementEventHandlers, DocumentOrShadowRoot, GlobalEventHandlers, NonElementParentNode, ParentNode, XPathEvaluatorBase {\n    /**\n     * Sets or gets the URL for the current document.\n     */\n    readonly URL: string;\n    /**\n     * Sets or gets the color of all active links in the document.\n     */\n    /** @deprecated */\n    alinkColor: string;\n    /**\n     * Returns a reference to the collection of elements contained by the object.\n     */\n    /** @deprecated */\n    readonly all: HTMLAllCollection;\n    /**\n     * Retrieves a collection of all a objects that have a name and/or id property. Objects in this collection are in HTML source order.\n     */\n    /** @deprecated */\n    readonly anchors: HTMLCollectionOf<HTMLAnchorElement>;\n    /**\n     * Retrieves a collection of all applet objects in the document.\n     */\n    /** @deprecated */\n    readonly applets: HTMLCollectionOf<HTMLAppletElement>;\n    /**\n     * Deprecated. Sets or retrieves a value that indicates the background color behind the object.\n     */\n    /** @deprecated */\n    bgColor: string;\n    /**\n     * Specifies the beginning and end of the document body.\n     */\n    body: HTMLElement;\n    /**\n     * Returns document\'s encoding.\n     */\n    readonly characterSet: string;\n    /**\n     * Gets or sets the character set used to encode the object.\n     */\n    readonly charset: string;\n    /**\n     * Gets a value that indicates whether standards-compliant mode is switched on for the object.\n     */\n    readonly compatMode: string;\n    /**\n     * Returns document\'s content type.\n     */\n    readonly contentType: string;\n    /**\n     * Returns the HTTP cookies that apply to the Document. If there are no cookies or cookies can\'t be applied to this resource, the empty string will be returned.\n     *\n     * Can be set, to add a new cookie to the element\'s set of HTTP cookies.\n     *\n     * If the contents are sandboxed into a unique origin (e.g. in an iframe with the sandbox attribute), a "SecurityError" DOMException will be thrown on getting and setting.\n     */\n    cookie: string;\n    /**\n     * Returns the script element, or the SVG script element, that is currently executing, as long as the element represents a classic script. In the case of reentrant script execution, returns the one that most recently started executing amongst those that have not yet finished executing.\n     *\n     * Returns null if the Document is not currently executing a script or SVG script element (e.g., because the running script is an event handler, or a timeout), or if the currently executing script or SVG script element represents a module script.\n     */\n    readonly currentScript: HTMLOrSVGScriptElement | null;\n    readonly defaultView: (WindowProxy & typeof globalThis) | null;\n    /**\n     * Sets or gets a value that indicates whether the document can be edited.\n     */\n    designMode: string;\n    /**\n     * Sets or retrieves a value that indicates the reading order of the object.\n     */\n    dir: string;\n    /**\n     * Gets an object representing the document type declaration associated with the current document.\n     */\n    readonly doctype: DocumentType | null;\n    /**\n     * Gets a reference to the root node of the document.\n     */\n    readonly documentElement: HTMLElement;\n    /**\n     * Returns document\'s URL.\n     */\n    readonly documentURI: string;\n    /**\n     * Sets or gets the security domain of the document.\n     */\n    domain: string;\n    /**\n     * Retrieves a collection of all embed objects in the document.\n     */\n    readonly embeds: HTMLCollectionOf<HTMLEmbedElement>;\n    /**\n     * Sets or gets the foreground (text) color of the document.\n     */\n    /** @deprecated */\n    fgColor: string;\n    /**\n     * Retrieves a collection, in source order, of all form objects in the document.\n     */\n    readonly forms: HTMLCollectionOf<HTMLFormElement>;\n    /** @deprecated */\n    readonly fullscreen: boolean;\n    /**\n     * Returns true if document has the ability to display elements fullscreen and fullscreen is supported, or false otherwise.\n     */\n    readonly fullscreenEnabled: boolean;\n    /**\n     * Returns the head element.\n     */\n    readonly head: HTMLHeadElement;\n    readonly hidden: boolean;\n    /**\n     * Retrieves a collection, in source order, of img objects in the document.\n     */\n    readonly images: HTMLCollectionOf<HTMLImageElement>;\n    /**\n     * Gets the implementation object of the current document.\n     */\n    readonly implementation: DOMImplementation;\n    /**\n     * Returns the character encoding used to create the webpage that is loaded into the document object.\n     */\n    readonly inputEncoding: string;\n    /**\n     * Gets the date that the page was last modified, if the page supplies one.\n     */\n    readonly lastModified: string;\n    /**\n     * Sets or gets the color of the document links.\n     */\n    /** @deprecated */\n    linkColor: string;\n    /**\n     * Retrieves a collection of all a objects that specify the href property and all area objects in the document.\n     */\n    readonly links: HTMLCollectionOf<HTMLAnchorElement | HTMLAreaElement>;\n    /**\n     * Contains information about the current URL.\n     */\n    location: Location;\n    onfullscreenchange: ((this: Document, ev: Event) => any) | null;\n    onfullscreenerror: ((this: Document, ev: Event) => any) | null;\n    onpointerlockchange: ((this: Document, ev: Event) => any) | null;\n    onpointerlockerror: ((this: Document, ev: Event) => any) | null;\n    /**\n     * Fires when the state of the object has changed.\n     * @param ev The event\n     */\n    onreadystatechange: ((this: Document, ev: Event) => any) | null;\n    onvisibilitychange: ((this: Document, ev: Event) => any) | null;\n    readonly ownerDocument: null;\n    /**\n     * Return an HTMLCollection of the embed elements in the Document.\n     */\n    readonly plugins: HTMLCollectionOf<HTMLEmbedElement>;\n    /**\n     * Retrieves a value that indicates the current state of the object.\n     */\n    readonly readyState: DocumentReadyState;\n    /**\n     * Gets the URL of the location that referred the user to the current page.\n     */\n    readonly referrer: string;\n    /**\n     * Retrieves a collection of all script objects in the document.\n     */\n    readonly scripts: HTMLCollectionOf<HTMLScriptElement>;\n    readonly scrollingElement: Element | null;\n    readonly timeline: DocumentTimeline;\n    /**\n     * Contains the title of the document.\n     */\n    title: string;\n    readonly visibilityState: VisibilityState;\n    /**\n     * Sets or gets the color of the links that the user has visited.\n     */\n    /** @deprecated */\n    vlinkColor: string;\n    /**\n     * Moves node from another document and returns it.\n     *\n     * If node is a document, throws a "NotSupportedError" DOMException or, if node is a shadow root, throws a "HierarchyRequestError" DOMException.\n     */\n    adoptNode<T extends Node>(source: T): T;\n    /** @deprecated */\n    captureEvents(): void;\n    caretPositionFromPoint(x: number, y: number): CaretPosition | null;\n    /** @deprecated */\n    caretRangeFromPoint(x: number, y: number): Range;\n    /** @deprecated */\n    clear(): void;\n    /**\n     * Closes an output stream and forces the sent data to display.\n     */\n    close(): void;\n    /**\n     * Creates an attribute object with a specified name.\n     * @param name String that sets the attribute object\'s name.\n     */\n    createAttribute(localName: string): Attr;\n    createAttributeNS(namespace: string | null, qualifiedName: string): Attr;\n    /**\n     * Returns a CDATASection node whose data is data.\n     */\n    createCDATASection(data: string): CDATASection;\n    /**\n     * Creates a comment object with the specified data.\n     * @param data Sets the comment object\'s data.\n     */\n    createComment(data: string): Comment;\n    /**\n     * Creates a new document.\n     */\n    createDocumentFragment(): DocumentFragment;\n    /**\n     * Creates an instance of the element for the specified tag.\n     * @param tagName The name of an element.\n     */\n    createElement<K extends keyof HTMLElementTagNameMap>(tagName: K, options?: ElementCreationOptions): HTMLElementTagNameMap[K];\n    /** @deprecated */\n    createElement<K extends keyof HTMLElementDeprecatedTagNameMap>(tagName: K, options?: ElementCreationOptions): HTMLElementDeprecatedTagNameMap[K];\n    createElement(tagName: string, options?: ElementCreationOptions): HTMLElement;\n    /**\n     * Returns an element with namespace namespace. Its namespace prefix will be everything before ":" (U+003E) in qualifiedName or null. Its local name will be everything after ":" (U+003E) in qualifiedName or qualifiedName.\n     *\n     * If localName does not match the Name production an "InvalidCharacterError" DOMException will be thrown.\n     *\n     * If one of the following conditions is true a "NamespaceError" DOMException will be thrown:\n     *\n     * localName does not match the QName production.\n     * Namespace prefix is not null and namespace is the empty string.\n     * Namespace prefix is "xml" and namespace is not the XML namespace.\n     * qualifiedName or namespace prefix is "xmlns" and namespace is not the XMLNS namespace.\n     * namespace is the XMLNS namespace and neither qualifiedName nor namespace prefix is "xmlns".\n     *\n     * When supplied, options\'s is can be used to create a customized built-in element.\n     */\n    createElementNS(namespaceURI: "http://www.w3.org/1999/xhtml", qualifiedName: string): HTMLElement;\n    createElementNS<K extends keyof SVGElementTagNameMap>(namespaceURI: "http://www.w3.org/2000/svg", qualifiedName: K): SVGElementTagNameMap[K];\n    createElementNS(namespaceURI: "http://www.w3.org/2000/svg", qualifiedName: string): SVGElement;\n    createElementNS(namespaceURI: string | null, qualifiedName: string, options?: ElementCreationOptions): Element;\n    createElementNS(namespace: string | null, qualifiedName: string, options?: string | ElementCreationOptions): Element;\n    createEvent(eventInterface: "AnimationEvent"): AnimationEvent;\n    createEvent(eventInterface: "AnimationPlaybackEvent"): AnimationPlaybackEvent;\n    createEvent(eventInterface: "AudioProcessingEvent"): AudioProcessingEvent;\n    createEvent(eventInterface: "BeforeUnloadEvent"): BeforeUnloadEvent;\n    createEvent(eventInterface: "ClipboardEvent"): ClipboardEvent;\n    createEvent(eventInterface: "CloseEvent"): CloseEvent;\n    createEvent(eventInterface: "CompositionEvent"): CompositionEvent;\n    createEvent(eventInterface: "CustomEvent"): CustomEvent;\n    createEvent(eventInterface: "DeviceMotionEvent"): DeviceMotionEvent;\n    createEvent(eventInterface: "DeviceOrientationEvent"): DeviceOrientationEvent;\n    createEvent(eventInterface: "DragEvent"): DragEvent;\n    createEvent(eventInterface: "ErrorEvent"): ErrorEvent;\n    createEvent(eventInterface: "Event"): Event;\n    createEvent(eventInterface: "Events"): Event;\n    createEvent(eventInterface: "FocusEvent"): FocusEvent;\n    createEvent(eventInterface: "FocusNavigationEvent"): FocusNavigationEvent;\n    createEvent(eventInterface: "GamepadEvent"): GamepadEvent;\n    createEvent(eventInterface: "HashChangeEvent"): HashChangeEvent;\n    createEvent(eventInterface: "IDBVersionChangeEvent"): IDBVersionChangeEvent;\n    createEvent(eventInterface: "InputEvent"): InputEvent;\n    createEvent(eventInterface: "KeyboardEvent"): KeyboardEvent;\n    createEvent(eventInterface: "ListeningStateChangedEvent"): ListeningStateChangedEvent;\n    createEvent(eventInterface: "MediaEncryptedEvent"): MediaEncryptedEvent;\n    createEvent(eventInterface: "MediaKeyMessageEvent"): MediaKeyMessageEvent;\n    createEvent(eventInterface: "MediaQueryListEvent"): MediaQueryListEvent;\n    createEvent(eventInterface: "MediaStreamErrorEvent"): MediaStreamErrorEvent;\n    createEvent(eventInterface: "MediaStreamEvent"): MediaStreamEvent;\n    createEvent(eventInterface: "MediaStreamTrackEvent"): MediaStreamTrackEvent;\n    createEvent(eventInterface: "MessageEvent"): MessageEvent;\n    createEvent(eventInterface: "MouseEvent"): MouseEvent;\n    createEvent(eventInterface: "MouseEvents"): MouseEvent;\n    createEvent(eventInterface: "MutationEvent"): MutationEvent;\n    createEvent(eventInterface: "MutationEvents"): MutationEvent;\n    createEvent(eventInterface: "OfflineAudioCompletionEvent"): OfflineAudioCompletionEvent;\n    createEvent(eventInterface: "OverflowEvent"): OverflowEvent;\n    createEvent(eventInterface: "PageTransitionEvent"): PageTransitionEvent;\n    createEvent(eventInterface: "PaymentMethodChangeEvent"): PaymentMethodChangeEvent;\n    createEvent(eventInterface: "PaymentRequestUpdateEvent"): PaymentRequestUpdateEvent;\n    createEvent(eventInterface: "PermissionRequestedEvent"): PermissionRequestedEvent;\n    createEvent(eventInterface: "PointerEvent"): PointerEvent;\n    createEvent(eventInterface: "PopStateEvent"): PopStateEvent;\n    createEvent(eventInterface: "ProgressEvent"): ProgressEvent;\n    createEvent(eventInterface: "PromiseRejectionEvent"): PromiseRejectionEvent;\n    createEvent(eventInterface: "RTCDTMFToneChangeEvent"): RTCDTMFToneChangeEvent;\n    createEvent(eventInterface: "RTCDataChannelEvent"): RTCDataChannelEvent;\n    createEvent(eventInterface: "RTCDtlsTransportStateChangedEvent"): RTCDtlsTransportStateChangedEvent;\n    createEvent(eventInterface: "RTCErrorEvent"): RTCErrorEvent;\n    createEvent(eventInterface: "RTCIceCandidatePairChangedEvent"): RTCIceCandidatePairChangedEvent;\n    createEvent(eventInterface: "RTCIceGathererEvent"): RTCIceGathererEvent;\n    createEvent(eventInterface: "RTCIceTransportStateChangedEvent"): RTCIceTransportStateChangedEvent;\n    createEvent(eventInterface: "RTCPeerConnectionIceErrorEvent"): RTCPeerConnectionIceErrorEvent;\n    createEvent(eventInterface: "RTCPeerConnectionIceEvent"): RTCPeerConnectionIceEvent;\n    createEvent(eventInterface: "RTCSsrcConflictEvent"): RTCSsrcConflictEvent;\n    createEvent(eventInterface: "RTCTrackEvent"): RTCTrackEvent;\n    createEvent(eventInterface: "SVGZoomEvent"): SVGZoomEvent;\n    createEvent(eventInterface: "SVGZoomEvents"): SVGZoomEvent;\n    createEvent(eventInterface: "SecurityPolicyViolationEvent"): SecurityPolicyViolationEvent;\n    createEvent(eventInterface: "SpeechRecognitionErrorEvent"): SpeechRecognitionErrorEvent;\n    createEvent(eventInterface: "SpeechRecognitionEvent"): SpeechRecognitionEvent;\n    createEvent(eventInterface: "SpeechSynthesisErrorEvent"): SpeechSynthesisErrorEvent;\n    createEvent(eventInterface: "SpeechSynthesisEvent"): SpeechSynthesisEvent;\n    createEvent(eventInterface: "StorageEvent"): StorageEvent;\n    createEvent(eventInterface: "TextEvent"): TextEvent;\n    createEvent(eventInterface: "TouchEvent"): TouchEvent;\n    createEvent(eventInterface: "TrackEvent"): TrackEvent;\n    createEvent(eventInterface: "TransitionEvent"): TransitionEvent;\n    createEvent(eventInterface: "UIEvent"): UIEvent;\n    createEvent(eventInterface: "UIEvents"): UIEvent;\n    createEvent(eventInterface: "VRDisplayEvent"): VRDisplayEvent;\n    createEvent(eventInterface: "VRDisplayEvent "): VRDisplayEvent ;\n    createEvent(eventInterface: "WebGLContextEvent"): WebGLContextEvent;\n    createEvent(eventInterface: "WheelEvent"): WheelEvent;\n    createEvent(eventInterface: string): Event;\n    /**\n     * Creates a NodeIterator object that you can use to traverse filtered lists of nodes or elements in a document.\n     * @param root The root element or node to start traversing on.\n     * @param whatToShow The type of nodes or elements to appear in the node list\n     * @param filter A custom NodeFilter function to use. For more information, see filter. Use null for no filter.\n     * @param entityReferenceExpansion A flag that specifies whether entity reference nodes are expanded.\n     */\n    createNodeIterator(root: Node, whatToShow?: number, filter?: NodeFilter | null): NodeIterator;\n    /**\n     * Returns a ProcessingInstruction node whose target is target and data is data. If target does not match the Name production an "InvalidCharacterError" DOMException will be thrown. If data contains "?>" an "InvalidCharacterError" DOMException will be thrown.\n     */\n    createProcessingInstruction(target: string, data: string): ProcessingInstruction;\n    /**\n     *  Returns an empty range object that has both of its boundary points positioned at the beginning of the document.\n     */\n    createRange(): Range;\n    /**\n     * Creates a text string from the specified value.\n     * @param data String that specifies the nodeValue property of the text node.\n     */\n    createTextNode(data: string): Text;\n    /**\n     * Creates a TreeWalker object that you can use to traverse filtered lists of nodes or elements in a document.\n     * @param root The root element or node to start traversing on.\n     * @param whatToShow The type of nodes or elements to appear in the node list. For more information, see whatToShow.\n     * @param filter A custom NodeFilter function to use.\n     * @param entityReferenceExpansion A flag that specifies whether entity reference nodes are expanded.\n     */\n    createTreeWalker(root: Node, whatToShow?: number, filter?: NodeFilter | null): TreeWalker;\n    /** @deprecated */\n    createTreeWalker(root: Node, whatToShow: number, filter: NodeFilter | null, entityReferenceExpansion?: boolean): TreeWalker;\n    /**\n     * Returns the element for the specified x coordinate and the specified y coordinate.\n     * @param x The x-offset\n     * @param y The y-offset\n     */\n    elementFromPoint(x: number, y: number): Element | null;\n    elementsFromPoint(x: number, y: number): Element[];\n    /**\n     * Executes a command on the current document, current selection, or the given range.\n     * @param commandId String that specifies the command to execute. This command can be any of the command identifiers that can be executed in script.\n     * @param showUI Display the user interface, defaults to false.\n     * @param value Value to assign.\n     */\n    execCommand(commandId: string, showUI?: boolean, value?: string): boolean;\n    /**\n     * Stops document\'s fullscreen element from being displayed fullscreen and resolves promise when done.\n     */\n    exitFullscreen(): Promise<void>;\n    exitPointerLock(): void;\n    getAnimations(): Animation[];\n    /**\n     * Returns a reference to the first object with the specified value of the ID attribute.\n     * @param elementId String that specifies the ID value.\n     */\n    getElementById(elementId: string): HTMLElement | null;\n    /**\n     * Returns a HTMLCollection of the elements in the object on which the method was invoked (a document or an element) that have all the classes given by classNames. The classNames argument is interpreted as a space-separated list of classes.\n     */\n    getElementsByClassName(classNames: string): HTMLCollectionOf<Element>;\n    /**\n     * Gets a collection of objects based on the value of the NAME or ID attribute.\n     * @param elementName Gets a collection of objects based on the value of the NAME or ID attribute.\n     */\n    getElementsByName(elementName: string): NodeListOf<HTMLElement>;\n    /**\n     * Retrieves a collection of objects based on the specified element name.\n     * @param name Specifies the name of an element.\n     */\n    getElementsByTagName<K extends keyof HTMLElementTagNameMap>(qualifiedName: K): HTMLCollectionOf<HTMLElementTagNameMap[K]>;\n    getElementsByTagName<K extends keyof SVGElementTagNameMap>(qualifiedName: K): HTMLCollectionOf<SVGElementTagNameMap[K]>;\n    getElementsByTagName(qualifiedName: string): HTMLCollectionOf<Element>;\n    /**\n     * If namespace and localName are "*" returns a HTMLCollection of all descendant elements.\n     *\n     * If only namespace is "*" returns a HTMLCollection of all descendant elements whose local name is localName.\n     *\n     * If only localName is "*" returns a HTMLCollection of all descendant elements whose namespace is namespace.\n     *\n     * Otherwise, returns a HTMLCollection of all descendant elements whose namespace is namespace and local name is localName.\n     */\n    getElementsByTagNameNS(namespaceURI: "http://www.w3.org/1999/xhtml", localName: string): HTMLCollectionOf<HTMLElement>;\n    getElementsByTagNameNS(namespaceURI: "http://www.w3.org/2000/svg", localName: string): HTMLCollectionOf<SVGElement>;\n    getElementsByTagNameNS(namespaceURI: string, localName: string): HTMLCollectionOf<Element>;\n    /**\n     * Returns an object representing the current selection of the document that is loaded into the object displaying a webpage.\n     */\n    getSelection(): Selection | null;\n    /**\n     * Gets a value indicating whether the object currently has focus.\n     */\n    hasFocus(): boolean;\n    /**\n     * Returns a copy of node. If deep is true, the copy also includes the node\'s descendants.\n     *\n     * If node is a document or a shadow root, throws a "NotSupportedError" DOMException.\n     */\n    importNode<T extends Node>(importedNode: T, deep: boolean): T;\n    /**\n     * Opens a new window and loads a document specified by a given URL. Also, opens a new window that uses the url parameter and the name parameter to collect the output of the write method and the writeln method.\n     * @param url Specifies a MIME type for the document.\n     * @param name Specifies the name of the window. This name is used as the value for the TARGET attribute on a form or an anchor element.\n     * @param features Contains a list of items separated by commas. Each item consists of an option and a value, separated by an equals sign (for example, "fullscreen=yes, toolbar=yes"). The following values are supported.\n     * @param replace Specifies whether the existing entry for the document is replaced in the history list.\n     */\n    open(url?: string, name?: string, features?: string, replace?: boolean): Document;\n    /**\n     * Returns a Boolean value that indicates whether a specified command can be successfully executed using execCommand, given the current state of the document.\n     * @param commandId Specifies a command identifier.\n     */\n    queryCommandEnabled(commandId: string): boolean;\n    /**\n     * Returns a Boolean value that indicates whether the specified command is in the indeterminate state.\n     * @param commandId String that specifies a command identifier.\n     */\n    queryCommandIndeterm(commandId: string): boolean;\n    /**\n     * Returns a Boolean value that indicates the current state of the command.\n     * @param commandId String that specifies a command identifier.\n     */\n    queryCommandState(commandId: string): boolean;\n    /**\n     * Returns a Boolean value that indicates whether the current command is supported on the current range.\n     * @param commandId Specifies a command identifier.\n     */\n    queryCommandSupported(commandId: string): boolean;\n    /**\n     * Returns the current value of the document, range, or current selection for the given command.\n     * @param commandId String that specifies a command identifier.\n     */\n    queryCommandValue(commandId: string): string;\n    /** @deprecated */\n    releaseEvents(): void;\n    /**\n     * Writes one or more HTML expressions to a document in the specified window.\n     * @param content Specifies the text and HTML tags to write.\n     */\n    write(...text: string[]): void;\n    /**\n     * Writes one or more HTML expressions, followed by a carriage return, to a document in the specified window.\n     * @param content The text and HTML tags to write.\n     */\n    writeln(...text: string[]): void;\n    addEventListener<K extends keyof DocumentEventMap>(type: K, listener: (this: Document, ev: DocumentEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof DocumentEventMap>(type: K, listener: (this: Document, ev: DocumentEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var Document: {\n    prototype: Document;\n    new(): Document;\n};\n\ninterface DocumentAndElementEventHandlersEventMap {\n    "copy": ClipboardEvent;\n    "cut": ClipboardEvent;\n    "paste": ClipboardEvent;\n}\n\ninterface DocumentAndElementEventHandlers {\n    oncopy: ((this: DocumentAndElementEventHandlers, ev: ClipboardEvent) => any) | null;\n    oncut: ((this: DocumentAndElementEventHandlers, ev: ClipboardEvent) => any) | null;\n    onpaste: ((this: DocumentAndElementEventHandlers, ev: ClipboardEvent) => any) | null;\n    addEventListener<K extends keyof DocumentAndElementEventHandlersEventMap>(type: K, listener: (this: DocumentAndElementEventHandlers, ev: DocumentAndElementEventHandlersEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof DocumentAndElementEventHandlersEventMap>(type: K, listener: (this: DocumentAndElementEventHandlers, ev: DocumentAndElementEventHandlersEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ninterface DocumentEvent {\n    createEvent(eventInterface: "AnimationEvent"): AnimationEvent;\n    createEvent(eventInterface: "AnimationPlaybackEvent"): AnimationPlaybackEvent;\n    createEvent(eventInterface: "AudioProcessingEvent"): AudioProcessingEvent;\n    createEvent(eventInterface: "BeforeUnloadEvent"): BeforeUnloadEvent;\n    createEvent(eventInterface: "ClipboardEvent"): ClipboardEvent;\n    createEvent(eventInterface: "CloseEvent"): CloseEvent;\n    createEvent(eventInterface: "CompositionEvent"): CompositionEvent;\n    createEvent(eventInterface: "CustomEvent"): CustomEvent;\n    createEvent(eventInterface: "DeviceMotionEvent"): DeviceMotionEvent;\n    createEvent(eventInterface: "DeviceOrientationEvent"): DeviceOrientationEvent;\n    createEvent(eventInterface: "DragEvent"): DragEvent;\n    createEvent(eventInterface: "ErrorEvent"): ErrorEvent;\n    createEvent(eventInterface: "Event"): Event;\n    createEvent(eventInterface: "Events"): Event;\n    createEvent(eventInterface: "FocusEvent"): FocusEvent;\n    createEvent(eventInterface: "FocusNavigationEvent"): FocusNavigationEvent;\n    createEvent(eventInterface: "GamepadEvent"): GamepadEvent;\n    createEvent(eventInterface: "HashChangeEvent"): HashChangeEvent;\n    createEvent(eventInterface: "IDBVersionChangeEvent"): IDBVersionChangeEvent;\n    createEvent(eventInterface: "InputEvent"): InputEvent;\n    createEvent(eventInterface: "KeyboardEvent"): KeyboardEvent;\n    createEvent(eventInterface: "ListeningStateChangedEvent"): ListeningStateChangedEvent;\n    createEvent(eventInterface: "MediaEncryptedEvent"): MediaEncryptedEvent;\n    createEvent(eventInterface: "MediaKeyMessageEvent"): MediaKeyMessageEvent;\n    createEvent(eventInterface: "MediaQueryListEvent"): MediaQueryListEvent;\n    createEvent(eventInterface: "MediaStreamErrorEvent"): MediaStreamErrorEvent;\n    createEvent(eventInterface: "MediaStreamEvent"): MediaStreamEvent;\n    createEvent(eventInterface: "MediaStreamTrackEvent"): MediaStreamTrackEvent;\n    createEvent(eventInterface: "MessageEvent"): MessageEvent;\n    createEvent(eventInterface: "MouseEvent"): MouseEvent;\n    createEvent(eventInterface: "MouseEvents"): MouseEvent;\n    createEvent(eventInterface: "MutationEvent"): MutationEvent;\n    createEvent(eventInterface: "MutationEvents"): MutationEvent;\n    createEvent(eventInterface: "OfflineAudioCompletionEvent"): OfflineAudioCompletionEvent;\n    createEvent(eventInterface: "OverflowEvent"): OverflowEvent;\n    createEvent(eventInterface: "PageTransitionEvent"): PageTransitionEvent;\n    createEvent(eventInterface: "PaymentMethodChangeEvent"): PaymentMethodChangeEvent;\n    createEvent(eventInterface: "PaymentRequestUpdateEvent"): PaymentRequestUpdateEvent;\n    createEvent(eventInterface: "PermissionRequestedEvent"): PermissionRequestedEvent;\n    createEvent(eventInterface: "PointerEvent"): PointerEvent;\n    createEvent(eventInterface: "PopStateEvent"): PopStateEvent;\n    createEvent(eventInterface: "ProgressEvent"): ProgressEvent;\n    createEvent(eventInterface: "PromiseRejectionEvent"): PromiseRejectionEvent;\n    createEvent(eventInterface: "RTCDTMFToneChangeEvent"): RTCDTMFToneChangeEvent;\n    createEvent(eventInterface: "RTCDataChannelEvent"): RTCDataChannelEvent;\n    createEvent(eventInterface: "RTCDtlsTransportStateChangedEvent"): RTCDtlsTransportStateChangedEvent;\n    createEvent(eventInterface: "RTCErrorEvent"): RTCErrorEvent;\n    createEvent(eventInterface: "RTCIceCandidatePairChangedEvent"): RTCIceCandidatePairChangedEvent;\n    createEvent(eventInterface: "RTCIceGathererEvent"): RTCIceGathererEvent;\n    createEvent(eventInterface: "RTCIceTransportStateChangedEvent"): RTCIceTransportStateChangedEvent;\n    createEvent(eventInterface: "RTCPeerConnectionIceErrorEvent"): RTCPeerConnectionIceErrorEvent;\n    createEvent(eventInterface: "RTCPeerConnectionIceEvent"): RTCPeerConnectionIceEvent;\n    createEvent(eventInterface: "RTCSsrcConflictEvent"): RTCSsrcConflictEvent;\n    createEvent(eventInterface: "RTCTrackEvent"): RTCTrackEvent;\n    createEvent(eventInterface: "SVGZoomEvent"): SVGZoomEvent;\n    createEvent(eventInterface: "SVGZoomEvents"): SVGZoomEvent;\n    createEvent(eventInterface: "SecurityPolicyViolationEvent"): SecurityPolicyViolationEvent;\n    createEvent(eventInterface: "SpeechRecognitionErrorEvent"): SpeechRecognitionErrorEvent;\n    createEvent(eventInterface: "SpeechRecognitionEvent"): SpeechRecognitionEvent;\n    createEvent(eventInterface: "SpeechSynthesisErrorEvent"): SpeechSynthesisErrorEvent;\n    createEvent(eventInterface: "SpeechSynthesisEvent"): SpeechSynthesisEvent;\n    createEvent(eventInterface: "StorageEvent"): StorageEvent;\n    createEvent(eventInterface: "TextEvent"): TextEvent;\n    createEvent(eventInterface: "TouchEvent"): TouchEvent;\n    createEvent(eventInterface: "TrackEvent"): TrackEvent;\n    createEvent(eventInterface: "TransitionEvent"): TransitionEvent;\n    createEvent(eventInterface: "UIEvent"): UIEvent;\n    createEvent(eventInterface: "UIEvents"): UIEvent;\n    createEvent(eventInterface: "VRDisplayEvent"): VRDisplayEvent;\n    createEvent(eventInterface: "VRDisplayEvent "): VRDisplayEvent ;\n    createEvent(eventInterface: "WebGLContextEvent"): WebGLContextEvent;\n    createEvent(eventInterface: "WheelEvent"): WheelEvent;\n    createEvent(eventInterface: string): Event;\n}\n\n/** A minimal document object that has no parent. It is used as a lightweight version of Document that stores a segment of a document structure comprised of nodes just like a standard document. The key difference is that because the document fragment isn\'t part of the active document tree structure, changes made to the fragment don\'t affect the document, cause reflow, or incur any performance impact that can occur when changes are made. */\ninterface DocumentFragment extends Node, NonElementParentNode, ParentNode {\n    readonly ownerDocument: Document;\n    getElementById(elementId: string): HTMLElement | null;\n}\n\ndeclare var DocumentFragment: {\n    prototype: DocumentFragment;\n    new(): DocumentFragment;\n};\n\ninterface DocumentOrShadowRoot {\n    readonly activeElement: Element | null;\n    /**\n     * Returns document\'s fullscreen element.\n     */\n    readonly fullscreenElement: Element | null;\n    readonly pointerLockElement: Element | null;\n    /**\n     * Retrieves a collection of styleSheet objects representing the style sheets that correspond to each instance of a link or style object in the document.\n     */\n    readonly styleSheets: StyleSheetList;\n    caretPositionFromPoint(x: number, y: number): CaretPosition | null;\n    /** @deprecated */\n    caretRangeFromPoint(x: number, y: number): Range;\n    elementFromPoint(x: number, y: number): Element | null;\n    elementsFromPoint(x: number, y: number): Element[];\n    getSelection(): Selection | null;\n}\n\ninterface DocumentTimeline extends AnimationTimeline {\n}\n\ndeclare var DocumentTimeline: {\n    prototype: DocumentTimeline;\n    new(options?: DocumentTimelineOptions): DocumentTimeline;\n};\n\n/** A Node containing a doctype. */\ninterface DocumentType extends Node, ChildNode {\n    readonly name: string;\n    readonly ownerDocument: Document;\n    readonly publicId: string;\n    readonly systemId: string;\n}\n\ndeclare var DocumentType: {\n    prototype: DocumentType;\n    new(): DocumentType;\n};\n\n/** A DOM event that represents a drag and drop interaction. The user initiates a drag by placing a pointer device (such as a mouse) on the touch surface and then dragging the pointer to a new location (such as another DOM element). Applications are free to interpret a drag and drop interaction in an application-specific way. */\ninterface DragEvent extends MouseEvent {\n    /**\n     * Returns the DataTransfer object for the event.\n     */\n    readonly dataTransfer: DataTransfer | null;\n}\n\ndeclare var DragEvent: {\n    prototype: DragEvent;\n    new(type: string, eventInitDict?: DragEventInit): DragEvent;\n};\n\n/** Inherits properties from its parent, AudioNode. */\ninterface DynamicsCompressorNode extends AudioNode {\n    readonly attack: AudioParam;\n    readonly knee: AudioParam;\n    readonly ratio: AudioParam;\n    readonly reduction: number;\n    readonly release: AudioParam;\n    readonly threshold: AudioParam;\n}\n\ndeclare var DynamicsCompressorNode: {\n    prototype: DynamicsCompressorNode;\n    new(context: BaseAudioContext, options?: DynamicsCompressorOptions): DynamicsCompressorNode;\n};\n\ninterface EXT_blend_minmax {\n    readonly MAX_EXT: GLenum;\n    readonly MIN_EXT: GLenum;\n}\n\n/** The EXT_frag_depth extension is part of the WebGL API and enables to set a depth value of a fragment from within the fragment shader. */\ninterface EXT_frag_depth {\n}\n\ninterface EXT_sRGB {\n    readonly FRAMEBUFFER_ATTACHMENT_COLOR_ENCODING_EXT: GLenum;\n    readonly SRGB8_ALPHA8_EXT: GLenum;\n    readonly SRGB_ALPHA_EXT: GLenum;\n    readonly SRGB_EXT: GLenum;\n}\n\ninterface EXT_shader_texture_lod {\n}\n\n/** The EXT_texture_filter_anisotropic extension is part of the WebGL API and exposes two constants for anisotropic filtering (AF). */\ninterface EXT_texture_filter_anisotropic {\n    readonly MAX_TEXTURE_MAX_ANISOTROPY_EXT: GLenum;\n    readonly TEXTURE_MAX_ANISOTROPY_EXT: GLenum;\n}\n\ninterface ElementEventMap {\n    "fullscreenchange": Event;\n    "fullscreenerror": Event;\n}\n\n/** Element is the most general base class from which all objects in a Document inherit. It only has methods and properties common to all kinds of elements. More specific classes inherit from Element. */\ninterface Element extends Node, Animatable, ChildNode, InnerHTML, NonDocumentTypeChildNode, ParentNode, Slottable {\n    readonly attributes: NamedNodeMap;\n    /**\n     * Allows for manipulation of element\'s class content attribute as a set of whitespace-separated tokens through a DOMTokenList object.\n     */\n    readonly classList: DOMTokenList;\n    /**\n     * Returns the value of element\'s class content attribute. Can be set to change it.\n     */\n    className: string;\n    readonly clientHeight: number;\n    readonly clientLeft: number;\n    readonly clientTop: number;\n    readonly clientWidth: number;\n    /**\n     * Returns the value of element\'s id content attribute. Can be set to change it.\n     */\n    id: string;\n    /**\n     * Returns the local name.\n     */\n    readonly localName: string;\n    /**\n     * Returns the namespace.\n     */\n    readonly namespaceURI: string | null;\n    onfullscreenchange: ((this: Element, ev: Event) => any) | null;\n    onfullscreenerror: ((this: Element, ev: Event) => any) | null;\n    outerHTML: string;\n    readonly ownerDocument: Document;\n    /**\n     * Returns the namespace prefix.\n     */\n    readonly prefix: string | null;\n    readonly scrollHeight: number;\n    scrollLeft: number;\n    scrollTop: number;\n    readonly scrollWidth: number;\n    /**\n     * Returns element\'s shadow root, if any, and if shadow root\'s mode is "open", and null otherwise.\n     */\n    readonly shadowRoot: ShadowRoot | null;\n    /**\n     * Returns the value of element\'s slot content attribute. Can be set to change it.\n     */\n    slot: string;\n    /**\n     * Returns the HTML-uppercased qualified name.\n     */\n    readonly tagName: string;\n    /**\n     * Creates a shadow root for element and returns it.\n     */\n    attachShadow(init: ShadowRootInit): ShadowRoot;\n    /**\n     * Returns the first (starting at element) inclusive ancestor that matches selectors, and null otherwise.\n     */\n    closest<K extends keyof HTMLElementTagNameMap>(selector: K): HTMLElementTagNameMap[K] | null;\n    closest<K extends keyof SVGElementTagNameMap>(selector: K): SVGElementTagNameMap[K] | null;\n    closest<E extends Element = Element>(selector: string): E | null;\n    /**\n     * Returns element\'s first attribute whose qualified name is qualifiedName, and null if there is no such attribute otherwise.\n     */\n    getAttribute(qualifiedName: string): string | null;\n    /**\n     * Returns element\'s attribute whose namespace is namespace and local name is localName, and null if there is no such attribute otherwise.\n     */\n    getAttributeNS(namespace: string | null, localName: string): string | null;\n    /**\n     * Returns the qualified names of all element\'s attributes. Can contain duplicates.\n     */\n    getAttributeNames(): string[];\n    getAttributeNode(qualifiedName: string): Attr | null;\n    getAttributeNodeNS(namespace: string | null, localName: string): Attr | null;\n    getBoundingClientRect(): DOMRect;\n    getClientRects(): DOMRectList;\n    /**\n     * Returns a HTMLCollection of the elements in the object on which the method was invoked (a document or an element) that have all the classes given by classNames. The classNames argument is interpreted as a space-separated list of classes.\n     */\n    getElementsByClassName(classNames: string): HTMLCollectionOf<Element>;\n    getElementsByTagName<K extends keyof HTMLElementTagNameMap>(qualifiedName: K): HTMLCollectionOf<HTMLElementTagNameMap[K]>;\n    getElementsByTagName<K extends keyof SVGElementTagNameMap>(qualifiedName: K): HTMLCollectionOf<SVGElementTagNameMap[K]>;\n    getElementsByTagName(qualifiedName: string): HTMLCollectionOf<Element>;\n    getElementsByTagNameNS(namespaceURI: "http://www.w3.org/1999/xhtml", localName: string): HTMLCollectionOf<HTMLElement>;\n    getElementsByTagNameNS(namespaceURI: "http://www.w3.org/2000/svg", localName: string): HTMLCollectionOf<SVGElement>;\n    getElementsByTagNameNS(namespaceURI: string, localName: string): HTMLCollectionOf<Element>;\n    /**\n     * Returns true if element has an attribute whose qualified name is qualifiedName, and false otherwise.\n     */\n    hasAttribute(qualifiedName: string): boolean;\n    /**\n     * Returns true if element has an attribute whose namespace is namespace and local name is localName.\n     */\n    hasAttributeNS(namespace: string | null, localName: string): boolean;\n    /**\n     * Returns true if element has attributes, and false otherwise.\n     */\n    hasAttributes(): boolean;\n    hasPointerCapture(pointerId: number): boolean;\n    insertAdjacentElement(position: InsertPosition, insertedElement: Element): Element | null;\n    insertAdjacentHTML(where: InsertPosition, html: string): void;\n    insertAdjacentText(where: InsertPosition, text: string): void;\n    /**\n     * Returns true if matching selectors against element\'s root yields element, and false otherwise.\n     */\n    matches(selectors: string): boolean;\n    msGetRegionContent(): any;\n    releasePointerCapture(pointerId: number): void;\n    /**\n     * Removes element\'s first attribute whose qualified name is qualifiedName.\n     */\n    removeAttribute(qualifiedName: string): void;\n    /**\n     * Removes element\'s attribute whose namespace is namespace and local name is localName.\n     */\n    removeAttributeNS(namespace: string | null, localName: string): void;\n    removeAttributeNode(attr: Attr): Attr;\n    /**\n     * Displays element fullscreen and resolves promise when done.\n     *\n     * When supplied, options\'s navigationUI member indicates whether showing navigation UI while in fullscreen is preferred or not. If set to "show", navigation simplicity is preferred over screen space, and if set to "hide", more screen space is preferred. User agents are always free to honor user preference over the application\'s. The default value "auto" indicates no application preference.\n     */\n    requestFullscreen(options?: FullscreenOptions): Promise<void>;\n    requestPointerLock(): void;\n    scroll(options?: ScrollToOptions): void;\n    scroll(x: number, y: number): void;\n    scrollBy(options?: ScrollToOptions): void;\n    scrollBy(x: number, y: number): void;\n    scrollIntoView(arg?: boolean | ScrollIntoViewOptions): void;\n    scrollTo(options?: ScrollToOptions): void;\n    scrollTo(x: number, y: number): void;\n    /**\n     * Sets the value of element\'s first attribute whose qualified name is qualifiedName to value.\n     */\n    setAttribute(qualifiedName: string, value: string): void;\n    /**\n     * Sets the value of element\'s attribute whose namespace is namespace and local name is localName to value.\n     */\n    setAttributeNS(namespace: string | null, qualifiedName: string, value: string): void;\n    setAttributeNode(attr: Attr): Attr | null;\n    setAttributeNodeNS(attr: Attr): Attr | null;\n    setPointerCapture(pointerId: number): void;\n    /**\n     * If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName. If force is false, removes qualifiedName.\n     *\n     * Returns true if qualifiedName is now present, and false otherwise.\n     */\n    toggleAttribute(qualifiedName: string, force?: boolean): boolean;\n    webkitMatchesSelector(selectors: string): boolean;\n    addEventListener<K extends keyof ElementEventMap>(type: K, listener: (this: Element, ev: ElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof ElementEventMap>(type: K, listener: (this: Element, ev: ElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var Element: {\n    prototype: Element;\n    new(): Element;\n};\n\ninterface ElementCSSInlineStyle {\n    readonly style: CSSStyleDeclaration;\n}\n\ninterface ElementContentEditable {\n    contentEditable: string;\n    enterKeyHint: string;\n    inputMode: string;\n    readonly isContentEditable: boolean;\n}\n\n/** Events providing information related to errors in scripts or in files. */\ninterface ErrorEvent extends Event {\n    readonly colno: number;\n    readonly error: any;\n    readonly filename: string;\n    readonly lineno: number;\n    readonly message: string;\n}\n\ndeclare var ErrorEvent: {\n    prototype: ErrorEvent;\n    new(type: string, eventInitDict?: ErrorEventInit): ErrorEvent;\n};\n\n/** An event which takes place in the DOM. */\ninterface Event {\n    /**\n     * Returns true or false depending on how event was initialized. True if event goes through its target\'s ancestors in reverse tree order, and false otherwise.\n     */\n    readonly bubbles: boolean;\n    cancelBubble: boolean;\n    /**\n     * Returns true or false depending on how event was initialized. Its return value does not always carry meaning, but true can indicate that part of the operation during which event was dispatched, can be canceled by invoking the preventDefault() method.\n     */\n    readonly cancelable: boolean;\n    /**\n     * Returns true or false depending on how event was initialized. True if event invokes listeners past a ShadowRoot node that is the root of its target, and false otherwise.\n     */\n    readonly composed: boolean;\n    /**\n     * Returns the object whose event listener\'s callback is currently being invoked.\n     */\n    readonly currentTarget: EventTarget | null;\n    /**\n     * Returns true if preventDefault() was invoked successfully to indicate cancelation, and false otherwise.\n     */\n    readonly defaultPrevented: boolean;\n    /**\n     * Returns the event\'s phase, which is one of NONE, CAPTURING_PHASE, AT_TARGET, and BUBBLING_PHASE.\n     */\n    readonly eventPhase: number;\n    /**\n     * Returns true if event was dispatched by the user agent, and false otherwise.\n     */\n    readonly isTrusted: boolean;\n    returnValue: boolean;\n    /** @deprecated */\n    readonly srcElement: EventTarget | null;\n    /**\n     * Returns the object to which event is dispatched (its target).\n     */\n    readonly target: EventTarget | null;\n    /**\n     * Returns the event\'s timestamp as the number of milliseconds measured relative to the time origin.\n     */\n    readonly timeStamp: number;\n    /**\n     * Returns the type of event, e.g. "click", "hashchange", or "submit".\n     */\n    readonly type: string;\n    /**\n     * Returns the invocation target objects of event\'s path (objects on which listeners will be invoked), except for any nodes in shadow trees of which the shadow root\'s mode is "closed" that are not reachable from event\'s currentTarget.\n     */\n    composedPath(): EventTarget[];\n    initEvent(type: string, bubbles?: boolean, cancelable?: boolean): void;\n    /**\n     * If invoked when the cancelable attribute value is true, and while executing a listener for the event with passive set to false, signals to the operation that caused event to be dispatched that it needs to be canceled.\n     */\n    preventDefault(): void;\n    /**\n     * Invoking this method prevents event from reaching any registered event listeners after the current one finishes running and, when dispatched in a tree, also prevents event from reaching any other objects.\n     */\n    stopImmediatePropagation(): void;\n    /**\n     * When dispatched in a tree, invoking this method prevents event from reaching any objects other than the current object.\n     */\n    stopPropagation(): void;\n    readonly AT_TARGET: number;\n    readonly BUBBLING_PHASE: number;\n    readonly CAPTURING_PHASE: number;\n    readonly NONE: number;\n}\n\ndeclare var Event: {\n    prototype: Event;\n    new(type: string, eventInitDict?: EventInit): Event;\n    readonly AT_TARGET: number;\n    readonly BUBBLING_PHASE: number;\n    readonly CAPTURING_PHASE: number;\n    readonly NONE: number;\n};\n\ninterface EventListenerObject {\n    handleEvent(evt: Event): void;\n}\n\ninterface EventSourceEventMap {\n    "error": Event;\n    "message": MessageEvent;\n    "open": Event;\n}\n\ninterface EventSource extends EventTarget {\n    onerror: ((this: EventSource, ev: Event) => any) | null;\n    onmessage: ((this: EventSource, ev: MessageEvent) => any) | null;\n    onopen: ((this: EventSource, ev: Event) => any) | null;\n    /**\n     * Returns the state of this EventSource object\'s connection. It can have the values described below.\n     */\n    readonly readyState: number;\n    /**\n     * Returns the URL providing the event stream.\n     */\n    readonly url: string;\n    /**\n     * Returns true if the credentials mode for connection requests to the URL providing the event stream is set to "include", and false otherwise.\n     */\n    readonly withCredentials: boolean;\n    /**\n     * Aborts any instances of the fetch algorithm started for this EventSource object, and sets the readyState attribute to CLOSED.\n     */\n    close(): void;\n    readonly CLOSED: number;\n    readonly CONNECTING: number;\n    readonly OPEN: number;\n    addEventListener<K extends keyof EventSourceEventMap>(type: K, listener: (this: EventSource, ev: EventSourceEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof EventSourceEventMap>(type: K, listener: (this: EventSource, ev: EventSourceEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var EventSource: {\n    prototype: EventSource;\n    new(url: string, eventSourceInitDict?: EventSourceInit): EventSource;\n    readonly CLOSED: number;\n    readonly CONNECTING: number;\n    readonly OPEN: number;\n};\n\n/** EventTarget is a DOM interface implemented by objects that can receive events and may have listeners for them. */\ninterface EventTarget {\n    /**\n     * Appends an event listener for events whose type attribute value is type. The callback argument sets the callback that will be invoked when the event is dispatched.\n     *\n     * The options argument sets listener-specific options. For compatibility this can be a boolean, in which case the method behaves exactly as if the value was specified as options\'s capture.\n     *\n     * When set to true, options\'s capture prevents callback from being invoked when the event\'s eventPhase attribute value is BUBBLING_PHASE. When false (or not present), callback will not be invoked when event\'s eventPhase attribute value is CAPTURING_PHASE. Either way, callback will be invoked if event\'s eventPhase attribute value is AT_TARGET.\n     *\n     * When set to true, options\'s passive indicates that the callback will not cancel the event by invoking preventDefault(). This is used to enable performance optimizations described in § 2.8 Observing event listeners.\n     *\n     * When set to true, options\'s once indicates that the callback will only be invoked once after which the event listener will be removed.\n     *\n     * The event listener is appended to target\'s event listener list and is not appended if it has the same type, callback, and capture.\n     */\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject | null, options?: boolean | AddEventListenerOptions): void;\n    /**\n     * Dispatches a synthetic event event to target and returns true if either event\'s cancelable attribute value is false or its preventDefault() method was not invoked, and false otherwise.\n     */\n    dispatchEvent(event: Event): boolean;\n    /**\n     * Removes the event listener in target\'s event listener list with the same type, callback, and options.\n     */\n    removeEventListener(type: string, callback: EventListenerOrEventListenerObject | null, options?: EventListenerOptions | boolean): void;\n}\n\ndeclare var EventTarget: {\n    prototype: EventTarget;\n    new(): EventTarget;\n};\n\ninterface ExtensionScriptApis {\n    extensionIdToShortId(extensionId: string): number;\n    fireExtensionApiTelemetry(functionName: string, isSucceeded: boolean, isSupported: boolean, errorString: string): void;\n    genericFunction(routerAddress: any, parameters?: string, callbackId?: number): void;\n    genericSynchronousFunction(functionId: number, parameters?: string): string;\n    genericWebRuntimeCallout(to: any, from: any, payload: string): void;\n    getExtensionId(): string;\n    registerGenericFunctionCallbackHandler(callbackHandler: Function): void;\n    registerGenericPersistentCallbackHandler(callbackHandler: Function): void;\n    registerWebRuntimeCallbackHandler(handler: Function): any;\n}\n\ndeclare var ExtensionScriptApis: {\n    prototype: ExtensionScriptApis;\n    new(): ExtensionScriptApis;\n};\n\ninterface External {\n    /** @deprecated */\n    AddSearchProvider(): void;\n    /** @deprecated */\n    IsSearchProviderInstalled(): void;\n}\n\ndeclare var External: {\n    prototype: External;\n    new(): External;\n};\n\n/** Provides information about files and allows JavaScript in a web page to access their content. */\ninterface File extends Blob {\n    readonly lastModified: number;\n    readonly name: string;\n}\n\ndeclare var File: {\n    prototype: File;\n    new(fileBits: BlobPart[], fileName: string, options?: FilePropertyBag): File;\n};\n\n/** An object of this type is returned by the files property of the HTML <input> element; this lets you access the list of files selected with the <input type="file"> element. It\'s also used for a list of files dropped into web content when using the drag and drop API; see the DataTransfer object for details on this usage. */\ninterface FileList {\n    readonly length: number;\n    item(index: number): File | null;\n    [index: number]: File;\n}\n\ndeclare var FileList: {\n    prototype: FileList;\n    new(): FileList;\n};\n\ninterface FileReaderEventMap {\n    "abort": ProgressEvent<FileReader>;\n    "error": ProgressEvent<FileReader>;\n    "load": ProgressEvent<FileReader>;\n    "loadend": ProgressEvent<FileReader>;\n    "loadstart": ProgressEvent<FileReader>;\n    "progress": ProgressEvent<FileReader>;\n}\n\n/** Lets web applications asynchronously read the contents of files (or raw data buffers) stored on the user\'s computer, using File or Blob objects to specify the file or data to read. */\ninterface FileReader extends EventTarget {\n    readonly error: DOMException | null;\n    onabort: ((this: FileReader, ev: ProgressEvent<FileReader>) => any) | null;\n    onerror: ((this: FileReader, ev: ProgressEvent<FileReader>) => any) | null;\n    onload: ((this: FileReader, ev: ProgressEvent<FileReader>) => any) | null;\n    onloadend: ((this: FileReader, ev: ProgressEvent<FileReader>) => any) | null;\n    onloadstart: ((this: FileReader, ev: ProgressEvent<FileReader>) => any) | null;\n    onprogress: ((this: FileReader, ev: ProgressEvent<FileReader>) => any) | null;\n    readonly readyState: number;\n    readonly result: string | ArrayBuffer | null;\n    abort(): void;\n    readAsArrayBuffer(blob: Blob): void;\n    readAsBinaryString(blob: Blob): void;\n    readAsDataURL(blob: Blob): void;\n    readAsText(blob: Blob, encoding?: string): void;\n    readonly DONE: number;\n    readonly EMPTY: number;\n    readonly LOADING: number;\n    addEventListener<K extends keyof FileReaderEventMap>(type: K, listener: (this: FileReader, ev: FileReaderEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof FileReaderEventMap>(type: K, listener: (this: FileReader, ev: FileReaderEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var FileReader: {\n    prototype: FileReader;\n    new(): FileReader;\n    readonly DONE: number;\n    readonly EMPTY: number;\n    readonly LOADING: number;\n};\n\n/** Focus-related events like focus, blur, focusin, or focusout. */\ninterface FocusEvent extends UIEvent {\n    readonly relatedTarget: EventTarget | null;\n}\n\ndeclare var FocusEvent: {\n    prototype: FocusEvent;\n    new(type: string, eventInitDict?: FocusEventInit): FocusEvent;\n};\n\ninterface FocusNavigationEvent extends Event {\n    readonly navigationReason: NavigationReason;\n    readonly originHeight: number;\n    readonly originLeft: number;\n    readonly originTop: number;\n    readonly originWidth: number;\n    requestFocus(): void;\n}\n\ndeclare var FocusNavigationEvent: {\n    prototype: FocusNavigationEvent;\n    new(type: string, eventInitDict?: FocusNavigationEventInit): FocusNavigationEvent;\n};\n\n/** Provides a way to easily construct a set of key/value pairs representing form fields and their values, which can then be easily sent using the XMLHttpRequest.send() method. It uses the same format a form would use if the encoding type were set to "multipart/form-data". */\ninterface FormData {\n    append(name: string, value: string | Blob, fileName?: string): void;\n    delete(name: string): void;\n    get(name: string): FormDataEntryValue | null;\n    getAll(name: string): FormDataEntryValue[];\n    has(name: string): boolean;\n    set(name: string, value: string | Blob, fileName?: string): void;\n    forEach(callbackfn: (value: FormDataEntryValue, key: string, parent: FormData) => void, thisArg?: any): void;\n}\n\ndeclare var FormData: {\n    prototype: FormData;\n    new(form?: HTMLFormElement): FormData;\n};\n\n/** A change in volume. It is an AudioNode audio-processing module that causes a given gain to be applied to the input data before its propagation to the output. A GainNode always has exactly one input and one output, both with the same number of channels. */\ninterface GainNode extends AudioNode {\n    readonly gain: AudioParam;\n}\n\ndeclare var GainNode: {\n    prototype: GainNode;\n    new(context: BaseAudioContext, options?: GainOptions): GainNode;\n};\n\n/** This Gamepad API interface defines an individual gamepad or other controller, allowing access to information such as button presses, axis positions, and id. */\ninterface Gamepad {\n    readonly axes: ReadonlyArray<number>;\n    readonly buttons: ReadonlyArray<GamepadButton>;\n    readonly connected: boolean;\n    readonly hand: GamepadHand;\n    readonly hapticActuators: ReadonlyArray<GamepadHapticActuator>;\n    readonly id: string;\n    readonly index: number;\n    readonly mapping: GamepadMappingType;\n    readonly pose: GamepadPose | null;\n    readonly timestamp: number;\n}\n\ndeclare var Gamepad: {\n    prototype: Gamepad;\n    new(): Gamepad;\n};\n\n/** An individual button of a gamepad or other controller, allowing access to the current state of different types of buttons available on the control device. */\ninterface GamepadButton {\n    readonly pressed: boolean;\n    readonly touched: boolean;\n    readonly value: number;\n}\n\ndeclare var GamepadButton: {\n    prototype: GamepadButton;\n    new(): GamepadButton;\n};\n\n/** This Gamepad API interface contains references to gamepads connected to the system, which is what the gamepad events Window.gamepadconnected and Window.gamepaddisconnected are fired in response to. */\ninterface GamepadEvent extends Event {\n    readonly gamepad: Gamepad;\n}\n\ndeclare var GamepadEvent: {\n    prototype: GamepadEvent;\n    new(type: string, eventInitDict: GamepadEventInit): GamepadEvent;\n};\n\n/** This Gamepad API interface represents hardware in the controller designed to provide haptic feedback to the user (if available), most commonly vibration hardware. */\ninterface GamepadHapticActuator {\n    readonly type: GamepadHapticActuatorType;\n    pulse(value: number, duration: number): Promise<boolean>;\n}\n\ndeclare var GamepadHapticActuator: {\n    prototype: GamepadHapticActuator;\n    new(): GamepadHapticActuator;\n};\n\n/** This Gamepad API interface represents the pose of a WebVR controller at a given timestamp (which includes orientation, position, velocity, and acceleration information.) */\ninterface GamepadPose {\n    readonly angularAcceleration: Float32Array | null;\n    readonly angularVelocity: Float32Array | null;\n    readonly hasOrientation: boolean;\n    readonly hasPosition: boolean;\n    readonly linearAcceleration: Float32Array | null;\n    readonly linearVelocity: Float32Array | null;\n    readonly orientation: Float32Array | null;\n    readonly position: Float32Array | null;\n}\n\ndeclare var GamepadPose: {\n    prototype: GamepadPose;\n    new(): GamepadPose;\n};\n\ninterface GenericTransformStream {\n    readonly readable: ReadableStream;\n    readonly writable: WritableStream;\n}\n\n/** An object able to programmatically obtain the position of the device. It gives Web content access to the location of the device. This allows a Web site or app to offer customized results based on the user\'s location. */\ninterface Geolocation {\n    clearWatch(watchId: number): void;\n    getCurrentPosition(successCallback: PositionCallback, errorCallback?: PositionErrorCallback, options?: PositionOptions): void;\n    watchPosition(successCallback: PositionCallback, errorCallback?: PositionErrorCallback, options?: PositionOptions): number;\n}\n\ndeclare var Geolocation: {\n    prototype: Geolocation;\n    new(): Geolocation;\n};\n\ninterface GeolocationCoordinates {\n    readonly accuracy: number;\n    readonly altitude: number | null;\n    readonly altitudeAccuracy: number | null;\n    readonly heading: number | null;\n    readonly latitude: number;\n    readonly longitude: number;\n    readonly speed: number | null;\n}\n\ndeclare var GeolocationCoordinates: {\n    prototype: GeolocationCoordinates;\n    new(): GeolocationCoordinates;\n};\n\ninterface GeolocationPosition {\n    readonly coords: GeolocationCoordinates;\n    readonly timestamp: number;\n}\n\ndeclare var GeolocationPosition: {\n    prototype: GeolocationPosition;\n    new(): GeolocationPosition;\n};\n\ninterface GeolocationPositionError {\n    readonly code: number;\n    readonly message: string;\n    readonly PERMISSION_DENIED: number;\n    readonly POSITION_UNAVAILABLE: number;\n    readonly TIMEOUT: number;\n}\n\ndeclare var GeolocationPositionError: {\n    prototype: GeolocationPositionError;\n    new(): GeolocationPositionError;\n    readonly PERMISSION_DENIED: number;\n    readonly POSITION_UNAVAILABLE: number;\n    readonly TIMEOUT: number;\n};\n\ninterface GlobalEventHandlersEventMap {\n    "abort": UIEvent;\n    "animationcancel": AnimationEvent;\n    "animationend": AnimationEvent;\n    "animationiteration": AnimationEvent;\n    "animationstart": AnimationEvent;\n    "auxclick": MouseEvent;\n    "beforeinput": InputEvent;\n    "blur": FocusEvent;\n    "cancel": Event;\n    "canplay": Event;\n    "canplaythrough": Event;\n    "change": Event;\n    "click": MouseEvent;\n    "close": Event;\n    "compositionend": CompositionEvent;\n    "compositionstart": CompositionEvent;\n    "compositionupdate": CompositionEvent;\n    "contextmenu": MouseEvent;\n    "cuechange": Event;\n    "dblclick": MouseEvent;\n    "drag": DragEvent;\n    "dragend": DragEvent;\n    "dragenter": DragEvent;\n    "dragexit": Event;\n    "dragleave": DragEvent;\n    "dragover": DragEvent;\n    "dragstart": DragEvent;\n    "drop": DragEvent;\n    "durationchange": Event;\n    "emptied": Event;\n    "ended": Event;\n    "error": ErrorEvent;\n    "focus": FocusEvent;\n    "focusin": FocusEvent;\n    "focusout": FocusEvent;\n    "gotpointercapture": PointerEvent;\n    "input": Event;\n    "invalid": Event;\n    "keydown": KeyboardEvent;\n    "keypress": KeyboardEvent;\n    "keyup": KeyboardEvent;\n    "load": Event;\n    "loadeddata": Event;\n    "loadedmetadata": Event;\n    "loadstart": Event;\n    "lostpointercapture": PointerEvent;\n    "mousedown": MouseEvent;\n    "mouseenter": MouseEvent;\n    "mouseleave": MouseEvent;\n    "mousemove": MouseEvent;\n    "mouseout": MouseEvent;\n    "mouseover": MouseEvent;\n    "mouseup": MouseEvent;\n    "pause": Event;\n    "play": Event;\n    "playing": Event;\n    "pointercancel": PointerEvent;\n    "pointerdown": PointerEvent;\n    "pointerenter": PointerEvent;\n    "pointerleave": PointerEvent;\n    "pointermove": PointerEvent;\n    "pointerout": PointerEvent;\n    "pointerover": PointerEvent;\n    "pointerup": PointerEvent;\n    "progress": ProgressEvent;\n    "ratechange": Event;\n    "reset": Event;\n    "resize": UIEvent;\n    "scroll": Event;\n    "securitypolicyviolation": SecurityPolicyViolationEvent;\n    "seeked": Event;\n    "seeking": Event;\n    "select": Event;\n    "selectionchange": Event;\n    "selectstart": Event;\n    "stalled": Event;\n    "submit": Event;\n    "suspend": Event;\n    "timeupdate": Event;\n    "toggle": Event;\n    "touchcancel": TouchEvent;\n    "touchend": TouchEvent;\n    "touchmove": TouchEvent;\n    "touchstart": TouchEvent;\n    "transitioncancel": TransitionEvent;\n    "transitionend": TransitionEvent;\n    "transitionrun": TransitionEvent;\n    "transitionstart": TransitionEvent;\n    "volumechange": Event;\n    "waiting": Event;\n    "wheel": WheelEvent;\n}\n\ninterface GlobalEventHandlers {\n    /**\n     * Fires when the user aborts the download.\n     * @param ev The event.\n     */\n    onabort: ((this: GlobalEventHandlers, ev: UIEvent) => any) | null;\n    onanimationcancel: ((this: GlobalEventHandlers, ev: AnimationEvent) => any) | null;\n    onanimationend: ((this: GlobalEventHandlers, ev: AnimationEvent) => any) | null;\n    onanimationiteration: ((this: GlobalEventHandlers, ev: AnimationEvent) => any) | null;\n    onanimationstart: ((this: GlobalEventHandlers, ev: AnimationEvent) => any) | null;\n    onauxclick: ((this: GlobalEventHandlers, ev: MouseEvent) => any) | null;\n    /**\n     * Fires when the object loses the input focus.\n     * @param ev The focus event.\n     */\n    onblur: ((this: GlobalEventHandlers, ev: FocusEvent) => any) | null;\n    oncancel: ((this: GlobalEventHandlers, ev: Event) => any) | null;\n    /**\n     * Occurs when playback is possible, but would require further buffering.\n     * @param ev The event.\n     */\n    oncanplay: ((this: GlobalEventHandlers, ev: Event) => any) | null;\n    oncanplaythrough: ((this: GlobalEventHandlers, ev: Event) => any) | null;\n    /**\n     * Fires when the contents of the object or selection have changed.\n     * @param ev The event.\n     */\n    onchange: ((this: GlobalEventHandlers, ev: Event) => any) | null;\n    /**\n     * Fires when the user clicks the left mouse button on the object\n     * @param ev The mouse event.\n     */\n    onclick: ((this: GlobalEventHandlers, ev: MouseEvent) => any) | null;\n    onclose: ((this: GlobalEventHandlers, ev: Event) => any) | null;\n    /**\n     * Fires when the user clicks the right mouse button in the client area, opening the context menu.\n     * @param ev The mouse event.\n     */\n    oncontextmenu: ((this: GlobalEventHandlers, ev: MouseEvent) => any) | null;\n    oncuechange: ((this: GlobalEventHandlers, ev: Event) => any) | null;\n    /**\n     * Fires when the user double-clicks the object.\n     * @param ev The mouse event.\n     */\n    ondblclick: ((this: GlobalEventHandlers, ev: MouseEvent) => any) | null;\n    /**\n     * Fires on the source object continuously during a drag operation.\n     * @param ev The event.\n     */\n    ondrag: ((this: GlobalEventHandlers, ev: DragEvent) => any) | null;\n    /**\n     * Fires on the source object when the user releases the mouse at the close of a drag operation.\n     * @param ev The event.\n     */\n    ondragend: ((this: GlobalEventHandlers, ev: DragEvent) => any) | null;\n    /**\n     * Fires on the target element when the user drags the object to a valid drop target.\n     * @param ev The drag event.\n     */\n    ondragenter: ((this: GlobalEventHandlers, ev: DragEvent) => any) | null;\n    ondragexit: ((this: GlobalEventHandlers, ev: Event) => any) | null;\n    /**\n     * Fires on the target object when the user moves the mouse out of a valid drop target during a drag operation.\n     * @param ev The drag event.\n     */\n    ondragleave: ((this: GlobalEventHandlers, ev: DragEvent) => any) | null;\n    /**\n     * Fires on the target element continuously while the user drags the object over a valid drop target.\n     * @param ev The event.\n     */\n    ondragover: ((this: GlobalEventHandlers, ev: DragEvent) => any) | null;\n    /**\n     * Fires on the source object when the user starts to drag a text selection or selected object.\n     * @param ev The event.\n     */\n    ondragstart: ((this: GlobalEventHandlers, ev: DragEvent) => any) | null;\n    ondrop: ((this: GlobalEventHandlers, ev: DragEvent) => any) | null;\n    /**\n     * Occurs when the duration attribute is updated.\n     * @param ev The event.\n     */\n    ondurationchange: ((this: GlobalEventHandlers, ev: Event) => any) | null;\n    /**\n     * Occurs when the media element is reset to its initial state.\n     * @param ev The event.\n     */\n    onemptied: ((this: GlobalEventHandlers, ev: Event) => any) | null;\n    /**\n     * Occurs when the end of playback is reached.\n     * @param ev The event\n     */\n    onended: ((this: GlobalEventHandlers, ev: Event) => any) | null;\n    /**\n     * Fires when an error occurs during object loading.\n     * @param ev The event.\n     */\n    onerror: OnErrorEventHandler;\n    /**\n     * Fires when the object receives focus.\n     * @param ev The event.\n     */\n    onfocus: ((this: GlobalEventHandlers, ev: FocusEvent) => any) | null;\n    ongotpointercapture: ((this: GlobalEventHandlers, ev: PointerEvent) => any) | null;\n    oninput: ((this: GlobalEventHandlers, ev: Event) => any) | null;\n    oninvalid: ((this: GlobalEventHandlers, ev: Event) => any) | null;\n    /**\n     * Fires when the user presses a key.\n     * @param ev The keyboard event\n     */\n    onkeydown: ((this: GlobalEventHandlers, ev: KeyboardEvent) => any) | null;\n    /**\n     * Fires when the user presses an alphanumeric key.\n     * @param ev The event.\n     */\n    onkeypress: ((this: GlobalEventHandlers, ev: KeyboardEvent) => any) | null;\n    /**\n     * Fires when the user releases a key.\n     * @param ev The keyboard event\n     */\n    onkeyup: ((this: GlobalEventHandlers, ev: KeyboardEvent) => any) | null;\n    /**\n     * Fires immediately after the browser loads the object.\n     * @param ev The event.\n     */\n    onload: ((this: GlobalEventHandlers, ev: Event) => any) | null;\n    /**\n     * Occurs when media data is loaded at the current playback position.\n     * @param ev The event.\n     */\n    onloadeddata: ((this: GlobalEventHandlers, ev: Event) => any) | null;\n    /**\n     * Occurs when the duration and dimensions of the media have been determined.\n     * @param ev The event.\n     */\n    onloadedmetadata: ((this: GlobalEventHandlers, ev: Event) => any) | null;\n    /**\n     * Occurs when Internet Explorer begins looking for media data.\n     * @param ev The event.\n     */\n    onloadstart: ((this: GlobalEventHandlers, ev: Event) => any) | null;\n    onlostpointercapture: ((this: GlobalEventHandlers, ev: PointerEvent) => any) | null;\n    /**\n     * Fires when the user clicks the object with either mouse button.\n     * @param ev The mouse event.\n     */\n    onmousedown: ((this: GlobalEventHandlers, ev: MouseEvent) => any) | null;\n    onmouseenter: ((this: GlobalEventHandlers, ev: MouseEvent) => any) | null;\n    onmouseleave: ((this: GlobalEventHandlers, ev: MouseEvent) => any) | null;\n    /**\n     * Fires when the user moves the mouse over the object.\n     * @param ev The mouse event.\n     */\n    onmousemove: ((this: GlobalEventHandlers, ev: MouseEvent) => any) | null;\n    /**\n     * Fires when the user moves the mouse pointer outside the boundaries of the object.\n     * @param ev The mouse event.\n     */\n    onmouseout: ((this: GlobalEventHandlers, ev: MouseEvent) => any) | null;\n    /**\n     * Fires when the user moves the mouse pointer into the object.\n     * @param ev The mouse event.\n     */\n    onmouseover: ((this: GlobalEventHandlers, ev: MouseEvent) => any) | null;\n    /**\n     * Fires when the user releases a mouse button while the mouse is over the object.\n     * @param ev The mouse event.\n     */\n    onmouseup: ((this: GlobalEventHandlers, ev: MouseEvent) => any) | null;\n    /**\n     * Occurs when playback is paused.\n     * @param ev The event.\n     */\n    onpause: ((this: GlobalEventHandlers, ev: Event) => any) | null;\n    /**\n     * Occurs when the play method is requested.\n     * @param ev The event.\n     */\n    onplay: ((this: GlobalEventHandlers, ev: Event) => any) | null;\n    /**\n     * Occurs when the audio or video has started playing.\n     * @param ev The event.\n     */\n    onplaying: ((this: GlobalEventHandlers, ev: Event) => any) | null;\n    onpointercancel: ((this: GlobalEventHandlers, ev: PointerEvent) => any) | null;\n    onpointerdown: ((this: GlobalEventHandlers, ev: PointerEvent) => any) | null;\n    onpointerenter: ((this: GlobalEventHandlers, ev: PointerEvent) => any) | null;\n    onpointerleave: ((this: GlobalEventHandlers, ev: PointerEvent) => any) | null;\n    onpointermove: ((this: GlobalEventHandlers, ev: PointerEvent) => any) | null;\n    onpointerout: ((this: GlobalEventHandlers, ev: PointerEvent) => any) | null;\n    onpointerover: ((this: GlobalEventHandlers, ev: PointerEvent) => any) | null;\n    onpointerup: ((this: GlobalEventHandlers, ev: PointerEvent) => any) | null;\n    /**\n     * Occurs to indicate progress while downloading media data.\n     * @param ev The event.\n     */\n    onprogress: ((this: GlobalEventHandlers, ev: ProgressEvent) => any) | null;\n    /**\n     * Occurs when the playback rate is increased or decreased.\n     * @param ev The event.\n     */\n    onratechange: ((this: GlobalEventHandlers, ev: Event) => any) | null;\n    /**\n     * Fires when the user resets a form.\n     * @param ev The event.\n     */\n    onreset: ((this: GlobalEventHandlers, ev: Event) => any) | null;\n    onresize: ((this: GlobalEventHandlers, ev: UIEvent) => any) | null;\n    /**\n     * Fires when the user repositions the scroll box in the scroll bar on the object.\n     * @param ev The event.\n     */\n    onscroll: ((this: GlobalEventHandlers, ev: Event) => any) | null;\n    onsecuritypolicyviolation: ((this: GlobalEventHandlers, ev: SecurityPolicyViolationEvent) => any) | null;\n    /**\n     * Occurs when the seek operation ends.\n     * @param ev The event.\n     */\n    onseeked: ((this: GlobalEventHandlers, ev: Event) => any) | null;\n    /**\n     * Occurs when the current playback position is moved.\n     * @param ev The event.\n     */\n    onseeking: ((this: GlobalEventHandlers, ev: Event) => any) | null;\n    /**\n     * Fires when the current selection changes.\n     * @param ev The event.\n     */\n    onselect: ((this: GlobalEventHandlers, ev: Event) => any) | null;\n    onselectionchange: ((this: GlobalEventHandlers, ev: Event) => any) | null;\n    onselectstart: ((this: GlobalEventHandlers, ev: Event) => any) | null;\n    /**\n     * Occurs when the download has stopped.\n     * @param ev The event.\n     */\n    onstalled: ((this: GlobalEventHandlers, ev: Event) => any) | null;\n    onsubmit: ((this: GlobalEventHandlers, ev: Event) => any) | null;\n    /**\n     * Occurs if the load operation has been intentionally halted.\n     * @param ev The event.\n     */\n    onsuspend: ((this: GlobalEventHandlers, ev: Event) => any) | null;\n    /**\n     * Occurs to indicate the current playback position.\n     * @param ev The event.\n     */\n    ontimeupdate: ((this: GlobalEventHandlers, ev: Event) => any) | null;\n    ontoggle: ((this: GlobalEventHandlers, ev: Event) => any) | null;\n    ontouchcancel?: ((this: GlobalEventHandlers, ev: TouchEvent) => any) | null;\n    ontouchend?: ((this: GlobalEventHandlers, ev: TouchEvent) => any) | null;\n    ontouchmove?: ((this: GlobalEventHandlers, ev: TouchEvent) => any) | null;\n    ontouchstart?: ((this: GlobalEventHandlers, ev: TouchEvent) => any) | null;\n    ontransitioncancel: ((this: GlobalEventHandlers, ev: TransitionEvent) => any) | null;\n    ontransitionend: ((this: GlobalEventHandlers, ev: TransitionEvent) => any) | null;\n    ontransitionrun: ((this: GlobalEventHandlers, ev: TransitionEvent) => any) | null;\n    ontransitionstart: ((this: GlobalEventHandlers, ev: TransitionEvent) => any) | null;\n    /**\n     * Occurs when the volume is changed, or playback is muted or unmuted.\n     * @param ev The event.\n     */\n    onvolumechange: ((this: GlobalEventHandlers, ev: Event) => any) | null;\n    /**\n     * Occurs when playback stops because the next frame of a video resource is not available.\n     * @param ev The event.\n     */\n    onwaiting: ((this: GlobalEventHandlers, ev: Event) => any) | null;\n    onwheel: ((this: GlobalEventHandlers, ev: WheelEvent) => any) | null;\n    addEventListener<K extends keyof GlobalEventHandlersEventMap>(type: K, listener: (this: GlobalEventHandlers, ev: GlobalEventHandlersEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof GlobalEventHandlersEventMap>(type: K, listener: (this: GlobalEventHandlers, ev: GlobalEventHandlersEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ninterface HTMLAllCollection {\n    /**\n     * Returns the number of elements in the collection.\n     */\n    readonly length: number;\n    /**\n     * Returns the item with index index from the collection (determined by tree order).\n     */\n    item(nameOrIndex?: string): HTMLCollection | Element | null;\n    /**\n     * Returns the item with ID or name name from the collection.\n     *\n     * If there are multiple matching items, then an HTMLCollection object containing all those elements is returned.\n     *\n     * Only button, form, iframe, input, map, meta, object, select, and textarea elements can have a name for the purpose of this method; their name is given by the value of their name attribute.\n     */\n    namedItem(name: string): HTMLCollection | Element | null;\n    [index: number]: Element;\n}\n\ndeclare var HTMLAllCollection: {\n    prototype: HTMLAllCollection;\n    new(): HTMLAllCollection;\n};\n\n/** Hyperlink elements and provides special properties and methods (beyond those of the regular HTMLElement object interface that they inherit from) for manipulating the layout and presentation of such elements. */\ninterface HTMLAnchorElement extends HTMLElement, HTMLHyperlinkElementUtils {\n    /**\n     * Sets or retrieves the character set used to encode the object.\n     */\n    /** @deprecated */\n    charset: string;\n    /**\n     * Sets or retrieves the coordinates of the object.\n     */\n    /** @deprecated */\n    coords: string;\n    download: string;\n    /**\n     * Sets or retrieves the language code of the object.\n     */\n    hreflang: string;\n    /**\n     * Sets or retrieves the shape of the object.\n     */\n    /** @deprecated */\n    name: string;\n    ping: string;\n    referrerPolicy: string;\n    /**\n     * Sets or retrieves the relationship between the object and the destination of the link.\n     */\n    rel: string;\n    readonly relList: DOMTokenList;\n    /**\n     * Sets or retrieves the relationship between the object and the destination of the link.\n     */\n    /** @deprecated */\n    rev: string;\n    /**\n     * Sets or retrieves the shape of the object.\n     */\n    /** @deprecated */\n    shape: string;\n    /**\n     * Sets or retrieves the window or frame at which to target content.\n     */\n    target: string;\n    /**\n     * Retrieves or sets the text of the object as a string.\n     */\n    text: string;\n    type: string;\n    addEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLAnchorElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLAnchorElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLAnchorElement: {\n    prototype: HTMLAnchorElement;\n    new(): HTMLAnchorElement;\n};\n\ninterface HTMLAppletElement extends HTMLElement {\n    /** @deprecated */\n    align: string;\n    /**\n     * Sets or retrieves a text alternative to the graphic.\n     */\n    /** @deprecated */\n    alt: string;\n    /**\n     * Sets or retrieves a character string that can be used to implement your own archive functionality for the object.\n     */\n    /** @deprecated */\n    archive: string;\n    /** @deprecated */\n    code: string;\n    /**\n     * Sets or retrieves the URL of the component.\n     */\n    /** @deprecated */\n    codeBase: string;\n    readonly form: HTMLFormElement | null;\n    /**\n     * Sets or retrieves the height of the object.\n     */\n    /** @deprecated */\n    height: string;\n    /** @deprecated */\n    hspace: number;\n    /**\n     * Sets or retrieves the shape of the object.\n     */\n    /** @deprecated */\n    name: string;\n    /** @deprecated */\n    object: string;\n    /** @deprecated */\n    vspace: number;\n    /** @deprecated */\n    width: string;\n    addEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLAppletElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLAppletElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLAppletElement: {\n    prototype: HTMLAppletElement;\n    new(): HTMLAppletElement;\n};\n\n/** Provides special properties and methods (beyond those of the regular object HTMLElement interface it also has available to it by inheritance) for manipulating the layout and presentation of <area> elements. */\ninterface HTMLAreaElement extends HTMLElement, HTMLHyperlinkElementUtils {\n    /**\n     * Sets or retrieves a text alternative to the graphic.\n     */\n    alt: string;\n    /**\n     * Sets or retrieves the coordinates of the object.\n     */\n    coords: string;\n    download: string;\n    /**\n     * Sets or gets whether clicks in this region cause action.\n     */\n    /** @deprecated */\n    noHref: boolean;\n    ping: string;\n    referrerPolicy: string;\n    rel: string;\n    readonly relList: DOMTokenList;\n    /**\n     * Sets or retrieves the shape of the object.\n     */\n    shape: string;\n    /**\n     * Sets or retrieves the window or frame at which to target content.\n     */\n    target: string;\n    addEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLAreaElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLAreaElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLAreaElement: {\n    prototype: HTMLAreaElement;\n    new(): HTMLAreaElement;\n};\n\n/** Provides access to the properties of <audio> elements, as well as methods to manipulate them. It derives from the HTMLMediaElement interface. */\ninterface HTMLAudioElement extends HTMLMediaElement {\n    addEventListener<K extends keyof HTMLMediaElementEventMap>(type: K, listener: (this: HTMLAudioElement, ev: HTMLMediaElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLMediaElementEventMap>(type: K, listener: (this: HTMLAudioElement, ev: HTMLMediaElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLAudioElement: {\n    prototype: HTMLAudioElement;\n    new(): HTMLAudioElement;\n};\n\n/** A HTML line break element (<br>). It inherits from HTMLElement. */\ninterface HTMLBRElement extends HTMLElement {\n    /**\n     * Sets or retrieves the side on which floating objects are not to be positioned when any IHTMLBlockElement is inserted into the document.\n     */\n    /** @deprecated */\n    clear: string;\n    addEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLBRElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLBRElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLBRElement: {\n    prototype: HTMLBRElement;\n    new(): HTMLBRElement;\n};\n\n/** Contains the base URI for a document. This object inherits all of the properties and methods as described in the HTMLElement interface. */\ninterface HTMLBaseElement extends HTMLElement {\n    /**\n     * Gets or sets the baseline URL on which relative links are based.\n     */\n    href: string;\n    /**\n     * Sets or retrieves the window or frame at which to target content.\n     */\n    target: string;\n    addEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLBaseElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLBaseElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLBaseElement: {\n    prototype: HTMLBaseElement;\n    new(): HTMLBaseElement;\n};\n\ninterface HTMLBodyElementEventMap extends HTMLElementEventMap, WindowEventHandlersEventMap {\n    "orientationchange": Event;\n}\n\n/** Provides special properties (beyond those inherited from the regular HTMLElement interface) for manipulating <body> elements. */\ninterface HTMLBodyElement extends HTMLElement, WindowEventHandlers {\n    /** @deprecated */\n    aLink: string;\n    /** @deprecated */\n    background: string;\n    /** @deprecated */\n    bgColor: string;\n    /** @deprecated */\n    link: string;\n    /** @deprecated */\n    onorientationchange: ((this: HTMLBodyElement, ev: Event) => any) | null;\n    /** @deprecated */\n    text: string;\n    /** @deprecated */\n    vLink: string;\n    addEventListener<K extends keyof HTMLBodyElementEventMap>(type: K, listener: (this: HTMLBodyElement, ev: HTMLBodyElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLBodyElementEventMap>(type: K, listener: (this: HTMLBodyElement, ev: HTMLBodyElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLBodyElement: {\n    prototype: HTMLBodyElement;\n    new(): HTMLBodyElement;\n};\n\n/** Provides properties and methods (beyond the regular HTMLElement interface it also has available to it by inheritance) for manipulating <button> elements. */\ninterface HTMLButtonElement extends HTMLElement {\n    disabled: boolean;\n    /**\n     * Retrieves a reference to the form that the object is embedded in.\n     */\n    readonly form: HTMLFormElement | null;\n    /**\n     * Overrides the action attribute (where the data on a form is sent) on the parent form element.\n     */\n    formAction: string;\n    /**\n     * Used to override the encoding (formEnctype attribute) specified on the form element.\n     */\n    formEnctype: string;\n    /**\n     * Overrides the submit method attribute previously specified on a form element.\n     */\n    formMethod: string;\n    /**\n     * Overrides any validation or required attributes on a form or form elements to allow it to be submitted without validation. This can be used to create a "save draft"-type submit option.\n     */\n    formNoValidate: boolean;\n    /**\n     * Overrides the target attribute on a form element.\n     */\n    formTarget: string;\n    readonly labels: NodeListOf<HTMLLabelElement>;\n    /**\n     * Sets or retrieves the name of the object.\n     */\n    name: string;\n    /**\n     * Gets the classification and default behavior of the button.\n     */\n    type: string;\n    /**\n     * Returns the error message that would be displayed if the user submits the form, or an empty string if no error message. It also triggers the standard error message, such as "this is a required field". The result is that the user sees validation messages without actually submitting.\n     */\n    readonly validationMessage: string;\n    /**\n     * Returns a  ValidityState object that represents the validity states of an element.\n     */\n    readonly validity: ValidityState;\n    /**\n     * Sets or retrieves the default or selected value of the control.\n     */\n    value: string;\n    /**\n     * Returns whether an element will successfully validate based on forms validation rules and constraints.\n     */\n    readonly willValidate: boolean;\n    /**\n     * Returns whether a form will validate when it is submitted, without having to submit it.\n     */\n    checkValidity(): boolean;\n    reportValidity(): boolean;\n    /**\n     * Sets a custom error message that is displayed when a form is submitted.\n     * @param error Sets a custom error message that is displayed when a form is submitted.\n     */\n    setCustomValidity(error: string): void;\n    addEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLButtonElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLButtonElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLButtonElement: {\n    prototype: HTMLButtonElement;\n    new(): HTMLButtonElement;\n};\n\n/** Provides properties and methods for manipulating the layout and presentation of <canvas> elements. The HTMLCanvasElement interface also inherits the properties and methods of the HTMLElement interface. */\ninterface HTMLCanvasElement extends HTMLElement {\n    /**\n     * Gets or sets the height of a canvas element on a document.\n     */\n    height: number;\n    /**\n     * Gets or sets the width of a canvas element on a document.\n     */\n    width: number;\n    /**\n     * Returns an object that provides methods and properties for drawing and manipulating images and graphics on a canvas element in a document. A context object includes information about colors, line widths, fonts, and other graphic parameters that can be drawn on a canvas.\n     * @param contextId The identifier (ID) of the type of canvas to create. Internet Explorer 9 and Internet Explorer 10 support only a 2-D context using canvas.getContext("2d"); IE11 Preview also supports 3-D or WebGL context using canvas.getContext("experimental-webgl");\n     */\n    getContext(contextId: "2d", options?: CanvasRenderingContext2DSettings): CanvasRenderingContext2D | null;\n    getContext(contextId: "bitmaprenderer", options?: ImageBitmapRenderingContextSettings): ImageBitmapRenderingContext | null;\n    getContext(contextId: "webgl", options?: WebGLContextAttributes): WebGLRenderingContext | null;\n    getContext(contextId: "webgl2", options?: WebGLContextAttributes): WebGL2RenderingContext | null;\n    getContext(contextId: string, options?: any): RenderingContext | null;\n    toBlob(callback: BlobCallback, type?: string, quality?: any): void;\n    /**\n     * Returns the content of the current canvas as an image that you can use as a source for another canvas or an HTML element.\n     * @param type The standard MIME type for the image format to return. If you do not specify this parameter, the default value is a PNG format image.\n     */\n    toDataURL(type?: string, quality?: any): string;\n    transferControlToOffscreen(): OffscreenCanvas;\n    addEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLCanvasElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLCanvasElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLCanvasElement: {\n    prototype: HTMLCanvasElement;\n    new(): HTMLCanvasElement;\n};\n\n/** A generic collection (array-like object similar to arguments) of elements (in document order) and offers methods and properties for selecting from the list. */\ninterface HTMLCollectionBase {\n    /**\n     * Sets or retrieves the number of objects in a collection.\n     */\n    readonly length: number;\n    /**\n     * Retrieves an object from various collections.\n     */\n    item(index: number): Element | null;\n    [index: number]: Element;\n}\n\ninterface HTMLCollection extends HTMLCollectionBase {\n    /**\n     * Retrieves a select object or an object from an options collection.\n     */\n    namedItem(name: string): Element | null;\n}\n\ndeclare var HTMLCollection: {\n    prototype: HTMLCollection;\n    new(): HTMLCollection;\n};\n\ninterface HTMLCollectionOf<T extends Element> extends HTMLCollectionBase {\n    item(index: number): T | null;\n    namedItem(name: string): T | null;\n    [index: number]: T;\n}\n\n/** Provides special properties (beyond those of the regular HTMLElement interface it also has available to it by inheritance) for manipulating definition list (<dl>) elements. */\ninterface HTMLDListElement extends HTMLElement {\n    /** @deprecated */\n    compact: boolean;\n    addEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLDListElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLDListElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLDListElement: {\n    prototype: HTMLDListElement;\n    new(): HTMLDListElement;\n};\n\n/** Provides special properties (beyond the regular HTMLElement interface it also has available to it by inheritance) for manipulating <data> elements. */\ninterface HTMLDataElement extends HTMLElement {\n    value: string;\n    addEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLDataElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLDataElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLDataElement: {\n    prototype: HTMLDataElement;\n    new(): HTMLDataElement;\n};\n\n/** Provides special properties (beyond the HTMLElement object interface it also has available to it by inheritance) to manipulate <datalist> elements and their content. */\ninterface HTMLDataListElement extends HTMLElement {\n    readonly options: HTMLCollectionOf<HTMLOptionElement>;\n    addEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLDataListElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLDataListElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLDataListElement: {\n    prototype: HTMLDataListElement;\n    new(): HTMLDataListElement;\n};\n\ninterface HTMLDetailsElement extends HTMLElement {\n    open: boolean;\n    addEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLDetailsElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLDetailsElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLDetailsElement: {\n    prototype: HTMLDetailsElement;\n    new(): HTMLDetailsElement;\n};\n\ninterface HTMLDialogElement extends HTMLElement {\n    open: boolean;\n    returnValue: string;\n    close(returnValue?: string): void;\n    show(): void;\n    showModal(): void;\n    addEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLDialogElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLDialogElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLDialogElement: {\n    prototype: HTMLDialogElement;\n    new(): HTMLDialogElement;\n};\n\ninterface HTMLDirectoryElement extends HTMLElement {\n    /** @deprecated */\n    compact: boolean;\n    addEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLDirectoryElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLDirectoryElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLDirectoryElement: {\n    prototype: HTMLDirectoryElement;\n    new(): HTMLDirectoryElement;\n};\n\n/** Provides special properties (beyond the regular HTMLElement interface it also has available to it by inheritance) for manipulating <div> elements. */\ninterface HTMLDivElement extends HTMLElement {\n    /**\n     * Sets or retrieves how the object is aligned with adjacent text.\n     */\n    /** @deprecated */\n    align: string;\n    addEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLDivElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLDivElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLDivElement: {\n    prototype: HTMLDivElement;\n    new(): HTMLDivElement;\n};\n\n/** The HTMLDocument property of Window objects is an alias that browsers expose for the Document interface object. */\ninterface HTMLDocument extends Document {\n    addEventListener<K extends keyof DocumentEventMap>(type: K, listener: (this: HTMLDocument, ev: DocumentEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof DocumentEventMap>(type: K, listener: (this: HTMLDocument, ev: DocumentEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLDocument: {\n    prototype: HTMLDocument;\n    new(): HTMLDocument;\n};\n\ninterface HTMLElementEventMap extends ElementEventMap, GlobalEventHandlersEventMap, DocumentAndElementEventHandlersEventMap {\n}\n\n/** Any HTML element. Some elements directly implement this interface, while others implement it via an interface that inherits it. */\ninterface HTMLElement extends Element, DocumentAndElementEventHandlers, ElementCSSInlineStyle, ElementCSSInlineStyle, ElementContentEditable, GlobalEventHandlers, HTMLOrSVGElement {\n    accessKey: string;\n    readonly accessKeyLabel: string;\n    autocapitalize: string;\n    dir: string;\n    draggable: boolean;\n    hidden: boolean;\n    innerText: string;\n    lang: string;\n    readonly offsetHeight: number;\n    readonly offsetLeft: number;\n    readonly offsetParent: Element | null;\n    readonly offsetTop: number;\n    readonly offsetWidth: number;\n    spellcheck: boolean;\n    title: string;\n    translate: boolean;\n    click(): void;\n    addEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLElement: {\n    prototype: HTMLElement;\n    new(): HTMLElement;\n};\n\n/** Provides special properties (beyond the regular HTMLElement interface it also has available to it by inheritance) for manipulating <embed> elements. */\ninterface HTMLEmbedElement extends HTMLElement {\n    /** @deprecated */\n    align: string;\n    /**\n     * Sets or retrieves the height of the object.\n     */\n    height: string;\n    /**\n     * Sets or retrieves the name of the object.\n     */\n    /** @deprecated */\n    name: string;\n    /**\n     * Sets or retrieves a URL to be loaded by the object.\n     */\n    src: string;\n    type: string;\n    /**\n     * Sets or retrieves the width of the object.\n     */\n    width: string;\n    getSVGDocument(): Document | null;\n    addEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLEmbedElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLEmbedElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLEmbedElement: {\n    prototype: HTMLEmbedElement;\n    new(): HTMLEmbedElement;\n};\n\n/** Provides special properties and methods (beyond the regular HTMLElement interface it also has available to it by inheritance) for manipulating the layout and presentation of <fieldset> elements. */\ninterface HTMLFieldSetElement extends HTMLElement {\n    disabled: boolean;\n    readonly elements: HTMLCollection;\n    /**\n     * Retrieves a reference to the form that the object is embedded in.\n     */\n    readonly form: HTMLFormElement | null;\n    name: string;\n    readonly type: string;\n    /**\n     * Returns the error message that would be displayed if the user submits the form, or an empty string if no error message. It also triggers the standard error message, such as "this is a required field". The result is that the user sees validation messages without actually submitting.\n     */\n    readonly validationMessage: string;\n    /**\n     * Returns a  ValidityState object that represents the validity states of an element.\n     */\n    readonly validity: ValidityState;\n    /**\n     * Returns whether an element will successfully validate based on forms validation rules and constraints.\n     */\n    readonly willValidate: boolean;\n    /**\n     * Returns whether a form will validate when it is submitted, without having to submit it.\n     */\n    checkValidity(): boolean;\n    reportValidity(): boolean;\n    /**\n     * Sets a custom error message that is displayed when a form is submitted.\n     * @param error Sets a custom error message that is displayed when a form is submitted.\n     */\n    setCustomValidity(error: string): void;\n    addEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLFieldSetElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLFieldSetElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLFieldSetElement: {\n    prototype: HTMLFieldSetElement;\n    new(): HTMLFieldSetElement;\n};\n\n/** Implements the document object model (DOM) representation of the font element. The HTML Font Element <font> defines the font size, font face and color of text. */\ninterface HTMLFontElement extends HTMLElement {\n    /** @deprecated */\n    color: string;\n    /**\n     * Sets or retrieves the current typeface family.\n     */\n    /** @deprecated */\n    face: string;\n    /** @deprecated */\n    size: string;\n    addEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLFontElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLFontElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLFontElement: {\n    prototype: HTMLFontElement;\n    new(): HTMLFontElement;\n};\n\n/** A collection of HTML form control elements.  */\ninterface HTMLFormControlsCollection extends HTMLCollectionBase {\n    /**\n     * Returns the item with ID or name name from the collection.\n     *\n     * If there are multiple matching items, then a RadioNodeList object containing all those elements is returned.\n     */\n    namedItem(name: string): RadioNodeList | Element | null;\n}\n\ndeclare var HTMLFormControlsCollection: {\n    prototype: HTMLFormControlsCollection;\n    new(): HTMLFormControlsCollection;\n};\n\n/** A <form> element in the DOM; it allows access to and in some cases modification of aspects of the form, as well as access to its component elements. */\ninterface HTMLFormElement extends HTMLElement {\n    /**\n     * Sets or retrieves a list of character encodings for input data that must be accepted by the server processing the form.\n     */\n    acceptCharset: string;\n    /**\n     * Sets or retrieves the URL to which the form content is sent for processing.\n     */\n    action: string;\n    /**\n     * Specifies whether autocomplete is applied to an editable text field.\n     */\n    autocomplete: string;\n    /**\n     * Retrieves a collection, in source order, of all controls in a given form.\n     */\n    readonly elements: HTMLFormControlsCollection;\n    /**\n     * Sets or retrieves the MIME encoding for the form.\n     */\n    encoding: string;\n    /**\n     * Sets or retrieves the encoding type for the form.\n     */\n    enctype: string;\n    /**\n     * Sets or retrieves the number of objects in a collection.\n     */\n    readonly length: number;\n    /**\n     * Sets or retrieves how to send the form data to the server.\n     */\n    method: string;\n    /**\n     * Sets or retrieves the name of the object.\n     */\n    name: string;\n    /**\n     * Designates a form that is not validated when submitted.\n     */\n    noValidate: boolean;\n    /**\n     * Sets or retrieves the window or frame at which to target content.\n     */\n    target: string;\n    /**\n     * Returns whether a form will validate when it is submitted, without having to submit it.\n     */\n    checkValidity(): boolean;\n    reportValidity(): boolean;\n    /**\n     * Fires when the user resets a form.\n     */\n    reset(): void;\n    /**\n     * Fires when a FORM is about to be submitted.\n     */\n    submit(): void;\n    addEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLFormElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLFormElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n    [index: number]: Element;\n    [name: string]: any;\n}\n\ndeclare var HTMLFormElement: {\n    prototype: HTMLFormElement;\n    new(): HTMLFormElement;\n};\n\ninterface HTMLFrameElement extends HTMLElement {\n    /**\n     * Retrieves the document object of the page or frame.\n     */\n    /** @deprecated */\n    readonly contentDocument: Document | null;\n    /**\n     * Retrieves the object of the specified.\n     */\n    /** @deprecated */\n    readonly contentWindow: WindowProxy | null;\n    /**\n     * Sets or retrieves whether to display a border for the frame.\n     */\n    /** @deprecated */\n    frameBorder: string;\n    /**\n     * Sets or retrieves a URI to a long description of the object.\n     */\n    /** @deprecated */\n    longDesc: string;\n    /**\n     * Sets or retrieves the top and bottom margin heights before displaying the text in a frame.\n     */\n    /** @deprecated */\n    marginHeight: string;\n    /**\n     * Sets or retrieves the left and right margin widths before displaying the text in a frame.\n     */\n    /** @deprecated */\n    marginWidth: string;\n    /**\n     * Sets or retrieves the frame name.\n     */\n    /** @deprecated */\n    name: string;\n    /**\n     * Sets or retrieves whether the user can resize the frame.\n     */\n    /** @deprecated */\n    noResize: boolean;\n    /**\n     * Sets or retrieves whether the frame can be scrolled.\n     */\n    /** @deprecated */\n    scrolling: string;\n    /**\n     * Sets or retrieves a URL to be loaded by the object.\n     */\n    /** @deprecated */\n    src: string;\n    addEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLFrameElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLFrameElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLFrameElement: {\n    prototype: HTMLFrameElement;\n    new(): HTMLFrameElement;\n};\n\ninterface HTMLFrameSetElementEventMap extends HTMLElementEventMap, WindowEventHandlersEventMap {\n}\n\n/** Provides special properties (beyond those of the regular HTMLElement interface they also inherit) for manipulating <frameset> elements. */\ninterface HTMLFrameSetElement extends HTMLElement, WindowEventHandlers {\n    /**\n     * Sets or retrieves the frame widths of the object.\n     */\n    /** @deprecated */\n    cols: string;\n    /**\n     * Sets or retrieves the frame heights of the object.\n     */\n    /** @deprecated */\n    rows: string;\n    addEventListener<K extends keyof HTMLFrameSetElementEventMap>(type: K, listener: (this: HTMLFrameSetElement, ev: HTMLFrameSetElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLFrameSetElementEventMap>(type: K, listener: (this: HTMLFrameSetElement, ev: HTMLFrameSetElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLFrameSetElement: {\n    prototype: HTMLFrameSetElement;\n    new(): HTMLFrameSetElement;\n};\n\n/** Provides special properties (beyond those of the HTMLElement interface it also has available to it by inheritance) for manipulating <hr> elements. */\ninterface HTMLHRElement extends HTMLElement {\n    /**\n     * Sets or retrieves how the object is aligned with adjacent text.\n     */\n    /** @deprecated */\n    align: string;\n    /** @deprecated */\n    color: string;\n    /**\n     * Sets or retrieves whether the horizontal rule is drawn with 3-D shading.\n     */\n    /** @deprecated */\n    noShade: boolean;\n    /** @deprecated */\n    size: string;\n    /**\n     * Sets or retrieves the width of the object.\n     */\n    /** @deprecated */\n    width: string;\n    addEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLHRElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLHRElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLHRElement: {\n    prototype: HTMLHRElement;\n    new(): HTMLHRElement;\n};\n\n/** Contains the descriptive information, or metadata, for a document. This object inherits all of the properties and methods described in the HTMLElement interface. */\ninterface HTMLHeadElement extends HTMLElement {\n    addEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLHeadElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLHeadElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLHeadElement: {\n    prototype: HTMLHeadElement;\n    new(): HTMLHeadElement;\n};\n\n/** The different heading elements. It inherits methods and properties from the HTMLElement interface. */\ninterface HTMLHeadingElement extends HTMLElement {\n    /**\n     * Sets or retrieves a value that indicates the table alignment.\n     */\n    /** @deprecated */\n    align: string;\n    addEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLHeadingElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLHeadingElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLHeadingElement: {\n    prototype: HTMLHeadingElement;\n    new(): HTMLHeadingElement;\n};\n\n/** Serves as the root node for a given HTML document. This object inherits the properties and methods described in the HTMLElement interface. */\ninterface HTMLHtmlElement extends HTMLElement {\n    /**\n     * Sets or retrieves the DTD version that governs the current document.\n     */\n    /** @deprecated */\n    version: string;\n    addEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLHtmlElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLHtmlElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLHtmlElement: {\n    prototype: HTMLHtmlElement;\n    new(): HTMLHtmlElement;\n};\n\ninterface HTMLHyperlinkElementUtils {\n    hash: string;\n    host: string;\n    hostname: string;\n    href: string;\n    toString(): string;\n    readonly origin: string;\n    password: string;\n    pathname: string;\n    port: string;\n    protocol: string;\n    search: string;\n    username: string;\n}\n\n/** Provides special properties and methods (beyond those of the HTMLElement interface it also has available to it by inheritance) for manipulating the layout and presentation of inline frame elements. */\ninterface HTMLIFrameElement extends HTMLElement {\n    /**\n     * Sets or retrieves how the object is aligned with adjacent text.\n     */\n    /** @deprecated */\n    align: string;\n    allow: string;\n    allowFullscreen: boolean;\n    allowPaymentRequest: boolean;\n    /**\n     * Retrieves the document object of the page or frame.\n     */\n    readonly contentDocument: Document | null;\n    /**\n     * Retrieves the object of the specified.\n     */\n    readonly contentWindow: WindowProxy | null;\n    /**\n     * Sets or retrieves whether to display a border for the frame.\n     */\n    /** @deprecated */\n    frameBorder: string;\n    /**\n     * Sets or retrieves the height of the object.\n     */\n    height: string;\n    /**\n     * Sets or retrieves a URI to a long description of the object.\n     */\n    /** @deprecated */\n    longDesc: string;\n    /**\n     * Sets or retrieves the top and bottom margin heights before displaying the text in a frame.\n     */\n    /** @deprecated */\n    marginHeight: string;\n    /**\n     * Sets or retrieves the left and right margin widths before displaying the text in a frame.\n     */\n    /** @deprecated */\n    marginWidth: string;\n    /**\n     * Sets or retrieves the frame name.\n     */\n    name: string;\n    referrerPolicy: ReferrerPolicy;\n    readonly sandbox: DOMTokenList;\n    /**\n     * Sets or retrieves whether the frame can be scrolled.\n     */\n    /** @deprecated */\n    scrolling: string;\n    /**\n     * Sets or retrieves a URL to be loaded by the object.\n     */\n    src: string;\n    /**\n     * Sets or retrives the content of the page that is to contain.\n     */\n    srcdoc: string;\n    /**\n     * Sets or retrieves the width of the object.\n     */\n    width: string;\n    getSVGDocument(): Document | null;\n    addEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLIFrameElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLIFrameElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLIFrameElement: {\n    prototype: HTMLIFrameElement;\n    new(): HTMLIFrameElement;\n};\n\n/** Provides special properties and methods for manipulating <img> elements. */\ninterface HTMLImageElement extends HTMLElement {\n    /**\n     * Sets or retrieves how the object is aligned with adjacent text.\n     */\n    /** @deprecated */\n    align: string;\n    /**\n     * Sets or retrieves a text alternative to the graphic.\n     */\n    alt: string;\n    /**\n     * Specifies the properties of a border drawn around an object.\n     */\n    /** @deprecated */\n    border: string;\n    /**\n     * Retrieves whether the object is fully loaded.\n     */\n    readonly complete: boolean;\n    crossOrigin: string | null;\n    readonly currentSrc: string;\n    decoding: "async" | "sync" | "auto";\n    /**\n     * Sets or retrieves the height of the object.\n     */\n    height: number;\n    /**\n     * Sets or retrieves the width of the border to draw around the object.\n     */\n    /** @deprecated */\n    hspace: number;\n    /**\n     * Sets or retrieves whether the image is a server-side image map.\n     */\n    isMap: boolean;\n    loading: string;\n    /**\n     * Sets or retrieves a Uniform Resource Identifier (URI) to a long description of the object.\n     */\n    /** @deprecated */\n    longDesc: string;\n    /** @deprecated */\n    lowsrc: string;\n    /**\n     * Sets or retrieves the name of the object.\n     */\n    /** @deprecated */\n    name: string;\n    /**\n     * The original height of the image resource before sizing.\n     */\n    readonly naturalHeight: number;\n    /**\n     * The original width of the image resource before sizing.\n     */\n    readonly naturalWidth: number;\n    referrerPolicy: string;\n    sizes: string;\n    /**\n     * The address or URL of the a media resource that is to be considered.\n     */\n    src: string;\n    srcset: string;\n    /**\n     * Sets or retrieves the URL, often with a bookmark extension (#name), to use as a client-side image map.\n     */\n    useMap: string;\n    /**\n     * Sets or retrieves the vertical margin for the object.\n     */\n    /** @deprecated */\n    vspace: number;\n    /**\n     * Sets or retrieves the width of the object.\n     */\n    width: number;\n    readonly x: number;\n    readonly y: number;\n    decode(): Promise<void>;\n    addEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLImageElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLImageElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLImageElement: {\n    prototype: HTMLImageElement;\n    new(): HTMLImageElement;\n};\n\n/** Provides special properties and methods for manipulating the options, layout, and presentation of <input> elements. */\ninterface HTMLInputElement extends HTMLElement {\n    /**\n     * Sets or retrieves a comma-separated list of content types.\n     */\n    accept: string;\n    /**\n     * Sets or retrieves how the object is aligned with adjacent text.\n     */\n    /** @deprecated */\n    align: string;\n    /**\n     * Sets or retrieves a text alternative to the graphic.\n     */\n    alt: string;\n    /**\n     * Specifies whether autocomplete is applied to an editable text field.\n     */\n    autocomplete: string;\n    /**\n     * Sets or retrieves the state of the check box or radio button.\n     */\n    checked: boolean;\n    /**\n     * Sets or retrieves the state of the check box or radio button.\n     */\n    defaultChecked: boolean;\n    /**\n     * Sets or retrieves the initial contents of the object.\n     */\n    defaultValue: string;\n    dirName: string;\n    disabled: boolean;\n    /**\n     * Returns a FileList object on a file type input object.\n     */\n    files: FileList | null;\n    /**\n     * Retrieves a reference to the form that the object is embedded in.\n     */\n    readonly form: HTMLFormElement | null;\n    /**\n     * Overrides the action attribute (where the data on a form is sent) on the parent form element.\n     */\n    formAction: string;\n    /**\n     * Used to override the encoding (formEnctype attribute) specified on the form element.\n     */\n    formEnctype: string;\n    /**\n     * Overrides the submit method attribute previously specified on a form element.\n     */\n    formMethod: string;\n    /**\n     * Overrides any validation or required attributes on a form or form elements to allow it to be submitted without validation. This can be used to create a "save draft"-type submit option.\n     */\n    formNoValidate: boolean;\n    /**\n     * Overrides the target attribute on a form element.\n     */\n    formTarget: string;\n    /**\n     * Sets or retrieves the height of the object.\n     */\n    height: number;\n    indeterminate: boolean;\n    readonly labels: NodeListOf<HTMLLabelElement> | null;\n    /**\n     * Specifies the ID of a pre-defined datalist of options for an input element.\n     */\n    readonly list: HTMLElement | null;\n    /**\n     * Defines the maximum acceptable value for an input element with type="number".When used with the min and step attributes, lets you control the range and increment (such as only even numbers) that the user can enter into an input field.\n     */\n    max: string;\n    /**\n     * Sets or retrieves the maximum number of characters that the user can enter in a text control.\n     */\n    maxLength: number;\n    /**\n     * Defines the minimum acceptable value for an input element with type="number". When used with the max and step attributes, lets you control the range and increment (such as even numbers only) that the user can enter into an input field.\n     */\n    min: string;\n    minLength: number;\n    /**\n     * Sets or retrieves the Boolean value indicating whether multiple items can be selected from a list.\n     */\n    multiple: boolean;\n    /**\n     * Sets or retrieves the name of the object.\n     */\n    name: string;\n    /**\n     * Gets or sets a string containing a regular expression that the user\'s input must match.\n     */\n    pattern: string;\n    /**\n     * Gets or sets a text string that is displayed in an input field as a hint or prompt to users as the format or type of information they need to enter.The text appears in an input field until the user puts focus on the field.\n     */\n    placeholder: string;\n    readOnly: boolean;\n    /**\n     * When present, marks an element that can\'t be submitted without a value.\n     */\n    required: boolean;\n    selectionDirection: "forward" | "backward" | "none" | null;\n    /**\n     * Gets or sets the end position or offset of a text selection.\n     */\n    selectionEnd: number | null;\n    /**\n     * Gets or sets the starting position or offset of a text selection.\n     */\n    selectionStart: number | null;\n    size: number;\n    /**\n     * The address or URL of the a media resource that is to be considered.\n     */\n    src: string;\n    /**\n     * Defines an increment or jump between values that you want to allow the user to enter. When used with the max and min attributes, lets you control the range and increment (for example, allow only even numbers) that the user can enter into an input field.\n     */\n    step: string;\n    /**\n     * Returns the content type of the object.\n     */\n    type: string;\n    /**\n     * Sets or retrieves the URL, often with a bookmark extension (#name), to use as a client-side image map.\n     */\n    /** @deprecated */\n    useMap: string;\n    /**\n     * Returns the error message that would be displayed if the user submits the form, or an empty string if no error message. It also triggers the standard error message, such as "this is a required field". The result is that the user sees validation messages without actually submitting.\n     */\n    readonly validationMessage: string;\n    /**\n     * Returns a  ValidityState object that represents the validity states of an element.\n     */\n    readonly validity: ValidityState;\n    /**\n     * Returns the value of the data at the cursor\'s current position.\n     */\n    value: string;\n    /**\n     * Returns a Date object representing the form control\'s value, if applicable; otherwise, returns null. Can be set, to change the value. Throws an "InvalidStateError" DOMException if the control isn\'t date- or time-based.\n     */\n    valueAsDate: Date | null;\n    /**\n     * Returns the input field value as a number.\n     */\n    valueAsNumber: number;\n    /**\n     * Sets or retrieves the width of the object.\n     */\n    width: number;\n    /**\n     * Returns whether an element will successfully validate based on forms validation rules and constraints.\n     */\n    readonly willValidate: boolean;\n    /**\n     * Returns whether a form will validate when it is submitted, without having to submit it.\n     */\n    checkValidity(): boolean;\n    reportValidity(): boolean;\n    /**\n     * Makes the selection equal to the current object.\n     */\n    select(): void;\n    /**\n     * Sets a custom error message that is displayed when a form is submitted.\n     * @param error Sets a custom error message that is displayed when a form is submitted.\n     */\n    setCustomValidity(error: string): void;\n    setRangeText(replacement: string): void;\n    setRangeText(replacement: string, start: number, end: number, selectionMode?: SelectionMode): void;\n    /**\n     * Sets the start and end positions of a selection in a text field.\n     * @param start The offset into the text field for the start of the selection.\n     * @param end The offset into the text field for the end of the selection.\n     * @param direction The direction in which the selection is performed.\n     */\n    setSelectionRange(start: number | null, end: number | null, direction?: "forward" | "backward" | "none"): void;\n    /**\n     * Decrements a range input control\'s value by the value given by the Step attribute. If the optional parameter is used, it will decrement the input control\'s step value multiplied by the parameter\'s value.\n     * @param n Value to decrement the value by.\n     */\n    stepDown(n?: number): void;\n    /**\n     * Increments a range input control\'s value by the value given by the Step attribute. If the optional parameter is used, will increment the input control\'s value by that value.\n     * @param n Value to increment the value by.\n     */\n    stepUp(n?: number): void;\n    addEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLInputElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLInputElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLInputElement: {\n    prototype: HTMLInputElement;\n    new(): HTMLInputElement;\n};\n\n/** Exposes specific properties and methods (beyond those defined by regular HTMLElement interface it also has available to it by inheritance) for manipulating list elements. */\ninterface HTMLLIElement extends HTMLElement {\n    /** @deprecated */\n    type: string;\n    /**\n     * Sets or retrieves the value of a list item.\n     */\n    value: number;\n    addEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLLIElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLLIElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLLIElement: {\n    prototype: HTMLLIElement;\n    new(): HTMLLIElement;\n};\n\n/** Gives access to properties specific to <label> elements. It inherits methods and properties from the base HTMLElement interface. */\ninterface HTMLLabelElement extends HTMLElement {\n    readonly control: HTMLElement | null;\n    /**\n     * Retrieves a reference to the form that the object is embedded in.\n     */\n    readonly form: HTMLFormElement | null;\n    /**\n     * Sets or retrieves the object to which the given label object is assigned.\n     */\n    htmlFor: string;\n    addEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLLabelElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLLabelElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLLabelElement: {\n    prototype: HTMLLabelElement;\n    new(): HTMLLabelElement;\n};\n\n/** The HTMLLegendElement is an interface allowing to access properties of the <legend> elements. It inherits properties and methods from the HTMLElement interface. */\ninterface HTMLLegendElement extends HTMLElement {\n    /** @deprecated */\n    align: string;\n    /**\n     * Retrieves a reference to the form that the object is embedded in.\n     */\n    readonly form: HTMLFormElement | null;\n    addEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLLegendElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLLegendElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLLegendElement: {\n    prototype: HTMLLegendElement;\n    new(): HTMLLegendElement;\n};\n\n/** Reference information for external resources and the relationship of those resources to a document and vice-versa. This object inherits all of the properties and methods of the HTMLElement interface. */\ninterface HTMLLinkElement extends HTMLElement, LinkStyle {\n    as: string;\n    /**\n     * Sets or retrieves the character set used to encode the object.\n     */\n    /** @deprecated */\n    charset: string;\n    crossOrigin: string | null;\n    disabled: boolean;\n    /**\n     * Sets or retrieves a destination URL or an anchor point.\n     */\n    href: string;\n    /**\n     * Sets or retrieves the language code of the object.\n     */\n    hreflang: string;\n    imageSizes: string;\n    imageSrcset: string;\n    integrity: string;\n    /**\n     * Sets or retrieves the media type.\n     */\n    media: string;\n    referrerPolicy: string;\n    /**\n     * Sets or retrieves the relationship between the object and the destination of the link.\n     */\n    rel: string;\n    readonly relList: DOMTokenList;\n    /**\n     * Sets or retrieves the relationship between the object and the destination of the link.\n     */\n    /** @deprecated */\n    rev: string;\n    readonly sizes: DOMTokenList;\n    /**\n     * Sets or retrieves the window or frame at which to target content.\n     */\n    /** @deprecated */\n    target: string;\n    /**\n     * Sets or retrieves the MIME type of the object.\n     */\n    type: string;\n    addEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLLinkElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLLinkElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLLinkElement: {\n    prototype: HTMLLinkElement;\n    new(): HTMLLinkElement;\n};\n\n/** Provides special properties and methods (beyond those of the regular object HTMLElement interface it also has available to it by inheritance) for manipulating the layout and presentation of map elements. */\ninterface HTMLMapElement extends HTMLElement {\n    /**\n     * Retrieves a collection of the area objects defined for the given map object.\n     */\n    readonly areas: HTMLCollection;\n    /**\n     * Sets or retrieves the name of the object.\n     */\n    name: string;\n    addEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLMapElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLMapElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLMapElement: {\n    prototype: HTMLMapElement;\n    new(): HTMLMapElement;\n};\n\ninterface HTMLMarqueeElementEventMap extends HTMLElementEventMap {\n    "bounce": Event;\n    "finish": Event;\n    "start": Event;\n}\n\n/** Provides methods to manipulate <marquee> elements. */\ninterface HTMLMarqueeElement extends HTMLElement {\n    /** @deprecated */\n    behavior: string;\n    /** @deprecated */\n    bgColor: string;\n    /** @deprecated */\n    direction: string;\n    /** @deprecated */\n    height: string;\n    /** @deprecated */\n    hspace: number;\n    /** @deprecated */\n    loop: number;\n    /** @deprecated */\n    onbounce: ((this: HTMLMarqueeElement, ev: Event) => any) | null;\n    /** @deprecated */\n    onfinish: ((this: HTMLMarqueeElement, ev: Event) => any) | null;\n    /** @deprecated */\n    onstart: ((this: HTMLMarqueeElement, ev: Event) => any) | null;\n    /** @deprecated */\n    scrollAmount: number;\n    /** @deprecated */\n    scrollDelay: number;\n    /** @deprecated */\n    trueSpeed: boolean;\n    /** @deprecated */\n    vspace: number;\n    /** @deprecated */\n    width: string;\n    /** @deprecated */\n    start(): void;\n    /** @deprecated */\n    stop(): void;\n    addEventListener<K extends keyof HTMLMarqueeElementEventMap>(type: K, listener: (this: HTMLMarqueeElement, ev: HTMLMarqueeElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLMarqueeElementEventMap>(type: K, listener: (this: HTMLMarqueeElement, ev: HTMLMarqueeElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLMarqueeElement: {\n    prototype: HTMLMarqueeElement;\n    new(): HTMLMarqueeElement;\n};\n\ninterface HTMLMediaElementEventMap extends HTMLElementEventMap {\n    "encrypted": MediaEncryptedEvent;\n    "waitingforkey": Event;\n}\n\n/** Adds to HTMLElement the properties and methods needed to support basic media-related capabilities that are common to audio and video. */\ninterface HTMLMediaElement extends HTMLElement {\n    /**\n     * Gets or sets a value that indicates whether to start playing the media automatically.\n     */\n    autoplay: boolean;\n    /**\n     * Gets a collection of buffered time ranges.\n     */\n    readonly buffered: TimeRanges;\n    /**\n     * Gets or sets a flag that indicates whether the client provides a set of controls for the media (in case the developer does not include controls for the player).\n     */\n    controls: boolean;\n    crossOrigin: string | null;\n    /**\n     * Gets the address or URL of the current media resource that is selected by IHTMLMediaElement.\n     */\n    readonly currentSrc: string;\n    /**\n     * Gets or sets the current playback position, in seconds.\n     */\n    currentTime: number;\n    defaultMuted: boolean;\n    /**\n     * Gets or sets the default playback rate when the user is not using fast forward or reverse for a video or audio resource.\n     */\n    defaultPlaybackRate: number;\n    /**\n     * Returns the duration in seconds of the current media resource. A NaN value is returned if duration is not available, or Infinity if the media resource is streaming.\n     */\n    readonly duration: number;\n    /**\n     * Gets information about whether the playback has ended or not.\n     */\n    readonly ended: boolean;\n    /**\n     * Returns an object representing the current error state of the audio or video element.\n     */\n    readonly error: MediaError | null;\n    /**\n     * Gets or sets a flag to specify whether playback should restart after it completes.\n     */\n    loop: boolean;\n    readonly mediaKeys: MediaKeys | null;\n    /**\n     * Gets or sets a flag that indicates whether the audio (either audio or the audio track on video media) is muted.\n     */\n    muted: boolean;\n    /**\n     * Gets the current network activity for the element.\n     */\n    readonly networkState: number;\n    onencrypted: ((this: HTMLMediaElement, ev: MediaEncryptedEvent) => any) | null;\n    onwaitingforkey: ((this: HTMLMediaElement, ev: Event) => any) | null;\n    /**\n     * Gets a flag that specifies whether playback is paused.\n     */\n    readonly paused: boolean;\n    /**\n     * Gets or sets the current rate of speed for the media resource to play. This speed is expressed as a multiple of the normal speed of the media resource.\n     */\n    playbackRate: number;\n    /**\n     * Gets TimeRanges for the current media resource that has been played.\n     */\n    readonly played: TimeRanges;\n    /**\n     * Gets or sets the current playback position, in seconds.\n     */\n    preload: string;\n    readonly readyState: number;\n    /**\n     * Returns a TimeRanges object that represents the ranges of the current media resource that can be seeked.\n     */\n    readonly seekable: TimeRanges;\n    /**\n     * Gets a flag that indicates whether the client is currently moving to a new playback position in the media resource.\n     */\n    readonly seeking: boolean;\n    /**\n     * The address or URL of the a media resource that is to be considered.\n     */\n    src: string;\n    srcObject: MediaProvider | null;\n    readonly textTracks: TextTrackList;\n    /**\n     * Gets or sets the volume level for audio portions of the media element.\n     */\n    volume: number;\n    addTextTrack(kind: TextTrackKind, label?: string, language?: string): TextTrack;\n    /**\n     * Returns a string that specifies whether the client can play a given media resource type.\n     */\n    canPlayType(type: string): CanPlayTypeResult;\n    fastSeek(time: number): void;\n    /**\n     * Resets the audio or video object and loads a new media resource.\n     */\n    load(): void;\n    /**\n     * Pauses the current playback and sets paused to TRUE. This can be used to test whether the media is playing or paused. You can also use the pause or play events to tell whether the media is playing or not.\n     */\n    pause(): void;\n    /**\n     * Loads and starts playback of a media resource.\n     */\n    play(): Promise<void>;\n    setMediaKeys(mediaKeys: MediaKeys | null): Promise<void>;\n    readonly HAVE_CURRENT_DATA: number;\n    readonly HAVE_ENOUGH_DATA: number;\n    readonly HAVE_FUTURE_DATA: number;\n    readonly HAVE_METADATA: number;\n    readonly HAVE_NOTHING: number;\n    readonly NETWORK_EMPTY: number;\n    readonly NETWORK_IDLE: number;\n    readonly NETWORK_LOADING: number;\n    readonly NETWORK_NO_SOURCE: number;\n    addEventListener<K extends keyof HTMLMediaElementEventMap>(type: K, listener: (this: HTMLMediaElement, ev: HTMLMediaElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLMediaElementEventMap>(type: K, listener: (this: HTMLMediaElement, ev: HTMLMediaElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLMediaElement: {\n    prototype: HTMLMediaElement;\n    new(): HTMLMediaElement;\n    readonly HAVE_CURRENT_DATA: number;\n    readonly HAVE_ENOUGH_DATA: number;\n    readonly HAVE_FUTURE_DATA: number;\n    readonly HAVE_METADATA: number;\n    readonly HAVE_NOTHING: number;\n    readonly NETWORK_EMPTY: number;\n    readonly NETWORK_IDLE: number;\n    readonly NETWORK_LOADING: number;\n    readonly NETWORK_NO_SOURCE: number;\n};\n\ninterface HTMLMenuElement extends HTMLElement {\n    /** @deprecated */\n    compact: boolean;\n    addEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLMenuElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLMenuElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLMenuElement: {\n    prototype: HTMLMenuElement;\n    new(): HTMLMenuElement;\n};\n\n/** Contains descriptive metadata about a document. It inherits all of the properties and methods described in the HTMLElement interface. */\ninterface HTMLMetaElement extends HTMLElement {\n    /**\n     * Gets or sets meta-information to associate with httpEquiv or name.\n     */\n    content: string;\n    /**\n     * Gets or sets information used to bind the value of a content attribute of a meta element to an HTTP response header.\n     */\n    httpEquiv: string;\n    /**\n     * Sets or retrieves the value specified in the content attribute of the meta object.\n     */\n    name: string;\n    /**\n     * Sets or retrieves a scheme to be used in interpreting the value of a property specified for the object.\n     */\n    /** @deprecated */\n    scheme: string;\n    addEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLMetaElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLMetaElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLMetaElement: {\n    prototype: HTMLMetaElement;\n    new(): HTMLMetaElement;\n};\n\n/** The HTML <meter> elements expose the HTMLMeterElement interface, which provides special properties and methods (beyond the HTMLElement object interface they also have available to them by inheritance) for manipulating the layout and presentation of <meter> elements. */\ninterface HTMLMeterElement extends HTMLElement {\n    high: number;\n    readonly labels: NodeListOf<HTMLLabelElement>;\n    low: number;\n    max: number;\n    min: number;\n    optimum: number;\n    value: number;\n    addEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLMeterElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLMeterElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLMeterElement: {\n    prototype: HTMLMeterElement;\n    new(): HTMLMeterElement;\n};\n\n/** Provides special properties (beyond the regular methods and properties available through the HTMLElement interface they also have available to them by inheritance) for manipulating modification elements, that is <del> and <ins>. */\ninterface HTMLModElement extends HTMLElement {\n    /**\n     * Sets or retrieves reference information about the object.\n     */\n    cite: string;\n    /**\n     * Sets or retrieves the date and time of a modification to the object.\n     */\n    dateTime: string;\n    addEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLModElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLModElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLModElement: {\n    prototype: HTMLModElement;\n    new(): HTMLModElement;\n};\n\n/** Provides special properties (beyond those defined on the regular HTMLElement interface it also has available to it by inheritance) for manipulating ordered list elements. */\ninterface HTMLOListElement extends HTMLElement {\n    /** @deprecated */\n    compact: boolean;\n    reversed: boolean;\n    /**\n     * The starting number.\n     */\n    start: number;\n    type: string;\n    addEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLOListElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLOListElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLOListElement: {\n    prototype: HTMLOListElement;\n    new(): HTMLOListElement;\n};\n\n/** Provides special properties and methods (beyond those on the HTMLElement interface it also has available to it by inheritance) for manipulating the layout and presentation of <object> element, representing external resources. */\ninterface HTMLObjectElement extends HTMLElement {\n    /** @deprecated */\n    align: string;\n    /**\n     * Sets or retrieves a character string that can be used to implement your own archive functionality for the object.\n     */\n    /** @deprecated */\n    archive: string;\n    /** @deprecated */\n    border: string;\n    /**\n     * Sets or retrieves the URL of the file containing the compiled Java class.\n     */\n    /** @deprecated */\n    code: string;\n    /**\n     * Sets or retrieves the URL of the component.\n     */\n    /** @deprecated */\n    codeBase: string;\n    /**\n     * Sets or retrieves the Internet media type for the code associated with the object.\n     */\n    /** @deprecated */\n    codeType: string;\n    /**\n     * Retrieves the document object of the page or frame.\n     */\n    readonly contentDocument: Document | null;\n    readonly contentWindow: WindowProxy | null;\n    /**\n     * Sets or retrieves the URL that references the data of the object.\n     */\n    data: string;\n    /** @deprecated */\n    declare: boolean;\n    /**\n     * Retrieves a reference to the form that the object is embedded in.\n     */\n    readonly form: HTMLFormElement | null;\n    /**\n     * Sets or retrieves the height of the object.\n     */\n    height: string;\n    /** @deprecated */\n    hspace: number;\n    /**\n     * Sets or retrieves the name of the object.\n     */\n    name: string;\n    /**\n     * Sets or retrieves a message to be displayed while an object is loading.\n     */\n    /** @deprecated */\n    standby: string;\n    /**\n     * Sets or retrieves the MIME type of the object.\n     */\n    type: string;\n    /**\n     * Sets or retrieves the URL, often with a bookmark extension (#name), to use as a client-side image map.\n     */\n    useMap: string;\n    /**\n     * Returns the error message that would be displayed if the user submits the form, or an empty string if no error message. It also triggers the standard error message, such as "this is a required field". The result is that the user sees validation messages without actually submitting.\n     */\n    readonly validationMessage: string;\n    /**\n     * Returns a  ValidityState object that represents the validity states of an element.\n     */\n    readonly validity: ValidityState;\n    /** @deprecated */\n    vspace: number;\n    /**\n     * Sets or retrieves the width of the object.\n     */\n    width: string;\n    /**\n     * Returns whether an element will successfully validate based on forms validation rules and constraints.\n     */\n    readonly willValidate: boolean;\n    /**\n     * Returns whether a form will validate when it is submitted, without having to submit it.\n     */\n    checkValidity(): boolean;\n    getSVGDocument(): Document | null;\n    reportValidity(): boolean;\n    /**\n     * Sets a custom error message that is displayed when a form is submitted.\n     * @param error Sets a custom error message that is displayed when a form is submitted.\n     */\n    setCustomValidity(error: string): void;\n    addEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLObjectElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLObjectElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLObjectElement: {\n    prototype: HTMLObjectElement;\n    new(): HTMLObjectElement;\n};\n\n/** Provides special properties and methods (beyond the regular HTMLElement object interface they also have available to them by inheritance) for manipulating the layout and presentation of <optgroup> elements. */\ninterface HTMLOptGroupElement extends HTMLElement {\n    disabled: boolean;\n    /**\n     * Retrieves a reference to the form that the object is embedded in.\n     */\n    readonly form: HTMLFormElement | null;\n    /**\n     * Sets or retrieves a value that you can use to implement your own label functionality for the object.\n     */\n    label: string;\n    addEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLOptGroupElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLOptGroupElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLOptGroupElement: {\n    prototype: HTMLOptGroupElement;\n    new(): HTMLOptGroupElement;\n};\n\n/** <option> elements and inherits all classes and methods of the HTMLElement interface. */\ninterface HTMLOptionElement extends HTMLElement {\n    /**\n     * Sets or retrieves the status of an option.\n     */\n    defaultSelected: boolean;\n    disabled: boolean;\n    /**\n     * Retrieves a reference to the form that the object is embedded in.\n     */\n    readonly form: HTMLFormElement | null;\n    /**\n     * Sets or retrieves the ordinal position of an option in a list box.\n     */\n    readonly index: number;\n    /**\n     * Sets or retrieves a value that you can use to implement your own label functionality for the object.\n     */\n    label: string;\n    /**\n     * Sets or retrieves whether the option in the list box is the default item.\n     */\n    selected: boolean;\n    /**\n     * Sets or retrieves the text string specified by the option tag.\n     */\n    text: string;\n    /**\n     * Sets or retrieves the value which is returned to the server when the form control is submitted.\n     */\n    value: string;\n    addEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLOptionElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLOptionElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLOptionElement: {\n    prototype: HTMLOptionElement;\n    new(): HTMLOptionElement;\n};\n\n/** HTMLOptionsCollection is an interface representing a collection of HTML option elements (in document order) and offers methods and properties for traversing the list as well as optionally altering its items. This type is returned solely by the "options" property of select. */\ninterface HTMLOptionsCollection extends HTMLCollectionOf<HTMLOptionElement> {\n    /**\n     * Returns the number of elements in the collection.\n     *\n     * When set to a smaller number, truncates the number of option elements in the corresponding container.\n     *\n     * When set to a greater number, adds new blank option elements to that container.\n     */\n    length: number;\n    /**\n     * Returns the index of the first selected item, if any, or −1 if there is no selected item.\n     *\n     * Can be set, to change the selection.\n     */\n    selectedIndex: number;\n    /**\n     * Inserts element before the node given by before.\n     *\n     * The before argument can be a number, in which case element is inserted before the item with that number, or an element from the collection, in which case element is inserted before that element.\n     *\n     * If before is omitted, null, or a number out of range, then element will be added at the end of the list.\n     *\n     * This method will throw a "HierarchyRequestError" DOMException if element is an ancestor of the element into which it is to be inserted.\n     */\n    add(element: HTMLOptionElement | HTMLOptGroupElement, before?: HTMLElement | number | null): void;\n    /**\n     * Removes the item with index index from the collection.\n     */\n    remove(index: number): void;\n}\n\ndeclare var HTMLOptionsCollection: {\n    prototype: HTMLOptionsCollection;\n    new(): HTMLOptionsCollection;\n};\n\ninterface HTMLOrSVGElement {\n    autofocus: boolean;\n    readonly dataset: DOMStringMap;\n    nonce?: string;\n    tabIndex: number;\n    blur(): void;\n    focus(options?: FocusOptions): void;\n}\n\n/** Provides properties and methods (beyond those inherited from HTMLElement) for manipulating the layout and presentation of <output> elements. */\ninterface HTMLOutputElement extends HTMLElement {\n    defaultValue: string;\n    readonly form: HTMLFormElement | null;\n    readonly htmlFor: DOMTokenList;\n    readonly labels: NodeListOf<HTMLLabelElement>;\n    name: string;\n    readonly type: string;\n    readonly validationMessage: string;\n    readonly validity: ValidityState;\n    value: string;\n    readonly willValidate: boolean;\n    checkValidity(): boolean;\n    reportValidity(): boolean;\n    setCustomValidity(error: string): void;\n    addEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLOutputElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLOutputElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLOutputElement: {\n    prototype: HTMLOutputElement;\n    new(): HTMLOutputElement;\n};\n\n/** Provides special properties (beyond those of the regular HTMLElement object interface it inherits) for manipulating <p> elements. */\ninterface HTMLParagraphElement extends HTMLElement {\n    /**\n     * Sets or retrieves how the object is aligned with adjacent text.\n     */\n    /** @deprecated */\n    align: string;\n    addEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLParagraphElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLParagraphElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLParagraphElement: {\n    prototype: HTMLParagraphElement;\n    new(): HTMLParagraphElement;\n};\n\n/** Provides special properties (beyond those of the regular HTMLElement object interface it inherits) for manipulating <param> elements, representing a pair of a key and a value that acts as a parameter for an <object> element. */\ninterface HTMLParamElement extends HTMLElement {\n    /**\n     * Sets or retrieves the name of an input parameter for an element.\n     */\n    name: string;\n    /**\n     * Sets or retrieves the content type of the resource designated by the value attribute.\n     */\n    /** @deprecated */\n    type: string;\n    /**\n     * Sets or retrieves the value of an input parameter for an element.\n     */\n    value: string;\n    /**\n     * Sets or retrieves the data type of the value attribute.\n     */\n    /** @deprecated */\n    valueType: string;\n    addEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLParamElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLParamElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLParamElement: {\n    prototype: HTMLParamElement;\n    new(): HTMLParamElement;\n};\n\n/** A <picture> HTML element. It doesn\'t implement specific properties or methods. */\ninterface HTMLPictureElement extends HTMLElement {\n    addEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLPictureElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLPictureElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLPictureElement: {\n    prototype: HTMLPictureElement;\n    new(): HTMLPictureElement;\n};\n\n/** Exposes specific properties and methods (beyond those of the HTMLElement interface it also has available to it by inheritance) for manipulating a block of preformatted text (<pre>). */\ninterface HTMLPreElement extends HTMLElement {\n    /**\n     * Sets or gets a value that you can use to implement your own width functionality for the object.\n     */\n    /** @deprecated */\n    width: number;\n    addEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLPreElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLPreElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLPreElement: {\n    prototype: HTMLPreElement;\n    new(): HTMLPreElement;\n};\n\n/** Provides special properties and methods (beyond the regular HTMLElement interface it also has available to it by inheritance) for manipulating the layout and presentation of <progress> elements. */\ninterface HTMLProgressElement extends HTMLElement {\n    readonly labels: NodeListOf<HTMLLabelElement>;\n    /**\n     * Defines the maximum, or "done" value for a progress element.\n     */\n    max: number;\n    /**\n     * Returns the quotient of value/max when the value attribute is set (determinate progress bar), or -1 when the value attribute is missing (indeterminate progress bar).\n     */\n    readonly position: number;\n    /**\n     * Sets or gets the current value of a progress element. The value must be a non-negative number between 0 and the max value.\n     */\n    value: number;\n    addEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLProgressElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLProgressElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLProgressElement: {\n    prototype: HTMLProgressElement;\n    new(): HTMLProgressElement;\n};\n\n/** Provides special properties and methods (beyond the regular HTMLElement interface it also has available to it by inheritance) for manipulating quoting elements, like <blockquote> and <q>, but not the <cite> element. */\ninterface HTMLQuoteElement extends HTMLElement {\n    /**\n     * Sets or retrieves reference information about the object.\n     */\n    cite: string;\n    addEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLQuoteElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLQuoteElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLQuoteElement: {\n    prototype: HTMLQuoteElement;\n    new(): HTMLQuoteElement;\n};\n\n/** HTML <script> elements expose the HTMLScriptElement interface, which provides special properties and methods for manipulating the behavior and execution of <script> elements (beyond the inherited HTMLElement interface). */\ninterface HTMLScriptElement extends HTMLElement {\n    async: boolean;\n    /**\n     * Sets or retrieves the character set used to encode the object.\n     */\n    /** @deprecated */\n    charset: string;\n    crossOrigin: string | null;\n    /**\n     * Sets or retrieves the status of the script.\n     */\n    defer: boolean;\n    /**\n     * Sets or retrieves the event for which the script is written.\n     */\n    /** @deprecated */\n    event: string;\n    /**\n     * Sets or retrieves the object that is bound to the event script.\n     */\n    /** @deprecated */\n    htmlFor: string;\n    integrity: string;\n    noModule: boolean;\n    referrerPolicy: string;\n    /**\n     * Retrieves the URL to an external file that contains the source code or data.\n     */\n    src: string;\n    /**\n     * Retrieves or sets the text of the object as a string.\n     */\n    text: string;\n    /**\n     * Sets or retrieves the MIME type for the associated scripting engine.\n     */\n    type: string;\n    addEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLScriptElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLScriptElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLScriptElement: {\n    prototype: HTMLScriptElement;\n    new(): HTMLScriptElement;\n};\n\n/** A <select> HTML Element. These elements also share all of the properties and methods of other HTML elements via the HTMLElement interface. */\ninterface HTMLSelectElement extends HTMLElement {\n    autocomplete: string;\n    disabled: boolean;\n    /**\n     * Retrieves a reference to the form that the object is embedded in.\n     */\n    readonly form: HTMLFormElement | null;\n    readonly labels: NodeListOf<HTMLLabelElement>;\n    /**\n     * Sets or retrieves the number of objects in a collection.\n     */\n    length: number;\n    /**\n     * Sets or retrieves the Boolean value indicating whether multiple items can be selected from a list.\n     */\n    multiple: boolean;\n    /**\n     * Sets or retrieves the name of the object.\n     */\n    name: string;\n    readonly options: HTMLOptionsCollection;\n    /**\n     * When present, marks an element that can\'t be submitted without a value.\n     */\n    required: boolean;\n    /**\n     * Sets or retrieves the index of the selected option in a select object.\n     */\n    selectedIndex: number;\n    readonly selectedOptions: HTMLCollectionOf<HTMLOptionElement>;\n    /**\n     * Sets or retrieves the number of rows in the list box.\n     */\n    size: number;\n    /**\n     * Retrieves the type of select control based on the value of the MULTIPLE attribute.\n     */\n    readonly type: string;\n    /**\n     * Returns the error message that would be displayed if the user submits the form, or an empty string if no error message. It also triggers the standard error message, such as "this is a required field". The result is that the user sees validation messages without actually submitting.\n     */\n    readonly validationMessage: string;\n    /**\n     * Returns a  ValidityState object that represents the validity states of an element.\n     */\n    readonly validity: ValidityState;\n    /**\n     * Sets or retrieves the value which is returned to the server when the form control is submitted.\n     */\n    value: string;\n    /**\n     * Returns whether an element will successfully validate based on forms validation rules and constraints.\n     */\n    readonly willValidate: boolean;\n    /**\n     * Adds an element to the areas, controlRange, or options collection.\n     * @param element Variant of type Number that specifies the index position in the collection where the element is placed. If no value is given, the method places the element at the end of the collection.\n     * @param before Variant of type Object that specifies an element to insert before, or null to append the object to the collection.\n     */\n    add(element: HTMLOptionElement | HTMLOptGroupElement, before?: HTMLElement | number | null): void;\n    /**\n     * Returns whether a form will validate when it is submitted, without having to submit it.\n     */\n    checkValidity(): boolean;\n    /**\n     * Retrieves a select object or an object from an options collection.\n     * @param name Variant of type Number or String that specifies the object or collection to retrieve. If this parameter is an integer, it is the zero-based index of the object. If this parameter is a string, all objects with matching name or id properties are retrieved, and a collection is returned if more than one match is made.\n     * @param index Variant of type Number that specifies the zero-based index of the object to retrieve when a collection is returned.\n     */\n    item(index: number): Element | null;\n    /**\n     * Retrieves a select object or an object from an options collection.\n     * @param namedItem A String that specifies the name or id property of the object to retrieve. A collection is returned if more than one match is made.\n     */\n    namedItem(name: string): HTMLOptionElement | null;\n    /**\n     * Removes an element from the collection.\n     * @param index Number that specifies the zero-based index of the element to remove from the collection.\n     */\n    remove(): void;\n    remove(index: number): void;\n    reportValidity(): boolean;\n    /**\n     * Sets a custom error message that is displayed when a form is submitted.\n     * @param error Sets a custom error message that is displayed when a form is submitted.\n     */\n    setCustomValidity(error: string): void;\n    addEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLSelectElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLSelectElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n    [name: number]: HTMLOptionElement | HTMLOptGroupElement;\n}\n\ndeclare var HTMLSelectElement: {\n    prototype: HTMLSelectElement;\n    new(): HTMLSelectElement;\n};\n\ninterface HTMLSlotElement extends HTMLElement {\n    name: string;\n    assignedElements(options?: AssignedNodesOptions): Element[];\n    assignedNodes(options?: AssignedNodesOptions): Node[];\n    addEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLSlotElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLSlotElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLSlotElement: {\n    prototype: HTMLSlotElement;\n    new(): HTMLSlotElement;\n};\n\n/** Provides special properties (beyond the regular HTMLElement object interface it also has available to it by inheritance) for manipulating <source> elements. */\ninterface HTMLSourceElement extends HTMLElement {\n    /**\n     * Gets or sets the intended media type of the media source.\n     */\n    media: string;\n    sizes: string;\n    /**\n     * The address or URL of the a media resource that is to be considered.\n     */\n    src: string;\n    srcset: string;\n    /**\n     * Gets or sets the MIME type of a media resource.\n     */\n    type: string;\n    addEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLSourceElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLSourceElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLSourceElement: {\n    prototype: HTMLSourceElement;\n    new(): HTMLSourceElement;\n};\n\n/** A <span> element and derives from the HTMLElement interface, but without implementing any additional properties or methods. */\ninterface HTMLSpanElement extends HTMLElement {\n    addEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLSpanElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLSpanElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLSpanElement: {\n    prototype: HTMLSpanElement;\n    new(): HTMLSpanElement;\n};\n\n/** A <style> element. It inherits properties and methods from its parent, HTMLElement, and from LinkStyle. */\ninterface HTMLStyleElement extends HTMLElement, LinkStyle {\n    /**\n     * Sets or retrieves the media type.\n     */\n    media: string;\n    /**\n     * Retrieves the CSS language in which the style sheet is written.\n     */\n    /** @deprecated */\n    type: string;\n    addEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLStyleElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLStyleElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLStyleElement: {\n    prototype: HTMLStyleElement;\n    new(): HTMLStyleElement;\n};\n\n/** Special properties (beyond the regular HTMLElement interface it also has available to it by inheritance) for manipulating table caption elements. */\ninterface HTMLTableCaptionElement extends HTMLElement {\n    /**\n     * Sets or retrieves the alignment of the caption or legend.\n     */\n    /** @deprecated */\n    align: string;\n    addEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLTableCaptionElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLTableCaptionElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLTableCaptionElement: {\n    prototype: HTMLTableCaptionElement;\n    new(): HTMLTableCaptionElement;\n};\n\n/** Provides special properties and methods (beyond the regular HTMLElement interface it also has available to it by inheritance) for manipulating the layout and presentation of table cells, either header or data cells, in an HTML document. */\ninterface HTMLTableCellElement extends HTMLElement {\n    /**\n     * Sets or retrieves abbreviated text for the object.\n     */\n    abbr: string;\n    /**\n     * Sets or retrieves how the object is aligned with adjacent text.\n     */\n    /** @deprecated */\n    align: string;\n    /**\n     * Sets or retrieves a comma-delimited list of conceptual categories associated with the object.\n     */\n    /** @deprecated */\n    axis: string;\n    /** @deprecated */\n    bgColor: string;\n    /**\n     * Retrieves the position of the object in the cells collection of a row.\n     */\n    readonly cellIndex: number;\n    /** @deprecated */\n    ch: string;\n    /** @deprecated */\n    chOff: string;\n    /**\n     * Sets or retrieves the number columns in the table that the object should span.\n     */\n    colSpan: number;\n    /**\n     * Sets or retrieves a list of header cells that provide information for the object.\n     */\n    headers: string;\n    /**\n     * Sets or retrieves the height of the object.\n     */\n    /** @deprecated */\n    height: string;\n    /**\n     * Sets or retrieves whether the browser automatically performs wordwrap.\n     */\n    /** @deprecated */\n    noWrap: boolean;\n    /**\n     * Sets or retrieves how many rows in a table the cell should span.\n     */\n    rowSpan: number;\n    /**\n     * Sets or retrieves the group of cells in a table to which the object\'s information applies.\n     */\n    scope: string;\n    /** @deprecated */\n    vAlign: string;\n    /**\n     * Sets or retrieves the width of the object.\n     */\n    /** @deprecated */\n    width: string;\n    addEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLTableCellElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLTableCellElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLTableCellElement: {\n    prototype: HTMLTableCellElement;\n    new(): HTMLTableCellElement;\n};\n\n/** Provides special properties (beyond the HTMLElement interface it also has available to it inheritance) for manipulating single or grouped table column elements. */\ninterface HTMLTableColElement extends HTMLElement {\n    /**\n     * Sets or retrieves the alignment of the object relative to the display or table.\n     */\n    /** @deprecated */\n    align: string;\n    /** @deprecated */\n    ch: string;\n    /** @deprecated */\n    chOff: string;\n    /**\n     * Sets or retrieves the number of columns in the group.\n     */\n    span: number;\n    /** @deprecated */\n    vAlign: string;\n    /**\n     * Sets or retrieves the width of the object.\n     */\n    /** @deprecated */\n    width: string;\n    addEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLTableColElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLTableColElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLTableColElement: {\n    prototype: HTMLTableColElement;\n    new(): HTMLTableColElement;\n};\n\ninterface HTMLTableDataCellElement extends HTMLTableCellElement {\n    addEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLTableDataCellElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLTableDataCellElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLTableDataCellElement: {\n    prototype: HTMLTableDataCellElement;\n    new(): HTMLTableDataCellElement;\n};\n\n/** Provides special properties and methods (beyond the regular HTMLElement object interface it also has available to it by inheritance) for manipulating the layout and presentation of tables in an HTML document. */\ninterface HTMLTableElement extends HTMLElement {\n    /**\n     * Sets or retrieves a value that indicates the table alignment.\n     */\n    /** @deprecated */\n    align: string;\n    /** @deprecated */\n    bgColor: string;\n    /**\n     * Sets or retrieves the width of the border to draw around the object.\n     */\n    /** @deprecated */\n    border: string;\n    /**\n     * Retrieves the caption object of a table.\n     */\n    caption: HTMLTableCaptionElement | null;\n    /**\n     * Sets or retrieves the amount of space between the border of the cell and the content of the cell.\n     */\n    /** @deprecated */\n    cellPadding: string;\n    /**\n     * Sets or retrieves the amount of space between cells in a table.\n     */\n    /** @deprecated */\n    cellSpacing: string;\n    /**\n     * Sets or retrieves the way the border frame around the table is displayed.\n     */\n    /** @deprecated */\n    frame: string;\n    /**\n     * Sets or retrieves the number of horizontal rows contained in the object.\n     */\n    readonly rows: HTMLCollectionOf<HTMLTableRowElement>;\n    /**\n     * Sets or retrieves which dividing lines (inner borders) are displayed.\n     */\n    /** @deprecated */\n    rules: string;\n    /**\n     * Sets or retrieves a description and/or structure of the object.\n     */\n    /** @deprecated */\n    summary: string;\n    /**\n     * Retrieves a collection of all tBody objects in the table. Objects in this collection are in source order.\n     */\n    readonly tBodies: HTMLCollectionOf<HTMLTableSectionElement>;\n    /**\n     * Retrieves the tFoot object of the table.\n     */\n    tFoot: HTMLTableSectionElement | null;\n    /**\n     * Retrieves the tHead object of the table.\n     */\n    tHead: HTMLTableSectionElement | null;\n    /**\n     * Sets or retrieves the width of the object.\n     */\n    /** @deprecated */\n    width: string;\n    /**\n     * Creates an empty caption element in the table.\n     */\n    createCaption(): HTMLTableCaptionElement;\n    /**\n     * Creates an empty tBody element in the table.\n     */\n    createTBody(): HTMLTableSectionElement;\n    /**\n     * Creates an empty tFoot element in the table.\n     */\n    createTFoot(): HTMLTableSectionElement;\n    /**\n     * Returns the tHead element object if successful, or null otherwise.\n     */\n    createTHead(): HTMLTableSectionElement;\n    /**\n     * Deletes the caption element and its contents from the table.\n     */\n    deleteCaption(): void;\n    /**\n     * Removes the specified row (tr) from the element and from the rows collection.\n     * @param index Number that specifies the zero-based position in the rows collection of the row to remove.\n     */\n    deleteRow(index: number): void;\n    /**\n     * Deletes the tFoot element and its contents from the table.\n     */\n    deleteTFoot(): void;\n    /**\n     * Deletes the tHead element and its contents from the table.\n     */\n    deleteTHead(): void;\n    /**\n     * Creates a new row (tr) in the table, and adds the row to the rows collection.\n     * @param index Number that specifies where to insert the row in the rows collection. The default value is -1, which appends the new row to the end of the rows collection.\n     */\n    insertRow(index?: number): HTMLTableRowElement;\n    addEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLTableElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLTableElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLTableElement: {\n    prototype: HTMLTableElement;\n    new(): HTMLTableElement;\n};\n\ninterface HTMLTableHeaderCellElement extends HTMLTableCellElement {\n    addEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLTableHeaderCellElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLTableHeaderCellElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLTableHeaderCellElement: {\n    prototype: HTMLTableHeaderCellElement;\n    new(): HTMLTableHeaderCellElement;\n};\n\n/** Provides special properties and methods (beyond the HTMLElement interface it also has available to it by inheritance) for manipulating the layout and presentation of rows in an HTML table. */\ninterface HTMLTableRowElement extends HTMLElement {\n    /**\n     * Sets or retrieves how the object is aligned with adjacent text.\n     */\n    /** @deprecated */\n    align: string;\n    /** @deprecated */\n    bgColor: string;\n    /**\n     * Retrieves a collection of all cells in the table row.\n     */\n    readonly cells: HTMLCollectionOf<HTMLTableDataCellElement | HTMLTableHeaderCellElement>;\n    /** @deprecated */\n    ch: string;\n    /** @deprecated */\n    chOff: string;\n    /**\n     * Retrieves the position of the object in the rows collection for the table.\n     */\n    readonly rowIndex: number;\n    /**\n     * Retrieves the position of the object in the collection.\n     */\n    readonly sectionRowIndex: number;\n    /** @deprecated */\n    vAlign: string;\n    /**\n     * Removes the specified cell from the table row, as well as from the cells collection.\n     * @param index Number that specifies the zero-based position of the cell to remove from the table row. If no value is provided, the last cell in the cells collection is deleted.\n     */\n    deleteCell(index: number): void;\n    /**\n     * Creates a new cell in the table row, and adds the cell to the cells collection.\n     * @param index Number that specifies where to insert the cell in the tr. The default value is -1, which appends the new cell to the end of the cells collection.\n     */\n    insertCell(index?: number): HTMLTableDataCellElement;\n    addEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLTableRowElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLTableRowElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLTableRowElement: {\n    prototype: HTMLTableRowElement;\n    new(): HTMLTableRowElement;\n};\n\n/** Provides special properties and methods (beyond the HTMLElement interface it also has available to it by inheritance) for manipulating the layout and presentation of sections, that is headers, footers and bodies, in an HTML table. */\ninterface HTMLTableSectionElement extends HTMLElement {\n    /**\n     * Sets or retrieves a value that indicates the table alignment.\n     */\n    /** @deprecated */\n    align: string;\n    /** @deprecated */\n    ch: string;\n    /** @deprecated */\n    chOff: string;\n    /**\n     * Sets or retrieves the number of horizontal rows contained in the object.\n     */\n    readonly rows: HTMLCollectionOf<HTMLTableRowElement>;\n    /** @deprecated */\n    vAlign: string;\n    /**\n     * Removes the specified row (tr) from the element and from the rows collection.\n     * @param index Number that specifies the zero-based position in the rows collection of the row to remove.\n     */\n    deleteRow(index: number): void;\n    /**\n     * Creates a new row (tr) in the table, and adds the row to the rows collection.\n     * @param index Number that specifies where to insert the row in the rows collection. The default value is -1, which appends the new row to the end of the rows collection.\n     */\n    insertRow(index?: number): HTMLTableRowElement;\n    addEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLTableSectionElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLTableSectionElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLTableSectionElement: {\n    prototype: HTMLTableSectionElement;\n    new(): HTMLTableSectionElement;\n};\n\n/** Enables access to the contents of an HTML <template> element. */\ninterface HTMLTemplateElement extends HTMLElement {\n    readonly content: DocumentFragment;\n    addEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLTemplateElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLTemplateElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLTemplateElement: {\n    prototype: HTMLTemplateElement;\n    new(): HTMLTemplateElement;\n};\n\n/** Provides special properties and methods for manipulating the layout and presentation of <textarea> elements. */\ninterface HTMLTextAreaElement extends HTMLElement {\n    autocomplete: string;\n    /**\n     * Sets or retrieves the width of the object.\n     */\n    cols: number;\n    /**\n     * Sets or retrieves the initial contents of the object.\n     */\n    defaultValue: string;\n    dirName: string;\n    disabled: boolean;\n    /**\n     * Retrieves a reference to the form that the object is embedded in.\n     */\n    readonly form: HTMLFormElement | null;\n    readonly labels: NodeListOf<HTMLLabelElement>;\n    /**\n     * Sets or retrieves the maximum number of characters that the user can enter in a text control.\n     */\n    maxLength: number;\n    minLength: number;\n    /**\n     * Sets or retrieves the name of the object.\n     */\n    name: string;\n    /**\n     * Gets or sets a text string that is displayed in an input field as a hint or prompt to users as the format or type of information they need to enter.The text appears in an input field until the user puts focus on the field.\n     */\n    placeholder: string;\n    /**\n     * Sets or retrieves the value indicated whether the content of the object is read-only.\n     */\n    readOnly: boolean;\n    /**\n     * When present, marks an element that can\'t be submitted without a value.\n     */\n    required: boolean;\n    /**\n     * Sets or retrieves the number of horizontal rows contained in the object.\n     */\n    rows: number;\n    selectionDirection: "forward" | "backward" | "none";\n    /**\n     * Gets or sets the end position or offset of a text selection.\n     */\n    selectionEnd: number;\n    /**\n     * Gets or sets the starting position or offset of a text selection.\n     */\n    selectionStart: number;\n    readonly textLength: number;\n    /**\n     * Retrieves the type of control.\n     */\n    readonly type: string;\n    /**\n     * Returns the error message that would be displayed if the user submits the form, or an empty string if no error message. It also triggers the standard error message, such as "this is a required field". The result is that the user sees validation messages without actually submitting.\n     */\n    readonly validationMessage: string;\n    /**\n     * Returns a  ValidityState object that represents the validity states of an element.\n     */\n    readonly validity: ValidityState;\n    /**\n     * Retrieves or sets the text in the entry field of the textArea element.\n     */\n    value: string;\n    /**\n     * Returns whether an element will successfully validate based on forms validation rules and constraints.\n     */\n    readonly willValidate: boolean;\n    /**\n     * Sets or retrieves how to handle wordwrapping in the object.\n     */\n    wrap: string;\n    /**\n     * Returns whether a form will validate when it is submitted, without having to submit it.\n     */\n    checkValidity(): boolean;\n    reportValidity(): boolean;\n    /**\n     * Highlights the input area of a form element.\n     */\n    select(): void;\n    /**\n     * Sets a custom error message that is displayed when a form is submitted.\n     * @param error Sets a custom error message that is displayed when a form is submitted.\n     */\n    setCustomValidity(error: string): void;\n    setRangeText(replacement: string): void;\n    setRangeText(replacement: string, start: number, end: number, selectionMode?: SelectionMode): void;\n    /**\n     * Sets the start and end positions of a selection in a text field.\n     * @param start The offset into the text field for the start of the selection.\n     * @param end The offset into the text field for the end of the selection.\n     * @param direction The direction in which the selection is performed.\n     */\n    setSelectionRange(start: number | null, end: number | null, direction?: "forward" | "backward" | "none"): void;\n    addEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLTextAreaElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLTextAreaElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLTextAreaElement: {\n    prototype: HTMLTextAreaElement;\n    new(): HTMLTextAreaElement;\n};\n\n/** Provides special properties (beyond the regular HTMLElement interface it also has available to it by inheritance) for manipulating <time> elements. */\ninterface HTMLTimeElement extends HTMLElement {\n    dateTime: string;\n    addEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLTimeElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLTimeElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLTimeElement: {\n    prototype: HTMLTimeElement;\n    new(): HTMLTimeElement;\n};\n\n/** Contains the title for a document. This element inherits all of the properties and methods of the HTMLElement interface. */\ninterface HTMLTitleElement extends HTMLElement {\n    /**\n     * Retrieves or sets the text of the object as a string.\n     */\n    text: string;\n    addEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLTitleElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLTitleElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLTitleElement: {\n    prototype: HTMLTitleElement;\n    new(): HTMLTitleElement;\n};\n\n/** The HTMLTrackElement */\ninterface HTMLTrackElement extends HTMLElement {\n    default: boolean;\n    kind: string;\n    label: string;\n    readonly readyState: number;\n    src: string;\n    srclang: string;\n    readonly track: TextTrack;\n    readonly ERROR: number;\n    readonly LOADED: number;\n    readonly LOADING: number;\n    readonly NONE: number;\n    addEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLTrackElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLTrackElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLTrackElement: {\n    prototype: HTMLTrackElement;\n    new(): HTMLTrackElement;\n    readonly ERROR: number;\n    readonly LOADED: number;\n    readonly LOADING: number;\n    readonly NONE: number;\n};\n\n/** Provides special properties (beyond those defined on the regular HTMLElement interface it also has available to it by inheritance) for manipulating unordered list elements. */\ninterface HTMLUListElement extends HTMLElement {\n    /** @deprecated */\n    compact: boolean;\n    /** @deprecated */\n    type: string;\n    addEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLUListElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLUListElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLUListElement: {\n    prototype: HTMLUListElement;\n    new(): HTMLUListElement;\n};\n\n/** An invalid HTML element and derives from the HTMLElement interface, but without implementing any additional properties or methods. */\ninterface HTMLUnknownElement extends HTMLElement {\n    addEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLUnknownElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLUnknownElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLUnknownElement: {\n    prototype: HTMLUnknownElement;\n    new(): HTMLUnknownElement;\n};\n\n/** Provides special properties and methods for manipulating video objects. It also inherits properties and methods of HTMLMediaElement and HTMLElement. */\ninterface HTMLVideoElement extends HTMLMediaElement {\n    /**\n     * Gets or sets the height of the video element.\n     */\n    height: number;\n    /**\n     * Gets or sets the playsinline of the video element. for example, On iPhone, video elements will now be allowed to play inline, and will not automatically enter fullscreen mode when playback begins.\n     */\n    playsInline: boolean;\n    /**\n     * Gets or sets a URL of an image to display, for example, like a movie poster. This can be a still frame from the video, or another image if no video data is available.\n     */\n    poster: string;\n    /**\n     * Gets the intrinsic height of a video in CSS pixels, or zero if the dimensions are not known.\n     */\n    readonly videoHeight: number;\n    /**\n     * Gets the intrinsic width of a video in CSS pixels, or zero if the dimensions are not known.\n     */\n    readonly videoWidth: number;\n    /**\n     * Gets or sets the width of the video element.\n     */\n    width: number;\n    getVideoPlaybackQuality(): VideoPlaybackQuality;\n    addEventListener<K extends keyof HTMLMediaElementEventMap>(type: K, listener: (this: HTMLVideoElement, ev: HTMLMediaElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof HTMLMediaElementEventMap>(type: K, listener: (this: HTMLVideoElement, ev: HTMLMediaElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var HTMLVideoElement: {\n    prototype: HTMLVideoElement;\n    new(): HTMLVideoElement;\n};\n\n/** Events that fire when the fragment identifier of the URL has changed. */\ninterface HashChangeEvent extends Event {\n    /**\n     * Returns the URL of the session history entry that is now current.\n     */\n    readonly newURL: string;\n    /**\n     * Returns the URL of the session history entry that was previously current.\n     */\n    readonly oldURL: string;\n}\n\ndeclare var HashChangeEvent: {\n    prototype: HashChangeEvent;\n    new(type: string, eventInitDict?: HashChangeEventInit): HashChangeEvent;\n};\n\n/** This Fetch API interface allows you to perform various actions on HTTP request and response headers. These actions include retrieving, setting, adding to, and removing. A Headers object has an associated header list, which is initially empty and consists of zero or more name and value pairs.  You can add to this using methods like append() (see Examples.) In all methods of this interface, header names are matched by case-insensitive byte sequence. */\ninterface Headers {\n    append(name: string, value: string): void;\n    delete(name: string): void;\n    get(name: string): string | null;\n    has(name: string): boolean;\n    set(name: string, value: string): void;\n    forEach(callbackfn: (value: string, key: string, parent: Headers) => void, thisArg?: any): void;\n}\n\ndeclare var Headers: {\n    prototype: Headers;\n    new(init?: HeadersInit): Headers;\n};\n\n/** Allows manipulation of the browser session history, that is the pages visited in the tab or frame that the current page is loaded in. */\ninterface History {\n    readonly length: number;\n    scrollRestoration: ScrollRestoration;\n    readonly state: any;\n    back(): void;\n    forward(): void;\n    go(delta?: number): void;\n    pushState(data: any, title: string, url?: string | null): void;\n    replaceState(data: any, title: string, url?: string | null): void;\n}\n\ndeclare var History: {\n    prototype: History;\n    new(): History;\n};\n\ninterface IDBArrayKey extends Array<IDBValidKey> {\n}\n\n/** This IndexedDB API interface represents a cursor for traversing or iterating over multiple records in a database. */\ninterface IDBCursor {\n    /**\n     * Returns the direction ("next", "nextunique", "prev" or "prevunique") of the cursor.\n     */\n    readonly direction: IDBCursorDirection;\n    /**\n     * Returns the key of the cursor. Throws a "InvalidStateError" DOMException if the cursor is advancing or is finished.\n     */\n    readonly key: IDBValidKey;\n    /**\n     * Returns the effective key of the cursor. Throws a "InvalidStateError" DOMException if the cursor is advancing or is finished.\n     */\n    readonly primaryKey: IDBValidKey;\n    /**\n     * Returns the IDBObjectStore or IDBIndex the cursor was opened from.\n     */\n    readonly source: IDBObjectStore | IDBIndex;\n    /**\n     * Advances the cursor through the next count records in range.\n     */\n    advance(count: number): void;\n    /**\n     * Advances the cursor to the next record in range.\n     */\n    continue(key?: IDBValidKey): void;\n    /**\n     * Advances the cursor to the next record in range matching or after key and primaryKey. Throws an "InvalidAccessError" DOMException if the source is not an index.\n     */\n    continuePrimaryKey(key: IDBValidKey, primaryKey: IDBValidKey): void;\n    /**\n     * Delete the record pointed at by the cursor with a new value.\n     *\n     * If successful, request\'s result will be undefined.\n     */\n    delete(): IDBRequest<undefined>;\n    /**\n     * Updated the record pointed at by the cursor with a new value.\n     *\n     * Throws a "DataError" DOMException if the effective object store uses in-line keys and the key would have changed.\n     *\n     * If successful, request\'s result will be the record\'s key.\n     */\n    update(value: any): IDBRequest<IDBValidKey>;\n}\n\ndeclare var IDBCursor: {\n    prototype: IDBCursor;\n    new(): IDBCursor;\n};\n\n/** This IndexedDB API interface represents a cursor for traversing or iterating over multiple records in a database. It is the same as the IDBCursor, except that it includes the value property. */\ninterface IDBCursorWithValue extends IDBCursor {\n    /**\n     * Returns the cursor\'s current value.\n     */\n    readonly value: any;\n}\n\ndeclare var IDBCursorWithValue: {\n    prototype: IDBCursorWithValue;\n    new(): IDBCursorWithValue;\n};\n\ninterface IDBDatabaseEventMap {\n    "abort": Event;\n    "close": Event;\n    "error": Event;\n    "versionchange": IDBVersionChangeEvent;\n}\n\n/** This IndexedDB API interface provides a connection to a database; you can use an IDBDatabase object to open a transaction on your database then create, manipulate, and delete objects (data) in that database. The interface provides the only way to get and manage versions of the database. */\ninterface IDBDatabase extends EventTarget {\n    /**\n     * Returns the name of the database.\n     */\n    readonly name: string;\n    /**\n     * Returns a list of the names of object stores in the database.\n     */\n    readonly objectStoreNames: DOMStringList;\n    onabort: ((this: IDBDatabase, ev: Event) => any) | null;\n    onclose: ((this: IDBDatabase, ev: Event) => any) | null;\n    onerror: ((this: IDBDatabase, ev: Event) => any) | null;\n    onversionchange: ((this: IDBDatabase, ev: IDBVersionChangeEvent) => any) | null;\n    /**\n     * Returns the version of the database.\n     */\n    readonly version: number;\n    /**\n     * Closes the connection once all running transactions have finished.\n     */\n    close(): void;\n    /**\n     * Creates a new object store with the given name and options and returns a new IDBObjectStore.\n     *\n     * Throws a "InvalidStateError" DOMException if not called within an upgrade transaction.\n     */\n    createObjectStore(name: string, options?: IDBObjectStoreParameters): IDBObjectStore;\n    /**\n     * Deletes the object store with the given name.\n     *\n     * Throws a "InvalidStateError" DOMException if not called within an upgrade transaction.\n     */\n    deleteObjectStore(name: string): void;\n    /**\n     * Returns a new transaction with the given mode ("readonly" or "readwrite") and scope which can be a single object store name or an array of names.\n     */\n    transaction(storeNames: string | string[], mode?: IDBTransactionMode): IDBTransaction;\n    addEventListener<K extends keyof IDBDatabaseEventMap>(type: K, listener: (this: IDBDatabase, ev: IDBDatabaseEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof IDBDatabaseEventMap>(type: K, listener: (this: IDBDatabase, ev: IDBDatabaseEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var IDBDatabase: {\n    prototype: IDBDatabase;\n    new(): IDBDatabase;\n};\n\n/** In the following code snippet, we make a request to open a database, and include handlers for the success and error cases. For a full working example, see our To-do Notifications app (view example live.) */\ninterface IDBFactory {\n    /**\n     * Compares two values as keys. Returns -1 if key1 precedes key2, 1 if key2 precedes key1, and 0 if the keys are equal.\n     *\n     * Throws a "DataError" DOMException if either input is not a valid key.\n     */\n    cmp(first: any, second: any): number;\n    /**\n     * Attempts to delete the named database. If the database already exists and there are open connections that don\'t close in response to a versionchange event, the request will be blocked until all they close. If the request is successful request\'s result will be null.\n     */\n    deleteDatabase(name: string): IDBOpenDBRequest;\n    /**\n     * Attempts to open a connection to the named database with the current version, or 1 if it does not already exist. If the request is successful request\'s result will be the connection.\n     */\n    open(name: string, version?: number): IDBOpenDBRequest;\n}\n\ndeclare var IDBFactory: {\n    prototype: IDBFactory;\n    new(): IDBFactory;\n};\n\n/** IDBIndex interface of the IndexedDB API provides asynchronous access to an index in a database. An index is a kind of object store for looking up records in another object store, called the referenced object store. You use this interface to retrieve data. */\ninterface IDBIndex {\n    readonly keyPath: string | string[];\n    readonly multiEntry: boolean;\n    /**\n     * Returns the name of the index.\n     */\n    name: string;\n    /**\n     * Returns the IDBObjectStore the index belongs to.\n     */\n    readonly objectStore: IDBObjectStore;\n    readonly unique: boolean;\n    /**\n     * Retrieves the number of records matching the given key or key range in query.\n     *\n     * If successful, request\'s result will be the count.\n     */\n    count(key?: IDBValidKey | IDBKeyRange): IDBRequest<number>;\n    /**\n     * Retrieves the value of the first record matching the given key or key range in query.\n     *\n     * If successful, request\'s result will be the value, or undefined if there was no matching record.\n     */\n    get(key: IDBValidKey | IDBKeyRange): IDBRequest<any | undefined>;\n    /**\n     * Retrieves the values of the records matching the given key or key range in query (up to count if given).\n     *\n     * If successful, request\'s result will be an Array of the values.\n     */\n    getAll(query?: IDBValidKey | IDBKeyRange | null, count?: number): IDBRequest<any[]>;\n    /**\n     * Retrieves the keys of records matching the given key or key range in query (up to count if given).\n     *\n     * If successful, request\'s result will be an Array of the keys.\n     */\n    getAllKeys(query?: IDBValidKey | IDBKeyRange | null, count?: number): IDBRequest<IDBValidKey[]>;\n    /**\n     * Retrieves the key of the first record matching the given key or key range in query.\n     *\n     * If successful, request\'s result will be the key, or undefined if there was no matching record.\n     */\n    getKey(key: IDBValidKey | IDBKeyRange): IDBRequest<IDBValidKey | undefined>;\n    /**\n     * Opens a cursor over the records matching query, ordered by direction. If query is null, all records in index are matched.\n     *\n     * If successful, request\'s result will be an IDBCursorWithValue, or null if there were no matching records.\n     */\n    openCursor(query?: IDBValidKey | IDBKeyRange | null, direction?: IDBCursorDirection): IDBRequest<IDBCursorWithValue | null>;\n    /**\n     * Opens a cursor with key only flag set over the records matching query, ordered by direction. If query is null, all records in index are matched.\n     *\n     * If successful, request\'s result will be an IDBCursor, or null if there were no matching records.\n     */\n    openKeyCursor(query?: IDBValidKey | IDBKeyRange | null, direction?: IDBCursorDirection): IDBRequest<IDBCursor | null>;\n}\n\ndeclare var IDBIndex: {\n    prototype: IDBIndex;\n    new(): IDBIndex;\n};\n\n/** A key range can be a single value or a range with upper and lower bounds or endpoints. If the key range has both upper and lower bounds, then it is bounded; if it has no bounds, it is unbounded. A bounded key range can either be open (the endpoints are excluded) or closed (the endpoints are included). To retrieve all keys within a certain range, you can use the following code constructs: */\ninterface IDBKeyRange {\n    /**\n     * Returns lower bound, or undefined if none.\n     */\n    readonly lower: any;\n    /**\n     * Returns true if the lower open flag is set, and false otherwise.\n     */\n    readonly lowerOpen: boolean;\n    /**\n     * Returns upper bound, or undefined if none.\n     */\n    readonly upper: any;\n    /**\n     * Returns true if the upper open flag is set, and false otherwise.\n     */\n    readonly upperOpen: boolean;\n    /**\n     * Returns true if key is included in the range, and false otherwise.\n     */\n    includes(key: any): boolean;\n}\n\ndeclare var IDBKeyRange: {\n    prototype: IDBKeyRange;\n    new(): IDBKeyRange;\n    /**\n     * Returns a new IDBKeyRange spanning from lower to upper. If lowerOpen is true, lower is not included in the range. If upperOpen is true, upper is not included in the range.\n     */\n    bound(lower: any, upper: any, lowerOpen?: boolean, upperOpen?: boolean): IDBKeyRange;\n    /**\n     * Returns a new IDBKeyRange starting at key with no upper bound. If open is true, key is not included in the range.\n     */\n    lowerBound(lower: any, open?: boolean): IDBKeyRange;\n    /**\n     * Returns a new IDBKeyRange spanning only key.\n     */\n    only(value: any): IDBKeyRange;\n    /**\n     * Returns a new IDBKeyRange with no lower bound and ending at key. If open is true, key is not included in the range.\n     */\n    upperBound(upper: any, open?: boolean): IDBKeyRange;\n};\n\n/** This example shows a variety of different uses of object stores, from updating the data structure with IDBObjectStore.createIndex inside an onupgradeneeded function, to adding a new item to our object store with IDBObjectStore.add. For a full working example, see our To-do Notifications app (view example live.) */\ninterface IDBObjectStore {\n    /**\n     * Returns true if the store has a key generator, and false otherwise.\n     */\n    readonly autoIncrement: boolean;\n    /**\n     * Returns a list of the names of indexes in the store.\n     */\n    readonly indexNames: DOMStringList;\n    /**\n     * Returns the key path of the store, or null if none.\n     */\n    readonly keyPath: string | string[];\n    /**\n     * Returns the name of the store.\n     */\n    name: string;\n    /**\n     * Returns the associated transaction.\n     */\n    readonly transaction: IDBTransaction;\n    /**\n     * Adds or updates a record in store with the given value and key.\n     *\n     * If the store uses in-line keys and key is specified a "DataError" DOMException will be thrown.\n     *\n     * If put() is used, any existing record with the key will be replaced. If add() is used, and if a record with the key already exists the request will fail, with request\'s error set to a "ConstraintError" DOMException.\n     *\n     * If successful, request\'s result will be the record\'s key.\n     */\n    add(value: any, key?: IDBValidKey): IDBRequest<IDBValidKey>;\n    /**\n     * Deletes all records in store.\n     *\n     * If successful, request\'s result will be undefined.\n     */\n    clear(): IDBRequest<undefined>;\n    /**\n     * Retrieves the number of records matching the given key or key range in query.\n     *\n     * If successful, request\'s result will be the count.\n     */\n    count(key?: IDBValidKey | IDBKeyRange): IDBRequest<number>;\n    /**\n     * Creates a new index in store with the given name, keyPath and options and returns a new IDBIndex. If the keyPath and options define constraints that cannot be satisfied with the data already in store the upgrade transaction will abort with a "ConstraintError" DOMException.\n     *\n     * Throws an "InvalidStateError" DOMException if not called within an upgrade transaction.\n     */\n    createIndex(name: string, keyPath: string | string[], options?: IDBIndexParameters): IDBIndex;\n    /**\n     * Deletes records in store with the given key or in the given key range in query.\n     *\n     * If successful, request\'s result will be undefined.\n     */\n    delete(key: IDBValidKey | IDBKeyRange): IDBRequest<undefined>;\n    /**\n     * Deletes the index in store with the given name.\n     *\n     * Throws an "InvalidStateError" DOMException if not called within an upgrade transaction.\n     */\n    deleteIndex(name: string): void;\n    /**\n     * Retrieves the value of the first record matching the given key or key range in query.\n     *\n     * If successful, request\'s result will be the value, or undefined if there was no matching record.\n     */\n    get(query: IDBValidKey | IDBKeyRange): IDBRequest<any | undefined>;\n    /**\n     * Retrieves the values of the records matching the given key or key range in query (up to count if given).\n     *\n     * If successful, request\'s result will be an Array of the values.\n     */\n    getAll(query?: IDBValidKey | IDBKeyRange | null, count?: number): IDBRequest<any[]>;\n    /**\n     * Retrieves the keys of records matching the given key or key range in query (up to count if given).\n     *\n     * If successful, request\'s result will be an Array of the keys.\n     */\n    getAllKeys(query?: IDBValidKey | IDBKeyRange | null, count?: number): IDBRequest<IDBValidKey[]>;\n    /**\n     * Retrieves the key of the first record matching the given key or key range in query.\n     *\n     * If successful, request\'s result will be the key, or undefined if there was no matching record.\n     */\n    getKey(query: IDBValidKey | IDBKeyRange): IDBRequest<IDBValidKey | undefined>;\n    index(name: string): IDBIndex;\n    /**\n     * Opens a cursor over the records matching query, ordered by direction. If query is null, all records in store are matched.\n     *\n     * If successful, request\'s result will be an IDBCursorWithValue pointing at the first matching record, or null if there were no matching records.\n     */\n    openCursor(query?: IDBValidKey | IDBKeyRange | null, direction?: IDBCursorDirection): IDBRequest<IDBCursorWithValue | null>;\n    /**\n     * Opens a cursor with key only flag set over the records matching query, ordered by direction. If query is null, all records in store are matched.\n     *\n     * If successful, request\'s result will be an IDBCursor pointing at the first matching record, or null if there were no matching records.\n     */\n    openKeyCursor(query?: IDBValidKey | IDBKeyRange | null, direction?: IDBCursorDirection): IDBRequest<IDBCursor | null>;\n    /**\n     * Adds or updates a record in store with the given value and key.\n     *\n     * If the store uses in-line keys and key is specified a "DataError" DOMException will be thrown.\n     *\n     * If put() is used, any existing record with the key will be replaced. If add() is used, and if a record with the key already exists the request will fail, with request\'s error set to a "ConstraintError" DOMException.\n     *\n     * If successful, request\'s result will be the record\'s key.\n     */\n    put(value: any, key?: IDBValidKey): IDBRequest<IDBValidKey>;\n}\n\ndeclare var IDBObjectStore: {\n    prototype: IDBObjectStore;\n    new(): IDBObjectStore;\n};\n\ninterface IDBOpenDBRequestEventMap extends IDBRequestEventMap {\n    "blocked": Event;\n    "upgradeneeded": IDBVersionChangeEvent;\n}\n\n/** Also inherits methods from its parents IDBRequest and EventTarget. */\ninterface IDBOpenDBRequest extends IDBRequest<IDBDatabase> {\n    onblocked: ((this: IDBOpenDBRequest, ev: Event) => any) | null;\n    onupgradeneeded: ((this: IDBOpenDBRequest, ev: IDBVersionChangeEvent) => any) | null;\n    addEventListener<K extends keyof IDBOpenDBRequestEventMap>(type: K, listener: (this: IDBOpenDBRequest, ev: IDBOpenDBRequestEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof IDBOpenDBRequestEventMap>(type: K, listener: (this: IDBOpenDBRequest, ev: IDBOpenDBRequestEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var IDBOpenDBRequest: {\n    prototype: IDBOpenDBRequest;\n    new(): IDBOpenDBRequest;\n};\n\ninterface IDBRequestEventMap {\n    "error": Event;\n    "success": Event;\n}\n\n/** The request object does not initially contain any information about the result of the operation, but once information becomes available, an event is fired on the request, and the information becomes available through the properties of the IDBRequest instance. */\ninterface IDBRequest<T = any> extends EventTarget {\n    /**\n     * When a request is completed, returns the error (a DOMException), or null if the request succeeded. Throws a "InvalidStateError" DOMException if the request is still pending.\n     */\n    readonly error: DOMException | null;\n    onerror: ((this: IDBRequest<T>, ev: Event) => any) | null;\n    onsuccess: ((this: IDBRequest<T>, ev: Event) => any) | null;\n    /**\n     * Returns "pending" until a request is complete, then returns "done".\n     */\n    readonly readyState: IDBRequestReadyState;\n    /**\n     * When a request is completed, returns the result, or undefined if the request failed. Throws a "InvalidStateError" DOMException if the request is still pending.\n     */\n    readonly result: T;\n    /**\n     * Returns the IDBObjectStore, IDBIndex, or IDBCursor the request was made against, or null if is was an open request.\n     */\n    readonly source: IDBObjectStore | IDBIndex | IDBCursor;\n    /**\n     * Returns the IDBTransaction the request was made within. If this as an open request, then it returns an upgrade transaction while it is running, or null otherwise.\n     */\n    readonly transaction: IDBTransaction | null;\n    addEventListener<K extends keyof IDBRequestEventMap>(type: K, listener: (this: IDBRequest<T>, ev: IDBRequestEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof IDBRequestEventMap>(type: K, listener: (this: IDBRequest<T>, ev: IDBRequestEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var IDBRequest: {\n    prototype: IDBRequest;\n    new(): IDBRequest;\n};\n\ninterface IDBTransactionEventMap {\n    "abort": Event;\n    "complete": Event;\n    "error": Event;\n}\n\ninterface IDBTransaction extends EventTarget {\n    /**\n     * Returns the transaction\'s connection.\n     */\n    readonly db: IDBDatabase;\n    /**\n     * If the transaction was aborted, returns the error (a DOMException) providing the reason.\n     */\n    readonly error: DOMException;\n    /**\n     * Returns the mode the transaction was created with ("readonly" or "readwrite"), or "versionchange" for an upgrade transaction.\n     */\n    readonly mode: IDBTransactionMode;\n    /**\n     * Returns a list of the names of object stores in the transaction\'s scope. For an upgrade transaction this is all object stores in the database.\n     */\n    readonly objectStoreNames: DOMStringList;\n    onabort: ((this: IDBTransaction, ev: Event) => any) | null;\n    oncomplete: ((this: IDBTransaction, ev: Event) => any) | null;\n    onerror: ((this: IDBTransaction, ev: Event) => any) | null;\n    /**\n     * Aborts the transaction. All pending requests will fail with a "AbortError" DOMException and all changes made to the database will be reverted.\n     */\n    abort(): void;\n    /**\n     * Returns an IDBObjectStore in the transaction\'s scope.\n     */\n    objectStore(name: string): IDBObjectStore;\n    addEventListener<K extends keyof IDBTransactionEventMap>(type: K, listener: (this: IDBTransaction, ev: IDBTransactionEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof IDBTransactionEventMap>(type: K, listener: (this: IDBTransaction, ev: IDBTransactionEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var IDBTransaction: {\n    prototype: IDBTransaction;\n    new(): IDBTransaction;\n};\n\n/** This IndexedDB API interface indicates that the version of the database has changed, as the result of an IDBOpenDBRequest.onupgradeneeded event handler function. */\ninterface IDBVersionChangeEvent extends Event {\n    readonly newVersion: number | null;\n    readonly oldVersion: number;\n}\n\ndeclare var IDBVersionChangeEvent: {\n    prototype: IDBVersionChangeEvent;\n    new(type: string, eventInitDict?: IDBVersionChangeEventInit): IDBVersionChangeEvent;\n};\n\n/** The IIRFilterNode interface of the Web Audio API is a AudioNode processor which implements a general infinite impulse response (IIR)  filter; this type of filter can be used to implement tone control devices and graphic equalizers as well. It lets the parameters of the filter response be specified, so that it can be tuned as needed. */\ninterface IIRFilterNode extends AudioNode {\n    getFrequencyResponse(frequencyHz: Float32Array, magResponse: Float32Array, phaseResponse: Float32Array): void;\n}\n\ndeclare var IIRFilterNode: {\n    prototype: IIRFilterNode;\n    new(context: BaseAudioContext, options: IIRFilterOptions): IIRFilterNode;\n};\n\ninterface ImageBitmap {\n    /**\n     * Returns the intrinsic height of the image, in CSS pixels.\n     */\n    readonly height: number;\n    /**\n     * Returns the intrinsic width of the image, in CSS pixels.\n     */\n    readonly width: number;\n    /**\n     * Releases imageBitmap\'s underlying bitmap data.\n     */\n    close(): void;\n}\n\ndeclare var ImageBitmap: {\n    prototype: ImageBitmap;\n    new(): ImageBitmap;\n};\n\ninterface ImageBitmapRenderingContext {\n    /**\n     * Returns the canvas element that the context is bound to.\n     */\n    readonly canvas: HTMLCanvasElement | OffscreenCanvas;\n    /**\n     * Transfers the underlying bitmap data from imageBitmap to context, and the bitmap becomes the contents of the canvas element to which context is bound.\n     */\n    transferFromImageBitmap(bitmap: ImageBitmap | null): void;\n}\n\ndeclare var ImageBitmapRenderingContext: {\n    prototype: ImageBitmapRenderingContext;\n    new(): ImageBitmapRenderingContext;\n};\n\n/** The underlying pixel data of an area of a <canvas> element. It is created using the ImageData() constructor or creator methods on the CanvasRenderingContext2D object associated with a canvas: createImageData() and getImageData(). It can also be used to set a part of the canvas by using putImageData(). */\ninterface ImageData {\n    /**\n     * Returns the one-dimensional array containing the data in RGBA order, as integers in the range 0 to 255.\n     */\n    readonly data: Uint8ClampedArray;\n    /**\n     * Returns the actual dimensions of the data in the ImageData object, in pixels.\n     */\n    readonly height: number;\n    /**\n     * Returns the actual dimensions of the data in the ImageData object, in pixels.\n     */\n    readonly width: number;\n}\n\ndeclare var ImageData: {\n    prototype: ImageData;\n    new(sw: number, sh: number): ImageData;\n    new(data: Uint8ClampedArray, sw: number, sh?: number): ImageData;\n};\n\ninterface InnerHTML {\n    innerHTML: string;\n}\n\ninterface InputDeviceInfo extends MediaDeviceInfo {\n    getCapabilities(): MediaTrackCapabilities;\n}\n\ndeclare var InputDeviceInfo: {\n    prototype: InputDeviceInfo;\n    new(): InputDeviceInfo;\n};\n\ninterface InputEvent extends UIEvent {\n    readonly data: string | null;\n    readonly inputType: string;\n    readonly isComposing: boolean;\n}\n\ndeclare var InputEvent: {\n    prototype: InputEvent;\n    new(type: string, eventInitDict?: InputEventInit): InputEvent;\n};\n\n/** provides a way to asynchronously observe changes in the intersection of a target element with an ancestor element or with a top-level document\'s viewport. */\ninterface IntersectionObserver {\n    readonly root: Element | Document | null;\n    readonly rootMargin: string;\n    readonly thresholds: ReadonlyArray<number>;\n    disconnect(): void;\n    observe(target: Element): void;\n    takeRecords(): IntersectionObserverEntry[];\n    unobserve(target: Element): void;\n}\n\ndeclare var IntersectionObserver: {\n    prototype: IntersectionObserver;\n    new(callback: IntersectionObserverCallback, options?: IntersectionObserverInit): IntersectionObserver;\n};\n\n/** This Intersection Observer API interface describes the intersection between the target element and its root container at a specific moment of transition. */\ninterface IntersectionObserverEntry {\n    readonly boundingClientRect: DOMRectReadOnly;\n    readonly intersectionRatio: number;\n    readonly intersectionRect: DOMRectReadOnly;\n    readonly isIntersecting: boolean;\n    readonly rootBounds: DOMRectReadOnly | null;\n    readonly target: Element;\n    readonly time: number;\n}\n\ndeclare var IntersectionObserverEntry: {\n    prototype: IntersectionObserverEntry;\n    new(intersectionObserverEntryInit: IntersectionObserverEntryInit): IntersectionObserverEntry;\n};\n\n/** KeyboardEvent objects describe a user interaction with the keyboard; each event describes a single interaction between the user and a key (or combination of a key with modifier keys) on the keyboard. */\ninterface KeyboardEvent extends UIEvent {\n    readonly altKey: boolean;\n    /** @deprecated */\n    char: string;\n    /** @deprecated */\n    readonly charCode: number;\n    readonly code: string;\n    readonly ctrlKey: boolean;\n    readonly isComposing: boolean;\n    readonly key: string;\n    /** @deprecated */\n    readonly keyCode: number;\n    readonly location: number;\n    readonly metaKey: boolean;\n    readonly repeat: boolean;\n    readonly shiftKey: boolean;\n    getModifierState(keyArg: string): boolean;\n    readonly DOM_KEY_LOCATION_LEFT: number;\n    readonly DOM_KEY_LOCATION_NUMPAD: number;\n    readonly DOM_KEY_LOCATION_RIGHT: number;\n    readonly DOM_KEY_LOCATION_STANDARD: number;\n}\n\ndeclare var KeyboardEvent: {\n    prototype: KeyboardEvent;\n    new(type: string, eventInitDict?: KeyboardEventInit): KeyboardEvent;\n    readonly DOM_KEY_LOCATION_LEFT: number;\n    readonly DOM_KEY_LOCATION_NUMPAD: number;\n    readonly DOM_KEY_LOCATION_RIGHT: number;\n    readonly DOM_KEY_LOCATION_STANDARD: number;\n};\n\ninterface KeyframeEffect extends AnimationEffect {\n    composite: CompositeOperation;\n    iterationComposite: IterationCompositeOperation;\n    target: Element | null;\n    getKeyframes(): ComputedKeyframe[];\n    setKeyframes(keyframes: Keyframe[] | PropertyIndexedKeyframes | null): void;\n}\n\ndeclare var KeyframeEffect: {\n    prototype: KeyframeEffect;\n    new(target: Element | null, keyframes: Keyframe[] | PropertyIndexedKeyframes | null, options?: number | KeyframeEffectOptions): KeyframeEffect;\n    new(source: KeyframeEffect): KeyframeEffect;\n};\n\ninterface LinkStyle {\n    readonly sheet: CSSStyleSheet | null;\n}\n\ninterface ListeningStateChangedEvent extends Event {\n    readonly label: string;\n    readonly state: ListeningState;\n}\n\ndeclare var ListeningStateChangedEvent: {\n    prototype: ListeningStateChangedEvent;\n    new(): ListeningStateChangedEvent;\n};\n\n/** The location (URL) of the object it is linked to. Changes done on it are reflected on the object it relates to. Both the Document and Window interface have such a linked Location, accessible via Document.location and Window.location respectively. */\ninterface Location {\n    /**\n     * Returns a DOMStringList object listing the origins of the ancestor browsing contexts, from the parent browsing context to the top-level browsing context.\n     */\n    readonly ancestorOrigins: DOMStringList;\n    /**\n     * Returns the Location object\'s URL\'s fragment (includes leading "#" if non-empty).\n     *\n     * Can be set, to navigate to the same URL with a changed fragment (ignores leading "#").\n     */\n    hash: string;\n    /**\n     * Returns the Location object\'s URL\'s host and port (if different from the default port for the scheme).\n     *\n     * Can be set, to navigate to the same URL with a changed host and port.\n     */\n    host: string;\n    /**\n     * Returns the Location object\'s URL\'s host.\n     *\n     * Can be set, to navigate to the same URL with a changed host.\n     */\n    hostname: string;\n    /**\n     * Returns the Location object\'s URL.\n     *\n     * Can be set, to navigate to the given URL.\n     */\n    href: string;\n    toString(): string;\n    /**\n     * Returns the Location object\'s URL\'s origin.\n     */\n    readonly origin: string;\n    /**\n     * Returns the Location object\'s URL\'s path.\n     *\n     * Can be set, to navigate to the same URL with a changed path.\n     */\n    pathname: string;\n    /**\n     * Returns the Location object\'s URL\'s port.\n     *\n     * Can be set, to navigate to the same URL with a changed port.\n     */\n    port: string;\n    /**\n     * Returns the Location object\'s URL\'s scheme.\n     *\n     * Can be set, to navigate to the same URL with a changed scheme.\n     */\n    protocol: string;\n    /**\n     * Returns the Location object\'s URL\'s query (includes leading "?" if non-empty).\n     *\n     * Can be set, to navigate to the same URL with a changed query (ignores leading "?").\n     */\n    search: string;\n    /**\n     * Navigates to the given URL.\n     */\n    assign(url: string): void;\n    /**\n     * Reloads the current page.\n     */\n    reload(): void;\n    /** @deprecated */\n    reload(forcedReload: boolean): void;\n    /**\n     * Removes the current page from the session history and navigates to the given URL.\n     */\n    replace(url: string): void;\n}\n\ndeclare var Location: {\n    prototype: Location;\n    new(): Location;\n};\n\ninterface MSAssertion {\n    readonly id: string;\n    readonly type: MSCredentialType;\n}\n\ndeclare var MSAssertion: {\n    prototype: MSAssertion;\n    new(): MSAssertion;\n};\n\ninterface MSBlobBuilder {\n    append(data: any, endings?: string): void;\n    getBlob(contentType?: string): Blob;\n}\n\ndeclare var MSBlobBuilder: {\n    prototype: MSBlobBuilder;\n    new(): MSBlobBuilder;\n};\n\ninterface MSFIDOCredentialAssertion extends MSAssertion {\n    readonly algorithm: string | Algorithm;\n    readonly attestation: any;\n    readonly publicKey: string;\n    readonly transportHints: MSTransportType[];\n}\n\ndeclare var MSFIDOCredentialAssertion: {\n    prototype: MSFIDOCredentialAssertion;\n    new(): MSFIDOCredentialAssertion;\n};\n\ninterface MSFIDOSignature {\n    readonly authnrData: string;\n    readonly clientData: string;\n    readonly signature: string;\n}\n\ndeclare var MSFIDOSignature: {\n    prototype: MSFIDOSignature;\n    new(): MSFIDOSignature;\n};\n\ninterface MSFIDOSignatureAssertion extends MSAssertion {\n    readonly signature: MSFIDOSignature;\n}\n\ndeclare var MSFIDOSignatureAssertion: {\n    prototype: MSFIDOSignatureAssertion;\n    new(): MSFIDOSignatureAssertion;\n};\n\ninterface MSFileSaver {\n    msSaveBlob(blob: any, defaultName?: string): boolean;\n    msSaveOrOpenBlob(blob: any, defaultName?: string): boolean;\n}\n\ninterface MSGesture {\n    target: Element;\n    addPointer(pointerId: number): void;\n    stop(): void;\n}\n\ndeclare var MSGesture: {\n    prototype: MSGesture;\n    new(): MSGesture;\n};\n\n/** The msGraphicsTrust() constructor returns an object that provides properties for info on protected video playback. */\ninterface MSGraphicsTrust {\n    readonly constrictionActive: boolean;\n    readonly status: string;\n}\n\ndeclare var MSGraphicsTrust: {\n    prototype: MSGraphicsTrust;\n    new(): MSGraphicsTrust;\n};\n\ninterface MSInputMethodContextEventMap {\n    "MSCandidateWindowHide": Event;\n    "MSCandidateWindowShow": Event;\n    "MSCandidateWindowUpdate": Event;\n}\n\ninterface MSInputMethodContext extends EventTarget {\n    readonly compositionEndOffset: number;\n    readonly compositionStartOffset: number;\n    oncandidatewindowhide: ((this: MSInputMethodContext, ev: Event) => any) | null;\n    oncandidatewindowshow: ((this: MSInputMethodContext, ev: Event) => any) | null;\n    oncandidatewindowupdate: ((this: MSInputMethodContext, ev: Event) => any) | null;\n    readonly target: HTMLElement;\n    getCandidateWindowClientRect(): ClientRect;\n    getCompositionAlternatives(): string[];\n    hasComposition(): boolean;\n    isCandidateWindowVisible(): boolean;\n    addEventListener<K extends keyof MSInputMethodContextEventMap>(type: K, listener: (this: MSInputMethodContext, ev: MSInputMethodContextEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof MSInputMethodContextEventMap>(type: K, listener: (this: MSInputMethodContext, ev: MSInputMethodContextEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var MSInputMethodContext: {\n    prototype: MSInputMethodContext;\n    new(): MSInputMethodContext;\n};\n\ninterface MSMediaKeyError {\n    readonly code: number;\n    readonly systemCode: number;\n    readonly MS_MEDIA_KEYERR_CLIENT: number;\n    readonly MS_MEDIA_KEYERR_DOMAIN: number;\n    readonly MS_MEDIA_KEYERR_HARDWARECHANGE: number;\n    readonly MS_MEDIA_KEYERR_OUTPUT: number;\n    readonly MS_MEDIA_KEYERR_SERVICE: number;\n    readonly MS_MEDIA_KEYERR_UNKNOWN: number;\n}\n\ndeclare var MSMediaKeyError: {\n    prototype: MSMediaKeyError;\n    new(): MSMediaKeyError;\n    readonly MS_MEDIA_KEYERR_CLIENT: number;\n    readonly MS_MEDIA_KEYERR_DOMAIN: number;\n    readonly MS_MEDIA_KEYERR_HARDWARECHANGE: number;\n    readonly MS_MEDIA_KEYERR_OUTPUT: number;\n    readonly MS_MEDIA_KEYERR_SERVICE: number;\n    readonly MS_MEDIA_KEYERR_UNKNOWN: number;\n};\n\ninterface MSMediaKeySession extends EventTarget {\n    readonly error: MSMediaKeyError | null;\n    readonly keySystem: string;\n    readonly sessionId: string;\n    close(): void;\n    update(key: Uint8Array): void;\n}\n\ndeclare var MSMediaKeySession: {\n    prototype: MSMediaKeySession;\n    new(): MSMediaKeySession;\n};\n\ninterface MSMediaKeys {\n    readonly keySystem: string;\n    createSession(type: string, initData: Uint8Array, cdmData?: Uint8Array | null): MSMediaKeySession;\n}\n\ndeclare var MSMediaKeys: {\n    prototype: MSMediaKeys;\n    new(keySystem: string): MSMediaKeys;\n    isTypeSupported(keySystem: string, type?: string | null): boolean;\n    isTypeSupportedWithFeatures(keySystem: string, type?: string | null): string;\n};\n\ninterface MSNavigatorDoNotTrack {\n    confirmSiteSpecificTrackingException(args: ConfirmSiteSpecificExceptionsInformation): boolean;\n    confirmWebWideTrackingException(args: ExceptionInformation): boolean;\n    removeSiteSpecificTrackingException(args: ExceptionInformation): void;\n    removeWebWideTrackingException(args: ExceptionInformation): void;\n    storeSiteSpecificTrackingException(args: StoreSiteSpecificExceptionsInformation): void;\n    storeWebWideTrackingException(args: StoreExceptionsInformation): void;\n}\n\ninterface MSStream {\n    readonly type: string;\n    msClose(): void;\n    msDetachStream(): any;\n}\n\ndeclare var MSStream: {\n    prototype: MSStream;\n    new(): MSStream;\n};\n\n/** The MediaDevicesInfo interface contains information that describes a single media input or output device. */\ninterface MediaDeviceInfo {\n    readonly deviceId: string;\n    readonly groupId: string;\n    readonly kind: MediaDeviceKind;\n    readonly label: string;\n    toJSON(): any;\n}\n\ndeclare var MediaDeviceInfo: {\n    prototype: MediaDeviceInfo;\n    new(): MediaDeviceInfo;\n};\n\ninterface MediaDevicesEventMap {\n    "devicechange": Event;\n}\n\n/** Provides access to connected media input devices like cameras and microphones, as well as screen sharing. In essence, it lets you obtain access to any hardware source of media data. */\ninterface MediaDevices extends EventTarget {\n    ondevicechange: ((this: MediaDevices, ev: Event) => any) | null;\n    enumerateDevices(): Promise<MediaDeviceInfo[]>;\n    getSupportedConstraints(): MediaTrackSupportedConstraints;\n    getUserMedia(constraints?: MediaStreamConstraints): Promise<MediaStream>;\n    addEventListener<K extends keyof MediaDevicesEventMap>(type: K, listener: (this: MediaDevices, ev: MediaDevicesEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof MediaDevicesEventMap>(type: K, listener: (this: MediaDevices, ev: MediaDevicesEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var MediaDevices: {\n    prototype: MediaDevices;\n    new(): MediaDevices;\n};\n\n/** A MediaElementSourceNode has no inputs and exactly one output, and is created using the AudioContext.createMediaElementSource method. The amount of channels in the output equals the number of channels of the audio referenced by the HTMLMediaElement used in the creation of the node, or is 1 if the HTMLMediaElement has no audio. */\ninterface MediaElementAudioSourceNode extends AudioNode {\n    readonly mediaElement: HTMLMediaElement;\n}\n\ndeclare var MediaElementAudioSourceNode: {\n    prototype: MediaElementAudioSourceNode;\n    new(context: AudioContext, options: MediaElementAudioSourceOptions): MediaElementAudioSourceNode;\n};\n\ninterface MediaEncryptedEvent extends Event {\n    readonly initData: ArrayBuffer | null;\n    readonly initDataType: string;\n}\n\ndeclare var MediaEncryptedEvent: {\n    prototype: MediaEncryptedEvent;\n    new(type: string, eventInitDict?: MediaEncryptedEventInit): MediaEncryptedEvent;\n};\n\n/** An error which occurred while handling media in an HTML media element based on HTMLMediaElement, such as <audio> or <video>. */\ninterface MediaError {\n    readonly code: number;\n    readonly message: string;\n    readonly MEDIA_ERR_ABORTED: number;\n    readonly MEDIA_ERR_DECODE: number;\n    readonly MEDIA_ERR_NETWORK: number;\n    readonly MEDIA_ERR_SRC_NOT_SUPPORTED: number;\n}\n\ndeclare var MediaError: {\n    prototype: MediaError;\n    new(): MediaError;\n    readonly MEDIA_ERR_ABORTED: number;\n    readonly MEDIA_ERR_DECODE: number;\n    readonly MEDIA_ERR_NETWORK: number;\n    readonly MEDIA_ERR_SRC_NOT_SUPPORTED: number;\n};\n\n/** This EncryptedMediaExtensions API interface contains the content and related data when the content decryption module generates a message for the session. */\ninterface MediaKeyMessageEvent extends Event {\n    readonly message: ArrayBuffer;\n    readonly messageType: MediaKeyMessageType;\n}\n\ndeclare var MediaKeyMessageEvent: {\n    prototype: MediaKeyMessageEvent;\n    new(type: string, eventInitDict: MediaKeyMessageEventInit): MediaKeyMessageEvent;\n};\n\ninterface MediaKeySessionEventMap {\n    "keystatuseschange": Event;\n    "message": MediaKeyMessageEvent;\n}\n\n/** This EncryptedMediaExtensions API interface represents a context for message exchange with a content decryption module (CDM). */\ninterface MediaKeySession extends EventTarget {\n    readonly closed: Promise<void>;\n    readonly expiration: number;\n    readonly keyStatuses: MediaKeyStatusMap;\n    onkeystatuseschange: ((this: MediaKeySession, ev: Event) => any) | null;\n    onmessage: ((this: MediaKeySession, ev: MediaKeyMessageEvent) => any) | null;\n    readonly sessionId: string;\n    close(): Promise<void>;\n    generateRequest(initDataType: string, initData: BufferSource): Promise<void>;\n    load(sessionId: string): Promise<boolean>;\n    remove(): Promise<void>;\n    update(response: BufferSource): Promise<void>;\n    addEventListener<K extends keyof MediaKeySessionEventMap>(type: K, listener: (this: MediaKeySession, ev: MediaKeySessionEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof MediaKeySessionEventMap>(type: K, listener: (this: MediaKeySession, ev: MediaKeySessionEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var MediaKeySession: {\n    prototype: MediaKeySession;\n    new(): MediaKeySession;\n};\n\n/** This EncryptedMediaExtensions API interface is a read-only map of media key statuses by key IDs. */\ninterface MediaKeyStatusMap {\n    readonly size: number;\n    get(keyId: BufferSource): MediaKeyStatus | undefined;\n    has(keyId: BufferSource): boolean;\n    forEach(callbackfn: (value: MediaKeyStatus, key: BufferSource, parent: MediaKeyStatusMap) => void, thisArg?: any): void;\n}\n\ndeclare var MediaKeyStatusMap: {\n    prototype: MediaKeyStatusMap;\n    new(): MediaKeyStatusMap;\n};\n\n/** This EncryptedMediaExtensions API interface provides access to a Key System for decryption and/or a content protection provider. You can request an instance of this object using the Navigator.requestMediaKeySystemAccess method. */\ninterface MediaKeySystemAccess {\n    readonly keySystem: string;\n    createMediaKeys(): Promise<MediaKeys>;\n    getConfiguration(): MediaKeySystemConfiguration;\n}\n\ndeclare var MediaKeySystemAccess: {\n    prototype: MediaKeySystemAccess;\n    new(): MediaKeySystemAccess;\n};\n\n/** This EncryptedMediaExtensions API interface the represents a set of keys that an associated HTMLMediaElement can use for decryption of media data during playback. */\ninterface MediaKeys {\n    createSession(sessionType?: MediaKeySessionType): MediaKeySession;\n    setServerCertificate(serverCertificate: BufferSource): Promise<boolean>;\n}\n\ndeclare var MediaKeys: {\n    prototype: MediaKeys;\n    new(): MediaKeys;\n};\n\ninterface MediaList {\n    readonly length: number;\n    mediaText: string;\n    toString(): string;\n    appendMedium(medium: string): void;\n    deleteMedium(medium: string): void;\n    item(index: number): string | null;\n    [index: number]: string;\n}\n\ndeclare var MediaList: {\n    prototype: MediaList;\n    new(): MediaList;\n};\n\ninterface MediaQueryListEventMap {\n    "change": MediaQueryListEvent;\n}\n\n/** Stores information on a media query applied to a document, and handles sending notifications to listeners when the media query state change (i.e. when the media query test starts or stops evaluating to true). */\ninterface MediaQueryList extends EventTarget {\n    readonly matches: boolean;\n    readonly media: string;\n    onchange: ((this: MediaQueryList, ev: MediaQueryListEvent) => any) | null;\n    /** @deprecated */\n    addListener(listener: ((this: MediaQueryList, ev: MediaQueryListEvent) => any) | null): void;\n    /** @deprecated */\n    removeListener(listener: ((this: MediaQueryList, ev: MediaQueryListEvent) => any) | null): void;\n    addEventListener<K extends keyof MediaQueryListEventMap>(type: K, listener: (this: MediaQueryList, ev: MediaQueryListEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof MediaQueryListEventMap>(type: K, listener: (this: MediaQueryList, ev: MediaQueryListEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var MediaQueryList: {\n    prototype: MediaQueryList;\n    new(): MediaQueryList;\n};\n\ninterface MediaQueryListEvent extends Event {\n    readonly matches: boolean;\n    readonly media: string;\n}\n\ndeclare var MediaQueryListEvent: {\n    prototype: MediaQueryListEvent;\n    new(type: string, eventInitDict?: MediaQueryListEventInit): MediaQueryListEvent;\n};\n\ninterface MediaSourceEventMap {\n    "sourceclose": Event;\n    "sourceended": Event;\n    "sourceopen": Event;\n}\n\n/** This Media Source Extensions API interface represents a source of media data for an HTMLMediaElement object. A MediaSource object can be attached to a HTMLMediaElement to be played in the user agent. */\ninterface MediaSource extends EventTarget {\n    readonly activeSourceBuffers: SourceBufferList;\n    duration: number;\n    onsourceclose: ((this: MediaSource, ev: Event) => any) | null;\n    onsourceended: ((this: MediaSource, ev: Event) => any) | null;\n    onsourceopen: ((this: MediaSource, ev: Event) => any) | null;\n    readonly readyState: ReadyState;\n    readonly sourceBuffers: SourceBufferList;\n    addSourceBuffer(type: string): SourceBuffer;\n    clearLiveSeekableRange(): void;\n    endOfStream(error?: EndOfStreamError): void;\n    removeSourceBuffer(sourceBuffer: SourceBuffer): void;\n    setLiveSeekableRange(start: number, end: number): void;\n    addEventListener<K extends keyof MediaSourceEventMap>(type: K, listener: (this: MediaSource, ev: MediaSourceEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof MediaSourceEventMap>(type: K, listener: (this: MediaSource, ev: MediaSourceEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var MediaSource: {\n    prototype: MediaSource;\n    new(): MediaSource;\n    isTypeSupported(type: string): boolean;\n};\n\ninterface MediaStreamEventMap {\n    "addtrack": MediaStreamTrackEvent;\n    "removetrack": MediaStreamTrackEvent;\n}\n\n/** A stream of media content. A stream consists of several tracks such as video or audio tracks. Each track is specified as an instance of MediaStreamTrack. */\ninterface MediaStream extends EventTarget {\n    readonly active: boolean;\n    readonly id: string;\n    onaddtrack: ((this: MediaStream, ev: MediaStreamTrackEvent) => any) | null;\n    onremovetrack: ((this: MediaStream, ev: MediaStreamTrackEvent) => any) | null;\n    addTrack(track: MediaStreamTrack): void;\n    clone(): MediaStream;\n    getAudioTracks(): MediaStreamTrack[];\n    getTrackById(trackId: string): MediaStreamTrack | null;\n    getTracks(): MediaStreamTrack[];\n    getVideoTracks(): MediaStreamTrack[];\n    removeTrack(track: MediaStreamTrack): void;\n    addEventListener<K extends keyof MediaStreamEventMap>(type: K, listener: (this: MediaStream, ev: MediaStreamEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof MediaStreamEventMap>(type: K, listener: (this: MediaStream, ev: MediaStreamEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var MediaStream: {\n    prototype: MediaStream;\n    new(): MediaStream;\n    new(stream: MediaStream): MediaStream;\n    new(tracks: MediaStreamTrack[]): MediaStream;\n};\n\ninterface MediaStreamAudioDestinationNode extends AudioNode {\n    readonly stream: MediaStream;\n}\n\ndeclare var MediaStreamAudioDestinationNode: {\n    prototype: MediaStreamAudioDestinationNode;\n    new(context: AudioContext, options?: AudioNodeOptions): MediaStreamAudioDestinationNode;\n};\n\n/** A type of AudioNode which operates as an audio source whose media is received from a MediaStream obtained using the WebRTC or Media Capture and Streams APIs. */\ninterface MediaStreamAudioSourceNode extends AudioNode {\n    readonly mediaStream: MediaStream;\n}\n\ndeclare var MediaStreamAudioSourceNode: {\n    prototype: MediaStreamAudioSourceNode;\n    new(context: AudioContext, options: MediaStreamAudioSourceOptions): MediaStreamAudioSourceNode;\n};\n\ninterface MediaStreamError {\n    readonly constraintName: string | null;\n    readonly message: string | null;\n    readonly name: string;\n}\n\ndeclare var MediaStreamError: {\n    prototype: MediaStreamError;\n    new(): MediaStreamError;\n};\n\ninterface MediaStreamErrorEvent extends Event {\n    readonly error: MediaStreamError | null;\n}\n\ndeclare var MediaStreamErrorEvent: {\n    prototype: MediaStreamErrorEvent;\n    new(typeArg: string, eventInitDict?: MediaStreamErrorEventInit): MediaStreamErrorEvent;\n};\n\n/** Events that occurs in relation to a MediaStream. Two events of this type can be thrown: addstream and removestream. */\ninterface MediaStreamEvent extends Event {\n    readonly stream: MediaStream | null;\n}\n\ndeclare var MediaStreamEvent: {\n    prototype: MediaStreamEvent;\n    new(type: string, eventInitDict: MediaStreamEventInit): MediaStreamEvent;\n};\n\ninterface MediaStreamTrackEventMap {\n    "ended": Event;\n    "mute": Event;\n    "unmute": Event;\n}\n\n/** A single media track within a stream; typically, these are audio or video tracks, but other track types may exist as well. */\ninterface MediaStreamTrack extends EventTarget {\n    enabled: boolean;\n    readonly id: string;\n    readonly kind: string;\n    readonly label: string;\n    readonly muted: boolean;\n    onended: ((this: MediaStreamTrack, ev: Event) => any) | null;\n    onmute: ((this: MediaStreamTrack, ev: Event) => any) | null;\n    onunmute: ((this: MediaStreamTrack, ev: Event) => any) | null;\n    readonly readyState: MediaStreamTrackState;\n    applyConstraints(constraints?: MediaTrackConstraints): Promise<void>;\n    clone(): MediaStreamTrack;\n    getCapabilities(): MediaTrackCapabilities;\n    getConstraints(): MediaTrackConstraints;\n    getSettings(): MediaTrackSettings;\n    stop(): void;\n    addEventListener<K extends keyof MediaStreamTrackEventMap>(type: K, listener: (this: MediaStreamTrack, ev: MediaStreamTrackEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof MediaStreamTrackEventMap>(type: K, listener: (this: MediaStreamTrack, ev: MediaStreamTrackEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var MediaStreamTrack: {\n    prototype: MediaStreamTrack;\n    new(): MediaStreamTrack;\n};\n\ninterface MediaStreamTrackAudioSourceNode extends AudioNode {\n}\n\ndeclare var MediaStreamTrackAudioSourceNode: {\n    prototype: MediaStreamTrackAudioSourceNode;\n    new(context: AudioContext, options: MediaStreamTrackAudioSourceOptions): MediaStreamTrackAudioSourceNode;\n};\n\n/** Events which indicate that a MediaStream has had tracks added to or removed from the stream through calls to Media Stream API methods. These events are sent to the stream when these changes occur. */\ninterface MediaStreamTrackEvent extends Event {\n    readonly track: MediaStreamTrack;\n}\n\ndeclare var MediaStreamTrackEvent: {\n    prototype: MediaStreamTrackEvent;\n    new(type: string, eventInitDict: MediaStreamTrackEventInit): MediaStreamTrackEvent;\n};\n\n/** This Channel Messaging API interface allows us to create a new message channel and send data through it via its two MessagePort properties. */\ninterface MessageChannel {\n    /**\n     * Returns the first MessagePort object.\n     */\n    readonly port1: MessagePort;\n    /**\n     * Returns the second MessagePort object.\n     */\n    readonly port2: MessagePort;\n}\n\ndeclare var MessageChannel: {\n    prototype: MessageChannel;\n    new(): MessageChannel;\n};\n\n/** A message received by a target object. */\ninterface MessageEvent<T = any> extends Event {\n    /**\n     * Returns the data of the message.\n     */\n    readonly data: T;\n    /**\n     * Returns the last event ID string, for server-sent events.\n     */\n    readonly lastEventId: string;\n    /**\n     * Returns the origin of the message, for server-sent events and cross-document messaging.\n     */\n    readonly origin: string;\n    /**\n     * Returns the MessagePort array sent with the message, for cross-document messaging and channel messaging.\n     */\n    readonly ports: ReadonlyArray<MessagePort>;\n    /**\n     * Returns the WindowProxy of the source window, for cross-document messaging, and the MessagePort being attached, in the connect event fired at SharedWorkerGlobalScope objects.\n     */\n    readonly source: MessageEventSource | null;\n}\n\ndeclare var MessageEvent: {\n    prototype: MessageEvent;\n    new<T>(type: string, eventInitDict?: MessageEventInit<T>): MessageEvent<T>;\n};\n\ninterface MessagePortEventMap {\n    "message": MessageEvent;\n    "messageerror": MessageEvent;\n}\n\n/** This Channel Messaging API interface represents one of the two ports of a MessageChannel, allowing messages to be sent from one port and listening out for them arriving at the other. */\ninterface MessagePort extends EventTarget {\n    onmessage: ((this: MessagePort, ev: MessageEvent) => any) | null;\n    onmessageerror: ((this: MessagePort, ev: MessageEvent) => any) | null;\n    /**\n     * Disconnects the port, so that it is no longer active.\n     */\n    close(): void;\n    /**\n     * Posts a message through the channel. Objects listed in transfer are transferred, not just cloned, meaning that they are no longer usable on the sending side.\n     *\n     * Throws a "DataCloneError" DOMException if transfer contains duplicate objects or port, or if message could not be cloned.\n     */\n    postMessage(message: any, transfer: Transferable[]): void;\n    postMessage(message: any, options?: PostMessageOptions): void;\n    /**\n     * Begins dispatching messages received on the port.\n     */\n    start(): void;\n    addEventListener<K extends keyof MessagePortEventMap>(type: K, listener: (this: MessagePort, ev: MessagePortEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof MessagePortEventMap>(type: K, listener: (this: MessagePort, ev: MessagePortEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var MessagePort: {\n    prototype: MessagePort;\n    new(): MessagePort;\n};\n\n/** Provides contains information about a MIME type associated with a particular plugin. NavigatorPlugins.mimeTypes returns an array of this object. */\ninterface MimeType {\n    /**\n     * Returns the MIME type\'s description.\n     */\n    readonly description: string;\n    /**\n     * Returns the Plugin object that implements this MIME type.\n     */\n    readonly enabledPlugin: Plugin;\n    /**\n     * Returns the MIME type\'s typical file extensions, in a comma-separated list.\n     */\n    readonly suffixes: string;\n    /**\n     * Returns the MIME type.\n     */\n    readonly type: string;\n}\n\ndeclare var MimeType: {\n    prototype: MimeType;\n    new(): MimeType;\n};\n\n/** Returns an array of MimeType instances, each of which contains information about a supported browser plugins. This object is returned by NavigatorPlugins.mimeTypes. */\ninterface MimeTypeArray {\n    readonly length: number;\n    item(index: number): MimeType | null;\n    namedItem(name: string): MimeType | null;\n    [index: number]: MimeType;\n}\n\ndeclare var MimeTypeArray: {\n    prototype: MimeTypeArray;\n    new(): MimeTypeArray;\n};\n\n/** Events that occur due to the user interacting with a pointing device (such as a mouse). Common events using this interface include click, dblclick, mouseup, mousedown. */\ninterface MouseEvent extends UIEvent {\n    readonly altKey: boolean;\n    readonly button: number;\n    readonly buttons: number;\n    readonly clientX: number;\n    readonly clientY: number;\n    readonly ctrlKey: boolean;\n    readonly metaKey: boolean;\n    readonly movementX: number;\n    readonly movementY: number;\n    readonly offsetX: number;\n    readonly offsetY: number;\n    readonly pageX: number;\n    readonly pageY: number;\n    readonly relatedTarget: EventTarget | null;\n    readonly screenX: number;\n    readonly screenY: number;\n    readonly shiftKey: boolean;\n    readonly x: number;\n    readonly y: number;\n    getModifierState(keyArg: string): boolean;\n    initMouseEvent(typeArg: string, canBubbleArg: boolean, cancelableArg: boolean, viewArg: Window, detailArg: number, screenXArg: number, screenYArg: number, clientXArg: number, clientYArg: number, ctrlKeyArg: boolean, altKeyArg: boolean, shiftKeyArg: boolean, metaKeyArg: boolean, buttonArg: number, relatedTargetArg: EventTarget | null): void;\n}\n\ndeclare var MouseEvent: {\n    prototype: MouseEvent;\n    new(type: string, eventInitDict?: MouseEventInit): MouseEvent;\n};\n\n/** Provides event properties that are specific to modifications to the Document Object Model (DOM) hierarchy and nodes.\n * @deprecated DOM4 [DOM] provides a new mechanism using a MutationObserver interface which addresses the use cases that mutation events solve, but in a more performant manner. Thus, this specification describes mutation events for reference and completeness of legacy behavior, but deprecates the use of the MutationEvent interface. */\ninterface MutationEvent extends Event {\n    readonly attrChange: number;\n    readonly attrName: string;\n    readonly newValue: string;\n    readonly prevValue: string;\n    readonly relatedNode: Node;\n    initMutationEvent(typeArg: string, canBubbleArg: boolean, cancelableArg: boolean, relatedNodeArg: Node, prevValueArg: string, newValueArg: string, attrNameArg: string, attrChangeArg: number): void;\n    readonly ADDITION: number;\n    readonly MODIFICATION: number;\n    readonly REMOVAL: number;\n}\n\ndeclare var MutationEvent: {\n    prototype: MutationEvent;\n    new(): MutationEvent;\n    readonly ADDITION: number;\n    readonly MODIFICATION: number;\n    readonly REMOVAL: number;\n};\n\n/** Provides the ability to watch for changes being made to the DOM tree. It is designed as a replacement for the older Mutation Events feature which was part of the DOM3 Events specification. */\ninterface MutationObserver {\n    /**\n     * Stops observer from observing any mutations. Until the observe() method is used again, observer\'s callback will not be invoked.\n     */\n    disconnect(): void;\n    /**\n     * Instructs the user agent to observe a given target (a node) and report any mutations based on the criteria given by options (an object).\n     *\n     * The options argument allows for setting mutation observation options via object members.\n     */\n    observe(target: Node, options?: MutationObserverInit): void;\n    /**\n     * Empties the record queue and returns what was in there.\n     */\n    takeRecords(): MutationRecord[];\n}\n\ndeclare var MutationObserver: {\n    prototype: MutationObserver;\n    new(callback: MutationCallback): MutationObserver;\n};\n\n/** A MutationRecord represents an individual DOM mutation. It is the object that is passed to MutationObserver\'s callback. */\ninterface MutationRecord {\n    /**\n     * Return the nodes added and removed respectively.\n     */\n    readonly addedNodes: NodeList;\n    /**\n     * Returns the local name of the changed attribute, and null otherwise.\n     */\n    readonly attributeName: string | null;\n    /**\n     * Returns the namespace of the changed attribute, and null otherwise.\n     */\n    readonly attributeNamespace: string | null;\n    /**\n     * Return the previous and next sibling respectively of the added or removed nodes, and null otherwise.\n     */\n    readonly nextSibling: Node | null;\n    /**\n     * The return value depends on type. For "attributes", it is the value of the changed attribute before the change. For "characterData", it is the data of the changed node before the change. For "childList", it is null.\n     */\n    readonly oldValue: string | null;\n    /**\n     * Return the previous and next sibling respectively of the added or removed nodes, and null otherwise.\n     */\n    readonly previousSibling: Node | null;\n    /**\n     * Return the nodes added and removed respectively.\n     */\n    readonly removedNodes: NodeList;\n    /**\n     * Returns the node the mutation affected, depending on the type. For "attributes", it is the element whose attribute changed. For "characterData", it is the CharacterData node. For "childList", it is the node whose children changed.\n     */\n    readonly target: Node;\n    /**\n     * Returns "attributes" if it was an attribute mutation. "characterData" if it was a mutation to a CharacterData node. And "childList" if it was a mutation to the tree of nodes.\n     */\n    readonly type: MutationRecordType;\n}\n\ndeclare var MutationRecord: {\n    prototype: MutationRecord;\n    new(): MutationRecord;\n};\n\n/** A collection of Attr objects. Objects inside a NamedNodeMap are not in any particular order, unlike NodeList, although they may be accessed by an index as in an array. */\ninterface NamedNodeMap {\n    readonly length: number;\n    getNamedItem(qualifiedName: string): Attr | null;\n    getNamedItemNS(namespace: string | null, localName: string): Attr | null;\n    item(index: number): Attr | null;\n    removeNamedItem(qualifiedName: string): Attr;\n    removeNamedItemNS(namespace: string | null, localName: string): Attr;\n    setNamedItem(attr: Attr): Attr | null;\n    setNamedItemNS(attr: Attr): Attr | null;\n    [index: number]: Attr;\n}\n\ndeclare var NamedNodeMap: {\n    prototype: NamedNodeMap;\n    new(): NamedNodeMap;\n};\n\ninterface NavigationPreloadManager {\n    disable(): Promise<void>;\n    enable(): Promise<void>;\n    getState(): Promise<NavigationPreloadState>;\n    setHeaderValue(value: string): Promise<void>;\n}\n\ndeclare var NavigationPreloadManager: {\n    prototype: NavigationPreloadManager;\n    new(): NavigationPreloadManager;\n};\n\n/** The state and the identity of the user agent. It allows scripts to query it and to register themselves to carry on some activities. */\ninterface Navigator extends MSFileSaver, MSNavigatorDoNotTrack, NavigatorAutomationInformation, NavigatorBeacon, NavigatorConcurrentHardware, NavigatorContentUtils, NavigatorCookies, NavigatorID, NavigatorLanguage, NavigatorOnLine, NavigatorPlugins, NavigatorStorage {\n    readonly activeVRDisplays: ReadonlyArray<VRDisplay>;\n    readonly clipboard: Clipboard;\n    readonly credentials: CredentialsContainer;\n    readonly doNotTrack: string | null;\n    readonly geolocation: Geolocation;\n    readonly maxTouchPoints: number;\n    readonly mediaDevices: MediaDevices;\n    readonly msManipulationViewsEnabled: boolean;\n    readonly msMaxTouchPoints: number;\n    readonly msPointerEnabled: boolean;\n    readonly permissions: Permissions;\n    readonly pointerEnabled: boolean;\n    readonly serviceWorker: ServiceWorkerContainer;\n    getGamepads(): (Gamepad | null)[];\n    getUserMedia(constraints: MediaStreamConstraints, successCallback: NavigatorUserMediaSuccessCallback, errorCallback: NavigatorUserMediaErrorCallback): void;\n    getVRDisplays(): Promise<VRDisplay[]>;\n    msLaunchUri(uri: string, successCallback?: MSLaunchUriCallback, noHandlerCallback?: MSLaunchUriCallback): void;\n    requestMediaKeySystemAccess(keySystem: string, supportedConfigurations: MediaKeySystemConfiguration[]): Promise<MediaKeySystemAccess>;\n    sendBeacon(url: string, data?: BodyInit | null): boolean;\n    share(data?: ShareData): Promise<void>;\n    vibrate(pattern: number | number[]): boolean;\n}\n\ndeclare var Navigator: {\n    prototype: Navigator;\n    new(): Navigator;\n};\n\ninterface NavigatorAutomationInformation {\n    readonly webdriver: boolean;\n}\n\ninterface NavigatorBeacon {\n    sendBeacon(url: string, data?: Blob | Int8Array | Int16Array | Int32Array | Uint8Array | Uint16Array | Uint32Array | Uint8ClampedArray | Float32Array | Float64Array | DataView | ArrayBuffer | FormData | string | null): boolean;\n}\n\ninterface NavigatorConcurrentHardware {\n    readonly hardwareConcurrency: number;\n}\n\ninterface NavigatorContentUtils {\n    registerProtocolHandler(scheme: string, url: string, title: string): void;\n    unregisterProtocolHandler(scheme: string, url: string): void;\n}\n\ninterface NavigatorCookies {\n    readonly cookieEnabled: boolean;\n}\n\ninterface NavigatorID {\n    readonly appCodeName: string;\n    readonly appName: string;\n    readonly appVersion: string;\n    readonly platform: string;\n    readonly product: string;\n    readonly productSub: string;\n    readonly userAgent: string;\n    readonly vendor: string;\n    readonly vendorSub: string;\n}\n\ninterface NavigatorLanguage {\n    readonly language: string;\n    readonly languages: ReadonlyArray<string>;\n}\n\ninterface NavigatorOnLine {\n    readonly onLine: boolean;\n}\n\ninterface NavigatorPlugins {\n    readonly mimeTypes: MimeTypeArray;\n    readonly plugins: PluginArray;\n    javaEnabled(): boolean;\n}\n\ninterface NavigatorStorage {\n    readonly storage: StorageManager;\n}\n\n/** Node is an interface from which a number of DOM API object types inherit. It allows those types to be treated similarly; for example, inheriting the same set of methods, or being tested in the same way. */\ninterface Node extends EventTarget {\n    /**\n     * Returns node\'s node document\'s document base URL.\n     */\n    readonly baseURI: string;\n    /**\n     * Returns the children.\n     */\n    readonly childNodes: NodeListOf<ChildNode>;\n    /**\n     * Returns the first child.\n     */\n    readonly firstChild: ChildNode | null;\n    /**\n     * Returns true if node is connected and false otherwise.\n     */\n    readonly isConnected: boolean;\n    /**\n     * Returns the last child.\n     */\n    readonly lastChild: ChildNode | null;\n    /** @deprecated */\n    readonly namespaceURI: string | null;\n    /**\n     * Returns the next sibling.\n     */\n    readonly nextSibling: ChildNode | null;\n    /**\n     * Returns a string appropriate for the type of node.\n     */\n    readonly nodeName: string;\n    /**\n     * Returns the type of node.\n     */\n    readonly nodeType: number;\n    nodeValue: string | null;\n    /**\n     * Returns the node document. Returns null for documents.\n     */\n    readonly ownerDocument: Document | null;\n    /**\n     * Returns the parent element.\n     */\n    readonly parentElement: HTMLElement | null;\n    /**\n     * Returns the parent.\n     */\n    readonly parentNode: Node & ParentNode | null;\n    /**\n     * Returns the previous sibling.\n     */\n    readonly previousSibling: ChildNode | null;\n    textContent: string | null;\n    appendChild<T extends Node>(newChild: T): T;\n    /**\n     * Returns a copy of node. If deep is true, the copy also includes the node\'s descendants.\n     */\n    cloneNode(deep?: boolean): Node;\n    /**\n     * Returns a bitmask indicating the position of other relative to node.\n     */\n    compareDocumentPosition(other: Node): number;\n    /**\n     * Returns true if other is an inclusive descendant of node, and false otherwise.\n     */\n    contains(other: Node | null): boolean;\n    /**\n     * Returns node\'s root.\n     */\n    getRootNode(options?: GetRootNodeOptions): Node;\n    /**\n     * Returns whether node has children.\n     */\n    hasChildNodes(): boolean;\n    insertBefore<T extends Node>(newChild: T, refChild: Node | null): T;\n    isDefaultNamespace(namespace: string | null): boolean;\n    /**\n     * Returns whether node and otherNode have the same properties.\n     */\n    isEqualNode(otherNode: Node | null): boolean;\n    isSameNode(otherNode: Node | null): boolean;\n    lookupNamespaceURI(prefix: string | null): string | null;\n    lookupPrefix(namespace: string | null): string | null;\n    /**\n     * Removes empty exclusive Text nodes and concatenates the data of remaining contiguous exclusive Text nodes into the first of their nodes.\n     */\n    normalize(): void;\n    removeChild<T extends Node>(oldChild: T): T;\n    replaceChild<T extends Node>(newChild: Node, oldChild: T): T;\n    readonly ATTRIBUTE_NODE: number;\n    /**\n     * node is a CDATASection node.\n     */\n    readonly CDATA_SECTION_NODE: number;\n    /**\n     * node is a Comment node.\n     */\n    readonly COMMENT_NODE: number;\n    /**\n     * node is a DocumentFragment node.\n     */\n    readonly DOCUMENT_FRAGMENT_NODE: number;\n    /**\n     * node is a document.\n     */\n    readonly DOCUMENT_NODE: number;\n    /**\n     * Set when other is a descendant of node.\n     */\n    readonly DOCUMENT_POSITION_CONTAINED_BY: number;\n    /**\n     * Set when other is an ancestor of node.\n     */\n    readonly DOCUMENT_POSITION_CONTAINS: number;\n    /**\n     * Set when node and other are not in the same tree.\n     */\n    readonly DOCUMENT_POSITION_DISCONNECTED: number;\n    /**\n     * Set when other is following node.\n     */\n    readonly DOCUMENT_POSITION_FOLLOWING: number;\n    readonly DOCUMENT_POSITION_IMPLEMENTATION_SPECIFIC: number;\n    /**\n     * Set when other is preceding node.\n     */\n    readonly DOCUMENT_POSITION_PRECEDING: number;\n    /**\n     * node is a doctype.\n     */\n    readonly DOCUMENT_TYPE_NODE: number;\n    /**\n     * node is an element.\n     */\n    readonly ELEMENT_NODE: number;\n    readonly ENTITY_NODE: number;\n    readonly ENTITY_REFERENCE_NODE: number;\n    readonly NOTATION_NODE: number;\n    /**\n     * node is a ProcessingInstruction node.\n     */\n    readonly PROCESSING_INSTRUCTION_NODE: number;\n    /**\n     * node is a Text node.\n     */\n    readonly TEXT_NODE: number;\n}\n\ndeclare var Node: {\n    prototype: Node;\n    new(): Node;\n    readonly ATTRIBUTE_NODE: number;\n    /**\n     * node is a CDATASection node.\n     */\n    readonly CDATA_SECTION_NODE: number;\n    /**\n     * node is a Comment node.\n     */\n    readonly COMMENT_NODE: number;\n    /**\n     * node is a DocumentFragment node.\n     */\n    readonly DOCUMENT_FRAGMENT_NODE: number;\n    /**\n     * node is a document.\n     */\n    readonly DOCUMENT_NODE: number;\n    /**\n     * Set when other is a descendant of node.\n     */\n    readonly DOCUMENT_POSITION_CONTAINED_BY: number;\n    /**\n     * Set when other is an ancestor of node.\n     */\n    readonly DOCUMENT_POSITION_CONTAINS: number;\n    /**\n     * Set when node and other are not in the same tree.\n     */\n    readonly DOCUMENT_POSITION_DISCONNECTED: number;\n    /**\n     * Set when other is following node.\n     */\n    readonly DOCUMENT_POSITION_FOLLOWING: number;\n    readonly DOCUMENT_POSITION_IMPLEMENTATION_SPECIFIC: number;\n    /**\n     * Set when other is preceding node.\n     */\n    readonly DOCUMENT_POSITION_PRECEDING: number;\n    /**\n     * node is a doctype.\n     */\n    readonly DOCUMENT_TYPE_NODE: number;\n    /**\n     * node is an element.\n     */\n    readonly ELEMENT_NODE: number;\n    readonly ENTITY_NODE: number;\n    readonly ENTITY_REFERENCE_NODE: number;\n    readonly NOTATION_NODE: number;\n    /**\n     * node is a ProcessingInstruction node.\n     */\n    readonly PROCESSING_INSTRUCTION_NODE: number;\n    /**\n     * node is a Text node.\n     */\n    readonly TEXT_NODE: number;\n};\n\n/** An object used to filter the nodes in a NodeIterator or TreeWalker. They don\'t know anything about the DOM or how to traverse nodes; they just know how to evaluate a single node against the provided filter. */\ninterface NodeFilter {\n    acceptNode(node: Node): number;\n}\n\ndeclare var NodeFilter: {\n    readonly FILTER_ACCEPT: number;\n    readonly FILTER_REJECT: number;\n    readonly FILTER_SKIP: number;\n    readonly SHOW_ALL: number;\n    readonly SHOW_ATTRIBUTE: number;\n    readonly SHOW_CDATA_SECTION: number;\n    readonly SHOW_COMMENT: number;\n    readonly SHOW_DOCUMENT: number;\n    readonly SHOW_DOCUMENT_FRAGMENT: number;\n    readonly SHOW_DOCUMENT_TYPE: number;\n    readonly SHOW_ELEMENT: number;\n    readonly SHOW_ENTITY: number;\n    readonly SHOW_ENTITY_REFERENCE: number;\n    readonly SHOW_NOTATION: number;\n    readonly SHOW_PROCESSING_INSTRUCTION: number;\n    readonly SHOW_TEXT: number;\n};\n\n/** An iterator over the members of a list of the nodes in a subtree of the DOM. The nodes will be returned in document order. */\ninterface NodeIterator {\n    readonly filter: NodeFilter | null;\n    readonly pointerBeforeReferenceNode: boolean;\n    readonly referenceNode: Node;\n    readonly root: Node;\n    readonly whatToShow: number;\n    detach(): void;\n    nextNode(): Node | null;\n    previousNode(): Node | null;\n}\n\ndeclare var NodeIterator: {\n    prototype: NodeIterator;\n    new(): NodeIterator;\n};\n\n/** NodeList objects are collections of nodes, usually returned by properties such as Node.childNodes and methods such as document.querySelectorAll(). */\ninterface NodeList {\n    /**\n     * Returns the number of nodes in the collection.\n     */\n    readonly length: number;\n    /**\n     * Returns the node with index index from the collection. The nodes are sorted in tree order.\n     */\n    item(index: number): Node | null;\n    /**\n     * Performs the specified action for each node in an list.\n     * @param callbackfn  A function that accepts up to three arguments. forEach calls the callbackfn function one time for each element in the list.\n     * @param thisArg  An object to which the this keyword can refer in the callbackfn function. If thisArg is omitted, undefined is used as the this value.\n     */\n    forEach(callbackfn: (value: Node, key: number, parent: NodeList) => void, thisArg?: any): void;\n    [index: number]: Node;\n}\n\ndeclare var NodeList: {\n    prototype: NodeList;\n    new(): NodeList;\n};\n\ninterface NodeListOf<TNode extends Node> extends NodeList {\n    item(index: number): TNode;\n    /**\n     * Performs the specified action for each node in an list.\n     * @param callbackfn  A function that accepts up to three arguments. forEach calls the callbackfn function one time for each element in the list.\n     * @param thisArg  An object to which the this keyword can refer in the callbackfn function. If thisArg is omitted, undefined is used as the this value.\n     */\n    forEach(callbackfn: (value: TNode, key: number, parent: NodeListOf<TNode>) => void, thisArg?: any): void;\n    [index: number]: TNode;\n}\n\ninterface NonDocumentTypeChildNode {\n    /**\n     * Returns the first following sibling that is an element, and null otherwise.\n     */\n    readonly nextElementSibling: Element | null;\n    /**\n     * Returns the first preceding sibling that is an element, and null otherwise.\n     */\n    readonly previousElementSibling: Element | null;\n}\n\ninterface NonElementParentNode {\n    /**\n     * Returns the first element within node\'s descendants whose ID is elementId.\n     */\n    getElementById(elementId: string): Element | null;\n}\n\ninterface NotificationEventMap {\n    "click": Event;\n    "close": Event;\n    "error": Event;\n    "show": Event;\n}\n\n/** This Notifications API interface is used to configure and display desktop notifications to the user. */\ninterface Notification extends EventTarget {\n    readonly actions: ReadonlyArray<NotificationAction>;\n    readonly badge: string;\n    readonly body: string;\n    readonly data: any;\n    readonly dir: NotificationDirection;\n    readonly icon: string;\n    readonly image: string;\n    readonly lang: string;\n    onclick: ((this: Notification, ev: Event) => any) | null;\n    onclose: ((this: Notification, ev: Event) => any) | null;\n    onerror: ((this: Notification, ev: Event) => any) | null;\n    onshow: ((this: Notification, ev: Event) => any) | null;\n    readonly renotify: boolean;\n    readonly requireInteraction: boolean;\n    readonly silent: boolean;\n    readonly tag: string;\n    readonly timestamp: number;\n    readonly title: string;\n    readonly vibrate: ReadonlyArray<number>;\n    close(): void;\n    addEventListener<K extends keyof NotificationEventMap>(type: K, listener: (this: Notification, ev: NotificationEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof NotificationEventMap>(type: K, listener: (this: Notification, ev: NotificationEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var Notification: {\n    prototype: Notification;\n    new(title: string, options?: NotificationOptions): Notification;\n    readonly maxActions: number;\n    readonly permission: NotificationPermission;\n    requestPermission(deprecatedCallback?: NotificationPermissionCallback): Promise<NotificationPermission>;\n};\n\n/** The OES_element_index_uint extension is part of the WebGL API and adds support for gl.UNSIGNED_INT types to WebGLRenderingContext.drawElements(). */\ninterface OES_element_index_uint {\n}\n\n/** The OES_standard_derivatives extension is part of the WebGL API and adds the GLSL derivative functions dFdx, dFdy, and fwidth. */\ninterface OES_standard_derivatives {\n    readonly FRAGMENT_SHADER_DERIVATIVE_HINT_OES: GLenum;\n}\n\n/** The OES_texture_float extension is part of the WebGL API and exposes floating-point pixel types for textures. */\ninterface OES_texture_float {\n}\n\n/** The OES_texture_float_linear extension is part of the WebGL API and allows linear filtering with floating-point pixel types for textures. */\ninterface OES_texture_float_linear {\n}\n\n/** The OES_texture_half_float extension is part of the WebGL API and adds texture formats with 16- (aka half float) and 32-bit floating-point components. */\ninterface OES_texture_half_float {\n    readonly HALF_FLOAT_OES: GLenum;\n}\n\n/** The OES_texture_half_float_linear extension is part of the WebGL API and allows linear filtering with half floating-point pixel types for textures. */\ninterface OES_texture_half_float_linear {\n}\n\ninterface OES_vertex_array_object {\n    bindVertexArrayOES(arrayObject: WebGLVertexArrayObjectOES | null): void;\n    createVertexArrayOES(): WebGLVertexArrayObjectOES | null;\n    deleteVertexArrayOES(arrayObject: WebGLVertexArrayObjectOES | null): void;\n    isVertexArrayOES(arrayObject: WebGLVertexArrayObjectOES | null): GLboolean;\n    readonly VERTEX_ARRAY_BINDING_OES: GLenum;\n}\n\n/** The Web Audio API OfflineAudioCompletionEvent interface represents events that occur when the processing of an OfflineAudioContext is terminated. The complete event implements this interface. */\ninterface OfflineAudioCompletionEvent extends Event {\n    readonly renderedBuffer: AudioBuffer;\n}\n\ndeclare var OfflineAudioCompletionEvent: {\n    prototype: OfflineAudioCompletionEvent;\n    new(type: string, eventInitDict: OfflineAudioCompletionEventInit): OfflineAudioCompletionEvent;\n};\n\ninterface OfflineAudioContextEventMap extends BaseAudioContextEventMap {\n    "complete": OfflineAudioCompletionEvent;\n}\n\n/** An AudioContext interface representing an audio-processing graph built from linked together AudioNodes. In contrast with a standard AudioContext, an OfflineAudioContext doesn\'t render the audio to the device hardware; instead, it generates it, as fast as it can, and outputs the result to an AudioBuffer. */\ninterface OfflineAudioContext extends BaseAudioContext {\n    readonly length: number;\n    oncomplete: ((this: OfflineAudioContext, ev: OfflineAudioCompletionEvent) => any) | null;\n    resume(): Promise<void>;\n    startRendering(): Promise<AudioBuffer>;\n    suspend(suspendTime: number): Promise<void>;\n    addEventListener<K extends keyof OfflineAudioContextEventMap>(type: K, listener: (this: OfflineAudioContext, ev: OfflineAudioContextEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof OfflineAudioContextEventMap>(type: K, listener: (this: OfflineAudioContext, ev: OfflineAudioContextEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var OfflineAudioContext: {\n    prototype: OfflineAudioContext;\n    new(contextOptions: OfflineAudioContextOptions): OfflineAudioContext;\n    new(numberOfChannels: number, length: number, sampleRate: number): OfflineAudioContext;\n};\n\ninterface OffscreenCanvas extends EventTarget {\n    /**\n     * These attributes return the dimensions of the OffscreenCanvas object\'s bitmap.\n     *\n     * They can be set, to replace the bitmap with a new, transparent black bitmap of the specified dimensions (effectively resizing it).\n     */\n    height: number;\n    /**\n     * These attributes return the dimensions of the OffscreenCanvas object\'s bitmap.\n     *\n     * They can be set, to replace the bitmap with a new, transparent black bitmap of the specified dimensions (effectively resizing it).\n     */\n    width: number;\n    /**\n     * Returns a promise that will fulfill with a new Blob object representing a file containing the image in the OffscreenCanvas object.\n     *\n     * The argument, if provided, is a dictionary that controls the encoding options of the image file to be created. The type field specifies the file format and has a default value of "image/png"; that type is also used if the requested type isn\'t supported. If the image format supports variable quality (such as "image/jpeg"), then the quality field is a number in the range 0.0 to 1.0 inclusive indicating the desired quality level for the resulting image.\n     */\n    convertToBlob(options?: ImageEncodeOptions): Promise<Blob>;\n    /**\n     * Returns an object that exposes an API for drawing on the OffscreenCanvas object. contextId specifies the desired API: "2d", "bitmaprenderer", "webgl", or "webgl2". options is handled by that API.\n     *\n     * This specification defines the "2d" context below, which is similar but distinct from the "2d" context that is created from a canvas element. The WebGL specifications define the "webgl" and "webgl2" contexts. [WEBGL]\n     *\n     * Returns null if the canvas has already been initialized with another context type (e.g., trying to get a "2d" context after getting a "webgl" context).\n     */\n    getContext(contextId: "2d", options?: CanvasRenderingContext2DSettings): OffscreenCanvasRenderingContext2D | null;\n    getContext(contextId: "bitmaprenderer", options?: ImageBitmapRenderingContextSettings): ImageBitmapRenderingContext | null;\n    getContext(contextId: "webgl", options?: WebGLContextAttributes): WebGLRenderingContext | null;\n    getContext(contextId: "webgl2", options?: WebGLContextAttributes): WebGL2RenderingContext | null;\n    getContext(contextId: OffscreenRenderingContextId, options?: any): OffscreenRenderingContext | null;\n    /**\n     * Returns a newly created ImageBitmap object with the image in the OffscreenCanvas object. The image in the OffscreenCanvas object is replaced with a new blank image.\n     */\n    transferToImageBitmap(): ImageBitmap;\n}\n\ndeclare var OffscreenCanvas: {\n    prototype: OffscreenCanvas;\n    new(width: number, height: number): OffscreenCanvas;\n};\n\ninterface OffscreenCanvasRenderingContext2D extends CanvasCompositing, CanvasDrawImage, CanvasDrawPath, CanvasFillStrokeStyles, CanvasFilters, CanvasImageData, CanvasImageSmoothing, CanvasPath, CanvasPathDrawingStyles, CanvasRect, CanvasShadowStyles, CanvasState, CanvasText, CanvasTextDrawingStyles, CanvasTransform {\n    readonly canvas: OffscreenCanvas;\n    commit(): void;\n}\n\ndeclare var OffscreenCanvasRenderingContext2D: {\n    prototype: OffscreenCanvasRenderingContext2D;\n    new(): OffscreenCanvasRenderingContext2D;\n};\n\n/** The OscillatorNode interface represents a periodic waveform, such as a sine wave. It is an AudioScheduledSourceNode audio-processing module that causes a specified frequency of a given wave to be created—in effect, a constant tone. */\ninterface OscillatorNode extends AudioScheduledSourceNode {\n    readonly detune: AudioParam;\n    readonly frequency: AudioParam;\n    type: OscillatorType;\n    setPeriodicWave(periodicWave: PeriodicWave): void;\n    addEventListener<K extends keyof AudioScheduledSourceNodeEventMap>(type: K, listener: (this: OscillatorNode, ev: AudioScheduledSourceNodeEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof AudioScheduledSourceNodeEventMap>(type: K, listener: (this: OscillatorNode, ev: AudioScheduledSourceNodeEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var OscillatorNode: {\n    prototype: OscillatorNode;\n    new(context: BaseAudioContext, options?: OscillatorOptions): OscillatorNode;\n};\n\ninterface OverconstrainedError extends Error {\n    constraint: string;\n}\n\ndeclare var OverconstrainedError: {\n    prototype: OverconstrainedError;\n    new(): OverconstrainedError;\n};\n\ninterface OverflowEvent extends UIEvent {\n    readonly horizontalOverflow: boolean;\n    readonly orient: number;\n    readonly verticalOverflow: boolean;\n    readonly BOTH: number;\n    readonly HORIZONTAL: number;\n    readonly VERTICAL: number;\n}\n\ndeclare var OverflowEvent: {\n    prototype: OverflowEvent;\n    new(): OverflowEvent;\n    readonly BOTH: number;\n    readonly HORIZONTAL: number;\n    readonly VERTICAL: number;\n};\n\n/** The PageTransitionEvent is fired when a document is being loaded or unloaded. */\ninterface PageTransitionEvent extends Event {\n    /**\n     * For the pageshow event, returns false if the page is newly being loaded (and the load event will fire). Otherwise, returns true.\n     *\n     * For the pagehide event, returns false if the page is going away for the last time. Otherwise, returns true, meaning that (if nothing conspires to make the page unsalvageable) the page might be reused if the user navigates back to this page.\n     *\n     * Things that can cause the page to be unsalvageable include:\n     *\n     * Listening for beforeunload events\n     * Listening for unload events\n     * Having iframes that are not salvageable\n     * Active WebSocket objects\n     * Aborting a Document\n     */\n    readonly persisted: boolean;\n}\n\ndeclare var PageTransitionEvent: {\n    prototype: PageTransitionEvent;\n    new(type: string, eventInitDict?: PageTransitionEventInit): PageTransitionEvent;\n};\n\n/** A PannerNode always has exactly one input and one output: the input can be mono or stereo but the output is always stereo (2 channels); you can\'t have panning effects without at least two audio channels! */\ninterface PannerNode extends AudioNode {\n    coneInnerAngle: number;\n    coneOuterAngle: number;\n    coneOuterGain: number;\n    distanceModel: DistanceModelType;\n    maxDistance: number;\n    readonly orientationX: AudioParam;\n    readonly orientationY: AudioParam;\n    readonly orientationZ: AudioParam;\n    panningModel: PanningModelType;\n    readonly positionX: AudioParam;\n    readonly positionY: AudioParam;\n    readonly positionZ: AudioParam;\n    refDistance: number;\n    rolloffFactor: number;\n    /** @deprecated */\n    setOrientation(x: number, y: number, z: number): void;\n    /** @deprecated */\n    setPosition(x: number, y: number, z: number): void;\n}\n\ndeclare var PannerNode: {\n    prototype: PannerNode;\n    new(context: BaseAudioContext, options?: PannerOptions): PannerNode;\n};\n\ninterface ParentNode {\n    readonly childElementCount: number;\n    /**\n     * Returns the child elements.\n     */\n    readonly children: HTMLCollection;\n    /**\n     * Returns the first child that is an element, and null otherwise.\n     */\n    readonly firstElementChild: Element | null;\n    /**\n     * Returns the last child that is an element, and null otherwise.\n     */\n    readonly lastElementChild: Element | null;\n    /**\n     * Inserts nodes after the last child of node, while replacing strings in nodes with equivalent Text nodes.\n     *\n     * Throws a "HierarchyRequestError" DOMException if the constraints of the node tree are violated.\n     */\n    append(...nodes: (Node | string)[]): void;\n    /**\n     * Inserts nodes before the first child of node, while replacing strings in nodes with equivalent Text nodes.\n     *\n     * Throws a "HierarchyRequestError" DOMException if the constraints of the node tree are violated.\n     */\n    prepend(...nodes: (Node | string)[]): void;\n    /**\n     * Returns the first element that is a descendant of node that matches selectors.\n     */\n    querySelector<K extends keyof HTMLElementTagNameMap>(selectors: K): HTMLElementTagNameMap[K] | null;\n    querySelector<K extends keyof SVGElementTagNameMap>(selectors: K): SVGElementTagNameMap[K] | null;\n    querySelector<E extends Element = Element>(selectors: string): E | null;\n    /**\n     * Returns all element descendants of node that match selectors.\n     */\n    querySelectorAll<K extends keyof HTMLElementTagNameMap>(selectors: K): NodeListOf<HTMLElementTagNameMap[K]>;\n    querySelectorAll<K extends keyof SVGElementTagNameMap>(selectors: K): NodeListOf<SVGElementTagNameMap[K]>;\n    querySelectorAll<E extends Element = Element>(selectors: string): NodeListOf<E>;\n}\n\n/** This Canvas 2D API interface is used to declare a path that can then be used on a CanvasRenderingContext2D object. The path methods of the CanvasRenderingContext2D interface are also present on this interface, which gives you the convenience of being able to retain and replay your path whenever desired. */\ninterface Path2D extends CanvasPath {\n    /**\n     * Adds to the path the path given by the argument.\n     */\n    addPath(path: Path2D, transform?: DOMMatrix2DInit): void;\n}\n\ndeclare var Path2D: {\n    prototype: Path2D;\n    new(path?: Path2D | string): Path2D;\n};\n\n/** This Payment Request API interface is used to store shipping or payment address information. */\ninterface PaymentAddress {\n    readonly addressLine: ReadonlyArray<string>;\n    readonly city: string;\n    readonly country: string;\n    readonly dependentLocality: string;\n    readonly organization: string;\n    readonly phone: string;\n    readonly postalCode: string;\n    readonly recipient: string;\n    readonly region: string;\n    readonly sortingCode: string;\n    toJSON(): any;\n}\n\ndeclare var PaymentAddress: {\n    prototype: PaymentAddress;\n    new(): PaymentAddress;\n};\n\ninterface PaymentMethodChangeEvent extends PaymentRequestUpdateEvent {\n    readonly methodDetails: any;\n    readonly methodName: string;\n}\n\ndeclare var PaymentMethodChangeEvent: {\n    prototype: PaymentMethodChangeEvent;\n    new(type: string, eventInitDict?: PaymentMethodChangeEventInit): PaymentMethodChangeEvent;\n};\n\ninterface PaymentRequestEventMap {\n    "paymentmethodchange": Event;\n    "shippingaddresschange": Event;\n    "shippingoptionchange": Event;\n}\n\n/** This Payment Request API interface is the primary access point into the API, and lets web content and apps accept payments from the end user. */\ninterface PaymentRequest extends EventTarget {\n    readonly id: string;\n    onpaymentmethodchange: ((this: PaymentRequest, ev: Event) => any) | null;\n    onshippingaddresschange: ((this: PaymentRequest, ev: Event) => any) | null;\n    onshippingoptionchange: ((this: PaymentRequest, ev: Event) => any) | null;\n    readonly shippingAddress: PaymentAddress | null;\n    readonly shippingOption: string | null;\n    readonly shippingType: PaymentShippingType | null;\n    abort(): Promise<void>;\n    canMakePayment(): Promise<boolean>;\n    show(detailsPromise: PaymentDetailsUpdate | Promise<PaymentDetailsUpdate>): Promise<PaymentResponse>;\n    addEventListener<K extends keyof PaymentRequestEventMap>(type: K, listener: (this: PaymentRequest, ev: PaymentRequestEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof PaymentRequestEventMap>(type: K, listener: (this: PaymentRequest, ev: PaymentRequestEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var PaymentRequest: {\n    prototype: PaymentRequest;\n    new(methodData: PaymentMethodData[], details: PaymentDetailsInit, options?: PaymentOptions): PaymentRequest;\n};\n\n/** This Payment Request API interface enables a web page to update the details of a PaymentRequest in response to a user action. */\ninterface PaymentRequestUpdateEvent extends Event {\n    updateWith(detailsPromise: PaymentDetailsUpdate | Promise<PaymentDetailsUpdate>): void;\n}\n\ndeclare var PaymentRequestUpdateEvent: {\n    prototype: PaymentRequestUpdateEvent;\n    new(type: string, eventInitDict?: PaymentRequestUpdateEventInit): PaymentRequestUpdateEvent;\n};\n\ninterface PaymentResponseEventMap {\n    "payerdetailchange": Event;\n}\n\n/** This Payment Request API interface is returned after a user selects a payment method and approves a payment request. */\ninterface PaymentResponse extends EventTarget {\n    readonly details: any;\n    readonly methodName: string;\n    onpayerdetailchange: ((this: PaymentResponse, ev: Event) => any) | null;\n    readonly payerEmail: string | null;\n    readonly payerName: string | null;\n    readonly payerPhone: string | null;\n    readonly requestId: string;\n    readonly shippingAddress: PaymentAddress | null;\n    readonly shippingOption: string | null;\n    complete(result?: PaymentComplete): Promise<void>;\n    retry(errorFields?: PaymentValidationErrors): Promise<void>;\n    toJSON(): any;\n    addEventListener<K extends keyof PaymentResponseEventMap>(type: K, listener: (this: PaymentResponse, ev: PaymentResponseEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof PaymentResponseEventMap>(type: K, listener: (this: PaymentResponse, ev: PaymentResponseEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var PaymentResponse: {\n    prototype: PaymentResponse;\n    new(): PaymentResponse;\n};\n\ninterface PerfWidgetExternal {\n    readonly activeNetworkRequestCount: number;\n    readonly averageFrameTime: number;\n    readonly averagePaintTime: number;\n    readonly extraInformationEnabled: boolean;\n    readonly independentRenderingEnabled: boolean;\n    readonly irDisablingContentString: string;\n    readonly irStatusAvailable: boolean;\n    readonly maxCpuSpeed: number;\n    readonly paintRequestsPerSecond: number;\n    readonly performanceCounter: number;\n    readonly performanceCounterFrequency: number;\n    addEventListener(eventType: string, callback: Function): void;\n    getMemoryUsage(): number;\n    getProcessCpuUsage(): number;\n    getRecentCpuUsage(last: number | null): any;\n    getRecentFrames(last: number | null): any;\n    getRecentMemoryUsage(last: number | null): any;\n    getRecentPaintRequests(last: number | null): any;\n    removeEventListener(eventType: string, callback: Function): void;\n    repositionWindow(x: number, y: number): void;\n    resizeWindow(width: number, height: number): void;\n}\n\ndeclare var PerfWidgetExternal: {\n    prototype: PerfWidgetExternal;\n    new(): PerfWidgetExternal;\n};\n\ninterface PerformanceEventMap {\n    "resourcetimingbufferfull": Event;\n}\n\n/** Provides access to performance-related information for the current page. It\'s part of the High Resolution Time API, but is enhanced by the Performance Timeline API, the Navigation Timing API, the User Timing API, and the Resource Timing API. */\ninterface Performance extends EventTarget {\n    /** @deprecated */\n    readonly navigation: PerformanceNavigation;\n    onresourcetimingbufferfull: ((this: Performance, ev: Event) => any) | null;\n    readonly timeOrigin: number;\n    /** @deprecated */\n    readonly timing: PerformanceTiming;\n    clearMarks(markName?: string): void;\n    clearMeasures(measureName?: string): void;\n    clearResourceTimings(): void;\n    getEntries(): PerformanceEntryList;\n    getEntriesByName(name: string, type?: string): PerformanceEntryList;\n    getEntriesByType(type: string): PerformanceEntryList;\n    mark(markName: string): void;\n    measure(measureName: string, startMark?: string, endMark?: string): void;\n    now(): number;\n    setResourceTimingBufferSize(maxSize: number): void;\n    toJSON(): any;\n    addEventListener<K extends keyof PerformanceEventMap>(type: K, listener: (this: Performance, ev: PerformanceEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof PerformanceEventMap>(type: K, listener: (this: Performance, ev: PerformanceEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var Performance: {\n    prototype: Performance;\n    new(): Performance;\n};\n\n/** Encapsulates a single performance metric that is part of the performance timeline. A performance entry can be directly created by making a performance mark or measure (for example by calling the mark() method) at an explicit point in an application. Performance entries are also created in indirect ways such as loading a resource (such as an image). */\ninterface PerformanceEntry {\n    readonly duration: number;\n    readonly entryType: string;\n    readonly name: string;\n    readonly startTime: number;\n    toJSON(): any;\n}\n\ndeclare var PerformanceEntry: {\n    prototype: PerformanceEntry;\n    new(): PerformanceEntry;\n};\n\n/** PerformanceMark is an abstract interface for PerformanceEntry objects with an entryType of "mark". Entries of this type are created by calling performance.mark() to add a named DOMHighResTimeStamp (the mark) to the browser\'s performance timeline. */\ninterface PerformanceMark extends PerformanceEntry {\n}\n\ndeclare var PerformanceMark: {\n    prototype: PerformanceMark;\n    new(): PerformanceMark;\n};\n\n/** PerformanceMeasure is an abstract interface for PerformanceEntry objects with an entryType of "measure". Entries of this type are created by calling performance.measure() to add a named DOMHighResTimeStamp (the measure) between two marks to the browser\'s performance timeline. */\ninterface PerformanceMeasure extends PerformanceEntry {\n}\n\ndeclare var PerformanceMeasure: {\n    prototype: PerformanceMeasure;\n    new(): PerformanceMeasure;\n};\n\n/** The legacy PerformanceNavigation interface represents information about how the navigation to the current document was done.\n * @deprecated This interface is deprecated in the Navigation Timing Level 2 specification. Please use the PerformanceNavigationTiming interface instead.\n */\ninterface PerformanceNavigation {\n    readonly redirectCount: number;\n    readonly type: number;\n    toJSON(): any;\n    readonly TYPE_BACK_FORWARD: number;\n    readonly TYPE_NAVIGATE: number;\n    readonly TYPE_RELOAD: number;\n    readonly TYPE_RESERVED: number;\n}\n\ndeclare var PerformanceNavigation: {\n    prototype: PerformanceNavigation;\n    new(): PerformanceNavigation;\n    readonly TYPE_BACK_FORWARD: number;\n    readonly TYPE_NAVIGATE: number;\n    readonly TYPE_RELOAD: number;\n    readonly TYPE_RESERVED: number;\n};\n\n/** Provides methods and properties to store and retrieve metrics regarding the browser\'s document navigation events. For example, this interface can be used to determine how much time it takes to load or unload a document. */\ninterface PerformanceNavigationTiming extends PerformanceResourceTiming {\n    readonly domComplete: number;\n    readonly domContentLoadedEventEnd: number;\n    readonly domContentLoadedEventStart: number;\n    readonly domInteractive: number;\n    readonly loadEventEnd: number;\n    readonly loadEventStart: number;\n    readonly redirectCount: number;\n    readonly type: NavigationType;\n    readonly unloadEventEnd: number;\n    readonly unloadEventStart: number;\n    toJSON(): any;\n}\n\ndeclare var PerformanceNavigationTiming: {\n    prototype: PerformanceNavigationTiming;\n    new(): PerformanceNavigationTiming;\n};\n\ninterface PerformanceObserver {\n    disconnect(): void;\n    observe(options?: PerformanceObserverInit): void;\n    takeRecords(): PerformanceEntryList;\n}\n\ndeclare var PerformanceObserver: {\n    prototype: PerformanceObserver;\n    new(callback: PerformanceObserverCallback): PerformanceObserver;\n    readonly supportedEntryTypes: ReadonlyArray<string>;\n};\n\ninterface PerformanceObserverEntryList {\n    getEntries(): PerformanceEntryList;\n    getEntriesByName(name: string, type?: string): PerformanceEntryList;\n    getEntriesByType(type: string): PerformanceEntryList;\n}\n\ndeclare var PerformanceObserverEntryList: {\n    prototype: PerformanceObserverEntryList;\n    new(): PerformanceObserverEntryList;\n};\n\n/** Enables retrieval and analysis of detailed network timing data regarding the loading of an application\'s resources. An application can use the timing metrics to determine, for example, the length of time it takes to fetch a specific resource, such as an XMLHttpRequest, <SVG>, image, or script. */\ninterface PerformanceResourceTiming extends PerformanceEntry {\n    readonly connectEnd: number;\n    readonly connectStart: number;\n    readonly decodedBodySize: number;\n    readonly domainLookupEnd: number;\n    readonly domainLookupStart: number;\n    readonly encodedBodySize: number;\n    readonly fetchStart: number;\n    readonly initiatorType: string;\n    readonly nextHopProtocol: string;\n    readonly redirectEnd: number;\n    readonly redirectStart: number;\n    readonly requestStart: number;\n    readonly responseEnd: number;\n    readonly responseStart: number;\n    readonly secureConnectionStart: number;\n    readonly transferSize: number;\n    readonly workerStart: number;\n    toJSON(): any;\n}\n\ndeclare var PerformanceResourceTiming: {\n    prototype: PerformanceResourceTiming;\n    new(): PerformanceResourceTiming;\n};\n\n/** A legacy interface kept for backwards compatibility and contains properties that offer performance timing information for various events which occur during the loading and use of the current page. You get a PerformanceTiming object describing your page using the window.performance.timing property.\n * @deprecated This interface is deprecated in the Navigation Timing Level 2 specification. Please use the PerformanceNavigationTiming interface instead.\n */\ninterface PerformanceTiming {\n    readonly connectEnd: number;\n    readonly connectStart: number;\n    readonly domComplete: number;\n    readonly domContentLoadedEventEnd: number;\n    readonly domContentLoadedEventStart: number;\n    readonly domInteractive: number;\n    readonly domLoading: number;\n    readonly domainLookupEnd: number;\n    readonly domainLookupStart: number;\n    readonly fetchStart: number;\n    readonly loadEventEnd: number;\n    readonly loadEventStart: number;\n    readonly navigationStart: number;\n    readonly redirectEnd: number;\n    readonly redirectStart: number;\n    readonly requestStart: number;\n    readonly responseEnd: number;\n    readonly responseStart: number;\n    readonly secureConnectionStart: number;\n    readonly unloadEventEnd: number;\n    readonly unloadEventStart: number;\n    toJSON(): any;\n}\n\ndeclare var PerformanceTiming: {\n    prototype: PerformanceTiming;\n    new(): PerformanceTiming;\n};\n\n/** PeriodicWave has no inputs or outputs; it is used to define custom oscillators when calling OscillatorNode.setPeriodicWave(). The PeriodicWave itself is created/returned by AudioContext.createPeriodicWave(). */\ninterface PeriodicWave {\n}\n\ndeclare var PeriodicWave: {\n    prototype: PeriodicWave;\n    new(context: BaseAudioContext, options?: PeriodicWaveOptions): PeriodicWave;\n};\n\ninterface PermissionRequest extends DeferredPermissionRequest {\n    readonly state: MSWebViewPermissionState;\n    defer(): void;\n}\n\ndeclare var PermissionRequest: {\n    prototype: PermissionRequest;\n    new(): PermissionRequest;\n};\n\ninterface PermissionRequestedEvent extends Event {\n    readonly permissionRequest: PermissionRequest;\n}\n\ndeclare var PermissionRequestedEvent: {\n    prototype: PermissionRequestedEvent;\n    new(): PermissionRequestedEvent;\n};\n\ninterface PermissionStatusEventMap {\n    "change": Event;\n}\n\ninterface PermissionStatus extends EventTarget {\n    onchange: ((this: PermissionStatus, ev: Event) => any) | null;\n    readonly state: PermissionState;\n    addEventListener<K extends keyof PermissionStatusEventMap>(type: K, listener: (this: PermissionStatus, ev: PermissionStatusEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof PermissionStatusEventMap>(type: K, listener: (this: PermissionStatus, ev: PermissionStatusEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var PermissionStatus: {\n    prototype: PermissionStatus;\n    new(): PermissionStatus;\n};\n\ninterface Permissions {\n    query(permissionDesc: PermissionDescriptor | DevicePermissionDescriptor | MidiPermissionDescriptor | PushPermissionDescriptor): Promise<PermissionStatus>;\n}\n\ndeclare var Permissions: {\n    prototype: Permissions;\n    new(): Permissions;\n};\n\n/** Provides information about a browser plugin. */\ninterface Plugin {\n    /**\n     * Returns the plugin\'s description.\n     */\n    readonly description: string;\n    /**\n     * Returns the plugin library\'s filename, if applicable on the current platform.\n     */\n    readonly filename: string;\n    /**\n     * Returns the number of MIME types, represented by MimeType objects, supported by the plugin.\n     */\n    readonly length: number;\n    /**\n     * Returns the plugin\'s name.\n     */\n    readonly name: string;\n    /**\n     * Returns the specified MimeType object.\n     */\n    item(index: number): MimeType | null;\n    namedItem(name: string): MimeType | null;\n    [index: number]: MimeType;\n}\n\ndeclare var Plugin: {\n    prototype: Plugin;\n    new(): Plugin;\n};\n\n/** Used to store a list of Plugin objects describing the available plugins; it\'s returned by the window.navigator.plugins property. The PluginArray is not a JavaScript array, but has the length property and supports accessing individual items using bracket notation (plugins[2]), as well as via item(index) and namedItem("name") methods. */\ninterface PluginArray {\n    readonly length: number;\n    item(index: number): Plugin | null;\n    namedItem(name: string): Plugin | null;\n    refresh(reload?: boolean): void;\n    [index: number]: Plugin;\n}\n\ndeclare var PluginArray: {\n    prototype: PluginArray;\n    new(): PluginArray;\n};\n\n/** The state of a DOM event produced by a pointer such as the geometry of the contact point, the device type that generated the event, the amount of pressure that was applied on the contact surface, etc. */\ninterface PointerEvent extends MouseEvent {\n    readonly height: number;\n    readonly isPrimary: boolean;\n    readonly pointerId: number;\n    readonly pointerType: string;\n    readonly pressure: number;\n    readonly tangentialPressure: number;\n    readonly tiltX: number;\n    readonly tiltY: number;\n    readonly twist: number;\n    readonly width: number;\n    getCoalescedEvents(): PointerEvent[];\n    getPredictedEvents(): PointerEvent[];\n}\n\ndeclare var PointerEvent: {\n    prototype: PointerEvent;\n    new(type: string, eventInitDict?: PointerEventInit): PointerEvent;\n};\n\n/** PopStateEvent is an event handler for the popstate event on the window. */\ninterface PopStateEvent extends Event {\n    /**\n     * Returns a copy of the information that was provided to pushState() or replaceState().\n     */\n    readonly state: any;\n}\n\ndeclare var PopStateEvent: {\n    prototype: PopStateEvent;\n    new(type: string, eventInitDict?: PopStateEventInit): PopStateEvent;\n};\n\n/** A processing instruction embeds application-specific instructions in XML which can be ignored by other applications that don\'t recognize them. */\ninterface ProcessingInstruction extends CharacterData, LinkStyle {\n    readonly ownerDocument: Document;\n    readonly target: string;\n}\n\ndeclare var ProcessingInstruction: {\n    prototype: ProcessingInstruction;\n    new(): ProcessingInstruction;\n};\n\n/** Events measuring progress of an underlying process, like an HTTP request (for an XMLHttpRequest, or the loading of the underlying resource of an <img>, <audio>, <video>, <style> or <link>). */\ninterface ProgressEvent<T extends EventTarget = EventTarget> extends Event {\n    readonly lengthComputable: boolean;\n    readonly loaded: number;\n    readonly target: T | null;\n    readonly total: number;\n}\n\ndeclare var ProgressEvent: {\n    prototype: ProgressEvent;\n    new(type: string, eventInitDict?: ProgressEventInit): ProgressEvent;\n};\n\ninterface PromiseRejectionEvent extends Event {\n    readonly promise: Promise<any>;\n    readonly reason: any;\n}\n\ndeclare var PromiseRejectionEvent: {\n    prototype: PromiseRejectionEvent;\n    new(type: string, eventInitDict: PromiseRejectionEventInit): PromiseRejectionEvent;\n};\n\ninterface PublicKeyCredential extends Credential {\n    readonly rawId: ArrayBuffer;\n    readonly response: AuthenticatorResponse;\n    getClientExtensionResults(): AuthenticationExtensionsClientOutputs;\n}\n\ndeclare var PublicKeyCredential: {\n    prototype: PublicKeyCredential;\n    new(): PublicKeyCredential;\n    isUserVerifyingPlatformAuthenticatorAvailable(): Promise<boolean>;\n};\n\n/** This Push API interface provides a way to receive notifications from third-party servers as well as request URLs for push notifications. */\ninterface PushManager {\n    getSubscription(): Promise<PushSubscription | null>;\n    permissionState(options?: PushSubscriptionOptionsInit): Promise<PushPermissionState>;\n    subscribe(options?: PushSubscriptionOptionsInit): Promise<PushSubscription>;\n}\n\ndeclare var PushManager: {\n    prototype: PushManager;\n    new(): PushManager;\n    readonly supportedContentEncodings: ReadonlyArray<string>;\n};\n\n/** This Push API interface provides a subcription\'s URL endpoint and allows unsubscription from a push service. */\ninterface PushSubscription {\n    readonly endpoint: string;\n    readonly expirationTime: number | null;\n    readonly options: PushSubscriptionOptions;\n    getKey(name: PushEncryptionKeyName): ArrayBuffer | null;\n    toJSON(): PushSubscriptionJSON;\n    unsubscribe(): Promise<boolean>;\n}\n\ndeclare var PushSubscription: {\n    prototype: PushSubscription;\n    new(): PushSubscription;\n};\n\ninterface PushSubscriptionOptions {\n    readonly applicationServerKey: ArrayBuffer | null;\n    readonly userVisibleOnly: boolean;\n}\n\ndeclare var PushSubscriptionOptions: {\n    prototype: PushSubscriptionOptions;\n    new(): PushSubscriptionOptions;\n};\n\ninterface RTCCertificate {\n    readonly expires: number;\n    getFingerprints(): RTCDtlsFingerprint[];\n}\n\ndeclare var RTCCertificate: {\n    prototype: RTCCertificate;\n    new(): RTCCertificate;\n};\n\ninterface RTCDTMFSenderEventMap {\n    "tonechange": RTCDTMFToneChangeEvent;\n}\n\ninterface RTCDTMFSender extends EventTarget {\n    readonly canInsertDTMF: boolean;\n    ontonechange: ((this: RTCDTMFSender, ev: RTCDTMFToneChangeEvent) => any) | null;\n    readonly toneBuffer: string;\n    insertDTMF(tones: string, duration?: number, interToneGap?: number): void;\n    addEventListener<K extends keyof RTCDTMFSenderEventMap>(type: K, listener: (this: RTCDTMFSender, ev: RTCDTMFSenderEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof RTCDTMFSenderEventMap>(type: K, listener: (this: RTCDTMFSender, ev: RTCDTMFSenderEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var RTCDTMFSender: {\n    prototype: RTCDTMFSender;\n    new(): RTCDTMFSender;\n};\n\n/** Events sent to indicate that DTMF tones have started or finished playing. This interface is used by the tonechange event. */\ninterface RTCDTMFToneChangeEvent extends Event {\n    readonly tone: string;\n}\n\ndeclare var RTCDTMFToneChangeEvent: {\n    prototype: RTCDTMFToneChangeEvent;\n    new(type: string, eventInitDict?: RTCDTMFToneChangeEventInit): RTCDTMFToneChangeEvent;\n};\n\ninterface RTCDataChannelEventMap {\n    "bufferedamountlow": Event;\n    "close": Event;\n    "error": RTCErrorEvent;\n    "message": MessageEvent;\n    "open": Event;\n}\n\ninterface RTCDataChannel extends EventTarget {\n    binaryType: BinaryType;\n    readonly bufferedAmount: number;\n    bufferedAmountLowThreshold: number;\n    readonly id: number | null;\n    readonly label: string;\n    readonly maxPacketLifeTime: number | null;\n    readonly maxRetransmits: number | null;\n    readonly negotiated: boolean;\n    onbufferedamountlow: ((this: RTCDataChannel, ev: Event) => any) | null;\n    onclose: ((this: RTCDataChannel, ev: Event) => any) | null;\n    onerror: ((this: RTCDataChannel, ev: RTCErrorEvent) => any) | null;\n    onmessage: ((this: RTCDataChannel, ev: MessageEvent) => any) | null;\n    onopen: ((this: RTCDataChannel, ev: Event) => any) | null;\n    readonly ordered: boolean;\n    readonly protocol: string;\n    readonly readyState: RTCDataChannelState;\n    close(): void;\n    send(data: string): void;\n    send(data: Blob): void;\n    send(data: ArrayBuffer): void;\n    send(data: ArrayBufferView): void;\n    addEventListener<K extends keyof RTCDataChannelEventMap>(type: K, listener: (this: RTCDataChannel, ev: RTCDataChannelEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof RTCDataChannelEventMap>(type: K, listener: (this: RTCDataChannel, ev: RTCDataChannelEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var RTCDataChannel: {\n    prototype: RTCDataChannel;\n    new(): RTCDataChannel;\n};\n\ninterface RTCDataChannelEvent extends Event {\n    readonly channel: RTCDataChannel;\n}\n\ndeclare var RTCDataChannelEvent: {\n    prototype: RTCDataChannelEvent;\n    new(type: string, eventInitDict: RTCDataChannelEventInit): RTCDataChannelEvent;\n};\n\ninterface RTCDtlsTransportEventMap {\n    "error": RTCErrorEvent;\n    "statechange": Event;\n}\n\ninterface RTCDtlsTransport extends EventTarget {\n    readonly iceTransport: RTCIceTransport;\n    onerror: ((this: RTCDtlsTransport, ev: RTCErrorEvent) => any) | null;\n    onstatechange: ((this: RTCDtlsTransport, ev: Event) => any) | null;\n    readonly state: RTCDtlsTransportState;\n    getRemoteCertificates(): ArrayBuffer[];\n    addEventListener<K extends keyof RTCDtlsTransportEventMap>(type: K, listener: (this: RTCDtlsTransport, ev: RTCDtlsTransportEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof RTCDtlsTransportEventMap>(type: K, listener: (this: RTCDtlsTransport, ev: RTCDtlsTransportEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var RTCDtlsTransport: {\n    prototype: RTCDtlsTransport;\n    new(): RTCDtlsTransport;\n};\n\ninterface RTCDtlsTransportStateChangedEvent extends Event {\n    readonly state: RTCDtlsTransportState;\n}\n\ndeclare var RTCDtlsTransportStateChangedEvent: {\n    prototype: RTCDtlsTransportStateChangedEvent;\n    new(): RTCDtlsTransportStateChangedEvent;\n};\n\ninterface RTCDtmfSenderEventMap {\n    "tonechange": RTCDTMFToneChangeEvent;\n}\n\ninterface RTCDtmfSender extends EventTarget {\n    readonly canInsertDTMF: boolean;\n    readonly duration: number;\n    readonly interToneGap: number;\n    ontonechange: ((this: RTCDtmfSender, ev: RTCDTMFToneChangeEvent) => any) | null;\n    readonly sender: RTCRtpSender;\n    readonly toneBuffer: string;\n    insertDTMF(tones: string, duration?: number, interToneGap?: number): void;\n    addEventListener<K extends keyof RTCDtmfSenderEventMap>(type: K, listener: (this: RTCDtmfSender, ev: RTCDtmfSenderEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof RTCDtmfSenderEventMap>(type: K, listener: (this: RTCDtmfSender, ev: RTCDtmfSenderEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var RTCDtmfSender: {\n    prototype: RTCDtmfSender;\n    new(sender: RTCRtpSender): RTCDtmfSender;\n};\n\ninterface RTCError extends DOMException {\n    readonly errorDetail: RTCErrorDetailType;\n    readonly receivedAlert: number | null;\n    readonly sctpCauseCode: number | null;\n    readonly sdpLineNumber: number | null;\n    readonly sentAlert: number | null;\n}\n\ndeclare var RTCError: {\n    prototype: RTCError;\n    new(init: RTCErrorInit, message?: string): RTCError;\n};\n\ninterface RTCErrorEvent extends Event {\n    readonly error: RTCError;\n}\n\ndeclare var RTCErrorEvent: {\n    prototype: RTCErrorEvent;\n    new(type: string, eventInitDict: RTCErrorEventInit): RTCErrorEvent;\n};\n\n/** The RTCIceCandidate interface—part of the WebRTC API—represents a candidate Internet Connectivity Establishment (ICE) configuration which may be used to establish an RTCPeerConnection. */\ninterface RTCIceCandidate {\n    readonly candidate: string;\n    readonly component: RTCIceComponent | null;\n    readonly foundation: string | null;\n    readonly port: number | null;\n    readonly priority: number | null;\n    readonly protocol: RTCIceProtocol | null;\n    readonly relatedAddress: string | null;\n    readonly relatedPort: number | null;\n    readonly sdpMLineIndex: number | null;\n    readonly sdpMid: string | null;\n    readonly tcpType: RTCIceTcpCandidateType | null;\n    readonly type: RTCIceCandidateType | null;\n    readonly usernameFragment: string | null;\n    toJSON(): RTCIceCandidateInit;\n}\n\ndeclare var RTCIceCandidate: {\n    prototype: RTCIceCandidate;\n    new(candidateInitDict?: RTCIceCandidateInit): RTCIceCandidate;\n};\n\ninterface RTCIceCandidatePairChangedEvent extends Event {\n    readonly pair: RTCIceCandidatePair;\n}\n\ndeclare var RTCIceCandidatePairChangedEvent: {\n    prototype: RTCIceCandidatePairChangedEvent;\n    new(): RTCIceCandidatePairChangedEvent;\n};\n\ninterface RTCIceGathererEventMap {\n    "error": Event;\n    "localcandidate": RTCIceGathererEvent;\n}\n\ninterface RTCIceGatherer extends RTCStatsProvider {\n    readonly component: RTCIceComponent;\n    onerror: ((this: RTCIceGatherer, ev: Event) => any) | null;\n    onlocalcandidate: ((this: RTCIceGatherer, ev: RTCIceGathererEvent) => any) | null;\n    createAssociatedGatherer(): RTCIceGatherer;\n    getLocalCandidates(): RTCIceCandidateDictionary[];\n    getLocalParameters(): RTCIceParameters;\n    addEventListener<K extends keyof RTCIceGathererEventMap>(type: K, listener: (this: RTCIceGatherer, ev: RTCIceGathererEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof RTCIceGathererEventMap>(type: K, listener: (this: RTCIceGatherer, ev: RTCIceGathererEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var RTCIceGatherer: {\n    prototype: RTCIceGatherer;\n    new(options: RTCIceGatherOptions): RTCIceGatherer;\n};\n\ninterface RTCIceGathererEvent extends Event {\n    readonly candidate: RTCIceCandidateDictionary | RTCIceCandidateComplete;\n}\n\ndeclare var RTCIceGathererEvent: {\n    prototype: RTCIceGathererEvent;\n    new(): RTCIceGathererEvent;\n};\n\ninterface RTCIceTransportEventMap {\n    "gatheringstatechange": Event;\n    "selectedcandidatepairchange": Event;\n    "statechange": Event;\n}\n\n/** Provides access to information about the ICE transport layer over which the data is being sent and received. */\ninterface RTCIceTransport extends EventTarget {\n    readonly gatheringState: RTCIceGathererState;\n    ongatheringstatechange: ((this: RTCIceTransport, ev: Event) => any) | null;\n    onselectedcandidatepairchange: ((this: RTCIceTransport, ev: Event) => any) | null;\n    onstatechange: ((this: RTCIceTransport, ev: Event) => any) | null;\n    readonly role: RTCIceRole;\n    readonly state: RTCIceTransportState;\n    getLocalCandidates(): RTCIceCandidate[];\n    getLocalParameters(): RTCIceParameters | null;\n    getRemoteCandidates(): RTCIceCandidate[];\n    getRemoteParameters(): RTCIceParameters | null;\n    getSelectedCandidatePair(): RTCIceCandidatePair | null;\n    addEventListener<K extends keyof RTCIceTransportEventMap>(type: K, listener: (this: RTCIceTransport, ev: RTCIceTransportEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof RTCIceTransportEventMap>(type: K, listener: (this: RTCIceTransport, ev: RTCIceTransportEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var RTCIceTransport: {\n    prototype: RTCIceTransport;\n    new(): RTCIceTransport;\n};\n\ninterface RTCIceTransportStateChangedEvent extends Event {\n    readonly state: RTCIceTransportState;\n}\n\ndeclare var RTCIceTransportStateChangedEvent: {\n    prototype: RTCIceTransportStateChangedEvent;\n    new(): RTCIceTransportStateChangedEvent;\n};\n\ninterface RTCIdentityAssertion {\n    idp: string;\n    name: string;\n}\n\ndeclare var RTCIdentityAssertion: {\n    prototype: RTCIdentityAssertion;\n    new(idp: string, name: string): RTCIdentityAssertion;\n};\n\ninterface RTCPeerConnectionEventMap {\n    "connectionstatechange": Event;\n    "datachannel": RTCDataChannelEvent;\n    "icecandidate": RTCPeerConnectionIceEvent;\n    "icecandidateerror": RTCPeerConnectionIceErrorEvent;\n    "iceconnectionstatechange": Event;\n    "icegatheringstatechange": Event;\n    "negotiationneeded": Event;\n    "signalingstatechange": Event;\n    "track": RTCTrackEvent;\n}\n\n/** A WebRTC connection between the local computer and a remote peer. It provides methods to connect to a remote peer, maintain and monitor the connection, and close the connection once it\'s no longer needed. */\ninterface RTCPeerConnection extends EventTarget {\n    readonly canTrickleIceCandidates: boolean | null;\n    readonly connectionState: RTCPeerConnectionState;\n    readonly currentLocalDescription: RTCSessionDescription | null;\n    readonly currentRemoteDescription: RTCSessionDescription | null;\n    readonly iceConnectionState: RTCIceConnectionState;\n    readonly iceGatheringState: RTCIceGatheringState;\n    readonly idpErrorInfo: string | null;\n    readonly idpLoginUrl: string | null;\n    readonly localDescription: RTCSessionDescription | null;\n    onconnectionstatechange: ((this: RTCPeerConnection, ev: Event) => any) | null;\n    ondatachannel: ((this: RTCPeerConnection, ev: RTCDataChannelEvent) => any) | null;\n    onicecandidate: ((this: RTCPeerConnection, ev: RTCPeerConnectionIceEvent) => any) | null;\n    onicecandidateerror: ((this: RTCPeerConnection, ev: RTCPeerConnectionIceErrorEvent) => any) | null;\n    oniceconnectionstatechange: ((this: RTCPeerConnection, ev: Event) => any) | null;\n    onicegatheringstatechange: ((this: RTCPeerConnection, ev: Event) => any) | null;\n    onnegotiationneeded: ((this: RTCPeerConnection, ev: Event) => any) | null;\n    onsignalingstatechange: ((this: RTCPeerConnection, ev: Event) => any) | null;\n    ontrack: ((this: RTCPeerConnection, ev: RTCTrackEvent) => any) | null;\n    readonly peerIdentity: Promise<RTCIdentityAssertion>;\n    readonly pendingLocalDescription: RTCSessionDescription | null;\n    readonly pendingRemoteDescription: RTCSessionDescription | null;\n    readonly remoteDescription: RTCSessionDescription | null;\n    readonly sctp: RTCSctpTransport | null;\n    readonly signalingState: RTCSignalingState;\n    addIceCandidate(candidate: RTCIceCandidateInit | RTCIceCandidate): Promise<void>;\n    addTrack(track: MediaStreamTrack, ...streams: MediaStream[]): RTCRtpSender;\n    addTransceiver(trackOrKind: MediaStreamTrack | string, init?: RTCRtpTransceiverInit): RTCRtpTransceiver;\n    close(): void;\n    createAnswer(options?: RTCOfferOptions): Promise<RTCSessionDescriptionInit>;\n    createDataChannel(label: string, dataChannelDict?: RTCDataChannelInit): RTCDataChannel;\n    createOffer(options?: RTCOfferOptions): Promise<RTCSessionDescriptionInit>;\n    getConfiguration(): RTCConfiguration;\n    getIdentityAssertion(): Promise<string>;\n    getReceivers(): RTCRtpReceiver[];\n    getSenders(): RTCRtpSender[];\n    getStats(selector?: MediaStreamTrack | null): Promise<RTCStatsReport>;\n    getTransceivers(): RTCRtpTransceiver[];\n    removeTrack(sender: RTCRtpSender): void;\n    restartIce(): void;\n    setConfiguration(configuration?: RTCConfiguration): void;\n    setIdentityProvider(provider: string, options?: RTCIdentityProviderOptions): void;\n    setLocalDescription(description?: RTCSessionDescriptionInit): Promise<void>;\n    setRemoteDescription(description: RTCSessionDescriptionInit): Promise<void>;\n    addEventListener<K extends keyof RTCPeerConnectionEventMap>(type: K, listener: (this: RTCPeerConnection, ev: RTCPeerConnectionEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof RTCPeerConnectionEventMap>(type: K, listener: (this: RTCPeerConnection, ev: RTCPeerConnectionEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var RTCPeerConnection: {\n    prototype: RTCPeerConnection;\n    new(configuration?: RTCConfiguration): RTCPeerConnection;\n    generateCertificate(keygenAlgorithm: AlgorithmIdentifier): Promise<RTCCertificate>;\n};\n\ninterface RTCPeerConnectionIceErrorEvent extends Event {\n    readonly address: string | null;\n    readonly errorCode: number;\n    readonly errorText: string;\n    readonly port: number | null;\n    readonly url: string;\n}\n\ndeclare var RTCPeerConnectionIceErrorEvent: {\n    prototype: RTCPeerConnectionIceErrorEvent;\n    new(type: string, eventInitDict: RTCPeerConnectionIceErrorEventInit): RTCPeerConnectionIceErrorEvent;\n};\n\n/** Events that occurs in relation to ICE candidates with the target, usually an RTCPeerConnection. Only one event is of this type: icecandidate. */\ninterface RTCPeerConnectionIceEvent extends Event {\n    readonly candidate: RTCIceCandidate | null;\n}\n\ndeclare var RTCPeerConnectionIceEvent: {\n    prototype: RTCPeerConnectionIceEvent;\n    new(type: string, eventInitDict?: RTCPeerConnectionIceEventInit): RTCPeerConnectionIceEvent;\n};\n\n/** This WebRTC API interface manages the reception and decoding of data for a MediaStreamTrack on an RTCPeerConnection. */\ninterface RTCRtpReceiver {\n    readonly track: MediaStreamTrack;\n    readonly transport: RTCDtlsTransport | null;\n    getContributingSources(): RTCRtpContributingSource[];\n    getParameters(): RTCRtpReceiveParameters;\n    getStats(): Promise<RTCStatsReport>;\n    getSynchronizationSources(): RTCRtpSynchronizationSource[];\n}\n\ndeclare var RTCRtpReceiver: {\n    prototype: RTCRtpReceiver;\n    new(): RTCRtpReceiver;\n    getCapabilities(kind: string): RTCRtpCapabilities | null;\n};\n\n/** Provides the ability to control and obtain details about how a particular MediaStreamTrack is encoded and sent to a remote peer. */\ninterface RTCRtpSender {\n    readonly dtmf: RTCDTMFSender | null;\n    readonly track: MediaStreamTrack | null;\n    readonly transport: RTCDtlsTransport | null;\n    getParameters(): RTCRtpSendParameters;\n    getStats(): Promise<RTCStatsReport>;\n    replaceTrack(withTrack: MediaStreamTrack | null): Promise<void>;\n    setParameters(parameters: RTCRtpSendParameters): Promise<void>;\n    setStreams(...streams: MediaStream[]): void;\n}\n\ndeclare var RTCRtpSender: {\n    prototype: RTCRtpSender;\n    new(): RTCRtpSender;\n    getCapabilities(kind: string): RTCRtpCapabilities | null;\n};\n\ninterface RTCRtpTransceiver {\n    readonly currentDirection: RTCRtpTransceiverDirection | null;\n    direction: RTCRtpTransceiverDirection;\n    readonly mid: string | null;\n    readonly receiver: RTCRtpReceiver;\n    readonly sender: RTCRtpSender;\n    setCodecPreferences(codecs: RTCRtpCodecCapability[]): void;\n    stop(): void;\n}\n\ndeclare var RTCRtpTransceiver: {\n    prototype: RTCRtpTransceiver;\n    new(): RTCRtpTransceiver;\n};\n\ninterface RTCSctpTransportEventMap {\n    "statechange": Event;\n}\n\ninterface RTCSctpTransport extends EventTarget {\n    readonly maxChannels: number | null;\n    readonly maxMessageSize: number;\n    onstatechange: ((this: RTCSctpTransport, ev: Event) => any) | null;\n    readonly state: RTCSctpTransportState;\n    readonly transport: RTCDtlsTransport;\n    addEventListener<K extends keyof RTCSctpTransportEventMap>(type: K, listener: (this: RTCSctpTransport, ev: RTCSctpTransportEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof RTCSctpTransportEventMap>(type: K, listener: (this: RTCSctpTransport, ev: RTCSctpTransportEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var RTCSctpTransport: {\n    prototype: RTCSctpTransport;\n    new(): RTCSctpTransport;\n};\n\n/** One end of a connection—or potential connection—and how it\'s configured. Each RTCSessionDescription consists of a description type indicating which part of the offer/answer negotiation process it describes and of the SDP descriptor of the session. */\ninterface RTCSessionDescription {\n    readonly sdp: string;\n    readonly type: RTCSdpType;\n    toJSON(): any;\n}\n\ndeclare var RTCSessionDescription: {\n    prototype: RTCSessionDescription;\n    new(descriptionInitDict: RTCSessionDescriptionInit): RTCSessionDescription;\n};\n\ninterface RTCSrtpSdesTransportEventMap {\n    "error": Event;\n}\n\ninterface RTCSrtpSdesTransport extends EventTarget {\n    onerror: ((this: RTCSrtpSdesTransport, ev: Event) => any) | null;\n    readonly transport: RTCIceTransport;\n    addEventListener<K extends keyof RTCSrtpSdesTransportEventMap>(type: K, listener: (this: RTCSrtpSdesTransport, ev: RTCSrtpSdesTransportEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof RTCSrtpSdesTransportEventMap>(type: K, listener: (this: RTCSrtpSdesTransport, ev: RTCSrtpSdesTransportEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var RTCSrtpSdesTransport: {\n    prototype: RTCSrtpSdesTransport;\n    new(transport: RTCIceTransport, encryptParameters: RTCSrtpSdesParameters, decryptParameters: RTCSrtpSdesParameters): RTCSrtpSdesTransport;\n    getLocalParameters(): RTCSrtpSdesParameters[];\n};\n\ninterface RTCSsrcConflictEvent extends Event {\n    readonly ssrc: number;\n}\n\ndeclare var RTCSsrcConflictEvent: {\n    prototype: RTCSsrcConflictEvent;\n    new(): RTCSsrcConflictEvent;\n};\n\ninterface RTCStatsProvider extends EventTarget {\n    getStats(): Promise<RTCStatsReport>;\n    msGetStats(): Promise<RTCStatsReport>;\n}\n\ndeclare var RTCStatsProvider: {\n    prototype: RTCStatsProvider;\n    new(): RTCStatsProvider;\n};\n\ninterface RTCStatsReport {\n    forEach(callbackfn: (value: any, key: string, parent: RTCStatsReport) => void, thisArg?: any): void;\n}\n\ndeclare var RTCStatsReport: {\n    prototype: RTCStatsReport;\n    new(): RTCStatsReport;\n};\n\ninterface RTCTrackEvent extends Event {\n    readonly receiver: RTCRtpReceiver;\n    readonly streams: ReadonlyArray<MediaStream>;\n    readonly track: MediaStreamTrack;\n    readonly transceiver: RTCRtpTransceiver;\n}\n\ndeclare var RTCTrackEvent: {\n    prototype: RTCTrackEvent;\n    new(type: string, eventInitDict: RTCTrackEventInit): RTCTrackEvent;\n};\n\ninterface RadioNodeList extends NodeList {\n    value: string;\n}\n\ndeclare var RadioNodeList: {\n    prototype: RadioNodeList;\n    new(): RadioNodeList;\n};\n\ninterface RandomSource {\n    getRandomValues<T extends Int8Array | Uint8ClampedArray | Uint8Array | Int16Array | Uint16Array | Int32Array | Uint32Array>(array: T): T;\n}\n\ndeclare var RandomSource: {\n    prototype: RandomSource;\n    new(): RandomSource;\n};\n\n/** A fragment of a document that can contain nodes and parts of text nodes. */\ninterface Range extends AbstractRange {\n    /**\n     * Returns the node, furthest away from the document, that is an ancestor of both range\'s start node and end node.\n     */\n    readonly commonAncestorContainer: Node;\n    cloneContents(): DocumentFragment;\n    cloneRange(): Range;\n    collapse(toStart?: boolean): void;\n    compareBoundaryPoints(how: number, sourceRange: Range): number;\n    /**\n     * Returns −1 if the point is before the range, 0 if the point is in the range, and 1 if the point is after the range.\n     */\n    comparePoint(node: Node, offset: number): number;\n    createContextualFragment(fragment: string): DocumentFragment;\n    deleteContents(): void;\n    detach(): void;\n    extractContents(): DocumentFragment;\n    getBoundingClientRect(): DOMRect;\n    getClientRects(): DOMRectList;\n    insertNode(node: Node): void;\n    /**\n     * Returns whether range intersects node.\n     */\n    intersectsNode(node: Node): boolean;\n    isPointInRange(node: Node, offset: number): boolean;\n    selectNode(node: Node): void;\n    selectNodeContents(node: Node): void;\n    setEnd(node: Node, offset: number): void;\n    setEndAfter(node: Node): void;\n    setEndBefore(node: Node): void;\n    setStart(node: Node, offset: number): void;\n    setStartAfter(node: Node): void;\n    setStartBefore(node: Node): void;\n    surroundContents(newParent: Node): void;\n    toString(): string;\n    readonly END_TO_END: number;\n    readonly END_TO_START: number;\n    readonly START_TO_END: number;\n    readonly START_TO_START: number;\n}\n\ndeclare var Range: {\n    prototype: Range;\n    new(): Range;\n    readonly END_TO_END: number;\n    readonly END_TO_START: number;\n    readonly START_TO_END: number;\n    readonly START_TO_START: number;\n    toString(): string;\n};\n\n/** This Streams API interface represents a readable stream of byte data. The Fetch API offers a concrete instance of a ReadableStream through the body property of a Response object. */\ninterface ReadableStream<R = any> {\n    readonly locked: boolean;\n    cancel(reason?: any): Promise<void>;\n    getReader(): ReadableStreamDefaultReader<R>;\n    pipeThrough<T>(transform: ReadableWritablePair<T, R>, options?: StreamPipeOptions): ReadableStream<T>;\n    pipeTo(dest: WritableStream<R>, options?: StreamPipeOptions): Promise<void>;\n    tee(): [ReadableStream<R>, ReadableStream<R>];\n}\n\ndeclare var ReadableStream: {\n    prototype: ReadableStream;\n    new<R = any>(underlyingSource?: UnderlyingSource<R>, strategy?: QueuingStrategy<R>): ReadableStream<R>;\n};\n\ninterface ReadableStreamDefaultController<R = any> {\n    readonly desiredSize: number | null;\n    close(): void;\n    enqueue(chunk: R): void;\n    error(e?: any): void;\n}\n\ndeclare var ReadableStreamDefaultController: {\n    prototype: ReadableStreamDefaultController;\n    new(): ReadableStreamDefaultController;\n};\n\ninterface ReadableStreamDefaultReader<R = any> extends ReadableStreamGenericReader {\n    read(): Promise<ReadableStreamDefaultReadResult<R>>;\n    releaseLock(): void;\n}\n\ndeclare var ReadableStreamDefaultReader: {\n    prototype: ReadableStreamDefaultReader;\n    new<R = any>(stream: ReadableStream<R>): ReadableStreamDefaultReader<R>;\n};\n\ninterface ReadableStreamGenericReader {\n    readonly closed: Promise<undefined>;\n    cancel(reason?: any): Promise<void>;\n}\n\n/** This Fetch API interface represents a resource request. */\ninterface Request extends Body {\n    /**\n     * Returns the cache mode associated with request, which is a string indicating how the request will interact with the browser\'s cache when fetching.\n     */\n    readonly cache: RequestCache;\n    /**\n     * Returns the credentials mode associated with request, which is a string indicating whether credentials will be sent with the request always, never, or only when sent to a same-origin URL.\n     */\n    readonly credentials: RequestCredentials;\n    /**\n     * Returns the kind of resource requested by request, e.g., "document" or "script".\n     */\n    readonly destination: RequestDestination;\n    /**\n     * Returns a Headers object consisting of the headers associated with request. Note that headers added in the network layer by the user agent will not be accounted for in this object, e.g., the "Host" header.\n     */\n    readonly headers: Headers;\n    /**\n     * Returns request\'s subresource integrity metadata, which is a cryptographic hash of the resource being fetched. Its value consists of multiple hashes separated by whitespace. [SRI]\n     */\n    readonly integrity: string;\n    /**\n     * Returns a boolean indicating whether or not request is for a history navigation (a.k.a. back-foward navigation).\n     */\n    readonly isHistoryNavigation: boolean;\n    /**\n     * Returns a boolean indicating whether or not request is for a reload navigation.\n     */\n    readonly isReloadNavigation: boolean;\n    /**\n     * Returns a boolean indicating whether or not request can outlive the global in which it was created.\n     */\n    readonly keepalive: boolean;\n    /**\n     * Returns request\'s HTTP method, which is "GET" by default.\n     */\n    readonly method: string;\n    /**\n     * Returns the mode associated with request, which is a string indicating whether the request will use CORS, or will be restricted to same-origin URLs.\n     */\n    readonly mode: RequestMode;\n    /**\n     * Returns the redirect mode associated with request, which is a string indicating how redirects for the request will be handled during fetching. A request will follow redirects by default.\n     */\n    readonly redirect: RequestRedirect;\n    /**\n     * Returns the referrer of request. Its value can be a same-origin URL if explicitly set in init, the empty string to indicate no referrer, and "about:client" when defaulting to the global\'s default. This is used during fetching to determine the value of the `Referer` header of the request being made.\n     */\n    readonly referrer: string;\n    /**\n     * Returns the referrer policy associated with request. This is used during fetching to compute the value of the request\'s referrer.\n     */\n    readonly referrerPolicy: ReferrerPolicy;\n    /**\n     * Returns the signal associated with request, which is an AbortSignal object indicating whether or not request has been aborted, and its abort event handler.\n     */\n    readonly signal: AbortSignal;\n    /**\n     * Returns the URL of request as a string.\n     */\n    readonly url: string;\n    clone(): Request;\n}\n\ndeclare var Request: {\n    prototype: Request;\n    new(input: RequestInfo, init?: RequestInit): Request;\n};\n\ninterface ResizeObserver {\n    disconnect(): void;\n    observe(target: Element, options?: ResizeObserverOptions): void;\n    unobserve(target: Element): void;\n}\n\ndeclare var ResizeObserver: {\n    prototype: ResizeObserver;\n    new(callback: ResizeObserverCallback): ResizeObserver;\n};\n\ninterface ResizeObserverEntry {\n    readonly borderBoxSize: ReadonlyArray<ResizeObserverSize>;\n    readonly contentBoxSize: ReadonlyArray<ResizeObserverSize>;\n    readonly contentRect: DOMRectReadOnly;\n    readonly target: Element;\n}\n\ndeclare var ResizeObserverEntry: {\n    prototype: ResizeObserverEntry;\n    new(): ResizeObserverEntry;\n};\n\ninterface ResizeObserverSize {\n    readonly blockSize: number;\n    readonly inlineSize: number;\n}\n\ndeclare var ResizeObserverSize: {\n    prototype: ResizeObserverSize;\n    new(): ResizeObserverSize;\n};\n\n/** This Fetch API interface represents the response to a request. */\ninterface Response extends Body {\n    readonly headers: Headers;\n    readonly ok: boolean;\n    readonly redirected: boolean;\n    readonly status: number;\n    readonly statusText: string;\n    readonly trailer: Promise<Headers>;\n    readonly type: ResponseType;\n    readonly url: string;\n    clone(): Response;\n}\n\ndeclare var Response: {\n    prototype: Response;\n    new(body?: BodyInit | null, init?: ResponseInit): Response;\n    error(): Response;\n    redirect(url: string, status?: number): Response;\n};\n\n/** Provides access to the properties of <a> element, as well as methods to manipulate them. */\ninterface SVGAElement extends SVGGraphicsElement, SVGURIReference {\n    readonly target: SVGAnimatedString;\n    addEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGAElement, ev: SVGElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGAElement, ev: SVGElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SVGAElement: {\n    prototype: SVGAElement;\n    new(): SVGAElement;\n};\n\n/** Used to represent a value that can be an <angle> or <number> value. An SVGAngle reflected through the animVal attribute is always read only. */\ninterface SVGAngle {\n    readonly unitType: number;\n    value: number;\n    valueAsString: string;\n    valueInSpecifiedUnits: number;\n    convertToSpecifiedUnits(unitType: number): void;\n    newValueSpecifiedUnits(unitType: number, valueInSpecifiedUnits: number): void;\n    readonly SVG_ANGLETYPE_DEG: number;\n    readonly SVG_ANGLETYPE_GRAD: number;\n    readonly SVG_ANGLETYPE_RAD: number;\n    readonly SVG_ANGLETYPE_UNKNOWN: number;\n    readonly SVG_ANGLETYPE_UNSPECIFIED: number;\n}\n\ndeclare var SVGAngle: {\n    prototype: SVGAngle;\n    new(): SVGAngle;\n    readonly SVG_ANGLETYPE_DEG: number;\n    readonly SVG_ANGLETYPE_GRAD: number;\n    readonly SVG_ANGLETYPE_RAD: number;\n    readonly SVG_ANGLETYPE_UNKNOWN: number;\n    readonly SVG_ANGLETYPE_UNSPECIFIED: number;\n};\n\ninterface SVGAnimateElement extends SVGAnimationElement {\n    addEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGAnimateElement, ev: SVGElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGAnimateElement, ev: SVGElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SVGAnimateElement: {\n    prototype: SVGAnimateElement;\n    new(): SVGAnimateElement;\n};\n\ninterface SVGAnimateMotionElement extends SVGAnimationElement {\n    addEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGAnimateMotionElement, ev: SVGElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGAnimateMotionElement, ev: SVGElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SVGAnimateMotionElement: {\n    prototype: SVGAnimateMotionElement;\n    new(): SVGAnimateMotionElement;\n};\n\ninterface SVGAnimateTransformElement extends SVGAnimationElement {\n    addEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGAnimateTransformElement, ev: SVGElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGAnimateTransformElement, ev: SVGElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SVGAnimateTransformElement: {\n    prototype: SVGAnimateTransformElement;\n    new(): SVGAnimateTransformElement;\n};\n\n/** Used for attributes of basic type <angle> which can be animated. */\ninterface SVGAnimatedAngle {\n    readonly animVal: SVGAngle;\n    readonly baseVal: SVGAngle;\n}\n\ndeclare var SVGAnimatedAngle: {\n    prototype: SVGAnimatedAngle;\n    new(): SVGAnimatedAngle;\n};\n\n/** Used for attributes of type boolean which can be animated. */\ninterface SVGAnimatedBoolean {\n    readonly animVal: boolean;\n    baseVal: boolean;\n}\n\ndeclare var SVGAnimatedBoolean: {\n    prototype: SVGAnimatedBoolean;\n    new(): SVGAnimatedBoolean;\n};\n\n/** Used for attributes whose value must be a constant from a particular enumeration and which can be animated. */\ninterface SVGAnimatedEnumeration {\n    readonly animVal: number;\n    baseVal: number;\n}\n\ndeclare var SVGAnimatedEnumeration: {\n    prototype: SVGAnimatedEnumeration;\n    new(): SVGAnimatedEnumeration;\n};\n\n/** Used for attributes of basic type <integer> which can be animated. */\ninterface SVGAnimatedInteger {\n    readonly animVal: number;\n    baseVal: number;\n}\n\ndeclare var SVGAnimatedInteger: {\n    prototype: SVGAnimatedInteger;\n    new(): SVGAnimatedInteger;\n};\n\n/** Used for attributes of basic type <length> which can be animated. */\ninterface SVGAnimatedLength {\n    readonly animVal: SVGLength;\n    readonly baseVal: SVGLength;\n}\n\ndeclare var SVGAnimatedLength: {\n    prototype: SVGAnimatedLength;\n    new(): SVGAnimatedLength;\n};\n\n/** Used for attributes of type SVGLengthList which can be animated. */\ninterface SVGAnimatedLengthList {\n    readonly animVal: SVGLengthList;\n    readonly baseVal: SVGLengthList;\n}\n\ndeclare var SVGAnimatedLengthList: {\n    prototype: SVGAnimatedLengthList;\n    new(): SVGAnimatedLengthList;\n};\n\n/** Used for attributes of basic type <Number> which can be animated. */\ninterface SVGAnimatedNumber {\n    readonly animVal: number;\n    baseVal: number;\n}\n\ndeclare var SVGAnimatedNumber: {\n    prototype: SVGAnimatedNumber;\n    new(): SVGAnimatedNumber;\n};\n\n/** The SVGAnimatedNumber interface is used for attributes which take a list of numbers and which can be animated. */\ninterface SVGAnimatedNumberList {\n    readonly animVal: SVGNumberList;\n    readonly baseVal: SVGNumberList;\n}\n\ndeclare var SVGAnimatedNumberList: {\n    prototype: SVGAnimatedNumberList;\n    new(): SVGAnimatedNumberList;\n};\n\ninterface SVGAnimatedPoints {\n    readonly animatedPoints: SVGPointList;\n    readonly points: SVGPointList;\n}\n\n/** Used for attributes of type SVGPreserveAspectRatio which can be animated. */\ninterface SVGAnimatedPreserveAspectRatio {\n    readonly animVal: SVGPreserveAspectRatio;\n    readonly baseVal: SVGPreserveAspectRatio;\n}\n\ndeclare var SVGAnimatedPreserveAspectRatio: {\n    prototype: SVGAnimatedPreserveAspectRatio;\n    new(): SVGAnimatedPreserveAspectRatio;\n};\n\n/** Used for attributes of basic SVGRect which can be animated. */\ninterface SVGAnimatedRect {\n    readonly animVal: DOMRectReadOnly;\n    readonly baseVal: DOMRect;\n}\n\ndeclare var SVGAnimatedRect: {\n    prototype: SVGAnimatedRect;\n    new(): SVGAnimatedRect;\n};\n\n/** The SVGAnimatedString interface represents string attributes which can be animated from each SVG declaration. You need to create SVG attribute before doing anything else, everything should be declared inside this. */\ninterface SVGAnimatedString {\n    readonly animVal: string;\n    baseVal: string;\n}\n\ndeclare var SVGAnimatedString: {\n    prototype: SVGAnimatedString;\n    new(): SVGAnimatedString;\n};\n\n/** Used for attributes which take a list of numbers and which can be animated. */\ninterface SVGAnimatedTransformList {\n    readonly animVal: SVGTransformList;\n    readonly baseVal: SVGTransformList;\n}\n\ndeclare var SVGAnimatedTransformList: {\n    prototype: SVGAnimatedTransformList;\n    new(): SVGAnimatedTransformList;\n};\n\ninterface SVGAnimationElement extends SVGElement {\n    readonly targetElement: SVGElement;\n    getCurrentTime(): number;\n    getSimpleDuration(): number;\n    getStartTime(): number;\n    addEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGAnimationElement, ev: SVGElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGAnimationElement, ev: SVGElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SVGAnimationElement: {\n    prototype: SVGAnimationElement;\n    new(): SVGAnimationElement;\n};\n\n/** An interface for the <circle> element. The circle element is defined by the cx and cy attributes that denote the coordinates of the centre of the circle. */\ninterface SVGCircleElement extends SVGGeometryElement {\n    readonly cx: SVGAnimatedLength;\n    readonly cy: SVGAnimatedLength;\n    readonly r: SVGAnimatedLength;\n    addEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGCircleElement, ev: SVGElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGCircleElement, ev: SVGElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SVGCircleElement: {\n    prototype: SVGCircleElement;\n    new(): SVGCircleElement;\n};\n\n/** Provides access to the properties of <clipPath> elements, as well as methods to manipulate them. */\ninterface SVGClipPathElement extends SVGElement {\n    readonly clipPathUnits: SVGAnimatedEnumeration;\n    readonly transform: SVGAnimatedTransformList;\n    addEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGClipPathElement, ev: SVGElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGClipPathElement, ev: SVGElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SVGClipPathElement: {\n    prototype: SVGClipPathElement;\n    new(): SVGClipPathElement;\n};\n\n/** A base interface used by the component transfer function interfaces. */\ninterface SVGComponentTransferFunctionElement extends SVGElement {\n    readonly amplitude: SVGAnimatedNumber;\n    readonly exponent: SVGAnimatedNumber;\n    readonly intercept: SVGAnimatedNumber;\n    readonly offset: SVGAnimatedNumber;\n    readonly slope: SVGAnimatedNumber;\n    readonly tableValues: SVGAnimatedNumberList;\n    readonly type: SVGAnimatedEnumeration;\n    readonly SVG_FECOMPONENTTRANSFER_TYPE_DISCRETE: number;\n    readonly SVG_FECOMPONENTTRANSFER_TYPE_GAMMA: number;\n    readonly SVG_FECOMPONENTTRANSFER_TYPE_IDENTITY: number;\n    readonly SVG_FECOMPONENTTRANSFER_TYPE_LINEAR: number;\n    readonly SVG_FECOMPONENTTRANSFER_TYPE_TABLE: number;\n    readonly SVG_FECOMPONENTTRANSFER_TYPE_UNKNOWN: number;\n    addEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGComponentTransferFunctionElement, ev: SVGElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGComponentTransferFunctionElement, ev: SVGElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SVGComponentTransferFunctionElement: {\n    prototype: SVGComponentTransferFunctionElement;\n    new(): SVGComponentTransferFunctionElement;\n    readonly SVG_FECOMPONENTTRANSFER_TYPE_DISCRETE: number;\n    readonly SVG_FECOMPONENTTRANSFER_TYPE_GAMMA: number;\n    readonly SVG_FECOMPONENTTRANSFER_TYPE_IDENTITY: number;\n    readonly SVG_FECOMPONENTTRANSFER_TYPE_LINEAR: number;\n    readonly SVG_FECOMPONENTTRANSFER_TYPE_TABLE: number;\n    readonly SVG_FECOMPONENTTRANSFER_TYPE_UNKNOWN: number;\n};\n\ninterface SVGCursorElement extends SVGElement {\n    readonly x: SVGAnimatedLength;\n    readonly y: SVGAnimatedLength;\n    addEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGCursorElement, ev: SVGElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGCursorElement, ev: SVGElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SVGCursorElement: {\n    prototype: SVGCursorElement;\n    new(): SVGCursorElement;\n};\n\n/** Corresponds to the <defs> element. */\ninterface SVGDefsElement extends SVGGraphicsElement {\n    addEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGDefsElement, ev: SVGElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGDefsElement, ev: SVGElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SVGDefsElement: {\n    prototype: SVGDefsElement;\n    new(): SVGDefsElement;\n};\n\n/** Corresponds to the <desc> element. */\ninterface SVGDescElement extends SVGElement {\n    addEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGDescElement, ev: SVGElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGDescElement, ev: SVGElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SVGDescElement: {\n    prototype: SVGDescElement;\n    new(): SVGDescElement;\n};\n\ninterface SVGElementEventMap extends ElementEventMap, GlobalEventHandlersEventMap, DocumentAndElementEventHandlersEventMap {\n}\n\n/** All of the SVG DOM interfaces that correspond directly to elements in the SVG language derive from the SVGElement interface. */\ninterface SVGElement extends Element, DocumentAndElementEventHandlers, DocumentAndElementEventHandlers, ElementCSSInlineStyle, GlobalEventHandlers, GlobalEventHandlers, HTMLOrSVGElement, SVGElementInstance {\n    /** @deprecated */\n    readonly className: any;\n    readonly ownerSVGElement: SVGSVGElement | null;\n    readonly viewportElement: SVGElement | null;\n    addEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGElement, ev: SVGElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGElement, ev: SVGElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SVGElement: {\n    prototype: SVGElement;\n    new(): SVGElement;\n};\n\ninterface SVGElementInstance extends EventTarget {\n    readonly correspondingElement: SVGElement;\n    readonly correspondingUseElement: SVGUseElement;\n}\n\ndeclare var SVGElementInstance: {\n    prototype: SVGElementInstance;\n    new(): SVGElementInstance;\n};\n\ninterface SVGElementInstanceList {\n    /** @deprecated */\n    readonly length: number;\n    /** @deprecated */\n    item(index: number): SVGElementInstance;\n}\n\ndeclare var SVGElementInstanceList: {\n    prototype: SVGElementInstanceList;\n    new(): SVGElementInstanceList;\n};\n\n/** Provides access to the properties of <ellipse> elements. */\ninterface SVGEllipseElement extends SVGGeometryElement {\n    readonly cx: SVGAnimatedLength;\n    readonly cy: SVGAnimatedLength;\n    readonly rx: SVGAnimatedLength;\n    readonly ry: SVGAnimatedLength;\n    addEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGEllipseElement, ev: SVGElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGEllipseElement, ev: SVGElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SVGEllipseElement: {\n    prototype: SVGEllipseElement;\n    new(): SVGEllipseElement;\n};\n\n/** Corresponds to the <feBlend> element. */\ninterface SVGFEBlendElement extends SVGElement, SVGFilterPrimitiveStandardAttributes {\n    readonly in1: SVGAnimatedString;\n    readonly in2: SVGAnimatedString;\n    readonly mode: SVGAnimatedEnumeration;\n    readonly SVG_FEBLEND_MODE_COLOR: number;\n    readonly SVG_FEBLEND_MODE_COLOR_BURN: number;\n    readonly SVG_FEBLEND_MODE_COLOR_DODGE: number;\n    readonly SVG_FEBLEND_MODE_DARKEN: number;\n    readonly SVG_FEBLEND_MODE_DIFFERENCE: number;\n    readonly SVG_FEBLEND_MODE_EXCLUSION: number;\n    readonly SVG_FEBLEND_MODE_HARD_LIGHT: number;\n    readonly SVG_FEBLEND_MODE_HUE: number;\n    readonly SVG_FEBLEND_MODE_LIGHTEN: number;\n    readonly SVG_FEBLEND_MODE_LUMINOSITY: number;\n    readonly SVG_FEBLEND_MODE_MULTIPLY: number;\n    readonly SVG_FEBLEND_MODE_NORMAL: number;\n    readonly SVG_FEBLEND_MODE_OVERLAY: number;\n    readonly SVG_FEBLEND_MODE_SATURATION: number;\n    readonly SVG_FEBLEND_MODE_SCREEN: number;\n    readonly SVG_FEBLEND_MODE_SOFT_LIGHT: number;\n    readonly SVG_FEBLEND_MODE_UNKNOWN: number;\n    addEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGFEBlendElement, ev: SVGElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGFEBlendElement, ev: SVGElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SVGFEBlendElement: {\n    prototype: SVGFEBlendElement;\n    new(): SVGFEBlendElement;\n    readonly SVG_FEBLEND_MODE_COLOR: number;\n    readonly SVG_FEBLEND_MODE_COLOR_BURN: number;\n    readonly SVG_FEBLEND_MODE_COLOR_DODGE: number;\n    readonly SVG_FEBLEND_MODE_DARKEN: number;\n    readonly SVG_FEBLEND_MODE_DIFFERENCE: number;\n    readonly SVG_FEBLEND_MODE_EXCLUSION: number;\n    readonly SVG_FEBLEND_MODE_HARD_LIGHT: number;\n    readonly SVG_FEBLEND_MODE_HUE: number;\n    readonly SVG_FEBLEND_MODE_LIGHTEN: number;\n    readonly SVG_FEBLEND_MODE_LUMINOSITY: number;\n    readonly SVG_FEBLEND_MODE_MULTIPLY: number;\n    readonly SVG_FEBLEND_MODE_NORMAL: number;\n    readonly SVG_FEBLEND_MODE_OVERLAY: number;\n    readonly SVG_FEBLEND_MODE_SATURATION: number;\n    readonly SVG_FEBLEND_MODE_SCREEN: number;\n    readonly SVG_FEBLEND_MODE_SOFT_LIGHT: number;\n    readonly SVG_FEBLEND_MODE_UNKNOWN: number;\n};\n\n/** Corresponds to the <feColorMatrix> element. */\ninterface SVGFEColorMatrixElement extends SVGElement, SVGFilterPrimitiveStandardAttributes {\n    readonly in1: SVGAnimatedString;\n    readonly type: SVGAnimatedEnumeration;\n    readonly values: SVGAnimatedNumberList;\n    readonly SVG_FECOLORMATRIX_TYPE_HUEROTATE: number;\n    readonly SVG_FECOLORMATRIX_TYPE_LUMINANCETOALPHA: number;\n    readonly SVG_FECOLORMATRIX_TYPE_MATRIX: number;\n    readonly SVG_FECOLORMATRIX_TYPE_SATURATE: number;\n    readonly SVG_FECOLORMATRIX_TYPE_UNKNOWN: number;\n    addEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGFEColorMatrixElement, ev: SVGElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGFEColorMatrixElement, ev: SVGElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SVGFEColorMatrixElement: {\n    prototype: SVGFEColorMatrixElement;\n    new(): SVGFEColorMatrixElement;\n    readonly SVG_FECOLORMATRIX_TYPE_HUEROTATE: number;\n    readonly SVG_FECOLORMATRIX_TYPE_LUMINANCETOALPHA: number;\n    readonly SVG_FECOLORMATRIX_TYPE_MATRIX: number;\n    readonly SVG_FECOLORMATRIX_TYPE_SATURATE: number;\n    readonly SVG_FECOLORMATRIX_TYPE_UNKNOWN: number;\n};\n\n/** Corresponds to the <feComponentTransfer> element. */\ninterface SVGFEComponentTransferElement extends SVGElement, SVGFilterPrimitiveStandardAttributes {\n    readonly in1: SVGAnimatedString;\n    addEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGFEComponentTransferElement, ev: SVGElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGFEComponentTransferElement, ev: SVGElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SVGFEComponentTransferElement: {\n    prototype: SVGFEComponentTransferElement;\n    new(): SVGFEComponentTransferElement;\n};\n\n/** Corresponds to the <feComposite> element. */\ninterface SVGFECompositeElement extends SVGElement, SVGFilterPrimitiveStandardAttributes {\n    readonly in1: SVGAnimatedString;\n    readonly in2: SVGAnimatedString;\n    readonly k1: SVGAnimatedNumber;\n    readonly k2: SVGAnimatedNumber;\n    readonly k3: SVGAnimatedNumber;\n    readonly k4: SVGAnimatedNumber;\n    readonly operator: SVGAnimatedEnumeration;\n    readonly SVG_FECOMPOSITE_OPERATOR_ARITHMETIC: number;\n    readonly SVG_FECOMPOSITE_OPERATOR_ATOP: number;\n    readonly SVG_FECOMPOSITE_OPERATOR_IN: number;\n    readonly SVG_FECOMPOSITE_OPERATOR_OUT: number;\n    readonly SVG_FECOMPOSITE_OPERATOR_OVER: number;\n    readonly SVG_FECOMPOSITE_OPERATOR_UNKNOWN: number;\n    readonly SVG_FECOMPOSITE_OPERATOR_XOR: number;\n    addEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGFECompositeElement, ev: SVGElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGFECompositeElement, ev: SVGElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SVGFECompositeElement: {\n    prototype: SVGFECompositeElement;\n    new(): SVGFECompositeElement;\n    readonly SVG_FECOMPOSITE_OPERATOR_ARITHMETIC: number;\n    readonly SVG_FECOMPOSITE_OPERATOR_ATOP: number;\n    readonly SVG_FECOMPOSITE_OPERATOR_IN: number;\n    readonly SVG_FECOMPOSITE_OPERATOR_OUT: number;\n    readonly SVG_FECOMPOSITE_OPERATOR_OVER: number;\n    readonly SVG_FECOMPOSITE_OPERATOR_UNKNOWN: number;\n    readonly SVG_FECOMPOSITE_OPERATOR_XOR: number;\n};\n\n/** Corresponds to the <feConvolveMatrix> element. */\ninterface SVGFEConvolveMatrixElement extends SVGElement, SVGFilterPrimitiveStandardAttributes {\n    readonly bias: SVGAnimatedNumber;\n    readonly divisor: SVGAnimatedNumber;\n    readonly edgeMode: SVGAnimatedEnumeration;\n    readonly in1: SVGAnimatedString;\n    readonly kernelMatrix: SVGAnimatedNumberList;\n    readonly kernelUnitLengthX: SVGAnimatedNumber;\n    readonly kernelUnitLengthY: SVGAnimatedNumber;\n    readonly orderX: SVGAnimatedInteger;\n    readonly orderY: SVGAnimatedInteger;\n    readonly preserveAlpha: SVGAnimatedBoolean;\n    readonly targetX: SVGAnimatedInteger;\n    readonly targetY: SVGAnimatedInteger;\n    readonly SVG_EDGEMODE_DUPLICATE: number;\n    readonly SVG_EDGEMODE_NONE: number;\n    readonly SVG_EDGEMODE_UNKNOWN: number;\n    readonly SVG_EDGEMODE_WRAP: number;\n    addEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGFEConvolveMatrixElement, ev: SVGElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGFEConvolveMatrixElement, ev: SVGElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SVGFEConvolveMatrixElement: {\n    prototype: SVGFEConvolveMatrixElement;\n    new(): SVGFEConvolveMatrixElement;\n    readonly SVG_EDGEMODE_DUPLICATE: number;\n    readonly SVG_EDGEMODE_NONE: number;\n    readonly SVG_EDGEMODE_UNKNOWN: number;\n    readonly SVG_EDGEMODE_WRAP: number;\n};\n\n/** Corresponds to the <feDiffuseLighting> element. */\ninterface SVGFEDiffuseLightingElement extends SVGElement, SVGFilterPrimitiveStandardAttributes {\n    readonly diffuseConstant: SVGAnimatedNumber;\n    readonly in1: SVGAnimatedString;\n    readonly kernelUnitLengthX: SVGAnimatedNumber;\n    readonly kernelUnitLengthY: SVGAnimatedNumber;\n    readonly surfaceScale: SVGAnimatedNumber;\n    addEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGFEDiffuseLightingElement, ev: SVGElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGFEDiffuseLightingElement, ev: SVGElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SVGFEDiffuseLightingElement: {\n    prototype: SVGFEDiffuseLightingElement;\n    new(): SVGFEDiffuseLightingElement;\n};\n\n/** Corresponds to the <feDisplacementMap> element. */\ninterface SVGFEDisplacementMapElement extends SVGElement, SVGFilterPrimitiveStandardAttributes {\n    readonly in1: SVGAnimatedString;\n    readonly in2: SVGAnimatedString;\n    readonly scale: SVGAnimatedNumber;\n    readonly xChannelSelector: SVGAnimatedEnumeration;\n    readonly yChannelSelector: SVGAnimatedEnumeration;\n    readonly SVG_CHANNEL_A: number;\n    readonly SVG_CHANNEL_B: number;\n    readonly SVG_CHANNEL_G: number;\n    readonly SVG_CHANNEL_R: number;\n    readonly SVG_CHANNEL_UNKNOWN: number;\n    addEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGFEDisplacementMapElement, ev: SVGElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGFEDisplacementMapElement, ev: SVGElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SVGFEDisplacementMapElement: {\n    prototype: SVGFEDisplacementMapElement;\n    new(): SVGFEDisplacementMapElement;\n    readonly SVG_CHANNEL_A: number;\n    readonly SVG_CHANNEL_B: number;\n    readonly SVG_CHANNEL_G: number;\n    readonly SVG_CHANNEL_R: number;\n    readonly SVG_CHANNEL_UNKNOWN: number;\n};\n\n/** Corresponds to the <feDistantLight> element. */\ninterface SVGFEDistantLightElement extends SVGElement {\n    readonly azimuth: SVGAnimatedNumber;\n    readonly elevation: SVGAnimatedNumber;\n    addEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGFEDistantLightElement, ev: SVGElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGFEDistantLightElement, ev: SVGElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SVGFEDistantLightElement: {\n    prototype: SVGFEDistantLightElement;\n    new(): SVGFEDistantLightElement;\n};\n\ninterface SVGFEDropShadowElement extends SVGElement, SVGFilterPrimitiveStandardAttributes {\n    readonly dx: SVGAnimatedNumber;\n    readonly dy: SVGAnimatedNumber;\n    readonly in1: SVGAnimatedString;\n    readonly stdDeviationX: SVGAnimatedNumber;\n    readonly stdDeviationY: SVGAnimatedNumber;\n    setStdDeviation(stdDeviationX: number, stdDeviationY: number): void;\n    addEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGFEDropShadowElement, ev: SVGElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGFEDropShadowElement, ev: SVGElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SVGFEDropShadowElement: {\n    prototype: SVGFEDropShadowElement;\n    new(): SVGFEDropShadowElement;\n};\n\n/** Corresponds to the <feFlood> element. */\ninterface SVGFEFloodElement extends SVGElement, SVGFilterPrimitiveStandardAttributes {\n    addEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGFEFloodElement, ev: SVGElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGFEFloodElement, ev: SVGElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SVGFEFloodElement: {\n    prototype: SVGFEFloodElement;\n    new(): SVGFEFloodElement;\n};\n\n/** Corresponds to the <feFuncA> element. */\ninterface SVGFEFuncAElement extends SVGComponentTransferFunctionElement {\n    addEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGFEFuncAElement, ev: SVGElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGFEFuncAElement, ev: SVGElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SVGFEFuncAElement: {\n    prototype: SVGFEFuncAElement;\n    new(): SVGFEFuncAElement;\n};\n\n/** Corresponds to the <feFuncB> element. */\ninterface SVGFEFuncBElement extends SVGComponentTransferFunctionElement {\n    addEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGFEFuncBElement, ev: SVGElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGFEFuncBElement, ev: SVGElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SVGFEFuncBElement: {\n    prototype: SVGFEFuncBElement;\n    new(): SVGFEFuncBElement;\n};\n\n/** Corresponds to the <feFuncG> element. */\ninterface SVGFEFuncGElement extends SVGComponentTransferFunctionElement {\n    addEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGFEFuncGElement, ev: SVGElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGFEFuncGElement, ev: SVGElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SVGFEFuncGElement: {\n    prototype: SVGFEFuncGElement;\n    new(): SVGFEFuncGElement;\n};\n\n/** Corresponds to the <feFuncR> element. */\ninterface SVGFEFuncRElement extends SVGComponentTransferFunctionElement {\n    addEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGFEFuncRElement, ev: SVGElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGFEFuncRElement, ev: SVGElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SVGFEFuncRElement: {\n    prototype: SVGFEFuncRElement;\n    new(): SVGFEFuncRElement;\n};\n\n/** Corresponds to the <feGaussianBlur> element. */\ninterface SVGFEGaussianBlurElement extends SVGElement, SVGFilterPrimitiveStandardAttributes {\n    readonly in1: SVGAnimatedString;\n    readonly stdDeviationX: SVGAnimatedNumber;\n    readonly stdDeviationY: SVGAnimatedNumber;\n    setStdDeviation(stdDeviationX: number, stdDeviationY: number): void;\n    addEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGFEGaussianBlurElement, ev: SVGElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGFEGaussianBlurElement, ev: SVGElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SVGFEGaussianBlurElement: {\n    prototype: SVGFEGaussianBlurElement;\n    new(): SVGFEGaussianBlurElement;\n};\n\n/** Corresponds to the <feImage> element. */\ninterface SVGFEImageElement extends SVGElement, SVGFilterPrimitiveStandardAttributes, SVGURIReference {\n    readonly preserveAspectRatio: SVGAnimatedPreserveAspectRatio;\n    addEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGFEImageElement, ev: SVGElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGFEImageElement, ev: SVGElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SVGFEImageElement: {\n    prototype: SVGFEImageElement;\n    new(): SVGFEImageElement;\n};\n\n/** Corresponds to the <feMerge> element. */\ninterface SVGFEMergeElement extends SVGElement, SVGFilterPrimitiveStandardAttributes {\n    addEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGFEMergeElement, ev: SVGElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGFEMergeElement, ev: SVGElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SVGFEMergeElement: {\n    prototype: SVGFEMergeElement;\n    new(): SVGFEMergeElement;\n};\n\n/** Corresponds to the <feMergeNode> element. */\ninterface SVGFEMergeNodeElement extends SVGElement {\n    readonly in1: SVGAnimatedString;\n    addEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGFEMergeNodeElement, ev: SVGElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGFEMergeNodeElement, ev: SVGElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SVGFEMergeNodeElement: {\n    prototype: SVGFEMergeNodeElement;\n    new(): SVGFEMergeNodeElement;\n};\n\n/** Corresponds to the <feMorphology> element. */\ninterface SVGFEMorphologyElement extends SVGElement, SVGFilterPrimitiveStandardAttributes {\n    readonly in1: SVGAnimatedString;\n    readonly operator: SVGAnimatedEnumeration;\n    readonly radiusX: SVGAnimatedNumber;\n    readonly radiusY: SVGAnimatedNumber;\n    readonly SVG_MORPHOLOGY_OPERATOR_DILATE: number;\n    readonly SVG_MORPHOLOGY_OPERATOR_ERODE: number;\n    readonly SVG_MORPHOLOGY_OPERATOR_UNKNOWN: number;\n    addEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGFEMorphologyElement, ev: SVGElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGFEMorphologyElement, ev: SVGElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SVGFEMorphologyElement: {\n    prototype: SVGFEMorphologyElement;\n    new(): SVGFEMorphologyElement;\n    readonly SVG_MORPHOLOGY_OPERATOR_DILATE: number;\n    readonly SVG_MORPHOLOGY_OPERATOR_ERODE: number;\n    readonly SVG_MORPHOLOGY_OPERATOR_UNKNOWN: number;\n};\n\n/** Corresponds to the <feOffset> element. */\ninterface SVGFEOffsetElement extends SVGElement, SVGFilterPrimitiveStandardAttributes {\n    readonly dx: SVGAnimatedNumber;\n    readonly dy: SVGAnimatedNumber;\n    readonly in1: SVGAnimatedString;\n    addEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGFEOffsetElement, ev: SVGElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGFEOffsetElement, ev: SVGElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SVGFEOffsetElement: {\n    prototype: SVGFEOffsetElement;\n    new(): SVGFEOffsetElement;\n};\n\n/** Corresponds to the <fePointLight> element. */\ninterface SVGFEPointLightElement extends SVGElement {\n    readonly x: SVGAnimatedNumber;\n    readonly y: SVGAnimatedNumber;\n    readonly z: SVGAnimatedNumber;\n    addEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGFEPointLightElement, ev: SVGElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGFEPointLightElement, ev: SVGElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SVGFEPointLightElement: {\n    prototype: SVGFEPointLightElement;\n    new(): SVGFEPointLightElement;\n};\n\n/** Corresponds to the <feSpecularLighting> element. */\ninterface SVGFESpecularLightingElement extends SVGElement, SVGFilterPrimitiveStandardAttributes {\n    readonly in1: SVGAnimatedString;\n    readonly kernelUnitLengthX: SVGAnimatedNumber;\n    readonly kernelUnitLengthY: SVGAnimatedNumber;\n    readonly specularConstant: SVGAnimatedNumber;\n    readonly specularExponent: SVGAnimatedNumber;\n    readonly surfaceScale: SVGAnimatedNumber;\n    addEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGFESpecularLightingElement, ev: SVGElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGFESpecularLightingElement, ev: SVGElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SVGFESpecularLightingElement: {\n    prototype: SVGFESpecularLightingElement;\n    new(): SVGFESpecularLightingElement;\n};\n\n/** Corresponds to the <feSpotLight> element. */\ninterface SVGFESpotLightElement extends SVGElement {\n    readonly limitingConeAngle: SVGAnimatedNumber;\n    readonly pointsAtX: SVGAnimatedNumber;\n    readonly pointsAtY: SVGAnimatedNumber;\n    readonly pointsAtZ: SVGAnimatedNumber;\n    readonly specularExponent: SVGAnimatedNumber;\n    readonly x: SVGAnimatedNumber;\n    readonly y: SVGAnimatedNumber;\n    readonly z: SVGAnimatedNumber;\n    addEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGFESpotLightElement, ev: SVGElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGFESpotLightElement, ev: SVGElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SVGFESpotLightElement: {\n    prototype: SVGFESpotLightElement;\n    new(): SVGFESpotLightElement;\n};\n\n/** Corresponds to the <feTile> element. */\ninterface SVGFETileElement extends SVGElement, SVGFilterPrimitiveStandardAttributes {\n    readonly in1: SVGAnimatedString;\n    addEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGFETileElement, ev: SVGElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGFETileElement, ev: SVGElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SVGFETileElement: {\n    prototype: SVGFETileElement;\n    new(): SVGFETileElement;\n};\n\n/** Corresponds to the <feTurbulence> element. */\ninterface SVGFETurbulenceElement extends SVGElement, SVGFilterPrimitiveStandardAttributes {\n    readonly baseFrequencyX: SVGAnimatedNumber;\n    readonly baseFrequencyY: SVGAnimatedNumber;\n    readonly numOctaves: SVGAnimatedInteger;\n    readonly seed: SVGAnimatedNumber;\n    readonly stitchTiles: SVGAnimatedEnumeration;\n    readonly type: SVGAnimatedEnumeration;\n    readonly SVG_STITCHTYPE_NOSTITCH: number;\n    readonly SVG_STITCHTYPE_STITCH: number;\n    readonly SVG_STITCHTYPE_UNKNOWN: number;\n    readonly SVG_TURBULENCE_TYPE_FRACTALNOISE: number;\n    readonly SVG_TURBULENCE_TYPE_TURBULENCE: number;\n    readonly SVG_TURBULENCE_TYPE_UNKNOWN: number;\n    addEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGFETurbulenceElement, ev: SVGElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGFETurbulenceElement, ev: SVGElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SVGFETurbulenceElement: {\n    prototype: SVGFETurbulenceElement;\n    new(): SVGFETurbulenceElement;\n    readonly SVG_STITCHTYPE_NOSTITCH: number;\n    readonly SVG_STITCHTYPE_STITCH: number;\n    readonly SVG_STITCHTYPE_UNKNOWN: number;\n    readonly SVG_TURBULENCE_TYPE_FRACTALNOISE: number;\n    readonly SVG_TURBULENCE_TYPE_TURBULENCE: number;\n    readonly SVG_TURBULENCE_TYPE_UNKNOWN: number;\n};\n\n/** Provides access to the properties of <filter> elements, as well as methods to manipulate them. */\ninterface SVGFilterElement extends SVGElement, SVGURIReference {\n    readonly filterUnits: SVGAnimatedEnumeration;\n    readonly height: SVGAnimatedLength;\n    readonly primitiveUnits: SVGAnimatedEnumeration;\n    readonly width: SVGAnimatedLength;\n    readonly x: SVGAnimatedLength;\n    readonly y: SVGAnimatedLength;\n    addEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGFilterElement, ev: SVGElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGFilterElement, ev: SVGElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SVGFilterElement: {\n    prototype: SVGFilterElement;\n    new(): SVGFilterElement;\n};\n\ninterface SVGFilterPrimitiveStandardAttributes {\n    readonly height: SVGAnimatedLength;\n    readonly result: SVGAnimatedString;\n    readonly width: SVGAnimatedLength;\n    readonly x: SVGAnimatedLength;\n    readonly y: SVGAnimatedLength;\n}\n\ninterface SVGFitToViewBox {\n    readonly preserveAspectRatio: SVGAnimatedPreserveAspectRatio;\n    readonly viewBox: SVGAnimatedRect;\n}\n\n/** Provides access to the properties of <foreignObject> elements, as well as methods to manipulate them. */\ninterface SVGForeignObjectElement extends SVGGraphicsElement {\n    readonly height: SVGAnimatedLength;\n    readonly width: SVGAnimatedLength;\n    readonly x: SVGAnimatedLength;\n    readonly y: SVGAnimatedLength;\n    addEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGForeignObjectElement, ev: SVGElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGForeignObjectElement, ev: SVGElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SVGForeignObjectElement: {\n    prototype: SVGForeignObjectElement;\n    new(): SVGForeignObjectElement;\n};\n\n/** Corresponds to the <g> element. */\ninterface SVGGElement extends SVGGraphicsElement {\n    addEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGGElement, ev: SVGElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGGElement, ev: SVGElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SVGGElement: {\n    prototype: SVGGElement;\n    new(): SVGGElement;\n};\n\ninterface SVGGeometryElement extends SVGGraphicsElement {\n    readonly pathLength: SVGAnimatedNumber;\n    getPointAtLength(distance: number): DOMPoint;\n    getTotalLength(): number;\n    isPointInFill(point?: DOMPointInit): boolean;\n    isPointInStroke(point?: DOMPointInit): boolean;\n    addEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGGeometryElement, ev: SVGElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGGeometryElement, ev: SVGElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SVGGeometryElement: {\n    prototype: SVGGeometryElement;\n    new(): SVGGeometryElement;\n};\n\n/** The SVGGradient interface is a base interface used by SVGLinearGradientElement and SVGRadialGradientElement. */\ninterface SVGGradientElement extends SVGElement, SVGURIReference {\n    readonly gradientTransform: SVGAnimatedTransformList;\n    readonly gradientUnits: SVGAnimatedEnumeration;\n    readonly spreadMethod: SVGAnimatedEnumeration;\n    readonly SVG_SPREADMETHOD_PAD: number;\n    readonly SVG_SPREADMETHOD_REFLECT: number;\n    readonly SVG_SPREADMETHOD_REPEAT: number;\n    readonly SVG_SPREADMETHOD_UNKNOWN: number;\n    addEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGGradientElement, ev: SVGElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGGradientElement, ev: SVGElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SVGGradientElement: {\n    prototype: SVGGradientElement;\n    new(): SVGGradientElement;\n    readonly SVG_SPREADMETHOD_PAD: number;\n    readonly SVG_SPREADMETHOD_REFLECT: number;\n    readonly SVG_SPREADMETHOD_REPEAT: number;\n    readonly SVG_SPREADMETHOD_UNKNOWN: number;\n};\n\n/** SVG elements whose primary purpose is to directly render graphics into a group. */\ninterface SVGGraphicsElement extends SVGElement, SVGTests {\n    readonly transform: SVGAnimatedTransformList;\n    getBBox(options?: SVGBoundingBoxOptions): DOMRect;\n    getCTM(): DOMMatrix | null;\n    getScreenCTM(): DOMMatrix | null;\n    addEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGGraphicsElement, ev: SVGElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGGraphicsElement, ev: SVGElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SVGGraphicsElement: {\n    prototype: SVGGraphicsElement;\n    new(): SVGGraphicsElement;\n};\n\n/** Corresponds to the <image> element. */\ninterface SVGImageElement extends SVGGraphicsElement, SVGURIReference {\n    readonly height: SVGAnimatedLength;\n    readonly preserveAspectRatio: SVGAnimatedPreserveAspectRatio;\n    readonly width: SVGAnimatedLength;\n    readonly x: SVGAnimatedLength;\n    readonly y: SVGAnimatedLength;\n    addEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGImageElement, ev: SVGElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGImageElement, ev: SVGElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SVGImageElement: {\n    prototype: SVGImageElement;\n    new(): SVGImageElement;\n};\n\n/** Correspond to the <length> basic data type. */\ninterface SVGLength {\n    readonly unitType: number;\n    value: number;\n    valueAsString: string;\n    valueInSpecifiedUnits: number;\n    convertToSpecifiedUnits(unitType: number): void;\n    newValueSpecifiedUnits(unitType: number, valueInSpecifiedUnits: number): void;\n    readonly SVG_LENGTHTYPE_CM: number;\n    readonly SVG_LENGTHTYPE_EMS: number;\n    readonly SVG_LENGTHTYPE_EXS: number;\n    readonly SVG_LENGTHTYPE_IN: number;\n    readonly SVG_LENGTHTYPE_MM: number;\n    readonly SVG_LENGTHTYPE_NUMBER: number;\n    readonly SVG_LENGTHTYPE_PC: number;\n    readonly SVG_LENGTHTYPE_PERCENTAGE: number;\n    readonly SVG_LENGTHTYPE_PT: number;\n    readonly SVG_LENGTHTYPE_PX: number;\n    readonly SVG_LENGTHTYPE_UNKNOWN: number;\n}\n\ndeclare var SVGLength: {\n    prototype: SVGLength;\n    new(): SVGLength;\n    readonly SVG_LENGTHTYPE_CM: number;\n    readonly SVG_LENGTHTYPE_EMS: number;\n    readonly SVG_LENGTHTYPE_EXS: number;\n    readonly SVG_LENGTHTYPE_IN: number;\n    readonly SVG_LENGTHTYPE_MM: number;\n    readonly SVG_LENGTHTYPE_NUMBER: number;\n    readonly SVG_LENGTHTYPE_PC: number;\n    readonly SVG_LENGTHTYPE_PERCENTAGE: number;\n    readonly SVG_LENGTHTYPE_PT: number;\n    readonly SVG_LENGTHTYPE_PX: number;\n    readonly SVG_LENGTHTYPE_UNKNOWN: number;\n};\n\n/** The SVGLengthList defines a list of SVGLength objects. */\ninterface SVGLengthList {\n    readonly length: number;\n    readonly numberOfItems: number;\n    appendItem(newItem: SVGLength): SVGLength;\n    clear(): void;\n    getItem(index: number): SVGLength;\n    initialize(newItem: SVGLength): SVGLength;\n    insertItemBefore(newItem: SVGLength, index: number): SVGLength;\n    removeItem(index: number): SVGLength;\n    replaceItem(newItem: SVGLength, index: number): SVGLength;\n    [index: number]: SVGLength;\n}\n\ndeclare var SVGLengthList: {\n    prototype: SVGLengthList;\n    new(): SVGLengthList;\n};\n\n/** Provides access to the properties of <line> elements, as well as methods to manipulate them. */\ninterface SVGLineElement extends SVGGeometryElement {\n    readonly x1: SVGAnimatedLength;\n    readonly x2: SVGAnimatedLength;\n    readonly y1: SVGAnimatedLength;\n    readonly y2: SVGAnimatedLength;\n    addEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGLineElement, ev: SVGElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGLineElement, ev: SVGElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SVGLineElement: {\n    prototype: SVGLineElement;\n    new(): SVGLineElement;\n};\n\n/** Corresponds to the <linearGradient> element. */\ninterface SVGLinearGradientElement extends SVGGradientElement {\n    readonly x1: SVGAnimatedLength;\n    readonly x2: SVGAnimatedLength;\n    readonly y1: SVGAnimatedLength;\n    readonly y2: SVGAnimatedLength;\n    addEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGLinearGradientElement, ev: SVGElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGLinearGradientElement, ev: SVGElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SVGLinearGradientElement: {\n    prototype: SVGLinearGradientElement;\n    new(): SVGLinearGradientElement;\n};\n\ninterface SVGMarkerElement extends SVGElement, SVGFitToViewBox {\n    readonly markerHeight: SVGAnimatedLength;\n    readonly markerUnits: SVGAnimatedEnumeration;\n    readonly markerWidth: SVGAnimatedLength;\n    readonly orientAngle: SVGAnimatedAngle;\n    readonly orientType: SVGAnimatedEnumeration;\n    readonly refX: SVGAnimatedLength;\n    readonly refY: SVGAnimatedLength;\n    setOrientToAngle(angle: SVGAngle): void;\n    setOrientToAuto(): void;\n    readonly SVG_MARKERUNITS_STROKEWIDTH: number;\n    readonly SVG_MARKERUNITS_UNKNOWN: number;\n    readonly SVG_MARKERUNITS_USERSPACEONUSE: number;\n    readonly SVG_MARKER_ORIENT_ANGLE: number;\n    readonly SVG_MARKER_ORIENT_AUTO: number;\n    readonly SVG_MARKER_ORIENT_UNKNOWN: number;\n    addEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGMarkerElement, ev: SVGElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGMarkerElement, ev: SVGElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SVGMarkerElement: {\n    prototype: SVGMarkerElement;\n    new(): SVGMarkerElement;\n    readonly SVG_MARKERUNITS_STROKEWIDTH: number;\n    readonly SVG_MARKERUNITS_UNKNOWN: number;\n    readonly SVG_MARKERUNITS_USERSPACEONUSE: number;\n    readonly SVG_MARKER_ORIENT_ANGLE: number;\n    readonly SVG_MARKER_ORIENT_AUTO: number;\n    readonly SVG_MARKER_ORIENT_UNKNOWN: number;\n};\n\n/** Provides access to the properties of <mask> elements, as well as methods to manipulate them. */\ninterface SVGMaskElement extends SVGElement {\n    readonly height: SVGAnimatedLength;\n    readonly maskContentUnits: SVGAnimatedEnumeration;\n    readonly maskUnits: SVGAnimatedEnumeration;\n    readonly width: SVGAnimatedLength;\n    readonly x: SVGAnimatedLength;\n    readonly y: SVGAnimatedLength;\n    addEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGMaskElement, ev: SVGElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGMaskElement, ev: SVGElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SVGMaskElement: {\n    prototype: SVGMaskElement;\n    new(): SVGMaskElement;\n};\n\n/** Corresponds to the <metadata> element. */\ninterface SVGMetadataElement extends SVGElement {\n    addEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGMetadataElement, ev: SVGElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGMetadataElement, ev: SVGElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SVGMetadataElement: {\n    prototype: SVGMetadataElement;\n    new(): SVGMetadataElement;\n};\n\n/** Corresponds to the <number> basic data type. */\ninterface SVGNumber {\n    value: number;\n}\n\ndeclare var SVGNumber: {\n    prototype: SVGNumber;\n    new(): SVGNumber;\n};\n\n/** The SVGNumberList defines a list of SVGNumber objects. */\ninterface SVGNumberList {\n    readonly length: number;\n    readonly numberOfItems: number;\n    appendItem(newItem: SVGNumber): SVGNumber;\n    clear(): void;\n    getItem(index: number): SVGNumber;\n    initialize(newItem: SVGNumber): SVGNumber;\n    insertItemBefore(newItem: SVGNumber, index: number): SVGNumber;\n    removeItem(index: number): SVGNumber;\n    replaceItem(newItem: SVGNumber, index: number): SVGNumber;\n    [index: number]: SVGNumber;\n}\n\ndeclare var SVGNumberList: {\n    prototype: SVGNumberList;\n    new(): SVGNumberList;\n};\n\n/** Corresponds to the <path> element. */\ninterface SVGPathElement extends SVGGraphicsElement {\n    /** @deprecated */\n    readonly pathSegList: SVGPathSegList;\n    getPointAtLength(distance: number): SVGPoint;\n    getTotalLength(): number;\n    addEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGPathElement, ev: SVGElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGPathElement, ev: SVGElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SVGPathElement: {\n    prototype: SVGPathElement;\n    new(): SVGPathElement;\n};\n\ninterface SVGPathSeg {\n    readonly pathSegType: number;\n    readonly pathSegTypeAsLetter: string;\n    readonly PATHSEG_ARC_ABS: number;\n    readonly PATHSEG_ARC_REL: number;\n    readonly PATHSEG_CLOSEPATH: number;\n    readonly PATHSEG_CURVETO_CUBIC_ABS: number;\n    readonly PATHSEG_CURVETO_CUBIC_REL: number;\n    readonly PATHSEG_CURVETO_CUBIC_SMOOTH_ABS: number;\n    readonly PATHSEG_CURVETO_CUBIC_SMOOTH_REL: number;\n    readonly PATHSEG_CURVETO_QUADRATIC_ABS: number;\n    readonly PATHSEG_CURVETO_QUADRATIC_REL: number;\n    readonly PATHSEG_CURVETO_QUADRATIC_SMOOTH_ABS: number;\n    readonly PATHSEG_CURVETO_QUADRATIC_SMOOTH_REL: number;\n    readonly PATHSEG_LINETO_ABS: number;\n    readonly PATHSEG_LINETO_HORIZONTAL_ABS: number;\n    readonly PATHSEG_LINETO_HORIZONTAL_REL: number;\n    readonly PATHSEG_LINETO_REL: number;\n    readonly PATHSEG_LINETO_VERTICAL_ABS: number;\n    readonly PATHSEG_LINETO_VERTICAL_REL: number;\n    readonly PATHSEG_MOVETO_ABS: number;\n    readonly PATHSEG_MOVETO_REL: number;\n    readonly PATHSEG_UNKNOWN: number;\n}\n\ndeclare var SVGPathSeg: {\n    prototype: SVGPathSeg;\n    new(): SVGPathSeg;\n    readonly PATHSEG_ARC_ABS: number;\n    readonly PATHSEG_ARC_REL: number;\n    readonly PATHSEG_CLOSEPATH: number;\n    readonly PATHSEG_CURVETO_CUBIC_ABS: number;\n    readonly PATHSEG_CURVETO_CUBIC_REL: number;\n    readonly PATHSEG_CURVETO_CUBIC_SMOOTH_ABS: number;\n    readonly PATHSEG_CURVETO_CUBIC_SMOOTH_REL: number;\n    readonly PATHSEG_CURVETO_QUADRATIC_ABS: number;\n    readonly PATHSEG_CURVETO_QUADRATIC_REL: number;\n    readonly PATHSEG_CURVETO_QUADRATIC_SMOOTH_ABS: number;\n    readonly PATHSEG_CURVETO_QUADRATIC_SMOOTH_REL: number;\n    readonly PATHSEG_LINETO_ABS: number;\n    readonly PATHSEG_LINETO_HORIZONTAL_ABS: number;\n    readonly PATHSEG_LINETO_HORIZONTAL_REL: number;\n    readonly PATHSEG_LINETO_REL: number;\n    readonly PATHSEG_LINETO_VERTICAL_ABS: number;\n    readonly PATHSEG_LINETO_VERTICAL_REL: number;\n    readonly PATHSEG_MOVETO_ABS: number;\n    readonly PATHSEG_MOVETO_REL: number;\n    readonly PATHSEG_UNKNOWN: number;\n};\n\ninterface SVGPathSegArcAbs extends SVGPathSeg {\n    angle: number;\n    largeArcFlag: boolean;\n    r1: number;\n    r2: number;\n    sweepFlag: boolean;\n    x: number;\n    y: number;\n}\n\ndeclare var SVGPathSegArcAbs: {\n    prototype: SVGPathSegArcAbs;\n    new(): SVGPathSegArcAbs;\n};\n\ninterface SVGPathSegArcRel extends SVGPathSeg {\n    angle: number;\n    largeArcFlag: boolean;\n    r1: number;\n    r2: number;\n    sweepFlag: boolean;\n    x: number;\n    y: number;\n}\n\ndeclare var SVGPathSegArcRel: {\n    prototype: SVGPathSegArcRel;\n    new(): SVGPathSegArcRel;\n};\n\ninterface SVGPathSegClosePath extends SVGPathSeg {\n}\n\ndeclare var SVGPathSegClosePath: {\n    prototype: SVGPathSegClosePath;\n    new(): SVGPathSegClosePath;\n};\n\ninterface SVGPathSegCurvetoCubicAbs extends SVGPathSeg {\n    x: number;\n    x1: number;\n    x2: number;\n    y: number;\n    y1: number;\n    y2: number;\n}\n\ndeclare var SVGPathSegCurvetoCubicAbs: {\n    prototype: SVGPathSegCurvetoCubicAbs;\n    new(): SVGPathSegCurvetoCubicAbs;\n};\n\ninterface SVGPathSegCurvetoCubicRel extends SVGPathSeg {\n    x: number;\n    x1: number;\n    x2: number;\n    y: number;\n    y1: number;\n    y2: number;\n}\n\ndeclare var SVGPathSegCurvetoCubicRel: {\n    prototype: SVGPathSegCurvetoCubicRel;\n    new(): SVGPathSegCurvetoCubicRel;\n};\n\ninterface SVGPathSegCurvetoCubicSmoothAbs extends SVGPathSeg {\n    x: number;\n    x2: number;\n    y: number;\n    y2: number;\n}\n\ndeclare var SVGPathSegCurvetoCubicSmoothAbs: {\n    prototype: SVGPathSegCurvetoCubicSmoothAbs;\n    new(): SVGPathSegCurvetoCubicSmoothAbs;\n};\n\ninterface SVGPathSegCurvetoCubicSmoothRel extends SVGPathSeg {\n    x: number;\n    x2: number;\n    y: number;\n    y2: number;\n}\n\ndeclare var SVGPathSegCurvetoCubicSmoothRel: {\n    prototype: SVGPathSegCurvetoCubicSmoothRel;\n    new(): SVGPathSegCurvetoCubicSmoothRel;\n};\n\ninterface SVGPathSegCurvetoQuadraticAbs extends SVGPathSeg {\n    x: number;\n    x1: number;\n    y: number;\n    y1: number;\n}\n\ndeclare var SVGPathSegCurvetoQuadraticAbs: {\n    prototype: SVGPathSegCurvetoQuadraticAbs;\n    new(): SVGPathSegCurvetoQuadraticAbs;\n};\n\ninterface SVGPathSegCurvetoQuadraticRel extends SVGPathSeg {\n    x: number;\n    x1: number;\n    y: number;\n    y1: number;\n}\n\ndeclare var SVGPathSegCurvetoQuadraticRel: {\n    prototype: SVGPathSegCurvetoQuadraticRel;\n    new(): SVGPathSegCurvetoQuadraticRel;\n};\n\ninterface SVGPathSegCurvetoQuadraticSmoothAbs extends SVGPathSeg {\n    x: number;\n    y: number;\n}\n\ndeclare var SVGPathSegCurvetoQuadraticSmoothAbs: {\n    prototype: SVGPathSegCurvetoQuadraticSmoothAbs;\n    new(): SVGPathSegCurvetoQuadraticSmoothAbs;\n};\n\ninterface SVGPathSegCurvetoQuadraticSmoothRel extends SVGPathSeg {\n    x: number;\n    y: number;\n}\n\ndeclare var SVGPathSegCurvetoQuadraticSmoothRel: {\n    prototype: SVGPathSegCurvetoQuadraticSmoothRel;\n    new(): SVGPathSegCurvetoQuadraticSmoothRel;\n};\n\ninterface SVGPathSegLinetoAbs extends SVGPathSeg {\n    x: number;\n    y: number;\n}\n\ndeclare var SVGPathSegLinetoAbs: {\n    prototype: SVGPathSegLinetoAbs;\n    new(): SVGPathSegLinetoAbs;\n};\n\ninterface SVGPathSegLinetoHorizontalAbs extends SVGPathSeg {\n    x: number;\n}\n\ndeclare var SVGPathSegLinetoHorizontalAbs: {\n    prototype: SVGPathSegLinetoHorizontalAbs;\n    new(): SVGPathSegLinetoHorizontalAbs;\n};\n\ninterface SVGPathSegLinetoHorizontalRel extends SVGPathSeg {\n    x: number;\n}\n\ndeclare var SVGPathSegLinetoHorizontalRel: {\n    prototype: SVGPathSegLinetoHorizontalRel;\n    new(): SVGPathSegLinetoHorizontalRel;\n};\n\ninterface SVGPathSegLinetoRel extends SVGPathSeg {\n    x: number;\n    y: number;\n}\n\ndeclare var SVGPathSegLinetoRel: {\n    prototype: SVGPathSegLinetoRel;\n    new(): SVGPathSegLinetoRel;\n};\n\ninterface SVGPathSegLinetoVerticalAbs extends SVGPathSeg {\n    y: number;\n}\n\ndeclare var SVGPathSegLinetoVerticalAbs: {\n    prototype: SVGPathSegLinetoVerticalAbs;\n    new(): SVGPathSegLinetoVerticalAbs;\n};\n\ninterface SVGPathSegLinetoVerticalRel extends SVGPathSeg {\n    y: number;\n}\n\ndeclare var SVGPathSegLinetoVerticalRel: {\n    prototype: SVGPathSegLinetoVerticalRel;\n    new(): SVGPathSegLinetoVerticalRel;\n};\n\ninterface SVGPathSegList {\n    readonly numberOfItems: number;\n    appendItem(newItem: SVGPathSeg): SVGPathSeg;\n    clear(): void;\n    getItem(index: number): SVGPathSeg;\n    initialize(newItem: SVGPathSeg): SVGPathSeg;\n    insertItemBefore(newItem: SVGPathSeg, index: number): SVGPathSeg;\n    removeItem(index: number): SVGPathSeg;\n    replaceItem(newItem: SVGPathSeg, index: number): SVGPathSeg;\n}\n\ndeclare var SVGPathSegList: {\n    prototype: SVGPathSegList;\n    new(): SVGPathSegList;\n};\n\ninterface SVGPathSegMovetoAbs extends SVGPathSeg {\n    x: number;\n    y: number;\n}\n\ndeclare var SVGPathSegMovetoAbs: {\n    prototype: SVGPathSegMovetoAbs;\n    new(): SVGPathSegMovetoAbs;\n};\n\ninterface SVGPathSegMovetoRel extends SVGPathSeg {\n    x: number;\n    y: number;\n}\n\ndeclare var SVGPathSegMovetoRel: {\n    prototype: SVGPathSegMovetoRel;\n    new(): SVGPathSegMovetoRel;\n};\n\n/** Corresponds to the <pattern> element. */\ninterface SVGPatternElement extends SVGElement, SVGFitToViewBox, SVGURIReference {\n    readonly height: SVGAnimatedLength;\n    readonly patternContentUnits: SVGAnimatedEnumeration;\n    readonly patternTransform: SVGAnimatedTransformList;\n    readonly patternUnits: SVGAnimatedEnumeration;\n    readonly width: SVGAnimatedLength;\n    readonly x: SVGAnimatedLength;\n    readonly y: SVGAnimatedLength;\n    addEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGPatternElement, ev: SVGElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGPatternElement, ev: SVGElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SVGPatternElement: {\n    prototype: SVGPatternElement;\n    new(): SVGPatternElement;\n};\n\ninterface SVGPointList {\n    readonly length: number;\n    readonly numberOfItems: number;\n    appendItem(newItem: DOMPoint): DOMPoint;\n    clear(): void;\n    getItem(index: number): DOMPoint;\n    initialize(newItem: DOMPoint): DOMPoint;\n    insertItemBefore(newItem: DOMPoint, index: number): DOMPoint;\n    removeItem(index: number): DOMPoint;\n    replaceItem(newItem: DOMPoint, index: number): DOMPoint;\n    [index: number]: DOMPoint;\n}\n\ndeclare var SVGPointList: {\n    prototype: SVGPointList;\n    new(): SVGPointList;\n};\n\n/** Provides access to the properties of <polygon> elements, as well as methods to manipulate them. */\ninterface SVGPolygonElement extends SVGGeometryElement, SVGAnimatedPoints {\n    addEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGPolygonElement, ev: SVGElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGPolygonElement, ev: SVGElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SVGPolygonElement: {\n    prototype: SVGPolygonElement;\n    new(): SVGPolygonElement;\n};\n\n/** Provides access to the properties of <polyline> elements, as well as methods to manipulate them. */\ninterface SVGPolylineElement extends SVGGeometryElement, SVGAnimatedPoints {\n    addEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGPolylineElement, ev: SVGElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGPolylineElement, ev: SVGElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SVGPolylineElement: {\n    prototype: SVGPolylineElement;\n    new(): SVGPolylineElement;\n};\n\n/** Corresponds to the preserveAspectRatio attribute, which is available for some of SVG\'s elements. */\ninterface SVGPreserveAspectRatio {\n    align: number;\n    meetOrSlice: number;\n    readonly SVG_MEETORSLICE_MEET: number;\n    readonly SVG_MEETORSLICE_SLICE: number;\n    readonly SVG_MEETORSLICE_UNKNOWN: number;\n    readonly SVG_PRESERVEASPECTRATIO_NONE: number;\n    readonly SVG_PRESERVEASPECTRATIO_UNKNOWN: number;\n    readonly SVG_PRESERVEASPECTRATIO_XMAXYMAX: number;\n    readonly SVG_PRESERVEASPECTRATIO_XMAXYMID: number;\n    readonly SVG_PRESERVEASPECTRATIO_XMAXYMIN: number;\n    readonly SVG_PRESERVEASPECTRATIO_XMIDYMAX: number;\n    readonly SVG_PRESERVEASPECTRATIO_XMIDYMID: number;\n    readonly SVG_PRESERVEASPECTRATIO_XMIDYMIN: number;\n    readonly SVG_PRESERVEASPECTRATIO_XMINYMAX: number;\n    readonly SVG_PRESERVEASPECTRATIO_XMINYMID: number;\n    readonly SVG_PRESERVEASPECTRATIO_XMINYMIN: number;\n}\n\ndeclare var SVGPreserveAspectRatio: {\n    prototype: SVGPreserveAspectRatio;\n    new(): SVGPreserveAspectRatio;\n    readonly SVG_MEETORSLICE_MEET: number;\n    readonly SVG_MEETORSLICE_SLICE: number;\n    readonly SVG_MEETORSLICE_UNKNOWN: number;\n    readonly SVG_PRESERVEASPECTRATIO_NONE: number;\n    readonly SVG_PRESERVEASPECTRATIO_UNKNOWN: number;\n    readonly SVG_PRESERVEASPECTRATIO_XMAXYMAX: number;\n    readonly SVG_PRESERVEASPECTRATIO_XMAXYMID: number;\n    readonly SVG_PRESERVEASPECTRATIO_XMAXYMIN: number;\n    readonly SVG_PRESERVEASPECTRATIO_XMIDYMAX: number;\n    readonly SVG_PRESERVEASPECTRATIO_XMIDYMID: number;\n    readonly SVG_PRESERVEASPECTRATIO_XMIDYMIN: number;\n    readonly SVG_PRESERVEASPECTRATIO_XMINYMAX: number;\n    readonly SVG_PRESERVEASPECTRATIO_XMINYMID: number;\n    readonly SVG_PRESERVEASPECTRATIO_XMINYMIN: number;\n};\n\n/** Corresponds to the <RadialGradient> element. */\ninterface SVGRadialGradientElement extends SVGGradientElement {\n    readonly cx: SVGAnimatedLength;\n    readonly cy: SVGAnimatedLength;\n    readonly fr: SVGAnimatedLength;\n    readonly fx: SVGAnimatedLength;\n    readonly fy: SVGAnimatedLength;\n    readonly r: SVGAnimatedLength;\n    addEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGRadialGradientElement, ev: SVGElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGRadialGradientElement, ev: SVGElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SVGRadialGradientElement: {\n    prototype: SVGRadialGradientElement;\n    new(): SVGRadialGradientElement;\n};\n\n/** Provides access to the properties of <rect> elements, as well as methods to manipulate them. */\ninterface SVGRectElement extends SVGGeometryElement {\n    readonly height: SVGAnimatedLength;\n    readonly rx: SVGAnimatedLength;\n    readonly ry: SVGAnimatedLength;\n    readonly width: SVGAnimatedLength;\n    readonly x: SVGAnimatedLength;\n    readonly y: SVGAnimatedLength;\n    addEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGRectElement, ev: SVGElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGRectElement, ev: SVGElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SVGRectElement: {\n    prototype: SVGRectElement;\n    new(): SVGRectElement;\n};\n\ninterface SVGSVGElementEventMap extends SVGElementEventMap {\n    "SVGUnload": Event;\n    "SVGZoom": SVGZoomEvent;\n}\n\n/** Provides access to the properties of <svg> elements, as well as methods to manipulate them. This interface contains also various miscellaneous commonly-used utility methods, such as matrix operations and the ability to control the time of redraw on visual rendering devices. */\ninterface SVGSVGElement extends SVGGraphicsElement, DocumentEvent, SVGFitToViewBox, SVGZoomAndPan {\n    currentScale: number;\n    readonly currentTranslate: SVGPoint;\n    readonly height: SVGAnimatedLength;\n    onunload: ((this: SVGSVGElement, ev: Event) => any) | null;\n    onzoom: ((this: SVGSVGElement, ev: SVGZoomEvent) => any) | null;\n    readonly width: SVGAnimatedLength;\n    readonly x: SVGAnimatedLength;\n    readonly y: SVGAnimatedLength;\n    animationsPaused(): boolean;\n    checkEnclosure(element: SVGElement, rect: SVGRect): boolean;\n    checkIntersection(element: SVGElement, rect: SVGRect): boolean;\n    createSVGAngle(): SVGAngle;\n    createSVGLength(): SVGLength;\n    createSVGMatrix(): SVGMatrix;\n    createSVGNumber(): SVGNumber;\n    createSVGPoint(): SVGPoint;\n    createSVGRect(): SVGRect;\n    createSVGTransform(): SVGTransform;\n    createSVGTransformFromMatrix(matrix: SVGMatrix): SVGTransform;\n    deselectAll(): void;\n    /** @deprecated */\n    forceRedraw(): void;\n    getComputedStyle(elt: Element, pseudoElt?: string | null): CSSStyleDeclaration;\n    getCurrentTime(): number;\n    getElementById(elementId: string): Element;\n    getEnclosureList(rect: SVGRect, referenceElement: SVGElement | null): NodeListOf<SVGCircleElement | SVGEllipseElement | SVGImageElement | SVGLineElement | SVGPathElement | SVGPolygonElement | SVGPolylineElement | SVGRectElement | SVGTextElement | SVGUseElement>;\n    getIntersectionList(rect: SVGRect, referenceElement: SVGElement | null): NodeListOf<SVGCircleElement | SVGEllipseElement | SVGImageElement | SVGLineElement | SVGPathElement | SVGPolygonElement | SVGPolylineElement | SVGRectElement | SVGTextElement | SVGUseElement>;\n    pauseAnimations(): void;\n    setCurrentTime(seconds: number): void;\n    /** @deprecated */\n    suspendRedraw(maxWaitMilliseconds: number): number;\n    unpauseAnimations(): void;\n    /** @deprecated */\n    unsuspendRedraw(suspendHandleID: number): void;\n    /** @deprecated */\n    unsuspendRedrawAll(): void;\n    addEventListener<K extends keyof SVGSVGElementEventMap>(type: K, listener: (this: SVGSVGElement, ev: SVGSVGElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SVGSVGElementEventMap>(type: K, listener: (this: SVGSVGElement, ev: SVGSVGElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SVGSVGElement: {\n    prototype: SVGSVGElement;\n    new(): SVGSVGElement;\n    readonly SVG_ZOOMANDPAN_DISABLE: number;\n    readonly SVG_ZOOMANDPAN_MAGNIFY: number;\n    readonly SVG_ZOOMANDPAN_UNKNOWN: number;\n};\n\n/** Corresponds to the SVG <script> element. */\ninterface SVGScriptElement extends SVGElement, SVGURIReference {\n    type: string;\n    addEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGScriptElement, ev: SVGElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGScriptElement, ev: SVGElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SVGScriptElement: {\n    prototype: SVGScriptElement;\n    new(): SVGScriptElement;\n};\n\n/** Corresponds to the <stop> element. */\ninterface SVGStopElement extends SVGElement {\n    readonly offset: SVGAnimatedNumber;\n    addEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGStopElement, ev: SVGElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGStopElement, ev: SVGElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SVGStopElement: {\n    prototype: SVGStopElement;\n    new(): SVGStopElement;\n};\n\n/** The SVGStringList defines a list of DOMString objects. */\ninterface SVGStringList {\n    readonly length: number;\n    readonly numberOfItems: number;\n    appendItem(newItem: string): string;\n    clear(): void;\n    getItem(index: number): string;\n    initialize(newItem: string): string;\n    insertItemBefore(newItem: string, index: number): string;\n    removeItem(index: number): string;\n    replaceItem(newItem: string, index: number): string;\n    [index: number]: string;\n}\n\ndeclare var SVGStringList: {\n    prototype: SVGStringList;\n    new(): SVGStringList;\n};\n\n/** Corresponds to the SVG <style> element. */\ninterface SVGStyleElement extends SVGElement, LinkStyle {\n    disabled: boolean;\n    media: string;\n    title: string;\n    type: string;\n    addEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGStyleElement, ev: SVGElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGStyleElement, ev: SVGElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SVGStyleElement: {\n    prototype: SVGStyleElement;\n    new(): SVGStyleElement;\n};\n\n/** Corresponds to the <switch> element. */\ninterface SVGSwitchElement extends SVGGraphicsElement {\n    addEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGSwitchElement, ev: SVGElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGSwitchElement, ev: SVGElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SVGSwitchElement: {\n    prototype: SVGSwitchElement;\n    new(): SVGSwitchElement;\n};\n\n/** Corresponds to the <symbol> element. */\ninterface SVGSymbolElement extends SVGElement, SVGFitToViewBox {\n    addEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGSymbolElement, ev: SVGElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGSymbolElement, ev: SVGElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SVGSymbolElement: {\n    prototype: SVGSymbolElement;\n    new(): SVGSymbolElement;\n};\n\n/** A <tspan> element. */\ninterface SVGTSpanElement extends SVGTextPositioningElement {\n    addEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGTSpanElement, ev: SVGElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGTSpanElement, ev: SVGElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SVGTSpanElement: {\n    prototype: SVGTSpanElement;\n    new(): SVGTSpanElement;\n};\n\ninterface SVGTests {\n    readonly requiredExtensions: SVGStringList;\n    readonly systemLanguage: SVGStringList;\n}\n\n/** Implemented by elements that support rendering child text content. It is inherited by various text-related interfaces, such as SVGTextElement, SVGTSpanElement, SVGTRefElement, SVGAltGlyphElement and SVGTextPathElement. */\ninterface SVGTextContentElement extends SVGGraphicsElement {\n    readonly lengthAdjust: SVGAnimatedEnumeration;\n    readonly textLength: SVGAnimatedLength;\n    getCharNumAtPosition(point?: DOMPointInit): number;\n    getComputedTextLength(): number;\n    getEndPositionOfChar(charnum: number): DOMPoint;\n    getExtentOfChar(charnum: number): DOMRect;\n    getNumberOfChars(): number;\n    getRotationOfChar(charnum: number): number;\n    getStartPositionOfChar(charnum: number): DOMPoint;\n    getSubStringLength(charnum: number, nchars: number): number;\n    selectSubString(charnum: number, nchars: number): void;\n    readonly LENGTHADJUST_SPACING: number;\n    readonly LENGTHADJUST_SPACINGANDGLYPHS: number;\n    readonly LENGTHADJUST_UNKNOWN: number;\n    addEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGTextContentElement, ev: SVGElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGTextContentElement, ev: SVGElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SVGTextContentElement: {\n    prototype: SVGTextContentElement;\n    new(): SVGTextContentElement;\n    readonly LENGTHADJUST_SPACING: number;\n    readonly LENGTHADJUST_SPACINGANDGLYPHS: number;\n    readonly LENGTHADJUST_UNKNOWN: number;\n};\n\n/** Corresponds to the <text> elements. */\ninterface SVGTextElement extends SVGTextPositioningElement {\n    addEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGTextElement, ev: SVGElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGTextElement, ev: SVGElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SVGTextElement: {\n    prototype: SVGTextElement;\n    new(): SVGTextElement;\n};\n\n/** Corresponds to the <textPath> element. */\ninterface SVGTextPathElement extends SVGTextContentElement, SVGURIReference {\n    readonly method: SVGAnimatedEnumeration;\n    readonly spacing: SVGAnimatedEnumeration;\n    readonly startOffset: SVGAnimatedLength;\n    readonly TEXTPATH_METHODTYPE_ALIGN: number;\n    readonly TEXTPATH_METHODTYPE_STRETCH: number;\n    readonly TEXTPATH_METHODTYPE_UNKNOWN: number;\n    readonly TEXTPATH_SPACINGTYPE_AUTO: number;\n    readonly TEXTPATH_SPACINGTYPE_EXACT: number;\n    readonly TEXTPATH_SPACINGTYPE_UNKNOWN: number;\n    addEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGTextPathElement, ev: SVGElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGTextPathElement, ev: SVGElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SVGTextPathElement: {\n    prototype: SVGTextPathElement;\n    new(): SVGTextPathElement;\n    readonly TEXTPATH_METHODTYPE_ALIGN: number;\n    readonly TEXTPATH_METHODTYPE_STRETCH: number;\n    readonly TEXTPATH_METHODTYPE_UNKNOWN: number;\n    readonly TEXTPATH_SPACINGTYPE_AUTO: number;\n    readonly TEXTPATH_SPACINGTYPE_EXACT: number;\n    readonly TEXTPATH_SPACINGTYPE_UNKNOWN: number;\n};\n\n/** Implemented by elements that support attributes that position individual text glyphs. It is inherited by SVGTextElement, SVGTSpanElement, SVGTRefElement and SVGAltGlyphElement. */\ninterface SVGTextPositioningElement extends SVGTextContentElement {\n    readonly dx: SVGAnimatedLengthList;\n    readonly dy: SVGAnimatedLengthList;\n    readonly rotate: SVGAnimatedNumberList;\n    readonly x: SVGAnimatedLengthList;\n    readonly y: SVGAnimatedLengthList;\n    addEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGTextPositioningElement, ev: SVGElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGTextPositioningElement, ev: SVGElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SVGTextPositioningElement: {\n    prototype: SVGTextPositioningElement;\n    new(): SVGTextPositioningElement;\n};\n\n/** Corresponds to the <title> element. */\ninterface SVGTitleElement extends SVGElement {\n    addEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGTitleElement, ev: SVGElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGTitleElement, ev: SVGElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SVGTitleElement: {\n    prototype: SVGTitleElement;\n    new(): SVGTitleElement;\n};\n\n/** SVGTransform is the interface for one of the component transformations within an SVGTransformList; thus, an SVGTransform object corresponds to a single component (e.g., scale(…) or matrix(…)) within a transform attribute. */\ninterface SVGTransform {\n    readonly angle: number;\n    readonly matrix: SVGMatrix;\n    readonly type: number;\n    setMatrix(matrix: SVGMatrix): void;\n    setRotate(angle: number, cx: number, cy: number): void;\n    setScale(sx: number, sy: number): void;\n    setSkewX(angle: number): void;\n    setSkewY(angle: number): void;\n    setTranslate(tx: number, ty: number): void;\n    readonly SVG_TRANSFORM_MATRIX: number;\n    readonly SVG_TRANSFORM_ROTATE: number;\n    readonly SVG_TRANSFORM_SCALE: number;\n    readonly SVG_TRANSFORM_SKEWX: number;\n    readonly SVG_TRANSFORM_SKEWY: number;\n    readonly SVG_TRANSFORM_TRANSLATE: number;\n    readonly SVG_TRANSFORM_UNKNOWN: number;\n}\n\ndeclare var SVGTransform: {\n    prototype: SVGTransform;\n    new(): SVGTransform;\n    readonly SVG_TRANSFORM_MATRIX: number;\n    readonly SVG_TRANSFORM_ROTATE: number;\n    readonly SVG_TRANSFORM_SCALE: number;\n    readonly SVG_TRANSFORM_SKEWX: number;\n    readonly SVG_TRANSFORM_SKEWY: number;\n    readonly SVG_TRANSFORM_TRANSLATE: number;\n    readonly SVG_TRANSFORM_UNKNOWN: number;\n};\n\n/** The SVGTransformList defines a list of SVGTransform objects. */\ninterface SVGTransformList {\n    readonly numberOfItems: number;\n    appendItem(newItem: SVGTransform): SVGTransform;\n    clear(): void;\n    consolidate(): SVGTransform;\n    createSVGTransformFromMatrix(matrix: SVGMatrix): SVGTransform;\n    getItem(index: number): SVGTransform;\n    initialize(newItem: SVGTransform): SVGTransform;\n    insertItemBefore(newItem: SVGTransform, index: number): SVGTransform;\n    removeItem(index: number): SVGTransform;\n    replaceItem(newItem: SVGTransform, index: number): SVGTransform;\n}\n\ndeclare var SVGTransformList: {\n    prototype: SVGTransformList;\n    new(): SVGTransformList;\n};\n\ninterface SVGURIReference {\n    readonly href: SVGAnimatedString;\n}\n\n/** A commonly used set of constants used for reflecting gradientUnits, patternContentUnits and other similar attributes. */\ninterface SVGUnitTypes {\n    readonly SVG_UNIT_TYPE_OBJECTBOUNDINGBOX: number;\n    readonly SVG_UNIT_TYPE_UNKNOWN: number;\n    readonly SVG_UNIT_TYPE_USERSPACEONUSE: number;\n}\n\ndeclare var SVGUnitTypes: {\n    prototype: SVGUnitTypes;\n    new(): SVGUnitTypes;\n    readonly SVG_UNIT_TYPE_OBJECTBOUNDINGBOX: number;\n    readonly SVG_UNIT_TYPE_UNKNOWN: number;\n    readonly SVG_UNIT_TYPE_USERSPACEONUSE: number;\n};\n\n/** Corresponds to the <use> element. */\ninterface SVGUseElement extends SVGGraphicsElement, SVGURIReference {\n    readonly height: SVGAnimatedLength;\n    readonly width: SVGAnimatedLength;\n    readonly x: SVGAnimatedLength;\n    readonly y: SVGAnimatedLength;\n    addEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGUseElement, ev: SVGElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGUseElement, ev: SVGElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SVGUseElement: {\n    prototype: SVGUseElement;\n    new(): SVGUseElement;\n};\n\n/** Provides access to the properties of <view> elements, as well as methods to manipulate them. */\ninterface SVGViewElement extends SVGElement, SVGFitToViewBox, SVGZoomAndPan {\n    /** @deprecated */\n    readonly viewTarget: SVGStringList;\n    addEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGViewElement, ev: SVGElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SVGElementEventMap>(type: K, listener: (this: SVGViewElement, ev: SVGElementEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SVGViewElement: {\n    prototype: SVGViewElement;\n    new(): SVGViewElement;\n    readonly SVG_ZOOMANDPAN_DISABLE: number;\n    readonly SVG_ZOOMANDPAN_MAGNIFY: number;\n    readonly SVG_ZOOMANDPAN_UNKNOWN: number;\n};\n\ninterface SVGZoomAndPan {\n    zoomAndPan: number;\n    readonly SVG_ZOOMANDPAN_DISABLE: number;\n    readonly SVG_ZOOMANDPAN_MAGNIFY: number;\n    readonly SVG_ZOOMANDPAN_UNKNOWN: number;\n}\n\ninterface SVGZoomEvent extends UIEvent {\n    readonly newScale: number;\n    readonly newTranslate: SVGPoint;\n    readonly previousScale: number;\n    readonly previousTranslate: SVGPoint;\n    readonly zoomRectScreen: SVGRect;\n}\n\ndeclare var SVGZoomEvent: {\n    prototype: SVGZoomEvent;\n    new(): SVGZoomEvent;\n};\n\n/** A screen, usually the one on which the current window is being rendered, and is obtained using window.screen. */\ninterface Screen {\n    readonly availHeight: number;\n    readonly availWidth: number;\n    readonly colorDepth: number;\n    readonly height: number;\n    readonly orientation: ScreenOrientation;\n    readonly pixelDepth: number;\n    readonly width: number;\n}\n\ndeclare var Screen: {\n    prototype: Screen;\n    new(): Screen;\n};\n\ninterface ScreenOrientationEventMap {\n    "change": Event;\n}\n\ninterface ScreenOrientation extends EventTarget {\n    readonly angle: number;\n    onchange: ((this: ScreenOrientation, ev: Event) => any) | null;\n    readonly type: OrientationType;\n    lock(orientation: OrientationLockType): Promise<void>;\n    unlock(): void;\n    addEventListener<K extends keyof ScreenOrientationEventMap>(type: K, listener: (this: ScreenOrientation, ev: ScreenOrientationEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof ScreenOrientationEventMap>(type: K, listener: (this: ScreenOrientation, ev: ScreenOrientationEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var ScreenOrientation: {\n    prototype: ScreenOrientation;\n    new(): ScreenOrientation;\n};\n\ninterface ScriptProcessorNodeEventMap {\n    "audioprocess": AudioProcessingEvent;\n}\n\n/** Allows the generation, processing, or analyzing of audio using JavaScript.\n * @deprecated As of the August 29 2014 Web Audio API spec publication, this feature has been marked as deprecated, and was replaced by AudioWorklet (see AudioWorkletNode).\n */\ninterface ScriptProcessorNode extends AudioNode {\n    /** @deprecated */\n    readonly bufferSize: number;\n    /** @deprecated */\n    onaudioprocess: ((this: ScriptProcessorNode, ev: AudioProcessingEvent) => any) | null;\n    addEventListener<K extends keyof ScriptProcessorNodeEventMap>(type: K, listener: (this: ScriptProcessorNode, ev: ScriptProcessorNodeEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof ScriptProcessorNodeEventMap>(type: K, listener: (this: ScriptProcessorNode, ev: ScriptProcessorNodeEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var ScriptProcessorNode: {\n    prototype: ScriptProcessorNode;\n    new(): ScriptProcessorNode;\n};\n\n/** Inherits from Event, and represents the event object of an event sent on a document or worker when its content security policy is violated. */\ninterface SecurityPolicyViolationEvent extends Event {\n    readonly blockedURI: string;\n    readonly columnNumber: number;\n    readonly documentURI: string;\n    readonly effectiveDirective: string;\n    readonly lineNumber: number;\n    readonly originalPolicy: string;\n    readonly referrer: string;\n    readonly sourceFile: string;\n    readonly statusCode: number;\n    readonly violatedDirective: string;\n}\n\ndeclare var SecurityPolicyViolationEvent: {\n    prototype: SecurityPolicyViolationEvent;\n    new(type: string, eventInitDict?: SecurityPolicyViolationEventInit): SecurityPolicyViolationEvent;\n};\n\n/** A Selection object represents the range of text selected by the user or the current position of the caret. To obtain a Selection object for examination or modification, call Window.getSelection(). */\ninterface Selection {\n    readonly anchorNode: Node | null;\n    readonly anchorOffset: number;\n    readonly focusNode: Node | null;\n    readonly focusOffset: number;\n    readonly isCollapsed: boolean;\n    readonly rangeCount: number;\n    readonly type: string;\n    addRange(range: Range): void;\n    collapse(node: Node | null, offset?: number): void;\n    collapseToEnd(): void;\n    collapseToStart(): void;\n    containsNode(node: Node, allowPartialContainment?: boolean): boolean;\n    deleteFromDocument(): void;\n    empty(): void;\n    extend(node: Node, offset?: number): void;\n    getRangeAt(index: number): Range;\n    removeAllRanges(): void;\n    removeRange(range: Range): void;\n    selectAllChildren(node: Node): void;\n    setBaseAndExtent(anchorNode: Node, anchorOffset: number, focusNode: Node, focusOffset: number): void;\n    setPosition(node: Node | null, offset?: number): void;\n    toString(): string;\n}\n\ndeclare var Selection: {\n    prototype: Selection;\n    new(): Selection;\n    toString(): string;\n};\n\ninterface ServiceUIFrameContext {\n    getCachedFrameMessage(key: string): string;\n    postFrameMessage(key: string, data: string): void;\n}\ndeclare var ServiceUIFrameContext: ServiceUIFrameContext;\n\ninterface ServiceWorkerEventMap extends AbstractWorkerEventMap {\n    "statechange": Event;\n}\n\n/** This ServiceWorker API interface provides a reference to a service worker. Multiple browsing contexts (e.g. pages, workers, etc.) can be associated with the same service worker, each through a unique ServiceWorker object. */\ninterface ServiceWorker extends EventTarget, AbstractWorker {\n    onstatechange: ((this: ServiceWorker, ev: Event) => any) | null;\n    readonly scriptURL: string;\n    readonly state: ServiceWorkerState;\n    postMessage(message: any, transfer: Transferable[]): void;\n    postMessage(message: any, options?: PostMessageOptions): void;\n    addEventListener<K extends keyof ServiceWorkerEventMap>(type: K, listener: (this: ServiceWorker, ev: ServiceWorkerEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof ServiceWorkerEventMap>(type: K, listener: (this: ServiceWorker, ev: ServiceWorkerEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var ServiceWorker: {\n    prototype: ServiceWorker;\n    new(): ServiceWorker;\n};\n\ninterface ServiceWorkerContainerEventMap {\n    "controllerchange": Event;\n    "message": MessageEvent;\n    "messageerror": MessageEvent;\n}\n\n/** The ServiceWorkerContainer interface of the ServiceWorker API provides an object representing the service worker as an overall unit in the network ecosystem, including facilities to register, unregister and update service workers, and access the state of service workers and their registrations. */\ninterface ServiceWorkerContainer extends EventTarget {\n    readonly controller: ServiceWorker | null;\n    oncontrollerchange: ((this: ServiceWorkerContainer, ev: Event) => any) | null;\n    onmessage: ((this: ServiceWorkerContainer, ev: MessageEvent) => any) | null;\n    onmessageerror: ((this: ServiceWorkerContainer, ev: MessageEvent) => any) | null;\n    readonly ready: Promise<ServiceWorkerRegistration>;\n    getRegistration(clientURL?: string): Promise<ServiceWorkerRegistration | undefined>;\n    getRegistrations(): Promise<ReadonlyArray<ServiceWorkerRegistration>>;\n    register(scriptURL: string | URL, options?: RegistrationOptions): Promise<ServiceWorkerRegistration>;\n    startMessages(): void;\n    addEventListener<K extends keyof ServiceWorkerContainerEventMap>(type: K, listener: (this: ServiceWorkerContainer, ev: ServiceWorkerContainerEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof ServiceWorkerContainerEventMap>(type: K, listener: (this: ServiceWorkerContainer, ev: ServiceWorkerContainerEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var ServiceWorkerContainer: {\n    prototype: ServiceWorkerContainer;\n    new(): ServiceWorkerContainer;\n};\n\ninterface ServiceWorkerRegistrationEventMap {\n    "updatefound": Event;\n}\n\n/** This ServiceWorker API interface represents the service worker registration. You register a service worker to control one or more pages that share the same origin. */\ninterface ServiceWorkerRegistration extends EventTarget {\n    readonly active: ServiceWorker | null;\n    readonly installing: ServiceWorker | null;\n    readonly navigationPreload: NavigationPreloadManager;\n    onupdatefound: ((this: ServiceWorkerRegistration, ev: Event) => any) | null;\n    readonly pushManager: PushManager;\n    readonly scope: string;\n    readonly sync: SyncManager;\n    readonly updateViaCache: ServiceWorkerUpdateViaCache;\n    readonly waiting: ServiceWorker | null;\n    getNotifications(filter?: GetNotificationOptions): Promise<Notification[]>;\n    showNotification(title: string, options?: NotificationOptions): Promise<void>;\n    unregister(): Promise<boolean>;\n    update(): Promise<void>;\n    addEventListener<K extends keyof ServiceWorkerRegistrationEventMap>(type: K, listener: (this: ServiceWorkerRegistration, ev: ServiceWorkerRegistrationEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof ServiceWorkerRegistrationEventMap>(type: K, listener: (this: ServiceWorkerRegistration, ev: ServiceWorkerRegistrationEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var ServiceWorkerRegistration: {\n    prototype: ServiceWorkerRegistration;\n    new(): ServiceWorkerRegistration;\n};\n\ninterface ShadowRoot extends DocumentFragment, DocumentOrShadowRoot, InnerHTML {\n    readonly host: Element;\n    readonly mode: ShadowRootMode;\n    /**\n     * Throws a "NotSupportedError" DOMException if context object is a shadow root.\n     */\n}\n\ndeclare var ShadowRoot: {\n    prototype: ShadowRoot;\n    new(): ShadowRoot;\n};\n\ninterface SharedWorker extends EventTarget, AbstractWorker {\n    /**\n     * Returns sharedWorker\'s MessagePort object which can be used to communicate with the global environment.\n     */\n    readonly port: MessagePort;\n    addEventListener<K extends keyof AbstractWorkerEventMap>(type: K, listener: (this: SharedWorker, ev: AbstractWorkerEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof AbstractWorkerEventMap>(type: K, listener: (this: SharedWorker, ev: AbstractWorkerEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SharedWorker: {\n    prototype: SharedWorker;\n    new(scriptURL: string, options?: string | WorkerOptions): SharedWorker;\n};\n\ninterface Slottable {\n    readonly assignedSlot: HTMLSlotElement | null;\n}\n\ninterface SourceBufferEventMap {\n    "abort": Event;\n    "error": Event;\n    "update": Event;\n    "updateend": Event;\n    "updatestart": Event;\n}\n\n/** A chunk of media to be passed into an HTMLMediaElement and played, via a MediaSource object. This can be made up of one or several media segments. */\ninterface SourceBuffer extends EventTarget {\n    appendWindowEnd: number;\n    appendWindowStart: number;\n    readonly buffered: TimeRanges;\n    mode: AppendMode;\n    onabort: ((this: SourceBuffer, ev: Event) => any) | null;\n    onerror: ((this: SourceBuffer, ev: Event) => any) | null;\n    onupdate: ((this: SourceBuffer, ev: Event) => any) | null;\n    onupdateend: ((this: SourceBuffer, ev: Event) => any) | null;\n    onupdatestart: ((this: SourceBuffer, ev: Event) => any) | null;\n    timestampOffset: number;\n    readonly updating: boolean;\n    abort(): void;\n    appendBuffer(data: BufferSource): void;\n    remove(start: number, end: number): void;\n    addEventListener<K extends keyof SourceBufferEventMap>(type: K, listener: (this: SourceBuffer, ev: SourceBufferEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SourceBufferEventMap>(type: K, listener: (this: SourceBuffer, ev: SourceBufferEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SourceBuffer: {\n    prototype: SourceBuffer;\n    new(): SourceBuffer;\n};\n\ninterface SourceBufferListEventMap {\n    "addsourcebuffer": Event;\n    "removesourcebuffer": Event;\n}\n\n/** A simple container list for multiple SourceBuffer objects. */\ninterface SourceBufferList extends EventTarget {\n    readonly length: number;\n    onaddsourcebuffer: ((this: SourceBufferList, ev: Event) => any) | null;\n    onremovesourcebuffer: ((this: SourceBufferList, ev: Event) => any) | null;\n    addEventListener<K extends keyof SourceBufferListEventMap>(type: K, listener: (this: SourceBufferList, ev: SourceBufferListEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SourceBufferListEventMap>(type: K, listener: (this: SourceBufferList, ev: SourceBufferListEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n    [index: number]: SourceBuffer;\n}\n\ndeclare var SourceBufferList: {\n    prototype: SourceBufferList;\n    new(): SourceBufferList;\n};\n\ninterface SpeechGrammar {\n    src: string;\n    weight: number;\n}\n\ndeclare var SpeechGrammar: {\n    prototype: SpeechGrammar;\n    new(): SpeechGrammar;\n};\n\ninterface SpeechGrammarList {\n    readonly length: number;\n    addFromString(string: string, weight?: number): void;\n    addFromURI(src: string, weight?: number): void;\n    item(index: number): SpeechGrammar;\n    [index: number]: SpeechGrammar;\n}\n\ndeclare var SpeechGrammarList: {\n    prototype: SpeechGrammarList;\n    new(): SpeechGrammarList;\n};\n\ninterface SpeechRecognitionEventMap {\n    "audioend": Event;\n    "audiostart": Event;\n    "end": Event;\n    "error": SpeechRecognitionErrorEvent;\n    "nomatch": SpeechRecognitionEvent;\n    "result": SpeechRecognitionEvent;\n    "soundend": Event;\n    "soundstart": Event;\n    "speechend": Event;\n    "speechstart": Event;\n    "start": Event;\n}\n\ninterface SpeechRecognition extends EventTarget {\n    continuous: boolean;\n    grammars: SpeechGrammarList;\n    interimResults: boolean;\n    lang: string;\n    maxAlternatives: number;\n    onaudioend: ((this: SpeechRecognition, ev: Event) => any) | null;\n    onaudiostart: ((this: SpeechRecognition, ev: Event) => any) | null;\n    onend: ((this: SpeechRecognition, ev: Event) => any) | null;\n    onerror: ((this: SpeechRecognition, ev: SpeechRecognitionErrorEvent) => any) | null;\n    onnomatch: ((this: SpeechRecognition, ev: SpeechRecognitionEvent) => any) | null;\n    onresult: ((this: SpeechRecognition, ev: SpeechRecognitionEvent) => any) | null;\n    onsoundend: ((this: SpeechRecognition, ev: Event) => any) | null;\n    onsoundstart: ((this: SpeechRecognition, ev: Event) => any) | null;\n    onspeechend: ((this: SpeechRecognition, ev: Event) => any) | null;\n    onspeechstart: ((this: SpeechRecognition, ev: Event) => any) | null;\n    onstart: ((this: SpeechRecognition, ev: Event) => any) | null;\n    abort(): void;\n    start(): void;\n    stop(): void;\n    addEventListener<K extends keyof SpeechRecognitionEventMap>(type: K, listener: (this: SpeechRecognition, ev: SpeechRecognitionEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SpeechRecognitionEventMap>(type: K, listener: (this: SpeechRecognition, ev: SpeechRecognitionEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SpeechRecognition: {\n    prototype: SpeechRecognition;\n    new(): SpeechRecognition;\n};\n\ninterface SpeechRecognitionAlternative {\n    readonly confidence: number;\n    readonly transcript: string;\n}\n\ndeclare var SpeechRecognitionAlternative: {\n    prototype: SpeechRecognitionAlternative;\n    new(): SpeechRecognitionAlternative;\n};\n\ninterface SpeechRecognitionErrorEvent extends Event {\n    readonly error: SpeechRecognitionErrorCode;\n    readonly message: string;\n}\n\ndeclare var SpeechRecognitionErrorEvent: {\n    prototype: SpeechRecognitionErrorEvent;\n    new(type: string, eventInitDict: SpeechRecognitionErrorEventInit): SpeechRecognitionErrorEvent;\n};\n\ninterface SpeechRecognitionEvent extends Event {\n    readonly resultIndex: number;\n    readonly results: SpeechRecognitionResultList;\n}\n\ndeclare var SpeechRecognitionEvent: {\n    prototype: SpeechRecognitionEvent;\n    new(type: string, eventInitDict: SpeechRecognitionEventInit): SpeechRecognitionEvent;\n};\n\ninterface SpeechRecognitionResult {\n    readonly isFinal: boolean;\n    readonly length: number;\n    item(index: number): SpeechRecognitionAlternative;\n    [index: number]: SpeechRecognitionAlternative;\n}\n\ndeclare var SpeechRecognitionResult: {\n    prototype: SpeechRecognitionResult;\n    new(): SpeechRecognitionResult;\n};\n\ninterface SpeechRecognitionResultList {\n    readonly length: number;\n    item(index: number): SpeechRecognitionResult;\n    [index: number]: SpeechRecognitionResult;\n}\n\ndeclare var SpeechRecognitionResultList: {\n    prototype: SpeechRecognitionResultList;\n    new(): SpeechRecognitionResultList;\n};\n\ninterface SpeechSynthesisEventMap {\n    "voiceschanged": Event;\n}\n\n/** This Web Speech API interface is the controller interface for the speech service; this can be used to retrieve information about the synthesis voices available on the device, start and pause speech, and other commands besides. */\ninterface SpeechSynthesis extends EventTarget {\n    onvoiceschanged: ((this: SpeechSynthesis, ev: Event) => any) | null;\n    readonly paused: boolean;\n    readonly pending: boolean;\n    readonly speaking: boolean;\n    cancel(): void;\n    getVoices(): SpeechSynthesisVoice[];\n    pause(): void;\n    resume(): void;\n    speak(utterance: SpeechSynthesisUtterance): void;\n    addEventListener<K extends keyof SpeechSynthesisEventMap>(type: K, listener: (this: SpeechSynthesis, ev: SpeechSynthesisEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SpeechSynthesisEventMap>(type: K, listener: (this: SpeechSynthesis, ev: SpeechSynthesisEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SpeechSynthesis: {\n    prototype: SpeechSynthesis;\n    new(): SpeechSynthesis;\n};\n\ninterface SpeechSynthesisErrorEvent extends SpeechSynthesisEvent {\n    readonly error: SpeechSynthesisErrorCode;\n}\n\ndeclare var SpeechSynthesisErrorEvent: {\n    prototype: SpeechSynthesisErrorEvent;\n    new(type: string, eventInitDict: SpeechSynthesisErrorEventInit): SpeechSynthesisErrorEvent;\n};\n\n/** This Web Speech API interface contains information about the current state of SpeechSynthesisUtterance objects that have been processed in the speech service. */\ninterface SpeechSynthesisEvent extends Event {\n    readonly charIndex: number;\n    readonly charLength: number;\n    readonly elapsedTime: number;\n    readonly name: string;\n    readonly utterance: SpeechSynthesisUtterance;\n}\n\ndeclare var SpeechSynthesisEvent: {\n    prototype: SpeechSynthesisEvent;\n    new(type: string, eventInitDict: SpeechSynthesisEventInit): SpeechSynthesisEvent;\n};\n\ninterface SpeechSynthesisUtteranceEventMap {\n    "boundary": SpeechSynthesisEvent;\n    "end": SpeechSynthesisEvent;\n    "error": SpeechSynthesisErrorEvent;\n    "mark": SpeechSynthesisEvent;\n    "pause": SpeechSynthesisEvent;\n    "resume": SpeechSynthesisEvent;\n    "start": SpeechSynthesisEvent;\n}\n\n/** This Web Speech API interface represents a speech request. It contains the content the speech service should read and information about how to read it (e.g. language, pitch and volume.) */\ninterface SpeechSynthesisUtterance extends EventTarget {\n    lang: string;\n    onboundary: ((this: SpeechSynthesisUtterance, ev: SpeechSynthesisEvent) => any) | null;\n    onend: ((this: SpeechSynthesisUtterance, ev: SpeechSynthesisEvent) => any) | null;\n    onerror: ((this: SpeechSynthesisUtterance, ev: SpeechSynthesisErrorEvent) => any) | null;\n    onmark: ((this: SpeechSynthesisUtterance, ev: SpeechSynthesisEvent) => any) | null;\n    onpause: ((this: SpeechSynthesisUtterance, ev: SpeechSynthesisEvent) => any) | null;\n    onresume: ((this: SpeechSynthesisUtterance, ev: SpeechSynthesisEvent) => any) | null;\n    onstart: ((this: SpeechSynthesisUtterance, ev: SpeechSynthesisEvent) => any) | null;\n    pitch: number;\n    rate: number;\n    text: string;\n    voice: SpeechSynthesisVoice | null;\n    volume: number;\n    addEventListener<K extends keyof SpeechSynthesisUtteranceEventMap>(type: K, listener: (this: SpeechSynthesisUtterance, ev: SpeechSynthesisUtteranceEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SpeechSynthesisUtteranceEventMap>(type: K, listener: (this: SpeechSynthesisUtterance, ev: SpeechSynthesisUtteranceEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SpeechSynthesisUtterance: {\n    prototype: SpeechSynthesisUtterance;\n    new(text?: string): SpeechSynthesisUtterance;\n};\n\n/** This Web Speech API interface represents a voice that the system supports. Every SpeechSynthesisVoice has its own relative speech service including information about language, name and URI. */\ninterface SpeechSynthesisVoice {\n    readonly default: boolean;\n    readonly lang: string;\n    readonly localService: boolean;\n    readonly name: string;\n    readonly voiceURI: string;\n}\n\ndeclare var SpeechSynthesisVoice: {\n    prototype: SpeechSynthesisVoice;\n    new(): SpeechSynthesisVoice;\n};\n\ninterface StaticRange extends AbstractRange {\n}\n\ndeclare var StaticRange: {\n    prototype: StaticRange;\n    new(init: StaticRangeInit): StaticRange;\n};\n\n/** The pan property takes a unitless value between -1 (full left pan) and 1 (full right pan). This interface was introduced as a much simpler way to apply a simple panning effect than having to use a full PannerNode. */\ninterface StereoPannerNode extends AudioNode {\n    readonly pan: AudioParam;\n}\n\ndeclare var StereoPannerNode: {\n    prototype: StereoPannerNode;\n    new(context: BaseAudioContext, options?: StereoPannerOptions): StereoPannerNode;\n};\n\n/** This Web Storage API interface provides access to a particular domain\'s session or local storage. It allows, for example, the addition, modification, or deletion of stored data items. */\ninterface Storage {\n    /**\n     * Returns the number of key/value pairs currently present in the list associated with the object.\n     */\n    readonly length: number;\n    /**\n     * Empties the list associated with the object of all key/value pairs, if there are any.\n     */\n    clear(): void;\n    /**\n     * Returns the current value associated with the given key, or null if the given key does not exist in the list associated with the object.\n     */\n    getItem(key: string): string | null;\n    /**\n     * Returns the name of the nth key in the list, or null if n is greater than or equal to the number of key/value pairs in the object.\n     */\n    key(index: number): string | null;\n    /**\n     * Removes the key/value pair with the given key from the list associated with the object, if a key/value pair with the given key exists.\n     */\n    removeItem(key: string): void;\n    /**\n     * Sets the value of the pair identified by key to value, creating a new key/value pair if none existed for key previously.\n     *\n     * Throws a "QuotaExceededError" DOMException exception if the new value couldn\'t be set. (Setting could fail if, e.g., the user has disabled storage for the site, or if the quota has been exceeded.)\n     */\n    setItem(key: string, value: string): void;\n    [name: string]: any;\n}\n\ndeclare var Storage: {\n    prototype: Storage;\n    new(): Storage;\n};\n\n/** A StorageEvent is sent to a window when a storage area it has access to is changed within the context of another document. */\ninterface StorageEvent extends Event {\n    /**\n     * Returns the key of the storage item being changed.\n     */\n    readonly key: string | null;\n    /**\n     * Returns the new value of the key of the storage item whose value is being changed.\n     */\n    readonly newValue: string | null;\n    /**\n     * Returns the old value of the key of the storage item whose value is being changed.\n     */\n    readonly oldValue: string | null;\n    /**\n     * Returns the Storage object that was affected.\n     */\n    readonly storageArea: Storage | null;\n    /**\n     * Returns the URL of the document whose storage item changed.\n     */\n    readonly url: string;\n}\n\ndeclare var StorageEvent: {\n    prototype: StorageEvent;\n    new(type: string, eventInitDict?: StorageEventInit): StorageEvent;\n};\n\ninterface StorageManager {\n    estimate(): Promise<StorageEstimate>;\n    persist(): Promise<boolean>;\n    persisted(): Promise<boolean>;\n}\n\ndeclare var StorageManager: {\n    prototype: StorageManager;\n    new(): StorageManager;\n};\n\ninterface StyleMedia {\n    readonly type: string;\n    matchMedium(mediaquery: string): boolean;\n}\n\ndeclare var StyleMedia: {\n    prototype: StyleMedia;\n    new(): StyleMedia;\n};\n\n/** A single style sheet. CSS style sheets will further implement the more specialized CSSStyleSheet interface. */\ninterface StyleSheet {\n    disabled: boolean;\n    readonly href: string | null;\n    readonly media: MediaList;\n    readonly ownerNode: Element | ProcessingInstruction | null;\n    readonly parentStyleSheet: CSSStyleSheet | null;\n    readonly title: string | null;\n    readonly type: string;\n}\n\ndeclare var StyleSheet: {\n    prototype: StyleSheet;\n    new(): StyleSheet;\n};\n\n/** A list of StyleSheet. */\ninterface StyleSheetList {\n    readonly length: number;\n    item(index: number): CSSStyleSheet | null;\n    [index: number]: CSSStyleSheet;\n}\n\ndeclare var StyleSheetList: {\n    prototype: StyleSheetList;\n    new(): StyleSheetList;\n};\n\n/** This Web Crypto API interface provides a number of low-level cryptographic functions. It is accessed via the Crypto.subtle properties available in a window context (via Window.crypto). */\ninterface SubtleCrypto {\n    decrypt(algorithm: AlgorithmIdentifier | RsaOaepParams | AesCtrParams | AesCbcParams | AesCmacParams | AesGcmParams | AesCfbParams, key: CryptoKey, data: Int8Array | Int16Array | Int32Array | Uint8Array | Uint16Array | Uint32Array | Uint8ClampedArray | Float32Array | Float64Array | DataView | ArrayBuffer): Promise<ArrayBuffer>;\n    deriveBits(algorithm: AlgorithmIdentifier | EcdhKeyDeriveParams | DhKeyDeriveParams | ConcatParams | HkdfParams | Pbkdf2Params, baseKey: CryptoKey, length: number): Promise<ArrayBuffer>;\n    deriveKey(algorithm: AlgorithmIdentifier | EcdhKeyDeriveParams | DhKeyDeriveParams | ConcatParams | HkdfParams | Pbkdf2Params, baseKey: CryptoKey, derivedKeyType: string | AesDerivedKeyParams | HmacImportParams | ConcatParams | HkdfParams | Pbkdf2Params, extractable: boolean, keyUsages: KeyUsage[]): Promise<CryptoKey>;\n    digest(algorithm: AlgorithmIdentifier, data: Int8Array | Int16Array | Int32Array | Uint8Array | Uint16Array | Uint32Array | Uint8ClampedArray | Float32Array | Float64Array | DataView | ArrayBuffer): Promise<ArrayBuffer>;\n    encrypt(algorithm: AlgorithmIdentifier | RsaOaepParams | AesCtrParams | AesCbcParams | AesCmacParams | AesGcmParams | AesCfbParams, key: CryptoKey, data: Int8Array | Int16Array | Int32Array | Uint8Array | Uint16Array | Uint32Array | Uint8ClampedArray | Float32Array | Float64Array | DataView | ArrayBuffer): Promise<ArrayBuffer>;\n    exportKey(format: "jwk", key: CryptoKey): Promise<JsonWebKey>;\n    exportKey(format: "raw" | "pkcs8" | "spki", key: CryptoKey): Promise<ArrayBuffer>;\n    exportKey(format: string, key: CryptoKey): Promise<JsonWebKey | ArrayBuffer>;\n    generateKey(algorithm: RsaHashedKeyGenParams | EcKeyGenParams | DhKeyGenParams, extractable: boolean, keyUsages: KeyUsage[]): Promise<CryptoKeyPair>;\n    generateKey(algorithm: AesKeyGenParams | HmacKeyGenParams | Pbkdf2Params, extractable: boolean, keyUsages: KeyUsage[]): Promise<CryptoKey>;\n    generateKey(algorithm: AlgorithmIdentifier, extractable: boolean, keyUsages: KeyUsage[]): Promise<CryptoKeyPair | CryptoKey>;\n    importKey(format: "jwk", keyData: JsonWebKey, algorithm: AlgorithmIdentifier | RsaHashedImportParams | EcKeyImportParams | HmacImportParams | DhImportKeyParams | AesKeyAlgorithm, extractable: boolean, keyUsages: KeyUsage[]): Promise<CryptoKey>;\n    importKey(format: "raw" | "pkcs8" | "spki", keyData: Int8Array | Int16Array | Int32Array | Uint8Array | Uint16Array | Uint32Array | Uint8ClampedArray | Float32Array | Float64Array | DataView | ArrayBuffer, algorithm: AlgorithmIdentifier | RsaHashedImportParams | EcKeyImportParams | HmacImportParams | DhImportKeyParams | AesKeyAlgorithm, extractable: boolean, keyUsages: KeyUsage[]): Promise<CryptoKey>;\n    importKey(format: string, keyData: JsonWebKey | Int8Array | Int16Array | Int32Array | Uint8Array | Uint16Array | Uint32Array | Uint8ClampedArray | Float32Array | Float64Array | DataView | ArrayBuffer, algorithm: AlgorithmIdentifier | RsaHashedImportParams | EcKeyImportParams | HmacImportParams | DhImportKeyParams | AesKeyAlgorithm, extractable: boolean, keyUsages: KeyUsage[]): Promise<CryptoKey>;\n    sign(algorithm: AlgorithmIdentifier | RsaPssParams | EcdsaParams | AesCmacParams, key: CryptoKey, data: Int8Array | Int16Array | Int32Array | Uint8Array | Uint16Array | Uint32Array | Uint8ClampedArray | Float32Array | Float64Array | DataView | ArrayBuffer): Promise<ArrayBuffer>;\n    unwrapKey(format: "raw" | "pkcs8" | "spki" | "jwk" | string, wrappedKey: Int8Array | Int16Array | Int32Array | Uint8Array | Uint16Array | Uint32Array | Uint8ClampedArray | Float32Array | Float64Array | DataView | ArrayBuffer, unwrappingKey: CryptoKey, unwrapAlgorithm: AlgorithmIdentifier | RsaOaepParams | AesCtrParams | AesCbcParams | AesCmacParams | AesGcmParams | AesCfbParams, unwrappedKeyAlgorithm: AlgorithmIdentifier | RsaHashedImportParams | EcKeyImportParams | HmacImportParams | DhImportKeyParams | AesKeyAlgorithm, extractable: boolean, keyUsages: KeyUsage[]): Promise<CryptoKey>;\n    verify(algorithm: AlgorithmIdentifier | RsaPssParams | EcdsaParams | AesCmacParams, key: CryptoKey, signature: Int8Array | Int16Array | Int32Array | Uint8Array | Uint16Array | Uint32Array | Uint8ClampedArray | Float32Array | Float64Array | DataView | ArrayBuffer, data: Int8Array | Int16Array | Int32Array | Uint8Array | Uint16Array | Uint32Array | Uint8ClampedArray | Float32Array | Float64Array | DataView | ArrayBuffer): Promise<boolean>;\n    wrapKey(format: "raw" | "pkcs8" | "spki" | "jwk" | string, key: CryptoKey, wrappingKey: CryptoKey, wrapAlgorithm: AlgorithmIdentifier | RsaOaepParams | AesCtrParams | AesCbcParams | AesCmacParams | AesGcmParams | AesCfbParams): Promise<ArrayBuffer>;\n}\n\ndeclare var SubtleCrypto: {\n    prototype: SubtleCrypto;\n    new(): SubtleCrypto;\n};\n\n/** This ServiceWorker API interface provides an interface for registering and listing sync registrations. */\ninterface SyncManager {\n    getTags(): Promise<string[]>;\n    register(tag: string): Promise<void>;\n}\n\ndeclare var SyncManager: {\n    prototype: SyncManager;\n    new(): SyncManager;\n};\n\n/** The textual content of Element or Attr. If an element has no markup within its content, it has a single child implementing Text that contains the element\'s text. However, if the element contains markup, it is parsed into information items and Text nodes that form its children. */\ninterface Text extends CharacterData, Slottable {\n    readonly assignedSlot: HTMLSlotElement | null;\n    /**\n     * Returns the combined data of all direct Text node siblings.\n     */\n    readonly wholeText: string;\n    /**\n     * Splits data at the given offset and returns the remainder as Text node.\n     */\n    splitText(offset: number): Text;\n}\n\ndeclare var Text: {\n    prototype: Text;\n    new(data?: string): Text;\n};\n\n/** A decoder for a specific method, that is a specific character encoding, like utf-8, iso-8859-2, koi8, cp1261, gbk, etc. A decoder takes a stream of bytes as input and emits a stream of code points. For a more scalable, non-native library, see StringView – a C-like representation of strings based on typed arrays. */\ninterface TextDecoder extends TextDecoderCommon {\n    /**\n     * Returns the result of running encoding\'s decoder. The method can be invoked zero or more times with options\'s stream set to true, and then once without options\'s stream (or set to false), to process a fragmented input. If the invocation without options\'s stream (or set to false) has no input, it\'s clearest to omit both arguments.\n     *\n     * ```\n     * var string = "", decoder = new TextDecoder(encoding), buffer;\n     * while(buffer = next_chunk()) {\n     *   string += decoder.decode(buffer, {stream:true});\n     * }\n     * string += decoder.decode(); // end-of-queue\n     * ```\n     *\n     * If the error mode is "fatal" and encoding\'s decoder returns error, throws a TypeError.\n     */\n    decode(input?: BufferSource, options?: TextDecodeOptions): string;\n}\n\ndeclare var TextDecoder: {\n    prototype: TextDecoder;\n    new(label?: string, options?: TextDecoderOptions): TextDecoder;\n};\n\ninterface TextDecoderCommon {\n    /**\n     * Returns encoding\'s name, lowercased.\n     */\n    readonly encoding: string;\n    /**\n     * Returns true if error mode is "fatal", otherwise false.\n     */\n    readonly fatal: boolean;\n    /**\n     * Returns the value of ignore BOM.\n     */\n    readonly ignoreBOM: boolean;\n}\n\ninterface TextDecoderStream extends GenericTransformStream, TextDecoderCommon {\n    readonly readable: ReadableStream<string>;\n    readonly writable: WritableStream<BufferSource>;\n}\n\ndeclare var TextDecoderStream: {\n    prototype: TextDecoderStream;\n    new(label?: string, options?: TextDecoderOptions): TextDecoderStream;\n};\n\n/** TextEncoder takes a stream of code points as input and emits a stream of bytes. For a more scalable, non-native library, see StringView – a C-like representation of strings based on typed arrays. */\ninterface TextEncoder extends TextEncoderCommon {\n    /**\n     * Returns the result of running UTF-8\'s encoder.\n     */\n    encode(input?: string): Uint8Array;\n    /**\n     * Runs the UTF-8 encoder on source, stores the result of that operation into destination, and returns the progress made as an object wherein read is the number of converted code units of source and written is the number of bytes modified in destination.\n     */\n    encodeInto(source: string, destination: Uint8Array): TextEncoderEncodeIntoResult;\n}\n\ndeclare var TextEncoder: {\n    prototype: TextEncoder;\n    new(): TextEncoder;\n};\n\ninterface TextEncoderCommon {\n    /**\n     * Returns "utf-8".\n     */\n    readonly encoding: string;\n}\n\ninterface TextEncoderStream extends GenericTransformStream, TextEncoderCommon {\n    readonly readable: ReadableStream<Uint8Array>;\n    readonly writable: WritableStream<string>;\n}\n\ndeclare var TextEncoderStream: {\n    prototype: TextEncoderStream;\n    new(): TextEncoderStream;\n};\n\ninterface TextEvent extends UIEvent {\n    readonly data: string;\n    initTextEvent(typeArg: string, canBubbleArg: boolean, cancelableArg: boolean, viewArg: Window, dataArg: string, inputMethod: number, locale: string): void;\n    readonly DOM_INPUT_METHOD_DROP: number;\n    readonly DOM_INPUT_METHOD_HANDWRITING: number;\n    readonly DOM_INPUT_METHOD_IME: number;\n    readonly DOM_INPUT_METHOD_KEYBOARD: number;\n    readonly DOM_INPUT_METHOD_MULTIMODAL: number;\n    readonly DOM_INPUT_METHOD_OPTION: number;\n    readonly DOM_INPUT_METHOD_PASTE: number;\n    readonly DOM_INPUT_METHOD_SCRIPT: number;\n    readonly DOM_INPUT_METHOD_UNKNOWN: number;\n    readonly DOM_INPUT_METHOD_VOICE: number;\n}\n\ndeclare var TextEvent: {\n    prototype: TextEvent;\n    new(): TextEvent;\n    readonly DOM_INPUT_METHOD_DROP: number;\n    readonly DOM_INPUT_METHOD_HANDWRITING: number;\n    readonly DOM_INPUT_METHOD_IME: number;\n    readonly DOM_INPUT_METHOD_KEYBOARD: number;\n    readonly DOM_INPUT_METHOD_MULTIMODAL: number;\n    readonly DOM_INPUT_METHOD_OPTION: number;\n    readonly DOM_INPUT_METHOD_PASTE: number;\n    readonly DOM_INPUT_METHOD_SCRIPT: number;\n    readonly DOM_INPUT_METHOD_UNKNOWN: number;\n    readonly DOM_INPUT_METHOD_VOICE: number;\n};\n\n/** The dimensions of a piece of text in the canvas, as created by the CanvasRenderingContext2D.measureText() method. */\ninterface TextMetrics {\n    /**\n     * Returns the measurement described below.\n     */\n    readonly actualBoundingBoxAscent: number;\n    /**\n     * Returns the measurement described below.\n     */\n    readonly actualBoundingBoxDescent: number;\n    /**\n     * Returns the measurement described below.\n     */\n    readonly actualBoundingBoxLeft: number;\n    /**\n     * Returns the measurement described below.\n     */\n    readonly actualBoundingBoxRight: number;\n    /**\n     * Returns the measurement described below.\n     */\n    readonly width: number;\n}\n\ndeclare var TextMetrics: {\n    prototype: TextMetrics;\n    new(): TextMetrics;\n};\n\ninterface TextTrackEventMap {\n    "cuechange": Event;\n}\n\n/** This interface also inherits properties from EventTarget. */\ninterface TextTrack extends EventTarget {\n    /**\n     * Returns the text track cues from the text track list of cues that are currently active (i.e. that start before the current playback position and end after it), as a TextTrackCueList object.\n     */\n    readonly activeCues: TextTrackCueList | null;\n    /**\n     * Returns the text track list of cues, as a TextTrackCueList object.\n     */\n    readonly cues: TextTrackCueList | null;\n    /**\n     * Returns the ID of the given track.\n     *\n     * For in-band tracks, this is the ID that can be used with a fragment if the format supports media fragment syntax, and that can be used with the getTrackById() method.\n     *\n     * For TextTrack objects corresponding to track elements, this is the ID of the track element.\n     */\n    readonly id: string;\n    /**\n     * Returns the text track in-band metadata track dispatch type string.\n     */\n    readonly inBandMetadataTrackDispatchType: string;\n    /**\n     * Returns the text track kind string.\n     */\n    readonly kind: TextTrackKind;\n    /**\n     * Returns the text track label, if there is one, or the empty string otherwise (indicating that a custom label probably needs to be generated from the other attributes of the object if the object is exposed to the user).\n     */\n    readonly label: string;\n    /**\n     * Returns the text track language string.\n     */\n    readonly language: string;\n    /**\n     * Returns the text track mode, represented by a string from the following list:\n     *\n     * Can be set, to change the mode.\n     */\n    mode: TextTrackMode;\n    oncuechange: ((this: TextTrack, ev: Event) => any) | null;\n    /**\n     * Adds the given cue to textTrack\'s text track list of cues.\n     */\n    addCue(cue: TextTrackCue): void;\n    /**\n     * Removes the given cue from textTrack\'s text track list of cues.\n     */\n    removeCue(cue: TextTrackCue): void;\n    addEventListener<K extends keyof TextTrackEventMap>(type: K, listener: (this: TextTrack, ev: TextTrackEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof TextTrackEventMap>(type: K, listener: (this: TextTrack, ev: TextTrackEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var TextTrack: {\n    prototype: TextTrack;\n    new(): TextTrack;\n};\n\ninterface TextTrackCueEventMap {\n    "enter": Event;\n    "exit": Event;\n}\n\n/** TextTrackCues represent a string of text that will be displayed for some duration of time on a TextTrack. This includes the start and end times that the cue will be displayed. A TextTrackCue cannot be used directly, instead one of the derived types (e.g. VTTCue) must be used. */\ninterface TextTrackCue extends EventTarget {\n    /**\n     * Returns the text track cue end time, in seconds.\n     *\n     * Can be set.\n     */\n    endTime: number;\n    /**\n     * Returns the text track cue identifier.\n     *\n     * Can be set.\n     */\n    id: string;\n    onenter: ((this: TextTrackCue, ev: Event) => any) | null;\n    onexit: ((this: TextTrackCue, ev: Event) => any) | null;\n    /**\n     * Returns true if the text track cue pause-on-exit flag is set, false otherwise.\n     *\n     * Can be set.\n     */\n    pauseOnExit: boolean;\n    /**\n     * Returns the text track cue start time, in seconds.\n     *\n     * Can be set.\n     */\n    startTime: number;\n    /**\n     * Returns the TextTrack object to which this text track cue belongs, if any, or null otherwise.\n     */\n    readonly track: TextTrack | null;\n    addEventListener<K extends keyof TextTrackCueEventMap>(type: K, listener: (this: TextTrackCue, ev: TextTrackCueEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof TextTrackCueEventMap>(type: K, listener: (this: TextTrackCue, ev: TextTrackCueEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var TextTrackCue: {\n    prototype: TextTrackCue;\n    new(): TextTrackCue;\n};\n\ninterface TextTrackCueList {\n    /**\n     * Returns the number of cues in the list.\n     */\n    readonly length: number;\n    /**\n     * Returns the first text track cue (in text track cue order) with text track cue identifier id.\n     *\n     * Returns null if none of the cues have the given identifier or if the argument is the empty string.\n     */\n    getCueById(id: string): TextTrackCue | null;\n    [index: number]: TextTrackCue;\n}\n\ndeclare var TextTrackCueList: {\n    prototype: TextTrackCueList;\n    new(): TextTrackCueList;\n};\n\ninterface TextTrackListEventMap {\n    "addtrack": TrackEvent;\n    "change": Event;\n    "removetrack": TrackEvent;\n}\n\ninterface TextTrackList extends EventTarget {\n    readonly length: number;\n    onaddtrack: ((this: TextTrackList, ev: TrackEvent) => any) | null;\n    onchange: ((this: TextTrackList, ev: Event) => any) | null;\n    onremovetrack: ((this: TextTrackList, ev: TrackEvent) => any) | null;\n    getTrackById(id: string): TextTrack | null;\n    addEventListener<K extends keyof TextTrackListEventMap>(type: K, listener: (this: TextTrackList, ev: TextTrackListEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof TextTrackListEventMap>(type: K, listener: (this: TextTrackList, ev: TextTrackListEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n    [index: number]: TextTrack;\n}\n\ndeclare var TextTrackList: {\n    prototype: TextTrackList;\n    new(): TextTrackList;\n};\n\n/** Used to represent a set of time ranges, primarily for the purpose of tracking which portions of media have been buffered when loading it for use by the <audio> and <video> elements. */\ninterface TimeRanges {\n    /**\n     * Returns the number of ranges in the object.\n     */\n    readonly length: number;\n    /**\n     * Returns the time for the end of the range with the given index.\n     *\n     * Throws an "IndexSizeError" DOMException if the index is out of range.\n     */\n    end(index: number): number;\n    /**\n     * Returns the time for the start of the range with the given index.\n     *\n     * Throws an "IndexSizeError" DOMException if the index is out of range.\n     */\n    start(index: number): number;\n}\n\ndeclare var TimeRanges: {\n    prototype: TimeRanges;\n    new(): TimeRanges;\n};\n\n/** A single contact point on a touch-sensitive device. The contact point is commonly a finger or stylus and the device may be a touchscreen or trackpad. */\ninterface Touch {\n    readonly altitudeAngle: number;\n    readonly azimuthAngle: number;\n    readonly clientX: number;\n    readonly clientY: number;\n    readonly force: number;\n    readonly identifier: number;\n    readonly pageX: number;\n    readonly pageY: number;\n    readonly radiusX: number;\n    readonly radiusY: number;\n    readonly rotationAngle: number;\n    readonly screenX: number;\n    readonly screenY: number;\n    readonly target: EventTarget;\n    readonly touchType: TouchType;\n}\n\ndeclare var Touch: {\n    prototype: Touch;\n    new(touchInitDict: TouchInit): Touch;\n};\n\n/** An event sent when the state of contacts with a touch-sensitive surface changes. This surface can be a touch screen or trackpad, for example. The event can describe one or more points of contact with the screen and includes support for detecting movement, addition and removal of contact points, and so forth. */\ninterface TouchEvent extends UIEvent {\n    readonly altKey: boolean;\n    readonly changedTouches: TouchList;\n    readonly ctrlKey: boolean;\n    readonly metaKey: boolean;\n    readonly shiftKey: boolean;\n    readonly targetTouches: TouchList;\n    readonly touches: TouchList;\n}\n\ndeclare var TouchEvent: {\n    prototype: TouchEvent;\n    new(type: string, eventInitDict?: TouchEventInit): TouchEvent;\n};\n\n/** A list of contact points on a touch surface. For example, if the user has three fingers on the touch surface (such as a screen or trackpad), the corresponding TouchList object would have one Touch object for each finger, for a total of three entries. */\ninterface TouchList {\n    readonly length: number;\n    item(index: number): Touch | null;\n    [index: number]: Touch;\n}\n\ndeclare var TouchList: {\n    prototype: TouchList;\n    new(): TouchList;\n};\n\n/** The TrackEvent interface, part of the HTML DOM specification, is used for events which represent changes to the set of available tracks on an HTML media element; these events are addtrack and removetrack. */\ninterface TrackEvent extends Event {\n    /**\n     * Returns the track object (TextTrack, AudioTrack, or VideoTrack) to which the event relates.\n     */\n    readonly track: TextTrack | null;\n}\n\ndeclare var TrackEvent: {\n    prototype: TrackEvent;\n    new(type: string, eventInitDict?: TrackEventInit): TrackEvent;\n};\n\ninterface TransformStream<I = any, O = any> {\n    readonly readable: ReadableStream<O>;\n    readonly writable: WritableStream<I>;\n}\n\ndeclare var TransformStream: {\n    prototype: TransformStream;\n    new<I = any, O = any>(transformer?: Transformer<I, O>, writableStrategy?: QueuingStrategy<I>, readableStrategy?: QueuingStrategy<O>): TransformStream<I, O>;\n};\n\ninterface TransformStreamDefaultController<O = any> {\n    readonly desiredSize: number | null;\n    enqueue(chunk: O): void;\n    error(reason?: any): void;\n    terminate(): void;\n}\n\ndeclare var TransformStreamDefaultController: {\n    prototype: TransformStreamDefaultController;\n    new(): TransformStreamDefaultController;\n};\n\n/** Events providing information related to transitions. */\ninterface TransitionEvent extends Event {\n    readonly elapsedTime: number;\n    readonly propertyName: string;\n    readonly pseudoElement: string;\n}\n\ndeclare var TransitionEvent: {\n    prototype: TransitionEvent;\n    new(type: string, transitionEventInitDict?: TransitionEventInit): TransitionEvent;\n};\n\n/** The nodes of a document subtree and a position within them. */\ninterface TreeWalker {\n    currentNode: Node;\n    readonly filter: NodeFilter | null;\n    readonly root: Node;\n    readonly whatToShow: number;\n    firstChild(): Node | null;\n    lastChild(): Node | null;\n    nextNode(): Node | null;\n    nextSibling(): Node | null;\n    parentNode(): Node | null;\n    previousNode(): Node | null;\n    previousSibling(): Node | null;\n}\n\ndeclare var TreeWalker: {\n    prototype: TreeWalker;\n    new(): TreeWalker;\n};\n\n/** Simple user interface events. */\ninterface UIEvent extends Event {\n    readonly detail: number;\n    readonly view: Window | null;\n    /** @deprecated */\n    readonly which: number;\n}\n\ndeclare var UIEvent: {\n    prototype: UIEvent;\n    new(type: string, eventInitDict?: UIEventInit): UIEvent;\n};\n\n/** The URL interface represents an object providing static methods used for creating object URLs. */\ninterface URL {\n    hash: string;\n    host: string;\n    hostname: string;\n    href: string;\n    toString(): string;\n    readonly origin: string;\n    password: string;\n    pathname: string;\n    port: string;\n    protocol: string;\n    search: string;\n    readonly searchParams: URLSearchParams;\n    username: string;\n    toJSON(): string;\n}\n\ndeclare var URL: {\n    prototype: URL;\n    new(url: string, base?: string | URL): URL;\n    createObjectURL(object: any): string;\n    revokeObjectURL(url: string): void;\n};\n\ntype webkitURL = URL;\ndeclare var webkitURL: typeof URL;\n\ninterface URLSearchParams {\n    /**\n     * Appends a specified key/value pair as a new search parameter.\n     */\n    append(name: string, value: string): void;\n    /**\n     * Deletes the given search parameter, and its associated value, from the list of all search parameters.\n     */\n    delete(name: string): void;\n    /**\n     * Returns the first value associated to the given search parameter.\n     */\n    get(name: string): string | null;\n    /**\n     * Returns all the values association with a given search parameter.\n     */\n    getAll(name: string): string[];\n    /**\n     * Returns a Boolean indicating if such a search parameter exists.\n     */\n    has(name: string): boolean;\n    /**\n     * Sets the value associated to a given search parameter to the given value. If there were several values, delete the others.\n     */\n    set(name: string, value: string): void;\n    sort(): void;\n    /**\n     * Returns a string containing a query string suitable for use in a URL. Does not include the question mark.\n     */\n    toString(): string;\n    forEach(callbackfn: (value: string, key: string, parent: URLSearchParams) => void, thisArg?: any): void;\n}\n\ndeclare var URLSearchParams: {\n    prototype: URLSearchParams;\n    new(init?: string[][] | Record<string, string> | string | URLSearchParams): URLSearchParams;\n    toString(): string;\n};\n\n/** This WebVR API interface represents any VR device supported by this API. It includes generic information such as device IDs and descriptions, as well as methods for starting to present a VR scene, retrieving eye parameters and display capabilities, and other important functionality. */\ninterface VRDisplay extends EventTarget {\n    readonly capabilities: VRDisplayCapabilities;\n    depthFar: number;\n    depthNear: number;\n    readonly displayId: number;\n    readonly displayName: string;\n    readonly isConnected: boolean;\n    readonly isPresenting: boolean;\n    readonly stageParameters: VRStageParameters | null;\n    cancelAnimationFrame(handle: number): void;\n    exitPresent(): Promise<void>;\n    getEyeParameters(whichEye: string): VREyeParameters;\n    getFrameData(frameData: VRFrameData): boolean;\n    getLayers(): VRLayer[];\n    /** @deprecated */\n    getPose(): VRPose;\n    requestAnimationFrame(callback: FrameRequestCallback): number;\n    requestPresent(layers: VRLayer[]): Promise<void>;\n    resetPose(): void;\n    submitFrame(pose?: VRPose): void;\n}\n\ndeclare var VRDisplay: {\n    prototype: VRDisplay;\n    new(): VRDisplay;\n};\n\n/** This WebVR API interface describes the capabilities of a VRDisplay — its features can be used to perform VR device capability tests, for example can it return position information. */\ninterface VRDisplayCapabilities {\n    readonly canPresent: boolean;\n    readonly hasExternalDisplay: boolean;\n    readonly hasOrientation: boolean;\n    readonly hasPosition: boolean;\n    readonly maxLayers: number;\n}\n\ndeclare var VRDisplayCapabilities: {\n    prototype: VRDisplayCapabilities;\n    new(): VRDisplayCapabilities;\n};\n\n/** This WebVR API interface represents represents the event object of WebVR-related events (see the list of WebVR window extensions). */\ninterface VRDisplayEvent extends Event {\n    readonly display: VRDisplay;\n    readonly reason: VRDisplayEventReason | null;\n}\n\ndeclare var VRDisplayEvent: {\n    prototype: VRDisplayEvent;\n    new(type: string, eventInitDict: VRDisplayEventInit): VRDisplayEvent;\n};\n\n/** This WebVR API interface represents all the information required to correctly render a scene for a given eye, including field of view information. */\ninterface VREyeParameters {\n    /** @deprecated */\n    readonly fieldOfView: VRFieldOfView;\n    readonly offset: Float32Array;\n    readonly renderHeight: number;\n    readonly renderWidth: number;\n}\n\ndeclare var VREyeParameters: {\n    prototype: VREyeParameters;\n    new(): VREyeParameters;\n};\n\n/** This WebVR API interface represents a field of view defined by 4 different degree values describing the view from a center point. */\ninterface VRFieldOfView {\n    readonly downDegrees: number;\n    readonly leftDegrees: number;\n    readonly rightDegrees: number;\n    readonly upDegrees: number;\n}\n\ndeclare var VRFieldOfView: {\n    prototype: VRFieldOfView;\n    new(): VRFieldOfView;\n};\n\n/** This WebVR API interface represents all the information needed to render a single frame of a VR scene; constructed by VRDisplay.getFrameData(). */\ninterface VRFrameData {\n    readonly leftProjectionMatrix: Float32Array;\n    readonly leftViewMatrix: Float32Array;\n    readonly pose: VRPose;\n    readonly rightProjectionMatrix: Float32Array;\n    readonly rightViewMatrix: Float32Array;\n    readonly timestamp: number;\n}\n\ndeclare var VRFrameData: {\n    prototype: VRFrameData;\n    new(): VRFrameData;\n};\n\n/** This WebVR API interface represents the state of a VR sensor at a given timestamp (which includes orientation, position, velocity, and acceleration information.) */\ninterface VRPose {\n    readonly angularAcceleration: Float32Array | null;\n    readonly angularVelocity: Float32Array | null;\n    readonly linearAcceleration: Float32Array | null;\n    readonly linearVelocity: Float32Array | null;\n    readonly orientation: Float32Array | null;\n    readonly position: Float32Array | null;\n}\n\ndeclare var VRPose: {\n    prototype: VRPose;\n    new(): VRPose;\n};\n\ninterface VTTCue extends TextTrackCue {\n    align: AlignSetting;\n    line: LineAndPositionSetting;\n    lineAlign: LineAlignSetting;\n    position: LineAndPositionSetting;\n    positionAlign: PositionAlignSetting;\n    region: VTTRegion | null;\n    size: number;\n    snapToLines: boolean;\n    text: string;\n    vertical: DirectionSetting;\n    getCueAsHTML(): DocumentFragment;\n    addEventListener<K extends keyof TextTrackCueEventMap>(type: K, listener: (this: VTTCue, ev: TextTrackCueEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof TextTrackCueEventMap>(type: K, listener: (this: VTTCue, ev: TextTrackCueEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var VTTCue: {\n    prototype: VTTCue;\n    new(startTime: number, endTime: number, text: string): VTTCue;\n};\n\ninterface VTTRegion {\n    id: string;\n    lines: number;\n    regionAnchorX: number;\n    regionAnchorY: number;\n    scroll: ScrollSetting;\n    viewportAnchorX: number;\n    viewportAnchorY: number;\n    width: number;\n}\n\ndeclare var VTTRegion: {\n    prototype: VTTRegion;\n    new(): VTTRegion;\n};\n\n/** The validity states that an element can be in, with respect to constraint validation. Together, they help explain why an element\'s value fails to validate, if it\'s not valid. */\ninterface ValidityState {\n    readonly badInput: boolean;\n    readonly customError: boolean;\n    readonly patternMismatch: boolean;\n    readonly rangeOverflow: boolean;\n    readonly rangeUnderflow: boolean;\n    readonly stepMismatch: boolean;\n    readonly tooLong: boolean;\n    readonly tooShort: boolean;\n    readonly typeMismatch: boolean;\n    readonly valid: boolean;\n    readonly valueMissing: boolean;\n}\n\ndeclare var ValidityState: {\n    prototype: ValidityState;\n    new(): ValidityState;\n};\n\n/** Returned by the HTMLVideoElement.getVideoPlaybackQuality() method and contains metrics that can be used to determine the playback quality of a video. */\ninterface VideoPlaybackQuality {\n    readonly creationTime: number;\n    readonly droppedVideoFrames: number;\n    readonly totalVideoFrames: number;\n}\n\ndeclare var VideoPlaybackQuality: {\n    prototype: VideoPlaybackQuality;\n    new(): VideoPlaybackQuality;\n};\n\ninterface VisualViewportEventMap {\n    "resize": UIEvent;\n    "scroll": Event;\n}\n\ninterface VisualViewport extends EventTarget {\n    readonly height: number;\n    readonly offsetLeft: number;\n    readonly offsetTop: number;\n    onresize: ((this: VisualViewport, ev: UIEvent) => any) | null;\n    onscroll: ((this: VisualViewport, ev: Event) => any) | null;\n    readonly pageLeft: number;\n    readonly pageTop: number;\n    readonly scale: number;\n    readonly width: number;\n    addEventListener<K extends keyof VisualViewportEventMap>(type: K, listener: (this: VisualViewport, ev: VisualViewportEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof VisualViewportEventMap>(type: K, listener: (this: VisualViewport, ev: VisualViewportEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var VisualViewport: {\n    prototype: VisualViewport;\n    new(): VisualViewport;\n};\n\ninterface WEBGL_color_buffer_float {\n    readonly FRAMEBUFFER_ATTACHMENT_COMPONENT_TYPE_EXT: GLenum;\n    readonly RGBA32F_EXT: GLenum;\n    readonly UNSIGNED_NORMALIZED_EXT: GLenum;\n}\n\ninterface WEBGL_compressed_texture_astc {\n    getSupportedProfiles(): string[];\n    readonly COMPRESSED_RGBA_ASTC_10x10_KHR: GLenum;\n    readonly COMPRESSED_RGBA_ASTC_10x5_KHR: GLenum;\n    readonly COMPRESSED_RGBA_ASTC_10x6_KHR: GLenum;\n    readonly COMPRESSED_RGBA_ASTC_10x8_KHR: GLenum;\n    readonly COMPRESSED_RGBA_ASTC_12x10_KHR: GLenum;\n    readonly COMPRESSED_RGBA_ASTC_12x12_KHR: GLenum;\n    readonly COMPRESSED_RGBA_ASTC_4x4_KHR: GLenum;\n    readonly COMPRESSED_RGBA_ASTC_5x4_KHR: GLenum;\n    readonly COMPRESSED_RGBA_ASTC_5x5_KHR: GLenum;\n    readonly COMPRESSED_RGBA_ASTC_6x5_KHR: GLenum;\n    readonly COMPRESSED_RGBA_ASTC_6x6_KHR: GLenum;\n    readonly COMPRESSED_RGBA_ASTC_8x5_KHR: GLenum;\n    readonly COMPRESSED_RGBA_ASTC_8x6_KHR: GLenum;\n    readonly COMPRESSED_RGBA_ASTC_8x8_KHR: GLenum;\n    readonly COMPRESSED_SRGB8_ALPHA8_ASTC_10x10_KHR: GLenum;\n    readonly COMPRESSED_SRGB8_ALPHA8_ASTC_10x5_KHR: GLenum;\n    readonly COMPRESSED_SRGB8_ALPHA8_ASTC_10x6_KHR: GLenum;\n    readonly COMPRESSED_SRGB8_ALPHA8_ASTC_10x8_KHR: GLenum;\n    readonly COMPRESSED_SRGB8_ALPHA8_ASTC_12x10_KHR: GLenum;\n    readonly COMPRESSED_SRGB8_ALPHA8_ASTC_12x12_KHR: GLenum;\n    readonly COMPRESSED_SRGB8_ALPHA8_ASTC_4x4_KHR: GLenum;\n    readonly COMPRESSED_SRGB8_ALPHA8_ASTC_5x4_KHR: GLenum;\n    readonly COMPRESSED_SRGB8_ALPHA8_ASTC_5x5_KHR: GLenum;\n    readonly COMPRESSED_SRGB8_ALPHA8_ASTC_6x5_KHR: GLenum;\n    readonly COMPRESSED_SRGB8_ALPHA8_ASTC_6x6_KHR: GLenum;\n    readonly COMPRESSED_SRGB8_ALPHA8_ASTC_8x5_KHR: GLenum;\n    readonly COMPRESSED_SRGB8_ALPHA8_ASTC_8x6_KHR: GLenum;\n    readonly COMPRESSED_SRGB8_ALPHA8_ASTC_8x8_KHR: GLenum;\n}\n\n/** The WEBGL_compressed_texture_s3tc extension is part of the WebGL API and exposes four S3TC compressed texture formats. */\ninterface WEBGL_compressed_texture_s3tc {\n    readonly COMPRESSED_RGBA_S3TC_DXT1_EXT: GLenum;\n    readonly COMPRESSED_RGBA_S3TC_DXT3_EXT: GLenum;\n    readonly COMPRESSED_RGBA_S3TC_DXT5_EXT: GLenum;\n    readonly COMPRESSED_RGB_S3TC_DXT1_EXT: GLenum;\n}\n\ninterface WEBGL_compressed_texture_s3tc_srgb {\n    readonly COMPRESSED_SRGB_ALPHA_S3TC_DXT1_EXT: GLenum;\n    readonly COMPRESSED_SRGB_ALPHA_S3TC_DXT3_EXT: GLenum;\n    readonly COMPRESSED_SRGB_ALPHA_S3TC_DXT5_EXT: GLenum;\n    readonly COMPRESSED_SRGB_S3TC_DXT1_EXT: GLenum;\n}\n\n/** The WEBGL_debug_renderer_info extension is part of the WebGL API and exposes two constants with information about the graphics driver for debugging purposes. */\ninterface WEBGL_debug_renderer_info {\n    readonly UNMASKED_RENDERER_WEBGL: GLenum;\n    readonly UNMASKED_VENDOR_WEBGL: GLenum;\n}\n\ninterface WEBGL_debug_shaders {\n    getTranslatedShaderSource(shader: WebGLShader): string;\n}\n\n/** The WEBGL_depth_texture extension is part of the WebGL API and defines 2D depth and depth-stencil textures. */\ninterface WEBGL_depth_texture {\n    readonly UNSIGNED_INT_24_8_WEBGL: GLenum;\n}\n\ninterface WEBGL_draw_buffers {\n    drawBuffersWEBGL(buffers: GLenum[]): void;\n    readonly COLOR_ATTACHMENT0_WEBGL: GLenum;\n    readonly COLOR_ATTACHMENT10_WEBGL: GLenum;\n    readonly COLOR_ATTACHMENT11_WEBGL: GLenum;\n    readonly COLOR_ATTACHMENT12_WEBGL: GLenum;\n    readonly COLOR_ATTACHMENT13_WEBGL: GLenum;\n    readonly COLOR_ATTACHMENT14_WEBGL: GLenum;\n    readonly COLOR_ATTACHMENT15_WEBGL: GLenum;\n    readonly COLOR_ATTACHMENT1_WEBGL: GLenum;\n    readonly COLOR_ATTACHMENT2_WEBGL: GLenum;\n    readonly COLOR_ATTACHMENT3_WEBGL: GLenum;\n    readonly COLOR_ATTACHMENT4_WEBGL: GLenum;\n    readonly COLOR_ATTACHMENT5_WEBGL: GLenum;\n    readonly COLOR_ATTACHMENT6_WEBGL: GLenum;\n    readonly COLOR_ATTACHMENT7_WEBGL: GLenum;\n    readonly COLOR_ATTACHMENT8_WEBGL: GLenum;\n    readonly COLOR_ATTACHMENT9_WEBGL: GLenum;\n    readonly DRAW_BUFFER0_WEBGL: GLenum;\n    readonly DRAW_BUFFER10_WEBGL: GLenum;\n    readonly DRAW_BUFFER11_WEBGL: GLenum;\n    readonly DRAW_BUFFER12_WEBGL: GLenum;\n    readonly DRAW_BUFFER13_WEBGL: GLenum;\n    readonly DRAW_BUFFER14_WEBGL: GLenum;\n    readonly DRAW_BUFFER15_WEBGL: GLenum;\n    readonly DRAW_BUFFER1_WEBGL: GLenum;\n    readonly DRAW_BUFFER2_WEBGL: GLenum;\n    readonly DRAW_BUFFER3_WEBGL: GLenum;\n    readonly DRAW_BUFFER4_WEBGL: GLenum;\n    readonly DRAW_BUFFER5_WEBGL: GLenum;\n    readonly DRAW_BUFFER6_WEBGL: GLenum;\n    readonly DRAW_BUFFER7_WEBGL: GLenum;\n    readonly DRAW_BUFFER8_WEBGL: GLenum;\n    readonly DRAW_BUFFER9_WEBGL: GLenum;\n    readonly MAX_COLOR_ATTACHMENTS_WEBGL: GLenum;\n    readonly MAX_DRAW_BUFFERS_WEBGL: GLenum;\n}\n\ninterface WEBGL_lose_context {\n    loseContext(): void;\n    restoreContext(): void;\n}\n\n/** A WaveShaperNode always has exactly one input and one output. */\ninterface WaveShaperNode extends AudioNode {\n    curve: Float32Array | null;\n    oversample: OverSampleType;\n}\n\ndeclare var WaveShaperNode: {\n    prototype: WaveShaperNode;\n    new(context: BaseAudioContext, options?: WaveShaperOptions): WaveShaperNode;\n};\n\ninterface WebGL2RenderingContext extends WebGL2RenderingContextBase, WebGL2RenderingContextOverloads, WebGLRenderingContextBase {\n}\n\ndeclare var WebGL2RenderingContext: {\n    prototype: WebGL2RenderingContext;\n    new(): WebGL2RenderingContext;\n    readonly ACTIVE_ATTRIBUTES: GLenum;\n    readonly ACTIVE_TEXTURE: GLenum;\n    readonly ACTIVE_UNIFORMS: GLenum;\n    readonly ALIASED_LINE_WIDTH_RANGE: GLenum;\n    readonly ALIASED_POINT_SIZE_RANGE: GLenum;\n    readonly ALPHA: GLenum;\n    readonly ALPHA_BITS: GLenum;\n    readonly ALWAYS: GLenum;\n    readonly ARRAY_BUFFER: GLenum;\n    readonly ARRAY_BUFFER_BINDING: GLenum;\n    readonly ATTACHED_SHADERS: GLenum;\n    readonly BACK: GLenum;\n    readonly BLEND: GLenum;\n    readonly BLEND_COLOR: GLenum;\n    readonly BLEND_DST_ALPHA: GLenum;\n    readonly BLEND_DST_RGB: GLenum;\n    readonly BLEND_EQUATION: GLenum;\n    readonly BLEND_EQUATION_ALPHA: GLenum;\n    readonly BLEND_EQUATION_RGB: GLenum;\n    readonly BLEND_SRC_ALPHA: GLenum;\n    readonly BLEND_SRC_RGB: GLenum;\n    readonly BLUE_BITS: GLenum;\n    readonly BOOL: GLenum;\n    readonly BOOL_VEC2: GLenum;\n    readonly BOOL_VEC3: GLenum;\n    readonly BOOL_VEC4: GLenum;\n    readonly BROWSER_DEFAULT_WEBGL: GLenum;\n    readonly BUFFER_SIZE: GLenum;\n    readonly BUFFER_USAGE: GLenum;\n    readonly BYTE: GLenum;\n    readonly CCW: GLenum;\n    readonly CLAMP_TO_EDGE: GLenum;\n    readonly COLOR_ATTACHMENT0: GLenum;\n    readonly COLOR_BUFFER_BIT: GLenum;\n    readonly COLOR_CLEAR_VALUE: GLenum;\n    readonly COLOR_WRITEMASK: GLenum;\n    readonly COMPILE_STATUS: GLenum;\n    readonly COMPRESSED_TEXTURE_FORMATS: GLenum;\n    readonly CONSTANT_ALPHA: GLenum;\n    readonly CONSTANT_COLOR: GLenum;\n    readonly CONTEXT_LOST_WEBGL: GLenum;\n    readonly CULL_FACE: GLenum;\n    readonly CULL_FACE_MODE: GLenum;\n    readonly CURRENT_PROGRAM: GLenum;\n    readonly CURRENT_VERTEX_ATTRIB: GLenum;\n    readonly CW: GLenum;\n    readonly DECR: GLenum;\n    readonly DECR_WRAP: GLenum;\n    readonly DELETE_STATUS: GLenum;\n    readonly DEPTH_ATTACHMENT: GLenum;\n    readonly DEPTH_BITS: GLenum;\n    readonly DEPTH_BUFFER_BIT: GLenum;\n    readonly DEPTH_CLEAR_VALUE: GLenum;\n    readonly DEPTH_COMPONENT: GLenum;\n    readonly DEPTH_COMPONENT16: GLenum;\n    readonly DEPTH_FUNC: GLenum;\n    readonly DEPTH_RANGE: GLenum;\n    readonly DEPTH_STENCIL: GLenum;\n    readonly DEPTH_STENCIL_ATTACHMENT: GLenum;\n    readonly DEPTH_TEST: GLenum;\n    readonly DEPTH_WRITEMASK: GLenum;\n    readonly DITHER: GLenum;\n    readonly DONT_CARE: GLenum;\n    readonly DST_ALPHA: GLenum;\n    readonly DST_COLOR: GLenum;\n    readonly DYNAMIC_DRAW: GLenum;\n    readonly ELEMENT_ARRAY_BUFFER: GLenum;\n    readonly ELEMENT_ARRAY_BUFFER_BINDING: GLenum;\n    readonly EQUAL: GLenum;\n    readonly FASTEST: GLenum;\n    readonly FLOAT: GLenum;\n    readonly FLOAT_MAT2: GLenum;\n    readonly FLOAT_MAT3: GLenum;\n    readonly FLOAT_MAT4: GLenum;\n    readonly FLOAT_VEC2: GLenum;\n    readonly FLOAT_VEC3: GLenum;\n    readonly FLOAT_VEC4: GLenum;\n    readonly FRAGMENT_SHADER: GLenum;\n    readonly FRAMEBUFFER: GLenum;\n    readonly FRAMEBUFFER_ATTACHMENT_OBJECT_NAME: GLenum;\n    readonly FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE: GLenum;\n    readonly FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE: GLenum;\n    readonly FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL: GLenum;\n    readonly FRAMEBUFFER_BINDING: GLenum;\n    readonly FRAMEBUFFER_COMPLETE: GLenum;\n    readonly FRAMEBUFFER_INCOMPLETE_ATTACHMENT: GLenum;\n    readonly FRAMEBUFFER_INCOMPLETE_DIMENSIONS: GLenum;\n    readonly FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT: GLenum;\n    readonly FRAMEBUFFER_UNSUPPORTED: GLenum;\n    readonly FRONT: GLenum;\n    readonly FRONT_AND_BACK: GLenum;\n    readonly FRONT_FACE: GLenum;\n    readonly FUNC_ADD: GLenum;\n    readonly FUNC_REVERSE_SUBTRACT: GLenum;\n    readonly FUNC_SUBTRACT: GLenum;\n    readonly GENERATE_MIPMAP_HINT: GLenum;\n    readonly GEQUAL: GLenum;\n    readonly GREATER: GLenum;\n    readonly GREEN_BITS: GLenum;\n    readonly HIGH_FLOAT: GLenum;\n    readonly HIGH_INT: GLenum;\n    readonly IMPLEMENTATION_COLOR_READ_FORMAT: GLenum;\n    readonly IMPLEMENTATION_COLOR_READ_TYPE: GLenum;\n    readonly INCR: GLenum;\n    readonly INCR_WRAP: GLenum;\n    readonly INT: GLenum;\n    readonly INT_VEC2: GLenum;\n    readonly INT_VEC3: GLenum;\n    readonly INT_VEC4: GLenum;\n    readonly INVALID_ENUM: GLenum;\n    readonly INVALID_FRAMEBUFFER_OPERATION: GLenum;\n    readonly INVALID_OPERATION: GLenum;\n    readonly INVALID_VALUE: GLenum;\n    readonly INVERT: GLenum;\n    readonly KEEP: GLenum;\n    readonly LEQUAL: GLenum;\n    readonly LESS: GLenum;\n    readonly LINEAR: GLenum;\n    readonly LINEAR_MIPMAP_LINEAR: GLenum;\n    readonly LINEAR_MIPMAP_NEAREST: GLenum;\n    readonly LINES: GLenum;\n    readonly LINE_LOOP: GLenum;\n    readonly LINE_STRIP: GLenum;\n    readonly LINE_WIDTH: GLenum;\n    readonly LINK_STATUS: GLenum;\n    readonly LOW_FLOAT: GLenum;\n    readonly LOW_INT: GLenum;\n    readonly LUMINANCE: GLenum;\n    readonly LUMINANCE_ALPHA: GLenum;\n    readonly MAX_COMBINED_TEXTURE_IMAGE_UNITS: GLenum;\n    readonly MAX_CUBE_MAP_TEXTURE_SIZE: GLenum;\n    readonly MAX_FRAGMENT_UNIFORM_VECTORS: GLenum;\n    readonly MAX_RENDERBUFFER_SIZE: GLenum;\n    readonly MAX_TEXTURE_IMAGE_UNITS: GLenum;\n    readonly MAX_TEXTURE_SIZE: GLenum;\n    readonly MAX_VARYING_VECTORS: GLenum;\n    readonly MAX_VERTEX_ATTRIBS: GLenum;\n    readonly MAX_VERTEX_TEXTURE_IMAGE_UNITS: GLenum;\n    readonly MAX_VERTEX_UNIFORM_VECTORS: GLenum;\n    readonly MAX_VIEWPORT_DIMS: GLenum;\n    readonly MEDIUM_FLOAT: GLenum;\n    readonly MEDIUM_INT: GLenum;\n    readonly MIRRORED_REPEAT: GLenum;\n    readonly NEAREST: GLenum;\n    readonly NEAREST_MIPMAP_LINEAR: GLenum;\n    readonly NEAREST_MIPMAP_NEAREST: GLenum;\n    readonly NEVER: GLenum;\n    readonly NICEST: GLenum;\n    readonly NONE: GLenum;\n    readonly NOTEQUAL: GLenum;\n    readonly NO_ERROR: GLenum;\n    readonly ONE: GLenum;\n    readonly ONE_MINUS_CONSTANT_ALPHA: GLenum;\n    readonly ONE_MINUS_CONSTANT_COLOR: GLenum;\n    readonly ONE_MINUS_DST_ALPHA: GLenum;\n    readonly ONE_MINUS_DST_COLOR: GLenum;\n    readonly ONE_MINUS_SRC_ALPHA: GLenum;\n    readonly ONE_MINUS_SRC_COLOR: GLenum;\n    readonly OUT_OF_MEMORY: GLenum;\n    readonly PACK_ALIGNMENT: GLenum;\n    readonly POINTS: GLenum;\n    readonly POLYGON_OFFSET_FACTOR: GLenum;\n    readonly POLYGON_OFFSET_FILL: GLenum;\n    readonly POLYGON_OFFSET_UNITS: GLenum;\n    readonly RED_BITS: GLenum;\n    readonly RENDERBUFFER: GLenum;\n    readonly RENDERBUFFER_ALPHA_SIZE: GLenum;\n    readonly RENDERBUFFER_BINDING: GLenum;\n    readonly RENDERBUFFER_BLUE_SIZE: GLenum;\n    readonly RENDERBUFFER_DEPTH_SIZE: GLenum;\n    readonly RENDERBUFFER_GREEN_SIZE: GLenum;\n    readonly RENDERBUFFER_HEIGHT: GLenum;\n    readonly RENDERBUFFER_INTERNAL_FORMAT: GLenum;\n    readonly RENDERBUFFER_RED_SIZE: GLenum;\n    readonly RENDERBUFFER_STENCIL_SIZE: GLenum;\n    readonly RENDERBUFFER_WIDTH: GLenum;\n    readonly RENDERER: GLenum;\n    readonly REPEAT: GLenum;\n    readonly REPLACE: GLenum;\n    readonly RGB: GLenum;\n    readonly RGB565: GLenum;\n    readonly RGB5_A1: GLenum;\n    readonly RGBA: GLenum;\n    readonly RGBA4: GLenum;\n    readonly SAMPLER_2D: GLenum;\n    readonly SAMPLER_CUBE: GLenum;\n    readonly SAMPLES: GLenum;\n    readonly SAMPLE_ALPHA_TO_COVERAGE: GLenum;\n    readonly SAMPLE_BUFFERS: GLenum;\n    readonly SAMPLE_COVERAGE: GLenum;\n    readonly SAMPLE_COVERAGE_INVERT: GLenum;\n    readonly SAMPLE_COVERAGE_VALUE: GLenum;\n    readonly SCISSOR_BOX: GLenum;\n    readonly SCISSOR_TEST: GLenum;\n    readonly SHADER_TYPE: GLenum;\n    readonly SHADING_LANGUAGE_VERSION: GLenum;\n    readonly SHORT: GLenum;\n    readonly SRC_ALPHA: GLenum;\n    readonly SRC_ALPHA_SATURATE: GLenum;\n    readonly SRC_COLOR: GLenum;\n    readonly STATIC_DRAW: GLenum;\n    readonly STENCIL_ATTACHMENT: GLenum;\n    readonly STENCIL_BACK_FAIL: GLenum;\n    readonly STENCIL_BACK_FUNC: GLenum;\n    readonly STENCIL_BACK_PASS_DEPTH_FAIL: GLenum;\n    readonly STENCIL_BACK_PASS_DEPTH_PASS: GLenum;\n    readonly STENCIL_BACK_REF: GLenum;\n    readonly STENCIL_BACK_VALUE_MASK: GLenum;\n    readonly STENCIL_BACK_WRITEMASK: GLenum;\n    readonly STENCIL_BITS: GLenum;\n    readonly STENCIL_BUFFER_BIT: GLenum;\n    readonly STENCIL_CLEAR_VALUE: GLenum;\n    readonly STENCIL_FAIL: GLenum;\n    readonly STENCIL_FUNC: GLenum;\n    readonly STENCIL_INDEX8: GLenum;\n    readonly STENCIL_PASS_DEPTH_FAIL: GLenum;\n    readonly STENCIL_PASS_DEPTH_PASS: GLenum;\n    readonly STENCIL_REF: GLenum;\n    readonly STENCIL_TEST: GLenum;\n    readonly STENCIL_VALUE_MASK: GLenum;\n    readonly STENCIL_WRITEMASK: GLenum;\n    readonly STREAM_DRAW: GLenum;\n    readonly SUBPIXEL_BITS: GLenum;\n    readonly TEXTURE: GLenum;\n    readonly TEXTURE0: GLenum;\n    readonly TEXTURE1: GLenum;\n    readonly TEXTURE10: GLenum;\n    readonly TEXTURE11: GLenum;\n    readonly TEXTURE12: GLenum;\n    readonly TEXTURE13: GLenum;\n    readonly TEXTURE14: GLenum;\n    readonly TEXTURE15: GLenum;\n    readonly TEXTURE16: GLenum;\n    readonly TEXTURE17: GLenum;\n    readonly TEXTURE18: GLenum;\n    readonly TEXTURE19: GLenum;\n    readonly TEXTURE2: GLenum;\n    readonly TEXTURE20: GLenum;\n    readonly TEXTURE21: GLenum;\n    readonly TEXTURE22: GLenum;\n    readonly TEXTURE23: GLenum;\n    readonly TEXTURE24: GLenum;\n    readonly TEXTURE25: GLenum;\n    readonly TEXTURE26: GLenum;\n    readonly TEXTURE27: GLenum;\n    readonly TEXTURE28: GLenum;\n    readonly TEXTURE29: GLenum;\n    readonly TEXTURE3: GLenum;\n    readonly TEXTURE30: GLenum;\n    readonly TEXTURE31: GLenum;\n    readonly TEXTURE4: GLenum;\n    readonly TEXTURE5: GLenum;\n    readonly TEXTURE6: GLenum;\n    readonly TEXTURE7: GLenum;\n    readonly TEXTURE8: GLenum;\n    readonly TEXTURE9: GLenum;\n    readonly TEXTURE_2D: GLenum;\n    readonly TEXTURE_BINDING_2D: GLenum;\n    readonly TEXTURE_BINDING_CUBE_MAP: GLenum;\n    readonly TEXTURE_CUBE_MAP: GLenum;\n    readonly TEXTURE_CUBE_MAP_NEGATIVE_X: GLenum;\n    readonly TEXTURE_CUBE_MAP_NEGATIVE_Y: GLenum;\n    readonly TEXTURE_CUBE_MAP_NEGATIVE_Z: GLenum;\n    readonly TEXTURE_CUBE_MAP_POSITIVE_X: GLenum;\n    readonly TEXTURE_CUBE_MAP_POSITIVE_Y: GLenum;\n    readonly TEXTURE_CUBE_MAP_POSITIVE_Z: GLenum;\n    readonly TEXTURE_MAG_FILTER: GLenum;\n    readonly TEXTURE_MIN_FILTER: GLenum;\n    readonly TEXTURE_WRAP_S: GLenum;\n    readonly TEXTURE_WRAP_T: GLenum;\n    readonly TRIANGLES: GLenum;\n    readonly TRIANGLE_FAN: GLenum;\n    readonly TRIANGLE_STRIP: GLenum;\n    readonly UNPACK_ALIGNMENT: GLenum;\n    readonly UNPACK_COLORSPACE_CONVERSION_WEBGL: GLenum;\n    readonly UNPACK_FLIP_Y_WEBGL: GLenum;\n    readonly UNPACK_PREMULTIPLY_ALPHA_WEBGL: GLenum;\n    readonly UNSIGNED_BYTE: GLenum;\n    readonly UNSIGNED_INT: GLenum;\n    readonly UNSIGNED_SHORT: GLenum;\n    readonly UNSIGNED_SHORT_4_4_4_4: GLenum;\n    readonly UNSIGNED_SHORT_5_5_5_1: GLenum;\n    readonly UNSIGNED_SHORT_5_6_5: GLenum;\n    readonly VALIDATE_STATUS: GLenum;\n    readonly VENDOR: GLenum;\n    readonly VERSION: GLenum;\n    readonly VERTEX_ATTRIB_ARRAY_BUFFER_BINDING: GLenum;\n    readonly VERTEX_ATTRIB_ARRAY_ENABLED: GLenum;\n    readonly VERTEX_ATTRIB_ARRAY_NORMALIZED: GLenum;\n    readonly VERTEX_ATTRIB_ARRAY_POINTER: GLenum;\n    readonly VERTEX_ATTRIB_ARRAY_SIZE: GLenum;\n    readonly VERTEX_ATTRIB_ARRAY_STRIDE: GLenum;\n    readonly VERTEX_ATTRIB_ARRAY_TYPE: GLenum;\n    readonly VERTEX_SHADER: GLenum;\n    readonly VIEWPORT: GLenum;\n    readonly ZERO: GLenum;\n    readonly ACTIVE_UNIFORM_BLOCKS: GLenum;\n    readonly ALREADY_SIGNALED: GLenum;\n    readonly ANY_SAMPLES_PASSED: GLenum;\n    readonly ANY_SAMPLES_PASSED_CONSERVATIVE: GLenum;\n    readonly COLOR: GLenum;\n    readonly COLOR_ATTACHMENT1: GLenum;\n    readonly COLOR_ATTACHMENT10: GLenum;\n    readonly COLOR_ATTACHMENT11: GLenum;\n    readonly COLOR_ATTACHMENT12: GLenum;\n    readonly COLOR_ATTACHMENT13: GLenum;\n    readonly COLOR_ATTACHMENT14: GLenum;\n    readonly COLOR_ATTACHMENT15: GLenum;\n    readonly COLOR_ATTACHMENT2: GLenum;\n    readonly COLOR_ATTACHMENT3: GLenum;\n    readonly COLOR_ATTACHMENT4: GLenum;\n    readonly COLOR_ATTACHMENT5: GLenum;\n    readonly COLOR_ATTACHMENT6: GLenum;\n    readonly COLOR_ATTACHMENT7: GLenum;\n    readonly COLOR_ATTACHMENT8: GLenum;\n    readonly COLOR_ATTACHMENT9: GLenum;\n    readonly COMPARE_REF_TO_TEXTURE: GLenum;\n    readonly CONDITION_SATISFIED: GLenum;\n    readonly COPY_READ_BUFFER: GLenum;\n    readonly COPY_READ_BUFFER_BINDING: GLenum;\n    readonly COPY_WRITE_BUFFER: GLenum;\n    readonly COPY_WRITE_BUFFER_BINDING: GLenum;\n    readonly CURRENT_QUERY: GLenum;\n    readonly DEPTH: GLenum;\n    readonly DEPTH24_STENCIL8: GLenum;\n    readonly DEPTH32F_STENCIL8: GLenum;\n    readonly DEPTH_COMPONENT24: GLenum;\n    readonly DEPTH_COMPONENT32F: GLenum;\n    readonly DRAW_BUFFER0: GLenum;\n    readonly DRAW_BUFFER1: GLenum;\n    readonly DRAW_BUFFER10: GLenum;\n    readonly DRAW_BUFFER11: GLenum;\n    readonly DRAW_BUFFER12: GLenum;\n    readonly DRAW_BUFFER13: GLenum;\n    readonly DRAW_BUFFER14: GLenum;\n    readonly DRAW_BUFFER15: GLenum;\n    readonly DRAW_BUFFER2: GLenum;\n    readonly DRAW_BUFFER3: GLenum;\n    readonly DRAW_BUFFER4: GLenum;\n    readonly DRAW_BUFFER5: GLenum;\n    readonly DRAW_BUFFER6: GLenum;\n    readonly DRAW_BUFFER7: GLenum;\n    readonly DRAW_BUFFER8: GLenum;\n    readonly DRAW_BUFFER9: GLenum;\n    readonly DRAW_FRAMEBUFFER: GLenum;\n    readonly DRAW_FRAMEBUFFER_BINDING: GLenum;\n    readonly DYNAMIC_COPY: GLenum;\n    readonly DYNAMIC_READ: GLenum;\n    readonly FLOAT_32_UNSIGNED_INT_24_8_REV: GLenum;\n    readonly FLOAT_MAT2x3: GLenum;\n    readonly FLOAT_MAT2x4: GLenum;\n    readonly FLOAT_MAT3x2: GLenum;\n    readonly FLOAT_MAT3x4: GLenum;\n    readonly FLOAT_MAT4x2: GLenum;\n    readonly FLOAT_MAT4x3: GLenum;\n    readonly FRAGMENT_SHADER_DERIVATIVE_HINT: GLenum;\n    readonly FRAMEBUFFER_ATTACHMENT_ALPHA_SIZE: GLenum;\n    readonly FRAMEBUFFER_ATTACHMENT_BLUE_SIZE: GLenum;\n    readonly FRAMEBUFFER_ATTACHMENT_COLOR_ENCODING: GLenum;\n    readonly FRAMEBUFFER_ATTACHMENT_COMPONENT_TYPE: GLenum;\n    readonly FRAMEBUFFER_ATTACHMENT_DEPTH_SIZE: GLenum;\n    readonly FRAMEBUFFER_ATTACHMENT_GREEN_SIZE: GLenum;\n    readonly FRAMEBUFFER_ATTACHMENT_RED_SIZE: GLenum;\n    readonly FRAMEBUFFER_ATTACHMENT_STENCIL_SIZE: GLenum;\n    readonly FRAMEBUFFER_ATTACHMENT_TEXTURE_LAYER: GLenum;\n    readonly FRAMEBUFFER_DEFAULT: GLenum;\n    readonly FRAMEBUFFER_INCOMPLETE_MULTISAMPLE: GLenum;\n    readonly HALF_FLOAT: GLenum;\n    readonly INTERLEAVED_ATTRIBS: GLenum;\n    readonly INT_2_10_10_10_REV: GLenum;\n    readonly INT_SAMPLER_2D: GLenum;\n    readonly INT_SAMPLER_2D_ARRAY: GLenum;\n    readonly INT_SAMPLER_3D: GLenum;\n    readonly INT_SAMPLER_CUBE: GLenum;\n    readonly INVALID_INDEX: GLenum;\n    readonly MAX: GLenum;\n    readonly MAX_3D_TEXTURE_SIZE: GLenum;\n    readonly MAX_ARRAY_TEXTURE_LAYERS: GLenum;\n    readonly MAX_CLIENT_WAIT_TIMEOUT_WEBGL: GLenum;\n    readonly MAX_COLOR_ATTACHMENTS: GLenum;\n    readonly MAX_COMBINED_FRAGMENT_UNIFORM_COMPONENTS: GLenum;\n    readonly MAX_COMBINED_UNIFORM_BLOCKS: GLenum;\n    readonly MAX_COMBINED_VERTEX_UNIFORM_COMPONENTS: GLenum;\n    readonly MAX_DRAW_BUFFERS: GLenum;\n    readonly MAX_ELEMENTS_INDICES: GLenum;\n    readonly MAX_ELEMENTS_VERTICES: GLenum;\n    readonly MAX_ELEMENT_INDEX: GLenum;\n    readonly MAX_FRAGMENT_INPUT_COMPONENTS: GLenum;\n    readonly MAX_FRAGMENT_UNIFORM_BLOCKS: GLenum;\n    readonly MAX_FRAGMENT_UNIFORM_COMPONENTS: GLenum;\n    readonly MAX_PROGRAM_TEXEL_OFFSET: GLenum;\n    readonly MAX_SAMPLES: GLenum;\n    readonly MAX_SERVER_WAIT_TIMEOUT: GLenum;\n    readonly MAX_TEXTURE_LOD_BIAS: GLenum;\n    readonly MAX_TRANSFORM_FEEDBACK_INTERLEAVED_COMPONENTS: GLenum;\n    readonly MAX_TRANSFORM_FEEDBACK_SEPARATE_ATTRIBS: GLenum;\n    readonly MAX_TRANSFORM_FEEDBACK_SEPARATE_COMPONENTS: GLenum;\n    readonly MAX_UNIFORM_BLOCK_SIZE: GLenum;\n    readonly MAX_UNIFORM_BUFFER_BINDINGS: GLenum;\n    readonly MAX_VARYING_COMPONENTS: GLenum;\n    readonly MAX_VERTEX_OUTPUT_COMPONENTS: GLenum;\n    readonly MAX_VERTEX_UNIFORM_BLOCKS: GLenum;\n    readonly MAX_VERTEX_UNIFORM_COMPONENTS: GLenum;\n    readonly MIN: GLenum;\n    readonly MIN_PROGRAM_TEXEL_OFFSET: GLenum;\n    readonly OBJECT_TYPE: GLenum;\n    readonly PACK_ROW_LENGTH: GLenum;\n    readonly PACK_SKIP_PIXELS: GLenum;\n    readonly PACK_SKIP_ROWS: GLenum;\n    readonly PIXEL_PACK_BUFFER: GLenum;\n    readonly PIXEL_PACK_BUFFER_BINDING: GLenum;\n    readonly PIXEL_UNPACK_BUFFER: GLenum;\n    readonly PIXEL_UNPACK_BUFFER_BINDING: GLenum;\n    readonly QUERY_RESULT: GLenum;\n    readonly QUERY_RESULT_AVAILABLE: GLenum;\n    readonly R11F_G11F_B10F: GLenum;\n    readonly R16F: GLenum;\n    readonly R16I: GLenum;\n    readonly R16UI: GLenum;\n    readonly R32F: GLenum;\n    readonly R32I: GLenum;\n    readonly R32UI: GLenum;\n    readonly R8: GLenum;\n    readonly R8I: GLenum;\n    readonly R8UI: GLenum;\n    readonly R8_SNORM: GLenum;\n    readonly RASTERIZER_DISCARD: GLenum;\n    readonly READ_BUFFER: GLenum;\n    readonly READ_FRAMEBUFFER: GLenum;\n    readonly READ_FRAMEBUFFER_BINDING: GLenum;\n    readonly RED: GLenum;\n    readonly RED_INTEGER: GLenum;\n    readonly RENDERBUFFER_SAMPLES: GLenum;\n    readonly RG: GLenum;\n    readonly RG16F: GLenum;\n    readonly RG16I: GLenum;\n    readonly RG16UI: GLenum;\n    readonly RG32F: GLenum;\n    readonly RG32I: GLenum;\n    readonly RG32UI: GLenum;\n    readonly RG8: GLenum;\n    readonly RG8I: GLenum;\n    readonly RG8UI: GLenum;\n    readonly RG8_SNORM: GLenum;\n    readonly RGB10_A2: GLenum;\n    readonly RGB10_A2UI: GLenum;\n    readonly RGB16F: GLenum;\n    readonly RGB16I: GLenum;\n    readonly RGB16UI: GLenum;\n    readonly RGB32F: GLenum;\n    readonly RGB32I: GLenum;\n    readonly RGB32UI: GLenum;\n    readonly RGB8: GLenum;\n    readonly RGB8I: GLenum;\n    readonly RGB8UI: GLenum;\n    readonly RGB8_SNORM: GLenum;\n    readonly RGB9_E5: GLenum;\n    readonly RGBA16F: GLenum;\n    readonly RGBA16I: GLenum;\n    readonly RGBA16UI: GLenum;\n    readonly RGBA32F: GLenum;\n    readonly RGBA32I: GLenum;\n    readonly RGBA32UI: GLenum;\n    readonly RGBA8: GLenum;\n    readonly RGBA8I: GLenum;\n    readonly RGBA8UI: GLenum;\n    readonly RGBA8_SNORM: GLenum;\n    readonly RGBA_INTEGER: GLenum;\n    readonly RGB_INTEGER: GLenum;\n    readonly RG_INTEGER: GLenum;\n    readonly SAMPLER_2D_ARRAY: GLenum;\n    readonly SAMPLER_2D_ARRAY_SHADOW: GLenum;\n    readonly SAMPLER_2D_SHADOW: GLenum;\n    readonly SAMPLER_3D: GLenum;\n    readonly SAMPLER_BINDING: GLenum;\n    readonly SAMPLER_CUBE_SHADOW: GLenum;\n    readonly SEPARATE_ATTRIBS: GLenum;\n    readonly SIGNALED: GLenum;\n    readonly SIGNED_NORMALIZED: GLenum;\n    readonly SRGB: GLenum;\n    readonly SRGB8: GLenum;\n    readonly SRGB8_ALPHA8: GLenum;\n    readonly STATIC_COPY: GLenum;\n    readonly STATIC_READ: GLenum;\n    readonly STENCIL: GLenum;\n    readonly STREAM_COPY: GLenum;\n    readonly STREAM_READ: GLenum;\n    readonly SYNC_CONDITION: GLenum;\n    readonly SYNC_FENCE: GLenum;\n    readonly SYNC_FLAGS: GLenum;\n    readonly SYNC_FLUSH_COMMANDS_BIT: GLenum;\n    readonly SYNC_GPU_COMMANDS_COMPLETE: GLenum;\n    readonly SYNC_STATUS: GLenum;\n    readonly TEXTURE_2D_ARRAY: GLenum;\n    readonly TEXTURE_3D: GLenum;\n    readonly TEXTURE_BASE_LEVEL: GLenum;\n    readonly TEXTURE_BINDING_2D_ARRAY: GLenum;\n    readonly TEXTURE_BINDING_3D: GLenum;\n    readonly TEXTURE_COMPARE_FUNC: GLenum;\n    readonly TEXTURE_COMPARE_MODE: GLenum;\n    readonly TEXTURE_IMMUTABLE_FORMAT: GLenum;\n    readonly TEXTURE_IMMUTABLE_LEVELS: GLenum;\n    readonly TEXTURE_MAX_LEVEL: GLenum;\n    readonly TEXTURE_MAX_LOD: GLenum;\n    readonly TEXTURE_MIN_LOD: GLenum;\n    readonly TEXTURE_WRAP_R: GLenum;\n    readonly TIMEOUT_EXPIRED: GLenum;\n    readonly TIMEOUT_IGNORED: GLint64;\n    readonly TRANSFORM_FEEDBACK: GLenum;\n    readonly TRANSFORM_FEEDBACK_ACTIVE: GLenum;\n    readonly TRANSFORM_FEEDBACK_BINDING: GLenum;\n    readonly TRANSFORM_FEEDBACK_BUFFER: GLenum;\n    readonly TRANSFORM_FEEDBACK_BUFFER_BINDING: GLenum;\n    readonly TRANSFORM_FEEDBACK_BUFFER_MODE: GLenum;\n    readonly TRANSFORM_FEEDBACK_BUFFER_SIZE: GLenum;\n    readonly TRANSFORM_FEEDBACK_BUFFER_START: GLenum;\n    readonly TRANSFORM_FEEDBACK_PAUSED: GLenum;\n    readonly TRANSFORM_FEEDBACK_PRIMITIVES_WRITTEN: GLenum;\n    readonly TRANSFORM_FEEDBACK_VARYINGS: GLenum;\n    readonly UNIFORM_ARRAY_STRIDE: GLenum;\n    readonly UNIFORM_BLOCK_ACTIVE_UNIFORMS: GLenum;\n    readonly UNIFORM_BLOCK_ACTIVE_UNIFORM_INDICES: GLenum;\n    readonly UNIFORM_BLOCK_BINDING: GLenum;\n    readonly UNIFORM_BLOCK_DATA_SIZE: GLenum;\n    readonly UNIFORM_BLOCK_INDEX: GLenum;\n    readonly UNIFORM_BLOCK_REFERENCED_BY_FRAGMENT_SHADER: GLenum;\n    readonly UNIFORM_BLOCK_REFERENCED_BY_VERTEX_SHADER: GLenum;\n    readonly UNIFORM_BUFFER: GLenum;\n    readonly UNIFORM_BUFFER_BINDING: GLenum;\n    readonly UNIFORM_BUFFER_OFFSET_ALIGNMENT: GLenum;\n    readonly UNIFORM_BUFFER_SIZE: GLenum;\n    readonly UNIFORM_BUFFER_START: GLenum;\n    readonly UNIFORM_IS_ROW_MAJOR: GLenum;\n    readonly UNIFORM_MATRIX_STRIDE: GLenum;\n    readonly UNIFORM_OFFSET: GLenum;\n    readonly UNIFORM_SIZE: GLenum;\n    readonly UNIFORM_TYPE: GLenum;\n    readonly UNPACK_IMAGE_HEIGHT: GLenum;\n    readonly UNPACK_ROW_LENGTH: GLenum;\n    readonly UNPACK_SKIP_IMAGES: GLenum;\n    readonly UNPACK_SKIP_PIXELS: GLenum;\n    readonly UNPACK_SKIP_ROWS: GLenum;\n    readonly UNSIGNALED: GLenum;\n    readonly UNSIGNED_INT_10F_11F_11F_REV: GLenum;\n    readonly UNSIGNED_INT_24_8: GLenum;\n    readonly UNSIGNED_INT_2_10_10_10_REV: GLenum;\n    readonly UNSIGNED_INT_5_9_9_9_REV: GLenum;\n    readonly UNSIGNED_INT_SAMPLER_2D: GLenum;\n    readonly UNSIGNED_INT_SAMPLER_2D_ARRAY: GLenum;\n    readonly UNSIGNED_INT_SAMPLER_3D: GLenum;\n    readonly UNSIGNED_INT_SAMPLER_CUBE: GLenum;\n    readonly UNSIGNED_INT_VEC2: GLenum;\n    readonly UNSIGNED_INT_VEC3: GLenum;\n    readonly UNSIGNED_INT_VEC4: GLenum;\n    readonly UNSIGNED_NORMALIZED: GLenum;\n    readonly VERTEX_ARRAY_BINDING: GLenum;\n    readonly VERTEX_ATTRIB_ARRAY_DIVISOR: GLenum;\n    readonly VERTEX_ATTRIB_ARRAY_INTEGER: GLenum;\n    readonly WAIT_FAILED: GLenum;\n};\n\ninterface WebGL2RenderingContextBase {\n    beginQuery(target: GLenum, query: WebGLQuery): void;\n    beginTransformFeedback(primitiveMode: GLenum): void;\n    bindBufferBase(target: GLenum, index: GLuint, buffer: WebGLBuffer | null): void;\n    bindBufferRange(target: GLenum, index: GLuint, buffer: WebGLBuffer | null, offset: GLintptr, size: GLsizeiptr): void;\n    bindSampler(unit: GLuint, sampler: WebGLSampler | null): void;\n    bindTransformFeedback(target: GLenum, tf: WebGLTransformFeedback | null): void;\n    bindVertexArray(array: WebGLVertexArrayObject | null): void;\n    blitFramebuffer(srcX0: GLint, srcY0: GLint, srcX1: GLint, srcY1: GLint, dstX0: GLint, dstY0: GLint, dstX1: GLint, dstY1: GLint, mask: GLbitfield, filter: GLenum): void;\n    clearBufferfi(buffer: GLenum, drawbuffer: GLint, depth: GLfloat, stencil: GLint): void;\n    clearBufferfv(buffer: GLenum, drawbuffer: GLint, values: Float32List, srcOffset?: GLuint): void;\n    clearBufferiv(buffer: GLenum, drawbuffer: GLint, values: Int32List, srcOffset?: GLuint): void;\n    clearBufferuiv(buffer: GLenum, drawbuffer: GLint, values: Uint32List, srcOffset?: GLuint): void;\n    clientWaitSync(sync: WebGLSync, flags: GLbitfield, timeout: GLuint64): GLenum;\n    compressedTexImage3D(target: GLenum, level: GLint, internalformat: GLenum, width: GLsizei, height: GLsizei, depth: GLsizei, border: GLint, imageSize: GLsizei, offset: GLintptr): void;\n    compressedTexImage3D(target: GLenum, level: GLint, internalformat: GLenum, width: GLsizei, height: GLsizei, depth: GLsizei, border: GLint, srcData: ArrayBufferView, srcOffset?: GLuint, srcLengthOverride?: GLuint): void;\n    compressedTexSubImage3D(target: GLenum, level: GLint, xoffset: GLint, yoffset: GLint, zoffset: GLint, width: GLsizei, height: GLsizei, depth: GLsizei, format: GLenum, imageSize: GLsizei, offset: GLintptr): void;\n    compressedTexSubImage3D(target: GLenum, level: GLint, xoffset: GLint, yoffset: GLint, zoffset: GLint, width: GLsizei, height: GLsizei, depth: GLsizei, format: GLenum, srcData: ArrayBufferView, srcOffset?: GLuint, srcLengthOverride?: GLuint): void;\n    copyBufferSubData(readTarget: GLenum, writeTarget: GLenum, readOffset: GLintptr, writeOffset: GLintptr, size: GLsizeiptr): void;\n    copyTexSubImage3D(target: GLenum, level: GLint, xoffset: GLint, yoffset: GLint, zoffset: GLint, x: GLint, y: GLint, width: GLsizei, height: GLsizei): void;\n    createQuery(): WebGLQuery | null;\n    createSampler(): WebGLSampler | null;\n    createTransformFeedback(): WebGLTransformFeedback | null;\n    createVertexArray(): WebGLVertexArrayObject | null;\n    deleteQuery(query: WebGLQuery | null): void;\n    deleteSampler(sampler: WebGLSampler | null): void;\n    deleteSync(sync: WebGLSync | null): void;\n    deleteTransformFeedback(tf: WebGLTransformFeedback | null): void;\n    deleteVertexArray(vertexArray: WebGLVertexArrayObject | null): void;\n    drawArraysInstanced(mode: GLenum, first: GLint, count: GLsizei, instanceCount: GLsizei): void;\n    drawBuffers(buffers: GLenum[]): void;\n    drawElementsInstanced(mode: GLenum, count: GLsizei, type: GLenum, offset: GLintptr, instanceCount: GLsizei): void;\n    drawRangeElements(mode: GLenum, start: GLuint, end: GLuint, count: GLsizei, type: GLenum, offset: GLintptr): void;\n    endQuery(target: GLenum): void;\n    endTransformFeedback(): void;\n    fenceSync(condition: GLenum, flags: GLbitfield): WebGLSync | null;\n    framebufferTextureLayer(target: GLenum, attachment: GLenum, texture: WebGLTexture | null, level: GLint, layer: GLint): void;\n    getActiveUniformBlockName(program: WebGLProgram, uniformBlockIndex: GLuint): string | null;\n    getActiveUniformBlockParameter(program: WebGLProgram, uniformBlockIndex: GLuint, pname: GLenum): any;\n    getActiveUniforms(program: WebGLProgram, uniformIndices: GLuint[], pname: GLenum): any;\n    getBufferSubData(target: GLenum, srcByteOffset: GLintptr, dstBuffer: ArrayBufferView, dstOffset?: GLuint, length?: GLuint): void;\n    getFragDataLocation(program: WebGLProgram, name: string): GLint;\n    getIndexedParameter(target: GLenum, index: GLuint): any;\n    getInternalformatParameter(target: GLenum, internalformat: GLenum, pname: GLenum): any;\n    getQuery(target: GLenum, pname: GLenum): WebGLQuery | null;\n    getQueryParameter(query: WebGLQuery, pname: GLenum): any;\n    getSamplerParameter(sampler: WebGLSampler, pname: GLenum): any;\n    getSyncParameter(sync: WebGLSync, pname: GLenum): any;\n    getTransformFeedbackVarying(program: WebGLProgram, index: GLuint): WebGLActiveInfo | null;\n    getUniformBlockIndex(program: WebGLProgram, uniformBlockName: string): GLuint;\n    getUniformIndices(program: WebGLProgram, uniformNames: string[]): GLuint[] | null;\n    invalidateFramebuffer(target: GLenum, attachments: GLenum[]): void;\n    invalidateSubFramebuffer(target: GLenum, attachments: GLenum[], x: GLint, y: GLint, width: GLsizei, height: GLsizei): void;\n    isQuery(query: WebGLQuery | null): GLboolean;\n    isSampler(sampler: WebGLSampler | null): GLboolean;\n    isSync(sync: WebGLSync | null): GLboolean;\n    isTransformFeedback(tf: WebGLTransformFeedback | null): GLboolean;\n    isVertexArray(vertexArray: WebGLVertexArrayObject | null): GLboolean;\n    pauseTransformFeedback(): void;\n    readBuffer(src: GLenum): void;\n    renderbufferStorageMultisample(target: GLenum, samples: GLsizei, internalformat: GLenum, width: GLsizei, height: GLsizei): void;\n    resumeTransformFeedback(): void;\n    samplerParameterf(sampler: WebGLSampler, pname: GLenum, param: GLfloat): void;\n    samplerParameteri(sampler: WebGLSampler, pname: GLenum, param: GLint): void;\n    texImage3D(target: GLenum, level: GLint, internalformat: GLint, width: GLsizei, height: GLsizei, depth: GLsizei, border: GLint, format: GLenum, type: GLenum, pboOffset: GLintptr): void;\n    texImage3D(target: GLenum, level: GLint, internalformat: GLint, width: GLsizei, height: GLsizei, depth: GLsizei, border: GLint, format: GLenum, type: GLenum, source: TexImageSource): void;\n    texImage3D(target: GLenum, level: GLint, internalformat: GLint, width: GLsizei, height: GLsizei, depth: GLsizei, border: GLint, format: GLenum, type: GLenum, srcData: ArrayBufferView | null): void;\n    texImage3D(target: GLenum, level: GLint, internalformat: GLint, width: GLsizei, height: GLsizei, depth: GLsizei, border: GLint, format: GLenum, type: GLenum, srcData: ArrayBufferView, srcOffset: GLuint): void;\n    texStorage2D(target: GLenum, levels: GLsizei, internalformat: GLenum, width: GLsizei, height: GLsizei): void;\n    texStorage3D(target: GLenum, levels: GLsizei, internalformat: GLenum, width: GLsizei, height: GLsizei, depth: GLsizei): void;\n    texSubImage3D(target: GLenum, level: GLint, xoffset: GLint, yoffset: GLint, zoffset: GLint, width: GLsizei, height: GLsizei, depth: GLsizei, format: GLenum, type: GLenum, pboOffset: GLintptr): void;\n    texSubImage3D(target: GLenum, level: GLint, xoffset: GLint, yoffset: GLint, zoffset: GLint, width: GLsizei, height: GLsizei, depth: GLsizei, format: GLenum, type: GLenum, source: TexImageSource): void;\n    texSubImage3D(target: GLenum, level: GLint, xoffset: GLint, yoffset: GLint, zoffset: GLint, width: GLsizei, height: GLsizei, depth: GLsizei, format: GLenum, type: GLenum, srcData: ArrayBufferView | null, srcOffset?: GLuint): void;\n    transformFeedbackVaryings(program: WebGLProgram, varyings: string[], bufferMode: GLenum): void;\n    uniform1ui(location: WebGLUniformLocation | null, v0: GLuint): void;\n    uniform1uiv(location: WebGLUniformLocation | null, data: Uint32List, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniform2ui(location: WebGLUniformLocation | null, v0: GLuint, v1: GLuint): void;\n    uniform2uiv(location: WebGLUniformLocation | null, data: Uint32List, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniform3ui(location: WebGLUniformLocation | null, v0: GLuint, v1: GLuint, v2: GLuint): void;\n    uniform3uiv(location: WebGLUniformLocation | null, data: Uint32List, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniform4ui(location: WebGLUniformLocation | null, v0: GLuint, v1: GLuint, v2: GLuint, v3: GLuint): void;\n    uniform4uiv(location: WebGLUniformLocation | null, data: Uint32List, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniformBlockBinding(program: WebGLProgram, uniformBlockIndex: GLuint, uniformBlockBinding: GLuint): void;\n    uniformMatrix2x3fv(location: WebGLUniformLocation | null, transpose: GLboolean, data: Float32List, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniformMatrix2x4fv(location: WebGLUniformLocation | null, transpose: GLboolean, data: Float32List, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniformMatrix3x2fv(location: WebGLUniformLocation | null, transpose: GLboolean, data: Float32List, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniformMatrix3x4fv(location: WebGLUniformLocation | null, transpose: GLboolean, data: Float32List, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniformMatrix4x2fv(location: WebGLUniformLocation | null, transpose: GLboolean, data: Float32List, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniformMatrix4x3fv(location: WebGLUniformLocation | null, transpose: GLboolean, data: Float32List, srcOffset?: GLuint, srcLength?: GLuint): void;\n    vertexAttribDivisor(index: GLuint, divisor: GLuint): void;\n    vertexAttribI4i(index: GLuint, x: GLint, y: GLint, z: GLint, w: GLint): void;\n    vertexAttribI4iv(index: GLuint, values: Int32List): void;\n    vertexAttribI4ui(index: GLuint, x: GLuint, y: GLuint, z: GLuint, w: GLuint): void;\n    vertexAttribI4uiv(index: GLuint, values: Uint32List): void;\n    vertexAttribIPointer(index: GLuint, size: GLint, type: GLenum, stride: GLsizei, offset: GLintptr): void;\n    waitSync(sync: WebGLSync, flags: GLbitfield, timeout: GLint64): void;\n    readonly ACTIVE_UNIFORM_BLOCKS: GLenum;\n    readonly ALREADY_SIGNALED: GLenum;\n    readonly ANY_SAMPLES_PASSED: GLenum;\n    readonly ANY_SAMPLES_PASSED_CONSERVATIVE: GLenum;\n    readonly COLOR: GLenum;\n    readonly COLOR_ATTACHMENT1: GLenum;\n    readonly COLOR_ATTACHMENT10: GLenum;\n    readonly COLOR_ATTACHMENT11: GLenum;\n    readonly COLOR_ATTACHMENT12: GLenum;\n    readonly COLOR_ATTACHMENT13: GLenum;\n    readonly COLOR_ATTACHMENT14: GLenum;\n    readonly COLOR_ATTACHMENT15: GLenum;\n    readonly COLOR_ATTACHMENT2: GLenum;\n    readonly COLOR_ATTACHMENT3: GLenum;\n    readonly COLOR_ATTACHMENT4: GLenum;\n    readonly COLOR_ATTACHMENT5: GLenum;\n    readonly COLOR_ATTACHMENT6: GLenum;\n    readonly COLOR_ATTACHMENT7: GLenum;\n    readonly COLOR_ATTACHMENT8: GLenum;\n    readonly COLOR_ATTACHMENT9: GLenum;\n    readonly COMPARE_REF_TO_TEXTURE: GLenum;\n    readonly CONDITION_SATISFIED: GLenum;\n    readonly COPY_READ_BUFFER: GLenum;\n    readonly COPY_READ_BUFFER_BINDING: GLenum;\n    readonly COPY_WRITE_BUFFER: GLenum;\n    readonly COPY_WRITE_BUFFER_BINDING: GLenum;\n    readonly CURRENT_QUERY: GLenum;\n    readonly DEPTH: GLenum;\n    readonly DEPTH24_STENCIL8: GLenum;\n    readonly DEPTH32F_STENCIL8: GLenum;\n    readonly DEPTH_COMPONENT24: GLenum;\n    readonly DEPTH_COMPONENT32F: GLenum;\n    readonly DRAW_BUFFER0: GLenum;\n    readonly DRAW_BUFFER1: GLenum;\n    readonly DRAW_BUFFER10: GLenum;\n    readonly DRAW_BUFFER11: GLenum;\n    readonly DRAW_BUFFER12: GLenum;\n    readonly DRAW_BUFFER13: GLenum;\n    readonly DRAW_BUFFER14: GLenum;\n    readonly DRAW_BUFFER15: GLenum;\n    readonly DRAW_BUFFER2: GLenum;\n    readonly DRAW_BUFFER3: GLenum;\n    readonly DRAW_BUFFER4: GLenum;\n    readonly DRAW_BUFFER5: GLenum;\n    readonly DRAW_BUFFER6: GLenum;\n    readonly DRAW_BUFFER7: GLenum;\n    readonly DRAW_BUFFER8: GLenum;\n    readonly DRAW_BUFFER9: GLenum;\n    readonly DRAW_FRAMEBUFFER: GLenum;\n    readonly DRAW_FRAMEBUFFER_BINDING: GLenum;\n    readonly DYNAMIC_COPY: GLenum;\n    readonly DYNAMIC_READ: GLenum;\n    readonly FLOAT_32_UNSIGNED_INT_24_8_REV: GLenum;\n    readonly FLOAT_MAT2x3: GLenum;\n    readonly FLOAT_MAT2x4: GLenum;\n    readonly FLOAT_MAT3x2: GLenum;\n    readonly FLOAT_MAT3x4: GLenum;\n    readonly FLOAT_MAT4x2: GLenum;\n    readonly FLOAT_MAT4x3: GLenum;\n    readonly FRAGMENT_SHADER_DERIVATIVE_HINT: GLenum;\n    readonly FRAMEBUFFER_ATTACHMENT_ALPHA_SIZE: GLenum;\n    readonly FRAMEBUFFER_ATTACHMENT_BLUE_SIZE: GLenum;\n    readonly FRAMEBUFFER_ATTACHMENT_COLOR_ENCODING: GLenum;\n    readonly FRAMEBUFFER_ATTACHMENT_COMPONENT_TYPE: GLenum;\n    readonly FRAMEBUFFER_ATTACHMENT_DEPTH_SIZE: GLenum;\n    readonly FRAMEBUFFER_ATTACHMENT_GREEN_SIZE: GLenum;\n    readonly FRAMEBUFFER_ATTACHMENT_RED_SIZE: GLenum;\n    readonly FRAMEBUFFER_ATTACHMENT_STENCIL_SIZE: GLenum;\n    readonly FRAMEBUFFER_ATTACHMENT_TEXTURE_LAYER: GLenum;\n    readonly FRAMEBUFFER_DEFAULT: GLenum;\n    readonly FRAMEBUFFER_INCOMPLETE_MULTISAMPLE: GLenum;\n    readonly HALF_FLOAT: GLenum;\n    readonly INTERLEAVED_ATTRIBS: GLenum;\n    readonly INT_2_10_10_10_REV: GLenum;\n    readonly INT_SAMPLER_2D: GLenum;\n    readonly INT_SAMPLER_2D_ARRAY: GLenum;\n    readonly INT_SAMPLER_3D: GLenum;\n    readonly INT_SAMPLER_CUBE: GLenum;\n    readonly INVALID_INDEX: GLenum;\n    readonly MAX: GLenum;\n    readonly MAX_3D_TEXTURE_SIZE: GLenum;\n    readonly MAX_ARRAY_TEXTURE_LAYERS: GLenum;\n    readonly MAX_CLIENT_WAIT_TIMEOUT_WEBGL: GLenum;\n    readonly MAX_COLOR_ATTACHMENTS: GLenum;\n    readonly MAX_COMBINED_FRAGMENT_UNIFORM_COMPONENTS: GLenum;\n    readonly MAX_COMBINED_UNIFORM_BLOCKS: GLenum;\n    readonly MAX_COMBINED_VERTEX_UNIFORM_COMPONENTS: GLenum;\n    readonly MAX_DRAW_BUFFERS: GLenum;\n    readonly MAX_ELEMENTS_INDICES: GLenum;\n    readonly MAX_ELEMENTS_VERTICES: GLenum;\n    readonly MAX_ELEMENT_INDEX: GLenum;\n    readonly MAX_FRAGMENT_INPUT_COMPONENTS: GLenum;\n    readonly MAX_FRAGMENT_UNIFORM_BLOCKS: GLenum;\n    readonly MAX_FRAGMENT_UNIFORM_COMPONENTS: GLenum;\n    readonly MAX_PROGRAM_TEXEL_OFFSET: GLenum;\n    readonly MAX_SAMPLES: GLenum;\n    readonly MAX_SERVER_WAIT_TIMEOUT: GLenum;\n    readonly MAX_TEXTURE_LOD_BIAS: GLenum;\n    readonly MAX_TRANSFORM_FEEDBACK_INTERLEAVED_COMPONENTS: GLenum;\n    readonly MAX_TRANSFORM_FEEDBACK_SEPARATE_ATTRIBS: GLenum;\n    readonly MAX_TRANSFORM_FEEDBACK_SEPARATE_COMPONENTS: GLenum;\n    readonly MAX_UNIFORM_BLOCK_SIZE: GLenum;\n    readonly MAX_UNIFORM_BUFFER_BINDINGS: GLenum;\n    readonly MAX_VARYING_COMPONENTS: GLenum;\n    readonly MAX_VERTEX_OUTPUT_COMPONENTS: GLenum;\n    readonly MAX_VERTEX_UNIFORM_BLOCKS: GLenum;\n    readonly MAX_VERTEX_UNIFORM_COMPONENTS: GLenum;\n    readonly MIN: GLenum;\n    readonly MIN_PROGRAM_TEXEL_OFFSET: GLenum;\n    readonly OBJECT_TYPE: GLenum;\n    readonly PACK_ROW_LENGTH: GLenum;\n    readonly PACK_SKIP_PIXELS: GLenum;\n    readonly PACK_SKIP_ROWS: GLenum;\n    readonly PIXEL_PACK_BUFFER: GLenum;\n    readonly PIXEL_PACK_BUFFER_BINDING: GLenum;\n    readonly PIXEL_UNPACK_BUFFER: GLenum;\n    readonly PIXEL_UNPACK_BUFFER_BINDING: GLenum;\n    readonly QUERY_RESULT: GLenum;\n    readonly QUERY_RESULT_AVAILABLE: GLenum;\n    readonly R11F_G11F_B10F: GLenum;\n    readonly R16F: GLenum;\n    readonly R16I: GLenum;\n    readonly R16UI: GLenum;\n    readonly R32F: GLenum;\n    readonly R32I: GLenum;\n    readonly R32UI: GLenum;\n    readonly R8: GLenum;\n    readonly R8I: GLenum;\n    readonly R8UI: GLenum;\n    readonly R8_SNORM: GLenum;\n    readonly RASTERIZER_DISCARD: GLenum;\n    readonly READ_BUFFER: GLenum;\n    readonly READ_FRAMEBUFFER: GLenum;\n    readonly READ_FRAMEBUFFER_BINDING: GLenum;\n    readonly RED: GLenum;\n    readonly RED_INTEGER: GLenum;\n    readonly RENDERBUFFER_SAMPLES: GLenum;\n    readonly RG: GLenum;\n    readonly RG16F: GLenum;\n    readonly RG16I: GLenum;\n    readonly RG16UI: GLenum;\n    readonly RG32F: GLenum;\n    readonly RG32I: GLenum;\n    readonly RG32UI: GLenum;\n    readonly RG8: GLenum;\n    readonly RG8I: GLenum;\n    readonly RG8UI: GLenum;\n    readonly RG8_SNORM: GLenum;\n    readonly RGB10_A2: GLenum;\n    readonly RGB10_A2UI: GLenum;\n    readonly RGB16F: GLenum;\n    readonly RGB16I: GLenum;\n    readonly RGB16UI: GLenum;\n    readonly RGB32F: GLenum;\n    readonly RGB32I: GLenum;\n    readonly RGB32UI: GLenum;\n    readonly RGB8: GLenum;\n    readonly RGB8I: GLenum;\n    readonly RGB8UI: GLenum;\n    readonly RGB8_SNORM: GLenum;\n    readonly RGB9_E5: GLenum;\n    readonly RGBA16F: GLenum;\n    readonly RGBA16I: GLenum;\n    readonly RGBA16UI: GLenum;\n    readonly RGBA32F: GLenum;\n    readonly RGBA32I: GLenum;\n    readonly RGBA32UI: GLenum;\n    readonly RGBA8: GLenum;\n    readonly RGBA8I: GLenum;\n    readonly RGBA8UI: GLenum;\n    readonly RGBA8_SNORM: GLenum;\n    readonly RGBA_INTEGER: GLenum;\n    readonly RGB_INTEGER: GLenum;\n    readonly RG_INTEGER: GLenum;\n    readonly SAMPLER_2D_ARRAY: GLenum;\n    readonly SAMPLER_2D_ARRAY_SHADOW: GLenum;\n    readonly SAMPLER_2D_SHADOW: GLenum;\n    readonly SAMPLER_3D: GLenum;\n    readonly SAMPLER_BINDING: GLenum;\n    readonly SAMPLER_CUBE_SHADOW: GLenum;\n    readonly SEPARATE_ATTRIBS: GLenum;\n    readonly SIGNALED: GLenum;\n    readonly SIGNED_NORMALIZED: GLenum;\n    readonly SRGB: GLenum;\n    readonly SRGB8: GLenum;\n    readonly SRGB8_ALPHA8: GLenum;\n    readonly STATIC_COPY: GLenum;\n    readonly STATIC_READ: GLenum;\n    readonly STENCIL: GLenum;\n    readonly STREAM_COPY: GLenum;\n    readonly STREAM_READ: GLenum;\n    readonly SYNC_CONDITION: GLenum;\n    readonly SYNC_FENCE: GLenum;\n    readonly SYNC_FLAGS: GLenum;\n    readonly SYNC_FLUSH_COMMANDS_BIT: GLenum;\n    readonly SYNC_GPU_COMMANDS_COMPLETE: GLenum;\n    readonly SYNC_STATUS: GLenum;\n    readonly TEXTURE_2D_ARRAY: GLenum;\n    readonly TEXTURE_3D: GLenum;\n    readonly TEXTURE_BASE_LEVEL: GLenum;\n    readonly TEXTURE_BINDING_2D_ARRAY: GLenum;\n    readonly TEXTURE_BINDING_3D: GLenum;\n    readonly TEXTURE_COMPARE_FUNC: GLenum;\n    readonly TEXTURE_COMPARE_MODE: GLenum;\n    readonly TEXTURE_IMMUTABLE_FORMAT: GLenum;\n    readonly TEXTURE_IMMUTABLE_LEVELS: GLenum;\n    readonly TEXTURE_MAX_LEVEL: GLenum;\n    readonly TEXTURE_MAX_LOD: GLenum;\n    readonly TEXTURE_MIN_LOD: GLenum;\n    readonly TEXTURE_WRAP_R: GLenum;\n    readonly TIMEOUT_EXPIRED: GLenum;\n    readonly TIMEOUT_IGNORED: GLint64;\n    readonly TRANSFORM_FEEDBACK: GLenum;\n    readonly TRANSFORM_FEEDBACK_ACTIVE: GLenum;\n    readonly TRANSFORM_FEEDBACK_BINDING: GLenum;\n    readonly TRANSFORM_FEEDBACK_BUFFER: GLenum;\n    readonly TRANSFORM_FEEDBACK_BUFFER_BINDING: GLenum;\n    readonly TRANSFORM_FEEDBACK_BUFFER_MODE: GLenum;\n    readonly TRANSFORM_FEEDBACK_BUFFER_SIZE: GLenum;\n    readonly TRANSFORM_FEEDBACK_BUFFER_START: GLenum;\n    readonly TRANSFORM_FEEDBACK_PAUSED: GLenum;\n    readonly TRANSFORM_FEEDBACK_PRIMITIVES_WRITTEN: GLenum;\n    readonly TRANSFORM_FEEDBACK_VARYINGS: GLenum;\n    readonly UNIFORM_ARRAY_STRIDE: GLenum;\n    readonly UNIFORM_BLOCK_ACTIVE_UNIFORMS: GLenum;\n    readonly UNIFORM_BLOCK_ACTIVE_UNIFORM_INDICES: GLenum;\n    readonly UNIFORM_BLOCK_BINDING: GLenum;\n    readonly UNIFORM_BLOCK_DATA_SIZE: GLenum;\n    readonly UNIFORM_BLOCK_INDEX: GLenum;\n    readonly UNIFORM_BLOCK_REFERENCED_BY_FRAGMENT_SHADER: GLenum;\n    readonly UNIFORM_BLOCK_REFERENCED_BY_VERTEX_SHADER: GLenum;\n    readonly UNIFORM_BUFFER: GLenum;\n    readonly UNIFORM_BUFFER_BINDING: GLenum;\n    readonly UNIFORM_BUFFER_OFFSET_ALIGNMENT: GLenum;\n    readonly UNIFORM_BUFFER_SIZE: GLenum;\n    readonly UNIFORM_BUFFER_START: GLenum;\n    readonly UNIFORM_IS_ROW_MAJOR: GLenum;\n    readonly UNIFORM_MATRIX_STRIDE: GLenum;\n    readonly UNIFORM_OFFSET: GLenum;\n    readonly UNIFORM_SIZE: GLenum;\n    readonly UNIFORM_TYPE: GLenum;\n    readonly UNPACK_IMAGE_HEIGHT: GLenum;\n    readonly UNPACK_ROW_LENGTH: GLenum;\n    readonly UNPACK_SKIP_IMAGES: GLenum;\n    readonly UNPACK_SKIP_PIXELS: GLenum;\n    readonly UNPACK_SKIP_ROWS: GLenum;\n    readonly UNSIGNALED: GLenum;\n    readonly UNSIGNED_INT_10F_11F_11F_REV: GLenum;\n    readonly UNSIGNED_INT_24_8: GLenum;\n    readonly UNSIGNED_INT_2_10_10_10_REV: GLenum;\n    readonly UNSIGNED_INT_5_9_9_9_REV: GLenum;\n    readonly UNSIGNED_INT_SAMPLER_2D: GLenum;\n    readonly UNSIGNED_INT_SAMPLER_2D_ARRAY: GLenum;\n    readonly UNSIGNED_INT_SAMPLER_3D: GLenum;\n    readonly UNSIGNED_INT_SAMPLER_CUBE: GLenum;\n    readonly UNSIGNED_INT_VEC2: GLenum;\n    readonly UNSIGNED_INT_VEC3: GLenum;\n    readonly UNSIGNED_INT_VEC4: GLenum;\n    readonly UNSIGNED_NORMALIZED: GLenum;\n    readonly VERTEX_ARRAY_BINDING: GLenum;\n    readonly VERTEX_ATTRIB_ARRAY_DIVISOR: GLenum;\n    readonly VERTEX_ATTRIB_ARRAY_INTEGER: GLenum;\n    readonly WAIT_FAILED: GLenum;\n}\n\ninterface WebGL2RenderingContextOverloads {\n    bufferData(target: GLenum, size: GLsizeiptr, usage: GLenum): void;\n    bufferData(target: GLenum, srcData: BufferSource | null, usage: GLenum): void;\n    bufferData(target: GLenum, srcData: ArrayBufferView, usage: GLenum, srcOffset: GLuint, length?: GLuint): void;\n    bufferSubData(target: GLenum, dstByteOffset: GLintptr, srcData: BufferSource): void;\n    bufferSubData(target: GLenum, dstByteOffset: GLintptr, srcData: ArrayBufferView, srcOffset: GLuint, length?: GLuint): void;\n    compressedTexImage2D(target: GLenum, level: GLint, internalformat: GLenum, width: GLsizei, height: GLsizei, border: GLint, imageSize: GLsizei, offset: GLintptr): void;\n    compressedTexImage2D(target: GLenum, level: GLint, internalformat: GLenum, width: GLsizei, height: GLsizei, border: GLint, srcData: ArrayBufferView, srcOffset?: GLuint, srcLengthOverride?: GLuint): void;\n    compressedTexSubImage2D(target: GLenum, level: GLint, xoffset: GLint, yoffset: GLint, width: GLsizei, height: GLsizei, format: GLenum, imageSize: GLsizei, offset: GLintptr): void;\n    compressedTexSubImage2D(target: GLenum, level: GLint, xoffset: GLint, yoffset: GLint, width: GLsizei, height: GLsizei, format: GLenum, srcData: ArrayBufferView, srcOffset?: GLuint, srcLengthOverride?: GLuint): void;\n    readPixels(x: GLint, y: GLint, width: GLsizei, height: GLsizei, format: GLenum, type: GLenum, dstData: ArrayBufferView | null): void;\n    readPixels(x: GLint, y: GLint, width: GLsizei, height: GLsizei, format: GLenum, type: GLenum, offset: GLintptr): void;\n    readPixels(x: GLint, y: GLint, width: GLsizei, height: GLsizei, format: GLenum, type: GLenum, dstData: ArrayBufferView, dstOffset: GLuint): void;\n    texImage2D(target: GLenum, level: GLint, internalformat: GLint, width: GLsizei, height: GLsizei, border: GLint, format: GLenum, type: GLenum, pixels: ArrayBufferView | null): void;\n    texImage2D(target: GLenum, level: GLint, internalformat: GLint, format: GLenum, type: GLenum, source: TexImageSource): void;\n    texImage2D(target: GLenum, level: GLint, internalformat: GLint, width: GLsizei, height: GLsizei, border: GLint, format: GLenum, type: GLenum, pboOffset: GLintptr): void;\n    texImage2D(target: GLenum, level: GLint, internalformat: GLint, width: GLsizei, height: GLsizei, border: GLint, format: GLenum, type: GLenum, source: TexImageSource): void;\n    texImage2D(target: GLenum, level: GLint, internalformat: GLint, width: GLsizei, height: GLsizei, border: GLint, format: GLenum, type: GLenum, srcData: ArrayBufferView, srcOffset: GLuint): void;\n    texSubImage2D(target: GLenum, level: GLint, xoffset: GLint, yoffset: GLint, width: GLsizei, height: GLsizei, format: GLenum, type: GLenum, pixels: ArrayBufferView | null): void;\n    texSubImage2D(target: GLenum, level: GLint, xoffset: GLint, yoffset: GLint, format: GLenum, type: GLenum, source: TexImageSource): void;\n    texSubImage2D(target: GLenum, level: GLint, xoffset: GLint, yoffset: GLint, width: GLsizei, height: GLsizei, format: GLenum, type: GLenum, pboOffset: GLintptr): void;\n    texSubImage2D(target: GLenum, level: GLint, xoffset: GLint, yoffset: GLint, width: GLsizei, height: GLsizei, format: GLenum, type: GLenum, source: TexImageSource): void;\n    texSubImage2D(target: GLenum, level: GLint, xoffset: GLint, yoffset: GLint, width: GLsizei, height: GLsizei, format: GLenum, type: GLenum, srcData: ArrayBufferView, srcOffset: GLuint): void;\n    uniform1fv(location: WebGLUniformLocation | null, data: Float32List, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniform1iv(location: WebGLUniformLocation | null, data: Int32List, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniform2fv(location: WebGLUniformLocation | null, data: Float32List, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniform2iv(location: WebGLUniformLocation | null, data: Int32List, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniform3fv(location: WebGLUniformLocation | null, data: Float32List, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniform3iv(location: WebGLUniformLocation | null, data: Int32List, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniform4fv(location: WebGLUniformLocation | null, data: Float32List, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniform4iv(location: WebGLUniformLocation | null, data: Int32List, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniformMatrix2fv(location: WebGLUniformLocation | null, transpose: GLboolean, data: Float32List, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniformMatrix3fv(location: WebGLUniformLocation | null, transpose: GLboolean, data: Float32List, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniformMatrix4fv(location: WebGLUniformLocation | null, transpose: GLboolean, data: Float32List, srcOffset?: GLuint, srcLength?: GLuint): void;\n}\n\n/** Part of the WebGL API and represents the information returned by calling the WebGLRenderingContext.getActiveAttrib() and WebGLRenderingContext.getActiveUniform() methods. */\ninterface WebGLActiveInfo {\n    readonly name: string;\n    readonly size: GLint;\n    readonly type: GLenum;\n}\n\ndeclare var WebGLActiveInfo: {\n    prototype: WebGLActiveInfo;\n    new(): WebGLActiveInfo;\n};\n\n/** Part of the WebGL API and represents an opaque buffer object storing data such as vertices or colors. */\ninterface WebGLBuffer {\n}\n\ndeclare var WebGLBuffer: {\n    prototype: WebGLBuffer;\n    new(): WebGLBuffer;\n};\n\n/** The WebContextEvent interface is part of the WebGL API and is an interface for an event that is generated in response to a status change to the WebGL rendering context. */\ninterface WebGLContextEvent extends Event {\n    readonly statusMessage: string;\n}\n\ndeclare var WebGLContextEvent: {\n    prototype: WebGLContextEvent;\n    new(type: string, eventInit?: WebGLContextEventInit): WebGLContextEvent;\n};\n\n/** Part of the WebGL API and represents a collection of buffers that serve as a rendering destination. */\ninterface WebGLFramebuffer {\n}\n\ndeclare var WebGLFramebuffer: {\n    prototype: WebGLFramebuffer;\n    new(): WebGLFramebuffer;\n};\n\n/** The WebGLProgram is part of the WebGL API and is a combination of two compiled WebGLShaders consisting of a vertex shader and a fragment shader (both written in GLSL). */\ninterface WebGLProgram {\n}\n\ndeclare var WebGLProgram: {\n    prototype: WebGLProgram;\n    new(): WebGLProgram;\n};\n\ninterface WebGLQuery {\n}\n\ndeclare var WebGLQuery: {\n    prototype: WebGLQuery;\n    new(): WebGLQuery;\n};\n\n/** Part of the WebGL API and represents a buffer that can contain an image, or can be source or target of an rendering operation. */\ninterface WebGLRenderbuffer {\n}\n\ndeclare var WebGLRenderbuffer: {\n    prototype: WebGLRenderbuffer;\n    new(): WebGLRenderbuffer;\n};\n\n/** Provides an interface to the OpenGL ES 2.0 graphics rendering context for the drawing surface of an HTML <canvas> element. */\ninterface WebGLRenderingContext extends WebGLRenderingContextBase, WebGLRenderingContextOverloads {\n}\n\ndeclare var WebGLRenderingContext: {\n    prototype: WebGLRenderingContext;\n    new(): WebGLRenderingContext;\n    readonly ACTIVE_ATTRIBUTES: GLenum;\n    readonly ACTIVE_TEXTURE: GLenum;\n    readonly ACTIVE_UNIFORMS: GLenum;\n    readonly ALIASED_LINE_WIDTH_RANGE: GLenum;\n    readonly ALIASED_POINT_SIZE_RANGE: GLenum;\n    readonly ALPHA: GLenum;\n    readonly ALPHA_BITS: GLenum;\n    readonly ALWAYS: GLenum;\n    readonly ARRAY_BUFFER: GLenum;\n    readonly ARRAY_BUFFER_BINDING: GLenum;\n    readonly ATTACHED_SHADERS: GLenum;\n    readonly BACK: GLenum;\n    readonly BLEND: GLenum;\n    readonly BLEND_COLOR: GLenum;\n    readonly BLEND_DST_ALPHA: GLenum;\n    readonly BLEND_DST_RGB: GLenum;\n    readonly BLEND_EQUATION: GLenum;\n    readonly BLEND_EQUATION_ALPHA: GLenum;\n    readonly BLEND_EQUATION_RGB: GLenum;\n    readonly BLEND_SRC_ALPHA: GLenum;\n    readonly BLEND_SRC_RGB: GLenum;\n    readonly BLUE_BITS: GLenum;\n    readonly BOOL: GLenum;\n    readonly BOOL_VEC2: GLenum;\n    readonly BOOL_VEC3: GLenum;\n    readonly BOOL_VEC4: GLenum;\n    readonly BROWSER_DEFAULT_WEBGL: GLenum;\n    readonly BUFFER_SIZE: GLenum;\n    readonly BUFFER_USAGE: GLenum;\n    readonly BYTE: GLenum;\n    readonly CCW: GLenum;\n    readonly CLAMP_TO_EDGE: GLenum;\n    readonly COLOR_ATTACHMENT0: GLenum;\n    readonly COLOR_BUFFER_BIT: GLenum;\n    readonly COLOR_CLEAR_VALUE: GLenum;\n    readonly COLOR_WRITEMASK: GLenum;\n    readonly COMPILE_STATUS: GLenum;\n    readonly COMPRESSED_TEXTURE_FORMATS: GLenum;\n    readonly CONSTANT_ALPHA: GLenum;\n    readonly CONSTANT_COLOR: GLenum;\n    readonly CONTEXT_LOST_WEBGL: GLenum;\n    readonly CULL_FACE: GLenum;\n    readonly CULL_FACE_MODE: GLenum;\n    readonly CURRENT_PROGRAM: GLenum;\n    readonly CURRENT_VERTEX_ATTRIB: GLenum;\n    readonly CW: GLenum;\n    readonly DECR: GLenum;\n    readonly DECR_WRAP: GLenum;\n    readonly DELETE_STATUS: GLenum;\n    readonly DEPTH_ATTACHMENT: GLenum;\n    readonly DEPTH_BITS: GLenum;\n    readonly DEPTH_BUFFER_BIT: GLenum;\n    readonly DEPTH_CLEAR_VALUE: GLenum;\n    readonly DEPTH_COMPONENT: GLenum;\n    readonly DEPTH_COMPONENT16: GLenum;\n    readonly DEPTH_FUNC: GLenum;\n    readonly DEPTH_RANGE: GLenum;\n    readonly DEPTH_STENCIL: GLenum;\n    readonly DEPTH_STENCIL_ATTACHMENT: GLenum;\n    readonly DEPTH_TEST: GLenum;\n    readonly DEPTH_WRITEMASK: GLenum;\n    readonly DITHER: GLenum;\n    readonly DONT_CARE: GLenum;\n    readonly DST_ALPHA: GLenum;\n    readonly DST_COLOR: GLenum;\n    readonly DYNAMIC_DRAW: GLenum;\n    readonly ELEMENT_ARRAY_BUFFER: GLenum;\n    readonly ELEMENT_ARRAY_BUFFER_BINDING: GLenum;\n    readonly EQUAL: GLenum;\n    readonly FASTEST: GLenum;\n    readonly FLOAT: GLenum;\n    readonly FLOAT_MAT2: GLenum;\n    readonly FLOAT_MAT3: GLenum;\n    readonly FLOAT_MAT4: GLenum;\n    readonly FLOAT_VEC2: GLenum;\n    readonly FLOAT_VEC3: GLenum;\n    readonly FLOAT_VEC4: GLenum;\n    readonly FRAGMENT_SHADER: GLenum;\n    readonly FRAMEBUFFER: GLenum;\n    readonly FRAMEBUFFER_ATTACHMENT_OBJECT_NAME: GLenum;\n    readonly FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE: GLenum;\n    readonly FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE: GLenum;\n    readonly FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL: GLenum;\n    readonly FRAMEBUFFER_BINDING: GLenum;\n    readonly FRAMEBUFFER_COMPLETE: GLenum;\n    readonly FRAMEBUFFER_INCOMPLETE_ATTACHMENT: GLenum;\n    readonly FRAMEBUFFER_INCOMPLETE_DIMENSIONS: GLenum;\n    readonly FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT: GLenum;\n    readonly FRAMEBUFFER_UNSUPPORTED: GLenum;\n    readonly FRONT: GLenum;\n    readonly FRONT_AND_BACK: GLenum;\n    readonly FRONT_FACE: GLenum;\n    readonly FUNC_ADD: GLenum;\n    readonly FUNC_REVERSE_SUBTRACT: GLenum;\n    readonly FUNC_SUBTRACT: GLenum;\n    readonly GENERATE_MIPMAP_HINT: GLenum;\n    readonly GEQUAL: GLenum;\n    readonly GREATER: GLenum;\n    readonly GREEN_BITS: GLenum;\n    readonly HIGH_FLOAT: GLenum;\n    readonly HIGH_INT: GLenum;\n    readonly IMPLEMENTATION_COLOR_READ_FORMAT: GLenum;\n    readonly IMPLEMENTATION_COLOR_READ_TYPE: GLenum;\n    readonly INCR: GLenum;\n    readonly INCR_WRAP: GLenum;\n    readonly INT: GLenum;\n    readonly INT_VEC2: GLenum;\n    readonly INT_VEC3: GLenum;\n    readonly INT_VEC4: GLenum;\n    readonly INVALID_ENUM: GLenum;\n    readonly INVALID_FRAMEBUFFER_OPERATION: GLenum;\n    readonly INVALID_OPERATION: GLenum;\n    readonly INVALID_VALUE: GLenum;\n    readonly INVERT: GLenum;\n    readonly KEEP: GLenum;\n    readonly LEQUAL: GLenum;\n    readonly LESS: GLenum;\n    readonly LINEAR: GLenum;\n    readonly LINEAR_MIPMAP_LINEAR: GLenum;\n    readonly LINEAR_MIPMAP_NEAREST: GLenum;\n    readonly LINES: GLenum;\n    readonly LINE_LOOP: GLenum;\n    readonly LINE_STRIP: GLenum;\n    readonly LINE_WIDTH: GLenum;\n    readonly LINK_STATUS: GLenum;\n    readonly LOW_FLOAT: GLenum;\n    readonly LOW_INT: GLenum;\n    readonly LUMINANCE: GLenum;\n    readonly LUMINANCE_ALPHA: GLenum;\n    readonly MAX_COMBINED_TEXTURE_IMAGE_UNITS: GLenum;\n    readonly MAX_CUBE_MAP_TEXTURE_SIZE: GLenum;\n    readonly MAX_FRAGMENT_UNIFORM_VECTORS: GLenum;\n    readonly MAX_RENDERBUFFER_SIZE: GLenum;\n    readonly MAX_TEXTURE_IMAGE_UNITS: GLenum;\n    readonly MAX_TEXTURE_SIZE: GLenum;\n    readonly MAX_VARYING_VECTORS: GLenum;\n    readonly MAX_VERTEX_ATTRIBS: GLenum;\n    readonly MAX_VERTEX_TEXTURE_IMAGE_UNITS: GLenum;\n    readonly MAX_VERTEX_UNIFORM_VECTORS: GLenum;\n    readonly MAX_VIEWPORT_DIMS: GLenum;\n    readonly MEDIUM_FLOAT: GLenum;\n    readonly MEDIUM_INT: GLenum;\n    readonly MIRRORED_REPEAT: GLenum;\n    readonly NEAREST: GLenum;\n    readonly NEAREST_MIPMAP_LINEAR: GLenum;\n    readonly NEAREST_MIPMAP_NEAREST: GLenum;\n    readonly NEVER: GLenum;\n    readonly NICEST: GLenum;\n    readonly NONE: GLenum;\n    readonly NOTEQUAL: GLenum;\n    readonly NO_ERROR: GLenum;\n    readonly ONE: GLenum;\n    readonly ONE_MINUS_CONSTANT_ALPHA: GLenum;\n    readonly ONE_MINUS_CONSTANT_COLOR: GLenum;\n    readonly ONE_MINUS_DST_ALPHA: GLenum;\n    readonly ONE_MINUS_DST_COLOR: GLenum;\n    readonly ONE_MINUS_SRC_ALPHA: GLenum;\n    readonly ONE_MINUS_SRC_COLOR: GLenum;\n    readonly OUT_OF_MEMORY: GLenum;\n    readonly PACK_ALIGNMENT: GLenum;\n    readonly POINTS: GLenum;\n    readonly POLYGON_OFFSET_FACTOR: GLenum;\n    readonly POLYGON_OFFSET_FILL: GLenum;\n    readonly POLYGON_OFFSET_UNITS: GLenum;\n    readonly RED_BITS: GLenum;\n    readonly RENDERBUFFER: GLenum;\n    readonly RENDERBUFFER_ALPHA_SIZE: GLenum;\n    readonly RENDERBUFFER_BINDING: GLenum;\n    readonly RENDERBUFFER_BLUE_SIZE: GLenum;\n    readonly RENDERBUFFER_DEPTH_SIZE: GLenum;\n    readonly RENDERBUFFER_GREEN_SIZE: GLenum;\n    readonly RENDERBUFFER_HEIGHT: GLenum;\n    readonly RENDERBUFFER_INTERNAL_FORMAT: GLenum;\n    readonly RENDERBUFFER_RED_SIZE: GLenum;\n    readonly RENDERBUFFER_STENCIL_SIZE: GLenum;\n    readonly RENDERBUFFER_WIDTH: GLenum;\n    readonly RENDERER: GLenum;\n    readonly REPEAT: GLenum;\n    readonly REPLACE: GLenum;\n    readonly RGB: GLenum;\n    readonly RGB565: GLenum;\n    readonly RGB5_A1: GLenum;\n    readonly RGBA: GLenum;\n    readonly RGBA4: GLenum;\n    readonly SAMPLER_2D: GLenum;\n    readonly SAMPLER_CUBE: GLenum;\n    readonly SAMPLES: GLenum;\n    readonly SAMPLE_ALPHA_TO_COVERAGE: GLenum;\n    readonly SAMPLE_BUFFERS: GLenum;\n    readonly SAMPLE_COVERAGE: GLenum;\n    readonly SAMPLE_COVERAGE_INVERT: GLenum;\n    readonly SAMPLE_COVERAGE_VALUE: GLenum;\n    readonly SCISSOR_BOX: GLenum;\n    readonly SCISSOR_TEST: GLenum;\n    readonly SHADER_TYPE: GLenum;\n    readonly SHADING_LANGUAGE_VERSION: GLenum;\n    readonly SHORT: GLenum;\n    readonly SRC_ALPHA: GLenum;\n    readonly SRC_ALPHA_SATURATE: GLenum;\n    readonly SRC_COLOR: GLenum;\n    readonly STATIC_DRAW: GLenum;\n    readonly STENCIL_ATTACHMENT: GLenum;\n    readonly STENCIL_BACK_FAIL: GLenum;\n    readonly STENCIL_BACK_FUNC: GLenum;\n    readonly STENCIL_BACK_PASS_DEPTH_FAIL: GLenum;\n    readonly STENCIL_BACK_PASS_DEPTH_PASS: GLenum;\n    readonly STENCIL_BACK_REF: GLenum;\n    readonly STENCIL_BACK_VALUE_MASK: GLenum;\n    readonly STENCIL_BACK_WRITEMASK: GLenum;\n    readonly STENCIL_BITS: GLenum;\n    readonly STENCIL_BUFFER_BIT: GLenum;\n    readonly STENCIL_CLEAR_VALUE: GLenum;\n    readonly STENCIL_FAIL: GLenum;\n    readonly STENCIL_FUNC: GLenum;\n    readonly STENCIL_INDEX8: GLenum;\n    readonly STENCIL_PASS_DEPTH_FAIL: GLenum;\n    readonly STENCIL_PASS_DEPTH_PASS: GLenum;\n    readonly STENCIL_REF: GLenum;\n    readonly STENCIL_TEST: GLenum;\n    readonly STENCIL_VALUE_MASK: GLenum;\n    readonly STENCIL_WRITEMASK: GLenum;\n    readonly STREAM_DRAW: GLenum;\n    readonly SUBPIXEL_BITS: GLenum;\n    readonly TEXTURE: GLenum;\n    readonly TEXTURE0: GLenum;\n    readonly TEXTURE1: GLenum;\n    readonly TEXTURE10: GLenum;\n    readonly TEXTURE11: GLenum;\n    readonly TEXTURE12: GLenum;\n    readonly TEXTURE13: GLenum;\n    readonly TEXTURE14: GLenum;\n    readonly TEXTURE15: GLenum;\n    readonly TEXTURE16: GLenum;\n    readonly TEXTURE17: GLenum;\n    readonly TEXTURE18: GLenum;\n    readonly TEXTURE19: GLenum;\n    readonly TEXTURE2: GLenum;\n    readonly TEXTURE20: GLenum;\n    readonly TEXTURE21: GLenum;\n    readonly TEXTURE22: GLenum;\n    readonly TEXTURE23: GLenum;\n    readonly TEXTURE24: GLenum;\n    readonly TEXTURE25: GLenum;\n    readonly TEXTURE26: GLenum;\n    readonly TEXTURE27: GLenum;\n    readonly TEXTURE28: GLenum;\n    readonly TEXTURE29: GLenum;\n    readonly TEXTURE3: GLenum;\n    readonly TEXTURE30: GLenum;\n    readonly TEXTURE31: GLenum;\n    readonly TEXTURE4: GLenum;\n    readonly TEXTURE5: GLenum;\n    readonly TEXTURE6: GLenum;\n    readonly TEXTURE7: GLenum;\n    readonly TEXTURE8: GLenum;\n    readonly TEXTURE9: GLenum;\n    readonly TEXTURE_2D: GLenum;\n    readonly TEXTURE_BINDING_2D: GLenum;\n    readonly TEXTURE_BINDING_CUBE_MAP: GLenum;\n    readonly TEXTURE_CUBE_MAP: GLenum;\n    readonly TEXTURE_CUBE_MAP_NEGATIVE_X: GLenum;\n    readonly TEXTURE_CUBE_MAP_NEGATIVE_Y: GLenum;\n    readonly TEXTURE_CUBE_MAP_NEGATIVE_Z: GLenum;\n    readonly TEXTURE_CUBE_MAP_POSITIVE_X: GLenum;\n    readonly TEXTURE_CUBE_MAP_POSITIVE_Y: GLenum;\n    readonly TEXTURE_CUBE_MAP_POSITIVE_Z: GLenum;\n    readonly TEXTURE_MAG_FILTER: GLenum;\n    readonly TEXTURE_MIN_FILTER: GLenum;\n    readonly TEXTURE_WRAP_S: GLenum;\n    readonly TEXTURE_WRAP_T: GLenum;\n    readonly TRIANGLES: GLenum;\n    readonly TRIANGLE_FAN: GLenum;\n    readonly TRIANGLE_STRIP: GLenum;\n    readonly UNPACK_ALIGNMENT: GLenum;\n    readonly UNPACK_COLORSPACE_CONVERSION_WEBGL: GLenum;\n    readonly UNPACK_FLIP_Y_WEBGL: GLenum;\n    readonly UNPACK_PREMULTIPLY_ALPHA_WEBGL: GLenum;\n    readonly UNSIGNED_BYTE: GLenum;\n    readonly UNSIGNED_INT: GLenum;\n    readonly UNSIGNED_SHORT: GLenum;\n    readonly UNSIGNED_SHORT_4_4_4_4: GLenum;\n    readonly UNSIGNED_SHORT_5_5_5_1: GLenum;\n    readonly UNSIGNED_SHORT_5_6_5: GLenum;\n    readonly VALIDATE_STATUS: GLenum;\n    readonly VENDOR: GLenum;\n    readonly VERSION: GLenum;\n    readonly VERTEX_ATTRIB_ARRAY_BUFFER_BINDING: GLenum;\n    readonly VERTEX_ATTRIB_ARRAY_ENABLED: GLenum;\n    readonly VERTEX_ATTRIB_ARRAY_NORMALIZED: GLenum;\n    readonly VERTEX_ATTRIB_ARRAY_POINTER: GLenum;\n    readonly VERTEX_ATTRIB_ARRAY_SIZE: GLenum;\n    readonly VERTEX_ATTRIB_ARRAY_STRIDE: GLenum;\n    readonly VERTEX_ATTRIB_ARRAY_TYPE: GLenum;\n    readonly VERTEX_SHADER: GLenum;\n    readonly VIEWPORT: GLenum;\n    readonly ZERO: GLenum;\n};\n\ninterface WebGLRenderingContextBase {\n    readonly canvas: HTMLCanvasElement | OffscreenCanvas;\n    readonly drawingBufferHeight: GLsizei;\n    readonly drawingBufferWidth: GLsizei;\n    activeTexture(texture: GLenum): void;\n    attachShader(program: WebGLProgram, shader: WebGLShader): void;\n    bindAttribLocation(program: WebGLProgram, index: GLuint, name: string): void;\n    bindBuffer(target: GLenum, buffer: WebGLBuffer | null): void;\n    bindFramebuffer(target: GLenum, framebuffer: WebGLFramebuffer | null): void;\n    bindRenderbuffer(target: GLenum, renderbuffer: WebGLRenderbuffer | null): void;\n    bindTexture(target: GLenum, texture: WebGLTexture | null): void;\n    blendColor(red: GLclampf, green: GLclampf, blue: GLclampf, alpha: GLclampf): void;\n    blendEquation(mode: GLenum): void;\n    blendEquationSeparate(modeRGB: GLenum, modeAlpha: GLenum): void;\n    blendFunc(sfactor: GLenum, dfactor: GLenum): void;\n    blendFuncSeparate(srcRGB: GLenum, dstRGB: GLenum, srcAlpha: GLenum, dstAlpha: GLenum): void;\n    checkFramebufferStatus(target: GLenum): GLenum;\n    clear(mask: GLbitfield): void;\n    clearColor(red: GLclampf, green: GLclampf, blue: GLclampf, alpha: GLclampf): void;\n    clearDepth(depth: GLclampf): void;\n    clearStencil(s: GLint): void;\n    colorMask(red: GLboolean, green: GLboolean, blue: GLboolean, alpha: GLboolean): void;\n    compileShader(shader: WebGLShader): void;\n    copyTexImage2D(target: GLenum, level: GLint, internalformat: GLenum, x: GLint, y: GLint, width: GLsizei, height: GLsizei, border: GLint): void;\n    copyTexSubImage2D(target: GLenum, level: GLint, xoffset: GLint, yoffset: GLint, x: GLint, y: GLint, width: GLsizei, height: GLsizei): void;\n    createBuffer(): WebGLBuffer | null;\n    createFramebuffer(): WebGLFramebuffer | null;\n    createProgram(): WebGLProgram | null;\n    createRenderbuffer(): WebGLRenderbuffer | null;\n    createShader(type: GLenum): WebGLShader | null;\n    createTexture(): WebGLTexture | null;\n    cullFace(mode: GLenum): void;\n    deleteBuffer(buffer: WebGLBuffer | null): void;\n    deleteFramebuffer(framebuffer: WebGLFramebuffer | null): void;\n    deleteProgram(program: WebGLProgram | null): void;\n    deleteRenderbuffer(renderbuffer: WebGLRenderbuffer | null): void;\n    deleteShader(shader: WebGLShader | null): void;\n    deleteTexture(texture: WebGLTexture | null): void;\n    depthFunc(func: GLenum): void;\n    depthMask(flag: GLboolean): void;\n    depthRange(zNear: GLclampf, zFar: GLclampf): void;\n    detachShader(program: WebGLProgram, shader: WebGLShader): void;\n    disable(cap: GLenum): void;\n    disableVertexAttribArray(index: GLuint): void;\n    drawArrays(mode: GLenum, first: GLint, count: GLsizei): void;\n    drawElements(mode: GLenum, count: GLsizei, type: GLenum, offset: GLintptr): void;\n    enable(cap: GLenum): void;\n    enableVertexAttribArray(index: GLuint): void;\n    finish(): void;\n    flush(): void;\n    framebufferRenderbuffer(target: GLenum, attachment: GLenum, renderbuffertarget: GLenum, renderbuffer: WebGLRenderbuffer | null): void;\n    framebufferTexture2D(target: GLenum, attachment: GLenum, textarget: GLenum, texture: WebGLTexture | null, level: GLint): void;\n    frontFace(mode: GLenum): void;\n    generateMipmap(target: GLenum): void;\n    getActiveAttrib(program: WebGLProgram, index: GLuint): WebGLActiveInfo | null;\n    getActiveUniform(program: WebGLProgram, index: GLuint): WebGLActiveInfo | null;\n    getAttachedShaders(program: WebGLProgram): WebGLShader[] | null;\n    getAttribLocation(program: WebGLProgram, name: string): GLint;\n    getBufferParameter(target: GLenum, pname: GLenum): any;\n    getContextAttributes(): WebGLContextAttributes | null;\n    getError(): GLenum;\n    getExtension(extensionName: "EXT_blend_minmax"): EXT_blend_minmax | null;\n    getExtension(extensionName: "EXT_texture_filter_anisotropic"): EXT_texture_filter_anisotropic | null;\n    getExtension(extensionName: "EXT_frag_depth"): EXT_frag_depth | null;\n    getExtension(extensionName: "EXT_shader_texture_lod"): EXT_shader_texture_lod | null;\n    getExtension(extensionName: "EXT_sRGB"): EXT_sRGB | null;\n    getExtension(extensionName: "OES_vertex_array_object"): OES_vertex_array_object | null;\n    getExtension(extensionName: "WEBGL_color_buffer_float"): WEBGL_color_buffer_float | null;\n    getExtension(extensionName: "WEBGL_compressed_texture_astc"): WEBGL_compressed_texture_astc | null;\n    getExtension(extensionName: "WEBGL_compressed_texture_s3tc_srgb"): WEBGL_compressed_texture_s3tc_srgb | null;\n    getExtension(extensionName: "WEBGL_debug_shaders"): WEBGL_debug_shaders | null;\n    getExtension(extensionName: "WEBGL_draw_buffers"): WEBGL_draw_buffers | null;\n    getExtension(extensionName: "WEBGL_lose_context"): WEBGL_lose_context | null;\n    getExtension(extensionName: "WEBGL_depth_texture"): WEBGL_depth_texture | null;\n    getExtension(extensionName: "WEBGL_debug_renderer_info"): WEBGL_debug_renderer_info | null;\n    getExtension(extensionName: "WEBGL_compressed_texture_s3tc"): WEBGL_compressed_texture_s3tc | null;\n    getExtension(extensionName: "OES_texture_half_float_linear"): OES_texture_half_float_linear | null;\n    getExtension(extensionName: "OES_texture_half_float"): OES_texture_half_float | null;\n    getExtension(extensionName: "OES_texture_float_linear"): OES_texture_float_linear | null;\n    getExtension(extensionName: "OES_texture_float"): OES_texture_float | null;\n    getExtension(extensionName: "OES_standard_derivatives"): OES_standard_derivatives | null;\n    getExtension(extensionName: "OES_element_index_uint"): OES_element_index_uint | null;\n    getExtension(extensionName: "ANGLE_instanced_arrays"): ANGLE_instanced_arrays | null;\n    getExtension(extensionName: string): any;\n    getFramebufferAttachmentParameter(target: GLenum, attachment: GLenum, pname: GLenum): any;\n    getParameter(pname: GLenum): any;\n    getProgramInfoLog(program: WebGLProgram): string | null;\n    getProgramParameter(program: WebGLProgram, pname: GLenum): any;\n    getRenderbufferParameter(target: GLenum, pname: GLenum): any;\n    getShaderInfoLog(shader: WebGLShader): string | null;\n    getShaderParameter(shader: WebGLShader, pname: GLenum): any;\n    getShaderPrecisionFormat(shadertype: GLenum, precisiontype: GLenum): WebGLShaderPrecisionFormat | null;\n    getShaderSource(shader: WebGLShader): string | null;\n    getSupportedExtensions(): string[] | null;\n    getTexParameter(target: GLenum, pname: GLenum): any;\n    getUniform(program: WebGLProgram, location: WebGLUniformLocation): any;\n    getUniformLocation(program: WebGLProgram, name: string): WebGLUniformLocation | null;\n    getVertexAttrib(index: GLuint, pname: GLenum): any;\n    getVertexAttribOffset(index: GLuint, pname: GLenum): GLintptr;\n    hint(target: GLenum, mode: GLenum): void;\n    isBuffer(buffer: WebGLBuffer | null): GLboolean;\n    isContextLost(): boolean;\n    isEnabled(cap: GLenum): GLboolean;\n    isFramebuffer(framebuffer: WebGLFramebuffer | null): GLboolean;\n    isProgram(program: WebGLProgram | null): GLboolean;\n    isRenderbuffer(renderbuffer: WebGLRenderbuffer | null): GLboolean;\n    isShader(shader: WebGLShader | null): GLboolean;\n    isTexture(texture: WebGLTexture | null): GLboolean;\n    lineWidth(width: GLfloat): void;\n    linkProgram(program: WebGLProgram): void;\n    pixelStorei(pname: GLenum, param: GLint | GLboolean): void;\n    polygonOffset(factor: GLfloat, units: GLfloat): void;\n    renderbufferStorage(target: GLenum, internalformat: GLenum, width: GLsizei, height: GLsizei): void;\n    sampleCoverage(value: GLclampf, invert: GLboolean): void;\n    scissor(x: GLint, y: GLint, width: GLsizei, height: GLsizei): void;\n    shaderSource(shader: WebGLShader, source: string): void;\n    stencilFunc(func: GLenum, ref: GLint, mask: GLuint): void;\n    stencilFuncSeparate(face: GLenum, func: GLenum, ref: GLint, mask: GLuint): void;\n    stencilMask(mask: GLuint): void;\n    stencilMaskSeparate(face: GLenum, mask: GLuint): void;\n    stencilOp(fail: GLenum, zfail: GLenum, zpass: GLenum): void;\n    stencilOpSeparate(face: GLenum, fail: GLenum, zfail: GLenum, zpass: GLenum): void;\n    texParameterf(target: GLenum, pname: GLenum, param: GLfloat): void;\n    texParameteri(target: GLenum, pname: GLenum, param: GLint): void;\n    uniform1f(location: WebGLUniformLocation | null, x: GLfloat): void;\n    uniform1i(location: WebGLUniformLocation | null, x: GLint): void;\n    uniform2f(location: WebGLUniformLocation | null, x: GLfloat, y: GLfloat): void;\n    uniform2i(location: WebGLUniformLocation | null, x: GLint, y: GLint): void;\n    uniform3f(location: WebGLUniformLocation | null, x: GLfloat, y: GLfloat, z: GLfloat): void;\n    uniform3i(location: WebGLUniformLocation | null, x: GLint, y: GLint, z: GLint): void;\n    uniform4f(location: WebGLUniformLocation | null, x: GLfloat, y: GLfloat, z: GLfloat, w: GLfloat): void;\n    uniform4i(location: WebGLUniformLocation | null, x: GLint, y: GLint, z: GLint, w: GLint): void;\n    useProgram(program: WebGLProgram | null): void;\n    validateProgram(program: WebGLProgram): void;\n    vertexAttrib1f(index: GLuint, x: GLfloat): void;\n    vertexAttrib1fv(index: GLuint, values: Float32List): void;\n    vertexAttrib2f(index: GLuint, x: GLfloat, y: GLfloat): void;\n    vertexAttrib2fv(index: GLuint, values: Float32List): void;\n    vertexAttrib3f(index: GLuint, x: GLfloat, y: GLfloat, z: GLfloat): void;\n    vertexAttrib3fv(index: GLuint, values: Float32List): void;\n    vertexAttrib4f(index: GLuint, x: GLfloat, y: GLfloat, z: GLfloat, w: GLfloat): void;\n    vertexAttrib4fv(index: GLuint, values: Float32List): void;\n    vertexAttribPointer(index: GLuint, size: GLint, type: GLenum, normalized: GLboolean, stride: GLsizei, offset: GLintptr): void;\n    viewport(x: GLint, y: GLint, width: GLsizei, height: GLsizei): void;\n    readonly ACTIVE_ATTRIBUTES: GLenum;\n    readonly ACTIVE_TEXTURE: GLenum;\n    readonly ACTIVE_UNIFORMS: GLenum;\n    readonly ALIASED_LINE_WIDTH_RANGE: GLenum;\n    readonly ALIASED_POINT_SIZE_RANGE: GLenum;\n    readonly ALPHA: GLenum;\n    readonly ALPHA_BITS: GLenum;\n    readonly ALWAYS: GLenum;\n    readonly ARRAY_BUFFER: GLenum;\n    readonly ARRAY_BUFFER_BINDING: GLenum;\n    readonly ATTACHED_SHADERS: GLenum;\n    readonly BACK: GLenum;\n    readonly BLEND: GLenum;\n    readonly BLEND_COLOR: GLenum;\n    readonly BLEND_DST_ALPHA: GLenum;\n    readonly BLEND_DST_RGB: GLenum;\n    readonly BLEND_EQUATION: GLenum;\n    readonly BLEND_EQUATION_ALPHA: GLenum;\n    readonly BLEND_EQUATION_RGB: GLenum;\n    readonly BLEND_SRC_ALPHA: GLenum;\n    readonly BLEND_SRC_RGB: GLenum;\n    readonly BLUE_BITS: GLenum;\n    readonly BOOL: GLenum;\n    readonly BOOL_VEC2: GLenum;\n    readonly BOOL_VEC3: GLenum;\n    readonly BOOL_VEC4: GLenum;\n    readonly BROWSER_DEFAULT_WEBGL: GLenum;\n    readonly BUFFER_SIZE: GLenum;\n    readonly BUFFER_USAGE: GLenum;\n    readonly BYTE: GLenum;\n    readonly CCW: GLenum;\n    readonly CLAMP_TO_EDGE: GLenum;\n    readonly COLOR_ATTACHMENT0: GLenum;\n    readonly COLOR_BUFFER_BIT: GLenum;\n    readonly COLOR_CLEAR_VALUE: GLenum;\n    readonly COLOR_WRITEMASK: GLenum;\n    readonly COMPILE_STATUS: GLenum;\n    readonly COMPRESSED_TEXTURE_FORMATS: GLenum;\n    readonly CONSTANT_ALPHA: GLenum;\n    readonly CONSTANT_COLOR: GLenum;\n    readonly CONTEXT_LOST_WEBGL: GLenum;\n    readonly CULL_FACE: GLenum;\n    readonly CULL_FACE_MODE: GLenum;\n    readonly CURRENT_PROGRAM: GLenum;\n    readonly CURRENT_VERTEX_ATTRIB: GLenum;\n    readonly CW: GLenum;\n    readonly DECR: GLenum;\n    readonly DECR_WRAP: GLenum;\n    readonly DELETE_STATUS: GLenum;\n    readonly DEPTH_ATTACHMENT: GLenum;\n    readonly DEPTH_BITS: GLenum;\n    readonly DEPTH_BUFFER_BIT: GLenum;\n    readonly DEPTH_CLEAR_VALUE: GLenum;\n    readonly DEPTH_COMPONENT: GLenum;\n    readonly DEPTH_COMPONENT16: GLenum;\n    readonly DEPTH_FUNC: GLenum;\n    readonly DEPTH_RANGE: GLenum;\n    readonly DEPTH_STENCIL: GLenum;\n    readonly DEPTH_STENCIL_ATTACHMENT: GLenum;\n    readonly DEPTH_TEST: GLenum;\n    readonly DEPTH_WRITEMASK: GLenum;\n    readonly DITHER: GLenum;\n    readonly DONT_CARE: GLenum;\n    readonly DST_ALPHA: GLenum;\n    readonly DST_COLOR: GLenum;\n    readonly DYNAMIC_DRAW: GLenum;\n    readonly ELEMENT_ARRAY_BUFFER: GLenum;\n    readonly ELEMENT_ARRAY_BUFFER_BINDING: GLenum;\n    readonly EQUAL: GLenum;\n    readonly FASTEST: GLenum;\n    readonly FLOAT: GLenum;\n    readonly FLOAT_MAT2: GLenum;\n    readonly FLOAT_MAT3: GLenum;\n    readonly FLOAT_MAT4: GLenum;\n    readonly FLOAT_VEC2: GLenum;\n    readonly FLOAT_VEC3: GLenum;\n    readonly FLOAT_VEC4: GLenum;\n    readonly FRAGMENT_SHADER: GLenum;\n    readonly FRAMEBUFFER: GLenum;\n    readonly FRAMEBUFFER_ATTACHMENT_OBJECT_NAME: GLenum;\n    readonly FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE: GLenum;\n    readonly FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE: GLenum;\n    readonly FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL: GLenum;\n    readonly FRAMEBUFFER_BINDING: GLenum;\n    readonly FRAMEBUFFER_COMPLETE: GLenum;\n    readonly FRAMEBUFFER_INCOMPLETE_ATTACHMENT: GLenum;\n    readonly FRAMEBUFFER_INCOMPLETE_DIMENSIONS: GLenum;\n    readonly FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT: GLenum;\n    readonly FRAMEBUFFER_UNSUPPORTED: GLenum;\n    readonly FRONT: GLenum;\n    readonly FRONT_AND_BACK: GLenum;\n    readonly FRONT_FACE: GLenum;\n    readonly FUNC_ADD: GLenum;\n    readonly FUNC_REVERSE_SUBTRACT: GLenum;\n    readonly FUNC_SUBTRACT: GLenum;\n    readonly GENERATE_MIPMAP_HINT: GLenum;\n    readonly GEQUAL: GLenum;\n    readonly GREATER: GLenum;\n    readonly GREEN_BITS: GLenum;\n    readonly HIGH_FLOAT: GLenum;\n    readonly HIGH_INT: GLenum;\n    readonly IMPLEMENTATION_COLOR_READ_FORMAT: GLenum;\n    readonly IMPLEMENTATION_COLOR_READ_TYPE: GLenum;\n    readonly INCR: GLenum;\n    readonly INCR_WRAP: GLenum;\n    readonly INT: GLenum;\n    readonly INT_VEC2: GLenum;\n    readonly INT_VEC3: GLenum;\n    readonly INT_VEC4: GLenum;\n    readonly INVALID_ENUM: GLenum;\n    readonly INVALID_FRAMEBUFFER_OPERATION: GLenum;\n    readonly INVALID_OPERATION: GLenum;\n    readonly INVALID_VALUE: GLenum;\n    readonly INVERT: GLenum;\n    readonly KEEP: GLenum;\n    readonly LEQUAL: GLenum;\n    readonly LESS: GLenum;\n    readonly LINEAR: GLenum;\n    readonly LINEAR_MIPMAP_LINEAR: GLenum;\n    readonly LINEAR_MIPMAP_NEAREST: GLenum;\n    readonly LINES: GLenum;\n    readonly LINE_LOOP: GLenum;\n    readonly LINE_STRIP: GLenum;\n    readonly LINE_WIDTH: GLenum;\n    readonly LINK_STATUS: GLenum;\n    readonly LOW_FLOAT: GLenum;\n    readonly LOW_INT: GLenum;\n    readonly LUMINANCE: GLenum;\n    readonly LUMINANCE_ALPHA: GLenum;\n    readonly MAX_COMBINED_TEXTURE_IMAGE_UNITS: GLenum;\n    readonly MAX_CUBE_MAP_TEXTURE_SIZE: GLenum;\n    readonly MAX_FRAGMENT_UNIFORM_VECTORS: GLenum;\n    readonly MAX_RENDERBUFFER_SIZE: GLenum;\n    readonly MAX_TEXTURE_IMAGE_UNITS: GLenum;\n    readonly MAX_TEXTURE_SIZE: GLenum;\n    readonly MAX_VARYING_VECTORS: GLenum;\n    readonly MAX_VERTEX_ATTRIBS: GLenum;\n    readonly MAX_VERTEX_TEXTURE_IMAGE_UNITS: GLenum;\n    readonly MAX_VERTEX_UNIFORM_VECTORS: GLenum;\n    readonly MAX_VIEWPORT_DIMS: GLenum;\n    readonly MEDIUM_FLOAT: GLenum;\n    readonly MEDIUM_INT: GLenum;\n    readonly MIRRORED_REPEAT: GLenum;\n    readonly NEAREST: GLenum;\n    readonly NEAREST_MIPMAP_LINEAR: GLenum;\n    readonly NEAREST_MIPMAP_NEAREST: GLenum;\n    readonly NEVER: GLenum;\n    readonly NICEST: GLenum;\n    readonly NONE: GLenum;\n    readonly NOTEQUAL: GLenum;\n    readonly NO_ERROR: GLenum;\n    readonly ONE: GLenum;\n    readonly ONE_MINUS_CONSTANT_ALPHA: GLenum;\n    readonly ONE_MINUS_CONSTANT_COLOR: GLenum;\n    readonly ONE_MINUS_DST_ALPHA: GLenum;\n    readonly ONE_MINUS_DST_COLOR: GLenum;\n    readonly ONE_MINUS_SRC_ALPHA: GLenum;\n    readonly ONE_MINUS_SRC_COLOR: GLenum;\n    readonly OUT_OF_MEMORY: GLenum;\n    readonly PACK_ALIGNMENT: GLenum;\n    readonly POINTS: GLenum;\n    readonly POLYGON_OFFSET_FACTOR: GLenum;\n    readonly POLYGON_OFFSET_FILL: GLenum;\n    readonly POLYGON_OFFSET_UNITS: GLenum;\n    readonly RED_BITS: GLenum;\n    readonly RENDERBUFFER: GLenum;\n    readonly RENDERBUFFER_ALPHA_SIZE: GLenum;\n    readonly RENDERBUFFER_BINDING: GLenum;\n    readonly RENDERBUFFER_BLUE_SIZE: GLenum;\n    readonly RENDERBUFFER_DEPTH_SIZE: GLenum;\n    readonly RENDERBUFFER_GREEN_SIZE: GLenum;\n    readonly RENDERBUFFER_HEIGHT: GLenum;\n    readonly RENDERBUFFER_INTERNAL_FORMAT: GLenum;\n    readonly RENDERBUFFER_RED_SIZE: GLenum;\n    readonly RENDERBUFFER_STENCIL_SIZE: GLenum;\n    readonly RENDERBUFFER_WIDTH: GLenum;\n    readonly RENDERER: GLenum;\n    readonly REPEAT: GLenum;\n    readonly REPLACE: GLenum;\n    readonly RGB: GLenum;\n    readonly RGB565: GLenum;\n    readonly RGB5_A1: GLenum;\n    readonly RGBA: GLenum;\n    readonly RGBA4: GLenum;\n    readonly SAMPLER_2D: GLenum;\n    readonly SAMPLER_CUBE: GLenum;\n    readonly SAMPLES: GLenum;\n    readonly SAMPLE_ALPHA_TO_COVERAGE: GLenum;\n    readonly SAMPLE_BUFFERS: GLenum;\n    readonly SAMPLE_COVERAGE: GLenum;\n    readonly SAMPLE_COVERAGE_INVERT: GLenum;\n    readonly SAMPLE_COVERAGE_VALUE: GLenum;\n    readonly SCISSOR_BOX: GLenum;\n    readonly SCISSOR_TEST: GLenum;\n    readonly SHADER_TYPE: GLenum;\n    readonly SHADING_LANGUAGE_VERSION: GLenum;\n    readonly SHORT: GLenum;\n    readonly SRC_ALPHA: GLenum;\n    readonly SRC_ALPHA_SATURATE: GLenum;\n    readonly SRC_COLOR: GLenum;\n    readonly STATIC_DRAW: GLenum;\n    readonly STENCIL_ATTACHMENT: GLenum;\n    readonly STENCIL_BACK_FAIL: GLenum;\n    readonly STENCIL_BACK_FUNC: GLenum;\n    readonly STENCIL_BACK_PASS_DEPTH_FAIL: GLenum;\n    readonly STENCIL_BACK_PASS_DEPTH_PASS: GLenum;\n    readonly STENCIL_BACK_REF: GLenum;\n    readonly STENCIL_BACK_VALUE_MASK: GLenum;\n    readonly STENCIL_BACK_WRITEMASK: GLenum;\n    readonly STENCIL_BITS: GLenum;\n    readonly STENCIL_BUFFER_BIT: GLenum;\n    readonly STENCIL_CLEAR_VALUE: GLenum;\n    readonly STENCIL_FAIL: GLenum;\n    readonly STENCIL_FUNC: GLenum;\n    readonly STENCIL_INDEX8: GLenum;\n    readonly STENCIL_PASS_DEPTH_FAIL: GLenum;\n    readonly STENCIL_PASS_DEPTH_PASS: GLenum;\n    readonly STENCIL_REF: GLenum;\n    readonly STENCIL_TEST: GLenum;\n    readonly STENCIL_VALUE_MASK: GLenum;\n    readonly STENCIL_WRITEMASK: GLenum;\n    readonly STREAM_DRAW: GLenum;\n    readonly SUBPIXEL_BITS: GLenum;\n    readonly TEXTURE: GLenum;\n    readonly TEXTURE0: GLenum;\n    readonly TEXTURE1: GLenum;\n    readonly TEXTURE10: GLenum;\n    readonly TEXTURE11: GLenum;\n    readonly TEXTURE12: GLenum;\n    readonly TEXTURE13: GLenum;\n    readonly TEXTURE14: GLenum;\n    readonly TEXTURE15: GLenum;\n    readonly TEXTURE16: GLenum;\n    readonly TEXTURE17: GLenum;\n    readonly TEXTURE18: GLenum;\n    readonly TEXTURE19: GLenum;\n    readonly TEXTURE2: GLenum;\n    readonly TEXTURE20: GLenum;\n    readonly TEXTURE21: GLenum;\n    readonly TEXTURE22: GLenum;\n    readonly TEXTURE23: GLenum;\n    readonly TEXTURE24: GLenum;\n    readonly TEXTURE25: GLenum;\n    readonly TEXTURE26: GLenum;\n    readonly TEXTURE27: GLenum;\n    readonly TEXTURE28: GLenum;\n    readonly TEXTURE29: GLenum;\n    readonly TEXTURE3: GLenum;\n    readonly TEXTURE30: GLenum;\n    readonly TEXTURE31: GLenum;\n    readonly TEXTURE4: GLenum;\n    readonly TEXTURE5: GLenum;\n    readonly TEXTURE6: GLenum;\n    readonly TEXTURE7: GLenum;\n    readonly TEXTURE8: GLenum;\n    readonly TEXTURE9: GLenum;\n    readonly TEXTURE_2D: GLenum;\n    readonly TEXTURE_BINDING_2D: GLenum;\n    readonly TEXTURE_BINDING_CUBE_MAP: GLenum;\n    readonly TEXTURE_CUBE_MAP: GLenum;\n    readonly TEXTURE_CUBE_MAP_NEGATIVE_X: GLenum;\n    readonly TEXTURE_CUBE_MAP_NEGATIVE_Y: GLenum;\n    readonly TEXTURE_CUBE_MAP_NEGATIVE_Z: GLenum;\n    readonly TEXTURE_CUBE_MAP_POSITIVE_X: GLenum;\n    readonly TEXTURE_CUBE_MAP_POSITIVE_Y: GLenum;\n    readonly TEXTURE_CUBE_MAP_POSITIVE_Z: GLenum;\n    readonly TEXTURE_MAG_FILTER: GLenum;\n    readonly TEXTURE_MIN_FILTER: GLenum;\n    readonly TEXTURE_WRAP_S: GLenum;\n    readonly TEXTURE_WRAP_T: GLenum;\n    readonly TRIANGLES: GLenum;\n    readonly TRIANGLE_FAN: GLenum;\n    readonly TRIANGLE_STRIP: GLenum;\n    readonly UNPACK_ALIGNMENT: GLenum;\n    readonly UNPACK_COLORSPACE_CONVERSION_WEBGL: GLenum;\n    readonly UNPACK_FLIP_Y_WEBGL: GLenum;\n    readonly UNPACK_PREMULTIPLY_ALPHA_WEBGL: GLenum;\n    readonly UNSIGNED_BYTE: GLenum;\n    readonly UNSIGNED_INT: GLenum;\n    readonly UNSIGNED_SHORT: GLenum;\n    readonly UNSIGNED_SHORT_4_4_4_4: GLenum;\n    readonly UNSIGNED_SHORT_5_5_5_1: GLenum;\n    readonly UNSIGNED_SHORT_5_6_5: GLenum;\n    readonly VALIDATE_STATUS: GLenum;\n    readonly VENDOR: GLenum;\n    readonly VERSION: GLenum;\n    readonly VERTEX_ATTRIB_ARRAY_BUFFER_BINDING: GLenum;\n    readonly VERTEX_ATTRIB_ARRAY_ENABLED: GLenum;\n    readonly VERTEX_ATTRIB_ARRAY_NORMALIZED: GLenum;\n    readonly VERTEX_ATTRIB_ARRAY_POINTER: GLenum;\n    readonly VERTEX_ATTRIB_ARRAY_SIZE: GLenum;\n    readonly VERTEX_ATTRIB_ARRAY_STRIDE: GLenum;\n    readonly VERTEX_ATTRIB_ARRAY_TYPE: GLenum;\n    readonly VERTEX_SHADER: GLenum;\n    readonly VIEWPORT: GLenum;\n    readonly ZERO: GLenum;\n}\n\ninterface WebGLRenderingContextOverloads {\n    bufferData(target: GLenum, size: GLsizeiptr, usage: GLenum): void;\n    bufferData(target: GLenum, data: BufferSource | null, usage: GLenum): void;\n    bufferSubData(target: GLenum, offset: GLintptr, data: BufferSource): void;\n    compressedTexImage2D(target: GLenum, level: GLint, internalformat: GLenum, width: GLsizei, height: GLsizei, border: GLint, data: ArrayBufferView): void;\n    compressedTexSubImage2D(target: GLenum, level: GLint, xoffset: GLint, yoffset: GLint, width: GLsizei, height: GLsizei, format: GLenum, data: ArrayBufferView): void;\n    readPixels(x: GLint, y: GLint, width: GLsizei, height: GLsizei, format: GLenum, type: GLenum, pixels: ArrayBufferView | null): void;\n    texImage2D(target: GLenum, level: GLint, internalformat: GLint, width: GLsizei, height: GLsizei, border: GLint, format: GLenum, type: GLenum, pixels: ArrayBufferView | null): void;\n    texImage2D(target: GLenum, level: GLint, internalformat: GLint, format: GLenum, type: GLenum, source: TexImageSource): void;\n    texSubImage2D(target: GLenum, level: GLint, xoffset: GLint, yoffset: GLint, width: GLsizei, height: GLsizei, format: GLenum, type: GLenum, pixels: ArrayBufferView | null): void;\n    texSubImage2D(target: GLenum, level: GLint, xoffset: GLint, yoffset: GLint, format: GLenum, type: GLenum, source: TexImageSource): void;\n    uniform1fv(location: WebGLUniformLocation | null, v: Float32List): void;\n    uniform1iv(location: WebGLUniformLocation | null, v: Int32List): void;\n    uniform2fv(location: WebGLUniformLocation | null, v: Float32List): void;\n    uniform2iv(location: WebGLUniformLocation | null, v: Int32List): void;\n    uniform3fv(location: WebGLUniformLocation | null, v: Float32List): void;\n    uniform3iv(location: WebGLUniformLocation | null, v: Int32List): void;\n    uniform4fv(location: WebGLUniformLocation | null, v: Float32List): void;\n    uniform4iv(location: WebGLUniformLocation | null, v: Int32List): void;\n    uniformMatrix2fv(location: WebGLUniformLocation | null, transpose: GLboolean, value: Float32List): void;\n    uniformMatrix3fv(location: WebGLUniformLocation | null, transpose: GLboolean, value: Float32List): void;\n    uniformMatrix4fv(location: WebGLUniformLocation | null, transpose: GLboolean, value: Float32List): void;\n}\n\ninterface WebGLSampler {\n}\n\ndeclare var WebGLSampler: {\n    prototype: WebGLSampler;\n    new(): WebGLSampler;\n};\n\n/** The WebGLShader is part of the WebGL API and can either be a vertex or a fragment shader. A WebGLProgram requires both types of shaders. */\ninterface WebGLShader {\n}\n\ndeclare var WebGLShader: {\n    prototype: WebGLShader;\n    new(): WebGLShader;\n};\n\n/** Part of the WebGL API and represents the information returned by calling the WebGLRenderingContext.getShaderPrecisionFormat() method. */\ninterface WebGLShaderPrecisionFormat {\n    readonly precision: GLint;\n    readonly rangeMax: GLint;\n    readonly rangeMin: GLint;\n}\n\ndeclare var WebGLShaderPrecisionFormat: {\n    prototype: WebGLShaderPrecisionFormat;\n    new(): WebGLShaderPrecisionFormat;\n};\n\ninterface WebGLSync {\n}\n\ndeclare var WebGLSync: {\n    prototype: WebGLSync;\n    new(): WebGLSync;\n};\n\n/** Part of the WebGL API and represents an opaque texture object providing storage and state for texturing operations. */\ninterface WebGLTexture {\n}\n\ndeclare var WebGLTexture: {\n    prototype: WebGLTexture;\n    new(): WebGLTexture;\n};\n\ninterface WebGLTransformFeedback {\n}\n\ndeclare var WebGLTransformFeedback: {\n    prototype: WebGLTransformFeedback;\n    new(): WebGLTransformFeedback;\n};\n\n/** Part of the WebGL API and represents the location of a uniform variable in a shader program. */\ninterface WebGLUniformLocation {\n}\n\ndeclare var WebGLUniformLocation: {\n    prototype: WebGLUniformLocation;\n    new(): WebGLUniformLocation;\n};\n\ninterface WebGLVertexArrayObject {\n}\n\ndeclare var WebGLVertexArrayObject: {\n    prototype: WebGLVertexArrayObject;\n    new(): WebGLVertexArrayObject;\n};\n\ninterface WebGLVertexArrayObjectOES {\n}\n\ninterface WebKitPoint {\n    x: number;\n    y: number;\n}\n\ndeclare var WebKitPoint: {\n    prototype: WebKitPoint;\n    new(x?: number, y?: number): WebKitPoint;\n};\n\ninterface WebSocketEventMap {\n    "close": CloseEvent;\n    "error": Event;\n    "message": MessageEvent;\n    "open": Event;\n}\n\n/** Provides the API for creating and managing a WebSocket connection to a server, as well as for sending and receiving data on the connection. */\ninterface WebSocket extends EventTarget {\n    /**\n     * Returns a string that indicates how binary data from the WebSocket object is exposed to scripts:\n     *\n     * Can be set, to change how binary data is returned. The default is "blob".\n     */\n    binaryType: BinaryType;\n    /**\n     * Returns the number of bytes of application data (UTF-8 text and binary data) that have been queued using send() but not yet been transmitted to the network.\n     *\n     * If the WebSocket connection is closed, this attribute\'s value will only increase with each call to the send() method. (The number does not reset to zero once the connection closes.)\n     */\n    readonly bufferedAmount: number;\n    /**\n     * Returns the extensions selected by the server, if any.\n     */\n    readonly extensions: string;\n    onclose: ((this: WebSocket, ev: CloseEvent) => any) | null;\n    onerror: ((this: WebSocket, ev: Event) => any) | null;\n    onmessage: ((this: WebSocket, ev: MessageEvent) => any) | null;\n    onopen: ((this: WebSocket, ev: Event) => any) | null;\n    /**\n     * Returns the subprotocol selected by the server, if any. It can be used in conjunction with the array form of the constructor\'s second argument to perform subprotocol negotiation.\n     */\n    readonly protocol: string;\n    /**\n     * Returns the state of the WebSocket object\'s connection. It can have the values described below.\n     */\n    readonly readyState: number;\n    /**\n     * Returns the URL that was used to establish the WebSocket connection.\n     */\n    readonly url: string;\n    /**\n     * Closes the WebSocket connection, optionally using code as the the WebSocket connection close code and reason as the the WebSocket connection close reason.\n     */\n    close(code?: number, reason?: string): void;\n    /**\n     * Transmits data using the WebSocket connection. data can be a string, a Blob, an ArrayBuffer, or an ArrayBufferView.\n     */\n    send(data: string | ArrayBufferLike | Blob | ArrayBufferView): void;\n    readonly CLOSED: number;\n    readonly CLOSING: number;\n    readonly CONNECTING: number;\n    readonly OPEN: number;\n    addEventListener<K extends keyof WebSocketEventMap>(type: K, listener: (this: WebSocket, ev: WebSocketEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof WebSocketEventMap>(type: K, listener: (this: WebSocket, ev: WebSocketEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var WebSocket: {\n    prototype: WebSocket;\n    new(url: string, protocols?: string | string[]): WebSocket;\n    readonly CLOSED: number;\n    readonly CLOSING: number;\n    readonly CONNECTING: number;\n    readonly OPEN: number;\n};\n\n/** Events that occur due to the user moving a mouse wheel or similar input device. */\ninterface WheelEvent extends MouseEvent {\n    readonly deltaMode: number;\n    readonly deltaX: number;\n    readonly deltaY: number;\n    readonly deltaZ: number;\n    readonly DOM_DELTA_LINE: number;\n    readonly DOM_DELTA_PAGE: number;\n    readonly DOM_DELTA_PIXEL: number;\n}\n\ndeclare var WheelEvent: {\n    prototype: WheelEvent;\n    new(type: string, eventInitDict?: WheelEventInit): WheelEvent;\n    readonly DOM_DELTA_LINE: number;\n    readonly DOM_DELTA_PAGE: number;\n    readonly DOM_DELTA_PIXEL: number;\n};\n\ninterface WindowEventMap extends GlobalEventHandlersEventMap, WindowEventHandlersEventMap {\n    "abort": UIEvent;\n    "afterprint": Event;\n    "beforeprint": Event;\n    "beforeunload": BeforeUnloadEvent;\n    "blur": FocusEvent;\n    "canplay": Event;\n    "canplaythrough": Event;\n    "change": Event;\n    "click": MouseEvent;\n    "compassneedscalibration": Event;\n    "contextmenu": MouseEvent;\n    "dblclick": MouseEvent;\n    "devicemotion": DeviceMotionEvent;\n    "deviceorientation": DeviceOrientationEvent;\n    "deviceorientationabsolute": DeviceOrientationEvent;\n    "drag": DragEvent;\n    "dragend": DragEvent;\n    "dragenter": DragEvent;\n    "dragleave": DragEvent;\n    "dragover": DragEvent;\n    "dragstart": DragEvent;\n    "drop": DragEvent;\n    "durationchange": Event;\n    "emptied": Event;\n    "ended": Event;\n    "error": ErrorEvent;\n    "focus": FocusEvent;\n    "gamepadconnected": GamepadEvent;\n    "gamepaddisconnected": GamepadEvent;\n    "hashchange": HashChangeEvent;\n    "input": Event;\n    "invalid": Event;\n    "keydown": KeyboardEvent;\n    "keypress": KeyboardEvent;\n    "keyup": KeyboardEvent;\n    "load": Event;\n    "loadeddata": Event;\n    "loadedmetadata": Event;\n    "loadstart": Event;\n    "message": MessageEvent;\n    "mousedown": MouseEvent;\n    "mouseenter": MouseEvent;\n    "mouseleave": MouseEvent;\n    "mousemove": MouseEvent;\n    "mouseout": MouseEvent;\n    "mouseover": MouseEvent;\n    "mouseup": MouseEvent;\n    "mousewheel": Event;\n    "offline": Event;\n    "online": Event;\n    "orientationchange": Event;\n    "pagehide": PageTransitionEvent;\n    "pageshow": PageTransitionEvent;\n    "pause": Event;\n    "play": Event;\n    "playing": Event;\n    "popstate": PopStateEvent;\n    "progress": ProgressEvent<Window>;\n    "ratechange": Event;\n    "readystatechange": ProgressEvent<Window>;\n    "reset": Event;\n    "resize": UIEvent;\n    "scroll": Event;\n    "seeked": Event;\n    "seeking": Event;\n    "select": Event;\n    "stalled": Event;\n    "storage": StorageEvent;\n    "submit": Event;\n    "suspend": Event;\n    "timeupdate": Event;\n    "unload": Event;\n    "volumechange": Event;\n    "vrdisplayactivate": Event;\n    "vrdisplayblur": Event;\n    "vrdisplayconnect": Event;\n    "vrdisplaydeactivate": Event;\n    "vrdisplaydisconnect": Event;\n    "vrdisplaypresentchange": Event;\n    "waiting": Event;\n}\n\n/** A window containing a DOM document; the document property points to the DOM document loaded in that window. */\ninterface Window extends EventTarget, AnimationFrameProvider, GlobalEventHandlers, WindowEventHandlers, WindowLocalStorage, WindowOrWorkerGlobalScope, WindowSessionStorage {\n    readonly applicationCache: ApplicationCache;\n    readonly clientInformation: Navigator;\n    readonly closed: boolean;\n    customElements: CustomElementRegistry;\n    defaultStatus: string;\n    readonly devicePixelRatio: number;\n    readonly doNotTrack: string;\n    readonly document: Document;\n    /** @deprecated */\n    readonly event: Event | undefined;\n    /** @deprecated */\n    readonly external: External;\n    readonly frameElement: Element | null;\n    readonly frames: Window;\n    readonly history: History;\n    readonly innerHeight: number;\n    readonly innerWidth: number;\n    readonly length: number;\n    location: Location;\n    readonly locationbar: BarProp;\n    readonly menubar: BarProp;\n    readonly msContentScript: ExtensionScriptApis;\n    name: string;\n    readonly navigator: Navigator;\n    offscreenBuffering: string | boolean;\n    oncompassneedscalibration: ((this: Window, ev: Event) => any) | null;\n    ondevicemotion: ((this: Window, ev: DeviceMotionEvent) => any) | null;\n    ondeviceorientation: ((this: Window, ev: DeviceOrientationEvent) => any) | null;\n    ondeviceorientationabsolute: ((this: Window, ev: DeviceOrientationEvent) => any) | null;\n    ongamepadconnected: ((this: Window, ev: GamepadEvent) => any) | null;\n    ongamepaddisconnected: ((this: Window, ev: GamepadEvent) => any) | null;\n    onmousewheel: ((this: Window, ev: Event) => any) | null;\n    /** @deprecated */\n    onorientationchange: ((this: Window, ev: Event) => any) | null;\n    onreadystatechange: ((this: Window, ev: ProgressEvent<Window>) => any) | null;\n    onvrdisplayactivate: ((this: Window, ev: Event) => any) | null;\n    onvrdisplayblur: ((this: Window, ev: Event) => any) | null;\n    onvrdisplayconnect: ((this: Window, ev: Event) => any) | null;\n    onvrdisplaydeactivate: ((this: Window, ev: Event) => any) | null;\n    onvrdisplaydisconnect: ((this: Window, ev: Event) => any) | null;\n    onvrdisplaypresentchange: ((this: Window, ev: Event) => any) | null;\n    opener: WindowProxy | null;\n    /** @deprecated */\n    readonly orientation: string | number;\n    readonly outerHeight: number;\n    readonly outerWidth: number;\n    readonly pageXOffset: number;\n    readonly pageYOffset: number;\n    readonly parent: Window;\n    readonly personalbar: BarProp;\n    readonly screen: Screen;\n    readonly screenLeft: number;\n    readonly screenTop: number;\n    readonly screenX: number;\n    readonly screenY: number;\n    readonly scrollX: number;\n    readonly scrollY: number;\n    readonly scrollbars: BarProp;\n    readonly self: Window & typeof globalThis;\n    readonly speechSynthesis: SpeechSynthesis;\n    status: string;\n    readonly statusbar: BarProp;\n    readonly styleMedia: StyleMedia;\n    readonly toolbar: BarProp;\n    readonly top: Window;\n    readonly visualViewport: VisualViewport;\n    readonly window: Window & typeof globalThis;\n    alert(message?: any): void;\n    blur(): void;\n    /** @deprecated */\n    captureEvents(): void;\n    close(): void;\n    confirm(message?: string): boolean;\n    departFocus(navigationReason: NavigationReason, origin: FocusNavigationOrigin): void;\n    focus(): void;\n    getComputedStyle(elt: Element, pseudoElt?: string | null): CSSStyleDeclaration;\n    getMatchedCSSRules(elt: Element, pseudoElt?: string | null): CSSRuleList;\n    getSelection(): Selection | null;\n    matchMedia(query: string): MediaQueryList;\n    moveBy(x: number, y: number): void;\n    moveTo(x: number, y: number): void;\n    msWriteProfilerMark(profilerMarkName: string): void;\n    open(url?: string, target?: string, features?: string, replace?: boolean): Window | null;\n    postMessage(message: any, targetOrigin: string, transfer?: Transferable[]): void;\n    print(): void;\n    prompt(message?: string, _default?: string): string | null;\n    /** @deprecated */\n    releaseEvents(): void;\n    resizeBy(x: number, y: number): void;\n    resizeTo(width: number, height: number): void;\n    scroll(options?: ScrollToOptions): void;\n    scroll(x: number, y: number): void;\n    scrollBy(options?: ScrollToOptions): void;\n    scrollBy(x: number, y: number): void;\n    scrollTo(options?: ScrollToOptions): void;\n    scrollTo(x: number, y: number): void;\n    stop(): void;\n    webkitCancelAnimationFrame(handle: number): void;\n    webkitConvertPointFromNodeToPage(node: Node, pt: WebKitPoint): WebKitPoint;\n    webkitConvertPointFromPageToNode(node: Node, pt: WebKitPoint): WebKitPoint;\n    webkitRequestAnimationFrame(callback: FrameRequestCallback): number;\n    addEventListener<K extends keyof WindowEventMap>(type: K, listener: (this: Window, ev: WindowEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof WindowEventMap>(type: K, listener: (this: Window, ev: WindowEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n    [index: number]: Window;\n}\n\ndeclare var Window: {\n    prototype: Window;\n    new(): Window;\n};\n\ninterface WindowEventHandlersEventMap {\n    "afterprint": Event;\n    "beforeprint": Event;\n    "beforeunload": BeforeUnloadEvent;\n    "hashchange": HashChangeEvent;\n    "languagechange": Event;\n    "message": MessageEvent;\n    "messageerror": MessageEvent;\n    "offline": Event;\n    "online": Event;\n    "pagehide": PageTransitionEvent;\n    "pageshow": PageTransitionEvent;\n    "popstate": PopStateEvent;\n    "rejectionhandled": PromiseRejectionEvent;\n    "storage": StorageEvent;\n    "unhandledrejection": PromiseRejectionEvent;\n    "unload": Event;\n}\n\ninterface WindowEventHandlers {\n    onafterprint: ((this: WindowEventHandlers, ev: Event) => any) | null;\n    onbeforeprint: ((this: WindowEventHandlers, ev: Event) => any) | null;\n    onbeforeunload: ((this: WindowEventHandlers, ev: BeforeUnloadEvent) => any) | null;\n    onhashchange: ((this: WindowEventHandlers, ev: HashChangeEvent) => any) | null;\n    onlanguagechange: ((this: WindowEventHandlers, ev: Event) => any) | null;\n    onmessage: ((this: WindowEventHandlers, ev: MessageEvent) => any) | null;\n    onmessageerror: ((this: WindowEventHandlers, ev: MessageEvent) => any) | null;\n    onoffline: ((this: WindowEventHandlers, ev: Event) => any) | null;\n    ononline: ((this: WindowEventHandlers, ev: Event) => any) | null;\n    onpagehide: ((this: WindowEventHandlers, ev: PageTransitionEvent) => any) | null;\n    onpageshow: ((this: WindowEventHandlers, ev: PageTransitionEvent) => any) | null;\n    onpopstate: ((this: WindowEventHandlers, ev: PopStateEvent) => any) | null;\n    onrejectionhandled: ((this: WindowEventHandlers, ev: PromiseRejectionEvent) => any) | null;\n    onstorage: ((this: WindowEventHandlers, ev: StorageEvent) => any) | null;\n    onunhandledrejection: ((this: WindowEventHandlers, ev: PromiseRejectionEvent) => any) | null;\n    onunload: ((this: WindowEventHandlers, ev: Event) => any) | null;\n    addEventListener<K extends keyof WindowEventHandlersEventMap>(type: K, listener: (this: WindowEventHandlers, ev: WindowEventHandlersEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof WindowEventHandlersEventMap>(type: K, listener: (this: WindowEventHandlers, ev: WindowEventHandlersEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ninterface WindowLocalStorage {\n    readonly localStorage: Storage;\n}\n\ninterface WindowOrWorkerGlobalScope {\n    readonly caches: CacheStorage;\n    readonly crypto: Crypto;\n    readonly indexedDB: IDBFactory;\n    readonly isSecureContext: boolean;\n    readonly origin: string;\n    readonly performance: Performance;\n    atob(data: string): string;\n    btoa(data: string): string;\n    clearInterval(handle?: number): void;\n    clearTimeout(handle?: number): void;\n    createImageBitmap(image: ImageBitmapSource, options?: ImageBitmapOptions): Promise<ImageBitmap>;\n    createImageBitmap(image: ImageBitmapSource, sx: number, sy: number, sw: number, sh: number, options?: ImageBitmapOptions): Promise<ImageBitmap>;\n    fetch(input: RequestInfo, init?: RequestInit): Promise<Response>;\n    queueMicrotask(callback: VoidFunction): void;\n    setInterval(handler: TimerHandler, timeout?: number, ...arguments: any[]): number;\n    setTimeout(handler: TimerHandler, timeout?: number, ...arguments: any[]): number;\n}\n\ninterface WindowSessionStorage {\n    readonly sessionStorage: Storage;\n}\n\ninterface WorkerEventMap extends AbstractWorkerEventMap {\n    "message": MessageEvent;\n    "messageerror": MessageEvent;\n}\n\n/** This Web Workers API interface represents a background task that can be easily created and can send messages back to its creator. Creating a worker is as simple as calling the Worker() constructor and specifying a script to be run in the worker thread. */\ninterface Worker extends EventTarget, AbstractWorker {\n    onmessage: ((this: Worker, ev: MessageEvent) => any) | null;\n    onmessageerror: ((this: Worker, ev: MessageEvent) => any) | null;\n    /**\n     * Clones message and transmits it to worker\'s global environment. transfer can be passed as a list of objects that are to be transferred rather than cloned.\n     */\n    postMessage(message: any, transfer: Transferable[]): void;\n    postMessage(message: any, options?: PostMessageOptions): void;\n    /**\n     * Aborts worker\'s associated global environment.\n     */\n    terminate(): void;\n    addEventListener<K extends keyof WorkerEventMap>(type: K, listener: (this: Worker, ev: WorkerEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof WorkerEventMap>(type: K, listener: (this: Worker, ev: WorkerEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var Worker: {\n    prototype: Worker;\n    new(stringUrl: string | URL, options?: WorkerOptions): Worker;\n};\n\ninterface Worklet {\n    addModule(moduleURL: string, options?: WorkletOptions): Promise<void>;\n}\n\ndeclare var Worklet: {\n    prototype: Worklet;\n    new(): Worklet;\n};\n\n/** This Streams API interface provides a standard abstraction for writing streaming data to a destination, known as a sink. This object comes with built-in backpressure and queuing. */\ninterface WritableStream<W = any> {\n    readonly locked: boolean;\n    abort(reason?: any): Promise<void>;\n    getWriter(): WritableStreamDefaultWriter<W>;\n}\n\ndeclare var WritableStream: {\n    prototype: WritableStream;\n    new<W = any>(underlyingSink?: UnderlyingSink<W>, strategy?: QueuingStrategy<W>): WritableStream<W>;\n};\n\n/** This Streams API interface represents a controller allowing control of a WritableStream\'s state. When constructing a WritableStream, the underlying sink is given a corresponding WritableStreamDefaultController instance to manipulate. */\ninterface WritableStreamDefaultController {\n    error(e?: any): void;\n}\n\ndeclare var WritableStreamDefaultController: {\n    prototype: WritableStreamDefaultController;\n    new(): WritableStreamDefaultController;\n};\n\n/** This Streams API interface is the object returned by WritableStream.getWriter() and once created locks the < writer to the WritableStream ensuring that no other streams can write to the underlying sink. */\ninterface WritableStreamDefaultWriter<W = any> {\n    readonly closed: Promise<undefined>;\n    readonly desiredSize: number | null;\n    readonly ready: Promise<undefined>;\n    abort(reason?: any): Promise<void>;\n    close(): Promise<void>;\n    releaseLock(): void;\n    write(chunk: W): Promise<void>;\n}\n\ndeclare var WritableStreamDefaultWriter: {\n    prototype: WritableStreamDefaultWriter;\n    new<W = any>(stream: WritableStream<W>): WritableStreamDefaultWriter<W>;\n};\n\n/** An XML document. It inherits from the generic Document and does not add any specific methods or properties to it: nevertheless, several algorithms behave differently with the two types of documents. */\ninterface XMLDocument extends Document {\n    addEventListener<K extends keyof DocumentEventMap>(type: K, listener: (this: XMLDocument, ev: DocumentEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof DocumentEventMap>(type: K, listener: (this: XMLDocument, ev: DocumentEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var XMLDocument: {\n    prototype: XMLDocument;\n    new(): XMLDocument;\n};\n\ninterface XMLHttpRequestEventMap extends XMLHttpRequestEventTargetEventMap {\n    "readystatechange": Event;\n}\n\n/** Use XMLHttpRequest (XHR) objects to interact with servers. You can retrieve data from a URL without having to do a full page refresh. This enables a Web page to update just part of a page without disrupting what the user is doing. */\ninterface XMLHttpRequest extends XMLHttpRequestEventTarget {\n    onreadystatechange: ((this: XMLHttpRequest, ev: Event) => any) | null;\n    /**\n     * Returns client\'s state.\n     */\n    readonly readyState: number;\n    /**\n     * Returns the response\'s body.\n     */\n    readonly response: any;\n    /**\n     * Returns the text response.\n     *\n     * Throws an "InvalidStateError" DOMException if responseType is not the empty string or "text".\n     */\n    readonly responseText: string;\n    /**\n     * Returns the response type.\n     *\n     * Can be set to change the response type. Values are: the empty string (default), "arraybuffer", "blob", "document", "json", and "text".\n     *\n     * When set: setting to "document" is ignored if current global object is not a Window object.\n     *\n     * When set: throws an "InvalidStateError" DOMException if state is loading or done.\n     *\n     * When set: throws an "InvalidAccessError" DOMException if the synchronous flag is set and current global object is a Window object.\n     */\n    responseType: XMLHttpRequestResponseType;\n    readonly responseURL: string;\n    /**\n     * Returns the document response.\n     *\n     * Throws an "InvalidStateError" DOMException if responseType is not the empty string or "document".\n     */\n    readonly responseXML: Document | null;\n    readonly status: number;\n    readonly statusText: string;\n    /**\n     * Can be set to a time in milliseconds. When set to a non-zero value will cause fetching to terminate after the given time has passed. When the time has passed, the request has not yet completed, and the synchronous flag is unset, a timeout event will then be dispatched, or a "TimeoutError" DOMException will be thrown otherwise (for the send() method).\n     *\n     * When set: throws an "InvalidAccessError" DOMException if the synchronous flag is set and current global object is a Window object.\n     */\n    timeout: number;\n    /**\n     * Returns the associated XMLHttpRequestUpload object. It can be used to gather transmission information when data is transferred to a server.\n     */\n    readonly upload: XMLHttpRequestUpload;\n    /**\n     * True when credentials are to be included in a cross-origin request. False when they are to be excluded in a cross-origin request and when cookies are to be ignored in its response. Initially false.\n     *\n     * When set: throws an "InvalidStateError" DOMException if state is not unsent or opened, or if the send() flag is set.\n     */\n    withCredentials: boolean;\n    /**\n     * Cancels any network activity.\n     */\n    abort(): void;\n    getAllResponseHeaders(): string;\n    getResponseHeader(name: string): string | null;\n    /**\n     * Sets the request method, request URL, and synchronous flag.\n     *\n     * Throws a "SyntaxError" DOMException if either method is not a valid HTTP method or url cannot be parsed.\n     *\n     * Throws a "SecurityError" DOMException if method is a case-insensitive match for `CONNECT`, `TRACE`, or `TRACK`.\n     *\n     * Throws an "InvalidAccessError" DOMException if async is false, current global object is a Window object, and the timeout attribute is not zero or the responseType attribute is not the empty string.\n     */\n    open(method: string, url: string): void;\n    open(method: string, url: string, async: boolean, username?: string | null, password?: string | null): void;\n    /**\n     * Acts as if the `Content-Type` header value for response is mime. (It does not actually change the header though.)\n     *\n     * Throws an "InvalidStateError" DOMException if state is loading or done.\n     */\n    overrideMimeType(mime: string): void;\n    /**\n     * Initiates the request. The body argument provides the request body, if any, and is ignored if the request method is GET or HEAD.\n     *\n     * Throws an "InvalidStateError" DOMException if either state is not opened or the send() flag is set.\n     */\n    send(body?: Document | BodyInit | null): void;\n    /**\n     * Combines a header in author request headers.\n     *\n     * Throws an "InvalidStateError" DOMException if either state is not opened or the send() flag is set.\n     *\n     * Throws a "SyntaxError" DOMException if name is not a header name or if value is not a header value.\n     */\n    setRequestHeader(name: string, value: string): void;\n    readonly DONE: number;\n    readonly HEADERS_RECEIVED: number;\n    readonly LOADING: number;\n    readonly OPENED: number;\n    readonly UNSENT: number;\n    addEventListener<K extends keyof XMLHttpRequestEventMap>(type: K, listener: (this: XMLHttpRequest, ev: XMLHttpRequestEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof XMLHttpRequestEventMap>(type: K, listener: (this: XMLHttpRequest, ev: XMLHttpRequestEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var XMLHttpRequest: {\n    prototype: XMLHttpRequest;\n    new(): XMLHttpRequest;\n    readonly DONE: number;\n    readonly HEADERS_RECEIVED: number;\n    readonly LOADING: number;\n    readonly OPENED: number;\n    readonly UNSENT: number;\n};\n\ninterface XMLHttpRequestEventTargetEventMap {\n    "abort": ProgressEvent<XMLHttpRequestEventTarget>;\n    "error": ProgressEvent<XMLHttpRequestEventTarget>;\n    "load": ProgressEvent<XMLHttpRequestEventTarget>;\n    "loadend": ProgressEvent<XMLHttpRequestEventTarget>;\n    "loadstart": ProgressEvent<XMLHttpRequestEventTarget>;\n    "progress": ProgressEvent<XMLHttpRequestEventTarget>;\n    "timeout": ProgressEvent<XMLHttpRequestEventTarget>;\n}\n\ninterface XMLHttpRequestEventTarget extends EventTarget {\n    onabort: ((this: XMLHttpRequest, ev: ProgressEvent) => any) | null;\n    onerror: ((this: XMLHttpRequest, ev: ProgressEvent) => any) | null;\n    onload: ((this: XMLHttpRequest, ev: ProgressEvent) => any) | null;\n    onloadend: ((this: XMLHttpRequest, ev: ProgressEvent) => any) | null;\n    onloadstart: ((this: XMLHttpRequest, ev: ProgressEvent) => any) | null;\n    onprogress: ((this: XMLHttpRequest, ev: ProgressEvent) => any) | null;\n    ontimeout: ((this: XMLHttpRequest, ev: ProgressEvent) => any) | null;\n    addEventListener<K extends keyof XMLHttpRequestEventTargetEventMap>(type: K, listener: (this: XMLHttpRequestEventTarget, ev: XMLHttpRequestEventTargetEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof XMLHttpRequestEventTargetEventMap>(type: K, listener: (this: XMLHttpRequestEventTarget, ev: XMLHttpRequestEventTargetEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var XMLHttpRequestEventTarget: {\n    prototype: XMLHttpRequestEventTarget;\n    new(): XMLHttpRequestEventTarget;\n};\n\ninterface XMLHttpRequestUpload extends XMLHttpRequestEventTarget {\n    addEventListener<K extends keyof XMLHttpRequestEventTargetEventMap>(type: K, listener: (this: XMLHttpRequestUpload, ev: XMLHttpRequestEventTargetEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof XMLHttpRequestEventTargetEventMap>(type: K, listener: (this: XMLHttpRequestUpload, ev: XMLHttpRequestEventTargetEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var XMLHttpRequestUpload: {\n    prototype: XMLHttpRequestUpload;\n    new(): XMLHttpRequestUpload;\n};\n\n/** Provides the serializeToString() method to construct an XML string representing a DOM tree. */\ninterface XMLSerializer {\n    serializeToString(root: Node): string;\n}\n\ndeclare var XMLSerializer: {\n    prototype: XMLSerializer;\n    new(): XMLSerializer;\n};\n\n/** The XPathEvaluator interface allows to compile and evaluate XPath expressions. */\ninterface XPathEvaluator extends XPathEvaluatorBase {\n}\n\ndeclare var XPathEvaluator: {\n    prototype: XPathEvaluator;\n    new(): XPathEvaluator;\n};\n\ninterface XPathEvaluatorBase {\n    createExpression(expression: string, resolver?: XPathNSResolver | null): XPathExpression;\n    createNSResolver(nodeResolver: Node): XPathNSResolver;\n    evaluate(expression: string, contextNode: Node, resolver?: XPathNSResolver | null, type?: number, result?: XPathResult | null): XPathResult;\n}\n\n/** This interface is a compiled XPath expression that can be evaluated on a document or specific node to return information its DOM tree. */\ninterface XPathExpression {\n    evaluate(contextNode: Node, type?: number, result?: XPathResult | null): XPathResult;\n}\n\ndeclare var XPathExpression: {\n    prototype: XPathExpression;\n    new(): XPathExpression;\n};\n\n/** The results generated by evaluating an XPath expression within the context of a given node. */\ninterface XPathResult {\n    readonly booleanValue: boolean;\n    readonly invalidIteratorState: boolean;\n    readonly numberValue: number;\n    readonly resultType: number;\n    readonly singleNodeValue: Node | null;\n    readonly snapshotLength: number;\n    readonly stringValue: string;\n    iterateNext(): Node | null;\n    snapshotItem(index: number): Node | null;\n    readonly ANY_TYPE: number;\n    readonly ANY_UNORDERED_NODE_TYPE: number;\n    readonly BOOLEAN_TYPE: number;\n    readonly FIRST_ORDERED_NODE_TYPE: number;\n    readonly NUMBER_TYPE: number;\n    readonly ORDERED_NODE_ITERATOR_TYPE: number;\n    readonly ORDERED_NODE_SNAPSHOT_TYPE: number;\n    readonly STRING_TYPE: number;\n    readonly UNORDERED_NODE_ITERATOR_TYPE: number;\n    readonly UNORDERED_NODE_SNAPSHOT_TYPE: number;\n}\n\ndeclare var XPathResult: {\n    prototype: XPathResult;\n    new(): XPathResult;\n    readonly ANY_TYPE: number;\n    readonly ANY_UNORDERED_NODE_TYPE: number;\n    readonly BOOLEAN_TYPE: number;\n    readonly FIRST_ORDERED_NODE_TYPE: number;\n    readonly NUMBER_TYPE: number;\n    readonly ORDERED_NODE_ITERATOR_TYPE: number;\n    readonly ORDERED_NODE_SNAPSHOT_TYPE: number;\n    readonly STRING_TYPE: number;\n    readonly UNORDERED_NODE_ITERATOR_TYPE: number;\n    readonly UNORDERED_NODE_SNAPSHOT_TYPE: number;\n};\n\n/** An XSLTProcessor applies an XSLT stylesheet transformation to an XML document to produce a new XML document as output. It has methods to load the XSLT stylesheet, to manipulate <xsl:param> parameter values, and to apply the transformation to documents. */\ninterface XSLTProcessor {\n    clearParameters(): void;\n    getParameter(namespaceURI: string, localName: string): any;\n    importStylesheet(style: Node): void;\n    removeParameter(namespaceURI: string, localName: string): void;\n    reset(): void;\n    setParameter(namespaceURI: string, localName: string, value: any): void;\n    transformToDocument(source: Node): Document;\n    transformToFragment(source: Node, document: Document): DocumentFragment;\n}\n\ndeclare var XSLTProcessor: {\n    prototype: XSLTProcessor;\n    new(): XSLTProcessor;\n};\n\ninterface webkitRTCPeerConnection extends RTCPeerConnection {\n    addEventListener<K extends keyof RTCPeerConnectionEventMap>(type: K, listener: (this: webkitRTCPeerConnection, ev: RTCPeerConnectionEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof RTCPeerConnectionEventMap>(type: K, listener: (this: webkitRTCPeerConnection, ev: RTCPeerConnectionEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var webkitRTCPeerConnection: {\n    prototype: webkitRTCPeerConnection;\n    new(configuration: RTCConfiguration): webkitRTCPeerConnection;\n};\n\ndeclare type EventListenerOrEventListenerObject = EventListener | EventListenerObject;\n\ninterface Console {\n    memory: any;\n    assert(condition?: boolean, ...data: any[]): void;\n    clear(): void;\n    count(label?: string): void;\n    countReset(label?: string): void;\n    debug(...data: any[]): void;\n    dir(item?: any, options?: any): void;\n    dirxml(...data: any[]): void;\n    error(...data: any[]): void;\n    exception(message?: string, ...optionalParams: any[]): void;\n    group(...data: any[]): void;\n    groupCollapsed(...data: any[]): void;\n    groupEnd(): void;\n    info(...data: any[]): void;\n    log(...data: any[]): void;\n    table(tabularData?: any, properties?: string[]): void;\n    time(label?: string): void;\n    timeEnd(label?: string): void;\n    timeLog(label?: string, ...data: any[]): void;\n    timeStamp(label?: string): void;\n    trace(...data: any[]): void;\n    warn(...data: any[]): void;\n}\n\ndeclare var console: Console;\n\n/** Holds useful CSS-related methods. No object with this interface are implemented: it contains only static methods and therefore is a utilitarian interface. */\ndeclare namespace CSS {\n    function escape(ident: string): string;\n    function supports(property: string, value: string): boolean;\n    function supports(conditionText: string): boolean;\n}\n\ndeclare namespace WebAssembly {\n    interface CompileError {\n    }\n\n    var CompileError: {\n        prototype: CompileError;\n        new(): CompileError;\n    };\n\n    interface Global {\n        value: any;\n        valueOf(): any;\n    }\n\n    var Global: {\n        prototype: Global;\n        new(descriptor: GlobalDescriptor, v?: any): Global;\n    };\n\n    interface Instance {\n        readonly exports: Exports;\n    }\n\n    var Instance: {\n        prototype: Instance;\n        new(module: Module, importObject?: Imports): Instance;\n    };\n\n    interface LinkError {\n    }\n\n    var LinkError: {\n        prototype: LinkError;\n        new(): LinkError;\n    };\n\n    interface Memory {\n        readonly buffer: ArrayBuffer;\n        grow(delta: number): number;\n    }\n\n    var Memory: {\n        prototype: Memory;\n        new(descriptor: MemoryDescriptor): Memory;\n    };\n\n    interface Module {\n    }\n\n    var Module: {\n        prototype: Module;\n        new(bytes: BufferSource): Module;\n        customSections(moduleObject: Module, sectionName: string): ArrayBuffer[];\n        exports(moduleObject: Module): ModuleExportDescriptor[];\n        imports(moduleObject: Module): ModuleImportDescriptor[];\n    };\n\n    interface RuntimeError {\n    }\n\n    var RuntimeError: {\n        prototype: RuntimeError;\n        new(): RuntimeError;\n    };\n\n    interface Table {\n        readonly length: number;\n        get(index: number): Function | null;\n        grow(delta: number): number;\n        set(index: number, value: Function | null): void;\n    }\n\n    var Table: {\n        prototype: Table;\n        new(descriptor: TableDescriptor): Table;\n    };\n\n    interface GlobalDescriptor {\n        mutable?: boolean;\n        value: ValueType;\n    }\n\n    interface MemoryDescriptor {\n        initial: number;\n        maximum?: number;\n        shared?: boolean;\n    }\n\n    interface ModuleExportDescriptor {\n        kind: ImportExportKind;\n        name: string;\n    }\n\n    interface ModuleImportDescriptor {\n        kind: ImportExportKind;\n        module: string;\n        name: string;\n    }\n\n    interface TableDescriptor {\n        element: TableKind;\n        initial: number;\n        maximum?: number;\n    }\n\n    interface WebAssemblyInstantiatedSource {\n        instance: Instance;\n        module: Module;\n    }\n\n    type ImportExportKind = "function" | "global" | "memory" | "table";\n    type TableKind = "anyfunc";\n    type ValueType = "f32" | "f64" | "i32" | "i64";\n    type ExportValue = Function | Global | Memory | Table;\n    type Exports = Record<string, ExportValue>;\n    type ImportValue = ExportValue | number;\n    type ModuleImports = Record<string, ImportValue>;\n    type Imports = Record<string, ModuleImports>;\n    function compile(bytes: BufferSource): Promise<Module>;\n    function compileStreaming(source: Response | Promise<Response>): Promise<Module>;\n    function instantiate(bytes: BufferSource, importObject?: Imports): Promise<WebAssemblyInstantiatedSource>;\n    function instantiate(moduleObject: Module, importObject?: Imports): Promise<Instance>;\n    function instantiateStreaming(response: Response | PromiseLike<Response>, importObject?: Imports): Promise<WebAssemblyInstantiatedSource>;\n    function validate(bytes: BufferSource): boolean;\n}\n\ninterface BlobCallback {\n    (blob: Blob | null): void;\n}\n\ninterface CustomElementConstructor {\n    new (...params: any[]): HTMLElement;\n}\n\ninterface DecodeErrorCallback {\n    (error: DOMException): void;\n}\n\ninterface DecodeSuccessCallback {\n    (decodedData: AudioBuffer): void;\n}\n\ninterface EventHandlerNonNull {\n    (event: Event): any;\n}\n\ninterface ForEachCallback {\n    (keyId: Int8Array | Int16Array | Int32Array | Uint8Array | Uint16Array | Uint32Array | Uint8ClampedArray | Float32Array | Float64Array | DataView | ArrayBuffer | null, status: MediaKeyStatus): void;\n}\n\ninterface FrameRequestCallback {\n    (time: number): void;\n}\n\ninterface FunctionStringCallback {\n    (data: string): void;\n}\n\ninterface IntersectionObserverCallback {\n    (entries: IntersectionObserverEntry[], observer: IntersectionObserver): void;\n}\n\ninterface MSLaunchUriCallback {\n    (): void;\n}\n\ninterface MutationCallback {\n    (mutations: MutationRecord[], observer: MutationObserver): void;\n}\n\ninterface NavigatorUserMediaErrorCallback {\n    (error: MediaStreamError): void;\n}\n\ninterface NavigatorUserMediaSuccessCallback {\n    (stream: MediaStream): void;\n}\n\ninterface NotificationPermissionCallback {\n    (permission: NotificationPermission): void;\n}\n\ninterface OnBeforeUnloadEventHandlerNonNull {\n    (event: Event): string | null;\n}\n\ninterface OnErrorEventHandlerNonNull {\n    (event: Event | string, source?: string, lineno?: number, colno?: number, error?: Error): any;\n}\n\ninterface PerformanceObserverCallback {\n    (entries: PerformanceObserverEntryList, observer: PerformanceObserver): void;\n}\n\ninterface PositionCallback {\n    (position: GeolocationPosition): void;\n}\n\ninterface PositionErrorCallback {\n    (positionError: GeolocationPositionError): void;\n}\n\ninterface QueuingStrategySize<T = any> {\n    (chunk: T): number;\n}\n\ninterface RTCPeerConnectionErrorCallback {\n    (error: DOMException): void;\n}\n\ninterface RTCSessionDescriptionCallback {\n    (description: RTCSessionDescriptionInit): void;\n}\n\ninterface RTCStatsCallback {\n    (report: RTCStatsReport): void;\n}\n\ninterface ResizeObserverCallback {\n    (entries: ResizeObserverEntry[], observer: ResizeObserver): void;\n}\n\ninterface TransformerFlushCallback<O> {\n    (controller: TransformStreamDefaultController<O>): void | PromiseLike<void>;\n}\n\ninterface TransformerStartCallback<O> {\n    (controller: TransformStreamDefaultController<O>): void | PromiseLike<void>;\n}\n\ninterface TransformerTransformCallback<I, O> {\n    (chunk: I, controller: TransformStreamDefaultController<O>): void | PromiseLike<void>;\n}\n\ninterface UnderlyingSinkAbortCallback {\n    (reason: any): void | PromiseLike<void>;\n}\n\ninterface UnderlyingSinkCloseCallback {\n    (): void | PromiseLike<void>;\n}\n\ninterface UnderlyingSinkStartCallback {\n    (controller: WritableStreamDefaultController): void | PromiseLike<void>;\n}\n\ninterface UnderlyingSinkWriteCallback<W> {\n    (chunk: W, controller: WritableStreamDefaultController): void | PromiseLike<void>;\n}\n\ninterface UnderlyingSourceCancelCallback {\n    (reason: any): void | PromiseLike<void>;\n}\n\ninterface UnderlyingSourcePullCallback<R> {\n    (controller: ReadableStreamController<R>): void | PromiseLike<void>;\n}\n\ninterface UnderlyingSourceStartCallback<R> {\n    (controller: ReadableStreamController<R>): void | PromiseLike<void>;\n}\n\ninterface VoidFunction {\n    (): void;\n}\n\ninterface HTMLElementTagNameMap {\n    "a": HTMLAnchorElement;\n    "abbr": HTMLElement;\n    "address": HTMLElement;\n    "applet": HTMLAppletElement;\n    "area": HTMLAreaElement;\n    "article": HTMLElement;\n    "aside": HTMLElement;\n    "audio": HTMLAudioElement;\n    "b": HTMLElement;\n    "base": HTMLBaseElement;\n    "bdi": HTMLElement;\n    "bdo": HTMLElement;\n    "blockquote": HTMLQuoteElement;\n    "body": HTMLBodyElement;\n    "br": HTMLBRElement;\n    "button": HTMLButtonElement;\n    "canvas": HTMLCanvasElement;\n    "caption": HTMLTableCaptionElement;\n    "cite": HTMLElement;\n    "code": HTMLElement;\n    "col": HTMLTableColElement;\n    "colgroup": HTMLTableColElement;\n    "data": HTMLDataElement;\n    "datalist": HTMLDataListElement;\n    "dd": HTMLElement;\n    "del": HTMLModElement;\n    "details": HTMLDetailsElement;\n    "dfn": HTMLElement;\n    "dialog": HTMLDialogElement;\n    "dir": HTMLDirectoryElement;\n    "div": HTMLDivElement;\n    "dl": HTMLDListElement;\n    "dt": HTMLElement;\n    "em": HTMLElement;\n    "embed": HTMLEmbedElement;\n    "fieldset": HTMLFieldSetElement;\n    "figcaption": HTMLElement;\n    "figure": HTMLElement;\n    "font": HTMLFontElement;\n    "footer": HTMLElement;\n    "form": HTMLFormElement;\n    "frame": HTMLFrameElement;\n    "frameset": HTMLFrameSetElement;\n    "h1": HTMLHeadingElement;\n    "h2": HTMLHeadingElement;\n    "h3": HTMLHeadingElement;\n    "h4": HTMLHeadingElement;\n    "h5": HTMLHeadingElement;\n    "h6": HTMLHeadingElement;\n    "head": HTMLHeadElement;\n    "header": HTMLElement;\n    "hgroup": HTMLElement;\n    "hr": HTMLHRElement;\n    "html": HTMLHtmlElement;\n    "i": HTMLElement;\n    "iframe": HTMLIFrameElement;\n    "img": HTMLImageElement;\n    "input": HTMLInputElement;\n    "ins": HTMLModElement;\n    "kbd": HTMLElement;\n    "label": HTMLLabelElement;\n    "legend": HTMLLegendElement;\n    "li": HTMLLIElement;\n    "link": HTMLLinkElement;\n    "main": HTMLElement;\n    "map": HTMLMapElement;\n    "mark": HTMLElement;\n    "marquee": HTMLMarqueeElement;\n    "menu": HTMLMenuElement;\n    "meta": HTMLMetaElement;\n    "meter": HTMLMeterElement;\n    "nav": HTMLElement;\n    "noscript": HTMLElement;\n    "object": HTMLObjectElement;\n    "ol": HTMLOListElement;\n    "optgroup": HTMLOptGroupElement;\n    "option": HTMLOptionElement;\n    "output": HTMLOutputElement;\n    "p": HTMLParagraphElement;\n    "param": HTMLParamElement;\n    "picture": HTMLPictureElement;\n    "pre": HTMLPreElement;\n    "progress": HTMLProgressElement;\n    "q": HTMLQuoteElement;\n    "rp": HTMLElement;\n    "rt": HTMLElement;\n    "ruby": HTMLElement;\n    "s": HTMLElement;\n    "samp": HTMLElement;\n    "script": HTMLScriptElement;\n    "section": HTMLElement;\n    "select": HTMLSelectElement;\n    "slot": HTMLSlotElement;\n    "small": HTMLElement;\n    "source": HTMLSourceElement;\n    "span": HTMLSpanElement;\n    "strong": HTMLElement;\n    "style": HTMLStyleElement;\n    "sub": HTMLElement;\n    "summary": HTMLElement;\n    "sup": HTMLElement;\n    "table": HTMLTableElement;\n    "tbody": HTMLTableSectionElement;\n    "td": HTMLTableDataCellElement;\n    "template": HTMLTemplateElement;\n    "textarea": HTMLTextAreaElement;\n    "tfoot": HTMLTableSectionElement;\n    "th": HTMLTableHeaderCellElement;\n    "thead": HTMLTableSectionElement;\n    "time": HTMLTimeElement;\n    "title": HTMLTitleElement;\n    "tr": HTMLTableRowElement;\n    "track": HTMLTrackElement;\n    "u": HTMLElement;\n    "ul": HTMLUListElement;\n    "var": HTMLElement;\n    "video": HTMLVideoElement;\n    "wbr": HTMLElement;\n}\n\ninterface HTMLElementDeprecatedTagNameMap {\n    "listing": HTMLPreElement;\n    "xmp": HTMLPreElement;\n}\n\ninterface SVGElementTagNameMap {\n    "a": SVGAElement;\n    "circle": SVGCircleElement;\n    "clipPath": SVGClipPathElement;\n    "defs": SVGDefsElement;\n    "desc": SVGDescElement;\n    "ellipse": SVGEllipseElement;\n    "feBlend": SVGFEBlendElement;\n    "feColorMatrix": SVGFEColorMatrixElement;\n    "feComponentTransfer": SVGFEComponentTransferElement;\n    "feComposite": SVGFECompositeElement;\n    "feConvolveMatrix": SVGFEConvolveMatrixElement;\n    "feDiffuseLighting": SVGFEDiffuseLightingElement;\n    "feDisplacementMap": SVGFEDisplacementMapElement;\n    "feDistantLight": SVGFEDistantLightElement;\n    "feFlood": SVGFEFloodElement;\n    "feFuncA": SVGFEFuncAElement;\n    "feFuncB": SVGFEFuncBElement;\n    "feFuncG": SVGFEFuncGElement;\n    "feFuncR": SVGFEFuncRElement;\n    "feGaussianBlur": SVGFEGaussianBlurElement;\n    "feImage": SVGFEImageElement;\n    "feMerge": SVGFEMergeElement;\n    "feMergeNode": SVGFEMergeNodeElement;\n    "feMorphology": SVGFEMorphologyElement;\n    "feOffset": SVGFEOffsetElement;\n    "fePointLight": SVGFEPointLightElement;\n    "feSpecularLighting": SVGFESpecularLightingElement;\n    "feSpotLight": SVGFESpotLightElement;\n    "feTile": SVGFETileElement;\n    "feTurbulence": SVGFETurbulenceElement;\n    "filter": SVGFilterElement;\n    "foreignObject": SVGForeignObjectElement;\n    "g": SVGGElement;\n    "image": SVGImageElement;\n    "line": SVGLineElement;\n    "linearGradient": SVGLinearGradientElement;\n    "marker": SVGMarkerElement;\n    "mask": SVGMaskElement;\n    "metadata": SVGMetadataElement;\n    "path": SVGPathElement;\n    "pattern": SVGPatternElement;\n    "polygon": SVGPolygonElement;\n    "polyline": SVGPolylineElement;\n    "radialGradient": SVGRadialGradientElement;\n    "rect": SVGRectElement;\n    "script": SVGScriptElement;\n    "stop": SVGStopElement;\n    "style": SVGStyleElement;\n    "svg": SVGSVGElement;\n    "switch": SVGSwitchElement;\n    "symbol": SVGSymbolElement;\n    "text": SVGTextElement;\n    "textPath": SVGTextPathElement;\n    "title": SVGTitleElement;\n    "tspan": SVGTSpanElement;\n    "use": SVGUseElement;\n    "view": SVGViewElement;\n}\n\n/** @deprecated Directly use HTMLElementTagNameMap or SVGElementTagNameMap as appropriate, instead. */\ntype ElementTagNameMap = HTMLElementTagNameMap & Pick<SVGElementTagNameMap, Exclude<keyof SVGElementTagNameMap, keyof HTMLElementTagNameMap>>;\n\ndeclare var Audio: {\n    new(src?: string): HTMLAudioElement;\n};\ndeclare var Image: {\n    new(width?: number, height?: number): HTMLImageElement;\n};\ndeclare var Option: {\n    new(text?: string, value?: string, defaultSelected?: boolean, selected?: boolean): HTMLOptionElement;\n};\ndeclare var applicationCache: ApplicationCache;\ndeclare var clientInformation: Navigator;\ndeclare var closed: boolean;\ndeclare var customElements: CustomElementRegistry;\ndeclare var defaultStatus: string;\ndeclare var devicePixelRatio: number;\ndeclare var doNotTrack: string;\ndeclare var document: Document;\n/** @deprecated */\ndeclare var event: Event | undefined;\n/** @deprecated */\ndeclare var external: External;\ndeclare var frameElement: Element | null;\ndeclare var frames: Window;\ndeclare var history: History;\ndeclare var innerHeight: number;\ndeclare var innerWidth: number;\ndeclare var length: number;\ndeclare var location: Location;\ndeclare var locationbar: BarProp;\ndeclare var menubar: BarProp;\ndeclare var msContentScript: ExtensionScriptApis;\n/** @deprecated */\ndeclare const name: void;\ndeclare var navigator: Navigator;\ndeclare var offscreenBuffering: string | boolean;\ndeclare var oncompassneedscalibration: ((this: Window, ev: Event) => any) | null;\ndeclare var ondevicemotion: ((this: Window, ev: DeviceMotionEvent) => any) | null;\ndeclare var ondeviceorientation: ((this: Window, ev: DeviceOrientationEvent) => any) | null;\ndeclare var ondeviceorientationabsolute: ((this: Window, ev: DeviceOrientationEvent) => any) | null;\ndeclare var ongamepadconnected: ((this: Window, ev: GamepadEvent) => any) | null;\ndeclare var ongamepaddisconnected: ((this: Window, ev: GamepadEvent) => any) | null;\ndeclare var onmousewheel: ((this: Window, ev: Event) => any) | null;\n/** @deprecated */\ndeclare var onorientationchange: ((this: Window, ev: Event) => any) | null;\ndeclare var onreadystatechange: ((this: Window, ev: ProgressEvent<Window>) => any) | null;\ndeclare var onvrdisplayactivate: ((this: Window, ev: Event) => any) | null;\ndeclare var onvrdisplayblur: ((this: Window, ev: Event) => any) | null;\ndeclare var onvrdisplayconnect: ((this: Window, ev: Event) => any) | null;\ndeclare var onvrdisplaydeactivate: ((this: Window, ev: Event) => any) | null;\ndeclare var onvrdisplaydisconnect: ((this: Window, ev: Event) => any) | null;\ndeclare var onvrdisplaypresentchange: ((this: Window, ev: Event) => any) | null;\ndeclare var opener: WindowProxy | null;\n/** @deprecated */\ndeclare var orientation: string | number;\ndeclare var outerHeight: number;\ndeclare var outerWidth: number;\ndeclare var pageXOffset: number;\ndeclare var pageYOffset: number;\ndeclare var parent: Window;\ndeclare var personalbar: BarProp;\ndeclare var screen: Screen;\ndeclare var screenLeft: number;\ndeclare var screenTop: number;\ndeclare var screenX: number;\ndeclare var screenY: number;\ndeclare var scrollX: number;\ndeclare var scrollY: number;\ndeclare var scrollbars: BarProp;\ndeclare var self: Window & typeof globalThis;\ndeclare var speechSynthesis: SpeechSynthesis;\ndeclare var status: string;\ndeclare var statusbar: BarProp;\ndeclare var styleMedia: StyleMedia;\ndeclare var toolbar: BarProp;\ndeclare var top: Window;\ndeclare var visualViewport: VisualViewport;\ndeclare var window: Window & typeof globalThis;\ndeclare function alert(message?: any): void;\ndeclare function blur(): void;\n/** @deprecated */\ndeclare function captureEvents(): void;\ndeclare function close(): void;\ndeclare function confirm(message?: string): boolean;\ndeclare function departFocus(navigationReason: NavigationReason, origin: FocusNavigationOrigin): void;\ndeclare function focus(): void;\ndeclare function getComputedStyle(elt: Element, pseudoElt?: string | null): CSSStyleDeclaration;\ndeclare function getMatchedCSSRules(elt: Element, pseudoElt?: string | null): CSSRuleList;\ndeclare function getSelection(): Selection | null;\ndeclare function matchMedia(query: string): MediaQueryList;\ndeclare function moveBy(x: number, y: number): void;\ndeclare function moveTo(x: number, y: number): void;\ndeclare function msWriteProfilerMark(profilerMarkName: string): void;\ndeclare function open(url?: string, target?: string, features?: string, replace?: boolean): Window | null;\ndeclare function postMessage(message: any, targetOrigin: string, transfer?: Transferable[]): void;\ndeclare function print(): void;\ndeclare function prompt(message?: string, _default?: string): string | null;\n/** @deprecated */\ndeclare function releaseEvents(): void;\ndeclare function resizeBy(x: number, y: number): void;\ndeclare function resizeTo(width: number, height: number): void;\ndeclare function scroll(options?: ScrollToOptions): void;\ndeclare function scroll(x: number, y: number): void;\ndeclare function scrollBy(options?: ScrollToOptions): void;\ndeclare function scrollBy(x: number, y: number): void;\ndeclare function scrollTo(options?: ScrollToOptions): void;\ndeclare function scrollTo(x: number, y: number): void;\ndeclare function stop(): void;\ndeclare function webkitCancelAnimationFrame(handle: number): void;\ndeclare function webkitConvertPointFromNodeToPage(node: Node, pt: WebKitPoint): WebKitPoint;\ndeclare function webkitConvertPointFromPageToNode(node: Node, pt: WebKitPoint): WebKitPoint;\ndeclare function webkitRequestAnimationFrame(callback: FrameRequestCallback): number;\ndeclare function toString(): string;\n/**\n * Dispatches a synthetic event event to target and returns true if either event\'s cancelable attribute value is false or its preventDefault() method was not invoked, and false otherwise.\n */\ndeclare function dispatchEvent(event: Event): boolean;\ndeclare var sessionStorage: Storage;\ndeclare var localStorage: Storage;\n/**\n * Fires when the user aborts the download.\n * @param ev The event.\n */\ndeclare var onabort: ((this: Window, ev: UIEvent) => any) | null;\ndeclare var onanimationcancel: ((this: Window, ev: AnimationEvent) => any) | null;\ndeclare var onanimationend: ((this: Window, ev: AnimationEvent) => any) | null;\ndeclare var onanimationiteration: ((this: Window, ev: AnimationEvent) => any) | null;\ndeclare var onanimationstart: ((this: Window, ev: AnimationEvent) => any) | null;\ndeclare var onauxclick: ((this: Window, ev: MouseEvent) => any) | null;\n/**\n * Fires when the object loses the input focus.\n * @param ev The focus event.\n */\ndeclare var onblur: ((this: Window, ev: FocusEvent) => any) | null;\ndeclare var oncancel: ((this: Window, ev: Event) => any) | null;\n/**\n * Occurs when playback is possible, but would require further buffering.\n * @param ev The event.\n */\ndeclare var oncanplay: ((this: Window, ev: Event) => any) | null;\ndeclare var oncanplaythrough: ((this: Window, ev: Event) => any) | null;\n/**\n * Fires when the contents of the object or selection have changed.\n * @param ev The event.\n */\ndeclare var onchange: ((this: Window, ev: Event) => any) | null;\n/**\n * Fires when the user clicks the left mouse button on the object\n * @param ev The mouse event.\n */\ndeclare var onclick: ((this: Window, ev: MouseEvent) => any) | null;\ndeclare var onclose: ((this: Window, ev: Event) => any) | null;\n/**\n * Fires when the user clicks the right mouse button in the client area, opening the context menu.\n * @param ev The mouse event.\n */\ndeclare var oncontextmenu: ((this: Window, ev: MouseEvent) => any) | null;\ndeclare var oncuechange: ((this: Window, ev: Event) => any) | null;\n/**\n * Fires when the user double-clicks the object.\n * @param ev The mouse event.\n */\ndeclare var ondblclick: ((this: Window, ev: MouseEvent) => any) | null;\n/**\n * Fires on the source object continuously during a drag operation.\n * @param ev The event.\n */\ndeclare var ondrag: ((this: Window, ev: DragEvent) => any) | null;\n/**\n * Fires on the source object when the user releases the mouse at the close of a drag operation.\n * @param ev The event.\n */\ndeclare var ondragend: ((this: Window, ev: DragEvent) => any) | null;\n/**\n * Fires on the target element when the user drags the object to a valid drop target.\n * @param ev The drag event.\n */\ndeclare var ondragenter: ((this: Window, ev: DragEvent) => any) | null;\ndeclare var ondragexit: ((this: Window, ev: Event) => any) | null;\n/**\n * Fires on the target object when the user moves the mouse out of a valid drop target during a drag operation.\n * @param ev The drag event.\n */\ndeclare var ondragleave: ((this: Window, ev: DragEvent) => any) | null;\n/**\n * Fires on the target element continuously while the user drags the object over a valid drop target.\n * @param ev The event.\n */\ndeclare var ondragover: ((this: Window, ev: DragEvent) => any) | null;\n/**\n * Fires on the source object when the user starts to drag a text selection or selected object.\n * @param ev The event.\n */\ndeclare var ondragstart: ((this: Window, ev: DragEvent) => any) | null;\ndeclare var ondrop: ((this: Window, ev: DragEvent) => any) | null;\n/**\n * Occurs when the duration attribute is updated.\n * @param ev The event.\n */\ndeclare var ondurationchange: ((this: Window, ev: Event) => any) | null;\n/**\n * Occurs when the media element is reset to its initial state.\n * @param ev The event.\n */\ndeclare var onemptied: ((this: Window, ev: Event) => any) | null;\n/**\n * Occurs when the end of playback is reached.\n * @param ev The event\n */\ndeclare var onended: ((this: Window, ev: Event) => any) | null;\n/**\n * Fires when an error occurs during object loading.\n * @param ev The event.\n */\ndeclare var onerror: OnErrorEventHandler;\n/**\n * Fires when the object receives focus.\n * @param ev The event.\n */\ndeclare var onfocus: ((this: Window, ev: FocusEvent) => any) | null;\ndeclare var ongotpointercapture: ((this: Window, ev: PointerEvent) => any) | null;\ndeclare var oninput: ((this: Window, ev: Event) => any) | null;\ndeclare var oninvalid: ((this: Window, ev: Event) => any) | null;\n/**\n * Fires when the user presses a key.\n * @param ev The keyboard event\n */\ndeclare var onkeydown: ((this: Window, ev: KeyboardEvent) => any) | null;\n/**\n * Fires when the user presses an alphanumeric key.\n * @param ev The event.\n */\ndeclare var onkeypress: ((this: Window, ev: KeyboardEvent) => any) | null;\n/**\n * Fires when the user releases a key.\n * @param ev The keyboard event\n */\ndeclare var onkeyup: ((this: Window, ev: KeyboardEvent) => any) | null;\n/**\n * Fires immediately after the browser loads the object.\n * @param ev The event.\n */\ndeclare var onload: ((this: Window, ev: Event) => any) | null;\n/**\n * Occurs when media data is loaded at the current playback position.\n * @param ev The event.\n */\ndeclare var onloadeddata: ((this: Window, ev: Event) => any) | null;\n/**\n * Occurs when the duration and dimensions of the media have been determined.\n * @param ev The event.\n */\ndeclare var onloadedmetadata: ((this: Window, ev: Event) => any) | null;\n/**\n * Occurs when Internet Explorer begins looking for media data.\n * @param ev The event.\n */\ndeclare var onloadstart: ((this: Window, ev: Event) => any) | null;\ndeclare var onlostpointercapture: ((this: Window, ev: PointerEvent) => any) | null;\n/**\n * Fires when the user clicks the object with either mouse button.\n * @param ev The mouse event.\n */\ndeclare var onmousedown: ((this: Window, ev: MouseEvent) => any) | null;\ndeclare var onmouseenter: ((this: Window, ev: MouseEvent) => any) | null;\ndeclare var onmouseleave: ((this: Window, ev: MouseEvent) => any) | null;\n/**\n * Fires when the user moves the mouse over the object.\n * @param ev The mouse event.\n */\ndeclare var onmousemove: ((this: Window, ev: MouseEvent) => any) | null;\n/**\n * Fires when the user moves the mouse pointer outside the boundaries of the object.\n * @param ev The mouse event.\n */\ndeclare var onmouseout: ((this: Window, ev: MouseEvent) => any) | null;\n/**\n * Fires when the user moves the mouse pointer into the object.\n * @param ev The mouse event.\n */\ndeclare var onmouseover: ((this: Window, ev: MouseEvent) => any) | null;\n/**\n * Fires when the user releases a mouse button while the mouse is over the object.\n * @param ev The mouse event.\n */\ndeclare var onmouseup: ((this: Window, ev: MouseEvent) => any) | null;\n/**\n * Occurs when playback is paused.\n * @param ev The event.\n */\ndeclare var onpause: ((this: Window, ev: Event) => any) | null;\n/**\n * Occurs when the play method is requested.\n * @param ev The event.\n */\ndeclare var onplay: ((this: Window, ev: Event) => any) | null;\n/**\n * Occurs when the audio or video has started playing.\n * @param ev The event.\n */\ndeclare var onplaying: ((this: Window, ev: Event) => any) | null;\ndeclare var onpointercancel: ((this: Window, ev: PointerEvent) => any) | null;\ndeclare var onpointerdown: ((this: Window, ev: PointerEvent) => any) | null;\ndeclare var onpointerenter: ((this: Window, ev: PointerEvent) => any) | null;\ndeclare var onpointerleave: ((this: Window, ev: PointerEvent) => any) | null;\ndeclare var onpointermove: ((this: Window, ev: PointerEvent) => any) | null;\ndeclare var onpointerout: ((this: Window, ev: PointerEvent) => any) | null;\ndeclare var onpointerover: ((this: Window, ev: PointerEvent) => any) | null;\ndeclare var onpointerup: ((this: Window, ev: PointerEvent) => any) | null;\n/**\n * Occurs to indicate progress while downloading media data.\n * @param ev The event.\n */\ndeclare var onprogress: ((this: Window, ev: ProgressEvent) => any) | null;\n/**\n * Occurs when the playback rate is increased or decreased.\n * @param ev The event.\n */\ndeclare var onratechange: ((this: Window, ev: Event) => any) | null;\n/**\n * Fires when the user resets a form.\n * @param ev The event.\n */\ndeclare var onreset: ((this: Window, ev: Event) => any) | null;\ndeclare var onresize: ((this: Window, ev: UIEvent) => any) | null;\n/**\n * Fires when the user repositions the scroll box in the scroll bar on the object.\n * @param ev The event.\n */\ndeclare var onscroll: ((this: Window, ev: Event) => any) | null;\ndeclare var onsecuritypolicyviolation: ((this: Window, ev: SecurityPolicyViolationEvent) => any) | null;\n/**\n * Occurs when the seek operation ends.\n * @param ev The event.\n */\ndeclare var onseeked: ((this: Window, ev: Event) => any) | null;\n/**\n * Occurs when the current playback position is moved.\n * @param ev The event.\n */\ndeclare var onseeking: ((this: Window, ev: Event) => any) | null;\n/**\n * Fires when the current selection changes.\n * @param ev The event.\n */\ndeclare var onselect: ((this: Window, ev: Event) => any) | null;\ndeclare var onselectionchange: ((this: Window, ev: Event) => any) | null;\ndeclare var onselectstart: ((this: Window, ev: Event) => any) | null;\n/**\n * Occurs when the download has stopped.\n * @param ev The event.\n */\ndeclare var onstalled: ((this: Window, ev: Event) => any) | null;\ndeclare var onsubmit: ((this: Window, ev: Event) => any) | null;\n/**\n * Occurs if the load operation has been intentionally halted.\n * @param ev The event.\n */\ndeclare var onsuspend: ((this: Window, ev: Event) => any) | null;\n/**\n * Occurs to indicate the current playback position.\n * @param ev The event.\n */\ndeclare var ontimeupdate: ((this: Window, ev: Event) => any) | null;\ndeclare var ontoggle: ((this: Window, ev: Event) => any) | null;\ndeclare var ontouchcancel: ((this: Window, ev: TouchEvent) => any) | null | undefined;\ndeclare var ontouchend: ((this: Window, ev: TouchEvent) => any) | null | undefined;\ndeclare var ontouchmove: ((this: Window, ev: TouchEvent) => any) | null | undefined;\ndeclare var ontouchstart: ((this: Window, ev: TouchEvent) => any) | null | undefined;\ndeclare var ontransitioncancel: ((this: Window, ev: TransitionEvent) => any) | null;\ndeclare var ontransitionend: ((this: Window, ev: TransitionEvent) => any) | null;\ndeclare var ontransitionrun: ((this: Window, ev: TransitionEvent) => any) | null;\ndeclare var ontransitionstart: ((this: Window, ev: TransitionEvent) => any) | null;\n/**\n * Occurs when the volume is changed, or playback is muted or unmuted.\n * @param ev The event.\n */\ndeclare var onvolumechange: ((this: Window, ev: Event) => any) | null;\n/**\n * Occurs when playback stops because the next frame of a video resource is not available.\n * @param ev The event.\n */\ndeclare var onwaiting: ((this: Window, ev: Event) => any) | null;\ndeclare var onwheel: ((this: Window, ev: WheelEvent) => any) | null;\ndeclare function cancelAnimationFrame(handle: number): void;\ndeclare function requestAnimationFrame(callback: FrameRequestCallback): number;\ndeclare var caches: CacheStorage;\ndeclare var crypto: Crypto;\ndeclare var indexedDB: IDBFactory;\ndeclare var isSecureContext: boolean;\ndeclare var origin: string;\ndeclare var performance: Performance;\ndeclare function atob(data: string): string;\ndeclare function btoa(data: string): string;\ndeclare function clearInterval(handle?: number): void;\ndeclare function clearTimeout(handle?: number): void;\ndeclare function createImageBitmap(image: ImageBitmapSource, options?: ImageBitmapOptions): Promise<ImageBitmap>;\ndeclare function createImageBitmap(image: ImageBitmapSource, sx: number, sy: number, sw: number, sh: number, options?: ImageBitmapOptions): Promise<ImageBitmap>;\ndeclare function fetch(input: RequestInfo, init?: RequestInit): Promise<Response>;\ndeclare function queueMicrotask(callback: VoidFunction): void;\ndeclare function setInterval(handler: TimerHandler, timeout?: number, ...arguments: any[]): number;\ndeclare function setTimeout(handler: TimerHandler, timeout?: number, ...arguments: any[]): number;\ndeclare var onafterprint: ((this: Window, ev: Event) => any) | null;\ndeclare var onbeforeprint: ((this: Window, ev: Event) => any) | null;\ndeclare var onbeforeunload: ((this: Window, ev: BeforeUnloadEvent) => any) | null;\ndeclare var onhashchange: ((this: Window, ev: HashChangeEvent) => any) | null;\ndeclare var onlanguagechange: ((this: Window, ev: Event) => any) | null;\ndeclare var onmessage: ((this: Window, ev: MessageEvent) => any) | null;\ndeclare var onmessageerror: ((this: Window, ev: MessageEvent) => any) | null;\ndeclare var onoffline: ((this: Window, ev: Event) => any) | null;\ndeclare var ononline: ((this: Window, ev: Event) => any) | null;\ndeclare var onpagehide: ((this: Window, ev: PageTransitionEvent) => any) | null;\ndeclare var onpageshow: ((this: Window, ev: PageTransitionEvent) => any) | null;\ndeclare var onpopstate: ((this: Window, ev: PopStateEvent) => any) | null;\ndeclare var onrejectionhandled: ((this: Window, ev: PromiseRejectionEvent) => any) | null;\ndeclare var onstorage: ((this: Window, ev: StorageEvent) => any) | null;\ndeclare var onunhandledrejection: ((this: Window, ev: PromiseRejectionEvent) => any) | null;\ndeclare var onunload: ((this: Window, ev: Event) => any) | null;\ndeclare function addEventListener<K extends keyof WindowEventMap>(type: K, listener: (this: Window, ev: WindowEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\ndeclare function addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\ndeclare function removeEventListener<K extends keyof WindowEventMap>(type: K, listener: (this: Window, ev: WindowEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\ndeclare function removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\ntype HeadersInit = Headers | string[][] | Record<string, string>;\ntype BodyInit = Blob | BufferSource | FormData | URLSearchParams | ReadableStream<Uint8Array> | string;\ntype RequestInfo = Request | string;\ntype BlobPart = BufferSource | Blob | string;\ntype DOMHighResTimeStamp = number;\ntype RenderingContext = CanvasRenderingContext2D | ImageBitmapRenderingContext | WebGLRenderingContext | WebGL2RenderingContext;\ntype HTMLOrSVGImageElement = HTMLImageElement | SVGImageElement;\ntype CanvasImageSource = HTMLOrSVGImageElement | HTMLVideoElement | HTMLCanvasElement | ImageBitmap | OffscreenCanvas;\ntype OffscreenRenderingContext = OffscreenCanvasRenderingContext2D | ImageBitmapRenderingContext | WebGLRenderingContext | WebGL2RenderingContext;\ntype MessageEventSource = WindowProxy | MessagePort | ServiceWorker;\ntype HTMLOrSVGScriptElement = HTMLScriptElement | SVGScriptElement;\ntype ImageBitmapSource = CanvasImageSource | Blob | ImageData;\ntype MediaProvider = MediaStream | MediaSource | Blob;\ntype OnErrorEventHandler = OnErrorEventHandlerNonNull | null;\ntype OnBeforeUnloadEventHandler = OnBeforeUnloadEventHandlerNonNull | null;\ntype TimerHandler = string | Function;\ntype ConstrainULong = number | ConstrainULongRange;\ntype ConstrainDouble = number | ConstrainDoubleRange;\ntype ConstrainBoolean = boolean | ConstrainBooleanParameters;\ntype ConstrainDOMString = string | string[] | ConstrainDOMStringParameters;\ntype PerformanceEntryList = PerformanceEntry[];\ntype ReadableStreamReader<T> = ReadableStreamDefaultReader<T>;\ntype ReadableStreamController<T> = ReadableStreamDefaultController<T>;\ntype VibratePattern = number | number[];\ntype COSEAlgorithmIdentifier = number;\ntype UvmEntry = number[];\ntype UvmEntries = UvmEntry[];\ntype AlgorithmIdentifier = string | Algorithm;\ntype HashAlgorithmIdentifier = AlgorithmIdentifier;\ntype BigInteger = Uint8Array;\ntype NamedCurve = string;\ntype GLenum = number;\ntype GLboolean = boolean;\ntype GLbitfield = number;\ntype GLint = number;\ntype GLsizei = number;\ntype GLintptr = number;\ntype GLsizeiptr = number;\ntype GLuint = number;\ntype GLfloat = number;\ntype GLclampf = number;\ntype TexImageSource = ImageBitmap | ImageData | HTMLImageElement | HTMLCanvasElement | HTMLVideoElement | OffscreenCanvas;\ntype Float32List = Float32Array | GLfloat[];\ntype Int32List = Int32Array | GLint[];\ntype GLint64 = number;\ntype GLuint64 = number;\ntype Uint32List = Uint32Array | GLuint[];\ntype BufferSource = ArrayBufferView | ArrayBuffer;\ntype DOMTimeStamp = number;\ntype LineAndPositionSetting = number | AutoKeyword;\ntype FormDataEntryValue = File | string;\ntype InsertPosition = "beforebegin" | "afterbegin" | "beforeend" | "afterend";\ntype IDBValidKey = number | string | Date | BufferSource | IDBArrayKey;\ntype MutationRecordType = "attributes" | "characterData" | "childList";\ntype IDBKeyPath = string;\ntype Transferable = ArrayBuffer | MessagePort | ImageBitmap | OffscreenCanvas;\ntype RTCIceGatherCandidate = RTCIceCandidateDictionary | RTCIceCandidateComplete;\ntype RTCTransport = RTCDtlsTransport | RTCSrtpSdesTransport;\n/** @deprecated */\ntype MouseWheelEvent = WheelEvent;\ntype WindowProxy = Window;\ntype ReadableStreamDefaultReadResult<T> = ReadableStreamDefaultReadValueResult<T> | ReadableStreamDefaultReadDoneResult;\ntype AlignSetting = "center" | "end" | "left" | "right" | "start";\ntype AnimationPlayState = "finished" | "idle" | "paused" | "running";\ntype AppendMode = "segments" | "sequence";\ntype AttestationConveyancePreference = "direct" | "enterprise" | "indirect" | "none";\ntype AudioContextLatencyCategory = "balanced" | "interactive" | "playback";\ntype AudioContextState = "closed" | "running" | "suspended";\ntype AuthenticatorAttachment = "cross-platform" | "platform";\ntype AuthenticatorTransport = "ble" | "internal" | "nfc" | "usb";\ntype AutoKeyword = "auto";\ntype AutomationRate = "a-rate" | "k-rate";\ntype BinaryType = "arraybuffer" | "blob";\ntype BiquadFilterType = "allpass" | "bandpass" | "highpass" | "highshelf" | "lowpass" | "lowshelf" | "notch" | "peaking";\ntype CanPlayTypeResult = "" | "maybe" | "probably";\ntype CanvasDirection = "inherit" | "ltr" | "rtl";\ntype CanvasFillRule = "evenodd" | "nonzero";\ntype CanvasLineCap = "butt" | "round" | "square";\ntype CanvasLineJoin = "bevel" | "miter" | "round";\ntype CanvasTextAlign = "center" | "end" | "left" | "right" | "start";\ntype CanvasTextBaseline = "alphabetic" | "bottom" | "hanging" | "ideographic" | "middle" | "top";\ntype ChannelCountMode = "clamped-max" | "explicit" | "max";\ntype ChannelInterpretation = "discrete" | "speakers";\ntype ClientTypes = "all" | "sharedworker" | "window" | "worker";\ntype ColorSpaceConversion = "default" | "none";\ntype CompositeOperation = "accumulate" | "add" | "replace";\ntype CompositeOperationOrAuto = "accumulate" | "add" | "auto" | "replace";\ntype CredentialMediationRequirement = "optional" | "required" | "silent";\ntype DOMParserSupportedType = "application/xhtml+xml" | "application/xml" | "image/svg+xml" | "text/html" | "text/xml";\ntype DirectionSetting = "" | "lr" | "rl";\ntype DisplayCaptureSurfaceType = "application" | "browser" | "monitor" | "window";\ntype DistanceModelType = "exponential" | "inverse" | "linear";\ntype DocumentReadyState = "complete" | "interactive" | "loading";\ntype EndOfStreamError = "decode" | "network";\ntype EndingType = "native" | "transparent";\ntype FillMode = "auto" | "backwards" | "both" | "forwards" | "none";\ntype FullscreenNavigationUI = "auto" | "hide" | "show";\ntype GamepadHand = "" | "left" | "right";\ntype GamepadHapticActuatorType = "vibration";\ntype GamepadMappingType = "" | "standard";\ntype IDBCursorDirection = "next" | "nextunique" | "prev" | "prevunique";\ntype IDBRequestReadyState = "done" | "pending";\ntype IDBTransactionMode = "readonly" | "readwrite" | "versionchange";\ntype ImageOrientation = "flipY" | "none";\ntype ImageSmoothingQuality = "high" | "low" | "medium";\ntype IterationCompositeOperation = "accumulate" | "replace";\ntype KeyFormat = "jwk" | "pkcs8" | "raw" | "spki";\ntype KeyType = "private" | "public" | "secret";\ntype KeyUsage = "decrypt" | "deriveBits" | "deriveKey" | "encrypt" | "sign" | "unwrapKey" | "verify" | "wrapKey";\ntype LineAlignSetting = "center" | "end" | "start";\ntype ListeningState = "active" | "disambiguation" | "inactive";\ntype MSCredentialType = "FIDO_2_0";\ntype MSTransportType = "BT" | "Embedded" | "NFC" | "USB";\ntype MSWebViewPermissionState = "allow" | "defer" | "deny" | "unknown";\ntype MSWebViewPermissionType = "geolocation" | "media" | "pointerlock" | "unlimitedIndexedDBQuota" | "webnotifications";\ntype MediaDeviceKind = "audioinput" | "audiooutput" | "videoinput";\ntype MediaKeyMessageType = "individualization-request" | "license-release" | "license-renewal" | "license-request";\ntype MediaKeySessionType = "persistent-license" | "temporary";\ntype MediaKeyStatus = "expired" | "internal-error" | "output-downscaled" | "output-restricted" | "released" | "status-pending" | "usable";\ntype MediaKeysRequirement = "not-allowed" | "optional" | "required";\ntype MediaStreamTrackState = "ended" | "live";\ntype NavigationReason = "down" | "left" | "right" | "up";\ntype NavigationType = "back_forward" | "navigate" | "prerender" | "reload";\ntype NotificationDirection = "auto" | "ltr" | "rtl";\ntype NotificationPermission = "default" | "denied" | "granted";\ntype OffscreenRenderingContextId = "2d" | "bitmaprenderer" | "webgl" | "webgl2";\ntype OrientationLockType = "any" | "landscape" | "landscape-primary" | "landscape-secondary" | "natural" | "portrait" | "portrait-primary" | "portrait-secondary";\ntype OrientationType = "landscape-primary" | "landscape-secondary" | "portrait-primary" | "portrait-secondary";\ntype OscillatorType = "custom" | "sawtooth" | "sine" | "square" | "triangle";\ntype OverSampleType = "2x" | "4x" | "none";\ntype PanningModelType = "HRTF" | "equalpower";\ntype PaymentComplete = "fail" | "success" | "unknown";\ntype PaymentShippingType = "delivery" | "pickup" | "shipping";\ntype PermissionName = "accelerometer" | "ambient-light-sensor" | "background-fetch" | "background-sync" | "bluetooth" | "camera" | "clipboard-read" | "clipboard-write" | "device-info" | "display-capture" | "geolocation" | "gyroscope" | "magnetometer" | "microphone" | "midi" | "nfc" | "notifications" | "persistent-storage" | "push" | "speaker";\ntype PermissionState = "denied" | "granted" | "prompt";\ntype PlaybackDirection = "alternate" | "alternate-reverse" | "normal" | "reverse";\ntype PositionAlignSetting = "auto" | "center" | "line-left" | "line-right";\ntype PremultiplyAlpha = "default" | "none" | "premultiply";\ntype PublicKeyCredentialType = "public-key";\ntype PushEncryptionKeyName = "auth" | "p256dh";\ntype PushPermissionState = "denied" | "granted" | "prompt";\ntype RTCBundlePolicy = "balanced" | "max-bundle" | "max-compat";\ntype RTCDataChannelState = "closed" | "closing" | "connecting" | "open";\ntype RTCDtlsRole = "auto" | "client" | "server";\ntype RTCDtlsTransportState = "closed" | "connected" | "connecting" | "failed" | "new";\ntype RTCErrorDetailType = "data-channel-failure" | "dtls-failure" | "fingerprint-failure" | "hardware-encoder-error" | "hardware-encoder-not-available" | "sctp-failure" | "sdp-syntax-error";\ntype RTCIceCandidateType = "host" | "prflx" | "relay" | "srflx";\ntype RTCIceComponent = "rtcp" | "rtp";\ntype RTCIceConnectionState = "checking" | "closed" | "completed" | "connected" | "disconnected" | "failed" | "new";\ntype RTCIceCredentialType = "password";\ntype RTCIceGatherPolicy = "all" | "nohost" | "relay";\ntype RTCIceGathererState = "complete" | "gathering" | "new";\ntype RTCIceGatheringState = "complete" | "gathering" | "new";\ntype RTCIceProtocol = "tcp" | "udp";\ntype RTCIceRole = "controlled" | "controlling" | "unknown";\ntype RTCIceTcpCandidateType = "active" | "passive" | "so";\ntype RTCIceTransportPolicy = "all" | "relay";\ntype RTCIceTransportState = "checking" | "closed" | "completed" | "connected" | "disconnected" | "failed" | "new";\ntype RTCPeerConnectionState = "closed" | "connected" | "connecting" | "disconnected" | "failed" | "new";\ntype RTCRtcpMuxPolicy = "require";\ntype RTCRtpTransceiverDirection = "inactive" | "recvonly" | "sendonly" | "sendrecv" | "stopped";\ntype RTCSctpTransportState = "closed" | "connected" | "connecting";\ntype RTCSdpType = "answer" | "offer" | "pranswer" | "rollback";\ntype RTCSignalingState = "closed" | "have-local-offer" | "have-local-pranswer" | "have-remote-offer" | "have-remote-pranswer" | "stable";\ntype RTCStatsIceCandidatePairState = "failed" | "frozen" | "in-progress" | "succeeded" | "waiting";\ntype RTCStatsIceCandidateType = "host" | "peerreflexive" | "relayed" | "serverreflexive";\ntype RTCStatsType = "candidate-pair" | "certificate" | "codec" | "csrc" | "data-channel" | "ice-server" | "inbound-rtp" | "local-candidate" | "media-source" | "outbound-rtp" | "peer-connection" | "receiver" | "remote-candidate" | "remote-inbound-rtp" | "remote-outbound-rtp" | "sctp-transport" | "sender" | "stream" | "track" | "transceiver" | "transport";\ntype ReadyState = "closed" | "ended" | "open";\ntype ReferrerPolicy = "" | "no-referrer" | "no-referrer-when-downgrade" | "origin" | "origin-when-cross-origin" | "same-origin" | "strict-origin" | "strict-origin-when-cross-origin" | "unsafe-url";\ntype RequestCache = "default" | "force-cache" | "no-cache" | "no-store" | "only-if-cached" | "reload";\ntype RequestCredentials = "include" | "omit" | "same-origin";\ntype RequestDestination = "" | "audio" | "audioworklet" | "document" | "embed" | "font" | "image" | "manifest" | "object" | "paintworklet" | "report" | "script" | "sharedworker" | "style" | "track" | "video" | "worker" | "xslt";\ntype RequestMode = "cors" | "navigate" | "no-cors" | "same-origin";\ntype RequestRedirect = "error" | "follow" | "manual";\ntype ResidentKeyRequirement = "discouraged" | "preferred" | "required";\ntype ResizeObserverBoxOptions = "border-box" | "content-box" | "device-pixel-content-box";\ntype ResizeQuality = "high" | "low" | "medium" | "pixelated";\ntype ResponseType = "basic" | "cors" | "default" | "error" | "opaque" | "opaqueredirect";\ntype ScrollBehavior = "auto" | "smooth";\ntype ScrollLogicalPosition = "center" | "end" | "nearest" | "start";\ntype ScrollRestoration = "auto" | "manual";\ntype ScrollSetting = "" | "up";\ntype SelectionMode = "end" | "preserve" | "select" | "start";\ntype ServiceWorkerState = "activated" | "activating" | "installed" | "installing" | "parsed" | "redundant";\ntype ServiceWorkerUpdateViaCache = "all" | "imports" | "none";\ntype ShadowRootMode = "closed" | "open";\ntype SpeechRecognitionErrorCode = "aborted" | "audio-capture" | "bad-grammar" | "language-not-supported" | "network" | "no-speech" | "not-allowed" | "service-not-allowed";\ntype SpeechSynthesisErrorCode = "audio-busy" | "audio-hardware" | "canceled" | "interrupted" | "invalid-argument" | "language-unavailable" | "network" | "not-allowed" | "synthesis-failed" | "synthesis-unavailable" | "text-too-long" | "voice-unavailable";\ntype TextTrackKind = "captions" | "chapters" | "descriptions" | "metadata" | "subtitles";\ntype TextTrackMode = "disabled" | "hidden" | "showing";\ntype TouchType = "direct" | "stylus";\ntype UserVerificationRequirement = "discouraged" | "preferred" | "required";\ntype VRDisplayEventReason = "mounted" | "navigation" | "requested" | "unmounted";\ntype VideoFacingModeEnum = "environment" | "left" | "right" | "user";\ntype VisibilityState = "hidden" | "visible";\ntype WebGLPowerPreference = "default" | "high-performance" | "low-power";\ntype WorkerType = "classic" | "module";\ntype XMLHttpRequestResponseType = "" | "arraybuffer" | "blob" | "document" | "json" | "text";\n',"lib.dom.iterable.d.ts":'/*! *****************************************************************************\nCopyright (c) Microsoft Corporation. All rights reserved.\nLicensed under the Apache License, Version 2.0 (the "License"); you may not use\nthis file except in compliance with the License. You may obtain a copy of the\nLicense at http://www.apache.org/licenses/LICENSE-2.0\n\nTHIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\nKIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED\nWARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,\nMERCHANTABLITY OR NON-INFRINGEMENT.\n\nSee the Apache Version 2.0 License for specific language governing permissions\nand limitations under the License.\n***************************************************************************** */\n\n\n\n/// <reference no-default-lib="true"/>\n\n\n/////////////////////////////\n/// DOM Iterable APIs\n/////////////////////////////\n\ninterface AudioParam {\n    setValueCurveAtTime(values: Iterable<number>, startTime: number, duration: number): AudioParam;\n}\n\ninterface AudioParamMap extends ReadonlyMap<string, AudioParam> {\n}\n\ninterface BaseAudioContext {\n    createIIRFilter(feedforward: Iterable<number>, feedback: Iterable<number>): IIRFilterNode;\n    createPeriodicWave(real: Iterable<number>, imag: Iterable<number>, constraints?: PeriodicWaveConstraints): PeriodicWave;\n}\n\ninterface CSSRuleList {\n    [Symbol.iterator](): IterableIterator<CSSRule>;\n}\n\ninterface CSSStyleDeclaration {\n    [Symbol.iterator](): IterableIterator<string>;\n}\n\ninterface Cache {\n    addAll(requests: Iterable<RequestInfo>): Promise<void>;\n}\n\ninterface CanvasPathDrawingStyles {\n    setLineDash(segments: Iterable<number>): void;\n}\n\ninterface ClientRectList {\n    [Symbol.iterator](): IterableIterator<ClientRect>;\n}\n\ninterface DOMRectList {\n    [Symbol.iterator](): IterableIterator<DOMRect>;\n}\n\ninterface DOMStringList {\n    [Symbol.iterator](): IterableIterator<string>;\n}\n\ninterface DOMTokenList {\n    [Symbol.iterator](): IterableIterator<string>;\n    entries(): IterableIterator<[number, string]>;\n    keys(): IterableIterator<number>;\n    values(): IterableIterator<string>;\n}\n\ninterface DataTransferItemList {\n    [Symbol.iterator](): IterableIterator<DataTransferItem>;\n}\n\ninterface FileList {\n    [Symbol.iterator](): IterableIterator<File>;\n}\n\ninterface FormData {\n    [Symbol.iterator](): IterableIterator<[string, FormDataEntryValue]>;\n    /**\n     * Returns an array of key, value pairs for every entry in the list.\n     */\n    entries(): IterableIterator<[string, FormDataEntryValue]>;\n    /**\n     * Returns a list of keys in the list.\n     */\n    keys(): IterableIterator<string>;\n    /**\n     * Returns a list of values in the list.\n     */\n    values(): IterableIterator<FormDataEntryValue>;\n}\n\ninterface HTMLAllCollection {\n    [Symbol.iterator](): IterableIterator<Element>;\n}\n\ninterface HTMLCollectionBase {\n    [Symbol.iterator](): IterableIterator<Element>;\n}\n\ninterface HTMLCollectionOf<T extends Element> {\n    [Symbol.iterator](): IterableIterator<T>;\n}\n\ninterface HTMLFormElement {\n    [Symbol.iterator](): IterableIterator<Element>;\n}\n\ninterface HTMLSelectElement {\n    [Symbol.iterator](): IterableIterator<Element>;\n}\n\ninterface Headers {\n    [Symbol.iterator](): IterableIterator<[string, string]>;\n    /**\n     * Returns an iterator allowing to go through all key/value pairs contained in this object.\n     */\n    entries(): IterableIterator<[string, string]>;\n    /**\n     * Returns an iterator allowing to go through all keys of the key/value pairs contained in this object.\n     */\n    keys(): IterableIterator<string>;\n    /**\n     * Returns an iterator allowing to go through all values of the key/value pairs contained in this object.\n     */\n    values(): IterableIterator<string>;\n}\n\ninterface IDBDatabase {\n    /**\n     * Returns a new transaction with the given mode ("readonly" or "readwrite") and scope which can be a single object store name or an array of names.\n     */\n    transaction(storeNames: string | Iterable<string>, mode?: IDBTransactionMode): IDBTransaction;\n}\n\ninterface IDBObjectStore {\n    /**\n     * Creates a new index in store with the given name, keyPath and options and returns a new IDBIndex. If the keyPath and options define constraints that cannot be satisfied with the data already in store the upgrade transaction will abort with a "ConstraintError" DOMException.\n     *\n     * Throws an "InvalidStateError" DOMException if not called within an upgrade transaction.\n     */\n    createIndex(name: string, keyPath: string | Iterable<string>, options?: IDBIndexParameters): IDBIndex;\n}\n\ninterface MediaKeyStatusMap {\n    [Symbol.iterator](): IterableIterator<[BufferSource, MediaKeyStatus]>;\n    entries(): IterableIterator<[BufferSource, MediaKeyStatus]>;\n    keys(): IterableIterator<BufferSource>;\n    values(): IterableIterator<MediaKeyStatus>;\n}\n\ninterface MediaList {\n    [Symbol.iterator](): IterableIterator<string>;\n}\n\ninterface MimeTypeArray {\n    [Symbol.iterator](): IterableIterator<MimeType>;\n}\n\ninterface NamedNodeMap {\n    [Symbol.iterator](): IterableIterator<Attr>;\n}\n\ninterface Navigator {\n    requestMediaKeySystemAccess(keySystem: string, supportedConfigurations: Iterable<MediaKeySystemConfiguration>): Promise<MediaKeySystemAccess>;\n}\n\ninterface NodeList {\n    [Symbol.iterator](): IterableIterator<Node>;\n    /**\n     * Returns an array of key, value pairs for every entry in the list.\n     */\n    entries(): IterableIterator<[number, Node]>;\n    /**\n     * Returns an list of keys in the list.\n     */\n    keys(): IterableIterator<number>;\n    /**\n     * Returns an list of values in the list.\n     */\n    values(): IterableIterator<Node>;\n}\n\ninterface NodeListOf<TNode extends Node> {\n    [Symbol.iterator](): IterableIterator<TNode>;\n    /**\n     * Returns an array of key, value pairs for every entry in the list.\n     */\n    entries(): IterableIterator<[number, TNode]>;\n    /**\n     * Returns an list of keys in the list.\n     */\n    keys(): IterableIterator<number>;\n    /**\n     * Returns an list of values in the list.\n     */\n    values(): IterableIterator<TNode>;\n}\n\ninterface Plugin {\n    [Symbol.iterator](): IterableIterator<MimeType>;\n}\n\ninterface PluginArray {\n    [Symbol.iterator](): IterableIterator<Plugin>;\n}\n\ninterface RTCRtpTransceiver {\n    setCodecPreferences(codecs: Iterable<RTCRtpCodecCapability>): void;\n}\n\ninterface RTCStatsReport extends ReadonlyMap<string, any> {\n}\n\ninterface SVGLengthList {\n    [Symbol.iterator](): IterableIterator<SVGLength>;\n}\n\ninterface SVGNumberList {\n    [Symbol.iterator](): IterableIterator<SVGNumber>;\n}\n\ninterface SVGPointList {\n    [Symbol.iterator](): IterableIterator<DOMPoint>;\n}\n\ninterface SVGStringList {\n    [Symbol.iterator](): IterableIterator<string>;\n}\n\ninterface SourceBufferList {\n    [Symbol.iterator](): IterableIterator<SourceBuffer>;\n}\n\ninterface SpeechGrammarList {\n    [Symbol.iterator](): IterableIterator<SpeechGrammar>;\n}\n\ninterface SpeechRecognitionResult {\n    [Symbol.iterator](): IterableIterator<SpeechRecognitionAlternative>;\n}\n\ninterface SpeechRecognitionResultList {\n    [Symbol.iterator](): IterableIterator<SpeechRecognitionResult>;\n}\n\ninterface StyleSheetList {\n    [Symbol.iterator](): IterableIterator<CSSStyleSheet>;\n}\n\ninterface TextTrackCueList {\n    [Symbol.iterator](): IterableIterator<TextTrackCue>;\n}\n\ninterface TextTrackList {\n    [Symbol.iterator](): IterableIterator<TextTrack>;\n}\n\ninterface TouchList {\n    [Symbol.iterator](): IterableIterator<Touch>;\n}\n\ninterface URLSearchParams {\n    [Symbol.iterator](): IterableIterator<[string, string]>;\n    /**\n     * Returns an array of key, value pairs for every entry in the search params.\n     */\n    entries(): IterableIterator<[string, string]>;\n    /**\n     * Returns a list of keys in the search params.\n     */\n    keys(): IterableIterator<string>;\n    /**\n     * Returns a list of values in the search params.\n     */\n    values(): IterableIterator<string>;\n}\n\ninterface VRDisplay {\n    requestPresent(layers: Iterable<VRLayer>): Promise<void>;\n}\n\ninterface WEBGL_draw_buffers {\n    drawBuffersWEBGL(buffers: Iterable<GLenum>): void;\n}\n\ninterface WebGL2RenderingContextBase {\n    clearBufferfv(buffer: GLenum, drawbuffer: GLint, values: Iterable<GLfloat>, srcOffset?: GLuint): void;\n    clearBufferiv(buffer: GLenum, drawbuffer: GLint, values: Iterable<GLint>, srcOffset?: GLuint): void;\n    clearBufferuiv(buffer: GLenum, drawbuffer: GLint, values: Iterable<GLuint>, srcOffset?: GLuint): void;\n    drawBuffers(buffers: Iterable<GLenum>): void;\n    getActiveUniforms(program: WebGLProgram, uniformIndices: Iterable<GLuint>, pname: GLenum): any;\n    getUniformIndices(program: WebGLProgram, uniformNames: Iterable<string>): Iterable<GLuint> | null;\n    invalidateFramebuffer(target: GLenum, attachments: Iterable<GLenum>): void;\n    invalidateSubFramebuffer(target: GLenum, attachments: Iterable<GLenum>, x: GLint, y: GLint, width: GLsizei, height: GLsizei): void;\n    transformFeedbackVaryings(program: WebGLProgram, varyings: Iterable<string>, bufferMode: GLenum): void;\n    uniform1uiv(location: WebGLUniformLocation | null, data: Iterable<GLuint>, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniform2uiv(location: WebGLUniformLocation | null, data: Iterable<GLuint>, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniform3uiv(location: WebGLUniformLocation | null, data: Iterable<GLuint>, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniform4uiv(location: WebGLUniformLocation | null, data: Iterable<GLuint>, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniformMatrix2x3fv(location: WebGLUniformLocation | null, transpose: GLboolean, data: Iterable<GLfloat>, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniformMatrix2x4fv(location: WebGLUniformLocation | null, transpose: GLboolean, data: Iterable<GLfloat>, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniformMatrix3x2fv(location: WebGLUniformLocation | null, transpose: GLboolean, data: Iterable<GLfloat>, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniformMatrix3x4fv(location: WebGLUniformLocation | null, transpose: GLboolean, data: Iterable<GLfloat>, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniformMatrix4x2fv(location: WebGLUniformLocation | null, transpose: GLboolean, data: Iterable<GLfloat>, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniformMatrix4x3fv(location: WebGLUniformLocation | null, transpose: GLboolean, data: Iterable<GLfloat>, srcOffset?: GLuint, srcLength?: GLuint): void;\n    vertexAttribI4iv(index: GLuint, values: Iterable<GLint>): void;\n    vertexAttribI4uiv(index: GLuint, values: Iterable<GLuint>): void;\n}\n\ninterface WebGL2RenderingContextOverloads {\n    uniform1fv(location: WebGLUniformLocation | null, data: Iterable<GLfloat>, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniform1iv(location: WebGLUniformLocation | null, data: Iterable<GLint>, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniform2fv(location: WebGLUniformLocation | null, data: Iterable<GLfloat>, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniform2iv(location: WebGLUniformLocation | null, data: Iterable<GLint>, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniform3fv(location: WebGLUniformLocation | null, data: Iterable<GLfloat>, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniform3iv(location: WebGLUniformLocation | null, data: Iterable<GLint>, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniform4fv(location: WebGLUniformLocation | null, data: Iterable<GLfloat>, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniform4iv(location: WebGLUniformLocation | null, data: Iterable<GLint>, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniformMatrix2fv(location: WebGLUniformLocation | null, transpose: GLboolean, data: Iterable<GLfloat>, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniformMatrix3fv(location: WebGLUniformLocation | null, transpose: GLboolean, data: Iterable<GLfloat>, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniformMatrix4fv(location: WebGLUniformLocation | null, transpose: GLboolean, data: Iterable<GLfloat>, srcOffset?: GLuint, srcLength?: GLuint): void;\n}\n\ninterface WebGLRenderingContextBase {\n    vertexAttrib1fv(index: GLuint, values: Iterable<GLfloat>): void;\n    vertexAttrib2fv(index: GLuint, values: Iterable<GLfloat>): void;\n    vertexAttrib3fv(index: GLuint, values: Iterable<GLfloat>): void;\n    vertexAttrib4fv(index: GLuint, values: Iterable<GLfloat>): void;\n}\n\ninterface WebGLRenderingContextOverloads {\n    uniform1fv(location: WebGLUniformLocation | null, v: Iterable<GLfloat>): void;\n    uniform1iv(location: WebGLUniformLocation | null, v: Iterable<GLint>): void;\n    uniform2fv(location: WebGLUniformLocation | null, v: Iterable<GLfloat>): void;\n    uniform2iv(location: WebGLUniformLocation | null, v: Iterable<GLint>): void;\n    uniform3fv(location: WebGLUniformLocation | null, v: Iterable<GLfloat>): void;\n    uniform3iv(location: WebGLUniformLocation | null, v: Iterable<GLint>): void;\n    uniform4fv(location: WebGLUniformLocation | null, v: Iterable<GLfloat>): void;\n    uniform4iv(location: WebGLUniformLocation | null, v: Iterable<GLint>): void;\n    uniformMatrix2fv(location: WebGLUniformLocation | null, transpose: GLboolean, value: Iterable<GLfloat>): void;\n    uniformMatrix3fv(location: WebGLUniformLocation | null, transpose: GLboolean, value: Iterable<GLfloat>): void;\n    uniformMatrix4fv(location: WebGLUniformLocation | null, transpose: GLboolean, value: Iterable<GLfloat>): void;\n}\n',"lib.es2015.collection.d.ts":'/*! *****************************************************************************\nCopyright (c) Microsoft Corporation. All rights reserved.\nLicensed under the Apache License, Version 2.0 (the "License"); you may not use\nthis file except in compliance with the License. You may obtain a copy of the\nLicense at http://www.apache.org/licenses/LICENSE-2.0\n\nTHIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\nKIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED\nWARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,\nMERCHANTABLITY OR NON-INFRINGEMENT.\n\nSee the Apache Version 2.0 License for specific language governing permissions\nand limitations under the License.\n***************************************************************************** */\n\n\n\n/// <reference no-default-lib="true"/>\n\n\ninterface Map<K, V> {\n    clear(): void;\n    delete(key: K): boolean;\n    forEach(callbackfn: (value: V, key: K, map: Map<K, V>) => void, thisArg?: any): void;\n    get(key: K): V | undefined;\n    has(key: K): boolean;\n    set(key: K, value: V): this;\n    readonly size: number;\n}\n\ninterface MapConstructor {\n    new(): Map<any, any>;\n    new<K, V>(entries?: readonly (readonly [K, V])[] | null): Map<K, V>;\n    readonly prototype: Map<any, any>;\n}\ndeclare var Map: MapConstructor;\n\ninterface ReadonlyMap<K, V> {\n    forEach(callbackfn: (value: V, key: K, map: ReadonlyMap<K, V>) => void, thisArg?: any): void;\n    get(key: K): V | undefined;\n    has(key: K): boolean;\n    readonly size: number;\n}\n\ninterface WeakMap<K extends object, V> {\n    delete(key: K): boolean;\n    get(key: K): V | undefined;\n    has(key: K): boolean;\n    set(key: K, value: V): this;\n}\n\ninterface WeakMapConstructor {\n    new <K extends object = object, V = any>(entries?: readonly [K, V][] | null): WeakMap<K, V>;\n    readonly prototype: WeakMap<object, any>;\n}\ndeclare var WeakMap: WeakMapConstructor;\n\ninterface Set<T> {\n    add(value: T): this;\n    clear(): void;\n    delete(value: T): boolean;\n    forEach(callbackfn: (value: T, value2: T, set: Set<T>) => void, thisArg?: any): void;\n    has(value: T): boolean;\n    readonly size: number;\n}\n\ninterface SetConstructor {\n    new <T = any>(values?: readonly T[] | null): Set<T>;\n    readonly prototype: Set<any>;\n}\ndeclare var Set: SetConstructor;\n\ninterface ReadonlySet<T> {\n    forEach(callbackfn: (value: T, value2: T, set: ReadonlySet<T>) => void, thisArg?: any): void;\n    has(value: T): boolean;\n    readonly size: number;\n}\n\ninterface WeakSet<T extends object> {\n    add(value: T): this;\n    delete(value: T): boolean;\n    has(value: T): boolean;\n}\n\ninterface WeakSetConstructor {\n    new <T extends object = object>(values?: readonly T[] | null): WeakSet<T>;\n    readonly prototype: WeakSet<object>;\n}\ndeclare var WeakSet: WeakSetConstructor;\n',"lib.es2015.core.d.ts":'/*! *****************************************************************************\nCopyright (c) Microsoft Corporation. All rights reserved.\nLicensed under the Apache License, Version 2.0 (the "License"); you may not use\nthis file except in compliance with the License. You may obtain a copy of the\nLicense at http://www.apache.org/licenses/LICENSE-2.0\n\nTHIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\nKIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED\nWARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,\nMERCHANTABLITY OR NON-INFRINGEMENT.\n\nSee the Apache Version 2.0 License for specific language governing permissions\nand limitations under the License.\n***************************************************************************** */\n\n\n\n/// <reference no-default-lib="true"/>\n\n\ninterface Array<T> {\n    /**\n     * Returns the value of the first element in the array where predicate is true, and undefined\n     * otherwise.\n     * @param predicate find calls predicate once for each element of the array, in ascending\n     * order, until it finds one where predicate returns true. If such an element is found, find\n     * immediately returns that element value. Otherwise, find returns undefined.\n     * @param thisArg If provided, it will be used as the this value for each invocation of\n     * predicate. If it is not provided, undefined is used instead.\n     */\n    find<S extends T>(predicate: (this: void, value: T, index: number, obj: T[]) => value is S, thisArg?: any): S | undefined;\n    find(predicate: (value: T, index: number, obj: T[]) => unknown, thisArg?: any): T | undefined;\n\n    /**\n     * Returns the index of the first element in the array where predicate is true, and -1\n     * otherwise.\n     * @param predicate find calls predicate once for each element of the array, in ascending\n     * order, until it finds one where predicate returns true. If such an element is found,\n     * findIndex immediately returns that element index. Otherwise, findIndex returns -1.\n     * @param thisArg If provided, it will be used as the this value for each invocation of\n     * predicate. If it is not provided, undefined is used instead.\n     */\n    findIndex(predicate: (value: T, index: number, obj: T[]) => unknown, thisArg?: any): number;\n\n    /**\n     * Returns the this object after filling the section identified by start and end with value\n     * @param value value to fill array section with\n     * @param start index to start filling the array at. If start is negative, it is treated as\n     * length+start where length is the length of the array.\n     * @param end index to stop filling the array at. If end is negative, it is treated as\n     * length+end.\n     */\n    fill(value: T, start?: number, end?: number): this;\n\n    /**\n     * Returns the this object after copying a section of the array identified by start and end\n     * to the same array starting at position target\n     * @param target If target is negative, it is treated as length+target where length is the\n     * length of the array.\n     * @param start If start is negative, it is treated as length+start. If end is negative, it\n     * is treated as length+end.\n     * @param end If not specified, length of the this object is used as its default value.\n     */\n    copyWithin(target: number, start: number, end?: number): this;\n}\n\ninterface ArrayConstructor {\n    /**\n     * Creates an array from an array-like object.\n     * @param arrayLike An array-like object to convert to an array.\n     */\n    from<T>(arrayLike: ArrayLike<T>): T[];\n\n    /**\n     * Creates an array from an iterable object.\n     * @param arrayLike An array-like object to convert to an array.\n     * @param mapfn A mapping function to call on every element of the array.\n     * @param thisArg Value of \'this\' used to invoke the mapfn.\n     */\n    from<T, U>(arrayLike: ArrayLike<T>, mapfn: (v: T, k: number) => U, thisArg?: any): U[];\n\n    /**\n     * Returns a new array from a set of elements.\n     * @param items A set of elements to include in the new array object.\n     */\n    of<T>(...items: T[]): T[];\n}\n\ninterface DateConstructor {\n    new (value: number | string | Date): Date;\n}\n\ninterface Function {\n    /**\n     * Returns the name of the function. Function names are read-only and can not be changed.\n     */\n    readonly name: string;\n}\n\ninterface Math {\n    /**\n     * Returns the number of leading zero bits in the 32-bit binary representation of a number.\n     * @param x A numeric expression.\n     */\n    clz32(x: number): number;\n\n    /**\n     * Returns the result of 32-bit multiplication of two numbers.\n     * @param x First number\n     * @param y Second number\n     */\n    imul(x: number, y: number): number;\n\n    /**\n     * Returns the sign of the x, indicating whether x is positive, negative or zero.\n     * @param x The numeric expression to test\n     */\n    sign(x: number): number;\n\n    /**\n     * Returns the base 10 logarithm of a number.\n     * @param x A numeric expression.\n     */\n    log10(x: number): number;\n\n    /**\n     * Returns the base 2 logarithm of a number.\n     * @param x A numeric expression.\n     */\n    log2(x: number): number;\n\n    /**\n     * Returns the natural logarithm of 1 + x.\n     * @param x A numeric expression.\n     */\n    log1p(x: number): number;\n\n    /**\n     * Returns the result of (e^x - 1), which is an implementation-dependent approximation to\n     * subtracting 1 from the exponential function of x (e raised to the power of x, where e\n     * is the base of the natural logarithms).\n     * @param x A numeric expression.\n     */\n    expm1(x: number): number;\n\n    /**\n     * Returns the hyperbolic cosine of a number.\n     * @param x A numeric expression that contains an angle measured in radians.\n     */\n    cosh(x: number): number;\n\n    /**\n     * Returns the hyperbolic sine of a number.\n     * @param x A numeric expression that contains an angle measured in radians.\n     */\n    sinh(x: number): number;\n\n    /**\n     * Returns the hyperbolic tangent of a number.\n     * @param x A numeric expression that contains an angle measured in radians.\n     */\n    tanh(x: number): number;\n\n    /**\n     * Returns the inverse hyperbolic cosine of a number.\n     * @param x A numeric expression that contains an angle measured in radians.\n     */\n    acosh(x: number): number;\n\n    /**\n     * Returns the inverse hyperbolic sine of a number.\n     * @param x A numeric expression that contains an angle measured in radians.\n     */\n    asinh(x: number): number;\n\n    /**\n     * Returns the inverse hyperbolic tangent of a number.\n     * @param x A numeric expression that contains an angle measured in radians.\n     */\n    atanh(x: number): number;\n\n    /**\n     * Returns the square root of the sum of squares of its arguments.\n     * @param values Values to compute the square root for.\n     *     If no arguments are passed, the result is +0.\n     *     If there is only one argument, the result is the absolute value.\n     *     If any argument is +Infinity or -Infinity, the result is +Infinity.\n     *     If any argument is NaN, the result is NaN.\n     *     If all arguments are either +0 or −0, the result is +0.\n     */\n    hypot(...values: number[]): number;\n\n    /**\n     * Returns the integral part of the a numeric expression, x, removing any fractional digits.\n     * If x is already an integer, the result is x.\n     * @param x A numeric expression.\n     */\n    trunc(x: number): number;\n\n    /**\n     * Returns the nearest single precision float representation of a number.\n     * @param x A numeric expression.\n     */\n    fround(x: number): number;\n\n    /**\n     * Returns an implementation-dependent approximation to the cube root of number.\n     * @param x A numeric expression.\n     */\n    cbrt(x: number): number;\n}\n\ninterface NumberConstructor {\n    /**\n     * The value of Number.EPSILON is the difference between 1 and the smallest value greater than 1\n     * that is representable as a Number value, which is approximately:\n     * 2.2204460492503130808472633361816 x 10‍−‍16.\n     */\n    readonly EPSILON: number;\n\n    /**\n     * Returns true if passed value is finite.\n     * Unlike the global isFinite, Number.isFinite doesn\'t forcibly convert the parameter to a\n     * number. Only finite values of the type number, result in true.\n     * @param number A numeric value.\n     */\n    isFinite(number: unknown): boolean;\n\n    /**\n     * Returns true if the value passed is an integer, false otherwise.\n     * @param number A numeric value.\n     */\n    isInteger(number: unknown): boolean;\n\n    /**\n     * Returns a Boolean value that indicates whether a value is the reserved value NaN (not a\n     * number). Unlike the global isNaN(), Number.isNaN() doesn\'t forcefully convert the parameter\n     * to a number. Only values of the type number, that are also NaN, result in true.\n     * @param number A numeric value.\n     */\n    isNaN(number: unknown): boolean;\n\n    /**\n     * Returns true if the value passed is a safe integer.\n     * @param number A numeric value.\n     */\n    isSafeInteger(number: unknown): boolean;\n\n    /**\n     * The value of the largest integer n such that n and n + 1 are both exactly representable as\n     * a Number value.\n     * The value of Number.MAX_SAFE_INTEGER is 9007199254740991 2^53 − 1.\n     */\n    readonly MAX_SAFE_INTEGER: number;\n\n    /**\n     * The value of the smallest integer n such that n and n − 1 are both exactly representable as\n     * a Number value.\n     * The value of Number.MIN_SAFE_INTEGER is −9007199254740991 (−(2^53 − 1)).\n     */\n    readonly MIN_SAFE_INTEGER: number;\n\n    /**\n     * Converts a string to a floating-point number.\n     * @param string A string that contains a floating-point number.\n     */\n    parseFloat(string: string): number;\n\n    /**\n     * Converts A string to an integer.\n     * @param string A string to convert into a number.\n     * @param radix A value between 2 and 36 that specifies the base of the number in `string`.\n     * If this argument is not supplied, strings with a prefix of \'0x\' are considered hexadecimal.\n     * All other strings are considered decimal.\n     */\n    parseInt(string: string, radix?: number): number;\n}\n\ninterface ObjectConstructor {\n    /**\n     * Copy the values of all of the enumerable own properties from one or more source objects to a\n     * target object. Returns the target object.\n     * @param target The target object to copy to.\n     * @param source The source object from which to copy properties.\n     */\n    assign<T, U>(target: T, source: U): T & U;\n\n    /**\n     * Copy the values of all of the enumerable own properties from one or more source objects to a\n     * target object. Returns the target object.\n     * @param target The target object to copy to.\n     * @param source1 The first source object from which to copy properties.\n     * @param source2 The second source object from which to copy properties.\n     */\n    assign<T, U, V>(target: T, source1: U, source2: V): T & U & V;\n\n    /**\n     * Copy the values of all of the enumerable own properties from one or more source objects to a\n     * target object. Returns the target object.\n     * @param target The target object to copy to.\n     * @param source1 The first source object from which to copy properties.\n     * @param source2 The second source object from which to copy properties.\n     * @param source3 The third source object from which to copy properties.\n     */\n    assign<T, U, V, W>(target: T, source1: U, source2: V, source3: W): T & U & V & W;\n\n    /**\n     * Copy the values of all of the enumerable own properties from one or more source objects to a\n     * target object. Returns the target object.\n     * @param target The target object to copy to.\n     * @param sources One or more source objects from which to copy properties\n     */\n    assign(target: object, ...sources: any[]): any;\n\n    /**\n     * Returns an array of all symbol properties found directly on object o.\n     * @param o Object to retrieve the symbols from.\n     */\n    getOwnPropertySymbols(o: any): symbol[];\n\n    /**\n     * Returns the names of the enumerable string properties and methods of an object.\n     * @param o Object that contains the properties and methods. This can be an object that you created or an existing Document Object Model (DOM) object.\n     */\n    keys(o: {}): string[];\n\n    /**\n     * Returns true if the values are the same value, false otherwise.\n     * @param value1 The first value.\n     * @param value2 The second value.\n     */\n    is(value1: any, value2: any): boolean;\n\n    /**\n     * Sets the prototype of a specified object o to object proto or null. Returns the object o.\n     * @param o The object to change its prototype.\n     * @param proto The value of the new prototype or null.\n     */\n    setPrototypeOf(o: any, proto: object | null): any;\n}\n\ninterface ReadonlyArray<T> {\n    /**\n     * Returns the value of the first element in the array where predicate is true, and undefined\n     * otherwise.\n     * @param predicate find calls predicate once for each element of the array, in ascending\n     * order, until it finds one where predicate returns true. If such an element is found, find\n     * immediately returns that element value. Otherwise, find returns undefined.\n     * @param thisArg If provided, it will be used as the this value for each invocation of\n     * predicate. If it is not provided, undefined is used instead.\n     */\n    find<S extends T>(predicate: (this: void, value: T, index: number, obj: readonly T[]) => value is S, thisArg?: any): S | undefined;\n    find(predicate: (value: T, index: number, obj: readonly T[]) => unknown, thisArg?: any): T | undefined;\n\n    /**\n     * Returns the index of the first element in the array where predicate is true, and -1\n     * otherwise.\n     * @param predicate find calls predicate once for each element of the array, in ascending\n     * order, until it finds one where predicate returns true. If such an element is found,\n     * findIndex immediately returns that element index. Otherwise, findIndex returns -1.\n     * @param thisArg If provided, it will be used as the this value for each invocation of\n     * predicate. If it is not provided, undefined is used instead.\n     */\n    findIndex(predicate: (value: T, index: number, obj: readonly T[]) => unknown, thisArg?: any): number;\n}\n\ninterface RegExp {\n    /**\n     * Returns a string indicating the flags of the regular expression in question. This field is read-only.\n     * The characters in this string are sequenced and concatenated in the following order:\n     *\n     *    - "g" for global\n     *    - "i" for ignoreCase\n     *    - "m" for multiline\n     *    - "u" for unicode\n     *    - "y" for sticky\n     *\n     * If no flags are set, the value is the empty string.\n     */\n    readonly flags: string;\n\n    /**\n     * Returns a Boolean value indicating the state of the sticky flag (y) used with a regular\n     * expression. Default is false. Read-only.\n     */\n    readonly sticky: boolean;\n\n    /**\n     * Returns a Boolean value indicating the state of the Unicode flag (u) used with a regular\n     * expression. Default is false. Read-only.\n     */\n    readonly unicode: boolean;\n}\n\ninterface RegExpConstructor {\n    new (pattern: RegExp | string, flags?: string): RegExp;\n    (pattern: RegExp | string, flags?: string): RegExp;\n}\n\ninterface String {\n    /**\n     * Returns a nonnegative integer Number less than 1114112 (0x110000) that is the code point\n     * value of the UTF-16 encoded code point starting at the string element at position pos in\n     * the String resulting from converting this object to a String.\n     * If there is no element at that position, the result is undefined.\n     * If a valid UTF-16 surrogate pair does not begin at pos, the result is the code unit at pos.\n     */\n    codePointAt(pos: number): number | undefined;\n\n    /**\n     * Returns true if searchString appears as a substring of the result of converting this\n     * object to a String, at one or more positions that are\n     * greater than or equal to position; otherwise, returns false.\n     * @param searchString search string\n     * @param position If position is undefined, 0 is assumed, so as to search all of the String.\n     */\n    includes(searchString: string, position?: number): boolean;\n\n    /**\n     * Returns true if the sequence of elements of searchString converted to a String is the\n     * same as the corresponding elements of this object (converted to a String) starting at\n     * endPosition – length(this). Otherwise returns false.\n     */\n    endsWith(searchString: string, endPosition?: number): boolean;\n\n    /**\n     * Returns the String value result of normalizing the string into the normalization form\n     * named by form as specified in Unicode Standard Annex #15, Unicode Normalization Forms.\n     * @param form Applicable values: "NFC", "NFD", "NFKC", or "NFKD", If not specified default\n     * is "NFC"\n     */\n    normalize(form: "NFC" | "NFD" | "NFKC" | "NFKD"): string;\n\n    /**\n     * Returns the String value result of normalizing the string into the normalization form\n     * named by form as specified in Unicode Standard Annex #15, Unicode Normalization Forms.\n     * @param form Applicable values: "NFC", "NFD", "NFKC", or "NFKD", If not specified default\n     * is "NFC"\n     */\n    normalize(form?: string): string;\n\n    /**\n     * Returns a String value that is made from count copies appended together. If count is 0,\n     * the empty string is returned.\n     * @param count number of copies to append\n     */\n    repeat(count: number): string;\n\n    /**\n     * Returns true if the sequence of elements of searchString converted to a String is the\n     * same as the corresponding elements of this object (converted to a String) starting at\n     * position. Otherwise returns false.\n     */\n    startsWith(searchString: string, position?: number): boolean;\n\n    /**\n     * Returns an `<a>` HTML anchor element and sets the name attribute to the text value\n     * @param name\n     */\n    anchor(name: string): string;\n\n    /** Returns a `<big>` HTML element */\n    big(): string;\n\n    /** Returns a `<blink>` HTML element */\n    blink(): string;\n\n    /** Returns a `<b>` HTML element */\n    bold(): string;\n\n    /** Returns a `<tt>` HTML element */\n    fixed(): string;\n\n    /** Returns a `<font>` HTML element and sets the color attribute value */\n    fontcolor(color: string): string;\n\n    /** Returns a `<font>` HTML element and sets the size attribute value */\n    fontsize(size: number): string;\n\n    /** Returns a `<font>` HTML element and sets the size attribute value */\n    fontsize(size: string): string;\n\n    /** Returns an `<i>` HTML element */\n    italics(): string;\n\n    /** Returns an `<a>` HTML element and sets the href attribute value */\n    link(url: string): string;\n\n    /** Returns a `<small>` HTML element */\n    small(): string;\n\n    /** Returns a `<strike>` HTML element */\n    strike(): string;\n\n    /** Returns a `<sub>` HTML element */\n    sub(): string;\n\n    /** Returns a `<sup>` HTML element */\n    sup(): string;\n}\n\ninterface StringConstructor {\n    /**\n     * Return the String value whose elements are, in order, the elements in the List elements.\n     * If length is 0, the empty string is returned.\n     */\n    fromCodePoint(...codePoints: number[]): string;\n\n    /**\n     * String.raw is intended for use as a tag function of a Tagged Template String. When called\n     * as such the first argument will be a well formed template call site object and the rest\n     * parameter will contain the substitution values.\n     * @param template A well-formed template string call site representation.\n     * @param substitutions A set of substitution values.\n     */\n    raw(template: TemplateStringsArray, ...substitutions: any[]): string;\n}\n',"lib.es2015.d.ts":'/*! *****************************************************************************\nCopyright (c) Microsoft Corporation. All rights reserved.\nLicensed under the Apache License, Version 2.0 (the "License"); you may not use\nthis file except in compliance with the License. You may obtain a copy of the\nLicense at http://www.apache.org/licenses/LICENSE-2.0\n\nTHIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\nKIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED\nWARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,\nMERCHANTABLITY OR NON-INFRINGEMENT.\n\nSee the Apache Version 2.0 License for specific language governing permissions\nand limitations under the License.\n***************************************************************************** */\n\n\n\n/// <reference no-default-lib="true"/>\n\n\n/// <reference lib="es5" />\n/// <reference lib="es2015.core" />\n/// <reference lib="es2015.collection" />\n/// <reference lib="es2015.iterable" />\n/// <reference lib="es2015.generator" />\n/// <reference lib="es2015.promise" />\n/// <reference lib="es2015.proxy" />\n/// <reference lib="es2015.reflect" />\n/// <reference lib="es2015.symbol" />\n/// <reference lib="es2015.symbol.wellknown" />\n',"lib.es2015.generator.d.ts":'/*! *****************************************************************************\nCopyright (c) Microsoft Corporation. All rights reserved.\nLicensed under the Apache License, Version 2.0 (the "License"); you may not use\nthis file except in compliance with the License. You may obtain a copy of the\nLicense at http://www.apache.org/licenses/LICENSE-2.0\n\nTHIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\nKIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED\nWARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,\nMERCHANTABLITY OR NON-INFRINGEMENT.\n\nSee the Apache Version 2.0 License for specific language governing permissions\nand limitations under the License.\n***************************************************************************** */\n\n\n\n/// <reference no-default-lib="true"/>\n\n\n/// <reference lib="es2015.iterable" />\n\ninterface Generator<T = unknown, TReturn = any, TNext = unknown> extends Iterator<T, TReturn, TNext> {\n    // NOTE: \'next\' is defined using a tuple to ensure we report the correct assignability errors in all places.\n    next(...args: [] | [TNext]): IteratorResult<T, TReturn>;\n    return(value: TReturn): IteratorResult<T, TReturn>;\n    throw(e: any): IteratorResult<T, TReturn>;\n    [Symbol.iterator](): Generator<T, TReturn, TNext>;\n}\n\ninterface GeneratorFunction {\n    /**\n     * Creates a new Generator object.\n     * @param args A list of arguments the function accepts.\n     */\n    new (...args: any[]): Generator;\n    /**\n     * Creates a new Generator object.\n     * @param args A list of arguments the function accepts.\n     */\n    (...args: any[]): Generator;\n    /**\n     * The length of the arguments.\n     */\n    readonly length: number;\n    /**\n     * Returns the name of the function.\n     */\n    readonly name: string;\n    /**\n     * A reference to the prototype.\n     */\n    readonly prototype: Generator;\n}\n\ninterface GeneratorFunctionConstructor {\n    /**\n     * Creates a new Generator function.\n     * @param args A list of arguments the function accepts.\n     */\n    new (...args: string[]): GeneratorFunction;\n    /**\n     * Creates a new Generator function.\n     * @param args A list of arguments the function accepts.\n     */\n    (...args: string[]): GeneratorFunction;\n    /**\n     * The length of the arguments.\n     */\n    readonly length: number;\n    /**\n     * Returns the name of the function.\n     */\n    readonly name: string;\n    /**\n     * A reference to the prototype.\n     */\n    readonly prototype: GeneratorFunction;\n}\n',"lib.es2015.iterable.d.ts":"/*! *****************************************************************************\nCopyright (c) Microsoft Corporation. All rights reserved.\nLicensed under the Apache License, Version 2.0 (the \"License\"); you may not use\nthis file except in compliance with the License. You may obtain a copy of the\nLicense at http://www.apache.org/licenses/LICENSE-2.0\n\nTHIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\nKIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED\nWARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,\nMERCHANTABLITY OR NON-INFRINGEMENT.\n\nSee the Apache Version 2.0 License for specific language governing permissions\nand limitations under the License.\n***************************************************************************** */\n\n\n\n/// <reference no-default-lib=\"true\"/>\n\n\n/// <reference lib=\"es2015.symbol\" />\n\ninterface SymbolConstructor {\n    /**\n     * A method that returns the default iterator for an object. Called by the semantics of the\n     * for-of statement.\n     */\n    readonly iterator: unique symbol;\n}\n\ninterface IteratorYieldResult<TYield> {\n    done?: false;\n    value: TYield;\n}\n\ninterface IteratorReturnResult<TReturn> {\n    done: true;\n    value: TReturn;\n}\n\ntype IteratorResult<T, TReturn = any> = IteratorYieldResult<T> | IteratorReturnResult<TReturn>;\n\ninterface Iterator<T, TReturn = any, TNext = undefined> {\n    // NOTE: 'next' is defined using a tuple to ensure we report the correct assignability errors in all places.\n    next(...args: [] | [TNext]): IteratorResult<T, TReturn>;\n    return?(value?: TReturn): IteratorResult<T, TReturn>;\n    throw?(e?: any): IteratorResult<T, TReturn>;\n}\n\ninterface Iterable<T> {\n    [Symbol.iterator](): Iterator<T>;\n}\n\ninterface IterableIterator<T> extends Iterator<T> {\n    [Symbol.iterator](): IterableIterator<T>;\n}\n\ninterface Array<T> {\n    /** Iterator */\n    [Symbol.iterator](): IterableIterator<T>;\n\n    /**\n     * Returns an iterable of key, value pairs for every entry in the array\n     */\n    entries(): IterableIterator<[number, T]>;\n\n    /**\n     * Returns an iterable of keys in the array\n     */\n    keys(): IterableIterator<number>;\n\n    /**\n     * Returns an iterable of values in the array\n     */\n    values(): IterableIterator<T>;\n}\n\ninterface ArrayConstructor {\n    /**\n     * Creates an array from an iterable object.\n     * @param iterable An iterable object to convert to an array.\n     */\n    from<T>(iterable: Iterable<T> | ArrayLike<T>): T[];\n\n    /**\n     * Creates an array from an iterable object.\n     * @param iterable An iterable object to convert to an array.\n     * @param mapfn A mapping function to call on every element of the array.\n     * @param thisArg Value of 'this' used to invoke the mapfn.\n     */\n    from<T, U>(iterable: Iterable<T> | ArrayLike<T>, mapfn: (v: T, k: number) => U, thisArg?: any): U[];\n}\n\ninterface ReadonlyArray<T> {\n    /** Iterator of values in the array. */\n    [Symbol.iterator](): IterableIterator<T>;\n\n    /**\n     * Returns an iterable of key, value pairs for every entry in the array\n     */\n    entries(): IterableIterator<[number, T]>;\n\n    /**\n     * Returns an iterable of keys in the array\n     */\n    keys(): IterableIterator<number>;\n\n    /**\n     * Returns an iterable of values in the array\n     */\n    values(): IterableIterator<T>;\n}\n\ninterface IArguments {\n    /** Iterator */\n    [Symbol.iterator](): IterableIterator<any>;\n}\n\ninterface Map<K, V> {\n    /** Returns an iterable of entries in the map. */\n    [Symbol.iterator](): IterableIterator<[K, V]>;\n\n    /**\n     * Returns an iterable of key, value pairs for every entry in the map.\n     */\n    entries(): IterableIterator<[K, V]>;\n\n    /**\n     * Returns an iterable of keys in the map\n     */\n    keys(): IterableIterator<K>;\n\n    /**\n     * Returns an iterable of values in the map\n     */\n    values(): IterableIterator<V>;\n}\n\ninterface ReadonlyMap<K, V> {\n    /** Returns an iterable of entries in the map. */\n    [Symbol.iterator](): IterableIterator<[K, V]>;\n\n    /**\n     * Returns an iterable of key, value pairs for every entry in the map.\n     */\n    entries(): IterableIterator<[K, V]>;\n\n    /**\n     * Returns an iterable of keys in the map\n     */\n    keys(): IterableIterator<K>;\n\n    /**\n     * Returns an iterable of values in the map\n     */\n    values(): IterableIterator<V>;\n}\n\ninterface MapConstructor {\n    new <K, V>(iterable: Iterable<readonly [K, V]>): Map<K, V>;\n}\n\ninterface WeakMap<K extends object, V> { }\n\ninterface WeakMapConstructor {\n    new <K extends object, V>(iterable: Iterable<[K, V]>): WeakMap<K, V>;\n}\n\ninterface Set<T> {\n    /** Iterates over values in the set. */\n    [Symbol.iterator](): IterableIterator<T>;\n    /**\n     * Returns an iterable of [v,v] pairs for every value `v` in the set.\n     */\n    entries(): IterableIterator<[T, T]>;\n    /**\n     * Despite its name, returns an iterable of the values in the set.\n     */\n    keys(): IterableIterator<T>;\n\n    /**\n     * Returns an iterable of values in the set.\n     */\n    values(): IterableIterator<T>;\n}\n\ninterface ReadonlySet<T> {\n    /** Iterates over values in the set. */\n    [Symbol.iterator](): IterableIterator<T>;\n\n    /**\n     * Returns an iterable of [v,v] pairs for every value `v` in the set.\n     */\n    entries(): IterableIterator<[T, T]>;\n\n    /**\n     * Despite its name, returns an iterable of the values in the set.\n     */\n    keys(): IterableIterator<T>;\n\n    /**\n     * Returns an iterable of values in the set.\n     */\n    values(): IterableIterator<T>;\n}\n\ninterface SetConstructor {\n    new <T>(iterable?: Iterable<T> | null): Set<T>;\n}\n\ninterface WeakSet<T extends object> { }\n\ninterface WeakSetConstructor {\n    new <T extends object = object>(iterable: Iterable<T>): WeakSet<T>;\n}\n\ninterface Promise<T> { }\n\ninterface PromiseConstructor {\n    /**\n     * Creates a Promise that is resolved with an array of results when all of the provided Promises\n     * resolve, or rejected when any Promise is rejected.\n     * @param values An iterable of Promises.\n     * @returns A new Promise.\n     */\n    all<T>(values: Iterable<T | PromiseLike<T>>): Promise<T[]>;\n\n    /**\n     * Creates a Promise that is resolved or rejected when any of the provided Promises are resolved\n     * or rejected.\n     * @param values An iterable of Promises.\n     * @returns A new Promise.\n     */\n    race<T>(values: Iterable<T>): Promise<T extends PromiseLike<infer U> ? U : T>;\n\n    /**\n     * Creates a Promise that is resolved or rejected when any of the provided Promises are resolved\n     * or rejected.\n     * @param values An iterable of Promises.\n     * @returns A new Promise.\n     */\n    race<T>(values: Iterable<T | PromiseLike<T>>): Promise<T>;\n}\n\ninterface String {\n    /** Iterator */\n    [Symbol.iterator](): IterableIterator<string>;\n}\n\ninterface Int8Array {\n    [Symbol.iterator](): IterableIterator<number>;\n    /**\n     * Returns an array of key, value pairs for every entry in the array\n     */\n    entries(): IterableIterator<[number, number]>;\n    /**\n     * Returns an list of keys in the array\n     */\n    keys(): IterableIterator<number>;\n    /**\n     * Returns an list of values in the array\n     */\n    values(): IterableIterator<number>;\n}\n\ninterface Int8ArrayConstructor {\n    new (elements: Iterable<number>): Int8Array;\n\n    /**\n     * Creates an array from an array-like or iterable object.\n     * @param arrayLike An array-like or iterable object to convert to an array.\n     * @param mapfn A mapping function to call on every element of the array.\n     * @param thisArg Value of 'this' used to invoke the mapfn.\n     */\n    from(arrayLike: Iterable<number>, mapfn?: (v: number, k: number) => number, thisArg?: any): Int8Array;\n}\n\ninterface Uint8Array {\n    [Symbol.iterator](): IterableIterator<number>;\n    /**\n     * Returns an array of key, value pairs for every entry in the array\n     */\n    entries(): IterableIterator<[number, number]>;\n    /**\n     * Returns an list of keys in the array\n     */\n    keys(): IterableIterator<number>;\n    /**\n     * Returns an list of values in the array\n     */\n    values(): IterableIterator<number>;\n}\n\ninterface Uint8ArrayConstructor {\n    new (elements: Iterable<number>): Uint8Array;\n\n    /**\n     * Creates an array from an array-like or iterable object.\n     * @param arrayLike An array-like or iterable object to convert to an array.\n     * @param mapfn A mapping function to call on every element of the array.\n     * @param thisArg Value of 'this' used to invoke the mapfn.\n     */\n    from(arrayLike: Iterable<number>, mapfn?: (v: number, k: number) => number, thisArg?: any): Uint8Array;\n}\n\ninterface Uint8ClampedArray {\n    [Symbol.iterator](): IterableIterator<number>;\n    /**\n     * Returns an array of key, value pairs for every entry in the array\n     */\n    entries(): IterableIterator<[number, number]>;\n\n    /**\n     * Returns an list of keys in the array\n     */\n    keys(): IterableIterator<number>;\n\n    /**\n     * Returns an list of values in the array\n     */\n    values(): IterableIterator<number>;\n}\n\ninterface Uint8ClampedArrayConstructor {\n    new (elements: Iterable<number>): Uint8ClampedArray;\n\n\n    /**\n     * Creates an array from an array-like or iterable object.\n     * @param arrayLike An array-like or iterable object to convert to an array.\n     * @param mapfn A mapping function to call on every element of the array.\n     * @param thisArg Value of 'this' used to invoke the mapfn.\n     */\n    from(arrayLike: Iterable<number>, mapfn?: (v: number, k: number) => number, thisArg?: any): Uint8ClampedArray;\n}\n\ninterface Int16Array {\n    [Symbol.iterator](): IterableIterator<number>;\n    /**\n     * Returns an array of key, value pairs for every entry in the array\n     */\n    entries(): IterableIterator<[number, number]>;\n\n    /**\n     * Returns an list of keys in the array\n     */\n    keys(): IterableIterator<number>;\n\n    /**\n     * Returns an list of values in the array\n     */\n    values(): IterableIterator<number>;\n}\n\ninterface Int16ArrayConstructor {\n    new (elements: Iterable<number>): Int16Array;\n\n    /**\n     * Creates an array from an array-like or iterable object.\n     * @param arrayLike An array-like or iterable object to convert to an array.\n     * @param mapfn A mapping function to call on every element of the array.\n     * @param thisArg Value of 'this' used to invoke the mapfn.\n     */\n    from(arrayLike: Iterable<number>, mapfn?: (v: number, k: number) => number, thisArg?: any): Int16Array;\n}\n\ninterface Uint16Array {\n    [Symbol.iterator](): IterableIterator<number>;\n    /**\n     * Returns an array of key, value pairs for every entry in the array\n     */\n    entries(): IterableIterator<[number, number]>;\n    /**\n     * Returns an list of keys in the array\n     */\n    keys(): IterableIterator<number>;\n    /**\n     * Returns an list of values in the array\n     */\n    values(): IterableIterator<number>;\n}\n\ninterface Uint16ArrayConstructor {\n    new (elements: Iterable<number>): Uint16Array;\n\n    /**\n     * Creates an array from an array-like or iterable object.\n     * @param arrayLike An array-like or iterable object to convert to an array.\n     * @param mapfn A mapping function to call on every element of the array.\n     * @param thisArg Value of 'this' used to invoke the mapfn.\n     */\n    from(arrayLike: Iterable<number>, mapfn?: (v: number, k: number) => number, thisArg?: any): Uint16Array;\n}\n\ninterface Int32Array {\n    [Symbol.iterator](): IterableIterator<number>;\n    /**\n     * Returns an array of key, value pairs for every entry in the array\n     */\n    entries(): IterableIterator<[number, number]>;\n    /**\n     * Returns an list of keys in the array\n     */\n    keys(): IterableIterator<number>;\n    /**\n     * Returns an list of values in the array\n     */\n    values(): IterableIterator<number>;\n}\n\ninterface Int32ArrayConstructor {\n    new (elements: Iterable<number>): Int32Array;\n\n    /**\n     * Creates an array from an array-like or iterable object.\n     * @param arrayLike An array-like or iterable object to convert to an array.\n     * @param mapfn A mapping function to call on every element of the array.\n     * @param thisArg Value of 'this' used to invoke the mapfn.\n     */\n    from(arrayLike: Iterable<number>, mapfn?: (v: number, k: number) => number, thisArg?: any): Int32Array;\n}\n\ninterface Uint32Array {\n    [Symbol.iterator](): IterableIterator<number>;\n    /**\n     * Returns an array of key, value pairs for every entry in the array\n     */\n    entries(): IterableIterator<[number, number]>;\n    /**\n     * Returns an list of keys in the array\n     */\n    keys(): IterableIterator<number>;\n    /**\n     * Returns an list of values in the array\n     */\n    values(): IterableIterator<number>;\n}\n\ninterface Uint32ArrayConstructor {\n    new (elements: Iterable<number>): Uint32Array;\n\n    /**\n     * Creates an array from an array-like or iterable object.\n     * @param arrayLike An array-like or iterable object to convert to an array.\n     * @param mapfn A mapping function to call on every element of the array.\n     * @param thisArg Value of 'this' used to invoke the mapfn.\n     */\n    from(arrayLike: Iterable<number>, mapfn?: (v: number, k: number) => number, thisArg?: any): Uint32Array;\n}\n\ninterface Float32Array {\n    [Symbol.iterator](): IterableIterator<number>;\n    /**\n     * Returns an array of key, value pairs for every entry in the array\n     */\n    entries(): IterableIterator<[number, number]>;\n    /**\n     * Returns an list of keys in the array\n     */\n    keys(): IterableIterator<number>;\n    /**\n     * Returns an list of values in the array\n     */\n    values(): IterableIterator<number>;\n}\n\ninterface Float32ArrayConstructor {\n    new (elements: Iterable<number>): Float32Array;\n\n    /**\n     * Creates an array from an array-like or iterable object.\n     * @param arrayLike An array-like or iterable object to convert to an array.\n     * @param mapfn A mapping function to call on every element of the array.\n     * @param thisArg Value of 'this' used to invoke the mapfn.\n     */\n    from(arrayLike: Iterable<number>, mapfn?: (v: number, k: number) => number, thisArg?: any): Float32Array;\n}\n\ninterface Float64Array {\n    [Symbol.iterator](): IterableIterator<number>;\n    /**\n     * Returns an array of key, value pairs for every entry in the array\n     */\n    entries(): IterableIterator<[number, number]>;\n    /**\n     * Returns an list of keys in the array\n     */\n    keys(): IterableIterator<number>;\n    /**\n     * Returns an list of values in the array\n     */\n    values(): IterableIterator<number>;\n}\n\ninterface Float64ArrayConstructor {\n    new (elements: Iterable<number>): Float64Array;\n\n    /**\n     * Creates an array from an array-like or iterable object.\n     * @param arrayLike An array-like or iterable object to convert to an array.\n     * @param mapfn A mapping function to call on every element of the array.\n     * @param thisArg Value of 'this' used to invoke the mapfn.\n     */\n    from(arrayLike: Iterable<number>, mapfn?: (v: number, k: number) => number, thisArg?: any): Float64Array;\n}\n","lib.es2015.promise.d.ts":'/*! *****************************************************************************\nCopyright (c) Microsoft Corporation. All rights reserved.\nLicensed under the Apache License, Version 2.0 (the "License"); you may not use\nthis file except in compliance with the License. You may obtain a copy of the\nLicense at http://www.apache.org/licenses/LICENSE-2.0\n\nTHIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\nKIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED\nWARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,\nMERCHANTABLITY OR NON-INFRINGEMENT.\n\nSee the Apache Version 2.0 License for specific language governing permissions\nand limitations under the License.\n***************************************************************************** */\n\n\n\n/// <reference no-default-lib="true"/>\n\n\ninterface PromiseConstructor {\n    /**\n     * A reference to the prototype.\n     */\n    readonly prototype: Promise<any>;\n\n    /**\n     * Creates a new Promise.\n     * @param executor A callback used to initialize the promise. This callback is passed two arguments:\n     * a resolve callback used to resolve the promise with a value or the result of another promise,\n     * and a reject callback used to reject the promise with a provided reason or error.\n     */\n    new <T>(executor: (resolve: (value: T | PromiseLike<T>) => void, reject: (reason?: any) => void) => void): Promise<T>;\n\n    /**\n     * Creates a Promise that is resolved with an array of results when all of the provided Promises\n     * resolve, or rejected when any Promise is rejected.\n     * @param values An array of Promises.\n     * @returns A new Promise.\n     */\n    all<T1, T2, T3, T4, T5, T6, T7, T8, T9, T10>(values: readonly [T1 | PromiseLike<T1>, T2 | PromiseLike<T2>, T3 | PromiseLike<T3>, T4 | PromiseLike<T4>, T5 | PromiseLike<T5>, T6 | PromiseLike<T6>, T7 | PromiseLike<T7>, T8 | PromiseLike<T8>, T9 | PromiseLike<T9>, T10 | PromiseLike<T10>]): Promise<[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10]>;\n\n    /**\n     * Creates a Promise that is resolved with an array of results when all of the provided Promises\n     * resolve, or rejected when any Promise is rejected.\n     * @param values An array of Promises.\n     * @returns A new Promise.\n     */\n    all<T1, T2, T3, T4, T5, T6, T7, T8, T9>(values: readonly [T1 | PromiseLike<T1>, T2 | PromiseLike<T2>, T3 | PromiseLike<T3>, T4 | PromiseLike<T4>, T5 | PromiseLike<T5>, T6 | PromiseLike<T6>, T7 | PromiseLike<T7>, T8 | PromiseLike<T8>, T9 | PromiseLike<T9>]): Promise<[T1, T2, T3, T4, T5, T6, T7, T8, T9]>;\n\n    /**\n     * Creates a Promise that is resolved with an array of results when all of the provided Promises\n     * resolve, or rejected when any Promise is rejected.\n     * @param values An array of Promises.\n     * @returns A new Promise.\n     */\n    all<T1, T2, T3, T4, T5, T6, T7, T8>(values: readonly [T1 | PromiseLike<T1>, T2 | PromiseLike<T2>, T3 | PromiseLike<T3>, T4 | PromiseLike<T4>, T5 | PromiseLike<T5>, T6 | PromiseLike<T6>, T7 | PromiseLike<T7>, T8 | PromiseLike<T8>]): Promise<[T1, T2, T3, T4, T5, T6, T7, T8]>;\n\n    /**\n     * Creates a Promise that is resolved with an array of results when all of the provided Promises\n     * resolve, or rejected when any Promise is rejected.\n     * @param values An array of Promises.\n     * @returns A new Promise.\n     */\n    all<T1, T2, T3, T4, T5, T6, T7>(values: readonly [T1 | PromiseLike<T1>, T2 | PromiseLike<T2>, T3 | PromiseLike<T3>, T4 | PromiseLike<T4>, T5 | PromiseLike<T5>, T6 | PromiseLike<T6>, T7 | PromiseLike<T7>]): Promise<[T1, T2, T3, T4, T5, T6, T7]>;\n\n    /**\n     * Creates a Promise that is resolved with an array of results when all of the provided Promises\n     * resolve, or rejected when any Promise is rejected.\n     * @param values An array of Promises.\n     * @returns A new Promise.\n     */\n    all<T1, T2, T3, T4, T5, T6>(values: readonly [T1 | PromiseLike<T1>, T2 | PromiseLike<T2>, T3 | PromiseLike<T3>, T4 | PromiseLike<T4>, T5 | PromiseLike<T5>, T6 | PromiseLike<T6>]): Promise<[T1, T2, T3, T4, T5, T6]>;\n\n    /**\n     * Creates a Promise that is resolved with an array of results when all of the provided Promises\n     * resolve, or rejected when any Promise is rejected.\n     * @param values An array of Promises.\n     * @returns A new Promise.\n     */\n    all<T1, T2, T3, T4, T5>(values: readonly [T1 | PromiseLike<T1>, T2 | PromiseLike<T2>, T3 | PromiseLike<T3>, T4 | PromiseLike<T4>, T5 | PromiseLike<T5>]): Promise<[T1, T2, T3, T4, T5]>;\n\n    /**\n     * Creates a Promise that is resolved with an array of results when all of the provided Promises\n     * resolve, or rejected when any Promise is rejected.\n     * @param values An array of Promises.\n     * @returns A new Promise.\n     */\n    all<T1, T2, T3, T4>(values: readonly [T1 | PromiseLike<T1>, T2 | PromiseLike<T2>, T3 | PromiseLike<T3>, T4 | PromiseLike<T4>]): Promise<[T1, T2, T3, T4]>;\n\n    /**\n     * Creates a Promise that is resolved with an array of results when all of the provided Promises\n     * resolve, or rejected when any Promise is rejected.\n     * @param values An array of Promises.\n     * @returns A new Promise.\n     */\n    all<T1, T2, T3>(values: readonly [T1 | PromiseLike<T1>, T2 | PromiseLike<T2>, T3 | PromiseLike<T3>]): Promise<[T1, T2, T3]>;\n\n    /**\n     * Creates a Promise that is resolved with an array of results when all of the provided Promises\n     * resolve, or rejected when any Promise is rejected.\n     * @param values An array of Promises.\n     * @returns A new Promise.\n     */\n    all<T1, T2>(values: readonly [T1 | PromiseLike<T1>, T2 | PromiseLike<T2>]): Promise<[T1, T2]>;\n\n    /**\n     * Creates a Promise that is resolved with an array of results when all of the provided Promises\n     * resolve, or rejected when any Promise is rejected.\n     * @param values An array of Promises.\n     * @returns A new Promise.\n     */\n    all<T>(values: readonly (T | PromiseLike<T>)[]): Promise<T[]>;\n\n    // see: lib.es2015.iterable.d.ts\n    // all<T>(values: Iterable<T | PromiseLike<T>>): Promise<T[]>;\n\n    /**\n     * Creates a Promise that is resolved or rejected when any of the provided Promises are resolved\n     * or rejected.\n     * @param values An array of Promises.\n     * @returns A new Promise.\n     */\n    race<T>(values: readonly T[]): Promise<T extends PromiseLike<infer U> ? U : T>;\n\n    // see: lib.es2015.iterable.d.ts\n    // race<T>(values: Iterable<T>): Promise<T extends PromiseLike<infer U> ? U : T>;\n\n    /**\n     * Creates a new rejected promise for the provided reason.\n     * @param reason The reason the promise was rejected.\n     * @returns A new rejected Promise.\n     */\n    reject<T = never>(reason?: any): Promise<T>;\n\n    /**\n     * Creates a new resolved promise.\n     * @returns A resolved promise.\n     */\n    resolve(): Promise<void>;\n\n    /**\n     * Creates a new resolved promise for the provided value.\n     * @param value A promise.\n     * @returns A promise whose internal state matches the provided promise.\n     */\n    resolve<T>(value: T | PromiseLike<T>): Promise<T>;\n}\n\ndeclare var Promise: PromiseConstructor;\n',"lib.es2015.proxy.d.ts":'/*! *****************************************************************************\nCopyright (c) Microsoft Corporation. All rights reserved.\nLicensed under the Apache License, Version 2.0 (the "License"); you may not use\nthis file except in compliance with the License. You may obtain a copy of the\nLicense at http://www.apache.org/licenses/LICENSE-2.0\n\nTHIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\nKIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED\nWARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,\nMERCHANTABLITY OR NON-INFRINGEMENT.\n\nSee the Apache Version 2.0 License for specific language governing permissions\nand limitations under the License.\n***************************************************************************** */\n\n\n\n/// <reference no-default-lib="true"/>\n\n\ninterface ProxyHandler<T extends object> {\n    apply?(target: T, thisArg: any, argArray: any[]): any;\n    construct?(target: T, argArray: any[], newTarget: Function): object;\n    defineProperty?(target: T, p: string | symbol, attributes: PropertyDescriptor): boolean;\n    deleteProperty?(target: T, p: string | symbol): boolean;\n    get?(target: T, p: string | symbol, receiver: any): any;\n    getOwnPropertyDescriptor?(target: T, p: string | symbol): PropertyDescriptor | undefined;\n    getPrototypeOf?(target: T): object | null;\n    has?(target: T, p: string | symbol): boolean;\n    isExtensible?(target: T): boolean;\n    ownKeys?(target: T): ArrayLike<string | symbol>;\n    preventExtensions?(target: T): boolean;\n    set?(target: T, p: string | symbol, value: any, receiver: any): boolean;\n    setPrototypeOf?(target: T, v: object | null): boolean;\n}\n\ninterface ProxyConstructor {\n    revocable<T extends object>(target: T, handler: ProxyHandler<T>): { proxy: T; revoke: () => void; };\n    new <T extends object>(target: T, handler: ProxyHandler<T>): T;\n}\ndeclare var Proxy: ProxyConstructor;\n',"lib.es2015.reflect.d.ts":'/*! *****************************************************************************\nCopyright (c) Microsoft Corporation. All rights reserved.\nLicensed under the Apache License, Version 2.0 (the "License"); you may not use\nthis file except in compliance with the License. You may obtain a copy of the\nLicense at http://www.apache.org/licenses/LICENSE-2.0\n\nTHIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\nKIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED\nWARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,\nMERCHANTABLITY OR NON-INFRINGEMENT.\n\nSee the Apache Version 2.0 License for specific language governing permissions\nand limitations under the License.\n***************************************************************************** */\n\n\n\n/// <reference no-default-lib="true"/>\n\n\ndeclare namespace Reflect {\n    /**\n     * Calls the function with the specified object as the this value\n     * and the elements of specified array as the arguments.\n     * @param target The function to call.\n     * @param thisArgument The object to be used as the this object.\n     * @param argumentsList An array of argument values to be passed to the function.\n     */\n    function apply(target: Function, thisArgument: any, argumentsList: ArrayLike<any>): any;\n\n    /**\n     * Constructs the target with the elements of specified array as the arguments\n     * and the specified constructor as the `new.target` value.\n     * @param target The constructor to invoke.\n     * @param argumentsList An array of argument values to be passed to the constructor.\n     * @param newTarget The constructor to be used as the `new.target` object.\n     */\n    function construct(target: Function, argumentsList: ArrayLike<any>, newTarget?: Function): any;\n\n    /**\n     * Adds a property to an object, or modifies attributes of an existing property.\n     * @param target Object on which to add or modify the property. This can be a native JavaScript object\n     *        (that is, a user-defined object or a built in object) or a DOM object.\n     * @param propertyKey The property name.\n     * @param attributes Descriptor for the property. It can be for a data property or an accessor property.\n     */\n    function defineProperty(target: object, propertyKey: PropertyKey, attributes: PropertyDescriptor): boolean;\n\n    /**\n     * Removes a property from an object, equivalent to `delete target[propertyKey]`,\n     * except it won\'t throw if `target[propertyKey]` is non-configurable.\n     * @param target Object from which to remove the own property.\n     * @param propertyKey The property name.\n     */\n    function deleteProperty(target: object, propertyKey: PropertyKey): boolean;\n\n    /**\n     * Gets the property of target, equivalent to `target[propertyKey]` when `receiver === target`.\n     * @param target Object that contains the property on itself or in its prototype chain.\n     * @param propertyKey The property name.\n     * @param receiver The reference to use as the `this` value in the getter function,\n     *        if `target[propertyKey]` is an accessor property.\n     */\n    function get(target: object, propertyKey: PropertyKey, receiver?: any): any;\n\n    /**\n     * Gets the own property descriptor of the specified object.\n     * An own property descriptor is one that is defined directly on the object and is not inherited from the object\'s prototype.\n     * @param target Object that contains the property.\n     * @param propertyKey The property name.\n     */\n    function getOwnPropertyDescriptor(target: object, propertyKey: PropertyKey): PropertyDescriptor | undefined;\n\n    /**\n     * Returns the prototype of an object.\n     * @param target The object that references the prototype.\n     */\n    function getPrototypeOf(target: object): object | null;\n\n    /**\n     * Equivalent to `propertyKey in target`.\n     * @param target Object that contains the property on itself or in its prototype chain.\n     * @param propertyKey Name of the property.\n     */\n    function has(target: object, propertyKey: PropertyKey): boolean;\n\n    /**\n     * Returns a value that indicates whether new properties can be added to an object.\n     * @param target Object to test.\n     */\n    function isExtensible(target: object): boolean;\n\n    /**\n     * Returns the string and symbol keys of the own properties of an object. The own properties of an object\n     * are those that are defined directly on that object, and are not inherited from the object\'s prototype.\n     * @param target Object that contains the own properties.\n     */\n    function ownKeys(target: object): (string | symbol)[];\n\n    /**\n     * Prevents the addition of new properties to an object.\n     * @param target Object to make non-extensible.\n     * @return Whether the object has been made non-extensible.\n     */\n    function preventExtensions(target: object): boolean;\n\n    /**\n     * Sets the property of target, equivalent to `target[propertyKey] = value` when `receiver === target`.\n     * @param target Object that contains the property on itself or in its prototype chain.\n     * @param propertyKey Name of the property.\n     * @param receiver The reference to use as the `this` value in the setter function,\n     *        if `target[propertyKey]` is an accessor property.\n     */\n    function set(target: object, propertyKey: PropertyKey, value: any, receiver?: any): boolean;\n\n    /**\n     * Sets the prototype of a specified object o to object proto or null.\n     * @param target The object to change its prototype.\n     * @param proto The value of the new prototype or null.\n     * @return Whether setting the prototype was successful.\n     */\n    function setPrototypeOf(target: object, proto: object | null): boolean;\n}\n',"lib.es2015.symbol.d.ts":'/*! *****************************************************************************\nCopyright (c) Microsoft Corporation. All rights reserved.\nLicensed under the Apache License, Version 2.0 (the "License"); you may not use\nthis file except in compliance with the License. You may obtain a copy of the\nLicense at http://www.apache.org/licenses/LICENSE-2.0\n\nTHIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\nKIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED\nWARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,\nMERCHANTABLITY OR NON-INFRINGEMENT.\n\nSee the Apache Version 2.0 License for specific language governing permissions\nand limitations under the License.\n***************************************************************************** */\n\n\n\n/// <reference no-default-lib="true"/>\n\n\ninterface SymbolConstructor {\n    /**\n     * A reference to the prototype.\n     */\n    readonly prototype: Symbol;\n\n    /**\n     * Returns a new unique Symbol value.\n     * @param  description Description of the new Symbol object.\n     */\n    (description?: string | number): symbol;\n\n    /**\n     * Returns a Symbol object from the global symbol registry matching the given key if found.\n     * Otherwise, returns a new symbol with this key.\n     * @param key key to search for.\n     */\n    for(key: string): symbol;\n\n    /**\n     * Returns a key from the global symbol registry matching the given Symbol if found.\n     * Otherwise, returns a undefined.\n     * @param sym Symbol to find the key for.\n     */\n    keyFor(sym: symbol): string | undefined;\n}\n\ndeclare var Symbol: SymbolConstructor;',"lib.es2015.symbol.wellknown.d.ts":'/*! *****************************************************************************\nCopyright (c) Microsoft Corporation. All rights reserved.\nLicensed under the Apache License, Version 2.0 (the "License"); you may not use\nthis file except in compliance with the License. You may obtain a copy of the\nLicense at http://www.apache.org/licenses/LICENSE-2.0\n\nTHIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\nKIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED\nWARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,\nMERCHANTABLITY OR NON-INFRINGEMENT.\n\nSee the Apache Version 2.0 License for specific language governing permissions\nand limitations under the License.\n***************************************************************************** */\n\n\n\n/// <reference no-default-lib="true"/>\n\n\n/// <reference lib="es2015.symbol" />\n\ninterface SymbolConstructor {\n    /**\n     * A method that determines if a constructor object recognizes an object as one of the\n     * constructor’s instances. Called by the semantics of the instanceof operator.\n     */\n    readonly hasInstance: unique symbol;\n\n    /**\n     * A Boolean value that if true indicates that an object should flatten to its array elements\n     * by Array.prototype.concat.\n     */\n    readonly isConcatSpreadable: unique symbol;\n\n    /**\n     * A regular expression method that matches the regular expression against a string. Called\n     * by the String.prototype.match method.\n     */\n    readonly match: unique symbol;\n\n    /**\n     * A regular expression method that replaces matched substrings of a string. Called by the\n     * String.prototype.replace method.\n     */\n    readonly replace: unique symbol;\n\n    /**\n     * A regular expression method that returns the index within a string that matches the\n     * regular expression. Called by the String.prototype.search method.\n     */\n    readonly search: unique symbol;\n\n    /**\n     * A function valued property that is the constructor function that is used to create\n     * derived objects.\n     */\n    readonly species: unique symbol;\n\n    /**\n     * A regular expression method that splits a string at the indices that match the regular\n     * expression. Called by the String.prototype.split method.\n     */\n    readonly split: unique symbol;\n\n    /**\n     * A method that converts an object to a corresponding primitive value.\n     * Called by the ToPrimitive abstract operation.\n     */\n    readonly toPrimitive: unique symbol;\n\n    /**\n     * A String value that is used in the creation of the default string description of an object.\n     * Called by the built-in method Object.prototype.toString.\n     */\n    readonly toStringTag: unique symbol;\n\n    /**\n     * An Object whose own property names are property names that are excluded from the \'with\'\n     * environment bindings of the associated objects.\n     */\n    readonly unscopables: unique symbol;\n}\n\ninterface Symbol {\n    /**\n     * Converts a Symbol object to a symbol.\n     */\n    [Symbol.toPrimitive](hint: string): symbol;\n\n    readonly [Symbol.toStringTag]: string;\n}\n\ninterface Array<T> {\n    /**\n     * Returns an object whose properties have the value \'true\'\n     * when they will be absent when used in a \'with\' statement.\n     */\n    [Symbol.unscopables](): {\n        copyWithin: boolean;\n        entries: boolean;\n        fill: boolean;\n        find: boolean;\n        findIndex: boolean;\n        keys: boolean;\n        values: boolean;\n    };\n}\n\ninterface Date {\n    /**\n     * Converts a Date object to a string.\n     */\n    [Symbol.toPrimitive](hint: "default"): string;\n    /**\n     * Converts a Date object to a string.\n     */\n    [Symbol.toPrimitive](hint: "string"): string;\n    /**\n     * Converts a Date object to a number.\n     */\n    [Symbol.toPrimitive](hint: "number"): number;\n    /**\n     * Converts a Date object to a string or number.\n     *\n     * @param hint The strings "number", "string", or "default" to specify what primitive to return.\n     *\n     * @throws {TypeError} If \'hint\' was given something other than "number", "string", or "default".\n     * @returns A number if \'hint\' was "number", a string if \'hint\' was "string" or "default".\n     */\n    [Symbol.toPrimitive](hint: string): string | number;\n}\n\ninterface Map<K, V> {\n    readonly [Symbol.toStringTag]: string;\n}\n\ninterface WeakMap<K extends object, V> {\n    readonly [Symbol.toStringTag]: string;\n}\n\ninterface Set<T> {\n    readonly [Symbol.toStringTag]: string;\n}\n\ninterface WeakSet<T extends object> {\n    readonly [Symbol.toStringTag]: string;\n}\n\ninterface JSON {\n    readonly [Symbol.toStringTag]: string;\n}\n\ninterface Function {\n    /**\n     * Determines whether the given value inherits from this function if this function was used\n     * as a constructor function.\n     *\n     * A constructor function can control which objects are recognized as its instances by\n     * \'instanceof\' by overriding this method.\n     */\n    [Symbol.hasInstance](value: any): boolean;\n}\n\ninterface GeneratorFunction {\n    readonly [Symbol.toStringTag]: string;\n}\n\ninterface Math {\n    readonly [Symbol.toStringTag]: string;\n}\n\ninterface Promise<T> {\n    readonly [Symbol.toStringTag]: string;\n}\n\ninterface PromiseConstructor {\n    readonly [Symbol.species]: PromiseConstructor;\n}\n\ninterface RegExp {\n    /**\n     * Matches a string with this regular expression, and returns an array containing the results of\n     * that search.\n     * @param string A string to search within.\n     */\n    [Symbol.match](string: string): RegExpMatchArray | null;\n\n    /**\n     * Replaces text in a string, using this regular expression.\n     * @param string A String object or string literal whose contents matching against\n     *               this regular expression will be replaced\n     * @param replaceValue A String object or string literal containing the text to replace for every\n     *                     successful match of this regular expression.\n     */\n    [Symbol.replace](string: string, replaceValue: string): string;\n\n    /**\n     * Replaces text in a string, using this regular expression.\n     * @param string A String object or string literal whose contents matching against\n     *               this regular expression will be replaced\n     * @param replacer A function that returns the replacement text.\n     */\n    [Symbol.replace](string: string, replacer: (substring: string, ...args: any[]) => string): string;\n\n    /**\n     * Finds the position beginning first substring match in a regular expression search\n     * using this regular expression.\n     *\n     * @param string The string to search within.\n     */\n    [Symbol.search](string: string): number;\n\n    /**\n     * Returns an array of substrings that were delimited by strings in the original input that\n     * match against this regular expression.\n     *\n     * If the regular expression contains capturing parentheses, then each time this\n     * regular expression matches, the results (including any undefined results) of the\n     * capturing parentheses are spliced.\n     *\n     * @param string string value to split\n     * @param limit if not undefined, the output array is truncated so that it contains no more\n     * than \'limit\' elements.\n     */\n    [Symbol.split](string: string, limit?: number): string[];\n}\n\ninterface RegExpConstructor {\n    readonly [Symbol.species]: RegExpConstructor;\n}\n\ninterface String {\n    /**\n     * Matches a string or an object that supports being matched against, and returns an array\n     * containing the results of that search, or null if no matches are found.\n     * @param matcher An object that supports being matched against.\n     */\n    match(matcher: { [Symbol.match](string: string): RegExpMatchArray | null; }): RegExpMatchArray | null;\n\n    /**\n     * Replaces text in a string, using an object that supports replacement within a string.\n     * @param searchValue A object can search for and replace matches within a string.\n     * @param replaceValue A string containing the text to replace for every successful match of searchValue in this string.\n     */\n    replace(searchValue: { [Symbol.replace](string: string, replaceValue: string): string; }, replaceValue: string): string;\n\n    /**\n     * Replaces text in a string, using an object that supports replacement within a string.\n     * @param searchValue A object can search for and replace matches within a string.\n     * @param replacer A function that returns the replacement text.\n     */\n    replace(searchValue: { [Symbol.replace](string: string, replacer: (substring: string, ...args: any[]) => string): string; }, replacer: (substring: string, ...args: any[]) => string): string;\n\n    /**\n     * Finds the first substring match in a regular expression search.\n     * @param searcher An object which supports searching within a string.\n     */\n    search(searcher: { [Symbol.search](string: string): number; }): number;\n\n    /**\n     * Split a string into substrings using the specified separator and return them as an array.\n     * @param splitter An object that can split a string.\n     * @param limit A value used to limit the number of elements returned in the array.\n     */\n    split(splitter: { [Symbol.split](string: string, limit?: number): string[]; }, limit?: number): string[];\n}\n\ninterface ArrayBuffer {\n    readonly [Symbol.toStringTag]: string;\n}\n\ninterface DataView {\n    readonly [Symbol.toStringTag]: string;\n}\n\ninterface Int8Array {\n    readonly [Symbol.toStringTag]: "Int8Array";\n}\n\ninterface Uint8Array {\n    readonly [Symbol.toStringTag]: "Uint8Array";\n}\n\ninterface Uint8ClampedArray {\n    readonly [Symbol.toStringTag]: "Uint8ClampedArray";\n}\n\ninterface Int16Array {\n    readonly [Symbol.toStringTag]: "Int16Array";\n}\n\ninterface Uint16Array {\n    readonly [Symbol.toStringTag]: "Uint16Array";\n}\n\ninterface Int32Array {\n    readonly [Symbol.toStringTag]: "Int32Array";\n}\n\ninterface Uint32Array {\n    readonly [Symbol.toStringTag]: "Uint32Array";\n}\n\ninterface Float32Array {\n    readonly [Symbol.toStringTag]: "Float32Array";\n}\n\ninterface Float64Array {\n    readonly [Symbol.toStringTag]: "Float64Array";\n}\n\ninterface ArrayConstructor {\n    readonly [Symbol.species]: ArrayConstructor;\n}\ninterface MapConstructor {\n    readonly [Symbol.species]: MapConstructor;\n}\ninterface SetConstructor {\n    readonly [Symbol.species]: SetConstructor;\n}\ninterface ArrayBufferConstructor {\n    readonly [Symbol.species]: ArrayBufferConstructor;\n}\n',"lib.es2016.array.include.d.ts":'/*! *****************************************************************************\nCopyright (c) Microsoft Corporation. All rights reserved.\nLicensed under the Apache License, Version 2.0 (the "License"); you may not use\nthis file except in compliance with the License. You may obtain a copy of the\nLicense at http://www.apache.org/licenses/LICENSE-2.0\n\nTHIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\nKIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED\nWARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,\nMERCHANTABLITY OR NON-INFRINGEMENT.\n\nSee the Apache Version 2.0 License for specific language governing permissions\nand limitations under the License.\n***************************************************************************** */\n\n\n\n/// <reference no-default-lib="true"/>\n\n\ninterface Array<T> {\n    /**\n     * Determines whether an array includes a certain element, returning true or false as appropriate.\n     * @param searchElement The element to search for.\n     * @param fromIndex The position in this array at which to begin searching for searchElement.\n     */\n    includes(searchElement: T, fromIndex?: number): boolean;\n}\n\ninterface ReadonlyArray<T> {\n    /**\n     * Determines whether an array includes a certain element, returning true or false as appropriate.\n     * @param searchElement The element to search for.\n     * @param fromIndex The position in this array at which to begin searching for searchElement.\n     */\n    includes(searchElement: T, fromIndex?: number): boolean;\n}\n\ninterface Int8Array {\n    /**\n     * Determines whether an array includes a certain element, returning true or false as appropriate.\n     * @param searchElement The element to search for.\n     * @param fromIndex The position in this array at which to begin searching for searchElement.\n     */\n    includes(searchElement: number, fromIndex?: number): boolean;\n}\n\ninterface Uint8Array {\n    /**\n     * Determines whether an array includes a certain element, returning true or false as appropriate.\n     * @param searchElement The element to search for.\n     * @param fromIndex The position in this array at which to begin searching for searchElement.\n     */\n    includes(searchElement: number, fromIndex?: number): boolean;\n}\n\ninterface Uint8ClampedArray {\n    /**\n     * Determines whether an array includes a certain element, returning true or false as appropriate.\n     * @param searchElement The element to search for.\n     * @param fromIndex The position in this array at which to begin searching for searchElement.\n     */\n    includes(searchElement: number, fromIndex?: number): boolean;\n}\n\ninterface Int16Array {\n    /**\n     * Determines whether an array includes a certain element, returning true or false as appropriate.\n     * @param searchElement The element to search for.\n     * @param fromIndex The position in this array at which to begin searching for searchElement.\n     */\n    includes(searchElement: number, fromIndex?: number): boolean;\n}\n\ninterface Uint16Array {\n    /**\n     * Determines whether an array includes a certain element, returning true or false as appropriate.\n     * @param searchElement The element to search for.\n     * @param fromIndex The position in this array at which to begin searching for searchElement.\n     */\n    includes(searchElement: number, fromIndex?: number): boolean;\n}\n\ninterface Int32Array {\n    /**\n     * Determines whether an array includes a certain element, returning true or false as appropriate.\n     * @param searchElement The element to search for.\n     * @param fromIndex The position in this array at which to begin searching for searchElement.\n     */\n    includes(searchElement: number, fromIndex?: number): boolean;\n}\n\ninterface Uint32Array {\n    /**\n     * Determines whether an array includes a certain element, returning true or false as appropriate.\n     * @param searchElement The element to search for.\n     * @param fromIndex The position in this array at which to begin searching for searchElement.\n     */\n    includes(searchElement: number, fromIndex?: number): boolean;\n}\n\ninterface Float32Array {\n    /**\n     * Determines whether an array includes a certain element, returning true or false as appropriate.\n     * @param searchElement The element to search for.\n     * @param fromIndex The position in this array at which to begin searching for searchElement.\n     */\n    includes(searchElement: number, fromIndex?: number): boolean;\n}\n\ninterface Float64Array {\n    /**\n     * Determines whether an array includes a certain element, returning true or false as appropriate.\n     * @param searchElement The element to search for.\n     * @param fromIndex The position in this array at which to begin searching for searchElement.\n     */\n    includes(searchElement: number, fromIndex?: number): boolean;\n}',"lib.es2016.d.ts":'/*! *****************************************************************************\nCopyright (c) Microsoft Corporation. All rights reserved.\nLicensed under the Apache License, Version 2.0 (the "License"); you may not use\nthis file except in compliance with the License. You may obtain a copy of the\nLicense at http://www.apache.org/licenses/LICENSE-2.0\n\nTHIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\nKIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED\nWARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,\nMERCHANTABLITY OR NON-INFRINGEMENT.\n\nSee the Apache Version 2.0 License for specific language governing permissions\nand limitations under the License.\n***************************************************************************** */\n\n\n\n/// <reference no-default-lib="true"/>\n\n\n/// <reference lib="es2015" />\n/// <reference lib="es2016.array.include" />',"lib.es2016.full.d.ts":'/*! *****************************************************************************\nCopyright (c) Microsoft Corporation. All rights reserved.\nLicensed under the Apache License, Version 2.0 (the "License"); you may not use\nthis file except in compliance with the License. You may obtain a copy of the\nLicense at http://www.apache.org/licenses/LICENSE-2.0\n\nTHIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\nKIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED\nWARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,\nMERCHANTABLITY OR NON-INFRINGEMENT.\n\nSee the Apache Version 2.0 License for specific language governing permissions\nand limitations under the License.\n***************************************************************************** */\n\n\n\n/// <reference no-default-lib="true"/>\n\n\n/// <reference lib="es2016" />\n/// <reference lib="dom" />\n/// <reference lib="webworker.importscripts" />\n/// <reference lib="scripthost" />\n/// <reference lib="dom.iterable" />',"lib.es2017.d.ts":'/*! *****************************************************************************\nCopyright (c) Microsoft Corporation. All rights reserved.\nLicensed under the Apache License, Version 2.0 (the "License"); you may not use\nthis file except in compliance with the License. You may obtain a copy of the\nLicense at http://www.apache.org/licenses/LICENSE-2.0\n\nTHIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\nKIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED\nWARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,\nMERCHANTABLITY OR NON-INFRINGEMENT.\n\nSee the Apache Version 2.0 License for specific language governing permissions\nand limitations under the License.\n***************************************************************************** */\n\n\n\n/// <reference no-default-lib="true"/>\n\n\n/// <reference lib="es2016" />\n/// <reference lib="es2017.object" />\n/// <reference lib="es2017.sharedmemory" />\n/// <reference lib="es2017.string" />\n/// <reference lib="es2017.intl" />\n/// <reference lib="es2017.typedarrays" />\n',"lib.es2017.full.d.ts":'/*! *****************************************************************************\nCopyright (c) Microsoft Corporation. All rights reserved.\nLicensed under the Apache License, Version 2.0 (the "License"); you may not use\nthis file except in compliance with the License. You may obtain a copy of the\nLicense at http://www.apache.org/licenses/LICENSE-2.0\n\nTHIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\nKIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED\nWARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,\nMERCHANTABLITY OR NON-INFRINGEMENT.\n\nSee the Apache Version 2.0 License for specific language governing permissions\nand limitations under the License.\n***************************************************************************** */\n\n\n\n/// <reference no-default-lib="true"/>\n\n\n/// <reference lib="es2017" />\n/// <reference lib="dom" />\n/// <reference lib="webworker.importscripts" />\n/// <reference lib="scripthost" />\n/// <reference lib="dom.iterable" />',"lib.es2017.intl.d.ts":'/*! *****************************************************************************\nCopyright (c) Microsoft Corporation. All rights reserved.\nLicensed under the Apache License, Version 2.0 (the "License"); you may not use\nthis file except in compliance with the License. You may obtain a copy of the\nLicense at http://www.apache.org/licenses/LICENSE-2.0\n\nTHIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\nKIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED\nWARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,\nMERCHANTABLITY OR NON-INFRINGEMENT.\n\nSee the Apache Version 2.0 License for specific language governing permissions\nand limitations under the License.\n***************************************************************************** */\n\n\n\n/// <reference no-default-lib="true"/>\n\n\ndeclare namespace Intl {\n    type DateTimeFormatPartTypes = "day" | "dayPeriod" | "era" | "hour" | "literal" | "minute" | "month" | "second" | "timeZoneName" | "weekday" | "year";\n\n    interface DateTimeFormatPart {\n        type: DateTimeFormatPartTypes;\n        value: string;\n    }\n\n    interface DateTimeFormat {\n        formatToParts(date?: Date | number): DateTimeFormatPart[];\n    }\n}\n',"lib.es2017.object.d.ts":'/*! *****************************************************************************\nCopyright (c) Microsoft Corporation. All rights reserved.\nLicensed under the Apache License, Version 2.0 (the "License"); you may not use\nthis file except in compliance with the License. You may obtain a copy of the\nLicense at http://www.apache.org/licenses/LICENSE-2.0\n\nTHIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\nKIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED\nWARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,\nMERCHANTABLITY OR NON-INFRINGEMENT.\n\nSee the Apache Version 2.0 License for specific language governing permissions\nand limitations under the License.\n***************************************************************************** */\n\n\n\n/// <reference no-default-lib="true"/>\n\n\ninterface ObjectConstructor {\n    /**\n     * Returns an array of values of the enumerable properties of an object\n     * @param o Object that contains the properties and methods. This can be an object that you created or an existing Document Object Model (DOM) object.\n     */\n    values<T>(o: { [s: string]: T } | ArrayLike<T>): T[];\n\n    /**\n     * Returns an array of values of the enumerable properties of an object\n     * @param o Object that contains the properties and methods. This can be an object that you created or an existing Document Object Model (DOM) object.\n     */\n    values(o: {}): any[];\n\n    /**\n     * Returns an array of key/values of the enumerable properties of an object\n     * @param o Object that contains the properties and methods. This can be an object that you created or an existing Document Object Model (DOM) object.\n     */\n    entries<T>(o: { [s: string]: T } | ArrayLike<T>): [string, T][];\n\n    /**\n     * Returns an array of key/values of the enumerable properties of an object\n     * @param o Object that contains the properties and methods. This can be an object that you created or an existing Document Object Model (DOM) object.\n     */\n    entries(o: {}): [string, any][];\n\n    /**\n     * Returns an object containing all own property descriptors of an object\n     * @param o Object that contains the properties and methods. This can be an object that you created or an existing Document Object Model (DOM) object.\n     */\n    getOwnPropertyDescriptors<T>(o: T): {[P in keyof T]: TypedPropertyDescriptor<T[P]>} & { [x: string]: PropertyDescriptor };\n}\n',"lib.es2017.sharedmemory.d.ts":'/*! *****************************************************************************\nCopyright (c) Microsoft Corporation. All rights reserved.\nLicensed under the Apache License, Version 2.0 (the "License"); you may not use\nthis file except in compliance with the License. You may obtain a copy of the\nLicense at http://www.apache.org/licenses/LICENSE-2.0\n\nTHIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\nKIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED\nWARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,\nMERCHANTABLITY OR NON-INFRINGEMENT.\n\nSee the Apache Version 2.0 License for specific language governing permissions\nand limitations under the License.\n***************************************************************************** */\n\n\n\n/// <reference no-default-lib="true"/>\n\n\n/// <reference lib="es2015.symbol" />\n/// <reference lib="es2015.symbol.wellknown" />\n\ninterface SharedArrayBuffer {\n    /**\n     * Read-only. The length of the ArrayBuffer (in bytes).\n     */\n    readonly byteLength: number;\n\n    /**\n     * Returns a section of an SharedArrayBuffer.\n     */\n    slice(begin: number, end?: number): SharedArrayBuffer;\n    readonly [Symbol.species]: SharedArrayBuffer;\n    readonly [Symbol.toStringTag]: "SharedArrayBuffer";\n}\n\ninterface SharedArrayBufferConstructor {\n    readonly prototype: SharedArrayBuffer;\n    new (byteLength: number): SharedArrayBuffer;\n}\ndeclare var SharedArrayBuffer: SharedArrayBufferConstructor;\n\ninterface ArrayBufferTypes {\n    SharedArrayBuffer: SharedArrayBuffer;\n}\n\ninterface Atomics {\n    /**\n     * Adds a value to the value at the given position in the array, returning the original value.\n     * Until this atomic operation completes, any other read or write operation against the array\n     * will block.\n     */\n    add(typedArray: Int8Array | Uint8Array | Int16Array | Uint16Array | Int32Array | Uint32Array, index: number, value: number): number;\n\n    /**\n     * Stores the bitwise AND of a value with the value at the given position in the array,\n     * returning the original value. Until this atomic operation completes, any other read or\n     * write operation against the array will block.\n     */\n    and(typedArray: Int8Array | Uint8Array | Int16Array | Uint16Array | Int32Array | Uint32Array, index: number, value: number): number;\n\n    /**\n     * Replaces the value at the given position in the array if the original value equals the given\n     * expected value, returning the original value. Until this atomic operation completes, any\n     * other read or write operation against the array will block.\n     */\n    compareExchange(typedArray: Int8Array | Uint8Array | Int16Array | Uint16Array | Int32Array | Uint32Array, index: number, expectedValue: number, replacementValue: number): number;\n\n    /**\n     * Replaces the value at the given position in the array, returning the original value. Until\n     * this atomic operation completes, any other read or write operation against the array will\n     * block.\n     */\n    exchange(typedArray: Int8Array | Uint8Array | Int16Array | Uint16Array | Int32Array | Uint32Array, index: number, value: number): number;\n\n    /**\n     * Returns a value indicating whether high-performance algorithms can use atomic operations\n     * (`true`) or must use locks (`false`) for the given number of bytes-per-element of a typed\n     * array.\n     */\n    isLockFree(size: number): boolean;\n\n    /**\n     * Returns the value at the given position in the array. Until this atomic operation completes,\n     * any other read or write operation against the array will block.\n     */\n    load(typedArray: Int8Array | Uint8Array | Int16Array | Uint16Array | Int32Array | Uint32Array, index: number): number;\n\n    /**\n     * Stores the bitwise OR of a value with the value at the given position in the array,\n     * returning the original value. Until this atomic operation completes, any other read or write\n     * operation against the array will block.\n     */\n    or(typedArray: Int8Array | Uint8Array | Int16Array | Uint16Array | Int32Array | Uint32Array, index: number, value: number): number;\n\n    /**\n     * Stores a value at the given position in the array, returning the new value. Until this\n     * atomic operation completes, any other read or write operation against the array will block.\n     */\n    store(typedArray: Int8Array | Uint8Array | Int16Array | Uint16Array | Int32Array | Uint32Array, index: number, value: number): number;\n\n    /**\n     * Subtracts a value from the value at the given position in the array, returning the original\n     * value. Until this atomic operation completes, any other read or write operation against the\n     * array will block.\n     */\n    sub(typedArray: Int8Array | Uint8Array | Int16Array | Uint16Array | Int32Array | Uint32Array, index: number, value: number): number;\n\n    /**\n     * If the value at the given position in the array is equal to the provided value, the current\n     * agent is put to sleep causing execution to suspend until the timeout expires (returning\n     * `"timed-out"`) or until the agent is awoken (returning `"ok"`); otherwise, returns\n     * `"not-equal"`.\n     */\n    wait(typedArray: Int32Array, index: number, value: number, timeout?: number): "ok" | "not-equal" | "timed-out";\n\n    /**\n     * Wakes up sleeping agents that are waiting on the given index of the array, returning the\n     * number of agents that were awoken.\n     * @param typedArray A shared Int32Array.\n     * @param index The position in the typedArray to wake up on.\n     * @param count The number of sleeping agents to notify. Defaults to +Infinity.\n     */\n    notify(typedArray: Int32Array, index: number, count?: number): number;\n\n    /**\n     * Stores the bitwise XOR of a value with the value at the given position in the array,\n     * returning the original value. Until this atomic operation completes, any other read or write\n     * operation against the array will block.\n     */\n    xor(typedArray: Int8Array | Uint8Array | Int16Array | Uint16Array | Int32Array | Uint32Array, index: number, value: number): number;\n\n    readonly [Symbol.toStringTag]: "Atomics";\n}\n\ndeclare var Atomics: Atomics;\n',"lib.es2017.string.d.ts":'/*! *****************************************************************************\nCopyright (c) Microsoft Corporation. All rights reserved.\nLicensed under the Apache License, Version 2.0 (the "License"); you may not use\nthis file except in compliance with the License. You may obtain a copy of the\nLicense at http://www.apache.org/licenses/LICENSE-2.0\n\nTHIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\nKIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED\nWARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,\nMERCHANTABLITY OR NON-INFRINGEMENT.\n\nSee the Apache Version 2.0 License for specific language governing permissions\nand limitations under the License.\n***************************************************************************** */\n\n\n\n/// <reference no-default-lib="true"/>\n\n\ninterface String {\n    /**\n     * Pads the current string with a given string (possibly repeated) so that the resulting string reaches a given length.\n     * The padding is applied from the start (left) of the current string.\n     *\n     * @param maxLength The length of the resulting string once the current string has been padded.\n     *        If this parameter is smaller than the current string\'s length, the current string will be returned as it is.\n     *\n     * @param fillString The string to pad the current string with.\n     *        If this string is too long, it will be truncated and the left-most part will be applied.\n     *        The default value for this parameter is " " (U+0020).\n     */\n    padStart(maxLength: number, fillString?: string): string;\n\n    /**\n     * Pads the current string with a given string (possibly repeated) so that the resulting string reaches a given length.\n     * The padding is applied from the end (right) of the current string.\n     *\n     * @param maxLength The length of the resulting string once the current string has been padded.\n     *        If this parameter is smaller than the current string\'s length, the current string will be returned as it is.\n     *\n     * @param fillString The string to pad the current string with.\n     *        If this string is too long, it will be truncated and the left-most part will be applied.\n     *        The default value for this parameter is " " (U+0020).\n     */\n    padEnd(maxLength: number, fillString?: string): string;\n}\n',"lib.es2017.typedarrays.d.ts":'/*! *****************************************************************************\nCopyright (c) Microsoft Corporation. All rights reserved.\nLicensed under the Apache License, Version 2.0 (the "License"); you may not use\nthis file except in compliance with the License. You may obtain a copy of the\nLicense at http://www.apache.org/licenses/LICENSE-2.0\n\nTHIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\nKIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED\nWARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,\nMERCHANTABLITY OR NON-INFRINGEMENT.\n\nSee the Apache Version 2.0 License for specific language governing permissions\nand limitations under the License.\n***************************************************************************** */\n\n\n\n/// <reference no-default-lib="true"/>\n\n\ninterface Int8ArrayConstructor {\n    new (): Int8Array;\n}\n\ninterface Uint8ArrayConstructor {\n    new (): Uint8Array;\n}\n\ninterface Uint8ClampedArrayConstructor {\n    new (): Uint8ClampedArray;\n}\n\ninterface Int16ArrayConstructor {\n    new (): Int16Array;\n}\n\ninterface Uint16ArrayConstructor {\n    new (): Uint16Array;\n}\n\ninterface Int32ArrayConstructor {\n    new (): Int32Array;\n}\n\ninterface Uint32ArrayConstructor {\n    new (): Uint32Array;\n}\n\ninterface Float32ArrayConstructor {\n    new (): Float32Array;\n}\n\ninterface Float64ArrayConstructor {\n    new (): Float64Array;\n}\n',"lib.es2018.asyncgenerator.d.ts":'/*! *****************************************************************************\nCopyright (c) Microsoft Corporation. All rights reserved.\nLicensed under the Apache License, Version 2.0 (the "License"); you may not use\nthis file except in compliance with the License. You may obtain a copy of the\nLicense at http://www.apache.org/licenses/LICENSE-2.0\n\nTHIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\nKIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED\nWARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,\nMERCHANTABLITY OR NON-INFRINGEMENT.\n\nSee the Apache Version 2.0 License for specific language governing permissions\nand limitations under the License.\n***************************************************************************** */\n\n\n\n/// <reference no-default-lib="true"/>\n\n\n/// <reference lib="es2018.asynciterable" />\n\ninterface AsyncGenerator<T = unknown, TReturn = any, TNext = unknown> extends AsyncIterator<T, TReturn, TNext> {\n    // NOTE: \'next\' is defined using a tuple to ensure we report the correct assignability errors in all places.\n    next(...args: [] | [TNext]): Promise<IteratorResult<T, TReturn>>;\n    return(value: TReturn | PromiseLike<TReturn>): Promise<IteratorResult<T, TReturn>>;\n    throw(e: any): Promise<IteratorResult<T, TReturn>>;\n    [Symbol.asyncIterator](): AsyncGenerator<T, TReturn, TNext>;\n}\n\ninterface AsyncGeneratorFunction {\n    /**\n     * Creates a new AsyncGenerator object.\n     * @param args A list of arguments the function accepts.\n     */\n    new (...args: any[]): AsyncGenerator;\n    /**\n     * Creates a new AsyncGenerator object.\n     * @param args A list of arguments the function accepts.\n     */\n    (...args: any[]): AsyncGenerator;\n    /**\n     * The length of the arguments.\n     */\n    readonly length: number;\n    /**\n     * Returns the name of the function.\n     */\n    readonly name: string;\n    /**\n     * A reference to the prototype.\n     */\n    readonly prototype: AsyncGenerator;\n}\n\ninterface AsyncGeneratorFunctionConstructor {\n    /**\n     * Creates a new AsyncGenerator function.\n     * @param args A list of arguments the function accepts.\n     */\n    new (...args: string[]): AsyncGeneratorFunction;\n    /**\n     * Creates a new AsyncGenerator function.\n     * @param args A list of arguments the function accepts.\n     */\n    (...args: string[]): AsyncGeneratorFunction;\n    /**\n     * The length of the arguments.\n     */\n    readonly length: number;\n    /**\n     * Returns the name of the function.\n     */\n    readonly name: string;\n    /**\n     * A reference to the prototype.\n     */\n    readonly prototype: AsyncGeneratorFunction;\n}\n',"lib.es2018.asynciterable.d.ts":'/*! *****************************************************************************\nCopyright (c) Microsoft Corporation. All rights reserved.\nLicensed under the Apache License, Version 2.0 (the "License"); you may not use\nthis file except in compliance with the License. You may obtain a copy of the\nLicense at http://www.apache.org/licenses/LICENSE-2.0\n\nTHIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\nKIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED\nWARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,\nMERCHANTABLITY OR NON-INFRINGEMENT.\n\nSee the Apache Version 2.0 License for specific language governing permissions\nand limitations under the License.\n***************************************************************************** */\n\n\n\n/// <reference no-default-lib="true"/>\n\n\n/// <reference lib="es2015.symbol" />\n/// <reference lib="es2015.iterable" />\n\ninterface SymbolConstructor {\n    /**\n     * A method that returns the default async iterator for an object. Called by the semantics of\n     * the for-await-of statement.\n     */\n    readonly asyncIterator: unique symbol;\n}\n\ninterface AsyncIterator<T, TReturn = any, TNext = undefined> {\n    // NOTE: \'next\' is defined using a tuple to ensure we report the correct assignability errors in all places.\n    next(...args: [] | [TNext]): Promise<IteratorResult<T, TReturn>>;\n    return?(value?: TReturn | PromiseLike<TReturn>): Promise<IteratorResult<T, TReturn>>;\n    throw?(e?: any): Promise<IteratorResult<T, TReturn>>;\n}\n\ninterface AsyncIterable<T> {\n    [Symbol.asyncIterator](): AsyncIterator<T>;\n}\n\ninterface AsyncIterableIterator<T> extends AsyncIterator<T> {\n    [Symbol.asyncIterator](): AsyncIterableIterator<T>;\n}',"lib.es2018.d.ts":'/*! *****************************************************************************\nCopyright (c) Microsoft Corporation. All rights reserved.\nLicensed under the Apache License, Version 2.0 (the "License"); you may not use\nthis file except in compliance with the License. You may obtain a copy of the\nLicense at http://www.apache.org/licenses/LICENSE-2.0\n\nTHIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\nKIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED\nWARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,\nMERCHANTABLITY OR NON-INFRINGEMENT.\n\nSee the Apache Version 2.0 License for specific language governing permissions\nand limitations under the License.\n***************************************************************************** */\n\n\n\n/// <reference no-default-lib="true"/>\n\n\n/// <reference lib="es2017" />\n/// <reference lib="es2018.asynciterable" />\n/// <reference lib="es2018.asyncgenerator" />\n/// <reference lib="es2018.promise" />\n/// <reference lib="es2018.regexp" />\n/// <reference lib="es2018.intl" />\n',"lib.es2018.full.d.ts":'/*! *****************************************************************************\nCopyright (c) Microsoft Corporation. All rights reserved.\nLicensed under the Apache License, Version 2.0 (the "License"); you may not use\nthis file except in compliance with the License. You may obtain a copy of the\nLicense at http://www.apache.org/licenses/LICENSE-2.0\n\nTHIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\nKIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED\nWARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,\nMERCHANTABLITY OR NON-INFRINGEMENT.\n\nSee the Apache Version 2.0 License for specific language governing permissions\nand limitations under the License.\n***************************************************************************** */\n\n\n\n/// <reference no-default-lib="true"/>\n\n\n/// <reference lib="es2018" />\n/// <reference lib="dom" />\n/// <reference lib="webworker.importscripts" />\n/// <reference lib="scripthost" />\n/// <reference lib="dom.iterable" />',"lib.es2018.intl.d.ts":'/*! *****************************************************************************\nCopyright (c) Microsoft Corporation. All rights reserved.\nLicensed under the Apache License, Version 2.0 (the "License"); you may not use\nthis file except in compliance with the License. You may obtain a copy of the\nLicense at http://www.apache.org/licenses/LICENSE-2.0\n\nTHIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\nKIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED\nWARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,\nMERCHANTABLITY OR NON-INFRINGEMENT.\n\nSee the Apache Version 2.0 License for specific language governing permissions\nand limitations under the License.\n***************************************************************************** */\n\n\n\n/// <reference no-default-lib="true"/>\n\n\ndeclare namespace Intl {\n\n    // http://cldr.unicode.org/index/cldr-spec/plural-rules#TOC-Determining-Plural-Categories\n    type LDMLPluralRule = "zero" | "one" | "two" | "few" | "many" | "other";\n    type PluralRuleType = "cardinal" | "ordinal";\n\n    interface PluralRulesOptions {\n        localeMatcher?: "lookup" | "best fit";\n        type?: PluralRuleType;\n        minimumIntegerDigits?: number;\n        minimumFractionDigits?: number;\n        maximumFractionDigits?: number;\n        minimumSignificantDigits?: number;\n        maximumSignificantDigits?: number;\n    }\n\n    interface ResolvedPluralRulesOptions {\n        locale: string;\n        pluralCategories: LDMLPluralRule[];\n        type: PluralRuleType;\n        minimumIntegerDigits: number;\n        minimumFractionDigits: number;\n        maximumFractionDigits: number;\n        minimumSignificantDigits?: number;\n        maximumSignificantDigits?: number;\n    }\n\n    interface PluralRules {\n        resolvedOptions(): ResolvedPluralRulesOptions;\n        select(n: number): LDMLPluralRule;\n    }\n\n    const PluralRules: {\n        new (locales?: string | string[], options?: PluralRulesOptions): PluralRules;\n        (locales?: string | string[], options?: PluralRulesOptions): PluralRules;\n        supportedLocalesOf(\n            locales: string | string[],\n            options?: PluralRulesOptions,\n        ): string[];\n    };\n}\n',"lib.es2018.promise.d.ts":'/*! *****************************************************************************\nCopyright (c) Microsoft Corporation. All rights reserved.\nLicensed under the Apache License, Version 2.0 (the "License"); you may not use\nthis file except in compliance with the License. You may obtain a copy of the\nLicense at http://www.apache.org/licenses/LICENSE-2.0\n\nTHIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\nKIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED\nWARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,\nMERCHANTABLITY OR NON-INFRINGEMENT.\n\nSee the Apache Version 2.0 License for specific language governing permissions\nand limitations under the License.\n***************************************************************************** */\n\n\n\n/// <reference no-default-lib="true"/>\n\n\n/**\n * Represents the completion of an asynchronous operation\n */\ninterface Promise<T> {\n    /**\n     * Attaches a callback that is invoked when the Promise is settled (fulfilled or rejected). The\n     * resolved value cannot be modified from the callback.\n     * @param onfinally The callback to execute when the Promise is settled (fulfilled or rejected).\n     * @returns A Promise for the completion of the callback.\n     */\n    finally(onfinally?: (() => void) | undefined | null): Promise<T>\n}\n',"lib.es2018.regexp.d.ts":'/*! *****************************************************************************\nCopyright (c) Microsoft Corporation. All rights reserved.\nLicensed under the Apache License, Version 2.0 (the "License"); you may not use\nthis file except in compliance with the License. You may obtain a copy of the\nLicense at http://www.apache.org/licenses/LICENSE-2.0\n\nTHIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\nKIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED\nWARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,\nMERCHANTABLITY OR NON-INFRINGEMENT.\n\nSee the Apache Version 2.0 License for specific language governing permissions\nand limitations under the License.\n***************************************************************************** */\n\n\n\n/// <reference no-default-lib="true"/>\n\n\ninterface RegExpMatchArray {\n    groups?: {\n        [key: string]: string\n    }\n}\n\ninterface RegExpExecArray {\n    groups?: {\n        [key: string]: string\n    }\n}\n\ninterface RegExp {\n    /**\n     * Returns a Boolean value indicating the state of the dotAll flag (s) used with a regular expression.\n     * Default is false. Read-only.\n     */\n    readonly dotAll: boolean;\n}',"lib.es2019.array.d.ts":'/*! *****************************************************************************\nCopyright (c) Microsoft Corporation. All rights reserved.\nLicensed under the Apache License, Version 2.0 (the "License"); you may not use\nthis file except in compliance with the License. You may obtain a copy of the\nLicense at http://www.apache.org/licenses/LICENSE-2.0\n\nTHIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\nKIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED\nWARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,\nMERCHANTABLITY OR NON-INFRINGEMENT.\n\nSee the Apache Version 2.0 License for specific language governing permissions\nand limitations under the License.\n***************************************************************************** */\n\n\n\n/// <reference no-default-lib="true"/>\n\n\ntype FlatArray<Arr, Depth extends number> = {\n    "done": Arr,\n    "recur": Arr extends ReadonlyArray<infer InnerArr>\n        ? FlatArray<InnerArr, [-1, 0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20][Depth]>\n        : Arr\n}[Depth extends -1 ? "done" : "recur"];\n\ninterface ReadonlyArray<T> {\n\n    /**\n     * Calls a defined callback function on each element of an array. Then, flattens the result into\n     * a new array.\n     * This is identical to a map followed by flat with depth 1.\n     *\n     * @param callback A function that accepts up to three arguments. The flatMap method calls the\n     * callback function one time for each element in the array.\n     * @param thisArg An object to which the this keyword can refer in the callback function. If\n     * thisArg is omitted, undefined is used as the this value.\n     */\n    flatMap<U, This = undefined> (\n        callback: (this: This, value: T, index: number, array: T[]) => U | ReadonlyArray<U>,\n        thisArg?: This\n    ): U[]\n\n\n    /**\n     * Returns a new array with all sub-array elements concatenated into it recursively up to the\n     * specified depth.\n     *\n     * @param depth The maximum recursion depth\n     */\n    flat<A, D extends number = 1>(\n        this: A,\n        depth?: D\n    ): FlatArray<A, D>[]\n  }\n\ninterface Array<T> {\n\n    /**\n     * Calls a defined callback function on each element of an array. Then, flattens the result into\n     * a new array.\n     * This is identical to a map followed by flat with depth 1.\n     *\n     * @param callback A function that accepts up to three arguments. The flatMap method calls the\n     * callback function one time for each element in the array.\n     * @param thisArg An object to which the this keyword can refer in the callback function. If\n     * thisArg is omitted, undefined is used as the this value.\n     */\n    flatMap<U, This = undefined> (\n        callback: (this: This, value: T, index: number, array: T[]) => U | ReadonlyArray<U>,\n        thisArg?: This\n    ): U[]\n\n    /**\n     * Returns a new array with all sub-array elements concatenated into it recursively up to the\n     * specified depth.\n     *\n     * @param depth The maximum recursion depth\n     */\n    flat<A, D extends number = 1>(\n        this: A,\n        depth?: D\n    ): FlatArray<A, D>[]\n}\n',"lib.es2019.d.ts":'/*! *****************************************************************************\nCopyright (c) Microsoft Corporation. All rights reserved.\nLicensed under the Apache License, Version 2.0 (the "License"); you may not use\nthis file except in compliance with the License. You may obtain a copy of the\nLicense at http://www.apache.org/licenses/LICENSE-2.0\n\nTHIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\nKIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED\nWARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,\nMERCHANTABLITY OR NON-INFRINGEMENT.\n\nSee the Apache Version 2.0 License for specific language governing permissions\nand limitations under the License.\n***************************************************************************** */\n\n\n\n/// <reference no-default-lib="true"/>\n\n\n/// <reference lib="es2018" />\n/// <reference lib="es2019.array" />\n/// <reference lib="es2019.object" />\n/// <reference lib="es2019.string" />\n/// <reference lib="es2019.symbol" />\n',"lib.es2019.full.d.ts":'/*! *****************************************************************************\nCopyright (c) Microsoft Corporation. All rights reserved.\nLicensed under the Apache License, Version 2.0 (the "License"); you may not use\nthis file except in compliance with the License. You may obtain a copy of the\nLicense at http://www.apache.org/licenses/LICENSE-2.0\n\nTHIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\nKIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED\nWARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,\nMERCHANTABLITY OR NON-INFRINGEMENT.\n\nSee the Apache Version 2.0 License for specific language governing permissions\nand limitations under the License.\n***************************************************************************** */\n\n\n\n/// <reference no-default-lib="true"/>\n\n\n/// <reference lib="es2019" />\n/// <reference lib="dom" />\n/// <reference lib="webworker.importscripts" />\n/// <reference lib="scripthost" />\n/// <reference lib="dom.iterable" />\n',"lib.es2019.object.d.ts":'/*! *****************************************************************************\nCopyright (c) Microsoft Corporation. All rights reserved.\nLicensed under the Apache License, Version 2.0 (the "License"); you may not use\nthis file except in compliance with the License. You may obtain a copy of the\nLicense at http://www.apache.org/licenses/LICENSE-2.0\n\nTHIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\nKIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED\nWARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,\nMERCHANTABLITY OR NON-INFRINGEMENT.\n\nSee the Apache Version 2.0 License for specific language governing permissions\nand limitations under the License.\n***************************************************************************** */\n\n\n\n/// <reference no-default-lib="true"/>\n\n\n/// <reference lib="es2015.iterable" />\n\ninterface ObjectConstructor {\n    /**\n     * Returns an object created by key-value entries for properties and methods\n     * @param entries An iterable object that contains key-value entries for properties and methods.\n     */\n    fromEntries<T = any>(entries: Iterable<readonly [PropertyKey, T]>): { [k: string]: T };\n\n    /**\n     * Returns an object created by key-value entries for properties and methods\n     * @param entries An iterable object that contains key-value entries for properties and methods.\n     */\n    fromEntries(entries: Iterable<readonly any[]>): any;\n}\n',"lib.es2019.string.d.ts":'/*! *****************************************************************************\nCopyright (c) Microsoft Corporation. All rights reserved.\nLicensed under the Apache License, Version 2.0 (the "License"); you may not use\nthis file except in compliance with the License. You may obtain a copy of the\nLicense at http://www.apache.org/licenses/LICENSE-2.0\n\nTHIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\nKIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED\nWARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,\nMERCHANTABLITY OR NON-INFRINGEMENT.\n\nSee the Apache Version 2.0 License for specific language governing permissions\nand limitations under the License.\n***************************************************************************** */\n\n\n\n/// <reference no-default-lib="true"/>\n\n\ninterface String {\n    /** Removes the trailing white space and line terminator characters from a string. */\n    trimEnd(): string;\n\n    /** Removes the leading white space and line terminator characters from a string. */\n    trimStart(): string;\n\n    /** Removes the leading white space and line terminator characters from a string. */\n    trimLeft(): string;\n\n    /** Removes the trailing white space and line terminator characters from a string. */\n    trimRight(): string;\n}\n',"lib.es2019.symbol.d.ts":'/*! *****************************************************************************\nCopyright (c) Microsoft Corporation. All rights reserved.\nLicensed under the Apache License, Version 2.0 (the "License"); you may not use\nthis file except in compliance with the License. You may obtain a copy of the\nLicense at http://www.apache.org/licenses/LICENSE-2.0\n\nTHIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\nKIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED\nWARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,\nMERCHANTABLITY OR NON-INFRINGEMENT.\n\nSee the Apache Version 2.0 License for specific language governing permissions\nand limitations under the License.\n***************************************************************************** */\n\n\n\n/// <reference no-default-lib="true"/>\n\n\ninterface Symbol {\n    /**\n     * Expose the [[Description]] internal slot of a symbol directly.\n     */\n    readonly description: string | undefined;\n}\n',"lib.es2020.bigint.d.ts":'/*! *****************************************************************************\nCopyright (c) Microsoft Corporation. All rights reserved.\nLicensed under the Apache License, Version 2.0 (the "License"); you may not use\nthis file except in compliance with the License. You may obtain a copy of the\nLicense at http://www.apache.org/licenses/LICENSE-2.0\n\nTHIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\nKIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED\nWARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,\nMERCHANTABLITY OR NON-INFRINGEMENT.\n\nSee the Apache Version 2.0 License for specific language governing permissions\nand limitations under the License.\n***************************************************************************** */\n\n\n\n/// <reference no-default-lib="true"/>\n\n\ninterface BigIntToLocaleStringOptions {\n    /**\n     * The locale matching algorithm to use.The default is "best fit". For information about this option, see the {@link https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Intl#Locale_negotiation Intl page}.\n     */\n    localeMatcher?: string;\n    /**\n     * The formatting style to use , the default is "decimal".\n     */\n    style?: string;\n\n    numberingSystem?: string;\n    /**\n     * The unit to use in unit formatting, Possible values are core unit identifiers, defined in UTS #35, Part 2, Section 6. A subset of units from the full list was selected for use in ECMAScript. Pairs of simple units can be concatenated with "-per-" to make a compound unit. There is no default value; if the style is "unit", the unit property must be provided.\n     */\n    unit?: string;\n\n    /**\n     * The unit formatting style to use in unit formatting, the defaults is "short".\n     */\n    unitDisplay?: string;\n\n    /**\n     * The currency to use in currency formatting. Possible values are the ISO 4217 currency codes, such as "USD" for the US dollar, "EUR" for the euro, or "CNY" for the Chinese RMB — see the Current currency & funds code list. There is no default value; if the style is "currency", the currency property must be provided. It is only used when [[Style]] has the value "currency".\n     */\n    currency?: string;\n\n    /**\n     * How to display the currency in currency formatting. It is only used when [[Style]] has the value "currency". The default is "symbol".\n     *\n     * "symbol" to use a localized currency symbol such as €,\n     *\n     * "code" to use the ISO currency code,\n     *\n     * "name" to use a localized currency name such as "dollar"\n     */\n    currencyDisplay?: string;\n\n    /**\n     * Whether to use grouping separators, such as thousands separators or thousand/lakh/crore separators. The default is true.\n     */\n    useGrouping?: boolean;\n\n    /**\n     * The minimum number of integer digits to use. Possible values are from 1 to 21; the default is 1.\n     */\n    minimumIntegerDigits?: 1 | 2 | 3 | 4 | 5 | 6 | 7 | 8 | 9 | 10 | 11 | 12 | 13 | 14 | 15 | 16 | 17 | 18 | 19 | 20 | 21;\n\n    /**\n     * The minimum number of fraction digits to use. Possible values are from 0 to 20; the default for plain number and percent formatting is 0; the default for currency formatting is the number of minor unit digits provided by the {@link http://www.currency-iso.org/en/home/tables/table-a1.html ISO 4217 currency codes list} (2 if the list doesn\'t provide that information).\n     */\n    minimumFractionDigits?: 0 | 1 | 2 | 3 | 4 | 5 | 6 | 7 | 8 | 9 | 10 | 11 | 12 | 13 | 14 | 15 | 16 | 17 | 18 | 19 | 20;\n\n    /**\n     * The maximum number of fraction digits to use. Possible values are from 0 to 20; the default for plain number formatting is the larger of minimumFractionDigits and 3; the default for currency formatting is the larger of minimumFractionDigits and the number of minor unit digits provided by the {@link http://www.currency-iso.org/en/home/tables/table-a1.html ISO 4217 currency codes list} (2 if the list doesn\'t provide that information); the default for percent formatting is the larger of minimumFractionDigits and 0.\n     */\n    maximumFractionDigits?: 0 | 1 | 2 | 3 | 4 | 5 | 6 | 7 | 8 | 9 | 10 | 11 | 12 | 13 | 14 | 15 | 16 | 17 | 18 | 19 | 20;\n\n    /**\n     * The minimum number of significant digits to use. Possible values are from 1 to 21; the default is 1.\n     */\n    minimumSignificantDigits?: 1 | 2 | 3 | 4 | 5 | 6 | 7 | 8 | 9 | 10 | 11 | 12 | 13 | 14 | 15 | 16 | 17 | 18 | 19 | 20 | 21;\n\n    /**\n     * The maximum number of significant digits to use. Possible values are from 1 to 21; the default is 21.\n     */\n    maximumSignificantDigits?: 1 | 2 | 3 | 4 | 5 | 6 | 7 | 8 | 9 | 10 | 11 | 12 | 13 | 14 | 15 | 16 | 17 | 18 | 19 | 20 | 21;\n\n    /**\n     * The formatting that should be displayed for the number, the defaults is "standard"\n     *\n     *     "standard" plain number formatting\n     *\n     *     "scientific" return the order-of-magnitude for formatted number.\n     *\n     *     "engineering" return the exponent of ten when divisible by three\n     *\n     *     "compact" string representing exponent, defaults is using the "short" form\n     */\n    notation?: string;\n\n    /**\n     * used only when notation is "compact"\n     */\n    compactDisplay?: string;\n}\n\ninterface BigInt {\n    /**\n     * Returns a string representation of an object.\n     * @param radix Specifies a radix for converting numeric values to strings.\n     */\n    toString(radix?: number): string;\n\n    /** Returns a string representation appropriate to the host environment\'s current locale. */\n    toLocaleString(locales?: string, options?: BigIntToLocaleStringOptions): string;\n\n    /** Returns the primitive value of the specified object. */\n    valueOf(): bigint;\n\n    readonly [Symbol.toStringTag]: "BigInt";\n}\n\ninterface BigIntConstructor {\n    (value: bigint | boolean | number | string): bigint;\n    readonly prototype: BigInt;\n\n    /**\n     * Interprets the low bits of a BigInt as a 2\'s-complement signed integer.\n     * All higher bits are discarded.\n     * @param bits The number of low bits to use\n     * @param int The BigInt whose bits to extract\n     */\n    asIntN(bits: number, int: bigint): bigint;\n    /**\n     * Interprets the low bits of a BigInt as an unsigned integer.\n     * All higher bits are discarded.\n     * @param bits The number of low bits to use\n     * @param int The BigInt whose bits to extract\n     */\n    asUintN(bits: number, int: bigint): bigint;\n}\n\ndeclare var BigInt: BigIntConstructor;\n\n/**\n * A typed array of 64-bit signed integer values. The contents are initialized to 0. If the\n * requested number of bytes could not be allocated, an exception is raised.\n */\ninterface BigInt64Array {\n    /** The size in bytes of each element in the array. */\n    readonly BYTES_PER_ELEMENT: number;\n\n    /** The ArrayBuffer instance referenced by the array. */\n    readonly buffer: ArrayBufferLike;\n\n    /** The length in bytes of the array. */\n    readonly byteLength: number;\n\n    /** The offset in bytes of the array. */\n    readonly byteOffset: number;\n\n    /**\n     * Returns the this object after copying a section of the array identified by start and end\n     * to the same array starting at position target\n     * @param target If target is negative, it is treated as length+target where length is the\n     * length of the array.\n     * @param start If start is negative, it is treated as length+start. If end is negative, it\n     * is treated as length+end.\n     * @param end If not specified, length of the this object is used as its default value.\n     */\n    copyWithin(target: number, start: number, end?: number): this;\n\n    /** Yields index, value pairs for every entry in the array. */\n    entries(): IterableIterator<[number, bigint]>;\n\n    /**\n     * Determines whether all the members of an array satisfy the specified test.\n     * @param predicate A function that accepts up to three arguments. The every method calls\n     * the predicate function for each element in the array until the predicate returns false,\n     * or until the end of the array.\n     * @param thisArg An object to which the this keyword can refer in the predicate function.\n     * If thisArg is omitted, undefined is used as the this value.\n     */\n    every(predicate: (value: bigint, index: number, array: BigInt64Array) => boolean, thisArg?: any): boolean;\n\n    /**\n     * Returns the this object after filling the section identified by start and end with value\n     * @param value value to fill array section with\n     * @param start index to start filling the array at. If start is negative, it is treated as\n     * length+start where length is the length of the array.\n     * @param end index to stop filling the array at. If end is negative, it is treated as\n     * length+end.\n     */\n    fill(value: bigint, start?: number, end?: number): this;\n\n    /**\n     * Returns the elements of an array that meet the condition specified in a callback function.\n     * @param predicate A function that accepts up to three arguments. The filter method calls\n     * the predicate function one time for each element in the array.\n     * @param thisArg An object to which the this keyword can refer in the predicate function.\n     * If thisArg is omitted, undefined is used as the this value.\n     */\n    filter(predicate: (value: bigint, index: number, array: BigInt64Array) => any, thisArg?: any): BigInt64Array;\n\n    /**\n     * Returns the value of the first element in the array where predicate is true, and undefined\n     * otherwise.\n     * @param predicate find calls predicate once for each element of the array, in ascending\n     * order, until it finds one where predicate returns true. If such an element is found, find\n     * immediately returns that element value. Otherwise, find returns undefined.\n     * @param thisArg If provided, it will be used as the this value for each invocation of\n     * predicate. If it is not provided, undefined is used instead.\n     */\n    find(predicate: (value: bigint, index: number, array: BigInt64Array) => boolean, thisArg?: any): bigint | undefined;\n\n    /**\n     * Returns the index of the first element in the array where predicate is true, and -1\n     * otherwise.\n     * @param predicate find calls predicate once for each element of the array, in ascending\n     * order, until it finds one where predicate returns true. If such an element is found,\n     * findIndex immediately returns that element index. Otherwise, findIndex returns -1.\n     * @param thisArg If provided, it will be used as the this value for each invocation of\n     * predicate. If it is not provided, undefined is used instead.\n     */\n    findIndex(predicate: (value: bigint, index: number, array: BigInt64Array) => boolean, thisArg?: any): number;\n\n    /**\n     * Performs the specified action for each element in an array.\n     * @param callbackfn A function that accepts up to three arguments. forEach calls the\n     * callbackfn function one time for each element in the array.\n     * @param thisArg An object to which the this keyword can refer in the callbackfn function.\n     * If thisArg is omitted, undefined is used as the this value.\n     */\n    forEach(callbackfn: (value: bigint, index: number, array: BigInt64Array) => void, thisArg?: any): void;\n\n    /**\n     * Determines whether an array includes a certain element, returning true or false as appropriate.\n     * @param searchElement The element to search for.\n     * @param fromIndex The position in this array at which to begin searching for searchElement.\n     */\n    includes(searchElement: bigint, fromIndex?: number): boolean;\n\n    /**\n     * Returns the index of the first occurrence of a value in an array.\n     * @param searchElement The value to locate in the array.\n     * @param fromIndex The array index at which to begin the search. If fromIndex is omitted, the\n     * search starts at index 0.\n     */\n    indexOf(searchElement: bigint, fromIndex?: number): number;\n\n    /**\n     * Adds all the elements of an array separated by the specified separator string.\n     * @param separator A string used to separate one element of an array from the next in the\n     * resulting String. If omitted, the array elements are separated with a comma.\n     */\n    join(separator?: string): string;\n\n    /** Yields each index in the array. */\n    keys(): IterableIterator<number>;\n\n    /**\n     * Returns the index of the last occurrence of a value in an array.\n     * @param searchElement The value to locate in the array.\n     * @param fromIndex The array index at which to begin the search. If fromIndex is omitted, the\n     * search starts at index 0.\n     */\n    lastIndexOf(searchElement: bigint, fromIndex?: number): number;\n\n    /** The length of the array. */\n    readonly length: number;\n\n    /**\n     * Calls a defined callback function on each element of an array, and returns an array that\n     * contains the results.\n     * @param callbackfn A function that accepts up to three arguments. The map method calls the\n     * callbackfn function one time for each element in the array.\n     * @param thisArg An object to which the this keyword can refer in the callbackfn function.\n     * If thisArg is omitted, undefined is used as the this value.\n     */\n    map(callbackfn: (value: bigint, index: number, array: BigInt64Array) => bigint, thisArg?: any): BigInt64Array;\n\n    /**\n     * Calls the specified callback function for all the elements in an array. The return value of\n     * the callback function is the accumulated result, and is provided as an argument in the next\n     * call to the callback function.\n     * @param callbackfn A function that accepts up to four arguments. The reduce method calls the\n     * callbackfn function one time for each element in the array.\n     * @param initialValue If initialValue is specified, it is used as the initial value to start\n     * the accumulation. The first call to the callbackfn function provides this value as an argument\n     * instead of an array value.\n     */\n    reduce(callbackfn: (previousValue: bigint, currentValue: bigint, currentIndex: number, array: BigInt64Array) => bigint): bigint;\n\n    /**\n     * Calls the specified callback function for all the elements in an array. The return value of\n     * the callback function is the accumulated result, and is provided as an argument in the next\n     * call to the callback function.\n     * @param callbackfn A function that accepts up to four arguments. The reduce method calls the\n     * callbackfn function one time for each element in the array.\n     * @param initialValue If initialValue is specified, it is used as the initial value to start\n     * the accumulation. The first call to the callbackfn function provides this value as an argument\n     * instead of an array value.\n     */\n    reduce<U>(callbackfn: (previousValue: U, currentValue: bigint, currentIndex: number, array: BigInt64Array) => U, initialValue: U): U;\n\n    /**\n     * Calls the specified callback function for all the elements in an array, in descending order.\n     * The return value of the callback function is the accumulated result, and is provided as an\n     * argument in the next call to the callback function.\n     * @param callbackfn A function that accepts up to four arguments. The reduceRight method calls\n     * the callbackfn function one time for each element in the array.\n     * @param initialValue If initialValue is specified, it is used as the initial value to start\n     * the accumulation. The first call to the callbackfn function provides this value as an\n     * argument instead of an array value.\n     */\n    reduceRight(callbackfn: (previousValue: bigint, currentValue: bigint, currentIndex: number, array: BigInt64Array) => bigint): bigint;\n\n    /**\n     * Calls the specified callback function for all the elements in an array, in descending order.\n     * The return value of the callback function is the accumulated result, and is provided as an\n     * argument in the next call to the callback function.\n     * @param callbackfn A function that accepts up to four arguments. The reduceRight method calls\n     * the callbackfn function one time for each element in the array.\n     * @param initialValue If initialValue is specified, it is used as the initial value to start\n     * the accumulation. The first call to the callbackfn function provides this value as an argument\n     * instead of an array value.\n     */\n    reduceRight<U>(callbackfn: (previousValue: U, currentValue: bigint, currentIndex: number, array: BigInt64Array) => U, initialValue: U): U;\n\n    /** Reverses the elements in the array. */\n    reverse(): this;\n\n    /**\n     * Sets a value or an array of values.\n     * @param array A typed or untyped array of values to set.\n     * @param offset The index in the current array at which the values are to be written.\n     */\n    set(array: ArrayLike<bigint>, offset?: number): void;\n\n    /**\n     * Returns a section of an array.\n     * @param start The beginning of the specified portion of the array.\n     * @param end The end of the specified portion of the array.\n     */\n    slice(start?: number, end?: number): BigInt64Array;\n\n    /**\n     * Determines whether the specified callback function returns true for any element of an array.\n     * @param predicate A function that accepts up to three arguments. The some method calls the\n     * predicate function for each element in the array until the predicate returns true, or until\n     * the end of the array.\n     * @param thisArg An object to which the this keyword can refer in the predicate function.\n     * If thisArg is omitted, undefined is used as the this value.\n     */\n    some(predicate: (value: bigint, index: number, array: BigInt64Array) => boolean, thisArg?: any): boolean;\n\n    /**\n     * Sorts the array.\n     * @param compareFn The function used to determine the order of the elements. If omitted, the elements are sorted in ascending order.\n     */\n    sort(compareFn?: (a: bigint, b: bigint) => number | bigint): this;\n\n    /**\n     * Gets a new BigInt64Array view of the ArrayBuffer store for this array, referencing the elements\n     * at begin, inclusive, up to end, exclusive.\n     * @param begin The index of the beginning of the array.\n     * @param end The index of the end of the array.\n     */\n    subarray(begin?: number, end?: number): BigInt64Array;\n\n    /** Converts the array to a string by using the current locale. */\n    toLocaleString(): string;\n\n    /** Returns a string representation of the array. */\n    toString(): string;\n\n    /** Returns the primitive value of the specified object. */\n    valueOf(): BigInt64Array;\n\n    /** Yields each value in the array. */\n    values(): IterableIterator<bigint>;\n\n    [Symbol.iterator](): IterableIterator<bigint>;\n\n    readonly [Symbol.toStringTag]: "BigInt64Array";\n\n    [index: number]: bigint;\n}\n\ninterface BigInt64ArrayConstructor {\n    readonly prototype: BigInt64Array;\n    new(length?: number): BigInt64Array;\n    new(array: Iterable<bigint>): BigInt64Array;\n    new(buffer: ArrayBufferLike, byteOffset?: number, length?: number): BigInt64Array;\n\n    /** The size in bytes of each element in the array. */\n    readonly BYTES_PER_ELEMENT: number;\n\n    /**\n     * Returns a new array from a set of elements.\n     * @param items A set of elements to include in the new array object.\n     */\n    of(...items: bigint[]): BigInt64Array;\n\n    /**\n     * Creates an array from an array-like or iterable object.\n     * @param arrayLike An array-like or iterable object to convert to an array.\n     * @param mapfn A mapping function to call on every element of the array.\n     * @param thisArg Value of \'this\' used to invoke the mapfn.\n     */\n    from(arrayLike: ArrayLike<bigint>): BigInt64Array;\n    from<U>(arrayLike: ArrayLike<U>, mapfn: (v: U, k: number) => bigint, thisArg?: any): BigInt64Array;\n}\n\ndeclare var BigInt64Array: BigInt64ArrayConstructor;\n\n/**\n * A typed array of 64-bit unsigned integer values. The contents are initialized to 0. If the\n * requested number of bytes could not be allocated, an exception is raised.\n */\ninterface BigUint64Array {\n    /** The size in bytes of each element in the array. */\n    readonly BYTES_PER_ELEMENT: number;\n\n    /** The ArrayBuffer instance referenced by the array. */\n    readonly buffer: ArrayBufferLike;\n\n    /** The length in bytes of the array. */\n    readonly byteLength: number;\n\n    /** The offset in bytes of the array. */\n    readonly byteOffset: number;\n\n    /**\n     * Returns the this object after copying a section of the array identified by start and end\n     * to the same array starting at position target\n     * @param target If target is negative, it is treated as length+target where length is the\n     * length of the array.\n     * @param start If start is negative, it is treated as length+start. If end is negative, it\n     * is treated as length+end.\n     * @param end If not specified, length of the this object is used as its default value.\n     */\n    copyWithin(target: number, start: number, end?: number): this;\n\n    /** Yields index, value pairs for every entry in the array. */\n    entries(): IterableIterator<[number, bigint]>;\n\n    /**\n     * Determines whether all the members of an array satisfy the specified test.\n     * @param predicate A function that accepts up to three arguments. The every method calls\n     * the predicate function for each element in the array until the predicate returns false,\n     * or until the end of the array.\n     * @param thisArg An object to which the this keyword can refer in the predicate function.\n     * If thisArg is omitted, undefined is used as the this value.\n     */\n    every(predicate: (value: bigint, index: number, array: BigUint64Array) => boolean, thisArg?: any): boolean;\n\n    /**\n     * Returns the this object after filling the section identified by start and end with value\n     * @param value value to fill array section with\n     * @param start index to start filling the array at. If start is negative, it is treated as\n     * length+start where length is the length of the array.\n     * @param end index to stop filling the array at. If end is negative, it is treated as\n     * length+end.\n     */\n    fill(value: bigint, start?: number, end?: number): this;\n\n    /**\n     * Returns the elements of an array that meet the condition specified in a callback function.\n     * @param predicate A function that accepts up to three arguments. The filter method calls\n     * the predicate function one time for each element in the array.\n     * @param thisArg An object to which the this keyword can refer in the predicate function.\n     * If thisArg is omitted, undefined is used as the this value.\n     */\n    filter(predicate: (value: bigint, index: number, array: BigUint64Array) => any, thisArg?: any): BigUint64Array;\n\n    /**\n     * Returns the value of the first element in the array where predicate is true, and undefined\n     * otherwise.\n     * @param predicate find calls predicate once for each element of the array, in ascending\n     * order, until it finds one where predicate returns true. If such an element is found, find\n     * immediately returns that element value. Otherwise, find returns undefined.\n     * @param thisArg If provided, it will be used as the this value for each invocation of\n     * predicate. If it is not provided, undefined is used instead.\n     */\n    find(predicate: (value: bigint, index: number, array: BigUint64Array) => boolean, thisArg?: any): bigint | undefined;\n\n    /**\n     * Returns the index of the first element in the array where predicate is true, and -1\n     * otherwise.\n     * @param predicate find calls predicate once for each element of the array, in ascending\n     * order, until it finds one where predicate returns true. If such an element is found,\n     * findIndex immediately returns that element index. Otherwise, findIndex returns -1.\n     * @param thisArg If provided, it will be used as the this value for each invocation of\n     * predicate. If it is not provided, undefined is used instead.\n     */\n    findIndex(predicate: (value: bigint, index: number, array: BigUint64Array) => boolean, thisArg?: any): number;\n\n    /**\n     * Performs the specified action for each element in an array.\n     * @param callbackfn A function that accepts up to three arguments. forEach calls the\n     * callbackfn function one time for each element in the array.\n     * @param thisArg An object to which the this keyword can refer in the callbackfn function.\n     * If thisArg is omitted, undefined is used as the this value.\n     */\n    forEach(callbackfn: (value: bigint, index: number, array: BigUint64Array) => void, thisArg?: any): void;\n\n    /**\n     * Determines whether an array includes a certain element, returning true or false as appropriate.\n     * @param searchElement The element to search for.\n     * @param fromIndex The position in this array at which to begin searching for searchElement.\n     */\n    includes(searchElement: bigint, fromIndex?: number): boolean;\n\n    /**\n     * Returns the index of the first occurrence of a value in an array.\n     * @param searchElement The value to locate in the array.\n     * @param fromIndex The array index at which to begin the search. If fromIndex is omitted, the\n     * search starts at index 0.\n     */\n    indexOf(searchElement: bigint, fromIndex?: number): number;\n\n    /**\n     * Adds all the elements of an array separated by the specified separator string.\n     * @param separator A string used to separate one element of an array from the next in the\n     * resulting String. If omitted, the array elements are separated with a comma.\n     */\n    join(separator?: string): string;\n\n    /** Yields each index in the array. */\n    keys(): IterableIterator<number>;\n\n    /**\n     * Returns the index of the last occurrence of a value in an array.\n     * @param searchElement The value to locate in the array.\n     * @param fromIndex The array index at which to begin the search. If fromIndex is omitted, the\n     * search starts at index 0.\n     */\n    lastIndexOf(searchElement: bigint, fromIndex?: number): number;\n\n    /** The length of the array. */\n    readonly length: number;\n\n    /**\n     * Calls a defined callback function on each element of an array, and returns an array that\n     * contains the results.\n     * @param callbackfn A function that accepts up to three arguments. The map method calls the\n     * callbackfn function one time for each element in the array.\n     * @param thisArg An object to which the this keyword can refer in the callbackfn function.\n     * If thisArg is omitted, undefined is used as the this value.\n     */\n    map(callbackfn: (value: bigint, index: number, array: BigUint64Array) => bigint, thisArg?: any): BigUint64Array;\n\n    /**\n     * Calls the specified callback function for all the elements in an array. The return value of\n     * the callback function is the accumulated result, and is provided as an argument in the next\n     * call to the callback function.\n     * @param callbackfn A function that accepts up to four arguments. The reduce method calls the\n     * callbackfn function one time for each element in the array.\n     * @param initialValue If initialValue is specified, it is used as the initial value to start\n     * the accumulation. The first call to the callbackfn function provides this value as an argument\n     * instead of an array value.\n     */\n    reduce(callbackfn: (previousValue: bigint, currentValue: bigint, currentIndex: number, array: BigUint64Array) => bigint): bigint;\n\n    /**\n     * Calls the specified callback function for all the elements in an array. The return value of\n     * the callback function is the accumulated result, and is provided as an argument in the next\n     * call to the callback function.\n     * @param callbackfn A function that accepts up to four arguments. The reduce method calls the\n     * callbackfn function one time for each element in the array.\n     * @param initialValue If initialValue is specified, it is used as the initial value to start\n     * the accumulation. The first call to the callbackfn function provides this value as an argument\n     * instead of an array value.\n     */\n    reduce<U>(callbackfn: (previousValue: U, currentValue: bigint, currentIndex: number, array: BigUint64Array) => U, initialValue: U): U;\n\n    /**\n     * Calls the specified callback function for all the elements in an array, in descending order.\n     * The return value of the callback function is the accumulated result, and is provided as an\n     * argument in the next call to the callback function.\n     * @param callbackfn A function that accepts up to four arguments. The reduceRight method calls\n     * the callbackfn function one time for each element in the array.\n     * @param initialValue If initialValue is specified, it is used as the initial value to start\n     * the accumulation. The first call to the callbackfn function provides this value as an\n     * argument instead of an array value.\n     */\n    reduceRight(callbackfn: (previousValue: bigint, currentValue: bigint, currentIndex: number, array: BigUint64Array) => bigint): bigint;\n\n    /**\n     * Calls the specified callback function for all the elements in an array, in descending order.\n     * The return value of the callback function is the accumulated result, and is provided as an\n     * argument in the next call to the callback function.\n     * @param callbackfn A function that accepts up to four arguments. The reduceRight method calls\n     * the callbackfn function one time for each element in the array.\n     * @param initialValue If initialValue is specified, it is used as the initial value to start\n     * the accumulation. The first call to the callbackfn function provides this value as an argument\n     * instead of an array value.\n     */\n    reduceRight<U>(callbackfn: (previousValue: U, currentValue: bigint, currentIndex: number, array: BigUint64Array) => U, initialValue: U): U;\n\n    /** Reverses the elements in the array. */\n    reverse(): this;\n\n    /**\n     * Sets a value or an array of values.\n     * @param array A typed or untyped array of values to set.\n     * @param offset The index in the current array at which the values are to be written.\n     */\n    set(array: ArrayLike<bigint>, offset?: number): void;\n\n    /**\n     * Returns a section of an array.\n     * @param start The beginning of the specified portion of the array.\n     * @param end The end of the specified portion of the array.\n     */\n    slice(start?: number, end?: number): BigUint64Array;\n\n    /**\n     * Determines whether the specified callback function returns true for any element of an array.\n     * @param predicate A function that accepts up to three arguments. The some method calls the\n     * predicate function for each element in the array until the predicate returns true, or until\n     * the end of the array.\n     * @param thisArg An object to which the this keyword can refer in the predicate function.\n     * If thisArg is omitted, undefined is used as the this value.\n     */\n    some(predicate: (value: bigint, index: number, array: BigUint64Array) => boolean, thisArg?: any): boolean;\n\n    /**\n     * Sorts the array.\n     * @param compareFn The function used to determine the order of the elements. If omitted, the elements are sorted in ascending order.\n     */\n    sort(compareFn?: (a: bigint, b: bigint) => number | bigint): this;\n\n    /**\n     * Gets a new BigUint64Array view of the ArrayBuffer store for this array, referencing the elements\n     * at begin, inclusive, up to end, exclusive.\n     * @param begin The index of the beginning of the array.\n     * @param end The index of the end of the array.\n     */\n    subarray(begin?: number, end?: number): BigUint64Array;\n\n    /** Converts the array to a string by using the current locale. */\n    toLocaleString(): string;\n\n    /** Returns a string representation of the array. */\n    toString(): string;\n\n    /** Returns the primitive value of the specified object. */\n    valueOf(): BigUint64Array;\n\n    /** Yields each value in the array. */\n    values(): IterableIterator<bigint>;\n\n    [Symbol.iterator](): IterableIterator<bigint>;\n\n    readonly [Symbol.toStringTag]: "BigUint64Array";\n\n    [index: number]: bigint;\n}\n\ninterface BigUint64ArrayConstructor {\n    readonly prototype: BigUint64Array;\n    new(length?: number): BigUint64Array;\n    new(array: Iterable<bigint>): BigUint64Array;\n    new(buffer: ArrayBufferLike, byteOffset?: number, length?: number): BigUint64Array;\n\n    /** The size in bytes of each element in the array. */\n    readonly BYTES_PER_ELEMENT: number;\n\n    /**\n     * Returns a new array from a set of elements.\n     * @param items A set of elements to include in the new array object.\n     */\n    of(...items: bigint[]): BigUint64Array;\n\n    /**\n     * Creates an array from an array-like or iterable object.\n     * @param arrayLike An array-like or iterable object to convert to an array.\n     * @param mapfn A mapping function to call on every element of the array.\n     * @param thisArg Value of \'this\' used to invoke the mapfn.\n     */\n    from(arrayLike: ArrayLike<bigint>): BigUint64Array;\n    from<U>(arrayLike: ArrayLike<U>, mapfn: (v: U, k: number) => bigint, thisArg?: any): BigUint64Array;\n}\n\ndeclare var BigUint64Array: BigUint64ArrayConstructor;\n\ninterface DataView {\n    /**\n     * Gets the BigInt64 value at the specified byte offset from the start of the view. There is\n     * no alignment constraint; multi-byte values may be fetched from any offset.\n     * @param byteOffset The place in the buffer at which the value should be retrieved.\n     */\n    getBigInt64(byteOffset: number, littleEndian?: boolean): bigint;\n\n    /**\n     * Gets the BigUint64 value at the specified byte offset from the start of the view. There is\n     * no alignment constraint; multi-byte values may be fetched from any offset.\n     * @param byteOffset The place in the buffer at which the value should be retrieved.\n     */\n    getBigUint64(byteOffset: number, littleEndian?: boolean): bigint;\n\n    /**\n     * Stores a BigInt64 value at the specified byte offset from the start of the view.\n     * @param byteOffset The place in the buffer at which the value should be set.\n     * @param value The value to set.\n     * @param littleEndian If false or undefined, a big-endian value should be written,\n     * otherwise a little-endian value should be written.\n     */\n    setBigInt64(byteOffset: number, value: bigint, littleEndian?: boolean): void;\n\n    /**\n     * Stores a BigUint64 value at the specified byte offset from the start of the view.\n     * @param byteOffset The place in the buffer at which the value should be set.\n     * @param value The value to set.\n     * @param littleEndian If false or undefined, a big-endian value should be written,\n     * otherwise a little-endian value should be written.\n     */\n    setBigUint64(byteOffset: number, value: bigint, littleEndian?: boolean): void;\n}\n\ndeclare namespace Intl{\n    interface NumberFormat {\n        format(value: number | bigint): string;\n        resolvedOptions(): ResolvedNumberFormatOptions;\n    }\n}\n',"lib.es2020.d.ts":'/*! *****************************************************************************\nCopyright (c) Microsoft Corporation. All rights reserved.\nLicensed under the Apache License, Version 2.0 (the "License"); you may not use\nthis file except in compliance with the License. You may obtain a copy of the\nLicense at http://www.apache.org/licenses/LICENSE-2.0\n\nTHIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\nKIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED\nWARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,\nMERCHANTABLITY OR NON-INFRINGEMENT.\n\nSee the Apache Version 2.0 License for specific language governing permissions\nand limitations under the License.\n***************************************************************************** */\n\n\n\n/// <reference no-default-lib="true"/>\n\n\n/// <reference lib="es2019" />\n/// <reference lib="es2020.bigint" />\n/// <reference lib="es2020.promise" />\n/// <reference lib="es2020.sharedmemory" />\n/// <reference lib="es2020.string" />\n/// <reference lib="es2020.symbol.wellknown" />\n/// <reference lib="es2020.intl" />\n',"lib.es2020.full.d.ts":'/*! *****************************************************************************\nCopyright (c) Microsoft Corporation. All rights reserved.\nLicensed under the Apache License, Version 2.0 (the "License"); you may not use\nthis file except in compliance with the License. You may obtain a copy of the\nLicense at http://www.apache.org/licenses/LICENSE-2.0\n\nTHIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\nKIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED\nWARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,\nMERCHANTABLITY OR NON-INFRINGEMENT.\n\nSee the Apache Version 2.0 License for specific language governing permissions\nand limitations under the License.\n***************************************************************************** */\n\n\n\n/// <reference no-default-lib="true"/>\n\n\n/// <reference lib="es2020" />\n/// <reference lib="dom" />\n/// <reference lib="webworker.importscripts" />\n/// <reference lib="scripthost" />\n/// <reference lib="dom.iterable" />\n',"lib.es2020.intl.d.ts":'/*! *****************************************************************************\nCopyright (c) Microsoft Corporation. All rights reserved.\nLicensed under the Apache License, Version 2.0 (the "License"); you may not use\nthis file except in compliance with the License. You may obtain a copy of the\nLicense at http://www.apache.org/licenses/LICENSE-2.0\n\nTHIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\nKIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED\nWARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,\nMERCHANTABLITY OR NON-INFRINGEMENT.\n\nSee the Apache Version 2.0 License for specific language governing permissions\nand limitations under the License.\n***************************************************************************** */\n\n\n\n/// <reference no-default-lib="true"/>\n\n\ndeclare namespace Intl {\n\n    /**\n     * [Unicode BCP 47 Locale Identifiers](https://unicode.org/reports/tr35/#Unicode_Language_and_Locale_Identifiers) definition.\n     *\n     * [MDN](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Intl#locales_argument).\n     *\n     */\n    type UnicodeBCP47LocaleIdentifier = string;\n\n    /**\n     * Unit to use in the relative time internationalized message.\n     *\n     * [MDN](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Intl/RelativeTimeFormat/format#Parameters).\n     *\n     * [Specification](https://tc39.es/ecma402/#sec-singularrelativetimeunit).\n     */\n    type RelativeTimeFormatUnit =\n        | "year" | "years"\n        | "quarter" | "quarters"\n        | "month" | "months"\n        | "week" | "weeks"\n        | "day" | "days"\n        | "hour" | "hours"\n        | "minute" | "minutes"\n        | "second" | "seconds"\n        ;\n\n    /**\n     * The locale matching algorithm to use.\n     *\n     * [MDN](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Intl#Locale_negotiation).\n     *\n     * [Specification](https://tc39.es/ecma402/#sec-InitializeRelativeTimeFormat).\n     */\n    type RelativeTimeFormatLocaleMatcher = "lookup" | "best fit";\n\n    /**\n     * The format of output message.\n     *\n     * [MDN](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Intl/RelativeTimeFormat/RelativeTimeFormat#Parameters).\n     *\n     * [Specification](https://tc39.es/ecma402/#sec-InitializeRelativeTimeFormat).\n     */\n    type RelativeTimeFormatNumeric = "always" | "auto";\n\n    /**\n     * The length of the internationalized message.\n     *\n     * [MDN](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Intl/RelativeTimeFormat/RelativeTimeFormat#Parameters).\n     *\n     * [Specification](https://tc39.es/ecma402/#sec-InitializeRelativeTimeFormat).\n     */\n    type RelativeTimeFormatStyle = "long" | "short" | "narrow";\n\n    /**\n     * An object with some or all of properties of `options` parameter\n     * of `Intl.RelativeTimeFormat` constructor.\n     *\n     * [MDN](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Intl/RelativeTimeFormat/RelativeTimeFormat#Parameters).\n     *\n     * [Specification](https://tc39.es/ecma402/#sec-InitializeRelativeTimeFormat).\n     */\n    interface RelativeTimeFormatOptions {\n        localeMatcher?: RelativeTimeFormatLocaleMatcher;\n        numeric?: RelativeTimeFormatNumeric;\n        style?: RelativeTimeFormatStyle;\n    }\n\n    /**\n     * An object with properties reflecting the locale\n     * and formatting options computed during initialization\n     * of the `Intel.RelativeTimeFormat` object\n     *\n     * [MDN](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Intl/RelativeTimeFormat/resolvedOptions#Description).\n     *\n     * [Specification](https://tc39.es/ecma402/#table-relativetimeformat-resolvedoptions-properties)\n     */\n    interface ResolvedRelativeTimeFormatOptions {\n        locale: UnicodeBCP47LocaleIdentifier;\n        style: RelativeTimeFormatStyle;\n        numeric: RelativeTimeFormatNumeric;\n        numberingSystem: string;\n    }\n\n    /**\n     * An object representing the relative time format in parts\n     * that can be used for custom locale-aware formatting.\n     *\n     * [MDN](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Intl/RelativeTimeFormat/formatToParts#Using_formatToParts).\n     *\n     * [Specification](https://tc39.es/ecma402/#sec-FormatRelativeTimeToParts).\n     */\n    interface RelativeTimeFormatPart {\n        type: string;\n        value: string;\n        unit?: RelativeTimeFormatUnit;\n    }\n\n    interface RelativeTimeFormat {\n        /**\n         * Formats a value and a unit according to the locale\n         * and formatting options of the given\n         * [`Intl.RelativeTimeFormat`](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/RelativeTimeFormat)\n         * object.\n         *\n         * While this method automatically provides the correct plural forms,\n         * the grammatical form is otherwise as neutral as possible.\n         * It is the caller\'s responsibility to handle cut-off logic\n         * such as deciding between displaying "in 7 days" or "in 1 week".\n         * This API does not support relative dates involving compound units.\n         * e.g "in 5 days and 4 hours".\n         *\n         * @param value -  Numeric value to use in the internationalized relative time message\n         *\n         * @param unit - [Unit](https://tc39.es/ecma402/#sec-singularrelativetimeunit)\n         *  to use in the relative time internationalized message.\n         *  Possible values are: `"year"`, `"quarter"`, `"month"`, `"week"`,\n         *  `"day"`, `"hour"`, `"minute"`, `"second"`.\n         *  Plural forms are also permitted.\n         *\n         * @throws `RangeError` if `unit` was given something other than `unit` possible values\n         *\n         * @returns Internationalized relative time message as string\n         *\n         * [MDN](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Intl/RelativeTimeFormat/format).\n         *\n         * [Specification](https://tc39.es/ecma402/#sec-Intl.RelativeTimeFormat.prototype.format).\n         */\n        format(\n            value: number,\n            unit: RelativeTimeFormatUnit,\n        ): string;\n\n        /**\n         *  A version of the format method which it returns an array of objects\n         *  which represent "parts" of the object,\n         *  separating the formatted number into its constituent parts\n         *  and separating it from other surrounding text.\n         *  These objects have two properties:\n         * `type` a NumberFormat formatToParts type, and `value`,\n         *  which is the String which is the component of the output.\n         *  If a "part" came from NumberFormat,\n         *  it will have a unit property which indicates the `unit` being formatted;\n         *  literals which are part of the larger frame will not have this property.\n         *\n         *  @param value - Numeric value to use in the internationalized relative time message\n         *\n         *  @param unit - [Unit](https://tc39.es/ecma402/#sec-singularrelativetimeunit)\n         *   to use in the relative time internationalized message.\n         *   Possible values are: `"year"`, `"quarter"`, `"month"`, `"week"`,\n         *   `"day"`, `"hour"`, `"minute"`, `"second"`.\n         *   Plural forms are also permitted.\n         *\n         *  @throws `RangeError` if `unit` was given something other than `unit` possible values\n         *\n         *  @returns Array of [FormatRelativeTimeToParts](https://tc39.es/ecma402/#sec-FormatRelativeTimeToParts)\n         *\n         *  [MDN](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Intl/RelativeTimeFormat/formatToParts).\n         *\n         *  [Specification](https://tc39.es/ecma402/#sec-Intl.RelativeTimeFormat.prototype.formatToParts).\n         */\n        formatToParts(\n            value: number,\n            unit: RelativeTimeFormatUnit,\n        ): RelativeTimeFormatPart[];\n\n        /**\n         * Provides access to the locale and options computed during initialization of this `Intl.RelativeTimeFormat` object.\n         *\n         * @returns A new object with properties reflecting the locale\n         *  and formatting options computed during initialization\n         *  of the `Intel.RelativeTimeFormat` object.\n         *\n         * [MDN](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Intl/RelativeTimeFormat/resolvedOptions).\n         *\n         * [Specification](https://tc39.es/ecma402/#sec-intl.relativetimeformat.prototype.resolvedoptions)\n         */\n        resolvedOptions(): ResolvedRelativeTimeFormatOptions;\n    }\n\n    /**\n     * The [`Intl.RelativeTimeFormat`](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/RelativeTimeFormat)\n     * object is a constructor for objects that enable language-sensitive relative time formatting.\n     *\n     * Part of [Intl object](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Intl)\n     * namespace and the [ECMAScript Internationalization API](https://www.ecma-international.org/publications/standards/Ecma-402.htm).\n     *\n     * [Compatibility](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Intl/RelativeTimeFormat#Browser_compatibility).\n     *\n     * [Polyfills](https://github.com/tc39/proposal-intl-relative-time#polyfills).\n     */\n    const RelativeTimeFormat: {\n        /**\n         * Constructor creates [Intl.RelativeTimeFormat](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/RelativeTimeFormat)\n         * objects\n         *\n         * @param locales - A string with a [BCP 47 language tag](http://tools.ietf.org/html/rfc5646), or an array of such strings.\n         *  For the general form and interpretation of the locales argument,\n         *  see the [`Intl` page](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Intl#Locale_identification_and_negotiation).\n         *\n         * @param options - An [object](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Intl/RelativeTimeFormat/RelativeTimeFormat#Parameters)\n         *  with some or all of options of the formatting.\n         *  An object with some or all of the following properties:\n         *  - `localeMatcher` - The locale matching algorithm to use.\n         *    Possible values are `"lookup"` and `"best fit"`; the default is `"best fit"`.\n         *    For information about this option, see [Intl page](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Intl#Locale_negotiation).\n         *  - `numeric` - The format of output message.\n         *    Possible values are: `"always"` (default, e.g., `1 day ago`) or `"auto"` (e.g., `yesterday`).\n         *    The `"auto"` value allows to not always have to use numeric values in the output.\n         *  - `style` - The length of the internationalized message. Possible values are:\n         *    `"long"` (default, e.g., in 1 month),\n         *    `"short"` (e.g., in 1 mo.)\n         *    or `"narrow"` (e.g., in 1 mo.). The narrow style could be similar to the short style for some locales.\n         *\n         * @returns [Intl.RelativeTimeFormat](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/RelativeTimeFormat) object.\n         *\n         * [MDN](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Intl/RelativeTimeFormat/RelativeTimeFormat).\n         *\n         * [Specification](https://tc39.es/ecma402/#sec-intl-relativetimeformat-constructor).\n         */\n        new(\n            locales?: UnicodeBCP47LocaleIdentifier | UnicodeBCP47LocaleIdentifier[],\n            options?: RelativeTimeFormatOptions,\n        ): RelativeTimeFormat;\n\n        /**\n         * Returns an array containing those of the provided locales\n         * that are supported in date and time formatting\n         * without having to fall back to the runtime\'s default locale.\n         *\n         * @param locales - A string with a [BCP 47 language tag](http://tools.ietf.org/html/rfc5646), or an array of such strings.\n         *  For the general form and interpretation of the locales argument,\n         *  see the [`Intl` page](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Intl#Locale_identification_and_negotiation).\n         *\n         * @param options - An [object](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Intl/RelativeTimeFormat/RelativeTimeFormat#Parameters)\n         *  with some or all of options of the formatting.\n         *  An object with some or all of the following properties:\n         *  - `localeMatcher` - The locale matching algorithm to use.\n         *    Possible values are `"lookup"` and `"best fit"`; the default is `"best fit"`.\n         *    For information about this option, see [Intl page](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Intl#Locale_negotiation).\n         *  - `numeric` - The format of output message.\n         *    Possible values are: `"always"` (default, e.g., `1 day ago`) or `"auto"` (e.g., `yesterday`).\n         *    The `"auto"` value allows to not always have to use numeric values in the output.\n         *  - `style` - The length of the internationalized message. Possible values are:\n         *    `"long"` (default, e.g., in 1 month),\n         *    `"short"` (e.g., in 1 mo.)\n         *    or `"narrow"` (e.g., in 1 mo.). The narrow style could be similar to the short style for some locales.\n         *\n         * @returns An array containing those of the provided locales\n         *  that are supported in date and time formatting\n         *  without having to fall back to the runtime\'s default locale.\n         *\n         * [MDN](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Intl/RelativeTimeFormat/supportedLocalesOf).\n         *\n         * [Specification](https://tc39.es/ecma402/#sec-Intl.RelativeTimeFormat.supportedLocalesOf).\n         */\n        supportedLocalesOf(\n            locales?: UnicodeBCP47LocaleIdentifier | UnicodeBCP47LocaleIdentifier[],\n            options?: RelativeTimeFormatOptions,\n        ): UnicodeBCP47LocaleIdentifier[];\n    };\n\n    interface NumberFormatOptions {\n        compactDisplay?: string;\n        notation?: string;\n        signDisplay?: string;\n        unit?: string;\n        unitDisplay?: string;\n    }\n\n    interface ResolvedNumberFormatOptions {\n        compactDisplay?: string;\n        notation?: string;\n        signDisplay?: string;\n        unit?: string;\n        unitDisplay?: string;\n    }\n\n    interface DateTimeFormatOptions {\n        dateStyle?: "full" | "long" | "medium" | "short";\n        timeStyle?: "full" | "long" | "medium" | "short";\n        calendar?: string;\n        dayPeriod?: "narrow" | "short" | "long";\n        numberingSystem?: string;\n        hourCycle?: "h11" | "h12" | "h23" | "h24";\n        fractionalSecondDigits?: 0 | 1 | 2 | 3;\n    }\n}\n',"lib.es2020.promise.d.ts":'/*! *****************************************************************************\nCopyright (c) Microsoft Corporation. All rights reserved.\nLicensed under the Apache License, Version 2.0 (the "License"); you may not use\nthis file except in compliance with the License. You may obtain a copy of the\nLicense at http://www.apache.org/licenses/LICENSE-2.0\n\nTHIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\nKIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED\nWARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,\nMERCHANTABLITY OR NON-INFRINGEMENT.\n\nSee the Apache Version 2.0 License for specific language governing permissions\nand limitations under the License.\n***************************************************************************** */\n\n\n\n/// <reference no-default-lib="true"/>\n\n\ninterface PromiseFulfilledResult<T> {\n    status: "fulfilled";\n    value: T;\n}\n\ninterface PromiseRejectedResult {\n    status: "rejected";\n    reason: any;\n}\n\ntype PromiseSettledResult<T> = PromiseFulfilledResult<T> | PromiseRejectedResult;\n\ninterface PromiseConstructor {\n    /**\n     * Creates a Promise that is resolved with an array of results when all\n     * of the provided Promises resolve or reject.\n     * @param values An array of Promises.\n     * @returns A new Promise.\n     */\n    allSettled<T extends readonly unknown[] | readonly [unknown]>(values: T):\n        Promise<{ -readonly [P in keyof T]: PromiseSettledResult<T[P] extends PromiseLike<infer U> ? U : T[P]> }>;\n\n    /**\n     * Creates a Promise that is resolved with an array of results when all\n     * of the provided Promises resolve or reject.\n     * @param values An array of Promises.\n     * @returns A new Promise.\n     */\n    allSettled<T>(values: Iterable<T>): Promise<PromiseSettledResult<T extends PromiseLike<infer U> ? U : T>[]>;\n}\n',"lib.es2020.sharedmemory.d.ts":'/*! *****************************************************************************\nCopyright (c) Microsoft Corporation. All rights reserved.\nLicensed under the Apache License, Version 2.0 (the "License"); you may not use\nthis file except in compliance with the License. You may obtain a copy of the\nLicense at http://www.apache.org/licenses/LICENSE-2.0\n\nTHIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\nKIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED\nWARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,\nMERCHANTABLITY OR NON-INFRINGEMENT.\n\nSee the Apache Version 2.0 License for specific language governing permissions\nand limitations under the License.\n***************************************************************************** */\n\n\n\n/// <reference no-default-lib="true"/>\n\n\ninterface Atomics {\n    /**\n     * Adds a value to the value at the given position in the array, returning the original value.\n     * Until this atomic operation completes, any other read or write operation against the array\n     * will block.\n     */\n    add(typedArray: BigInt64Array | BigUint64Array, index: number, value: bigint): bigint;\n\n    /**\n     * Stores the bitwise AND of a value with the value at the given position in the array,\n     * returning the original value. Until this atomic operation completes, any other read or\n     * write operation against the array will block.\n     */\n    and(typedArray: BigInt64Array | BigUint64Array, index: number, value: bigint): bigint;\n\n    /**\n     * Replaces the value at the given position in the array if the original value equals the given\n     * expected value, returning the original value. Until this atomic operation completes, any\n     * other read or write operation against the array will block.\n     */\n    compareExchange(typedArray: BigInt64Array | BigUint64Array, index: number, expectedValue: bigint, replacementValue: bigint): bigint;\n\n    /**\n     * Replaces the value at the given position in the array, returning the original value. Until\n     * this atomic operation completes, any other read or write operation against the array will\n     * block.\n     */\n    exchange(typedArray: BigInt64Array | BigUint64Array, index: number, value: bigint): bigint;\n\n    /**\n     * Returns the value at the given position in the array. Until this atomic operation completes,\n     * any other read or write operation against the array will block.\n     */\n    load(typedArray: BigInt64Array | BigUint64Array, index: number): bigint;\n\n    /**\n     * Stores the bitwise OR of a value with the value at the given position in the array,\n     * returning the original value. Until this atomic operation completes, any other read or write\n     * operation against the array will block.\n     */\n    or(typedArray: BigInt64Array | BigUint64Array, index: number, value: bigint): bigint;\n\n    /**\n     * Stores a value at the given position in the array, returning the new value. Until this\n     * atomic operation completes, any other read or write operation against the array will block.\n     */\n    store(typedArray: BigInt64Array | BigUint64Array, index: number, value: bigint): bigint;\n\n    /**\n     * Subtracts a value from the value at the given position in the array, returning the original\n     * value. Until this atomic operation completes, any other read or write operation against the\n     * array will block.\n     */\n    sub(typedArray: BigInt64Array | BigUint64Array, index: number, value: bigint): bigint;\n\n    /**\n     * If the value at the given position in the array is equal to the provided value, the current\n     * agent is put to sleep causing execution to suspend until the timeout expires (returning\n     * `"timed-out"`) or until the agent is awoken (returning `"ok"`); otherwise, returns\n     * `"not-equal"`.\n     */\n    wait(typedArray: BigInt64Array, index: number, value: bigint, timeout?: number): "ok" | "not-equal" | "timed-out";\n\n    /**\n     * Wakes up sleeping agents that are waiting on the given index of the array, returning the\n     * number of agents that were awoken.\n     * @param typedArray A shared BigInt64Array.\n     * @param index The position in the typedArray to wake up on.\n     * @param count The number of sleeping agents to notify. Defaults to +Infinity.\n     */\n    notify(typedArray: BigInt64Array, index: number, count?: number): number;\n\n    /**\n     * Stores the bitwise XOR of a value with the value at the given position in the array,\n     * returning the original value. Until this atomic operation completes, any other read or write\n     * operation against the array will block.\n     */\n    xor(typedArray: BigInt64Array | BigUint64Array, index: number, value: bigint): bigint;\n}\n',"lib.es2020.string.d.ts":'/*! *****************************************************************************\nCopyright (c) Microsoft Corporation. All rights reserved.\nLicensed under the Apache License, Version 2.0 (the "License"); you may not use\nthis file except in compliance with the License. You may obtain a copy of the\nLicense at http://www.apache.org/licenses/LICENSE-2.0\n\nTHIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\nKIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED\nWARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,\nMERCHANTABLITY OR NON-INFRINGEMENT.\n\nSee the Apache Version 2.0 License for specific language governing permissions\nand limitations under the License.\n***************************************************************************** */\n\n\n\n/// <reference no-default-lib="true"/>\n\n\n/// <reference lib="es2015.iterable" />\n\ninterface String {\n    /**\n     * Matches a string with a regular expression, and returns an iterable of matches\n     * containing the results of that search.\n     * @param regexp A variable name or string literal containing the regular expression pattern and flags.\n     */\n    matchAll(regexp: RegExp): IterableIterator<RegExpMatchArray>;\n}\n',"lib.es2020.symbol.wellknown.d.ts":'/*! *****************************************************************************\nCopyright (c) Microsoft Corporation. All rights reserved.\nLicensed under the Apache License, Version 2.0 (the "License"); you may not use\nthis file except in compliance with the License. You may obtain a copy of the\nLicense at http://www.apache.org/licenses/LICENSE-2.0\n\nTHIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\nKIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED\nWARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,\nMERCHANTABLITY OR NON-INFRINGEMENT.\n\nSee the Apache Version 2.0 License for specific language governing permissions\nand limitations under the License.\n***************************************************************************** */\n\n\n\n/// <reference no-default-lib="true"/>\n\n\n/// <reference lib="es2015.iterable" />\n/// <reference lib="es2015.symbol" />\n\ninterface SymbolConstructor {\n    /**\n     * A regular expression method that matches the regular expression against a string. Called\n     * by the String.prototype.matchAll method.\n     */\n    readonly matchAll: unique symbol;\n}\n\ninterface RegExp {\n    /**\n     * Matches a string with this regular expression, and returns an iterable of matches\n     * containing the results of that search.\n     * @param string A string to search within.\n     */\n    [Symbol.matchAll](str: string): IterableIterator<RegExpMatchArray>;\n}\n',"lib.es2021.d.ts":'/*! *****************************************************************************\nCopyright (c) Microsoft Corporation. All rights reserved.\nLicensed under the Apache License, Version 2.0 (the "License"); you may not use\nthis file except in compliance with the License. You may obtain a copy of the\nLicense at http://www.apache.org/licenses/LICENSE-2.0\n\nTHIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\nKIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED\nWARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,\nMERCHANTABLITY OR NON-INFRINGEMENT.\n\nSee the Apache Version 2.0 License for specific language governing permissions\nand limitations under the License.\n***************************************************************************** */\n\n\n\n/// <reference no-default-lib="true"/>\n\n\n/// <reference lib="es2020" />\n/// <reference lib="es2021.promise" />\n/// <reference lib="es2021.string" />\n/// <reference lib="es2021.weakref" />\n',"lib.es2021.full.d.ts":'/*! *****************************************************************************\nCopyright (c) Microsoft Corporation. All rights reserved.\nLicensed under the Apache License, Version 2.0 (the "License"); you may not use\nthis file except in compliance with the License. You may obtain a copy of the\nLicense at http://www.apache.org/licenses/LICENSE-2.0\n\nTHIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\nKIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED\nWARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,\nMERCHANTABLITY OR NON-INFRINGEMENT.\n\nSee the Apache Version 2.0 License for specific language governing permissions\nand limitations under the License.\n***************************************************************************** */\n\n\n\n/// <reference no-default-lib="true"/>\n\n\n/// <reference lib="es2021" />\n/// <reference lib="dom" />\n/// <reference lib="webworker.importscripts" />\n/// <reference lib="scripthost" />\n/// <reference lib="dom.iterable" />\n',"lib.es2021.promise.d.ts":'/*! *****************************************************************************\nCopyright (c) Microsoft Corporation. All rights reserved.\nLicensed under the Apache License, Version 2.0 (the "License"); you may not use\nthis file except in compliance with the License. You may obtain a copy of the\nLicense at http://www.apache.org/licenses/LICENSE-2.0\n\nTHIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\nKIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED\nWARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,\nMERCHANTABLITY OR NON-INFRINGEMENT.\n\nSee the Apache Version 2.0 License for specific language governing permissions\nand limitations under the License.\n***************************************************************************** */\n\n\n\n/// <reference no-default-lib="true"/>\n\n\ninterface AggregateError extends Error {\n    errors: any[]\n}\n\ninterface AggregateErrorConstructor {\n    new(errors: Iterable<any>, message?: string): AggregateError;\n    (errors: Iterable<any>, message?: string): AggregateError;\n    readonly prototype: AggregateError;\n}\n\ndeclare var AggregateError: AggregateErrorConstructor;\n\n/**\n * Represents the completion of an asynchronous operation\n */\ninterface PromiseConstructor {\n    /**\n     * The any function returns a promise that is fulfilled by the first given promise to be fulfilled, or rejected with an AggregateError containing an array of rejection reasons if all of the given promises are rejected. It resolves all elements of the passed iterable to promises as it runs this algorithm.\n     * @param values An array or iterable of Promises.\n     * @returns A new Promise.\n     */\n    any<T>(values: (T | PromiseLike<T>)[] | Iterable<T | PromiseLike<T>>): Promise<T>\n}\n',"lib.es2021.string.d.ts":'/*! *****************************************************************************\nCopyright (c) Microsoft Corporation. All rights reserved.\nLicensed under the Apache License, Version 2.0 (the "License"); you may not use\nthis file except in compliance with the License. You may obtain a copy of the\nLicense at http://www.apache.org/licenses/LICENSE-2.0\n\nTHIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\nKIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED\nWARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,\nMERCHANTABLITY OR NON-INFRINGEMENT.\n\nSee the Apache Version 2.0 License for specific language governing permissions\nand limitations under the License.\n***************************************************************************** */\n\n\n\n/// <reference no-default-lib="true"/>\n\n\ninterface String {\n    /**\n     * Replace all instances of a substring in a string, using a regular expression or search string.\n     * @param searchValue A string to search for.\n     * @param replaceValue A string containing the text to replace for every successful match of searchValue in this string.\n     */\n    replaceAll(searchValue: string | RegExp, replaceValue: string): string;\n\n    /**\n     * Replace all instances of a substring in a string, using a regular expression or search string.\n     * @param searchValue A string to search for.\n     * @param replacer A function that returns the replacement text.\n     */\n    replaceAll(searchValue: string | RegExp, replacer: (substring: string, ...args: any[]) => string): string;\n}\n',"lib.es2021.weakref.d.ts":'/*! *****************************************************************************\nCopyright (c) Microsoft Corporation. All rights reserved.\nLicensed under the Apache License, Version 2.0 (the "License"); you may not use\nthis file except in compliance with the License. You may obtain a copy of the\nLicense at http://www.apache.org/licenses/LICENSE-2.0\n\nTHIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\nKIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED\nWARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,\nMERCHANTABLITY OR NON-INFRINGEMENT.\n\nSee the Apache Version 2.0 License for specific language governing permissions\nand limitations under the License.\n***************************************************************************** */\n\n\n\n/// <reference no-default-lib="true"/>\n\n\ninterface WeakRef<T extends object> {\n    readonly [Symbol.toStringTag]: "WeakRef";\n\n    /**\n     * Returns the WeakRef instance\'s target object, or undefined if the target object has been\n     * reclaimed.\n     */\n    deref(): T | undefined;\n}\n\ninterface WeakRefConstructor {\n    readonly prototype: WeakRef<any>;\n\n    /**\n     * Creates a WeakRef instance for the given target object.\n     * @param target The target object for the WeakRef instance.\n     */\n    new<T extends object>(target: T): WeakRef<T>;\n}\n\ndeclare var WeakRef: WeakRefConstructor;\n\ninterface FinalizationRegistry<T> {\n    readonly [Symbol.toStringTag]: "FinalizationRegistry";\n\n    /**\n     * Registers an object with the registry.\n     * @param target The target object to register.\n     * @param heldValue The value to pass to the finalizer for this object. This cannot be the\n     * target object.\n     * @param unregisterToken The token to pass to the unregister method to unregister the target\n     * object. If provided (and not undefined), this must be an object. If not provided, the target\n     * cannot be unregistered.\n     */\n    register(target: object, heldValue: T, unregisterToken?: object): void;\n\n    /**\n     * Unregisters an object from the registry.\n     * @param unregisterToken The token that was used as the unregisterToken argument when calling\n     * register to register the target object.\n     */\n    unregister(unregisterToken: object): void;\n}\n\ninterface FinalizationRegistryConstructor {\n    readonly prototype: FinalizationRegistry<any>;\n\n    /**\n     * Creates a finalization registry with an associated cleanup callback\n     * @param cleanupCallback The callback to call after an object in the registry has been reclaimed.\n     */\n    new<T>(cleanupCallback: (heldValue: T) => void): FinalizationRegistry<T>;\n}\n\ndeclare var FinalizationRegistry: FinalizationRegistryConstructor;\n',"lib.es5.d.ts":"/*! *****************************************************************************\nCopyright (c) Microsoft Corporation. All rights reserved.\nLicensed under the Apache License, Version 2.0 (the \"License\"); you may not use\nthis file except in compliance with the License. You may obtain a copy of the\nLicense at http://www.apache.org/licenses/LICENSE-2.0\n\nTHIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\nKIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED\nWARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,\nMERCHANTABLITY OR NON-INFRINGEMENT.\n\nSee the Apache Version 2.0 License for specific language governing permissions\nand limitations under the License.\n***************************************************************************** */\n\n\n\n/// <reference no-default-lib=\"true\"/>\n\n\n/////////////////////////////\n/// ECMAScript APIs\n/////////////////////////////\n\ndeclare var NaN: number;\ndeclare var Infinity: number;\n\n/**\n * Evaluates JavaScript code and executes it.\n * @param x A String value that contains valid JavaScript code.\n */\ndeclare function eval(x: string): any;\n\n/**\n * Converts a string to an integer.\n * @param string A string to convert into a number.\n * @param radix A value between 2 and 36 that specifies the base of the number in `string`.\n * If this argument is not supplied, strings with a prefix of '0x' are considered hexadecimal.\n * All other strings are considered decimal.\n */\ndeclare function parseInt(string: string, radix?: number): number;\n\n/**\n * Converts a string to a floating-point number.\n * @param string A string that contains a floating-point number.\n */\ndeclare function parseFloat(string: string): number;\n\n/**\n * Returns a Boolean value that indicates whether a value is the reserved value NaN (not a number).\n * @param number A numeric value.\n */\ndeclare function isNaN(number: number): boolean;\n\n/**\n * Determines whether a supplied number is finite.\n * @param number Any numeric value.\n */\ndeclare function isFinite(number: number): boolean;\n\n/**\n * Gets the unencoded version of an encoded Uniform Resource Identifier (URI).\n * @param encodedURI A value representing an encoded URI.\n */\ndeclare function decodeURI(encodedURI: string): string;\n\n/**\n * Gets the unencoded version of an encoded component of a Uniform Resource Identifier (URI).\n * @param encodedURIComponent A value representing an encoded URI component.\n */\ndeclare function decodeURIComponent(encodedURIComponent: string): string;\n\n/**\n * Encodes a text string as a valid Uniform Resource Identifier (URI)\n * @param uri A value representing an encoded URI.\n */\ndeclare function encodeURI(uri: string): string;\n\n/**\n * Encodes a text string as a valid component of a Uniform Resource Identifier (URI).\n * @param uriComponent A value representing an encoded URI component.\n */\ndeclare function encodeURIComponent(uriComponent: string | number | boolean): string;\n\n/**\n * Computes a new string in which certain characters have been replaced by a hexadecimal escape sequence.\n * @param string A string value\n */\ndeclare function escape(string: string): string;\n\n/**\n * Computes a new string in which hexadecimal escape sequences are replaced with the character that it represents.\n * @param string A string value\n */\ndeclare function unescape(string: string): string;\n\ninterface Symbol {\n    /** Returns a string representation of an object. */\n    toString(): string;\n\n    /** Returns the primitive value of the specified object. */\n    valueOf(): symbol;\n}\n\ndeclare type PropertyKey = string | number | symbol;\n\ninterface PropertyDescriptor {\n    configurable?: boolean;\n    enumerable?: boolean;\n    value?: any;\n    writable?: boolean;\n    get?(): any;\n    set?(v: any): void;\n}\n\ninterface PropertyDescriptorMap {\n    [s: string]: PropertyDescriptor;\n}\n\ninterface Object {\n    /** The initial value of Object.prototype.constructor is the standard built-in Object constructor. */\n    constructor: Function;\n\n    /** Returns a string representation of an object. */\n    toString(): string;\n\n    /** Returns a date converted to a string using the current locale. */\n    toLocaleString(): string;\n\n    /** Returns the primitive value of the specified object. */\n    valueOf(): Object;\n\n    /**\n     * Determines whether an object has a property with the specified name.\n     * @param v A property name.\n     */\n    hasOwnProperty(v: PropertyKey): boolean;\n\n    /**\n     * Determines whether an object exists in another object's prototype chain.\n     * @param v Another object whose prototype chain is to be checked.\n     */\n    isPrototypeOf(v: Object): boolean;\n\n    /**\n     * Determines whether a specified property is enumerable.\n     * @param v A property name.\n     */\n    propertyIsEnumerable(v: PropertyKey): boolean;\n}\n\ninterface ObjectConstructor {\n    new(value?: any): Object;\n    (): any;\n    (value: any): any;\n\n    /** A reference to the prototype for a class of objects. */\n    readonly prototype: Object;\n\n    /**\n     * Returns the prototype of an object.\n     * @param o The object that references the prototype.\n     */\n    getPrototypeOf(o: any): any;\n\n    /**\n     * Gets the own property descriptor of the specified object.\n     * An own property descriptor is one that is defined directly on the object and is not inherited from the object's prototype.\n     * @param o Object that contains the property.\n     * @param p Name of the property.\n     */\n    getOwnPropertyDescriptor(o: any, p: PropertyKey): PropertyDescriptor | undefined;\n\n    /**\n     * Returns the names of the own properties of an object. The own properties of an object are those that are defined directly\n     * on that object, and are not inherited from the object's prototype. The properties of an object include both fields (objects) and functions.\n     * @param o Object that contains the own properties.\n     */\n    getOwnPropertyNames(o: any): string[];\n\n    /**\n     * Creates an object that has the specified prototype or that has null prototype.\n     * @param o Object to use as a prototype. May be null.\n     */\n    create(o: object | null): any;\n\n    /**\n     * Creates an object that has the specified prototype, and that optionally contains specified properties.\n     * @param o Object to use as a prototype. May be null\n     * @param properties JavaScript object that contains one or more property descriptors.\n     */\n    create(o: object | null, properties: PropertyDescriptorMap & ThisType<any>): any;\n\n    /**\n     * Adds a property to an object, or modifies attributes of an existing property.\n     * @param o Object on which to add or modify the property. This can be a native JavaScript object (that is, a user-defined object or a built in object) or a DOM object.\n     * @param p The property name.\n     * @param attributes Descriptor for the property. It can be for a data property or an accessor property.\n     */\n    defineProperty<T>(o: T, p: PropertyKey, attributes: PropertyDescriptor & ThisType<any>): T;\n\n    /**\n     * Adds one or more properties to an object, and/or modifies attributes of existing properties.\n     * @param o Object on which to add or modify the properties. This can be a native JavaScript object or a DOM object.\n     * @param properties JavaScript object that contains one or more descriptor objects. Each descriptor object describes a data property or an accessor property.\n     */\n    defineProperties<T>(o: T, properties: PropertyDescriptorMap & ThisType<any>): T;\n\n    /**\n     * Prevents the modification of attributes of existing properties, and prevents the addition of new properties.\n     * @param o Object on which to lock the attributes.\n     */\n    seal<T>(o: T): T;\n\n    /**\n     * Prevents the modification of existing property attributes and values, and prevents the addition of new properties.\n     * @param o Object on which to lock the attributes.\n     */\n    freeze<T>(a: T[]): readonly T[];\n\n    /**\n     * Prevents the modification of existing property attributes and values, and prevents the addition of new properties.\n     * @param o Object on which to lock the attributes.\n     */\n    freeze<T extends Function>(f: T): T;\n\n    /**\n     * Prevents the modification of existing property attributes and values, and prevents the addition of new properties.\n     * @param o Object on which to lock the attributes.\n     */\n    freeze<T>(o: T): Readonly<T>;\n\n    /**\n     * Prevents the addition of new properties to an object.\n     * @param o Object to make non-extensible.\n     */\n    preventExtensions<T>(o: T): T;\n\n    /**\n     * Returns true if existing property attributes cannot be modified in an object and new properties cannot be added to the object.\n     * @param o Object to test.\n     */\n    isSealed(o: any): boolean;\n\n    /**\n     * Returns true if existing property attributes and values cannot be modified in an object, and new properties cannot be added to the object.\n     * @param o Object to test.\n     */\n    isFrozen(o: any): boolean;\n\n    /**\n     * Returns a value that indicates whether new properties can be added to an object.\n     * @param o Object to test.\n     */\n    isExtensible(o: any): boolean;\n\n    /**\n     * Returns the names of the enumerable string properties and methods of an object.\n     * @param o Object that contains the properties and methods. This can be an object that you created or an existing Document Object Model (DOM) object.\n     */\n    keys(o: object): string[];\n}\n\n/**\n * Provides functionality common to all JavaScript objects.\n */\ndeclare var Object: ObjectConstructor;\n\n/**\n * Creates a new function.\n */\ninterface Function {\n    /**\n     * Calls the function, substituting the specified object for the this value of the function, and the specified array for the arguments of the function.\n     * @param thisArg The object to be used as the this object.\n     * @param argArray A set of arguments to be passed to the function.\n     */\n    apply(this: Function, thisArg: any, argArray?: any): any;\n\n    /**\n     * Calls a method of an object, substituting another object for the current object.\n     * @param thisArg The object to be used as the current object.\n     * @param argArray A list of arguments to be passed to the method.\n     */\n    call(this: Function, thisArg: any, ...argArray: any[]): any;\n\n    /**\n     * For a given function, creates a bound function that has the same body as the original function.\n     * The this object of the bound function is associated with the specified object, and has the specified initial parameters.\n     * @param thisArg An object to which the this keyword can refer inside the new function.\n     * @param argArray A list of arguments to be passed to the new function.\n     */\n    bind(this: Function, thisArg: any, ...argArray: any[]): any;\n\n    /** Returns a string representation of a function. */\n    toString(): string;\n\n    prototype: any;\n    readonly length: number;\n\n    // Non-standard extensions\n    arguments: any;\n    caller: Function;\n}\n\ninterface FunctionConstructor {\n    /**\n     * Creates a new function.\n     * @param args A list of arguments the function accepts.\n     */\n    new(...args: string[]): Function;\n    (...args: string[]): Function;\n    readonly prototype: Function;\n}\n\ndeclare var Function: FunctionConstructor;\n\n/**\n * Extracts the type of the 'this' parameter of a function type, or 'unknown' if the function type has no 'this' parameter.\n */\ntype ThisParameterType<T> = T extends (this: infer U, ...args: any[]) => any ? U : unknown;\n\n/**\n * Removes the 'this' parameter from a function type.\n */\ntype OmitThisParameter<T> = unknown extends ThisParameterType<T> ? T : T extends (...args: infer A) => infer R ? (...args: A) => R : T;\n\ninterface CallableFunction extends Function {\n    /**\n     * Calls the function with the specified object as the this value and the elements of specified array as the arguments.\n     * @param thisArg The object to be used as the this object.\n     * @param args An array of argument values to be passed to the function.\n     */\n    apply<T, R>(this: (this: T) => R, thisArg: T): R;\n    apply<T, A extends any[], R>(this: (this: T, ...args: A) => R, thisArg: T, args: A): R;\n\n    /**\n     * Calls the function with the specified object as the this value and the specified rest arguments as the arguments.\n     * @param thisArg The object to be used as the this object.\n     * @param args Argument values to be passed to the function.\n     */\n    call<T, A extends any[], R>(this: (this: T, ...args: A) => R, thisArg: T, ...args: A): R;\n\n    /**\n     * For a given function, creates a bound function that has the same body as the original function.\n     * The this object of the bound function is associated with the specified object, and has the specified initial parameters.\n     * @param thisArg The object to be used as the this object.\n     * @param args Arguments to bind to the parameters of the function.\n     */\n    bind<T>(this: T, thisArg: ThisParameterType<T>): OmitThisParameter<T>;\n    bind<T, A0, A extends any[], R>(this: (this: T, arg0: A0, ...args: A) => R, thisArg: T, arg0: A0): (...args: A) => R;\n    bind<T, A0, A1, A extends any[], R>(this: (this: T, arg0: A0, arg1: A1, ...args: A) => R, thisArg: T, arg0: A0, arg1: A1): (...args: A) => R;\n    bind<T, A0, A1, A2, A extends any[], R>(this: (this: T, arg0: A0, arg1: A1, arg2: A2, ...args: A) => R, thisArg: T, arg0: A0, arg1: A1, arg2: A2): (...args: A) => R;\n    bind<T, A0, A1, A2, A3, A extends any[], R>(this: (this: T, arg0: A0, arg1: A1, arg2: A2, arg3: A3, ...args: A) => R, thisArg: T, arg0: A0, arg1: A1, arg2: A2, arg3: A3): (...args: A) => R;\n    bind<T, AX, R>(this: (this: T, ...args: AX[]) => R, thisArg: T, ...args: AX[]): (...args: AX[]) => R;\n}\n\ninterface NewableFunction extends Function {\n    /**\n     * Calls the function with the specified object as the this value and the elements of specified array as the arguments.\n     * @param thisArg The object to be used as the this object.\n     * @param args An array of argument values to be passed to the function.\n     */\n    apply<T>(this: new () => T, thisArg: T): void;\n    apply<T, A extends any[]>(this: new (...args: A) => T, thisArg: T, args: A): void;\n\n    /**\n     * Calls the function with the specified object as the this value and the specified rest arguments as the arguments.\n     * @param thisArg The object to be used as the this object.\n     * @param args Argument values to be passed to the function.\n     */\n    call<T, A extends any[]>(this: new (...args: A) => T, thisArg: T, ...args: A): void;\n\n    /**\n     * For a given function, creates a bound function that has the same body as the original function.\n     * The this object of the bound function is associated with the specified object, and has the specified initial parameters.\n     * @param thisArg The object to be used as the this object.\n     * @param args Arguments to bind to the parameters of the function.\n     */\n    bind<T>(this: T, thisArg: any): T;\n    bind<A0, A extends any[], R>(this: new (arg0: A0, ...args: A) => R, thisArg: any, arg0: A0): new (...args: A) => R;\n    bind<A0, A1, A extends any[], R>(this: new (arg0: A0, arg1: A1, ...args: A) => R, thisArg: any, arg0: A0, arg1: A1): new (...args: A) => R;\n    bind<A0, A1, A2, A extends any[], R>(this: new (arg0: A0, arg1: A1, arg2: A2, ...args: A) => R, thisArg: any, arg0: A0, arg1: A1, arg2: A2): new (...args: A) => R;\n    bind<A0, A1, A2, A3, A extends any[], R>(this: new (arg0: A0, arg1: A1, arg2: A2, arg3: A3, ...args: A) => R, thisArg: any, arg0: A0, arg1: A1, arg2: A2, arg3: A3): new (...args: A) => R;\n    bind<AX, R>(this: new (...args: AX[]) => R, thisArg: any, ...args: AX[]): new (...args: AX[]) => R;\n}\n\ninterface IArguments {\n    [index: number]: any;\n    length: number;\n    callee: Function;\n}\n\ninterface String {\n    /** Returns a string representation of a string. */\n    toString(): string;\n\n    /**\n     * Returns the character at the specified index.\n     * @param pos The zero-based index of the desired character.\n     */\n    charAt(pos: number): string;\n\n    /**\n     * Returns the Unicode value of the character at the specified location.\n     * @param index The zero-based index of the desired character. If there is no character at the specified index, NaN is returned.\n     */\n    charCodeAt(index: number): number;\n\n    /**\n     * Returns a string that contains the concatenation of two or more strings.\n     * @param strings The strings to append to the end of the string.\n     */\n    concat(...strings: string[]): string;\n\n    /**\n     * Returns the position of the first occurrence of a substring.\n     * @param searchString The substring to search for in the string\n     * @param position The index at which to begin searching the String object. If omitted, search starts at the beginning of the string.\n     */\n    indexOf(searchString: string, position?: number): number;\n\n    /**\n     * Returns the last occurrence of a substring in the string.\n     * @param searchString The substring to search for.\n     * @param position The index at which to begin searching. If omitted, the search begins at the end of the string.\n     */\n    lastIndexOf(searchString: string, position?: number): number;\n\n    /**\n     * Determines whether two strings are equivalent in the current locale.\n     * @param that String to compare to target string\n     */\n    localeCompare(that: string): number;\n\n    /**\n     * Matches a string with a regular expression, and returns an array containing the results of that search.\n     * @param regexp A variable name or string literal containing the regular expression pattern and flags.\n     */\n    match(regexp: string | RegExp): RegExpMatchArray | null;\n\n    /**\n     * Replaces text in a string, using a regular expression or search string.\n     * @param searchValue A string to search for.\n     * @param replaceValue A string containing the text to replace for every successful match of searchValue in this string.\n     */\n    replace(searchValue: string | RegExp, replaceValue: string): string;\n\n    /**\n     * Replaces text in a string, using a regular expression or search string.\n     * @param searchValue A string to search for.\n     * @param replacer A function that returns the replacement text.\n     */\n    replace(searchValue: string | RegExp, replacer: (substring: string, ...args: any[]) => string): string;\n\n    /**\n     * Finds the first substring match in a regular expression search.\n     * @param regexp The regular expression pattern and applicable flags.\n     */\n    search(regexp: string | RegExp): number;\n\n    /**\n     * Returns a section of a string.\n     * @param start The index to the beginning of the specified portion of stringObj.\n     * @param end The index to the end of the specified portion of stringObj. The substring includes the characters up to, but not including, the character indicated by end.\n     * If this value is not specified, the substring continues to the end of stringObj.\n     */\n    slice(start?: number, end?: number): string;\n\n    /**\n     * Split a string into substrings using the specified separator and return them as an array.\n     * @param separator A string that identifies character or characters to use in separating the string. If omitted, a single-element array containing the entire string is returned.\n     * @param limit A value used to limit the number of elements returned in the array.\n     */\n    split(separator: string | RegExp, limit?: number): string[];\n\n    /**\n     * Returns the substring at the specified location within a String object.\n     * @param start The zero-based index number indicating the beginning of the substring.\n     * @param end Zero-based index number indicating the end of the substring. The substring includes the characters up to, but not including, the character indicated by end.\n     * If end is omitted, the characters from start through the end of the original string are returned.\n     */\n    substring(start: number, end?: number): string;\n\n    /** Converts all the alphabetic characters in a string to lowercase. */\n    toLowerCase(): string;\n\n    /** Converts all alphabetic characters to lowercase, taking into account the host environment's current locale. */\n    toLocaleLowerCase(locales?: string | string[]): string;\n\n    /** Converts all the alphabetic characters in a string to uppercase. */\n    toUpperCase(): string;\n\n    /** Returns a string where all alphabetic characters have been converted to uppercase, taking into account the host environment's current locale. */\n    toLocaleUpperCase(locales?: string | string[]): string;\n\n    /** Removes the leading and trailing white space and line terminator characters from a string. */\n    trim(): string;\n\n    /** Returns the length of a String object. */\n    readonly length: number;\n\n    // IE extensions\n    /**\n     * Gets a substring beginning at the specified location and having the specified length.\n     * @param from The starting position of the desired substring. The index of the first character in the string is zero.\n     * @param length The number of characters to include in the returned substring.\n     */\n    substr(from: number, length?: number): string;\n\n    /** Returns the primitive value of the specified object. */\n    valueOf(): string;\n\n    readonly [index: number]: string;\n}\n\ninterface StringConstructor {\n    new(value?: any): String;\n    (value?: any): string;\n    readonly prototype: String;\n    fromCharCode(...codes: number[]): string;\n}\n\n/**\n * Allows manipulation and formatting of text strings and determination and location of substrings within strings.\n */\ndeclare var String: StringConstructor;\n\ninterface Boolean {\n    /** Returns the primitive value of the specified object. */\n    valueOf(): boolean;\n}\n\ninterface BooleanConstructor {\n    new(value?: any): Boolean;\n    <T>(value?: T): boolean;\n    readonly prototype: Boolean;\n}\n\ndeclare var Boolean: BooleanConstructor;\n\ninterface Number {\n    /**\n     * Returns a string representation of an object.\n     * @param radix Specifies a radix for converting numeric values to strings. This value is only used for numbers.\n     */\n    toString(radix?: number): string;\n\n    /**\n     * Returns a string representing a number in fixed-point notation.\n     * @param fractionDigits Number of digits after the decimal point. Must be in the range 0 - 20, inclusive.\n     */\n    toFixed(fractionDigits?: number): string;\n\n    /**\n     * Returns a string containing a number represented in exponential notation.\n     * @param fractionDigits Number of digits after the decimal point. Must be in the range 0 - 20, inclusive.\n     */\n    toExponential(fractionDigits?: number): string;\n\n    /**\n     * Returns a string containing a number represented either in exponential or fixed-point notation with a specified number of digits.\n     * @param precision Number of significant digits. Must be in the range 1 - 21, inclusive.\n     */\n    toPrecision(precision?: number): string;\n\n    /** Returns the primitive value of the specified object. */\n    valueOf(): number;\n}\n\ninterface NumberConstructor {\n    new(value?: any): Number;\n    (value?: any): number;\n    readonly prototype: Number;\n\n    /** The largest number that can be represented in JavaScript. Equal to approximately 1.79E+308. */\n    readonly MAX_VALUE: number;\n\n    /** The closest number to zero that can be represented in JavaScript. Equal to approximately 5.00E-324. */\n    readonly MIN_VALUE: number;\n\n    /**\n     * A value that is not a number.\n     * In equality comparisons, NaN does not equal any value, including itself. To test whether a value is equivalent to NaN, use the isNaN function.\n     */\n    readonly NaN: number;\n\n    /**\n     * A value that is less than the largest negative number that can be represented in JavaScript.\n     * JavaScript displays NEGATIVE_INFINITY values as -infinity.\n     */\n    readonly NEGATIVE_INFINITY: number;\n\n    /**\n     * A value greater than the largest number that can be represented in JavaScript.\n     * JavaScript displays POSITIVE_INFINITY values as infinity.\n     */\n    readonly POSITIVE_INFINITY: number;\n}\n\n/** An object that represents a number of any kind. All JavaScript numbers are 64-bit floating-point numbers. */\ndeclare var Number: NumberConstructor;\n\ninterface TemplateStringsArray extends ReadonlyArray<string> {\n    readonly raw: readonly string[];\n}\n\n/**\n * The type of `import.meta`.\n *\n * If you need to declare that a given property exists on `import.meta`,\n * this type may be augmented via interface merging.\n */\ninterface ImportMeta {\n}\n\ninterface Math {\n    /** The mathematical constant e. This is Euler's number, the base of natural logarithms. */\n    readonly E: number;\n    /** The natural logarithm of 10. */\n    readonly LN10: number;\n    /** The natural logarithm of 2. */\n    readonly LN2: number;\n    /** The base-2 logarithm of e. */\n    readonly LOG2E: number;\n    /** The base-10 logarithm of e. */\n    readonly LOG10E: number;\n    /** Pi. This is the ratio of the circumference of a circle to its diameter. */\n    readonly PI: number;\n    /** The square root of 0.5, or, equivalently, one divided by the square root of 2. */\n    readonly SQRT1_2: number;\n    /** The square root of 2. */\n    readonly SQRT2: number;\n    /**\n     * Returns the absolute value of a number (the value without regard to whether it is positive or negative).\n     * For example, the absolute value of -5 is the same as the absolute value of 5.\n     * @param x A numeric expression for which the absolute value is needed.\n     */\n    abs(x: number): number;\n    /**\n     * Returns the arc cosine (or inverse cosine) of a number.\n     * @param x A numeric expression.\n     */\n    acos(x: number): number;\n    /**\n     * Returns the arcsine of a number.\n     * @param x A numeric expression.\n     */\n    asin(x: number): number;\n    /**\n     * Returns the arctangent of a number.\n     * @param x A numeric expression for which the arctangent is needed.\n     */\n    atan(x: number): number;\n    /**\n     * Returns the angle (in radians) from the X axis to a point.\n     * @param y A numeric expression representing the cartesian y-coordinate.\n     * @param x A numeric expression representing the cartesian x-coordinate.\n     */\n    atan2(y: number, x: number): number;\n    /**\n     * Returns the smallest integer greater than or equal to its numeric argument.\n     * @param x A numeric expression.\n     */\n    ceil(x: number): number;\n    /**\n     * Returns the cosine of a number.\n     * @param x A numeric expression that contains an angle measured in radians.\n     */\n    cos(x: number): number;\n    /**\n     * Returns e (the base of natural logarithms) raised to a power.\n     * @param x A numeric expression representing the power of e.\n     */\n    exp(x: number): number;\n    /**\n     * Returns the greatest integer less than or equal to its numeric argument.\n     * @param x A numeric expression.\n     */\n    floor(x: number): number;\n    /**\n     * Returns the natural logarithm (base e) of a number.\n     * @param x A numeric expression.\n     */\n    log(x: number): number;\n    /**\n     * Returns the larger of a set of supplied numeric expressions.\n     * @param values Numeric expressions to be evaluated.\n     */\n    max(...values: number[]): number;\n    /**\n     * Returns the smaller of a set of supplied numeric expressions.\n     * @param values Numeric expressions to be evaluated.\n     */\n    min(...values: number[]): number;\n    /**\n     * Returns the value of a base expression taken to a specified power.\n     * @param x The base value of the expression.\n     * @param y The exponent value of the expression.\n     */\n    pow(x: number, y: number): number;\n    /** Returns a pseudorandom number between 0 and 1. */\n    random(): number;\n    /**\n     * Returns a supplied numeric expression rounded to the nearest integer.\n     * @param x The value to be rounded to the nearest integer.\n     */\n    round(x: number): number;\n    /**\n     * Returns the sine of a number.\n     * @param x A numeric expression that contains an angle measured in radians.\n     */\n    sin(x: number): number;\n    /**\n     * Returns the square root of a number.\n     * @param x A numeric expression.\n     */\n    sqrt(x: number): number;\n    /**\n     * Returns the tangent of a number.\n     * @param x A numeric expression that contains an angle measured in radians.\n     */\n    tan(x: number): number;\n}\n/** An intrinsic object that provides basic mathematics functionality and constants. */\ndeclare var Math: Math;\n\n/** Enables basic storage and retrieval of dates and times. */\ninterface Date {\n    /** Returns a string representation of a date. The format of the string depends on the locale. */\n    toString(): string;\n    /** Returns a date as a string value. */\n    toDateString(): string;\n    /** Returns a time as a string value. */\n    toTimeString(): string;\n    /** Returns a value as a string value appropriate to the host environment's current locale. */\n    toLocaleString(): string;\n    /** Returns a date as a string value appropriate to the host environment's current locale. */\n    toLocaleDateString(): string;\n    /** Returns a time as a string value appropriate to the host environment's current locale. */\n    toLocaleTimeString(): string;\n    /** Returns the stored time value in milliseconds since midnight, January 1, 1970 UTC. */\n    valueOf(): number;\n    /** Gets the time value in milliseconds. */\n    getTime(): number;\n    /** Gets the year, using local time. */\n    getFullYear(): number;\n    /** Gets the year using Universal Coordinated Time (UTC). */\n    getUTCFullYear(): number;\n    /** Gets the month, using local time. */\n    getMonth(): number;\n    /** Gets the month of a Date object using Universal Coordinated Time (UTC). */\n    getUTCMonth(): number;\n    /** Gets the day-of-the-month, using local time. */\n    getDate(): number;\n    /** Gets the day-of-the-month, using Universal Coordinated Time (UTC). */\n    getUTCDate(): number;\n    /** Gets the day of the week, using local time. */\n    getDay(): number;\n    /** Gets the day of the week using Universal Coordinated Time (UTC). */\n    getUTCDay(): number;\n    /** Gets the hours in a date, using local time. */\n    getHours(): number;\n    /** Gets the hours value in a Date object using Universal Coordinated Time (UTC). */\n    getUTCHours(): number;\n    /** Gets the minutes of a Date object, using local time. */\n    getMinutes(): number;\n    /** Gets the minutes of a Date object using Universal Coordinated Time (UTC). */\n    getUTCMinutes(): number;\n    /** Gets the seconds of a Date object, using local time. */\n    getSeconds(): number;\n    /** Gets the seconds of a Date object using Universal Coordinated Time (UTC). */\n    getUTCSeconds(): number;\n    /** Gets the milliseconds of a Date, using local time. */\n    getMilliseconds(): number;\n    /** Gets the milliseconds of a Date object using Universal Coordinated Time (UTC). */\n    getUTCMilliseconds(): number;\n    /** Gets the difference in minutes between the time on the local computer and Universal Coordinated Time (UTC). */\n    getTimezoneOffset(): number;\n    /**\n     * Sets the date and time value in the Date object.\n     * @param time A numeric value representing the number of elapsed milliseconds since midnight, January 1, 1970 GMT.\n     */\n    setTime(time: number): number;\n    /**\n     * Sets the milliseconds value in the Date object using local time.\n     * @param ms A numeric value equal to the millisecond value.\n     */\n    setMilliseconds(ms: number): number;\n    /**\n     * Sets the milliseconds value in the Date object using Universal Coordinated Time (UTC).\n     * @param ms A numeric value equal to the millisecond value.\n     */\n    setUTCMilliseconds(ms: number): number;\n\n    /**\n     * Sets the seconds value in the Date object using local time.\n     * @param sec A numeric value equal to the seconds value.\n     * @param ms A numeric value equal to the milliseconds value.\n     */\n    setSeconds(sec: number, ms?: number): number;\n    /**\n     * Sets the seconds value in the Date object using Universal Coordinated Time (UTC).\n     * @param sec A numeric value equal to the seconds value.\n     * @param ms A numeric value equal to the milliseconds value.\n     */\n    setUTCSeconds(sec: number, ms?: number): number;\n    /**\n     * Sets the minutes value in the Date object using local time.\n     * @param min A numeric value equal to the minutes value.\n     * @param sec A numeric value equal to the seconds value.\n     * @param ms A numeric value equal to the milliseconds value.\n     */\n    setMinutes(min: number, sec?: number, ms?: number): number;\n    /**\n     * Sets the minutes value in the Date object using Universal Coordinated Time (UTC).\n     * @param min A numeric value equal to the minutes value.\n     * @param sec A numeric value equal to the seconds value.\n     * @param ms A numeric value equal to the milliseconds value.\n     */\n    setUTCMinutes(min: number, sec?: number, ms?: number): number;\n    /**\n     * Sets the hour value in the Date object using local time.\n     * @param hours A numeric value equal to the hours value.\n     * @param min A numeric value equal to the minutes value.\n     * @param sec A numeric value equal to the seconds value.\n     * @param ms A numeric value equal to the milliseconds value.\n     */\n    setHours(hours: number, min?: number, sec?: number, ms?: number): number;\n    /**\n     * Sets the hours value in the Date object using Universal Coordinated Time (UTC).\n     * @param hours A numeric value equal to the hours value.\n     * @param min A numeric value equal to the minutes value.\n     * @param sec A numeric value equal to the seconds value.\n     * @param ms A numeric value equal to the milliseconds value.\n     */\n    setUTCHours(hours: number, min?: number, sec?: number, ms?: number): number;\n    /**\n     * Sets the numeric day-of-the-month value of the Date object using local time.\n     * @param date A numeric value equal to the day of the month.\n     */\n    setDate(date: number): number;\n    /**\n     * Sets the numeric day of the month in the Date object using Universal Coordinated Time (UTC).\n     * @param date A numeric value equal to the day of the month.\n     */\n    setUTCDate(date: number): number;\n    /**\n     * Sets the month value in the Date object using local time.\n     * @param month A numeric value equal to the month. The value for January is 0, and other month values follow consecutively.\n     * @param date A numeric value representing the day of the month. If this value is not supplied, the value from a call to the getDate method is used.\n     */\n    setMonth(month: number, date?: number): number;\n    /**\n     * Sets the month value in the Date object using Universal Coordinated Time (UTC).\n     * @param month A numeric value equal to the month. The value for January is 0, and other month values follow consecutively.\n     * @param date A numeric value representing the day of the month. If it is not supplied, the value from a call to the getUTCDate method is used.\n     */\n    setUTCMonth(month: number, date?: number): number;\n    /**\n     * Sets the year of the Date object using local time.\n     * @param year A numeric value for the year.\n     * @param month A zero-based numeric value for the month (0 for January, 11 for December). Must be specified if numDate is specified.\n     * @param date A numeric value equal for the day of the month.\n     */\n    setFullYear(year: number, month?: number, date?: number): number;\n    /**\n     * Sets the year value in the Date object using Universal Coordinated Time (UTC).\n     * @param year A numeric value equal to the year.\n     * @param month A numeric value equal to the month. The value for January is 0, and other month values follow consecutively. Must be supplied if numDate is supplied.\n     * @param date A numeric value equal to the day of the month.\n     */\n    setUTCFullYear(year: number, month?: number, date?: number): number;\n    /** Returns a date converted to a string using Universal Coordinated Time (UTC). */\n    toUTCString(): string;\n    /** Returns a date as a string value in ISO format. */\n    toISOString(): string;\n    /** Used by the JSON.stringify method to enable the transformation of an object's data for JavaScript Object Notation (JSON) serialization. */\n    toJSON(key?: any): string;\n}\n\ninterface DateConstructor {\n    new(): Date;\n    new(value: number | string): Date;\n    new(year: number, month: number, date?: number, hours?: number, minutes?: number, seconds?: number, ms?: number): Date;\n    (): string;\n    readonly prototype: Date;\n    /**\n     * Parses a string containing a date, and returns the number of milliseconds between that date and midnight, January 1, 1970.\n     * @param s A date string\n     */\n    parse(s: string): number;\n    /**\n     * Returns the number of milliseconds between midnight, January 1, 1970 Universal Coordinated Time (UTC) (or GMT) and the specified date.\n     * @param year The full year designation is required for cross-century date accuracy. If year is between 0 and 99 is used, then year is assumed to be 1900 + year.\n     * @param month The month as a number between 0 and 11 (January to December).\n     * @param date The date as a number between 1 and 31.\n     * @param hours Must be supplied if minutes is supplied. A number from 0 to 23 (midnight to 11pm) that specifies the hour.\n     * @param minutes Must be supplied if seconds is supplied. A number from 0 to 59 that specifies the minutes.\n     * @param seconds Must be supplied if milliseconds is supplied. A number from 0 to 59 that specifies the seconds.\n     * @param ms A number from 0 to 999 that specifies the milliseconds.\n     */\n    UTC(year: number, month: number, date?: number, hours?: number, minutes?: number, seconds?: number, ms?: number): number;\n    now(): number;\n}\n\ndeclare var Date: DateConstructor;\n\ninterface RegExpMatchArray extends Array<string> {\n    index?: number;\n    input?: string;\n}\n\ninterface RegExpExecArray extends Array<string> {\n    index: number;\n    input: string;\n}\n\ninterface RegExp {\n    /**\n     * Executes a search on a string using a regular expression pattern, and returns an array containing the results of that search.\n     * @param string The String object or string literal on which to perform the search.\n     */\n    exec(string: string): RegExpExecArray | null;\n\n    /**\n     * Returns a Boolean value that indicates whether or not a pattern exists in a searched string.\n     * @param string String on which to perform the search.\n     */\n    test(string: string): boolean;\n\n    /** Returns a copy of the text of the regular expression pattern. Read-only. The regExp argument is a Regular expression object. It can be a variable name or a literal. */\n    readonly source: string;\n\n    /** Returns a Boolean value indicating the state of the global flag (g) used with a regular expression. Default is false. Read-only. */\n    readonly global: boolean;\n\n    /** Returns a Boolean value indicating the state of the ignoreCase flag (i) used with a regular expression. Default is false. Read-only. */\n    readonly ignoreCase: boolean;\n\n    /** Returns a Boolean value indicating the state of the multiline flag (m) used with a regular expression. Default is false. Read-only. */\n    readonly multiline: boolean;\n\n    lastIndex: number;\n\n    // Non-standard extensions\n    compile(): this;\n}\n\ninterface RegExpConstructor {\n    new(pattern: RegExp | string): RegExp;\n    new(pattern: string, flags?: string): RegExp;\n    (pattern: RegExp | string): RegExp;\n    (pattern: string, flags?: string): RegExp;\n    readonly prototype: RegExp;\n\n    // Non-standard extensions\n    $1: string;\n    $2: string;\n    $3: string;\n    $4: string;\n    $5: string;\n    $6: string;\n    $7: string;\n    $8: string;\n    $9: string;\n    lastMatch: string;\n}\n\ndeclare var RegExp: RegExpConstructor;\n\ninterface Error {\n    name: string;\n    message: string;\n    stack?: string;\n}\n\ninterface ErrorConstructor {\n    new(message?: string): Error;\n    (message?: string): Error;\n    readonly prototype: Error;\n}\n\ndeclare var Error: ErrorConstructor;\n\ninterface EvalError extends Error {\n}\n\ninterface EvalErrorConstructor extends ErrorConstructor {\n    new(message?: string): EvalError;\n    (message?: string): EvalError;\n    readonly prototype: EvalError;\n}\n\ndeclare var EvalError: EvalErrorConstructor;\n\ninterface RangeError extends Error {\n}\n\ninterface RangeErrorConstructor extends ErrorConstructor {\n    new(message?: string): RangeError;\n    (message?: string): RangeError;\n    readonly prototype: RangeError;\n}\n\ndeclare var RangeError: RangeErrorConstructor;\n\ninterface ReferenceError extends Error {\n}\n\ninterface ReferenceErrorConstructor extends ErrorConstructor {\n    new(message?: string): ReferenceError;\n    (message?: string): ReferenceError;\n    readonly prototype: ReferenceError;\n}\n\ndeclare var ReferenceError: ReferenceErrorConstructor;\n\ninterface SyntaxError extends Error {\n}\n\ninterface SyntaxErrorConstructor extends ErrorConstructor {\n    new(message?: string): SyntaxError;\n    (message?: string): SyntaxError;\n    readonly prototype: SyntaxError;\n}\n\ndeclare var SyntaxError: SyntaxErrorConstructor;\n\ninterface TypeError extends Error {\n}\n\ninterface TypeErrorConstructor extends ErrorConstructor {\n    new(message?: string): TypeError;\n    (message?: string): TypeError;\n    readonly prototype: TypeError;\n}\n\ndeclare var TypeError: TypeErrorConstructor;\n\ninterface URIError extends Error {\n}\n\ninterface URIErrorConstructor extends ErrorConstructor {\n    new(message?: string): URIError;\n    (message?: string): URIError;\n    readonly prototype: URIError;\n}\n\ndeclare var URIError: URIErrorConstructor;\n\ninterface JSON {\n    /**\n     * Converts a JavaScript Object Notation (JSON) string into an object.\n     * @param text A valid JSON string.\n     * @param reviver A function that transforms the results. This function is called for each member of the object.\n     * If a member contains nested objects, the nested objects are transformed before the parent object is.\n     */\n    parse(text: string, reviver?: (this: any, key: string, value: any) => any): any;\n    /**\n     * Converts a JavaScript value to a JavaScript Object Notation (JSON) string.\n     * @param value A JavaScript value, usually an object or array, to be converted.\n     * @param replacer A function that transforms the results.\n     * @param space Adds indentation, white space, and line break characters to the return-value JSON text to make it easier to read.\n     */\n    stringify(value: any, replacer?: (this: any, key: string, value: any) => any, space?: string | number): string;\n    /**\n     * Converts a JavaScript value to a JavaScript Object Notation (JSON) string.\n     * @param value A JavaScript value, usually an object or array, to be converted.\n     * @param replacer An array of strings and numbers that acts as an approved list for selecting the object properties that will be stringified.\n     * @param space Adds indentation, white space, and line break characters to the return-value JSON text to make it easier to read.\n     */\n    stringify(value: any, replacer?: (number | string)[] | null, space?: string | number): string;\n}\n\n/**\n * An intrinsic object that provides functions to convert JavaScript values to and from the JavaScript Object Notation (JSON) format.\n */\ndeclare var JSON: JSON;\n\n\n/////////////////////////////\n/// ECMAScript Array API (specially handled by compiler)\n/////////////////////////////\n\ninterface ReadonlyArray<T> {\n    /**\n     * Gets the length of the array. This is a number one higher than the highest element defined in an array.\n     */\n    readonly length: number;\n    /**\n     * Returns a string representation of an array.\n     */\n    toString(): string;\n    /**\n     * Returns a string representation of an array. The elements are converted to string using their toLocaleString methods.\n     */\n    toLocaleString(): string;\n    /**\n     * Combines two or more arrays.\n     * @param items Additional items to add to the end of array1.\n     */\n    concat(...items: ConcatArray<T>[]): T[];\n    /**\n     * Combines two or more arrays.\n     * @param items Additional items to add to the end of array1.\n     */\n    concat(...items: (T | ConcatArray<T>)[]): T[];\n    /**\n     * Adds all the elements of an array separated by the specified separator string.\n     * @param separator A string used to separate one element of an array from the next in the resulting String. If omitted, the array elements are separated with a comma.\n     */\n    join(separator?: string): string;\n    /**\n     * Returns a section of an array.\n     * @param start The beginning of the specified portion of the array.\n     * @param end The end of the specified portion of the array. This is exclusive of the element at the index 'end'.\n     */\n    slice(start?: number, end?: number): T[];\n    /**\n     * Returns the index of the first occurrence of a value in an array.\n     * @param searchElement The value to locate in the array.\n     * @param fromIndex The array index at which to begin the search. If fromIndex is omitted, the search starts at index 0.\n     */\n    indexOf(searchElement: T, fromIndex?: number): number;\n    /**\n     * Returns the index of the last occurrence of a specified value in an array.\n     * @param searchElement The value to locate in the array.\n     * @param fromIndex The array index at which to begin the search. If fromIndex is omitted, the search starts at the last index in the array.\n     */\n    lastIndexOf(searchElement: T, fromIndex?: number): number;\n    /**\n     * Determines whether all the members of an array satisfy the specified test.\n     * @param predicate A function that accepts up to three arguments. The every method calls\n     * the predicate function for each element in the array until the predicate returns a value\n     * which is coercible to the Boolean value false, or until the end of the array.\n     * @param thisArg An object to which the this keyword can refer in the predicate function.\n     * If thisArg is omitted, undefined is used as the this value.\n     */\n    every<S extends T>(predicate: (value: T, index: number, array: readonly T[]) => value is S, thisArg?: any): this is readonly S[];\n    /**\n     * Determines whether all the members of an array satisfy the specified test.\n     * @param predicate A function that accepts up to three arguments. The every method calls\n     * the predicate function for each element in the array until the predicate returns a value\n     * which is coercible to the Boolean value false, or until the end of the array.\n     * @param thisArg An object to which the this keyword can refer in the predicate function.\n     * If thisArg is omitted, undefined is used as the this value.\n     */\n    every(predicate: (value: T, index: number, array: readonly T[]) => unknown, thisArg?: any): boolean;\n    /**\n     * Determines whether the specified callback function returns true for any element of an array.\n     * @param predicate A function that accepts up to three arguments. The some method calls\n     * the predicate function for each element in the array until the predicate returns a value\n     * which is coercible to the Boolean value true, or until the end of the array.\n     * @param thisArg An object to which the this keyword can refer in the predicate function.\n     * If thisArg is omitted, undefined is used as the this value.\n     */\n    some(predicate: (value: T, index: number, array: readonly T[]) => unknown, thisArg?: any): boolean;\n    /**\n     * Performs the specified action for each element in an array.\n     * @param callbackfn  A function that accepts up to three arguments. forEach calls the callbackfn function one time for each element in the array.\n     * @param thisArg  An object to which the this keyword can refer in the callbackfn function. If thisArg is omitted, undefined is used as the this value.\n     */\n    forEach(callbackfn: (value: T, index: number, array: readonly T[]) => void, thisArg?: any): void;\n    /**\n     * Calls a defined callback function on each element of an array, and returns an array that contains the results.\n     * @param callbackfn A function that accepts up to three arguments. The map method calls the callbackfn function one time for each element in the array.\n     * @param thisArg An object to which the this keyword can refer in the callbackfn function. If thisArg is omitted, undefined is used as the this value.\n     */\n    map<U>(callbackfn: (value: T, index: number, array: readonly T[]) => U, thisArg?: any): U[];\n    /**\n     * Returns the elements of an array that meet the condition specified in a callback function.\n     * @param predicate A function that accepts up to three arguments. The filter method calls the predicate function one time for each element in the array.\n     * @param thisArg An object to which the this keyword can refer in the predicate function. If thisArg is omitted, undefined is used as the this value.\n     */\n    filter<S extends T>(predicate: (value: T, index: number, array: readonly T[]) => value is S, thisArg?: any): S[];\n    /**\n     * Returns the elements of an array that meet the condition specified in a callback function.\n     * @param predicate A function that accepts up to three arguments. The filter method calls the predicate function one time for each element in the array.\n     * @param thisArg An object to which the this keyword can refer in the predicate function. If thisArg is omitted, undefined is used as the this value.\n     */\n    filter(predicate: (value: T, index: number, array: readonly T[]) => unknown, thisArg?: any): T[];\n    /**\n     * Calls the specified callback function for all the elements in an array. The return value of the callback function is the accumulated result, and is provided as an argument in the next call to the callback function.\n     * @param callbackfn A function that accepts up to four arguments. The reduce method calls the callbackfn function one time for each element in the array.\n     * @param initialValue If initialValue is specified, it is used as the initial value to start the accumulation. The first call to the callbackfn function provides this value as an argument instead of an array value.\n     */\n    reduce(callbackfn: (previousValue: T, currentValue: T, currentIndex: number, array: readonly T[]) => T): T;\n    reduce(callbackfn: (previousValue: T, currentValue: T, currentIndex: number, array: readonly T[]) => T, initialValue: T): T;\n    /**\n     * Calls the specified callback function for all the elements in an array. The return value of the callback function is the accumulated result, and is provided as an argument in the next call to the callback function.\n     * @param callbackfn A function that accepts up to four arguments. The reduce method calls the callbackfn function one time for each element in the array.\n     * @param initialValue If initialValue is specified, it is used as the initial value to start the accumulation. The first call to the callbackfn function provides this value as an argument instead of an array value.\n     */\n    reduce<U>(callbackfn: (previousValue: U, currentValue: T, currentIndex: number, array: readonly T[]) => U, initialValue: U): U;\n    /**\n     * Calls the specified callback function for all the elements in an array, in descending order. The return value of the callback function is the accumulated result, and is provided as an argument in the next call to the callback function.\n     * @param callbackfn A function that accepts up to four arguments. The reduceRight method calls the callbackfn function one time for each element in the array.\n     * @param initialValue If initialValue is specified, it is used as the initial value to start the accumulation. The first call to the callbackfn function provides this value as an argument instead of an array value.\n     */\n    reduceRight(callbackfn: (previousValue: T, currentValue: T, currentIndex: number, array: readonly T[]) => T): T;\n    reduceRight(callbackfn: (previousValue: T, currentValue: T, currentIndex: number, array: readonly T[]) => T, initialValue: T): T;\n    /**\n     * Calls the specified callback function for all the elements in an array, in descending order. The return value of the callback function is the accumulated result, and is provided as an argument in the next call to the callback function.\n     * @param callbackfn A function that accepts up to four arguments. The reduceRight method calls the callbackfn function one time for each element in the array.\n     * @param initialValue If initialValue is specified, it is used as the initial value to start the accumulation. The first call to the callbackfn function provides this value as an argument instead of an array value.\n     */\n    reduceRight<U>(callbackfn: (previousValue: U, currentValue: T, currentIndex: number, array: readonly T[]) => U, initialValue: U): U;\n\n    readonly [n: number]: T;\n}\n\ninterface ConcatArray<T> {\n    readonly length: number;\n    readonly [n: number]: T;\n    join(separator?: string): string;\n    slice(start?: number, end?: number): T[];\n}\n\ninterface Array<T> {\n    /**\n     * Gets or sets the length of the array. This is a number one higher than the highest index in the array.\n     */\n    length: number;\n    /**\n     * Returns a string representation of an array.\n     */\n    toString(): string;\n    /**\n     * Returns a string representation of an array. The elements are converted to string using their toLocaleString methods.\n     */\n    toLocaleString(): string;\n    /**\n     * Removes the last element from an array and returns it.\n     * If the array is empty, undefined is returned and the array is not modified.\n     */\n    pop(): T | undefined;\n    /**\n     * Appends new elements to the end of an array, and returns the new length of the array.\n     * @param items New elements to add to the array.\n     */\n    push(...items: T[]): number;\n    /**\n     * Combines two or more arrays.\n     * This method returns a new array without modifying any existing arrays.\n     * @param items Additional arrays and/or items to add to the end of the array.\n     */\n    concat(...items: ConcatArray<T>[]): T[];\n    /**\n     * Combines two or more arrays.\n     * This method returns a new array without modifying any existing arrays.\n     * @param items Additional arrays and/or items to add to the end of the array.\n     */\n    concat(...items: (T | ConcatArray<T>)[]): T[];\n    /**\n     * Adds all the elements of an array into a string, separated by the specified separator string.\n     * @param separator A string used to separate one element of the array from the next in the resulting string. If omitted, the array elements are separated with a comma.\n     */\n    join(separator?: string): string;\n    /**\n     * Reverses the elements in an array in place.\n     * This method mutates the array and returns a reference to the same array.\n     */\n    reverse(): T[];\n    /**\n     * Removes the first element from an array and returns it.\n     * If the array is empty, undefined is returned and the array is not modified.\n     */\n    shift(): T | undefined;\n    /**\n     * Returns a copy of a section of an array.\n     * For both start and end, a negative index can be used to indicate an offset from the end of the array.\n     * For example, -2 refers to the second to last element of the array.\n     * @param start The beginning index of the specified portion of the array.\n     * If start is undefined, then the slice begins at index 0.\n     * @param end The end index of the specified portion of the array. This is exclusive of the element at the index 'end'.\n     * If end is undefined, then the slice extends to the end of the array.\n     */\n    slice(start?: number, end?: number): T[];\n    /**\n     * Sorts an array in place.\n     * This method mutates the array and returns a reference to the same array.\n     * @param compareFn Function used to determine the order of the elements. It is expected to return\n     * a negative value if first argument is less than second argument, zero if they're equal and a positive\n     * value otherwise. If omitted, the elements are sorted in ascending, ASCII character order.\n     * ```ts\n     * [11,2,22,1].sort((a, b) => a - b)\n     * ```\n     */\n    sort(compareFn?: (a: T, b: T) => number): this;\n    /**\n     * Removes elements from an array and, if necessary, inserts new elements in their place, returning the deleted elements.\n     * @param start The zero-based location in the array from which to start removing elements.\n     * @param deleteCount The number of elements to remove.\n     * @returns An array containing the elements that were deleted.\n     */\n    splice(start: number, deleteCount?: number): T[];\n    /**\n     * Removes elements from an array and, if necessary, inserts new elements in their place, returning the deleted elements.\n     * @param start The zero-based location in the array from which to start removing elements.\n     * @param deleteCount The number of elements to remove.\n     * @param items Elements to insert into the array in place of the deleted elements.\n     * @returns An array containing the elements that were deleted.\n     */\n    splice(start: number, deleteCount: number, ...items: T[]): T[];\n    /**\n     * Inserts new elements at the start of an array, and returns the new length of the array.\n     * @param items Elements to insert at the start of the array.\n     */\n    unshift(...items: T[]): number;\n    /**\n     * Returns the index of the first occurrence of a value in an array, or -1 if it is not present.\n     * @param searchElement The value to locate in the array.\n     * @param fromIndex The array index at which to begin the search. If fromIndex is omitted, the search starts at index 0.\n     */\n    indexOf(searchElement: T, fromIndex?: number): number;\n    /**\n     * Returns the index of the last occurrence of a specified value in an array, or -1 if it is not present.\n     * @param searchElement The value to locate in the array.\n     * @param fromIndex The array index at which to begin searching backward. If fromIndex is omitted, the search starts at the last index in the array.\n     */\n    lastIndexOf(searchElement: T, fromIndex?: number): number;\n    /**\n     * Determines whether all the members of an array satisfy the specified test.\n     * @param predicate A function that accepts up to three arguments. The every method calls\n     * the predicate function for each element in the array until the predicate returns a value\n     * which is coercible to the Boolean value false, or until the end of the array.\n     * @param thisArg An object to which the this keyword can refer in the predicate function.\n     * If thisArg is omitted, undefined is used as the this value.\n     */\n    every<S extends T>(predicate: (value: T, index: number, array: T[]) => value is S, thisArg?: any): this is S[];\n    /**\n     * Determines whether all the members of an array satisfy the specified test.\n     * @param predicate A function that accepts up to three arguments. The every method calls\n     * the predicate function for each element in the array until the predicate returns a value\n     * which is coercible to the Boolean value false, or until the end of the array.\n     * @param thisArg An object to which the this keyword can refer in the predicate function.\n     * If thisArg is omitted, undefined is used as the this value.\n     */\n    every(predicate: (value: T, index: number, array: T[]) => unknown, thisArg?: any): boolean;\n    /**\n     * Determines whether the specified callback function returns true for any element of an array.\n     * @param predicate A function that accepts up to three arguments. The some method calls\n     * the predicate function for each element in the array until the predicate returns a value\n     * which is coercible to the Boolean value true, or until the end of the array.\n     * @param thisArg An object to which the this keyword can refer in the predicate function.\n     * If thisArg is omitted, undefined is used as the this value.\n     */\n    some(predicate: (value: T, index: number, array: T[]) => unknown, thisArg?: any): boolean;\n    /**\n     * Performs the specified action for each element in an array.\n     * @param callbackfn  A function that accepts up to three arguments. forEach calls the callbackfn function one time for each element in the array.\n     * @param thisArg  An object to which the this keyword can refer in the callbackfn function. If thisArg is omitted, undefined is used as the this value.\n     */\n    forEach(callbackfn: (value: T, index: number, array: T[]) => void, thisArg?: any): void;\n    /**\n     * Calls a defined callback function on each element of an array, and returns an array that contains the results.\n     * @param callbackfn A function that accepts up to three arguments. The map method calls the callbackfn function one time for each element in the array.\n     * @param thisArg An object to which the this keyword can refer in the callbackfn function. If thisArg is omitted, undefined is used as the this value.\n     */\n    map<U>(callbackfn: (value: T, index: number, array: T[]) => U, thisArg?: any): U[];\n    /**\n     * Returns the elements of an array that meet the condition specified in a callback function.\n     * @param predicate A function that accepts up to three arguments. The filter method calls the predicate function one time for each element in the array.\n     * @param thisArg An object to which the this keyword can refer in the predicate function. If thisArg is omitted, undefined is used as the this value.\n     */\n    filter<S extends T>(predicate: (value: T, index: number, array: T[]) => value is S, thisArg?: any): S[];\n    /**\n     * Returns the elements of an array that meet the condition specified in a callback function.\n     * @param predicate A function that accepts up to three arguments. The filter method calls the predicate function one time for each element in the array.\n     * @param thisArg An object to which the this keyword can refer in the predicate function. If thisArg is omitted, undefined is used as the this value.\n     */\n    filter(predicate: (value: T, index: number, array: T[]) => unknown, thisArg?: any): T[];\n    /**\n     * Calls the specified callback function for all the elements in an array. The return value of the callback function is the accumulated result, and is provided as an argument in the next call to the callback function.\n     * @param callbackfn A function that accepts up to four arguments. The reduce method calls the callbackfn function one time for each element in the array.\n     * @param initialValue If initialValue is specified, it is used as the initial value to start the accumulation. The first call to the callbackfn function provides this value as an argument instead of an array value.\n     */\n    reduce(callbackfn: (previousValue: T, currentValue: T, currentIndex: number, array: T[]) => T): T;\n    reduce(callbackfn: (previousValue: T, currentValue: T, currentIndex: number, array: T[]) => T, initialValue: T): T;\n    /**\n     * Calls the specified callback function for all the elements in an array. The return value of the callback function is the accumulated result, and is provided as an argument in the next call to the callback function.\n     * @param callbackfn A function that accepts up to four arguments. The reduce method calls the callbackfn function one time for each element in the array.\n     * @param initialValue If initialValue is specified, it is used as the initial value to start the accumulation. The first call to the callbackfn function provides this value as an argument instead of an array value.\n     */\n    reduce<U>(callbackfn: (previousValue: U, currentValue: T, currentIndex: number, array: T[]) => U, initialValue: U): U;\n    /**\n     * Calls the specified callback function for all the elements in an array, in descending order. The return value of the callback function is the accumulated result, and is provided as an argument in the next call to the callback function.\n     * @param callbackfn A function that accepts up to four arguments. The reduceRight method calls the callbackfn function one time for each element in the array.\n     * @param initialValue If initialValue is specified, it is used as the initial value to start the accumulation. The first call to the callbackfn function provides this value as an argument instead of an array value.\n     */\n    reduceRight(callbackfn: (previousValue: T, currentValue: T, currentIndex: number, array: T[]) => T): T;\n    reduceRight(callbackfn: (previousValue: T, currentValue: T, currentIndex: number, array: T[]) => T, initialValue: T): T;\n    /**\n     * Calls the specified callback function for all the elements in an array, in descending order. The return value of the callback function is the accumulated result, and is provided as an argument in the next call to the callback function.\n     * @param callbackfn A function that accepts up to four arguments. The reduceRight method calls the callbackfn function one time for each element in the array.\n     * @param initialValue If initialValue is specified, it is used as the initial value to start the accumulation. The first call to the callbackfn function provides this value as an argument instead of an array value.\n     */\n    reduceRight<U>(callbackfn: (previousValue: U, currentValue: T, currentIndex: number, array: T[]) => U, initialValue: U): U;\n\n    [n: number]: T;\n}\n\ninterface ArrayConstructor {\n    new(arrayLength?: number): any[];\n    new <T>(arrayLength: number): T[];\n    new <T>(...items: T[]): T[];\n    (arrayLength?: number): any[];\n    <T>(arrayLength: number): T[];\n    <T>(...items: T[]): T[];\n    isArray(arg: any): arg is any[];\n    readonly prototype: any[];\n}\n\ndeclare var Array: ArrayConstructor;\n\ninterface TypedPropertyDescriptor<T> {\n    enumerable?: boolean;\n    configurable?: boolean;\n    writable?: boolean;\n    value?: T;\n    get?: () => T;\n    set?: (value: T) => void;\n}\n\ndeclare type ClassDecorator = <TFunction extends Function>(target: TFunction) => TFunction | void;\ndeclare type PropertyDecorator = (target: Object, propertyKey: string | symbol) => void;\ndeclare type MethodDecorator = <T>(target: Object, propertyKey: string | symbol, descriptor: TypedPropertyDescriptor<T>) => TypedPropertyDescriptor<T> | void;\ndeclare type ParameterDecorator = (target: Object, propertyKey: string | symbol, parameterIndex: number) => void;\n\ndeclare type PromiseConstructorLike = new <T>(executor: (resolve: (value: T | PromiseLike<T>) => void, reject: (reason?: any) => void) => void) => PromiseLike<T>;\n\ninterface PromiseLike<T> {\n    /**\n     * Attaches callbacks for the resolution and/or rejection of the Promise.\n     * @param onfulfilled The callback to execute when the Promise is resolved.\n     * @param onrejected The callback to execute when the Promise is rejected.\n     * @returns A Promise for the completion of which ever callback is executed.\n     */\n    then<TResult1 = T, TResult2 = never>(onfulfilled?: ((value: T) => TResult1 | PromiseLike<TResult1>) | undefined | null, onrejected?: ((reason: any) => TResult2 | PromiseLike<TResult2>) | undefined | null): PromiseLike<TResult1 | TResult2>;\n}\n\n/**\n * Represents the completion of an asynchronous operation\n */\ninterface Promise<T> {\n    /**\n     * Attaches callbacks for the resolution and/or rejection of the Promise.\n     * @param onfulfilled The callback to execute when the Promise is resolved.\n     * @param onrejected The callback to execute when the Promise is rejected.\n     * @returns A Promise for the completion of which ever callback is executed.\n     */\n    then<TResult1 = T, TResult2 = never>(onfulfilled?: ((value: T) => TResult1 | PromiseLike<TResult1>) | undefined | null, onrejected?: ((reason: any) => TResult2 | PromiseLike<TResult2>) | undefined | null): Promise<TResult1 | TResult2>;\n\n    /**\n     * Attaches a callback for only the rejection of the Promise.\n     * @param onrejected The callback to execute when the Promise is rejected.\n     * @returns A Promise for the completion of the callback.\n     */\n    catch<TResult = never>(onrejected?: ((reason: any) => TResult | PromiseLike<TResult>) | undefined | null): Promise<T | TResult>;\n}\n\ninterface ArrayLike<T> {\n    readonly length: number;\n    readonly [n: number]: T;\n}\n\n/**\n * Make all properties in T optional\n */\ntype Partial<T> = {\n    [P in keyof T]?: T[P];\n};\n\n/**\n * Make all properties in T required\n */\ntype Required<T> = {\n    [P in keyof T]-?: T[P];\n};\n\n/**\n * Make all properties in T readonly\n */\ntype Readonly<T> = {\n    readonly [P in keyof T]: T[P];\n};\n\n/**\n * From T, pick a set of properties whose keys are in the union K\n */\ntype Pick<T, K extends keyof T> = {\n    [P in K]: T[P];\n};\n\n/**\n * Construct a type with a set of properties K of type T\n */\ntype Record<K extends keyof any, T> = {\n    [P in K]: T;\n};\n\n/**\n * Exclude from T those types that are assignable to U\n */\ntype Exclude<T, U> = T extends U ? never : T;\n\n/**\n * Extract from T those types that are assignable to U\n */\ntype Extract<T, U> = T extends U ? T : never;\n\n/**\n * Construct a type with the properties of T except for those in type K.\n */\ntype Omit<T, K extends keyof any> = Pick<T, Exclude<keyof T, K>>;\n\n/**\n * Exclude null and undefined from T\n */\ntype NonNullable<T> = T extends null | undefined ? never : T;\n\n/**\n * Obtain the parameters of a function type in a tuple\n */\ntype Parameters<T extends (...args: any) => any> = T extends (...args: infer P) => any ? P : never;\n\n/**\n * Obtain the parameters of a constructor function type in a tuple\n */\ntype ConstructorParameters<T extends abstract new (...args: any) => any> = T extends abstract new (...args: infer P) => any ? P : never;\n\n/**\n * Obtain the return type of a function type\n */\ntype ReturnType<T extends (...args: any) => any> = T extends (...args: any) => infer R ? R : any;\n\n/**\n * Obtain the return type of a constructor function type\n */\ntype InstanceType<T extends abstract new (...args: any) => any> = T extends abstract new (...args: any) => infer R ? R : any;\n\n/**\n * Convert string literal type to uppercase\n */\ntype Uppercase<S extends string> = intrinsic;\n\n/**\n * Convert string literal type to lowercase\n */\ntype Lowercase<S extends string> = intrinsic;\n\n/**\n * Convert first character of string literal type to uppercase\n */\ntype Capitalize<S extends string> = intrinsic;\n\n/**\n * Convert first character of string literal type to lowercase\n */\ntype Uncapitalize<S extends string> = intrinsic;\n\n/**\n * Marker for contextual 'this' type\n */\ninterface ThisType<T> { }\n\n/**\n * Represents a raw buffer of binary data, which is used to store data for the\n * different typed arrays. ArrayBuffers cannot be read from or written to directly,\n * but can be passed to a typed array or DataView Object to interpret the raw\n * buffer as needed.\n */\ninterface ArrayBuffer {\n    /**\n     * Read-only. The length of the ArrayBuffer (in bytes).\n     */\n    readonly byteLength: number;\n\n    /**\n     * Returns a section of an ArrayBuffer.\n     */\n    slice(begin: number, end?: number): ArrayBuffer;\n}\n\n/**\n * Allowed ArrayBuffer types for the buffer of an ArrayBufferView and related Typed Arrays.\n */\ninterface ArrayBufferTypes {\n    ArrayBuffer: ArrayBuffer;\n}\ntype ArrayBufferLike = ArrayBufferTypes[keyof ArrayBufferTypes];\n\ninterface ArrayBufferConstructor {\n    readonly prototype: ArrayBuffer;\n    new(byteLength: number): ArrayBuffer;\n    isView(arg: any): arg is ArrayBufferView;\n}\ndeclare var ArrayBuffer: ArrayBufferConstructor;\n\ninterface ArrayBufferView {\n    /**\n     * The ArrayBuffer instance referenced by the array.\n     */\n    buffer: ArrayBufferLike;\n\n    /**\n     * The length in bytes of the array.\n     */\n    byteLength: number;\n\n    /**\n     * The offset in bytes of the array.\n     */\n    byteOffset: number;\n}\n\ninterface DataView {\n    readonly buffer: ArrayBuffer;\n    readonly byteLength: number;\n    readonly byteOffset: number;\n    /**\n     * Gets the Float32 value at the specified byte offset from the start of the view. There is\n     * no alignment constraint; multi-byte values may be fetched from any offset.\n     * @param byteOffset The place in the buffer at which the value should be retrieved.\n     */\n    getFloat32(byteOffset: number, littleEndian?: boolean): number;\n\n    /**\n     * Gets the Float64 value at the specified byte offset from the start of the view. There is\n     * no alignment constraint; multi-byte values may be fetched from any offset.\n     * @param byteOffset The place in the buffer at which the value should be retrieved.\n     */\n    getFloat64(byteOffset: number, littleEndian?: boolean): number;\n\n    /**\n     * Gets the Int8 value at the specified byte offset from the start of the view. There is\n     * no alignment constraint; multi-byte values may be fetched from any offset.\n     * @param byteOffset The place in the buffer at which the value should be retrieved.\n     */\n    getInt8(byteOffset: number): number;\n\n    /**\n     * Gets the Int16 value at the specified byte offset from the start of the view. There is\n     * no alignment constraint; multi-byte values may be fetched from any offset.\n     * @param byteOffset The place in the buffer at which the value should be retrieved.\n     */\n    getInt16(byteOffset: number, littleEndian?: boolean): number;\n    /**\n     * Gets the Int32 value at the specified byte offset from the start of the view. There is\n     * no alignment constraint; multi-byte values may be fetched from any offset.\n     * @param byteOffset The place in the buffer at which the value should be retrieved.\n     */\n    getInt32(byteOffset: number, littleEndian?: boolean): number;\n\n    /**\n     * Gets the Uint8 value at the specified byte offset from the start of the view. There is\n     * no alignment constraint; multi-byte values may be fetched from any offset.\n     * @param byteOffset The place in the buffer at which the value should be retrieved.\n     */\n    getUint8(byteOffset: number): number;\n\n    /**\n     * Gets the Uint16 value at the specified byte offset from the start of the view. There is\n     * no alignment constraint; multi-byte values may be fetched from any offset.\n     * @param byteOffset The place in the buffer at which the value should be retrieved.\n     */\n    getUint16(byteOffset: number, littleEndian?: boolean): number;\n\n    /**\n     * Gets the Uint32 value at the specified byte offset from the start of the view. There is\n     * no alignment constraint; multi-byte values may be fetched from any offset.\n     * @param byteOffset The place in the buffer at which the value should be retrieved.\n     */\n    getUint32(byteOffset: number, littleEndian?: boolean): number;\n\n    /**\n     * Stores an Float32 value at the specified byte offset from the start of the view.\n     * @param byteOffset The place in the buffer at which the value should be set.\n     * @param value The value to set.\n     * @param littleEndian If false or undefined, a big-endian value should be written,\n     * otherwise a little-endian value should be written.\n     */\n    setFloat32(byteOffset: number, value: number, littleEndian?: boolean): void;\n\n    /**\n     * Stores an Float64 value at the specified byte offset from the start of the view.\n     * @param byteOffset The place in the buffer at which the value should be set.\n     * @param value The value to set.\n     * @param littleEndian If false or undefined, a big-endian value should be written,\n     * otherwise a little-endian value should be written.\n     */\n    setFloat64(byteOffset: number, value: number, littleEndian?: boolean): void;\n\n    /**\n     * Stores an Int8 value at the specified byte offset from the start of the view.\n     * @param byteOffset The place in the buffer at which the value should be set.\n     * @param value The value to set.\n     */\n    setInt8(byteOffset: number, value: number): void;\n\n    /**\n     * Stores an Int16 value at the specified byte offset from the start of the view.\n     * @param byteOffset The place in the buffer at which the value should be set.\n     * @param value The value to set.\n     * @param littleEndian If false or undefined, a big-endian value should be written,\n     * otherwise a little-endian value should be written.\n     */\n    setInt16(byteOffset: number, value: number, littleEndian?: boolean): void;\n\n    /**\n     * Stores an Int32 value at the specified byte offset from the start of the view.\n     * @param byteOffset The place in the buffer at which the value should be set.\n     * @param value The value to set.\n     * @param littleEndian If false or undefined, a big-endian value should be written,\n     * otherwise a little-endian value should be written.\n     */\n    setInt32(byteOffset: number, value: number, littleEndian?: boolean): void;\n\n    /**\n     * Stores an Uint8 value at the specified byte offset from the start of the view.\n     * @param byteOffset The place in the buffer at which the value should be set.\n     * @param value The value to set.\n     */\n    setUint8(byteOffset: number, value: number): void;\n\n    /**\n     * Stores an Uint16 value at the specified byte offset from the start of the view.\n     * @param byteOffset The place in the buffer at which the value should be set.\n     * @param value The value to set.\n     * @param littleEndian If false or undefined, a big-endian value should be written,\n     * otherwise a little-endian value should be written.\n     */\n    setUint16(byteOffset: number, value: number, littleEndian?: boolean): void;\n\n    /**\n     * Stores an Uint32 value at the specified byte offset from the start of the view.\n     * @param byteOffset The place in the buffer at which the value should be set.\n     * @param value The value to set.\n     * @param littleEndian If false or undefined, a big-endian value should be written,\n     * otherwise a little-endian value should be written.\n     */\n    setUint32(byteOffset: number, value: number, littleEndian?: boolean): void;\n}\n\ninterface DataViewConstructor {\n    readonly prototype: DataView;\n    new(buffer: ArrayBufferLike, byteOffset?: number, byteLength?: number): DataView;\n}\ndeclare var DataView: DataViewConstructor;\n\n/**\n * A typed array of 8-bit integer values. The contents are initialized to 0. If the requested\n * number of bytes could not be allocated an exception is raised.\n */\ninterface Int8Array {\n    /**\n     * The size in bytes of each element in the array.\n     */\n    readonly BYTES_PER_ELEMENT: number;\n\n    /**\n     * The ArrayBuffer instance referenced by the array.\n     */\n    readonly buffer: ArrayBufferLike;\n\n    /**\n     * The length in bytes of the array.\n     */\n    readonly byteLength: number;\n\n    /**\n     * The offset in bytes of the array.\n     */\n    readonly byteOffset: number;\n\n    /**\n     * Returns the this object after copying a section of the array identified by start and end\n     * to the same array starting at position target\n     * @param target If target is negative, it is treated as length+target where length is the\n     * length of the array.\n     * @param start If start is negative, it is treated as length+start. If end is negative, it\n     * is treated as length+end.\n     * @param end If not specified, length of the this object is used as its default value.\n     */\n    copyWithin(target: number, start: number, end?: number): this;\n\n    /**\n     * Determines whether all the members of an array satisfy the specified test.\n     * @param predicate A function that accepts up to three arguments. The every method calls\n     * the predicate function for each element in the array until the predicate returns a value\n     * which is coercible to the Boolean value false, or until the end of the array.\n     * @param thisArg An object to which the this keyword can refer in the predicate function.\n     * If thisArg is omitted, undefined is used as the this value.\n     */\n    every(predicate: (value: number, index: number, array: Int8Array) => unknown, thisArg?: any): boolean;\n\n    /**\n     * Returns the this object after filling the section identified by start and end with value\n     * @param value value to fill array section with\n     * @param start index to start filling the array at. If start is negative, it is treated as\n     * length+start where length is the length of the array.\n     * @param end index to stop filling the array at. If end is negative, it is treated as\n     * length+end.\n     */\n    fill(value: number, start?: number, end?: number): this;\n\n    /**\n     * Returns the elements of an array that meet the condition specified in a callback function.\n     * @param predicate A function that accepts up to three arguments. The filter method calls\n     * the predicate function one time for each element in the array.\n     * @param thisArg An object to which the this keyword can refer in the predicate function.\n     * If thisArg is omitted, undefined is used as the this value.\n     */\n    filter(predicate: (value: number, index: number, array: Int8Array) => any, thisArg?: any): Int8Array;\n\n    /**\n     * Returns the value of the first element in the array where predicate is true, and undefined\n     * otherwise.\n     * @param predicate find calls predicate once for each element of the array, in ascending\n     * order, until it finds one where predicate returns true. If such an element is found, find\n     * immediately returns that element value. Otherwise, find returns undefined.\n     * @param thisArg If provided, it will be used as the this value for each invocation of\n     * predicate. If it is not provided, undefined is used instead.\n     */\n    find(predicate: (value: number, index: number, obj: Int8Array) => boolean, thisArg?: any): number | undefined;\n\n    /**\n     * Returns the index of the first element in the array where predicate is true, and -1\n     * otherwise.\n     * @param predicate find calls predicate once for each element of the array, in ascending\n     * order, until it finds one where predicate returns true. If such an element is found,\n     * findIndex immediately returns that element index. Otherwise, findIndex returns -1.\n     * @param thisArg If provided, it will be used as the this value for each invocation of\n     * predicate. If it is not provided, undefined is used instead.\n     */\n    findIndex(predicate: (value: number, index: number, obj: Int8Array) => boolean, thisArg?: any): number;\n\n    /**\n     * Performs the specified action for each element in an array.\n     * @param callbackfn  A function that accepts up to three arguments. forEach calls the\n     * callbackfn function one time for each element in the array.\n     * @param thisArg  An object to which the this keyword can refer in the callbackfn function.\n     * If thisArg is omitted, undefined is used as the this value.\n     */\n    forEach(callbackfn: (value: number, index: number, array: Int8Array) => void, thisArg?: any): void;\n\n    /**\n     * Returns the index of the first occurrence of a value in an array.\n     * @param searchElement The value to locate in the array.\n     * @param fromIndex The array index at which to begin the search. If fromIndex is omitted, the\n     *  search starts at index 0.\n     */\n    indexOf(searchElement: number, fromIndex?: number): number;\n\n    /**\n     * Adds all the elements of an array separated by the specified separator string.\n     * @param separator A string used to separate one element of an array from the next in the\n     * resulting String. If omitted, the array elements are separated with a comma.\n     */\n    join(separator?: string): string;\n\n    /**\n     * Returns the index of the last occurrence of a value in an array.\n     * @param searchElement The value to locate in the array.\n     * @param fromIndex The array index at which to begin the search. If fromIndex is omitted, the\n     * search starts at index 0.\n     */\n    lastIndexOf(searchElement: number, fromIndex?: number): number;\n\n    /**\n     * The length of the array.\n     */\n    readonly length: number;\n\n    /**\n     * Calls a defined callback function on each element of an array, and returns an array that\n     * contains the results.\n     * @param callbackfn A function that accepts up to three arguments. The map method calls the\n     * callbackfn function one time for each element in the array.\n     * @param thisArg An object to which the this keyword can refer in the callbackfn function.\n     * If thisArg is omitted, undefined is used as the this value.\n     */\n    map(callbackfn: (value: number, index: number, array: Int8Array) => number, thisArg?: any): Int8Array;\n\n    /**\n     * Calls the specified callback function for all the elements in an array. The return value of\n     * the callback function is the accumulated result, and is provided as an argument in the next\n     * call to the callback function.\n     * @param callbackfn A function that accepts up to four arguments. The reduce method calls the\n     * callbackfn function one time for each element in the array.\n     * @param initialValue If initialValue is specified, it is used as the initial value to start\n     * the accumulation. The first call to the callbackfn function provides this value as an argument\n     * instead of an array value.\n     */\n    reduce(callbackfn: (previousValue: number, currentValue: number, currentIndex: number, array: Int8Array) => number): number;\n    reduce(callbackfn: (previousValue: number, currentValue: number, currentIndex: number, array: Int8Array) => number, initialValue: number): number;\n\n    /**\n     * Calls the specified callback function for all the elements in an array. The return value of\n     * the callback function is the accumulated result, and is provided as an argument in the next\n     * call to the callback function.\n     * @param callbackfn A function that accepts up to four arguments. The reduce method calls the\n     * callbackfn function one time for each element in the array.\n     * @param initialValue If initialValue is specified, it is used as the initial value to start\n     * the accumulation. The first call to the callbackfn function provides this value as an argument\n     * instead of an array value.\n     */\n    reduce<U>(callbackfn: (previousValue: U, currentValue: number, currentIndex: number, array: Int8Array) => U, initialValue: U): U;\n\n    /**\n     * Calls the specified callback function for all the elements in an array, in descending order.\n     * The return value of the callback function is the accumulated result, and is provided as an\n     * argument in the next call to the callback function.\n     * @param callbackfn A function that accepts up to four arguments. The reduceRight method calls\n     * the callbackfn function one time for each element in the array.\n     * @param initialValue If initialValue is specified, it is used as the initial value to start\n     * the accumulation. The first call to the callbackfn function provides this value as an\n     * argument instead of an array value.\n     */\n    reduceRight(callbackfn: (previousValue: number, currentValue: number, currentIndex: number, array: Int8Array) => number): number;\n    reduceRight(callbackfn: (previousValue: number, currentValue: number, currentIndex: number, array: Int8Array) => number, initialValue: number): number;\n\n    /**\n     * Calls the specified callback function for all the elements in an array, in descending order.\n     * The return value of the callback function is the accumulated result, and is provided as an\n     * argument in the next call to the callback function.\n     * @param callbackfn A function that accepts up to four arguments. The reduceRight method calls\n     * the callbackfn function one time for each element in the array.\n     * @param initialValue If initialValue is specified, it is used as the initial value to start\n     * the accumulation. The first call to the callbackfn function provides this value as an argument\n     * instead of an array value.\n     */\n    reduceRight<U>(callbackfn: (previousValue: U, currentValue: number, currentIndex: number, array: Int8Array) => U, initialValue: U): U;\n\n    /**\n     * Reverses the elements in an Array.\n     */\n    reverse(): Int8Array;\n\n    /**\n     * Sets a value or an array of values.\n     * @param array A typed or untyped array of values to set.\n     * @param offset The index in the current array at which the values are to be written.\n     */\n    set(array: ArrayLike<number>, offset?: number): void;\n\n    /**\n     * Returns a section of an array.\n     * @param start The beginning of the specified portion of the array.\n     * @param end The end of the specified portion of the array. This is exclusive of the element at the index 'end'.\n     */\n    slice(start?: number, end?: number): Int8Array;\n\n    /**\n     * Determines whether the specified callback function returns true for any element of an array.\n     * @param predicate A function that accepts up to three arguments. The some method calls\n     * the predicate function for each element in the array until the predicate returns a value\n     * which is coercible to the Boolean value true, or until the end of the array.\n     * @param thisArg An object to which the this keyword can refer in the predicate function.\n     * If thisArg is omitted, undefined is used as the this value.\n     */\n    some(predicate: (value: number, index: number, array: Int8Array) => unknown, thisArg?: any): boolean;\n\n    /**\n     * Sorts an array.\n     * @param compareFn Function used to determine the order of the elements. It is expected to return\n     * a negative value if first argument is less than second argument, zero if they're equal and a positive\n     * value otherwise. If omitted, the elements are sorted in ascending, ASCII character order.\n     * ```ts\n     * [11,2,22,1].sort((a, b) => a - b)\n     * ```\n     */\n    sort(compareFn?: (a: number, b: number) => number): this;\n\n    /**\n     * Gets a new Int8Array view of the ArrayBuffer store for this array, referencing the elements\n     * at begin, inclusive, up to end, exclusive.\n     * @param begin The index of the beginning of the array.\n     * @param end The index of the end of the array.\n     */\n    subarray(begin?: number, end?: number): Int8Array;\n\n    /**\n     * Converts a number to a string by using the current locale.\n     */\n    toLocaleString(): string;\n\n    /**\n     * Returns a string representation of an array.\n     */\n    toString(): string;\n\n    /** Returns the primitive value of the specified object. */\n    valueOf(): Int8Array;\n\n    [index: number]: number;\n}\ninterface Int8ArrayConstructor {\n    readonly prototype: Int8Array;\n    new(length: number): Int8Array;\n    new(array: ArrayLike<number> | ArrayBufferLike): Int8Array;\n    new(buffer: ArrayBufferLike, byteOffset?: number, length?: number): Int8Array;\n\n    /**\n     * The size in bytes of each element in the array.\n     */\n    readonly BYTES_PER_ELEMENT: number;\n\n    /**\n     * Returns a new array from a set of elements.\n     * @param items A set of elements to include in the new array object.\n     */\n    of(...items: number[]): Int8Array;\n\n    /**\n     * Creates an array from an array-like or iterable object.\n     * @param arrayLike An array-like or iterable object to convert to an array.\n     */\n    from(arrayLike: ArrayLike<number>): Int8Array;\n\n    /**\n     * Creates an array from an array-like or iterable object.\n     * @param arrayLike An array-like or iterable object to convert to an array.\n     * @param mapfn A mapping function to call on every element of the array.\n     * @param thisArg Value of 'this' used to invoke the mapfn.\n     */\n    from<T>(arrayLike: ArrayLike<T>, mapfn: (v: T, k: number) => number, thisArg?: any): Int8Array;\n\n\n}\ndeclare var Int8Array: Int8ArrayConstructor;\n\n/**\n * A typed array of 8-bit unsigned integer values. The contents are initialized to 0. If the\n * requested number of bytes could not be allocated an exception is raised.\n */\ninterface Uint8Array {\n    /**\n     * The size in bytes of each element in the array.\n     */\n    readonly BYTES_PER_ELEMENT: number;\n\n    /**\n     * The ArrayBuffer instance referenced by the array.\n     */\n    readonly buffer: ArrayBufferLike;\n\n    /**\n     * The length in bytes of the array.\n     */\n    readonly byteLength: number;\n\n    /**\n     * The offset in bytes of the array.\n     */\n    readonly byteOffset: number;\n\n    /**\n     * Returns the this object after copying a section of the array identified by start and end\n     * to the same array starting at position target\n     * @param target If target is negative, it is treated as length+target where length is the\n     * length of the array.\n     * @param start If start is negative, it is treated as length+start. If end is negative, it\n     * is treated as length+end.\n     * @param end If not specified, length of the this object is used as its default value.\n     */\n    copyWithin(target: number, start: number, end?: number): this;\n\n    /**\n     * Determines whether all the members of an array satisfy the specified test.\n     * @param predicate A function that accepts up to three arguments. The every method calls\n     * the predicate function for each element in the array until the predicate returns a value\n     * which is coercible to the Boolean value false, or until the end of the array.\n     * @param thisArg An object to which the this keyword can refer in the predicate function.\n     * If thisArg is omitted, undefined is used as the this value.\n     */\n    every(predicate: (value: number, index: number, array: Uint8Array) => unknown, thisArg?: any): boolean;\n\n    /**\n     * Returns the this object after filling the section identified by start and end with value\n     * @param value value to fill array section with\n     * @param start index to start filling the array at. If start is negative, it is treated as\n     * length+start where length is the length of the array.\n     * @param end index to stop filling the array at. If end is negative, it is treated as\n     * length+end.\n     */\n    fill(value: number, start?: number, end?: number): this;\n\n    /**\n     * Returns the elements of an array that meet the condition specified in a callback function.\n     * @param predicate A function that accepts up to three arguments. The filter method calls\n     * the predicate function one time for each element in the array.\n     * @param thisArg An object to which the this keyword can refer in the predicate function.\n     * If thisArg is omitted, undefined is used as the this value.\n     */\n    filter(predicate: (value: number, index: number, array: Uint8Array) => any, thisArg?: any): Uint8Array;\n\n    /**\n     * Returns the value of the first element in the array where predicate is true, and undefined\n     * otherwise.\n     * @param predicate find calls predicate once for each element of the array, in ascending\n     * order, until it finds one where predicate returns true. If such an element is found, find\n     * immediately returns that element value. Otherwise, find returns undefined.\n     * @param thisArg If provided, it will be used as the this value for each invocation of\n     * predicate. If it is not provided, undefined is used instead.\n     */\n    find(predicate: (value: number, index: number, obj: Uint8Array) => boolean, thisArg?: any): number | undefined;\n\n    /**\n     * Returns the index of the first element in the array where predicate is true, and -1\n     * otherwise.\n     * @param predicate find calls predicate once for each element of the array, in ascending\n     * order, until it finds one where predicate returns true. If such an element is found,\n     * findIndex immediately returns that element index. Otherwise, findIndex returns -1.\n     * @param thisArg If provided, it will be used as the this value for each invocation of\n     * predicate. If it is not provided, undefined is used instead.\n     */\n    findIndex(predicate: (value: number, index: number, obj: Uint8Array) => boolean, thisArg?: any): number;\n\n    /**\n     * Performs the specified action for each element in an array.\n     * @param callbackfn  A function that accepts up to three arguments. forEach calls the\n     * callbackfn function one time for each element in the array.\n     * @param thisArg  An object to which the this keyword can refer in the callbackfn function.\n     * If thisArg is omitted, undefined is used as the this value.\n     */\n    forEach(callbackfn: (value: number, index: number, array: Uint8Array) => void, thisArg?: any): void;\n\n    /**\n     * Returns the index of the first occurrence of a value in an array.\n     * @param searchElement The value to locate in the array.\n     * @param fromIndex The array index at which to begin the search. If fromIndex is omitted, the\n     *  search starts at index 0.\n     */\n    indexOf(searchElement: number, fromIndex?: number): number;\n\n    /**\n     * Adds all the elements of an array separated by the specified separator string.\n     * @param separator A string used to separate one element of an array from the next in the\n     * resulting String. If omitted, the array elements are separated with a comma.\n     */\n    join(separator?: string): string;\n\n    /**\n     * Returns the index of the last occurrence of a value in an array.\n     * @param searchElement The value to locate in the array.\n     * @param fromIndex The array index at which to begin the search. If fromIndex is omitted, the\n     * search starts at index 0.\n     */\n    lastIndexOf(searchElement: number, fromIndex?: number): number;\n\n    /**\n     * The length of the array.\n     */\n    readonly length: number;\n\n    /**\n     * Calls a defined callback function on each element of an array, and returns an array that\n     * contains the results.\n     * @param callbackfn A function that accepts up to three arguments. The map method calls the\n     * callbackfn function one time for each element in the array.\n     * @param thisArg An object to which the this keyword can refer in the callbackfn function.\n     * If thisArg is omitted, undefined is used as the this value.\n     */\n    map(callbackfn: (value: number, index: number, array: Uint8Array) => number, thisArg?: any): Uint8Array;\n\n    /**\n     * Calls the specified callback function for all the elements in an array. The return value of\n     * the callback function is the accumulated result, and is provided as an argument in the next\n     * call to the callback function.\n     * @param callbackfn A function that accepts up to four arguments. The reduce method calls the\n     * callbackfn function one time for each element in the array.\n     * @param initialValue If initialValue is specified, it is used as the initial value to start\n     * the accumulation. The first call to the callbackfn function provides this value as an argument\n     * instead of an array value.\n     */\n    reduce(callbackfn: (previousValue: number, currentValue: number, currentIndex: number, array: Uint8Array) => number): number;\n    reduce(callbackfn: (previousValue: number, currentValue: number, currentIndex: number, array: Uint8Array) => number, initialValue: number): number;\n\n    /**\n     * Calls the specified callback function for all the elements in an array. The return value of\n     * the callback function is the accumulated result, and is provided as an argument in the next\n     * call to the callback function.\n     * @param callbackfn A function that accepts up to four arguments. The reduce method calls the\n     * callbackfn function one time for each element in the array.\n     * @param initialValue If initialValue is specified, it is used as the initial value to start\n     * the accumulation. The first call to the callbackfn function provides this value as an argument\n     * instead of an array value.\n     */\n    reduce<U>(callbackfn: (previousValue: U, currentValue: number, currentIndex: number, array: Uint8Array) => U, initialValue: U): U;\n\n    /**\n     * Calls the specified callback function for all the elements in an array, in descending order.\n     * The return value of the callback function is the accumulated result, and is provided as an\n     * argument in the next call to the callback function.\n     * @param callbackfn A function that accepts up to four arguments. The reduceRight method calls\n     * the callbackfn function one time for each element in the array.\n     * @param initialValue If initialValue is specified, it is used as the initial value to start\n     * the accumulation. The first call to the callbackfn function provides this value as an\n     * argument instead of an array value.\n     */\n    reduceRight(callbackfn: (previousValue: number, currentValue: number, currentIndex: number, array: Uint8Array) => number): number;\n    reduceRight(callbackfn: (previousValue: number, currentValue: number, currentIndex: number, array: Uint8Array) => number, initialValue: number): number;\n\n    /**\n     * Calls the specified callback function for all the elements in an array, in descending order.\n     * The return value of the callback function is the accumulated result, and is provided as an\n     * argument in the next call to the callback function.\n     * @param callbackfn A function that accepts up to four arguments. The reduceRight method calls\n     * the callbackfn function one time for each element in the array.\n     * @param initialValue If initialValue is specified, it is used as the initial value to start\n     * the accumulation. The first call to the callbackfn function provides this value as an argument\n     * instead of an array value.\n     */\n    reduceRight<U>(callbackfn: (previousValue: U, currentValue: number, currentIndex: number, array: Uint8Array) => U, initialValue: U): U;\n\n    /**\n     * Reverses the elements in an Array.\n     */\n    reverse(): Uint8Array;\n\n    /**\n     * Sets a value or an array of values.\n     * @param array A typed or untyped array of values to set.\n     * @param offset The index in the current array at which the values are to be written.\n     */\n    set(array: ArrayLike<number>, offset?: number): void;\n\n    /**\n     * Returns a section of an array.\n     * @param start The beginning of the specified portion of the array.\n     * @param end The end of the specified portion of the array. This is exclusive of the element at the index 'end'.\n     */\n    slice(start?: number, end?: number): Uint8Array;\n\n    /**\n     * Determines whether the specified callback function returns true for any element of an array.\n     * @param predicate A function that accepts up to three arguments. The some method calls\n     * the predicate function for each element in the array until the predicate returns a value\n     * which is coercible to the Boolean value true, or until the end of the array.\n     * @param thisArg An object to which the this keyword can refer in the predicate function.\n     * If thisArg is omitted, undefined is used as the this value.\n     */\n    some(predicate: (value: number, index: number, array: Uint8Array) => unknown, thisArg?: any): boolean;\n\n    /**\n     * Sorts an array.\n     * @param compareFn Function used to determine the order of the elements. It is expected to return\n     * a negative value if first argument is less than second argument, zero if they're equal and a positive\n     * value otherwise. If omitted, the elements are sorted in ascending, ASCII character order.\n     * ```ts\n     * [11,2,22,1].sort((a, b) => a - b)\n     * ```\n     */\n    sort(compareFn?: (a: number, b: number) => number): this;\n\n    /**\n     * Gets a new Uint8Array view of the ArrayBuffer store for this array, referencing the elements\n     * at begin, inclusive, up to end, exclusive.\n     * @param begin The index of the beginning of the array.\n     * @param end The index of the end of the array.\n     */\n    subarray(begin?: number, end?: number): Uint8Array;\n\n    /**\n     * Converts a number to a string by using the current locale.\n     */\n    toLocaleString(): string;\n\n    /**\n     * Returns a string representation of an array.\n     */\n    toString(): string;\n\n    /** Returns the primitive value of the specified object. */\n    valueOf(): Uint8Array;\n\n    [index: number]: number;\n}\n\ninterface Uint8ArrayConstructor {\n    readonly prototype: Uint8Array;\n    new(length: number): Uint8Array;\n    new(array: ArrayLike<number> | ArrayBufferLike): Uint8Array;\n    new(buffer: ArrayBufferLike, byteOffset?: number, length?: number): Uint8Array;\n\n    /**\n     * The size in bytes of each element in the array.\n     */\n    readonly BYTES_PER_ELEMENT: number;\n\n    /**\n     * Returns a new array from a set of elements.\n     * @param items A set of elements to include in the new array object.\n     */\n    of(...items: number[]): Uint8Array;\n\n    /**\n     * Creates an array from an array-like or iterable object.\n     * @param arrayLike An array-like or iterable object to convert to an array.\n     */\n    from(arrayLike: ArrayLike<number>): Uint8Array;\n\n    /**\n     * Creates an array from an array-like or iterable object.\n     * @param arrayLike An array-like or iterable object to convert to an array.\n     * @param mapfn A mapping function to call on every element of the array.\n     * @param thisArg Value of 'this' used to invoke the mapfn.\n     */\n    from<T>(arrayLike: ArrayLike<T>, mapfn: (v: T, k: number) => number, thisArg?: any): Uint8Array;\n\n}\ndeclare var Uint8Array: Uint8ArrayConstructor;\n\n/**\n * A typed array of 8-bit unsigned integer (clamped) values. The contents are initialized to 0.\n * If the requested number of bytes could not be allocated an exception is raised.\n */\ninterface Uint8ClampedArray {\n    /**\n     * The size in bytes of each element in the array.\n     */\n    readonly BYTES_PER_ELEMENT: number;\n\n    /**\n     * The ArrayBuffer instance referenced by the array.\n     */\n    readonly buffer: ArrayBufferLike;\n\n    /**\n     * The length in bytes of the array.\n     */\n    readonly byteLength: number;\n\n    /**\n     * The offset in bytes of the array.\n     */\n    readonly byteOffset: number;\n\n    /**\n     * Returns the this object after copying a section of the array identified by start and end\n     * to the same array starting at position target\n     * @param target If target is negative, it is treated as length+target where length is the\n     * length of the array.\n     * @param start If start is negative, it is treated as length+start. If end is negative, it\n     * is treated as length+end.\n     * @param end If not specified, length of the this object is used as its default value.\n     */\n    copyWithin(target: number, start: number, end?: number): this;\n\n    /**\n     * Determines whether all the members of an array satisfy the specified test.\n     * @param predicate A function that accepts up to three arguments. The every method calls\n     * the predicate function for each element in the array until the predicate returns a value\n     * which is coercible to the Boolean value false, or until the end of the array.\n     * @param thisArg An object to which the this keyword can refer in the predicate function.\n     * If thisArg is omitted, undefined is used as the this value.\n     */\n    every(predicate: (value: number, index: number, array: Uint8ClampedArray) => unknown, thisArg?: any): boolean;\n\n    /**\n     * Returns the this object after filling the section identified by start and end with value\n     * @param value value to fill array section with\n     * @param start index to start filling the array at. If start is negative, it is treated as\n     * length+start where length is the length of the array.\n     * @param end index to stop filling the array at. If end is negative, it is treated as\n     * length+end.\n     */\n    fill(value: number, start?: number, end?: number): this;\n\n    /**\n     * Returns the elements of an array that meet the condition specified in a callback function.\n     * @param predicate A function that accepts up to three arguments. The filter method calls\n     * the predicate function one time for each element in the array.\n     * @param thisArg An object to which the this keyword can refer in the predicate function.\n     * If thisArg is omitted, undefined is used as the this value.\n     */\n    filter(predicate: (value: number, index: number, array: Uint8ClampedArray) => any, thisArg?: any): Uint8ClampedArray;\n\n    /**\n     * Returns the value of the first element in the array where predicate is true, and undefined\n     * otherwise.\n     * @param predicate find calls predicate once for each element of the array, in ascending\n     * order, until it finds one where predicate returns true. If such an element is found, find\n     * immediately returns that element value. Otherwise, find returns undefined.\n     * @param thisArg If provided, it will be used as the this value for each invocation of\n     * predicate. If it is not provided, undefined is used instead.\n     */\n    find(predicate: (value: number, index: number, obj: Uint8ClampedArray) => boolean, thisArg?: any): number | undefined;\n\n    /**\n     * Returns the index of the first element in the array where predicate is true, and -1\n     * otherwise.\n     * @param predicate find calls predicate once for each element of the array, in ascending\n     * order, until it finds one where predicate returns true. If such an element is found,\n     * findIndex immediately returns that element index. Otherwise, findIndex returns -1.\n     * @param thisArg If provided, it will be used as the this value for each invocation of\n     * predicate. If it is not provided, undefined is used instead.\n     */\n    findIndex(predicate: (value: number, index: number, obj: Uint8ClampedArray) => boolean, thisArg?: any): number;\n\n    /**\n     * Performs the specified action for each element in an array.\n     * @param callbackfn  A function that accepts up to three arguments. forEach calls the\n     * callbackfn function one time for each element in the array.\n     * @param thisArg  An object to which the this keyword can refer in the callbackfn function.\n     * If thisArg is omitted, undefined is used as the this value.\n     */\n    forEach(callbackfn: (value: number, index: number, array: Uint8ClampedArray) => void, thisArg?: any): void;\n\n    /**\n     * Returns the index of the first occurrence of a value in an array.\n     * @param searchElement The value to locate in the array.\n     * @param fromIndex The array index at which to begin the search. If fromIndex is omitted, the\n     *  search starts at index 0.\n     */\n    indexOf(searchElement: number, fromIndex?: number): number;\n\n    /**\n     * Adds all the elements of an array separated by the specified separator string.\n     * @param separator A string used to separate one element of an array from the next in the\n     * resulting String. If omitted, the array elements are separated with a comma.\n     */\n    join(separator?: string): string;\n\n    /**\n     * Returns the index of the last occurrence of a value in an array.\n     * @param searchElement The value to locate in the array.\n     * @param fromIndex The array index at which to begin the search. If fromIndex is omitted, the\n     * search starts at index 0.\n     */\n    lastIndexOf(searchElement: number, fromIndex?: number): number;\n\n    /**\n     * The length of the array.\n     */\n    readonly length: number;\n\n    /**\n     * Calls a defined callback function on each element of an array, and returns an array that\n     * contains the results.\n     * @param callbackfn A function that accepts up to three arguments. The map method calls the\n     * callbackfn function one time for each element in the array.\n     * @param thisArg An object to which the this keyword can refer in the callbackfn function.\n     * If thisArg is omitted, undefined is used as the this value.\n     */\n    map(callbackfn: (value: number, index: number, array: Uint8ClampedArray) => number, thisArg?: any): Uint8ClampedArray;\n\n    /**\n     * Calls the specified callback function for all the elements in an array. The return value of\n     * the callback function is the accumulated result, and is provided as an argument in the next\n     * call to the callback function.\n     * @param callbackfn A function that accepts up to four arguments. The reduce method calls the\n     * callbackfn function one time for each element in the array.\n     * @param initialValue If initialValue is specified, it is used as the initial value to start\n     * the accumulation. The first call to the callbackfn function provides this value as an argument\n     * instead of an array value.\n     */\n    reduce(callbackfn: (previousValue: number, currentValue: number, currentIndex: number, array: Uint8ClampedArray) => number): number;\n    reduce(callbackfn: (previousValue: number, currentValue: number, currentIndex: number, array: Uint8ClampedArray) => number, initialValue: number): number;\n\n    /**\n     * Calls the specified callback function for all the elements in an array. The return value of\n     * the callback function is the accumulated result, and is provided as an argument in the next\n     * call to the callback function.\n     * @param callbackfn A function that accepts up to four arguments. The reduce method calls the\n     * callbackfn function one time for each element in the array.\n     * @param initialValue If initialValue is specified, it is used as the initial value to start\n     * the accumulation. The first call to the callbackfn function provides this value as an argument\n     * instead of an array value.\n     */\n    reduce<U>(callbackfn: (previousValue: U, currentValue: number, currentIndex: number, array: Uint8ClampedArray) => U, initialValue: U): U;\n\n    /**\n     * Calls the specified callback function for all the elements in an array, in descending order.\n     * The return value of the callback function is the accumulated result, and is provided as an\n     * argument in the next call to the callback function.\n     * @param callbackfn A function that accepts up to four arguments. The reduceRight method calls\n     * the callbackfn function one time for each element in the array.\n     * @param initialValue If initialValue is specified, it is used as the initial value to start\n     * the accumulation. The first call to the callbackfn function provides this value as an\n     * argument instead of an array value.\n     */\n    reduceRight(callbackfn: (previousValue: number, currentValue: number, currentIndex: number, array: Uint8ClampedArray) => number): number;\n    reduceRight(callbackfn: (previousValue: number, currentValue: number, currentIndex: number, array: Uint8ClampedArray) => number, initialValue: number): number;\n\n    /**\n     * Calls the specified callback function for all the elements in an array, in descending order.\n     * The return value of the callback function is the accumulated result, and is provided as an\n     * argument in the next call to the callback function.\n     * @param callbackfn A function that accepts up to four arguments. The reduceRight method calls\n     * the callbackfn function one time for each element in the array.\n     * @param initialValue If initialValue is specified, it is used as the initial value to start\n     * the accumulation. The first call to the callbackfn function provides this value as an argument\n     * instead of an array value.\n     */\n    reduceRight<U>(callbackfn: (previousValue: U, currentValue: number, currentIndex: number, array: Uint8ClampedArray) => U, initialValue: U): U;\n\n    /**\n     * Reverses the elements in an Array.\n     */\n    reverse(): Uint8ClampedArray;\n\n    /**\n     * Sets a value or an array of values.\n     * @param array A typed or untyped array of values to set.\n     * @param offset The index in the current array at which the values are to be written.\n     */\n    set(array: ArrayLike<number>, offset?: number): void;\n\n    /**\n     * Returns a section of an array.\n     * @param start The beginning of the specified portion of the array.\n     * @param end The end of the specified portion of the array. This is exclusive of the element at the index 'end'.\n     */\n    slice(start?: number, end?: number): Uint8ClampedArray;\n\n    /**\n     * Determines whether the specified callback function returns true for any element of an array.\n     * @param predicate A function that accepts up to three arguments. The some method calls\n     * the predicate function for each element in the array until the predicate returns a value\n     * which is coercible to the Boolean value true, or until the end of the array.\n     * @param thisArg An object to which the this keyword can refer in the predicate function.\n     * If thisArg is omitted, undefined is used as the this value.\n     */\n    some(predicate: (value: number, index: number, array: Uint8ClampedArray) => unknown, thisArg?: any): boolean;\n\n    /**\n     * Sorts an array.\n     * @param compareFn Function used to determine the order of the elements. It is expected to return\n     * a negative value if first argument is less than second argument, zero if they're equal and a positive\n     * value otherwise. If omitted, the elements are sorted in ascending, ASCII character order.\n     * ```ts\n     * [11,2,22,1].sort((a, b) => a - b)\n     * ```\n     */\n    sort(compareFn?: (a: number, b: number) => number): this;\n\n    /**\n     * Gets a new Uint8ClampedArray view of the ArrayBuffer store for this array, referencing the elements\n     * at begin, inclusive, up to end, exclusive.\n     * @param begin The index of the beginning of the array.\n     * @param end The index of the end of the array.\n     */\n    subarray(begin?: number, end?: number): Uint8ClampedArray;\n\n    /**\n     * Converts a number to a string by using the current locale.\n     */\n    toLocaleString(): string;\n\n    /**\n     * Returns a string representation of an array.\n     */\n    toString(): string;\n\n    /** Returns the primitive value of the specified object. */\n    valueOf(): Uint8ClampedArray;\n\n    [index: number]: number;\n}\n\ninterface Uint8ClampedArrayConstructor {\n    readonly prototype: Uint8ClampedArray;\n    new(length: number): Uint8ClampedArray;\n    new(array: ArrayLike<number> | ArrayBufferLike): Uint8ClampedArray;\n    new(buffer: ArrayBufferLike, byteOffset?: number, length?: number): Uint8ClampedArray;\n\n    /**\n     * The size in bytes of each element in the array.\n     */\n    readonly BYTES_PER_ELEMENT: number;\n\n    /**\n     * Returns a new array from a set of elements.\n     * @param items A set of elements to include in the new array object.\n     */\n    of(...items: number[]): Uint8ClampedArray;\n\n    /**\n     * Creates an array from an array-like or iterable object.\n     * @param arrayLike An array-like or iterable object to convert to an array.\n     */\n    from(arrayLike: ArrayLike<number>): Uint8ClampedArray;\n\n    /**\n     * Creates an array from an array-like or iterable object.\n     * @param arrayLike An array-like or iterable object to convert to an array.\n     * @param mapfn A mapping function to call on every element of the array.\n     * @param thisArg Value of 'this' used to invoke the mapfn.\n     */\n    from<T>(arrayLike: ArrayLike<T>, mapfn: (v: T, k: number) => number, thisArg?: any): Uint8ClampedArray;\n}\ndeclare var Uint8ClampedArray: Uint8ClampedArrayConstructor;\n\n/**\n * A typed array of 16-bit signed integer values. The contents are initialized to 0. If the\n * requested number of bytes could not be allocated an exception is raised.\n */\ninterface Int16Array {\n    /**\n     * The size in bytes of each element in the array.\n     */\n    readonly BYTES_PER_ELEMENT: number;\n\n    /**\n     * The ArrayBuffer instance referenced by the array.\n     */\n    readonly buffer: ArrayBufferLike;\n\n    /**\n     * The length in bytes of the array.\n     */\n    readonly byteLength: number;\n\n    /**\n     * The offset in bytes of the array.\n     */\n    readonly byteOffset: number;\n\n    /**\n     * Returns the this object after copying a section of the array identified by start and end\n     * to the same array starting at position target\n     * @param target If target is negative, it is treated as length+target where length is the\n     * length of the array.\n     * @param start If start is negative, it is treated as length+start. If end is negative, it\n     * is treated as length+end.\n     * @param end If not specified, length of the this object is used as its default value.\n     */\n    copyWithin(target: number, start: number, end?: number): this;\n\n    /**\n     * Determines whether all the members of an array satisfy the specified test.\n     * @param predicate A function that accepts up to three arguments. The every method calls\n     * the predicate function for each element in the array until the predicate returns a value\n     * which is coercible to the Boolean value false, or until the end of the array.\n     * @param thisArg An object to which the this keyword can refer in the predicate function.\n     * If thisArg is omitted, undefined is used as the this value.\n     */\n    every(predicate: (value: number, index: number, array: Int16Array) => unknown, thisArg?: any): boolean;\n\n    /**\n     * Returns the this object after filling the section identified by start and end with value\n     * @param value value to fill array section with\n     * @param start index to start filling the array at. If start is negative, it is treated as\n     * length+start where length is the length of the array.\n     * @param end index to stop filling the array at. If end is negative, it is treated as\n     * length+end.\n     */\n    fill(value: number, start?: number, end?: number): this;\n\n    /**\n     * Returns the elements of an array that meet the condition specified in a callback function.\n     * @param predicate A function that accepts up to three arguments. The filter method calls\n     * the predicate function one time for each element in the array.\n     * @param thisArg An object to which the this keyword can refer in the predicate function.\n     * If thisArg is omitted, undefined is used as the this value.\n     */\n    filter(predicate: (value: number, index: number, array: Int16Array) => any, thisArg?: any): Int16Array;\n\n    /**\n     * Returns the value of the first element in the array where predicate is true, and undefined\n     * otherwise.\n     * @param predicate find calls predicate once for each element of the array, in ascending\n     * order, until it finds one where predicate returns true. If such an element is found, find\n     * immediately returns that element value. Otherwise, find returns undefined.\n     * @param thisArg If provided, it will be used as the this value for each invocation of\n     * predicate. If it is not provided, undefined is used instead.\n     */\n    find(predicate: (value: number, index: number, obj: Int16Array) => boolean, thisArg?: any): number | undefined;\n\n    /**\n     * Returns the index of the first element in the array where predicate is true, and -1\n     * otherwise.\n     * @param predicate find calls predicate once for each element of the array, in ascending\n     * order, until it finds one where predicate returns true. If such an element is found,\n     * findIndex immediately returns that element index. Otherwise, findIndex returns -1.\n     * @param thisArg If provided, it will be used as the this value for each invocation of\n     * predicate. If it is not provided, undefined is used instead.\n     */\n    findIndex(predicate: (value: number, index: number, obj: Int16Array) => boolean, thisArg?: any): number;\n\n    /**\n     * Performs the specified action for each element in an array.\n     * @param callbackfn  A function that accepts up to three arguments. forEach calls the\n     * callbackfn function one time for each element in the array.\n     * @param thisArg  An object to which the this keyword can refer in the callbackfn function.\n     * If thisArg is omitted, undefined is used as the this value.\n     */\n    forEach(callbackfn: (value: number, index: number, array: Int16Array) => void, thisArg?: any): void;\n    /**\n     * Returns the index of the first occurrence of a value in an array.\n     * @param searchElement The value to locate in the array.\n     * @param fromIndex The array index at which to begin the search. If fromIndex is omitted, the\n     *  search starts at index 0.\n     */\n    indexOf(searchElement: number, fromIndex?: number): number;\n\n    /**\n     * Adds all the elements of an array separated by the specified separator string.\n     * @param separator A string used to separate one element of an array from the next in the\n     * resulting String. If omitted, the array elements are separated with a comma.\n     */\n    join(separator?: string): string;\n\n    /**\n     * Returns the index of the last occurrence of a value in an array.\n     * @param searchElement The value to locate in the array.\n     * @param fromIndex The array index at which to begin the search. If fromIndex is omitted, the\n     * search starts at index 0.\n     */\n    lastIndexOf(searchElement: number, fromIndex?: number): number;\n\n    /**\n     * The length of the array.\n     */\n    readonly length: number;\n\n    /**\n     * Calls a defined callback function on each element of an array, and returns an array that\n     * contains the results.\n     * @param callbackfn A function that accepts up to three arguments. The map method calls the\n     * callbackfn function one time for each element in the array.\n     * @param thisArg An object to which the this keyword can refer in the callbackfn function.\n     * If thisArg is omitted, undefined is used as the this value.\n     */\n    map(callbackfn: (value: number, index: number, array: Int16Array) => number, thisArg?: any): Int16Array;\n\n    /**\n     * Calls the specified callback function for all the elements in an array. The return value of\n     * the callback function is the accumulated result, and is provided as an argument in the next\n     * call to the callback function.\n     * @param callbackfn A function that accepts up to four arguments. The reduce method calls the\n     * callbackfn function one time for each element in the array.\n     * @param initialValue If initialValue is specified, it is used as the initial value to start\n     * the accumulation. The first call to the callbackfn function provides this value as an argument\n     * instead of an array value.\n     */\n    reduce(callbackfn: (previousValue: number, currentValue: number, currentIndex: number, array: Int16Array) => number): number;\n    reduce(callbackfn: (previousValue: number, currentValue: number, currentIndex: number, array: Int16Array) => number, initialValue: number): number;\n\n    /**\n     * Calls the specified callback function for all the elements in an array. The return value of\n     * the callback function is the accumulated result, and is provided as an argument in the next\n     * call to the callback function.\n     * @param callbackfn A function that accepts up to four arguments. The reduce method calls the\n     * callbackfn function one time for each element in the array.\n     * @param initialValue If initialValue is specified, it is used as the initial value to start\n     * the accumulation. The first call to the callbackfn function provides this value as an argument\n     * instead of an array value.\n     */\n    reduce<U>(callbackfn: (previousValue: U, currentValue: number, currentIndex: number, array: Int16Array) => U, initialValue: U): U;\n\n    /**\n     * Calls the specified callback function for all the elements in an array, in descending order.\n     * The return value of the callback function is the accumulated result, and is provided as an\n     * argument in the next call to the callback function.\n     * @param callbackfn A function that accepts up to four arguments. The reduceRight method calls\n     * the callbackfn function one time for each element in the array.\n     * @param initialValue If initialValue is specified, it is used as the initial value to start\n     * the accumulation. The first call to the callbackfn function provides this value as an\n     * argument instead of an array value.\n     */\n    reduceRight(callbackfn: (previousValue: number, currentValue: number, currentIndex: number, array: Int16Array) => number): number;\n    reduceRight(callbackfn: (previousValue: number, currentValue: number, currentIndex: number, array: Int16Array) => number, initialValue: number): number;\n\n    /**\n     * Calls the specified callback function for all the elements in an array, in descending order.\n     * The return value of the callback function is the accumulated result, and is provided as an\n     * argument in the next call to the callback function.\n     * @param callbackfn A function that accepts up to four arguments. The reduceRight method calls\n     * the callbackfn function one time for each element in the array.\n     * @param initialValue If initialValue is specified, it is used as the initial value to start\n     * the accumulation. The first call to the callbackfn function provides this value as an argument\n     * instead of an array value.\n     */\n    reduceRight<U>(callbackfn: (previousValue: U, currentValue: number, currentIndex: number, array: Int16Array) => U, initialValue: U): U;\n\n    /**\n     * Reverses the elements in an Array.\n     */\n    reverse(): Int16Array;\n\n    /**\n     * Sets a value or an array of values.\n     * @param array A typed or untyped array of values to set.\n     * @param offset The index in the current array at which the values are to be written.\n     */\n    set(array: ArrayLike<number>, offset?: number): void;\n\n    /**\n     * Returns a section of an array.\n     * @param start The beginning of the specified portion of the array.\n     * @param end The end of the specified portion of the array. This is exclusive of the element at the index 'end'.\n     */\n    slice(start?: number, end?: number): Int16Array;\n\n    /**\n     * Determines whether the specified callback function returns true for any element of an array.\n     * @param predicate A function that accepts up to three arguments. The some method calls\n     * the predicate function for each element in the array until the predicate returns a value\n     * which is coercible to the Boolean value true, or until the end of the array.\n     * @param thisArg An object to which the this keyword can refer in the predicate function.\n     * If thisArg is omitted, undefined is used as the this value.\n     */\n    some(predicate: (value: number, index: number, array: Int16Array) => unknown, thisArg?: any): boolean;\n\n    /**\n     * Sorts an array.\n     * @param compareFn Function used to determine the order of the elements. It is expected to return\n     * a negative value if first argument is less than second argument, zero if they're equal and a positive\n     * value otherwise. If omitted, the elements are sorted in ascending, ASCII character order.\n     * ```ts\n     * [11,2,22,1].sort((a, b) => a - b)\n     * ```\n     */\n    sort(compareFn?: (a: number, b: number) => number): this;\n\n    /**\n     * Gets a new Int16Array view of the ArrayBuffer store for this array, referencing the elements\n     * at begin, inclusive, up to end, exclusive.\n     * @param begin The index of the beginning of the array.\n     * @param end The index of the end of the array.\n     */\n    subarray(begin?: number, end?: number): Int16Array;\n\n    /**\n     * Converts a number to a string by using the current locale.\n     */\n    toLocaleString(): string;\n\n    /**\n     * Returns a string representation of an array.\n     */\n    toString(): string;\n\n    /** Returns the primitive value of the specified object. */\n    valueOf(): Int16Array;\n\n    [index: number]: number;\n}\n\ninterface Int16ArrayConstructor {\n    readonly prototype: Int16Array;\n    new(length: number): Int16Array;\n    new(array: ArrayLike<number> | ArrayBufferLike): Int16Array;\n    new(buffer: ArrayBufferLike, byteOffset?: number, length?: number): Int16Array;\n\n    /**\n     * The size in bytes of each element in the array.\n     */\n    readonly BYTES_PER_ELEMENT: number;\n\n    /**\n     * Returns a new array from a set of elements.\n     * @param items A set of elements to include in the new array object.\n     */\n    of(...items: number[]): Int16Array;\n\n    /**\n     * Creates an array from an array-like or iterable object.\n     * @param arrayLike An array-like or iterable object to convert to an array.\n     */\n    from(arrayLike: ArrayLike<number>): Int16Array;\n\n    /**\n     * Creates an array from an array-like or iterable object.\n     * @param arrayLike An array-like or iterable object to convert to an array.\n     * @param mapfn A mapping function to call on every element of the array.\n     * @param thisArg Value of 'this' used to invoke the mapfn.\n     */\n    from<T>(arrayLike: ArrayLike<T>, mapfn: (v: T, k: number) => number, thisArg?: any): Int16Array;\n\n\n}\ndeclare var Int16Array: Int16ArrayConstructor;\n\n/**\n * A typed array of 16-bit unsigned integer values. The contents are initialized to 0. If the\n * requested number of bytes could not be allocated an exception is raised.\n */\ninterface Uint16Array {\n    /**\n     * The size in bytes of each element in the array.\n     */\n    readonly BYTES_PER_ELEMENT: number;\n\n    /**\n     * The ArrayBuffer instance referenced by the array.\n     */\n    readonly buffer: ArrayBufferLike;\n\n    /**\n     * The length in bytes of the array.\n     */\n    readonly byteLength: number;\n\n    /**\n     * The offset in bytes of the array.\n     */\n    readonly byteOffset: number;\n\n    /**\n     * Returns the this object after copying a section of the array identified by start and end\n     * to the same array starting at position target\n     * @param target If target is negative, it is treated as length+target where length is the\n     * length of the array.\n     * @param start If start is negative, it is treated as length+start. If end is negative, it\n     * is treated as length+end.\n     * @param end If not specified, length of the this object is used as its default value.\n     */\n    copyWithin(target: number, start: number, end?: number): this;\n\n    /**\n     * Determines whether all the members of an array satisfy the specified test.\n     * @param predicate A function that accepts up to three arguments. The every method calls\n     * the predicate function for each element in the array until the predicate returns a value\n     * which is coercible to the Boolean value false, or until the end of the array.\n     * @param thisArg An object to which the this keyword can refer in the predicate function.\n     * If thisArg is omitted, undefined is used as the this value.\n     */\n    every(predicate: (value: number, index: number, array: Uint16Array) => unknown, thisArg?: any): boolean;\n\n    /**\n     * Returns the this object after filling the section identified by start and end with value\n     * @param value value to fill array section with\n     * @param start index to start filling the array at. If start is negative, it is treated as\n     * length+start where length is the length of the array.\n     * @param end index to stop filling the array at. If end is negative, it is treated as\n     * length+end.\n     */\n    fill(value: number, start?: number, end?: number): this;\n\n    /**\n     * Returns the elements of an array that meet the condition specified in a callback function.\n     * @param predicate A function that accepts up to three arguments. The filter method calls\n     * the predicate function one time for each element in the array.\n     * @param thisArg An object to which the this keyword can refer in the predicate function.\n     * If thisArg is omitted, undefined is used as the this value.\n     */\n    filter(predicate: (value: number, index: number, array: Uint16Array) => any, thisArg?: any): Uint16Array;\n\n    /**\n     * Returns the value of the first element in the array where predicate is true, and undefined\n     * otherwise.\n     * @param predicate find calls predicate once for each element of the array, in ascending\n     * order, until it finds one where predicate returns true. If such an element is found, find\n     * immediately returns that element value. Otherwise, find returns undefined.\n     * @param thisArg If provided, it will be used as the this value for each invocation of\n     * predicate. If it is not provided, undefined is used instead.\n     */\n    find(predicate: (value: number, index: number, obj: Uint16Array) => boolean, thisArg?: any): number | undefined;\n\n    /**\n     * Returns the index of the first element in the array where predicate is true, and -1\n     * otherwise.\n     * @param predicate find calls predicate once for each element of the array, in ascending\n     * order, until it finds one where predicate returns true. If such an element is found,\n     * findIndex immediately returns that element index. Otherwise, findIndex returns -1.\n     * @param thisArg If provided, it will be used as the this value for each invocation of\n     * predicate. If it is not provided, undefined is used instead.\n     */\n    findIndex(predicate: (value: number, index: number, obj: Uint16Array) => boolean, thisArg?: any): number;\n\n    /**\n     * Performs the specified action for each element in an array.\n     * @param callbackfn  A function that accepts up to three arguments. forEach calls the\n     * callbackfn function one time for each element in the array.\n     * @param thisArg  An object to which the this keyword can refer in the callbackfn function.\n     * If thisArg is omitted, undefined is used as the this value.\n     */\n    forEach(callbackfn: (value: number, index: number, array: Uint16Array) => void, thisArg?: any): void;\n\n    /**\n     * Returns the index of the first occurrence of a value in an array.\n     * @param searchElement The value to locate in the array.\n     * @param fromIndex The array index at which to begin the search. If fromIndex is omitted, the\n     *  search starts at index 0.\n     */\n    indexOf(searchElement: number, fromIndex?: number): number;\n\n    /**\n     * Adds all the elements of an array separated by the specified separator string.\n     * @param separator A string used to separate one element of an array from the next in the\n     * resulting String. If omitted, the array elements are separated with a comma.\n     */\n    join(separator?: string): string;\n\n    /**\n     * Returns the index of the last occurrence of a value in an array.\n     * @param searchElement The value to locate in the array.\n     * @param fromIndex The array index at which to begin the search. If fromIndex is omitted, the\n     * search starts at index 0.\n     */\n    lastIndexOf(searchElement: number, fromIndex?: number): number;\n\n    /**\n     * The length of the array.\n     */\n    readonly length: number;\n\n    /**\n     * Calls a defined callback function on each element of an array, and returns an array that\n     * contains the results.\n     * @param callbackfn A function that accepts up to three arguments. The map method calls the\n     * callbackfn function one time for each element in the array.\n     * @param thisArg An object to which the this keyword can refer in the callbackfn function.\n     * If thisArg is omitted, undefined is used as the this value.\n     */\n    map(callbackfn: (value: number, index: number, array: Uint16Array) => number, thisArg?: any): Uint16Array;\n\n    /**\n     * Calls the specified callback function for all the elements in an array. The return value of\n     * the callback function is the accumulated result, and is provided as an argument in the next\n     * call to the callback function.\n     * @param callbackfn A function that accepts up to four arguments. The reduce method calls the\n     * callbackfn function one time for each element in the array.\n     * @param initialValue If initialValue is specified, it is used as the initial value to start\n     * the accumulation. The first call to the callbackfn function provides this value as an argument\n     * instead of an array value.\n     */\n    reduce(callbackfn: (previousValue: number, currentValue: number, currentIndex: number, array: Uint16Array) => number): number;\n    reduce(callbackfn: (previousValue: number, currentValue: number, currentIndex: number, array: Uint16Array) => number, initialValue: number): number;\n\n    /**\n     * Calls the specified callback function for all the elements in an array. The return value of\n     * the callback function is the accumulated result, and is provided as an argument in the next\n     * call to the callback function.\n     * @param callbackfn A function that accepts up to four arguments. The reduce method calls the\n     * callbackfn function one time for each element in the array.\n     * @param initialValue If initialValue is specified, it is used as the initial value to start\n     * the accumulation. The first call to the callbackfn function provides this value as an argument\n     * instead of an array value.\n     */\n    reduce<U>(callbackfn: (previousValue: U, currentValue: number, currentIndex: number, array: Uint16Array) => U, initialValue: U): U;\n\n    /**\n     * Calls the specified callback function for all the elements in an array, in descending order.\n     * The return value of the callback function is the accumulated result, and is provided as an\n     * argument in the next call to the callback function.\n     * @param callbackfn A function that accepts up to four arguments. The reduceRight method calls\n     * the callbackfn function one time for each element in the array.\n     * @param initialValue If initialValue is specified, it is used as the initial value to start\n     * the accumulation. The first call to the callbackfn function provides this value as an\n     * argument instead of an array value.\n     */\n    reduceRight(callbackfn: (previousValue: number, currentValue: number, currentIndex: number, array: Uint16Array) => number): number;\n    reduceRight(callbackfn: (previousValue: number, currentValue: number, currentIndex: number, array: Uint16Array) => number, initialValue: number): number;\n\n    /**\n     * Calls the specified callback function for all the elements in an array, in descending order.\n     * The return value of the callback function is the accumulated result, and is provided as an\n     * argument in the next call to the callback function.\n     * @param callbackfn A function that accepts up to four arguments. The reduceRight method calls\n     * the callbackfn function one time for each element in the array.\n     * @param initialValue If initialValue is specified, it is used as the initial value to start\n     * the accumulation. The first call to the callbackfn function provides this value as an argument\n     * instead of an array value.\n     */\n    reduceRight<U>(callbackfn: (previousValue: U, currentValue: number, currentIndex: number, array: Uint16Array) => U, initialValue: U): U;\n\n    /**\n     * Reverses the elements in an Array.\n     */\n    reverse(): Uint16Array;\n\n    /**\n     * Sets a value or an array of values.\n     * @param array A typed or untyped array of values to set.\n     * @param offset The index in the current array at which the values are to be written.\n     */\n    set(array: ArrayLike<number>, offset?: number): void;\n\n    /**\n     * Returns a section of an array.\n     * @param start The beginning of the specified portion of the array.\n     * @param end The end of the specified portion of the array. This is exclusive of the element at the index 'end'.\n     */\n    slice(start?: number, end?: number): Uint16Array;\n\n    /**\n     * Determines whether the specified callback function returns true for any element of an array.\n     * @param predicate A function that accepts up to three arguments. The some method calls\n     * the predicate function for each element in the array until the predicate returns a value\n     * which is coercible to the Boolean value true, or until the end of the array.\n     * @param thisArg An object to which the this keyword can refer in the predicate function.\n     * If thisArg is omitted, undefined is used as the this value.\n     */\n    some(predicate: (value: number, index: number, array: Uint16Array) => unknown, thisArg?: any): boolean;\n\n    /**\n     * Sorts an array.\n     * @param compareFn Function used to determine the order of the elements. It is expected to return\n     * a negative value if first argument is less than second argument, zero if they're equal and a positive\n     * value otherwise. If omitted, the elements are sorted in ascending, ASCII character order.\n     * ```ts\n     * [11,2,22,1].sort((a, b) => a - b)\n     * ```\n     */\n    sort(compareFn?: (a: number, b: number) => number): this;\n\n    /**\n     * Gets a new Uint16Array view of the ArrayBuffer store for this array, referencing the elements\n     * at begin, inclusive, up to end, exclusive.\n     * @param begin The index of the beginning of the array.\n     * @param end The index of the end of the array.\n     */\n    subarray(begin?: number, end?: number): Uint16Array;\n\n    /**\n     * Converts a number to a string by using the current locale.\n     */\n    toLocaleString(): string;\n\n    /**\n     * Returns a string representation of an array.\n     */\n    toString(): string;\n\n    /** Returns the primitive value of the specified object. */\n    valueOf(): Uint16Array;\n\n    [index: number]: number;\n}\n\ninterface Uint16ArrayConstructor {\n    readonly prototype: Uint16Array;\n    new(length: number): Uint16Array;\n    new(array: ArrayLike<number> | ArrayBufferLike): Uint16Array;\n    new(buffer: ArrayBufferLike, byteOffset?: number, length?: number): Uint16Array;\n\n    /**\n     * The size in bytes of each element in the array.\n     */\n    readonly BYTES_PER_ELEMENT: number;\n\n    /**\n     * Returns a new array from a set of elements.\n     * @param items A set of elements to include in the new array object.\n     */\n    of(...items: number[]): Uint16Array;\n\n    /**\n     * Creates an array from an array-like or iterable object.\n     * @param arrayLike An array-like or iterable object to convert to an array.\n     */\n    from(arrayLike: ArrayLike<number>): Uint16Array;\n\n    /**\n     * Creates an array from an array-like or iterable object.\n     * @param arrayLike An array-like or iterable object to convert to an array.\n     * @param mapfn A mapping function to call on every element of the array.\n     * @param thisArg Value of 'this' used to invoke the mapfn.\n     */\n    from<T>(arrayLike: ArrayLike<T>, mapfn: (v: T, k: number) => number, thisArg?: any): Uint16Array;\n\n\n}\ndeclare var Uint16Array: Uint16ArrayConstructor;\n/**\n * A typed array of 32-bit signed integer values. The contents are initialized to 0. If the\n * requested number of bytes could not be allocated an exception is raised.\n */\ninterface Int32Array {\n    /**\n     * The size in bytes of each element in the array.\n     */\n    readonly BYTES_PER_ELEMENT: number;\n\n    /**\n     * The ArrayBuffer instance referenced by the array.\n     */\n    readonly buffer: ArrayBufferLike;\n\n    /**\n     * The length in bytes of the array.\n     */\n    readonly byteLength: number;\n\n    /**\n     * The offset in bytes of the array.\n     */\n    readonly byteOffset: number;\n\n    /**\n     * Returns the this object after copying a section of the array identified by start and end\n     * to the same array starting at position target\n     * @param target If target is negative, it is treated as length+target where length is the\n     * length of the array.\n     * @param start If start is negative, it is treated as length+start. If end is negative, it\n     * is treated as length+end.\n     * @param end If not specified, length of the this object is used as its default value.\n     */\n    copyWithin(target: number, start: number, end?: number): this;\n\n    /**\n     * Determines whether all the members of an array satisfy the specified test.\n     * @param predicate A function that accepts up to three arguments. The every method calls\n     * the predicate function for each element in the array until the predicate returns a value\n     * which is coercible to the Boolean value false, or until the end of the array.\n     * @param thisArg An object to which the this keyword can refer in the predicate function.\n     * If thisArg is omitted, undefined is used as the this value.\n     */\n    every(predicate: (value: number, index: number, array: Int32Array) => unknown, thisArg?: any): boolean;\n\n    /**\n     * Returns the this object after filling the section identified by start and end with value\n     * @param value value to fill array section with\n     * @param start index to start filling the array at. If start is negative, it is treated as\n     * length+start where length is the length of the array.\n     * @param end index to stop filling the array at. If end is negative, it is treated as\n     * length+end.\n     */\n    fill(value: number, start?: number, end?: number): this;\n\n    /**\n     * Returns the elements of an array that meet the condition specified in a callback function.\n     * @param predicate A function that accepts up to three arguments. The filter method calls\n     * the predicate function one time for each element in the array.\n     * @param thisArg An object to which the this keyword can refer in the predicate function.\n     * If thisArg is omitted, undefined is used as the this value.\n     */\n    filter(predicate: (value: number, index: number, array: Int32Array) => any, thisArg?: any): Int32Array;\n\n    /**\n     * Returns the value of the first element in the array where predicate is true, and undefined\n     * otherwise.\n     * @param predicate find calls predicate once for each element of the array, in ascending\n     * order, until it finds one where predicate returns true. If such an element is found, find\n     * immediately returns that element value. Otherwise, find returns undefined.\n     * @param thisArg If provided, it will be used as the this value for each invocation of\n     * predicate. If it is not provided, undefined is used instead.\n     */\n    find(predicate: (value: number, index: number, obj: Int32Array) => boolean, thisArg?: any): number | undefined;\n\n    /**\n     * Returns the index of the first element in the array where predicate is true, and -1\n     * otherwise.\n     * @param predicate find calls predicate once for each element of the array, in ascending\n     * order, until it finds one where predicate returns true. If such an element is found,\n     * findIndex immediately returns that element index. Otherwise, findIndex returns -1.\n     * @param thisArg If provided, it will be used as the this value for each invocation of\n     * predicate. If it is not provided, undefined is used instead.\n     */\n    findIndex(predicate: (value: number, index: number, obj: Int32Array) => boolean, thisArg?: any): number;\n\n    /**\n     * Performs the specified action for each element in an array.\n     * @param callbackfn  A function that accepts up to three arguments. forEach calls the\n     * callbackfn function one time for each element in the array.\n     * @param thisArg  An object to which the this keyword can refer in the callbackfn function.\n     * If thisArg is omitted, undefined is used as the this value.\n     */\n    forEach(callbackfn: (value: number, index: number, array: Int32Array) => void, thisArg?: any): void;\n\n    /**\n     * Returns the index of the first occurrence of a value in an array.\n     * @param searchElement The value to locate in the array.\n     * @param fromIndex The array index at which to begin the search. If fromIndex is omitted, the\n     *  search starts at index 0.\n     */\n    indexOf(searchElement: number, fromIndex?: number): number;\n\n    /**\n     * Adds all the elements of an array separated by the specified separator string.\n     * @param separator A string used to separate one element of an array from the next in the\n     * resulting String. If omitted, the array elements are separated with a comma.\n     */\n    join(separator?: string): string;\n\n    /**\n     * Returns the index of the last occurrence of a value in an array.\n     * @param searchElement The value to locate in the array.\n     * @param fromIndex The array index at which to begin the search. If fromIndex is omitted, the\n     * search starts at index 0.\n     */\n    lastIndexOf(searchElement: number, fromIndex?: number): number;\n\n    /**\n     * The length of the array.\n     */\n    readonly length: number;\n\n    /**\n     * Calls a defined callback function on each element of an array, and returns an array that\n     * contains the results.\n     * @param callbackfn A function that accepts up to three arguments. The map method calls the\n     * callbackfn function one time for each element in the array.\n     * @param thisArg An object to which the this keyword can refer in the callbackfn function.\n     * If thisArg is omitted, undefined is used as the this value.\n     */\n    map(callbackfn: (value: number, index: number, array: Int32Array) => number, thisArg?: any): Int32Array;\n\n    /**\n     * Calls the specified callback function for all the elements in an array. The return value of\n     * the callback function is the accumulated result, and is provided as an argument in the next\n     * call to the callback function.\n     * @param callbackfn A function that accepts up to four arguments. The reduce method calls the\n     * callbackfn function one time for each element in the array.\n     * @param initialValue If initialValue is specified, it is used as the initial value to start\n     * the accumulation. The first call to the callbackfn function provides this value as an argument\n     * instead of an array value.\n     */\n    reduce(callbackfn: (previousValue: number, currentValue: number, currentIndex: number, array: Int32Array) => number): number;\n    reduce(callbackfn: (previousValue: number, currentValue: number, currentIndex: number, array: Int32Array) => number, initialValue: number): number;\n\n    /**\n     * Calls the specified callback function for all the elements in an array. The return value of\n     * the callback function is the accumulated result, and is provided as an argument in the next\n     * call to the callback function.\n     * @param callbackfn A function that accepts up to four arguments. The reduce method calls the\n     * callbackfn function one time for each element in the array.\n     * @param initialValue If initialValue is specified, it is used as the initial value to start\n     * the accumulation. The first call to the callbackfn function provides this value as an argument\n     * instead of an array value.\n     */\n    reduce<U>(callbackfn: (previousValue: U, currentValue: number, currentIndex: number, array: Int32Array) => U, initialValue: U): U;\n\n    /**\n     * Calls the specified callback function for all the elements in an array, in descending order.\n     * The return value of the callback function is the accumulated result, and is provided as an\n     * argument in the next call to the callback function.\n     * @param callbackfn A function that accepts up to four arguments. The reduceRight method calls\n     * the callbackfn function one time for each element in the array.\n     * @param initialValue If initialValue is specified, it is used as the initial value to start\n     * the accumulation. The first call to the callbackfn function provides this value as an\n     * argument instead of an array value.\n     */\n    reduceRight(callbackfn: (previousValue: number, currentValue: number, currentIndex: number, array: Int32Array) => number): number;\n    reduceRight(callbackfn: (previousValue: number, currentValue: number, currentIndex: number, array: Int32Array) => number, initialValue: number): number;\n\n    /**\n     * Calls the specified callback function for all the elements in an array, in descending order.\n     * The return value of the callback function is the accumulated result, and is provided as an\n     * argument in the next call to the callback function.\n     * @param callbackfn A function that accepts up to four arguments. The reduceRight method calls\n     * the callbackfn function one time for each element in the array.\n     * @param initialValue If initialValue is specified, it is used as the initial value to start\n     * the accumulation. The first call to the callbackfn function provides this value as an argument\n     * instead of an array value.\n     */\n    reduceRight<U>(callbackfn: (previousValue: U, currentValue: number, currentIndex: number, array: Int32Array) => U, initialValue: U): U;\n\n    /**\n     * Reverses the elements in an Array.\n     */\n    reverse(): Int32Array;\n\n    /**\n     * Sets a value or an array of values.\n     * @param array A typed or untyped array of values to set.\n     * @param offset The index in the current array at which the values are to be written.\n     */\n    set(array: ArrayLike<number>, offset?: number): void;\n\n    /**\n     * Returns a section of an array.\n     * @param start The beginning of the specified portion of the array.\n     * @param end The end of the specified portion of the array. This is exclusive of the element at the index 'end'.\n     */\n    slice(start?: number, end?: number): Int32Array;\n\n    /**\n     * Determines whether the specified callback function returns true for any element of an array.\n     * @param predicate A function that accepts up to three arguments. The some method calls\n     * the predicate function for each element in the array until the predicate returns a value\n     * which is coercible to the Boolean value true, or until the end of the array.\n     * @param thisArg An object to which the this keyword can refer in the predicate function.\n     * If thisArg is omitted, undefined is used as the this value.\n     */\n    some(predicate: (value: number, index: number, array: Int32Array) => unknown, thisArg?: any): boolean;\n\n    /**\n     * Sorts an array.\n     * @param compareFn Function used to determine the order of the elements. It is expected to return\n     * a negative value if first argument is less than second argument, zero if they're equal and a positive\n     * value otherwise. If omitted, the elements are sorted in ascending, ASCII character order.\n     * ```ts\n     * [11,2,22,1].sort((a, b) => a - b)\n     * ```\n     */\n    sort(compareFn?: (a: number, b: number) => number): this;\n\n    /**\n     * Gets a new Int32Array view of the ArrayBuffer store for this array, referencing the elements\n     * at begin, inclusive, up to end, exclusive.\n     * @param begin The index of the beginning of the array.\n     * @param end The index of the end of the array.\n     */\n    subarray(begin?: number, end?: number): Int32Array;\n\n    /**\n     * Converts a number to a string by using the current locale.\n     */\n    toLocaleString(): string;\n\n    /**\n     * Returns a string representation of an array.\n     */\n    toString(): string;\n\n    /** Returns the primitive value of the specified object. */\n    valueOf(): Int32Array;\n\n    [index: number]: number;\n}\n\ninterface Int32ArrayConstructor {\n    readonly prototype: Int32Array;\n    new(length: number): Int32Array;\n    new(array: ArrayLike<number> | ArrayBufferLike): Int32Array;\n    new(buffer: ArrayBufferLike, byteOffset?: number, length?: number): Int32Array;\n\n    /**\n     * The size in bytes of each element in the array.\n     */\n    readonly BYTES_PER_ELEMENT: number;\n\n    /**\n     * Returns a new array from a set of elements.\n     * @param items A set of elements to include in the new array object.\n     */\n    of(...items: number[]): Int32Array;\n\n    /**\n     * Creates an array from an array-like or iterable object.\n     * @param arrayLike An array-like or iterable object to convert to an array.\n     */\n    from(arrayLike: ArrayLike<number>): Int32Array;\n\n    /**\n     * Creates an array from an array-like or iterable object.\n     * @param arrayLike An array-like or iterable object to convert to an array.\n     * @param mapfn A mapping function to call on every element of the array.\n     * @param thisArg Value of 'this' used to invoke the mapfn.\n     */\n    from<T>(arrayLike: ArrayLike<T>, mapfn: (v: T, k: number) => number, thisArg?: any): Int32Array;\n\n}\ndeclare var Int32Array: Int32ArrayConstructor;\n\n/**\n * A typed array of 32-bit unsigned integer values. The contents are initialized to 0. If the\n * requested number of bytes could not be allocated an exception is raised.\n */\ninterface Uint32Array {\n    /**\n     * The size in bytes of each element in the array.\n     */\n    readonly BYTES_PER_ELEMENT: number;\n\n    /**\n     * The ArrayBuffer instance referenced by the array.\n     */\n    readonly buffer: ArrayBufferLike;\n\n    /**\n     * The length in bytes of the array.\n     */\n    readonly byteLength: number;\n\n    /**\n     * The offset in bytes of the array.\n     */\n    readonly byteOffset: number;\n\n    /**\n     * Returns the this object after copying a section of the array identified by start and end\n     * to the same array starting at position target\n     * @param target If target is negative, it is treated as length+target where length is the\n     * length of the array.\n     * @param start If start is negative, it is treated as length+start. If end is negative, it\n     * is treated as length+end.\n     * @param end If not specified, length of the this object is used as its default value.\n     */\n    copyWithin(target: number, start: number, end?: number): this;\n\n    /**\n     * Determines whether all the members of an array satisfy the specified test.\n     * @param predicate A function that accepts up to three arguments. The every method calls\n     * the predicate function for each element in the array until the predicate returns a value\n     * which is coercible to the Boolean value false, or until the end of the array.\n     * @param thisArg An object to which the this keyword can refer in the predicate function.\n     * If thisArg is omitted, undefined is used as the this value.\n     */\n    every(predicate: (value: number, index: number, array: Uint32Array) => unknown, thisArg?: any): boolean;\n\n    /**\n     * Returns the this object after filling the section identified by start and end with value\n     * @param value value to fill array section with\n     * @param start index to start filling the array at. If start is negative, it is treated as\n     * length+start where length is the length of the array.\n     * @param end index to stop filling the array at. If end is negative, it is treated as\n     * length+end.\n     */\n    fill(value: number, start?: number, end?: number): this;\n\n    /**\n     * Returns the elements of an array that meet the condition specified in a callback function.\n     * @param predicate A function that accepts up to three arguments. The filter method calls\n     * the predicate function one time for each element in the array.\n     * @param thisArg An object to which the this keyword can refer in the predicate function.\n     * If thisArg is omitted, undefined is used as the this value.\n     */\n    filter(predicate: (value: number, index: number, array: Uint32Array) => any, thisArg?: any): Uint32Array;\n\n    /**\n     * Returns the value of the first element in the array where predicate is true, and undefined\n     * otherwise.\n     * @param predicate find calls predicate once for each element of the array, in ascending\n     * order, until it finds one where predicate returns true. If such an element is found, find\n     * immediately returns that element value. Otherwise, find returns undefined.\n     * @param thisArg If provided, it will be used as the this value for each invocation of\n     * predicate. If it is not provided, undefined is used instead.\n     */\n    find(predicate: (value: number, index: number, obj: Uint32Array) => boolean, thisArg?: any): number | undefined;\n\n    /**\n     * Returns the index of the first element in the array where predicate is true, and -1\n     * otherwise.\n     * @param predicate find calls predicate once for each element of the array, in ascending\n     * order, until it finds one where predicate returns true. If such an element is found,\n     * findIndex immediately returns that element index. Otherwise, findIndex returns -1.\n     * @param thisArg If provided, it will be used as the this value for each invocation of\n     * predicate. If it is not provided, undefined is used instead.\n     */\n    findIndex(predicate: (value: number, index: number, obj: Uint32Array) => boolean, thisArg?: any): number;\n\n    /**\n     * Performs the specified action for each element in an array.\n     * @param callbackfn  A function that accepts up to three arguments. forEach calls the\n     * callbackfn function one time for each element in the array.\n     * @param thisArg  An object to which the this keyword can refer in the callbackfn function.\n     * If thisArg is omitted, undefined is used as the this value.\n     */\n    forEach(callbackfn: (value: number, index: number, array: Uint32Array) => void, thisArg?: any): void;\n    /**\n     * Returns the index of the first occurrence of a value in an array.\n     * @param searchElement The value to locate in the array.\n     * @param fromIndex The array index at which to begin the search. If fromIndex is omitted, the\n     *  search starts at index 0.\n     */\n    indexOf(searchElement: number, fromIndex?: number): number;\n\n    /**\n     * Adds all the elements of an array separated by the specified separator string.\n     * @param separator A string used to separate one element of an array from the next in the\n     * resulting String. If omitted, the array elements are separated with a comma.\n     */\n    join(separator?: string): string;\n\n    /**\n     * Returns the index of the last occurrence of a value in an array.\n     * @param searchElement The value to locate in the array.\n     * @param fromIndex The array index at which to begin the search. If fromIndex is omitted, the\n     * search starts at index 0.\n     */\n    lastIndexOf(searchElement: number, fromIndex?: number): number;\n\n    /**\n     * The length of the array.\n     */\n    readonly length: number;\n\n    /**\n     * Calls a defined callback function on each element of an array, and returns an array that\n     * contains the results.\n     * @param callbackfn A function that accepts up to three arguments. The map method calls the\n     * callbackfn function one time for each element in the array.\n     * @param thisArg An object to which the this keyword can refer in the callbackfn function.\n     * If thisArg is omitted, undefined is used as the this value.\n     */\n    map(callbackfn: (value: number, index: number, array: Uint32Array) => number, thisArg?: any): Uint32Array;\n\n    /**\n     * Calls the specified callback function for all the elements in an array. The return value of\n     * the callback function is the accumulated result, and is provided as an argument in the next\n     * call to the callback function.\n     * @param callbackfn A function that accepts up to four arguments. The reduce method calls the\n     * callbackfn function one time for each element in the array.\n     * @param initialValue If initialValue is specified, it is used as the initial value to start\n     * the accumulation. The first call to the callbackfn function provides this value as an argument\n     * instead of an array value.\n     */\n    reduce(callbackfn: (previousValue: number, currentValue: number, currentIndex: number, array: Uint32Array) => number): number;\n    reduce(callbackfn: (previousValue: number, currentValue: number, currentIndex: number, array: Uint32Array) => number, initialValue: number): number;\n\n    /**\n     * Calls the specified callback function for all the elements in an array. The return value of\n     * the callback function is the accumulated result, and is provided as an argument in the next\n     * call to the callback function.\n     * @param callbackfn A function that accepts up to four arguments. The reduce method calls the\n     * callbackfn function one time for each element in the array.\n     * @param initialValue If initialValue is specified, it is used as the initial value to start\n     * the accumulation. The first call to the callbackfn function provides this value as an argument\n     * instead of an array value.\n     */\n    reduce<U>(callbackfn: (previousValue: U, currentValue: number, currentIndex: number, array: Uint32Array) => U, initialValue: U): U;\n\n    /**\n     * Calls the specified callback function for all the elements in an array, in descending order.\n     * The return value of the callback function is the accumulated result, and is provided as an\n     * argument in the next call to the callback function.\n     * @param callbackfn A function that accepts up to four arguments. The reduceRight method calls\n     * the callbackfn function one time for each element in the array.\n     * @param initialValue If initialValue is specified, it is used as the initial value to start\n     * the accumulation. The first call to the callbackfn function provides this value as an\n     * argument instead of an array value.\n     */\n    reduceRight(callbackfn: (previousValue: number, currentValue: number, currentIndex: number, array: Uint32Array) => number): number;\n    reduceRight(callbackfn: (previousValue: number, currentValue: number, currentIndex: number, array: Uint32Array) => number, initialValue: number): number;\n\n    /**\n     * Calls the specified callback function for all the elements in an array, in descending order.\n     * The return value of the callback function is the accumulated result, and is provided as an\n     * argument in the next call to the callback function.\n     * @param callbackfn A function that accepts up to four arguments. The reduceRight method calls\n     * the callbackfn function one time for each element in the array.\n     * @param initialValue If initialValue is specified, it is used as the initial value to start\n     * the accumulation. The first call to the callbackfn function provides this value as an argument\n     * instead of an array value.\n     */\n    reduceRight<U>(callbackfn: (previousValue: U, currentValue: number, currentIndex: number, array: Uint32Array) => U, initialValue: U): U;\n\n    /**\n     * Reverses the elements in an Array.\n     */\n    reverse(): Uint32Array;\n\n    /**\n     * Sets a value or an array of values.\n     * @param array A typed or untyped array of values to set.\n     * @param offset The index in the current array at which the values are to be written.\n     */\n    set(array: ArrayLike<number>, offset?: number): void;\n\n    /**\n     * Returns a section of an array.\n     * @param start The beginning of the specified portion of the array.\n     * @param end The end of the specified portion of the array. This is exclusive of the element at the index 'end'.\n     */\n    slice(start?: number, end?: number): Uint32Array;\n\n    /**\n     * Determines whether the specified callback function returns true for any element of an array.\n     * @param predicate A function that accepts up to three arguments. The some method calls\n     * the predicate function for each element in the array until the predicate returns a value\n     * which is coercible to the Boolean value true, or until the end of the array.\n     * @param thisArg An object to which the this keyword can refer in the predicate function.\n     * If thisArg is omitted, undefined is used as the this value.\n     */\n    some(predicate: (value: number, index: number, array: Uint32Array) => unknown, thisArg?: any): boolean;\n\n    /**\n     * Sorts an array.\n     * @param compareFn Function used to determine the order of the elements. It is expected to return\n     * a negative value if first argument is less than second argument, zero if they're equal and a positive\n     * value otherwise. If omitted, the elements are sorted in ascending, ASCII character order.\n     * ```ts\n     * [11,2,22,1].sort((a, b) => a - b)\n     * ```\n     */\n    sort(compareFn?: (a: number, b: number) => number): this;\n\n    /**\n     * Gets a new Uint32Array view of the ArrayBuffer store for this array, referencing the elements\n     * at begin, inclusive, up to end, exclusive.\n     * @param begin The index of the beginning of the array.\n     * @param end The index of the end of the array.\n     */\n    subarray(begin?: number, end?: number): Uint32Array;\n\n    /**\n     * Converts a number to a string by using the current locale.\n     */\n    toLocaleString(): string;\n\n    /**\n     * Returns a string representation of an array.\n     */\n    toString(): string;\n\n    /** Returns the primitive value of the specified object. */\n    valueOf(): Uint32Array;\n\n    [index: number]: number;\n}\n\ninterface Uint32ArrayConstructor {\n    readonly prototype: Uint32Array;\n    new(length: number): Uint32Array;\n    new(array: ArrayLike<number> | ArrayBufferLike): Uint32Array;\n    new(buffer: ArrayBufferLike, byteOffset?: number, length?: number): Uint32Array;\n\n    /**\n     * The size in bytes of each element in the array.\n     */\n    readonly BYTES_PER_ELEMENT: number;\n\n    /**\n     * Returns a new array from a set of elements.\n     * @param items A set of elements to include in the new array object.\n     */\n    of(...items: number[]): Uint32Array;\n\n    /**\n     * Creates an array from an array-like or iterable object.\n     * @param arrayLike An array-like or iterable object to convert to an array.\n     */\n    from(arrayLike: ArrayLike<number>): Uint32Array;\n\n    /**\n     * Creates an array from an array-like or iterable object.\n     * @param arrayLike An array-like or iterable object to convert to an array.\n     * @param mapfn A mapping function to call on every element of the array.\n     * @param thisArg Value of 'this' used to invoke the mapfn.\n     */\n    from<T>(arrayLike: ArrayLike<T>, mapfn: (v: T, k: number) => number, thisArg?: any): Uint32Array;\n\n}\ndeclare var Uint32Array: Uint32ArrayConstructor;\n\n/**\n * A typed array of 32-bit float values. The contents are initialized to 0. If the requested number\n * of bytes could not be allocated an exception is raised.\n */\ninterface Float32Array {\n    /**\n     * The size in bytes of each element in the array.\n     */\n    readonly BYTES_PER_ELEMENT: number;\n\n    /**\n     * The ArrayBuffer instance referenced by the array.\n     */\n    readonly buffer: ArrayBufferLike;\n\n    /**\n     * The length in bytes of the array.\n     */\n    readonly byteLength: number;\n\n    /**\n     * The offset in bytes of the array.\n     */\n    readonly byteOffset: number;\n\n    /**\n     * Returns the this object after copying a section of the array identified by start and end\n     * to the same array starting at position target\n     * @param target If target is negative, it is treated as length+target where length is the\n     * length of the array.\n     * @param start If start is negative, it is treated as length+start. If end is negative, it\n     * is treated as length+end.\n     * @param end If not specified, length of the this object is used as its default value.\n     */\n    copyWithin(target: number, start: number, end?: number): this;\n\n    /**\n     * Determines whether all the members of an array satisfy the specified test.\n     * @param predicate A function that accepts up to three arguments. The every method calls\n     * the predicate function for each element in the array until the predicate returns a value\n     * which is coercible to the Boolean value false, or until the end of the array.\n     * @param thisArg An object to which the this keyword can refer in the predicate function.\n     * If thisArg is omitted, undefined is used as the this value.\n     */\n    every(predicate: (value: number, index: number, array: Float32Array) => unknown, thisArg?: any): boolean;\n\n    /**\n     * Returns the this object after filling the section identified by start and end with value\n     * @param value value to fill array section with\n     * @param start index to start filling the array at. If start is negative, it is treated as\n     * length+start where length is the length of the array.\n     * @param end index to stop filling the array at. If end is negative, it is treated as\n     * length+end.\n     */\n    fill(value: number, start?: number, end?: number): this;\n\n    /**\n     * Returns the elements of an array that meet the condition specified in a callback function.\n     * @param predicate A function that accepts up to three arguments. The filter method calls\n     * the predicate function one time for each element in the array.\n     * @param thisArg An object to which the this keyword can refer in the predicate function.\n     * If thisArg is omitted, undefined is used as the this value.\n     */\n    filter(predicate: (value: number, index: number, array: Float32Array) => any, thisArg?: any): Float32Array;\n\n    /**\n     * Returns the value of the first element in the array where predicate is true, and undefined\n     * otherwise.\n     * @param predicate find calls predicate once for each element of the array, in ascending\n     * order, until it finds one where predicate returns true. If such an element is found, find\n     * immediately returns that element value. Otherwise, find returns undefined.\n     * @param thisArg If provided, it will be used as the this value for each invocation of\n     * predicate. If it is not provided, undefined is used instead.\n     */\n    find(predicate: (value: number, index: number, obj: Float32Array) => boolean, thisArg?: any): number | undefined;\n\n    /**\n     * Returns the index of the first element in the array where predicate is true, and -1\n     * otherwise.\n     * @param predicate find calls predicate once for each element of the array, in ascending\n     * order, until it finds one where predicate returns true. If such an element is found,\n     * findIndex immediately returns that element index. Otherwise, findIndex returns -1.\n     * @param thisArg If provided, it will be used as the this value for each invocation of\n     * predicate. If it is not provided, undefined is used instead.\n     */\n    findIndex(predicate: (value: number, index: number, obj: Float32Array) => boolean, thisArg?: any): number;\n\n    /**\n     * Performs the specified action for each element in an array.\n     * @param callbackfn  A function that accepts up to three arguments. forEach calls the\n     * callbackfn function one time for each element in the array.\n     * @param thisArg  An object to which the this keyword can refer in the callbackfn function.\n     * If thisArg is omitted, undefined is used as the this value.\n     */\n    forEach(callbackfn: (value: number, index: number, array: Float32Array) => void, thisArg?: any): void;\n\n    /**\n     * Returns the index of the first occurrence of a value in an array.\n     * @param searchElement The value to locate in the array.\n     * @param fromIndex The array index at which to begin the search. If fromIndex is omitted, the\n     *  search starts at index 0.\n     */\n    indexOf(searchElement: number, fromIndex?: number): number;\n\n    /**\n     * Adds all the elements of an array separated by the specified separator string.\n     * @param separator A string used to separate one element of an array from the next in the\n     * resulting String. If omitted, the array elements are separated with a comma.\n     */\n    join(separator?: string): string;\n\n    /**\n     * Returns the index of the last occurrence of a value in an array.\n     * @param searchElement The value to locate in the array.\n     * @param fromIndex The array index at which to begin the search. If fromIndex is omitted, the\n     * search starts at index 0.\n     */\n    lastIndexOf(searchElement: number, fromIndex?: number): number;\n\n    /**\n     * The length of the array.\n     */\n    readonly length: number;\n\n    /**\n     * Calls a defined callback function on each element of an array, and returns an array that\n     * contains the results.\n     * @param callbackfn A function that accepts up to three arguments. The map method calls the\n     * callbackfn function one time for each element in the array.\n     * @param thisArg An object to which the this keyword can refer in the callbackfn function.\n     * If thisArg is omitted, undefined is used as the this value.\n     */\n    map(callbackfn: (value: number, index: number, array: Float32Array) => number, thisArg?: any): Float32Array;\n\n    /**\n     * Calls the specified callback function for all the elements in an array. The return value of\n     * the callback function is the accumulated result, and is provided as an argument in the next\n     * call to the callback function.\n     * @param callbackfn A function that accepts up to four arguments. The reduce method calls the\n     * callbackfn function one time for each element in the array.\n     * @param initialValue If initialValue is specified, it is used as the initial value to start\n     * the accumulation. The first call to the callbackfn function provides this value as an argument\n     * instead of an array value.\n     */\n    reduce(callbackfn: (previousValue: number, currentValue: number, currentIndex: number, array: Float32Array) => number): number;\n    reduce(callbackfn: (previousValue: number, currentValue: number, currentIndex: number, array: Float32Array) => number, initialValue: number): number;\n\n    /**\n     * Calls the specified callback function for all the elements in an array. The return value of\n     * the callback function is the accumulated result, and is provided as an argument in the next\n     * call to the callback function.\n     * @param callbackfn A function that accepts up to four arguments. The reduce method calls the\n     * callbackfn function one time for each element in the array.\n     * @param initialValue If initialValue is specified, it is used as the initial value to start\n     * the accumulation. The first call to the callbackfn function provides this value as an argument\n     * instead of an array value.\n     */\n    reduce<U>(callbackfn: (previousValue: U, currentValue: number, currentIndex: number, array: Float32Array) => U, initialValue: U): U;\n\n    /**\n     * Calls the specified callback function for all the elements in an array, in descending order.\n     * The return value of the callback function is the accumulated result, and is provided as an\n     * argument in the next call to the callback function.\n     * @param callbackfn A function that accepts up to four arguments. The reduceRight method calls\n     * the callbackfn function one time for each element in the array.\n     * @param initialValue If initialValue is specified, it is used as the initial value to start\n     * the accumulation. The first call to the callbackfn function provides this value as an\n     * argument instead of an array value.\n     */\n    reduceRight(callbackfn: (previousValue: number, currentValue: number, currentIndex: number, array: Float32Array) => number): number;\n    reduceRight(callbackfn: (previousValue: number, currentValue: number, currentIndex: number, array: Float32Array) => number, initialValue: number): number;\n\n    /**\n     * Calls the specified callback function for all the elements in an array, in descending order.\n     * The return value of the callback function is the accumulated result, and is provided as an\n     * argument in the next call to the callback function.\n     * @param callbackfn A function that accepts up to four arguments. The reduceRight method calls\n     * the callbackfn function one time for each element in the array.\n     * @param initialValue If initialValue is specified, it is used as the initial value to start\n     * the accumulation. The first call to the callbackfn function provides this value as an argument\n     * instead of an array value.\n     */\n    reduceRight<U>(callbackfn: (previousValue: U, currentValue: number, currentIndex: number, array: Float32Array) => U, initialValue: U): U;\n\n    /**\n     * Reverses the elements in an Array.\n     */\n    reverse(): Float32Array;\n\n    /**\n     * Sets a value or an array of values.\n     * @param array A typed or untyped array of values to set.\n     * @param offset The index in the current array at which the values are to be written.\n     */\n    set(array: ArrayLike<number>, offset?: number): void;\n\n    /**\n     * Returns a section of an array.\n     * @param start The beginning of the specified portion of the array.\n     * @param end The end of the specified portion of the array. This is exclusive of the element at the index 'end'.\n     */\n    slice(start?: number, end?: number): Float32Array;\n\n    /**\n     * Determines whether the specified callback function returns true for any element of an array.\n     * @param predicate A function that accepts up to three arguments. The some method calls\n     * the predicate function for each element in the array until the predicate returns a value\n     * which is coercible to the Boolean value true, or until the end of the array.\n     * @param thisArg An object to which the this keyword can refer in the predicate function.\n     * If thisArg is omitted, undefined is used as the this value.\n     */\n    some(predicate: (value: number, index: number, array: Float32Array) => unknown, thisArg?: any): boolean;\n\n    /**\n     * Sorts an array.\n     * @param compareFn Function used to determine the order of the elements. It is expected to return\n     * a negative value if first argument is less than second argument, zero if they're equal and a positive\n     * value otherwise. If omitted, the elements are sorted in ascending, ASCII character order.\n     * ```ts\n     * [11,2,22,1].sort((a, b) => a - b)\n     * ```\n     */\n    sort(compareFn?: (a: number, b: number) => number): this;\n\n    /**\n     * Gets a new Float32Array view of the ArrayBuffer store for this array, referencing the elements\n     * at begin, inclusive, up to end, exclusive.\n     * @param begin The index of the beginning of the array.\n     * @param end The index of the end of the array.\n     */\n    subarray(begin?: number, end?: number): Float32Array;\n\n    /**\n     * Converts a number to a string by using the current locale.\n     */\n    toLocaleString(): string;\n\n    /**\n     * Returns a string representation of an array.\n     */\n    toString(): string;\n\n    /** Returns the primitive value of the specified object. */\n    valueOf(): Float32Array;\n\n    [index: number]: number;\n}\n\ninterface Float32ArrayConstructor {\n    readonly prototype: Float32Array;\n    new(length: number): Float32Array;\n    new(array: ArrayLike<number> | ArrayBufferLike): Float32Array;\n    new(buffer: ArrayBufferLike, byteOffset?: number, length?: number): Float32Array;\n\n    /**\n     * The size in bytes of each element in the array.\n     */\n    readonly BYTES_PER_ELEMENT: number;\n\n    /**\n     * Returns a new array from a set of elements.\n     * @param items A set of elements to include in the new array object.\n     */\n    of(...items: number[]): Float32Array;\n\n    /**\n     * Creates an array from an array-like or iterable object.\n     * @param arrayLike An array-like or iterable object to convert to an array.\n     */\n    from(arrayLike: ArrayLike<number>): Float32Array;\n\n    /**\n     * Creates an array from an array-like or iterable object.\n     * @param arrayLike An array-like or iterable object to convert to an array.\n     * @param mapfn A mapping function to call on every element of the array.\n     * @param thisArg Value of 'this' used to invoke the mapfn.\n     */\n    from<T>(arrayLike: ArrayLike<T>, mapfn: (v: T, k: number) => number, thisArg?: any): Float32Array;\n\n\n}\ndeclare var Float32Array: Float32ArrayConstructor;\n\n/**\n * A typed array of 64-bit float values. The contents are initialized to 0. If the requested\n * number of bytes could not be allocated an exception is raised.\n */\ninterface Float64Array {\n    /**\n     * The size in bytes of each element in the array.\n     */\n    readonly BYTES_PER_ELEMENT: number;\n\n    /**\n     * The ArrayBuffer instance referenced by the array.\n     */\n    readonly buffer: ArrayBufferLike;\n\n    /**\n     * The length in bytes of the array.\n     */\n    readonly byteLength: number;\n\n    /**\n     * The offset in bytes of the array.\n     */\n    readonly byteOffset: number;\n\n    /**\n     * Returns the this object after copying a section of the array identified by start and end\n     * to the same array starting at position target\n     * @param target If target is negative, it is treated as length+target where length is the\n     * length of the array.\n     * @param start If start is negative, it is treated as length+start. If end is negative, it\n     * is treated as length+end.\n     * @param end If not specified, length of the this object is used as its default value.\n     */\n    copyWithin(target: number, start: number, end?: number): this;\n\n    /**\n     * Determines whether all the members of an array satisfy the specified test.\n     * @param predicate A function that accepts up to three arguments. The every method calls\n     * the predicate function for each element in the array until the predicate returns a value\n     * which is coercible to the Boolean value false, or until the end of the array.\n     * @param thisArg An object to which the this keyword can refer in the predicate function.\n     * If thisArg is omitted, undefined is used as the this value.\n     */\n    every(predicate: (value: number, index: number, array: Float64Array) => unknown, thisArg?: any): boolean;\n\n    /**\n     * Returns the this object after filling the section identified by start and end with value\n     * @param value value to fill array section with\n     * @param start index to start filling the array at. If start is negative, it is treated as\n     * length+start where length is the length of the array.\n     * @param end index to stop filling the array at. If end is negative, it is treated as\n     * length+end.\n     */\n    fill(value: number, start?: number, end?: number): this;\n\n    /**\n     * Returns the elements of an array that meet the condition specified in a callback function.\n     * @param predicate A function that accepts up to three arguments. The filter method calls\n     * the predicate function one time for each element in the array.\n     * @param thisArg An object to which the this keyword can refer in the predicate function.\n     * If thisArg is omitted, undefined is used as the this value.\n     */\n    filter(predicate: (value: number, index: number, array: Float64Array) => any, thisArg?: any): Float64Array;\n\n    /**\n     * Returns the value of the first element in the array where predicate is true, and undefined\n     * otherwise.\n     * @param predicate find calls predicate once for each element of the array, in ascending\n     * order, until it finds one where predicate returns true. If such an element is found, find\n     * immediately returns that element value. Otherwise, find returns undefined.\n     * @param thisArg If provided, it will be used as the this value for each invocation of\n     * predicate. If it is not provided, undefined is used instead.\n     */\n    find(predicate: (value: number, index: number, obj: Float64Array) => boolean, thisArg?: any): number | undefined;\n\n    /**\n     * Returns the index of the first element in the array where predicate is true, and -1\n     * otherwise.\n     * @param predicate find calls predicate once for each element of the array, in ascending\n     * order, until it finds one where predicate returns true. If such an element is found,\n     * findIndex immediately returns that element index. Otherwise, findIndex returns -1.\n     * @param thisArg If provided, it will be used as the this value for each invocation of\n     * predicate. If it is not provided, undefined is used instead.\n     */\n    findIndex(predicate: (value: number, index: number, obj: Float64Array) => boolean, thisArg?: any): number;\n\n    /**\n     * Performs the specified action for each element in an array.\n     * @param callbackfn  A function that accepts up to three arguments. forEach calls the\n     * callbackfn function one time for each element in the array.\n     * @param thisArg  An object to which the this keyword can refer in the callbackfn function.\n     * If thisArg is omitted, undefined is used as the this value.\n     */\n    forEach(callbackfn: (value: number, index: number, array: Float64Array) => void, thisArg?: any): void;\n\n    /**\n     * Returns the index of the first occurrence of a value in an array.\n     * @param searchElement The value to locate in the array.\n     * @param fromIndex The array index at which to begin the search. If fromIndex is omitted, the\n     *  search starts at index 0.\n     */\n    indexOf(searchElement: number, fromIndex?: number): number;\n\n    /**\n     * Adds all the elements of an array separated by the specified separator string.\n     * @param separator A string used to separate one element of an array from the next in the\n     * resulting String. If omitted, the array elements are separated with a comma.\n     */\n    join(separator?: string): string;\n\n    /**\n     * Returns the index of the last occurrence of a value in an array.\n     * @param searchElement The value to locate in the array.\n     * @param fromIndex The array index at which to begin the search. If fromIndex is omitted, the\n     * search starts at index 0.\n     */\n    lastIndexOf(searchElement: number, fromIndex?: number): number;\n\n    /**\n     * The length of the array.\n     */\n    readonly length: number;\n\n    /**\n     * Calls a defined callback function on each element of an array, and returns an array that\n     * contains the results.\n     * @param callbackfn A function that accepts up to three arguments. The map method calls the\n     * callbackfn function one time for each element in the array.\n     * @param thisArg An object to which the this keyword can refer in the callbackfn function.\n     * If thisArg is omitted, undefined is used as the this value.\n     */\n    map(callbackfn: (value: number, index: number, array: Float64Array) => number, thisArg?: any): Float64Array;\n\n    /**\n     * Calls the specified callback function for all the elements in an array. The return value of\n     * the callback function is the accumulated result, and is provided as an argument in the next\n     * call to the callback function.\n     * @param callbackfn A function that accepts up to four arguments. The reduce method calls the\n     * callbackfn function one time for each element in the array.\n     * @param initialValue If initialValue is specified, it is used as the initial value to start\n     * the accumulation. The first call to the callbackfn function provides this value as an argument\n     * instead of an array value.\n     */\n    reduce(callbackfn: (previousValue: number, currentValue: number, currentIndex: number, array: Float64Array) => number): number;\n    reduce(callbackfn: (previousValue: number, currentValue: number, currentIndex: number, array: Float64Array) => number, initialValue: number): number;\n\n    /**\n     * Calls the specified callback function for all the elements in an array. The return value of\n     * the callback function is the accumulated result, and is provided as an argument in the next\n     * call to the callback function.\n     * @param callbackfn A function that accepts up to four arguments. The reduce method calls the\n     * callbackfn function one time for each element in the array.\n     * @param initialValue If initialValue is specified, it is used as the initial value to start\n     * the accumulation. The first call to the callbackfn function provides this value as an argument\n     * instead of an array value.\n     */\n    reduce<U>(callbackfn: (previousValue: U, currentValue: number, currentIndex: number, array: Float64Array) => U, initialValue: U): U;\n\n    /**\n     * Calls the specified callback function for all the elements in an array, in descending order.\n     * The return value of the callback function is the accumulated result, and is provided as an\n     * argument in the next call to the callback function.\n     * @param callbackfn A function that accepts up to four arguments. The reduceRight method calls\n     * the callbackfn function one time for each element in the array.\n     * @param initialValue If initialValue is specified, it is used as the initial value to start\n     * the accumulation. The first call to the callbackfn function provides this value as an\n     * argument instead of an array value.\n     */\n    reduceRight(callbackfn: (previousValue: number, currentValue: number, currentIndex: number, array: Float64Array) => number): number;\n    reduceRight(callbackfn: (previousValue: number, currentValue: number, currentIndex: number, array: Float64Array) => number, initialValue: number): number;\n\n    /**\n     * Calls the specified callback function for all the elements in an array, in descending order.\n     * The return value of the callback function is the accumulated result, and is provided as an\n     * argument in the next call to the callback function.\n     * @param callbackfn A function that accepts up to four arguments. The reduceRight method calls\n     * the callbackfn function one time for each element in the array.\n     * @param initialValue If initialValue is specified, it is used as the initial value to start\n     * the accumulation. The first call to the callbackfn function provides this value as an argument\n     * instead of an array value.\n     */\n    reduceRight<U>(callbackfn: (previousValue: U, currentValue: number, currentIndex: number, array: Float64Array) => U, initialValue: U): U;\n\n    /**\n     * Reverses the elements in an Array.\n     */\n    reverse(): Float64Array;\n\n    /**\n     * Sets a value or an array of values.\n     * @param array A typed or untyped array of values to set.\n     * @param offset The index in the current array at which the values are to be written.\n     */\n    set(array: ArrayLike<number>, offset?: number): void;\n\n    /**\n     * Returns a section of an array.\n     * @param start The beginning of the specified portion of the array.\n     * @param end The end of the specified portion of the array. This is exclusive of the element at the index 'end'.\n     */\n    slice(start?: number, end?: number): Float64Array;\n\n    /**\n     * Determines whether the specified callback function returns true for any element of an array.\n     * @param predicate A function that accepts up to three arguments. The some method calls\n     * the predicate function for each element in the array until the predicate returns a value\n     * which is coercible to the Boolean value true, or until the end of the array.\n     * @param thisArg An object to which the this keyword can refer in the predicate function.\n     * If thisArg is omitted, undefined is used as the this value.\n     */\n    some(predicate: (value: number, index: number, array: Float64Array) => unknown, thisArg?: any): boolean;\n\n    /**\n     * Sorts an array.\n     * @param compareFn Function used to determine the order of the elements. It is expected to return\n     * a negative value if first argument is less than second argument, zero if they're equal and a positive\n     * value otherwise. If omitted, the elements are sorted in ascending, ASCII character order.\n     * ```ts\n     * [11,2,22,1].sort((a, b) => a - b)\n     * ```\n     */\n    sort(compareFn?: (a: number, b: number) => number): this;\n\n    /**\n     * at begin, inclusive, up to end, exclusive.\n     * @param begin The index of the beginning of the array.\n     * @param end The index of the end of the array.\n     */\n    subarray(begin?: number, end?: number): Float64Array;\n\n    toString(): string;\n\n    /** Returns the primitive value of the specified object. */\n    valueOf(): Float64Array;\n\n    [index: number]: number;\n}\n\ninterface Float64ArrayConstructor {\n    readonly prototype: Float64Array;\n    new(length: number): Float64Array;\n    new(array: ArrayLike<number> | ArrayBufferLike): Float64Array;\n    new(buffer: ArrayBufferLike, byteOffset?: number, length?: number): Float64Array;\n\n    /**\n     * The size in bytes of each element in the array.\n     */\n    readonly BYTES_PER_ELEMENT: number;\n\n    /**\n     * Returns a new array from a set of elements.\n     * @param items A set of elements to include in the new array object.\n     */\n    of(...items: number[]): Float64Array;\n\n    /**\n     * Creates an array from an array-like or iterable object.\n     * @param arrayLike An array-like or iterable object to convert to an array.\n     */\n    from(arrayLike: ArrayLike<number>): Float64Array;\n\n    /**\n     * Creates an array from an array-like or iterable object.\n     * @param arrayLike An array-like or iterable object to convert to an array.\n     * @param mapfn A mapping function to call on every element of the array.\n     * @param thisArg Value of 'this' used to invoke the mapfn.\n     */\n    from<T>(arrayLike: ArrayLike<T>, mapfn: (v: T, k: number) => number, thisArg?: any): Float64Array;\n\n}\ndeclare var Float64Array: Float64ArrayConstructor;\n\n/////////////////////////////\n/// ECMAScript Internationalization API\n/////////////////////////////\n\ndeclare namespace Intl {\n    interface CollatorOptions {\n        usage?: string;\n        localeMatcher?: string;\n        numeric?: boolean;\n        caseFirst?: string;\n        sensitivity?: string;\n        ignorePunctuation?: boolean;\n    }\n\n    interface ResolvedCollatorOptions {\n        locale: string;\n        usage: string;\n        sensitivity: string;\n        ignorePunctuation: boolean;\n        collation: string;\n        caseFirst: string;\n        numeric: boolean;\n    }\n\n    interface Collator {\n        compare(x: string, y: string): number;\n        resolvedOptions(): ResolvedCollatorOptions;\n    }\n    var Collator: {\n        new(locales?: string | string[], options?: CollatorOptions): Collator;\n        (locales?: string | string[], options?: CollatorOptions): Collator;\n        supportedLocalesOf(locales: string | string[], options?: CollatorOptions): string[];\n    };\n\n    interface NumberFormatOptions {\n        localeMatcher?: string;\n        style?: string;\n        currency?: string;\n        currencyDisplay?: string;\n        currencySign?: string;\n        useGrouping?: boolean;\n        minimumIntegerDigits?: number;\n        minimumFractionDigits?: number;\n        maximumFractionDigits?: number;\n        minimumSignificantDigits?: number;\n        maximumSignificantDigits?: number;\n    }\n\n    interface ResolvedNumberFormatOptions {\n        locale: string;\n        numberingSystem: string;\n        style: string;\n        currency?: string;\n        currencyDisplay?: string;\n        minimumIntegerDigits: number;\n        minimumFractionDigits: number;\n        maximumFractionDigits: number;\n        minimumSignificantDigits?: number;\n        maximumSignificantDigits?: number;\n        useGrouping: boolean;\n    }\n\n    interface NumberFormat {\n        format(value: number): string;\n        resolvedOptions(): ResolvedNumberFormatOptions;\n    }\n    var NumberFormat: {\n        new(locales?: string | string[], options?: NumberFormatOptions): NumberFormat;\n        (locales?: string | string[], options?: NumberFormatOptions): NumberFormat;\n        supportedLocalesOf(locales: string | string[], options?: NumberFormatOptions): string[];\n    };\n\n    interface DateTimeFormatOptions {\n        localeMatcher?: \"best fit\" | \"lookup\";\n        weekday?: \"long\" | \"short\" | \"narrow\";\n        era?: \"long\" | \"short\" | \"narrow\";\n        year?: \"numeric\" | \"2-digit\";\n        month?: \"numeric\" | \"2-digit\" | \"long\" | \"short\" | \"narrow\";\n        day?: \"numeric\" | \"2-digit\";\n        hour?: \"numeric\" | \"2-digit\";\n        minute?: \"numeric\" | \"2-digit\";\n        second?: \"numeric\" | \"2-digit\";\n        timeZoneName?: \"long\" | \"short\";\n        formatMatcher?: \"best fit\" | \"basic\";\n        hour12?: boolean;\n        timeZone?: string;\n    }\n\n    interface ResolvedDateTimeFormatOptions {\n        locale: string;\n        calendar: string;\n        numberingSystem: string;\n        timeZone: string;\n        hour12?: boolean;\n        weekday?: string;\n        era?: string;\n        year?: string;\n        month?: string;\n        day?: string;\n        hour?: string;\n        minute?: string;\n        second?: string;\n        timeZoneName?: string;\n    }\n\n    interface DateTimeFormat {\n        format(date?: Date | number): string;\n        resolvedOptions(): ResolvedDateTimeFormatOptions;\n    }\n    var DateTimeFormat: {\n        new(locales?: string | string[], options?: DateTimeFormatOptions): DateTimeFormat;\n        (locales?: string | string[], options?: DateTimeFormatOptions): DateTimeFormat;\n        supportedLocalesOf(locales: string | string[], options?: DateTimeFormatOptions): string[];\n    };\n}\n\ninterface String {\n    /**\n     * Determines whether two strings are equivalent in the current or specified locale.\n     * @param that String to compare to target string\n     * @param locales A locale string or array of locale strings that contain one or more language or locale tags. If you include more than one locale string, list them in descending order of priority so that the first entry is the preferred locale. If you omit this parameter, the default locale of the JavaScript runtime is used. This parameter must conform to BCP 47 standards; see the Intl.Collator object for details.\n     * @param options An object that contains one or more properties that specify comparison options. see the Intl.Collator object for details.\n     */\n    localeCompare(that: string, locales?: string | string[], options?: Intl.CollatorOptions): number;\n}\n\ninterface Number {\n    /**\n     * Converts a number to a string by using the current or specified locale.\n     * @param locales A locale string or array of locale strings that contain one or more language or locale tags. If you include more than one locale string, list them in descending order of priority so that the first entry is the preferred locale. If you omit this parameter, the default locale of the JavaScript runtime is used.\n     * @param options An object that contains one or more properties that specify comparison options.\n     */\n    toLocaleString(locales?: string | string[], options?: Intl.NumberFormatOptions): string;\n}\n\ninterface Date {\n    /**\n     * Converts a date and time to a string by using the current or specified locale.\n     * @param locales A locale string or array of locale strings that contain one or more language or locale tags. If you include more than one locale string, list them in descending order of priority so that the first entry is the preferred locale. If you omit this parameter, the default locale of the JavaScript runtime is used.\n     * @param options An object that contains one or more properties that specify comparison options.\n     */\n    toLocaleString(locales?: string | string[], options?: Intl.DateTimeFormatOptions): string;\n    /**\n     * Converts a date to a string by using the current or specified locale.\n     * @param locales A locale string or array of locale strings that contain one or more language or locale tags. If you include more than one locale string, list them in descending order of priority so that the first entry is the preferred locale. If you omit this parameter, the default locale of the JavaScript runtime is used.\n     * @param options An object that contains one or more properties that specify comparison options.\n     */\n    toLocaleDateString(locales?: string | string[], options?: Intl.DateTimeFormatOptions): string;\n\n    /**\n     * Converts a time to a string by using the current or specified locale.\n     * @param locales A locale string or array of locale strings that contain one or more language or locale tags. If you include more than one locale string, list them in descending order of priority so that the first entry is the preferred locale. If you omit this parameter, the default locale of the JavaScript runtime is used.\n     * @param options An object that contains one or more properties that specify comparison options.\n     */\n    toLocaleTimeString(locales?: string | string[], options?: Intl.DateTimeFormatOptions): string;\n}\n","lib.es6.d.ts":'/*! *****************************************************************************\nCopyright (c) Microsoft Corporation. All rights reserved.\nLicensed under the Apache License, Version 2.0 (the "License"); you may not use\nthis file except in compliance with the License. You may obtain a copy of the\nLicense at http://www.apache.org/licenses/LICENSE-2.0\n\nTHIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\nKIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED\nWARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,\nMERCHANTABLITY OR NON-INFRINGEMENT.\n\nSee the Apache Version 2.0 License for specific language governing permissions\nand limitations under the License.\n***************************************************************************** */\n\n\n\n/// <reference no-default-lib="true"/>\n\n\n/// <reference lib="es2015" />\n/// <reference lib="dom" />\n/// <reference lib="dom.iterable" />\n/// <reference lib="webworker.importscripts" />\n/// <reference lib="scripthost" />\n',"lib.esnext.d.ts":'/*! *****************************************************************************\nCopyright (c) Microsoft Corporation. All rights reserved.\nLicensed under the Apache License, Version 2.0 (the "License"); you may not use\nthis file except in compliance with the License. You may obtain a copy of the\nLicense at http://www.apache.org/licenses/LICENSE-2.0\n\nTHIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\nKIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED\nWARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,\nMERCHANTABLITY OR NON-INFRINGEMENT.\n\nSee the Apache Version 2.0 License for specific language governing permissions\nand limitations under the License.\n***************************************************************************** */\n\n\n\n/// <reference no-default-lib="true"/>\n\n\n/// <reference lib="es2021" />\n/// <reference lib="esnext.intl" />\n',"lib.esnext.full.d.ts":'/*! *****************************************************************************\nCopyright (c) Microsoft Corporation. All rights reserved.\nLicensed under the Apache License, Version 2.0 (the "License"); you may not use\nthis file except in compliance with the License. You may obtain a copy of the\nLicense at http://www.apache.org/licenses/LICENSE-2.0\n\nTHIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\nKIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED\nWARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,\nMERCHANTABLITY OR NON-INFRINGEMENT.\n\nSee the Apache Version 2.0 License for specific language governing permissions\nand limitations under the License.\n***************************************************************************** */\n\n\n\n/// <reference no-default-lib="true"/>\n\n\n/// <reference lib="esnext" />\n/// <reference lib="dom" />\n/// <reference lib="webworker.importscripts" />\n/// <reference lib="scripthost" />\n/// <reference lib="dom.iterable" />',"lib.esnext.intl.d.ts":'/*! *****************************************************************************\nCopyright (c) Microsoft Corporation. All rights reserved.\nLicensed under the Apache License, Version 2.0 (the "License"); you may not use\nthis file except in compliance with the License. You may obtain a copy of the\nLicense at http://www.apache.org/licenses/LICENSE-2.0\n\nTHIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\nKIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED\nWARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,\nMERCHANTABLITY OR NON-INFRINGEMENT.\n\nSee the Apache Version 2.0 License for specific language governing permissions\nand limitations under the License.\n***************************************************************************** */\n\n\n\n/// <reference no-default-lib="true"/>\n\n\ndeclare namespace Intl {\n    type NumberFormatPartTypes = "compact" | "currency" | "decimal" | "exponentInteger" | "exponentMinusSign" | "exponentSeparator" | "fraction" | "group" | "infinity" | "integer" | "literal" | "minusSign" | "nan" | "plusSign" | "percentSign" | "unit" | "unknown";\n\n    interface NumberFormatPart {\n        type: NumberFormatPartTypes;\n        value: string;\n    }\n\n    interface NumberFormat {\n        formatToParts(number?: number): NumberFormatPart[];\n    }\n}\n',"lib.esnext.promise.d.ts":'/*! *****************************************************************************\nCopyright (c) Microsoft Corporation. All rights reserved.\nLicensed under the Apache License, Version 2.0 (the "License"); you may not use\nthis file except in compliance with the License. You may obtain a copy of the\nLicense at http://www.apache.org/licenses/LICENSE-2.0\n\nTHIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\nKIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED\nWARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,\nMERCHANTABLITY OR NON-INFRINGEMENT.\n\nSee the Apache Version 2.0 License for specific language governing permissions\nand limitations under the License.\n***************************************************************************** */\n\n\n\n/// <reference no-default-lib="true"/>\n\n\ninterface AggregateError extends Error {\n    errors: any[]\n}\n\ninterface AggregateErrorConstructor {\n    new(errors: Iterable<any>, message?: string): AggregateError;\n    (errors: Iterable<any>, message?: string): AggregateError;\n    readonly prototype: AggregateError;\n}\n\ndeclare var AggregateError: AggregateErrorConstructor;\n\n/**\n * Represents the completion of an asynchronous operation\n */\ninterface PromiseConstructor {\n    /**\n     * The any function returns a promise that is fulfilled by the first given promise to be fulfilled, or rejected with an AggregateError containing an array of rejection reasons if all of the given promises are rejected. It resolves all elements of the passed iterable to promises as it runs this algorithm.\n     * @param values An array or iterable of Promises.\n     * @returns A new Promise.\n     */\n    any<T>(values: (T | PromiseLike<T>)[] | Iterable<T | PromiseLike<T>>): Promise<T>\n}\n',"lib.esnext.string.d.ts":'/*! *****************************************************************************\nCopyright (c) Microsoft Corporation. All rights reserved.\nLicensed under the Apache License, Version 2.0 (the "License"); you may not use\nthis file except in compliance with the License. You may obtain a copy of the\nLicense at http://www.apache.org/licenses/LICENSE-2.0\n\nTHIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\nKIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED\nWARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,\nMERCHANTABLITY OR NON-INFRINGEMENT.\n\nSee the Apache Version 2.0 License for specific language governing permissions\nand limitations under the License.\n***************************************************************************** */\n\n\n\n/// <reference no-default-lib="true"/>\n\n\ninterface String {\n    /**\n     * Replace all instances of a substring in a string, using a regular expression or search string.\n     * @param searchValue A string to search for.\n     * @param replaceValue A string containing the text to replace for every successful match of searchValue in this string.\n     */\n    replaceAll(searchValue: string | RegExp, replaceValue: string): string;\n\n    /**\n     * Replace all instances of a substring in a string, using a regular expression or search string.\n     * @param searchValue A string to search for.\n     * @param replacer A function that returns the replacement text.\n     */\n    replaceAll(searchValue: string | RegExp, replacer: (substring: string, ...args: any[]) => string): string;\n}\n',"lib.esnext.weakref.d.ts":'/*! *****************************************************************************\nCopyright (c) Microsoft Corporation. All rights reserved.\nLicensed under the Apache License, Version 2.0 (the "License"); you may not use\nthis file except in compliance with the License. You may obtain a copy of the\nLicense at http://www.apache.org/licenses/LICENSE-2.0\n\nTHIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\nKIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED\nWARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,\nMERCHANTABLITY OR NON-INFRINGEMENT.\n\nSee the Apache Version 2.0 License for specific language governing permissions\nand limitations under the License.\n***************************************************************************** */\n\n\n\n/// <reference no-default-lib="true"/>\n\n\ninterface WeakRef<T extends object> {\n    readonly [Symbol.toStringTag]: "WeakRef";\n\n    /**\n     * Returns the WeakRef instance\'s target object, or undefined if the target object has been\n     * reclaimed.\n     */\n    deref(): T | undefined;\n}\n\ninterface WeakRefConstructor {\n    readonly prototype: WeakRef<any>;\n\n    /**\n     * Creates a WeakRef instance for the given target object.\n     * @param target The target object for the WeakRef instance.\n     */\n    new<T extends object>(target?: T): WeakRef<T>;\n}\n\ndeclare var WeakRef: WeakRefConstructor;\n\ninterface FinalizationRegistry {\n    readonly [Symbol.toStringTag]: "FinalizationRegistry";\n\n    /**\n     * Registers an object with the registry.\n     * @param target The target object to register.\n     * @param heldValue The value to pass to the finalizer for this object. This cannot be the\n     * target object.\n     * @param unregisterToken The token to pass to the unregister method to unregister the target\n     * object. If provided (and not undefined), this must be an object. If not provided, the target\n     * cannot be unregistered.\n     */\n    register(target: object, heldValue: any, unregisterToken?: object): void;\n\n    /**\n     * Unregisters an object from the registry.\n     * @param unregisterToken The token that was used as the unregisterToken argument when calling\n     * register to register the target object.\n     */\n    unregister(unregisterToken: object): void;\n}\n\ninterface FinalizationRegistryConstructor {\n    readonly prototype: FinalizationRegistry;\n\n    /**\n     * Creates a finalization registry with an associated cleanup callback\n     * @param cleanupCallback The callback to call after an object in the registry has been reclaimed.\n     */\n    new(cleanupCallback: (heldValue: any) => void): FinalizationRegistry;\n}\n\ndeclare var FinalizationRegistry: FinalizationRegistryConstructor;\n',"lib.scripthost.d.ts":'/*! *****************************************************************************\nCopyright (c) Microsoft Corporation. All rights reserved.\nLicensed under the Apache License, Version 2.0 (the "License"); you may not use\nthis file except in compliance with the License. You may obtain a copy of the\nLicense at http://www.apache.org/licenses/LICENSE-2.0\n\nTHIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\nKIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED\nWARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,\nMERCHANTABLITY OR NON-INFRINGEMENT.\n\nSee the Apache Version 2.0 License for specific language governing permissions\nand limitations under the License.\n***************************************************************************** */\n\n\n\n/// <reference no-default-lib="true"/>\n\n\n\n\n/////////////////////////////\n/// Windows Script Host APIS\n/////////////////////////////\n\n\ninterface ActiveXObject {\n    new (s: string): any;\n}\ndeclare var ActiveXObject: ActiveXObject;\n\ninterface ITextWriter {\n    Write(s: string): void;\n    WriteLine(s: string): void;\n    Close(): void;\n}\n\ninterface TextStreamBase {\n    /**\n     * The column number of the current character position in an input stream.\n     */\n    Column: number;\n\n    /**\n     * The current line number in an input stream.\n     */\n    Line: number;\n\n    /**\n     * Closes a text stream.\n     * It is not necessary to close standard streams; they close automatically when the process ends. If\n     * you close a standard stream, be aware that any other pointers to that standard stream become invalid.\n     */\n    Close(): void;\n}\n\ninterface TextStreamWriter extends TextStreamBase {\n    /**\n     * Sends a string to an output stream.\n     */\n    Write(s: string): void;\n\n    /**\n     * Sends a specified number of blank lines (newline characters) to an output stream.\n     */\n    WriteBlankLines(intLines: number): void;\n\n    /**\n     * Sends a string followed by a newline character to an output stream.\n     */\n    WriteLine(s: string): void;\n}\n\ninterface TextStreamReader extends TextStreamBase {\n    /**\n     * Returns a specified number of characters from an input stream, starting at the current pointer position.\n     * Does not return until the ENTER key is pressed.\n     * Can only be used on a stream in reading mode; causes an error in writing or appending mode.\n     */\n    Read(characters: number): string;\n\n    /**\n     * Returns all characters from an input stream.\n     * Can only be used on a stream in reading mode; causes an error in writing or appending mode.\n     */\n    ReadAll(): string;\n\n    /**\n     * Returns an entire line from an input stream.\n     * Although this method extracts the newline character, it does not add it to the returned string.\n     * Can only be used on a stream in reading mode; causes an error in writing or appending mode.\n     */\n    ReadLine(): string;\n\n    /**\n     * Skips a specified number of characters when reading from an input text stream.\n     * Can only be used on a stream in reading mode; causes an error in writing or appending mode.\n     * @param characters Positive number of characters to skip forward. (Backward skipping is not supported.)\n     */\n    Skip(characters: number): void;\n\n    /**\n     * Skips the next line when reading from an input text stream.\n     * Can only be used on a stream in reading mode, not writing or appending mode.\n     */\n    SkipLine(): void;\n\n    /**\n     * Indicates whether the stream pointer position is at the end of a line.\n     */\n    AtEndOfLine: boolean;\n\n    /**\n     * Indicates whether the stream pointer position is at the end of a stream.\n     */\n    AtEndOfStream: boolean;\n}\n\ndeclare var WScript: {\n    /**\n     * Outputs text to either a message box (under WScript.exe) or the command console window followed by\n     * a newline (under CScript.exe).\n     */\n    Echo(s: any): void;\n\n    /**\n     * Exposes the write-only error output stream for the current script.\n     * Can be accessed only while using CScript.exe.\n     */\n    StdErr: TextStreamWriter;\n\n    /**\n     * Exposes the write-only output stream for the current script.\n     * Can be accessed only while using CScript.exe.\n     */\n    StdOut: TextStreamWriter;\n    Arguments: { length: number; Item(n: number): string; };\n\n    /**\n     *  The full path of the currently running script.\n     */\n    ScriptFullName: string;\n\n    /**\n     * Forces the script to stop immediately, with an optional exit code.\n     */\n    Quit(exitCode?: number): number;\n\n    /**\n     * The Windows Script Host build version number.\n     */\n    BuildVersion: number;\n\n    /**\n     * Fully qualified path of the host executable.\n     */\n    FullName: string;\n\n    /**\n     * Gets/sets the script mode - interactive(true) or batch(false).\n     */\n    Interactive: boolean;\n\n    /**\n     * The name of the host executable (WScript.exe or CScript.exe).\n     */\n    Name: string;\n\n    /**\n     * Path of the directory containing the host executable.\n     */\n    Path: string;\n\n    /**\n     * The filename of the currently running script.\n     */\n    ScriptName: string;\n\n    /**\n     * Exposes the read-only input stream for the current script.\n     * Can be accessed only while using CScript.exe.\n     */\n    StdIn: TextStreamReader;\n\n    /**\n     * Windows Script Host version\n     */\n    Version: string;\n\n    /**\n     * Connects a COM object\'s event sources to functions named with a given prefix, in the form prefix_event.\n     */\n    ConnectObject(objEventSource: any, strPrefix: string): void;\n\n    /**\n     * Creates a COM object.\n     * @param strProgiID\n     * @param strPrefix Function names in the form prefix_event will be bound to this object\'s COM events.\n     */\n    CreateObject(strProgID: string, strPrefix?: string): any;\n\n    /**\n     * Disconnects a COM object from its event sources.\n     */\n    DisconnectObject(obj: any): void;\n\n    /**\n     * Retrieves an existing object with the specified ProgID from memory, or creates a new one from a file.\n     * @param strPathname Fully qualified path to the file containing the object persisted to disk.\n     *                       For objects in memory, pass a zero-length string.\n     * @param strProgID\n     * @param strPrefix Function names in the form prefix_event will be bound to this object\'s COM events.\n     */\n    GetObject(strPathname: string, strProgID?: string, strPrefix?: string): any;\n\n    /**\n     * Suspends script execution for a specified length of time, then continues execution.\n     * @param intTime Interval (in milliseconds) to suspend script execution.\n     */\n    Sleep(intTime: number): void;\n};\n\n/**\n * WSH is an alias for WScript under Windows Script Host\n */\ndeclare var WSH: typeof WScript;\n\n/**\n * Represents an Automation SAFEARRAY\n */\ndeclare class SafeArray<T = any> {\n    private constructor();\n    private SafeArray_typekey: SafeArray<T>;\n}\n\n/**\n * Allows enumerating over a COM collection, which may not have indexed item access.\n */\ninterface Enumerator<T = any> {\n    /**\n     * Returns true if the current item is the last one in the collection, or the collection is empty,\n     * or the current item is undefined.\n     */\n    atEnd(): boolean;\n\n    /**\n     * Returns the current item in the collection\n     */\n    item(): T;\n\n    /**\n     * Resets the current item in the collection to the first item. If there are no items in the collection,\n     * the current item is set to undefined.\n     */\n    moveFirst(): void;\n\n    /**\n     * Moves the current item to the next item in the collection. If the enumerator is at the end of\n     * the collection or the collection is empty, the current item is set to undefined.\n     */\n    moveNext(): void;\n}\n\ninterface EnumeratorConstructor {\n    new <T = any>(safearray: SafeArray<T>): Enumerator<T>;\n    new <T = any>(collection: { Item(index: any): T }): Enumerator<T>;\n    new <T = any>(collection: any): Enumerator<T>;\n}\n\ndeclare var Enumerator: EnumeratorConstructor;\n\n/**\n * Enables reading from a COM safe array, which might have an alternate lower bound, or multiple dimensions.\n */\ninterface VBArray<T = any> {\n    /**\n     * Returns the number of dimensions (1-based).\n     */\n    dimensions(): number;\n\n    /**\n     * Takes an index for each dimension in the array, and returns the item at the corresponding location.\n     */\n    getItem(dimension1Index: number, ...dimensionNIndexes: number[]): T;\n\n    /**\n     * Returns the smallest available index for a given dimension.\n     * @param dimension 1-based dimension (defaults to 1)\n     */\n    lbound(dimension?: number): number;\n\n    /**\n     * Returns the largest available index for a given dimension.\n     * @param dimension 1-based dimension (defaults to 1)\n     */\n    ubound(dimension?: number): number;\n\n    /**\n     * Returns a Javascript array with all the elements in the VBArray. If there are multiple dimensions,\n     * each successive dimension is appended to the end of the array.\n     * Example: [[1,2,3],[4,5,6]] becomes [1,2,3,4,5,6]\n     */\n    toArray(): T[];\n}\n\ninterface VBArrayConstructor {\n    new <T = any>(safeArray: SafeArray<T>): VBArray<T>;\n}\n\ndeclare var VBArray: VBArrayConstructor;\n\n/**\n * Automation date (VT_DATE)\n */\ndeclare class VarDate {\n    private constructor();\n    private VarDate_typekey: VarDate;\n}\n\ninterface DateConstructor {\n    new (vd: VarDate): Date;\n}\n\ninterface Date {\n    getVarDate: () => VarDate;\n}\n',"lib.webworker.d.ts":'/*! *****************************************************************************\nCopyright (c) Microsoft Corporation. All rights reserved.\nLicensed under the Apache License, Version 2.0 (the "License"); you may not use\nthis file except in compliance with the License. You may obtain a copy of the\nLicense at http://www.apache.org/licenses/LICENSE-2.0\n\nTHIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\nKIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED\nWARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,\nMERCHANTABLITY OR NON-INFRINGEMENT.\n\nSee the Apache Version 2.0 License for specific language governing permissions\nand limitations under the License.\n***************************************************************************** */\n\n\n\n/// <reference no-default-lib="true"/>\n\n\n/////////////////////////////\n/// Worker APIs\n/////////////////////////////\n\ninterface AddEventListenerOptions extends EventListenerOptions {\n    once?: boolean;\n    passive?: boolean;\n}\n\ninterface AesCbcParams extends Algorithm {\n    iv: Int8Array | Int16Array | Int32Array | Uint8Array | Uint16Array | Uint32Array | Uint8ClampedArray | Float32Array | Float64Array | DataView | ArrayBuffer;\n}\n\ninterface AesCtrParams extends Algorithm {\n    counter: Int8Array | Int16Array | Int32Array | Uint8Array | Uint16Array | Uint32Array | Uint8ClampedArray | Float32Array | Float64Array | DataView | ArrayBuffer;\n    length: number;\n}\n\ninterface AesDerivedKeyParams extends Algorithm {\n    length: number;\n}\n\ninterface AesGcmParams extends Algorithm {\n    additionalData?: Int8Array | Int16Array | Int32Array | Uint8Array | Uint16Array | Uint32Array | Uint8ClampedArray | Float32Array | Float64Array | DataView | ArrayBuffer;\n    iv: Int8Array | Int16Array | Int32Array | Uint8Array | Uint16Array | Uint32Array | Uint8ClampedArray | Float32Array | Float64Array | DataView | ArrayBuffer;\n    tagLength?: number;\n}\n\ninterface AesKeyAlgorithm extends KeyAlgorithm {\n    length: number;\n}\n\ninterface AesKeyGenParams extends Algorithm {\n    length: number;\n}\n\ninterface Algorithm {\n    name: string;\n}\n\ninterface BlobPropertyBag {\n    endings?: EndingType;\n    type?: string;\n}\n\ninterface CacheQueryOptions {\n    ignoreMethod?: boolean;\n    ignoreSearch?: boolean;\n    ignoreVary?: boolean;\n}\n\ninterface CanvasRenderingContext2DSettings {\n    alpha?: boolean;\n    desynchronized?: boolean;\n}\n\ninterface ClientQueryOptions {\n    includeUncontrolled?: boolean;\n    type?: ClientTypes;\n}\n\ninterface CloseEventInit extends EventInit {\n    code?: number;\n    reason?: string;\n    wasClean?: boolean;\n}\n\ninterface CryptoKeyPair {\n    privateKey?: CryptoKey;\n    publicKey?: CryptoKey;\n}\n\ninterface CustomEventInit<T = any> extends EventInit {\n    detail?: T;\n}\n\ninterface DOMMatrix2DInit {\n    a?: number;\n    b?: number;\n    c?: number;\n    d?: number;\n    e?: number;\n    f?: number;\n    m11?: number;\n    m12?: number;\n    m21?: number;\n    m22?: number;\n    m41?: number;\n    m42?: number;\n}\n\ninterface DOMMatrixInit extends DOMMatrix2DInit {\n    is2D?: boolean;\n    m13?: number;\n    m14?: number;\n    m23?: number;\n    m24?: number;\n    m31?: number;\n    m32?: number;\n    m33?: number;\n    m34?: number;\n    m43?: number;\n    m44?: number;\n}\n\ninterface DOMPointInit {\n    w?: number;\n    x?: number;\n    y?: number;\n    z?: number;\n}\n\ninterface DOMQuadInit {\n    p1?: DOMPointInit;\n    p2?: DOMPointInit;\n    p3?: DOMPointInit;\n    p4?: DOMPointInit;\n}\n\ninterface DOMRectInit {\n    height?: number;\n    width?: number;\n    x?: number;\n    y?: number;\n}\n\ninterface DevicePermissionDescriptor extends PermissionDescriptor {\n    deviceId?: string;\n    name: "camera" | "microphone" | "speaker";\n}\n\ninterface EcKeyGenParams extends Algorithm {\n    namedCurve: NamedCurve;\n}\n\ninterface EcKeyImportParams extends Algorithm {\n    namedCurve: NamedCurve;\n}\n\ninterface EcdhKeyDeriveParams extends Algorithm {\n    public: CryptoKey;\n}\n\ninterface EcdsaParams extends Algorithm {\n    hash: HashAlgorithmIdentifier;\n}\n\ninterface ErrorEventInit extends EventInit {\n    colno?: number;\n    error?: any;\n    filename?: string;\n    lineno?: number;\n    message?: string;\n}\n\ninterface EventInit {\n    bubbles?: boolean;\n    cancelable?: boolean;\n    composed?: boolean;\n}\n\ninterface EventListenerOptions {\n    capture?: boolean;\n}\n\ninterface EventSourceInit {\n    withCredentials?: boolean;\n}\n\ninterface ExtendableEventInit extends EventInit {\n}\n\ninterface ExtendableMessageEventInit extends ExtendableEventInit {\n    data?: any;\n    lastEventId?: string;\n    origin?: string;\n    ports?: MessagePort[];\n    source?: Client | ServiceWorker | MessagePort | null;\n}\n\ninterface FetchEventInit extends ExtendableEventInit {\n    clientId?: string;\n    preloadResponse?: Promise<any>;\n    replacesClientId?: string;\n    request: Request;\n    resultingClientId?: string;\n}\n\ninterface FilePropertyBag extends BlobPropertyBag {\n    lastModified?: number;\n}\n\ninterface GetNotificationOptions {\n    tag?: string;\n}\n\ninterface HkdfParams extends Algorithm {\n    hash: HashAlgorithmIdentifier;\n    info: Int8Array | Int16Array | Int32Array | Uint8Array | Uint16Array | Uint32Array | Uint8ClampedArray | Float32Array | Float64Array | DataView | ArrayBuffer;\n    salt: Int8Array | Int16Array | Int32Array | Uint8Array | Uint16Array | Uint32Array | Uint8ClampedArray | Float32Array | Float64Array | DataView | ArrayBuffer;\n}\n\ninterface HmacImportParams extends Algorithm {\n    hash: HashAlgorithmIdentifier;\n    length?: number;\n}\n\ninterface HmacKeyGenParams extends Algorithm {\n    hash: HashAlgorithmIdentifier;\n    length?: number;\n}\n\ninterface IDBIndexParameters {\n    multiEntry?: boolean;\n    unique?: boolean;\n}\n\ninterface IDBObjectStoreParameters {\n    autoIncrement?: boolean;\n    keyPath?: string | string[] | null;\n}\n\ninterface IDBVersionChangeEventInit extends EventInit {\n    newVersion?: number | null;\n    oldVersion?: number;\n}\n\ninterface ImageBitmapOptions {\n    colorSpaceConversion?: ColorSpaceConversion;\n    imageOrientation?: ImageOrientation;\n    premultiplyAlpha?: PremultiplyAlpha;\n    resizeHeight?: number;\n    resizeQuality?: ResizeQuality;\n    resizeWidth?: number;\n}\n\ninterface ImageBitmapRenderingContextSettings {\n    alpha?: boolean;\n}\n\ninterface ImageEncodeOptions {\n    quality?: number;\n    type?: string;\n}\n\ninterface ImportMeta {\n    url: string;\n}\n\ninterface JsonWebKey {\n    alg?: string;\n    crv?: string;\n    d?: string;\n    dp?: string;\n    dq?: string;\n    e?: string;\n    ext?: boolean;\n    k?: string;\n    key_ops?: string[];\n    kty?: string;\n    n?: string;\n    oth?: RsaOtherPrimesInfo[];\n    p?: string;\n    q?: string;\n    qi?: string;\n    use?: string;\n    x?: string;\n    y?: string;\n}\n\ninterface KeyAlgorithm {\n    name: string;\n}\n\ninterface MessageEventInit<T = any> extends EventInit {\n    data?: T;\n    lastEventId?: string;\n    origin?: string;\n    ports?: MessagePort[];\n    source?: MessageEventSource | null;\n}\n\ninterface MidiPermissionDescriptor extends PermissionDescriptor {\n    name: "midi";\n    sysex?: boolean;\n}\n\ninterface MultiCacheQueryOptions extends CacheQueryOptions {\n    cacheName?: string;\n}\n\ninterface NavigationPreloadState {\n    enabled?: boolean;\n    headerValue?: string;\n}\n\ninterface NotificationAction {\n    action: string;\n    icon?: string;\n    title: string;\n}\n\ninterface NotificationEventInit extends ExtendableEventInit {\n    action?: string;\n    notification: Notification;\n}\n\ninterface NotificationOptions {\n    actions?: NotificationAction[];\n    badge?: string;\n    body?: string;\n    data?: any;\n    dir?: NotificationDirection;\n    icon?: string;\n    image?: string;\n    lang?: string;\n    renotify?: boolean;\n    requireInteraction?: boolean;\n    silent?: boolean;\n    tag?: string;\n    timestamp?: number;\n    vibrate?: VibratePattern;\n}\n\ninterface Pbkdf2Params extends Algorithm {\n    hash: HashAlgorithmIdentifier;\n    iterations: number;\n    salt: Int8Array | Int16Array | Int32Array | Uint8Array | Uint16Array | Uint32Array | Uint8ClampedArray | Float32Array | Float64Array | DataView | ArrayBuffer;\n}\n\ninterface PerformanceObserverInit {\n    buffered?: boolean;\n    entryTypes?: string[];\n    type?: string;\n}\n\ninterface PermissionDescriptor {\n    name: PermissionName;\n}\n\ninterface PostMessageOptions {\n    transfer?: any[];\n}\n\ninterface ProgressEventInit extends EventInit {\n    lengthComputable?: boolean;\n    loaded?: number;\n    total?: number;\n}\n\ninterface PromiseRejectionEventInit extends EventInit {\n    promise: Promise<any>;\n    reason?: any;\n}\n\ninterface PushEventInit extends ExtendableEventInit {\n    data?: PushMessageDataInit;\n}\n\ninterface PushPermissionDescriptor extends PermissionDescriptor {\n    name: "push";\n    userVisibleOnly?: boolean;\n}\n\ninterface PushSubscriptionJSON {\n    endpoint?: string;\n    expirationTime?: number | null;\n    keys?: Record<string, string>;\n}\n\ninterface PushSubscriptionOptionsInit {\n    applicationServerKey?: BufferSource | string | null;\n    userVisibleOnly?: boolean;\n}\n\ninterface QueuingStrategy<T = any> {\n    highWaterMark?: number;\n    size?: QueuingStrategySize<T>;\n}\n\ninterface QueuingStrategyInit {\n    /**\n     * Creates a new ByteLengthQueuingStrategy with the provided high water mark.\n     *\n     * Note that the provided high water mark will not be validated ahead of time. Instead, if it is negative, NaN, or not a number, the resulting ByteLengthQueuingStrategy will cause the corresponding stream constructor to throw.\n     */\n    highWaterMark: number;\n}\n\ninterface ReadableStreamDefaultReadDoneResult {\n    done: true;\n    value?: undefined;\n}\n\ninterface ReadableStreamDefaultReadValueResult<T> {\n    done: false;\n    value: T;\n}\n\ninterface ReadableWritablePair<R = any, W = any> {\n    readable: ReadableStream<R>;\n    /**\n     * Provides a convenient, chainable way of piping this readable stream through a transform stream (or any other { writable, readable } pair). It simply pipes the stream into the writable side of the supplied pair, and returns the readable side for further use.\n     *\n     * Piping a stream will lock it for the duration of the pipe, preventing any other consumer from acquiring a reader.\n     */\n    writable: WritableStream<W>;\n}\n\ninterface RegistrationOptions {\n    scope?: string;\n    type?: WorkerType;\n    updateViaCache?: ServiceWorkerUpdateViaCache;\n}\n\ninterface RequestInit {\n    /**\n     * A BodyInit object or null to set request\'s body.\n     */\n    body?: BodyInit | null;\n    /**\n     * A string indicating how the request will interact with the browser\'s cache to set request\'s cache.\n     */\n    cache?: RequestCache;\n    /**\n     * A string indicating whether credentials will be sent with the request always, never, or only when sent to a same-origin URL. Sets request\'s credentials.\n     */\n    credentials?: RequestCredentials;\n    /**\n     * A Headers object, an object literal, or an array of two-item arrays to set request\'s headers.\n     */\n    headers?: HeadersInit;\n    /**\n     * A cryptographic hash of the resource to be fetched by request. Sets request\'s integrity.\n     */\n    integrity?: string;\n    /**\n     * A boolean to set request\'s keepalive.\n     */\n    keepalive?: boolean;\n    /**\n     * A string to set request\'s method.\n     */\n    method?: string;\n    /**\n     * A string to indicate whether the request will use CORS, or will be restricted to same-origin URLs. Sets request\'s mode.\n     */\n    mode?: RequestMode;\n    /**\n     * A string indicating whether request follows redirects, results in an error upon encountering a redirect, or returns the redirect (in an opaque fashion). Sets request\'s redirect.\n     */\n    redirect?: RequestRedirect;\n    /**\n     * A string whose value is a same-origin URL, "about:client", or the empty string, to set request\'s referrer.\n     */\n    referrer?: string;\n    /**\n     * A referrer policy to set request\'s referrerPolicy.\n     */\n    referrerPolicy?: ReferrerPolicy;\n    /**\n     * An AbortSignal to set request\'s signal.\n     */\n    signal?: AbortSignal | null;\n    /**\n     * Can only be null. Used to disassociate request from any Window.\n     */\n    window?: any;\n}\n\ninterface ResponseInit {\n    headers?: HeadersInit;\n    status?: number;\n    statusText?: string;\n}\n\ninterface RsaHashedImportParams extends Algorithm {\n    hash: HashAlgorithmIdentifier;\n}\n\ninterface RsaHashedKeyGenParams extends RsaKeyGenParams {\n    hash: HashAlgorithmIdentifier;\n}\n\ninterface RsaKeyGenParams extends Algorithm {\n    modulusLength: number;\n    publicExponent: BigInteger;\n}\n\ninterface RsaOaepParams extends Algorithm {\n    label?: Int8Array | Int16Array | Int32Array | Uint8Array | Uint16Array | Uint32Array | Uint8ClampedArray | Float32Array | Float64Array | DataView | ArrayBuffer;\n}\n\ninterface RsaOtherPrimesInfo {\n    d?: string;\n    r?: string;\n    t?: string;\n}\n\ninterface RsaPssParams extends Algorithm {\n    saltLength: number;\n}\n\ninterface StorageEstimate {\n    quota?: number;\n    usage?: number;\n}\n\ninterface StreamPipeOptions {\n    preventAbort?: boolean;\n    preventCancel?: boolean;\n    /**\n     * Pipes this readable stream to a given writable stream destination. The way in which the piping process behaves under various error conditions can be customized with a number of passed options. It returns a promise that fulfills when the piping process completes successfully, or rejects if any errors were encountered.\n     *\n     * Piping a stream will lock it for the duration of the pipe, preventing any other consumer from acquiring a reader.\n     *\n     * Errors and closures of the source and destination streams propagate as follows:\n     *\n     * An error in this source readable stream will abort destination, unless preventAbort is truthy. The returned promise will be rejected with the source\'s error, or with any error that occurs during aborting the destination.\n     *\n     * An error in destination will cancel this source readable stream, unless preventCancel is truthy. The returned promise will be rejected with the destination\'s error, or with any error that occurs during canceling the source.\n     *\n     * When this source readable stream closes, destination will be closed, unless preventClose is truthy. The returned promise will be fulfilled once this process completes, unless an error is encountered while closing the destination, in which case it will be rejected with that error.\n     *\n     * If destination starts out closed or closing, this source readable stream will be canceled, unless preventCancel is true. The returned promise will be rejected with an error indicating piping to a closed stream failed, or with any error that occurs during canceling the source.\n     *\n     * The signal option can be set to an AbortSignal to allow aborting an ongoing pipe operation via the corresponding AbortController. In this case, this source readable stream will be canceled, and destination aborted, unless the respective options preventCancel or preventAbort are set.\n     */\n    preventClose?: boolean;\n    signal?: AbortSignal;\n}\n\ninterface SyncEventInit extends ExtendableEventInit {\n    lastChance?: boolean;\n    tag: string;\n}\n\ninterface TextDecodeOptions {\n    stream?: boolean;\n}\n\ninterface TextDecoderOptions {\n    fatal?: boolean;\n    ignoreBOM?: boolean;\n}\n\ninterface TextEncoderEncodeIntoResult {\n    read?: number;\n    written?: number;\n}\n\ninterface Transformer<I = any, O = any> {\n    flush?: TransformerFlushCallback<O>;\n    readableType?: undefined;\n    start?: TransformerStartCallback<O>;\n    transform?: TransformerTransformCallback<I, O>;\n    writableType?: undefined;\n}\n\ninterface UnderlyingSink<W = any> {\n    abort?: UnderlyingSinkAbortCallback;\n    close?: UnderlyingSinkCloseCallback;\n    start?: UnderlyingSinkStartCallback;\n    type?: undefined;\n    write?: UnderlyingSinkWriteCallback<W>;\n}\n\ninterface UnderlyingSource<R = any> {\n    cancel?: UnderlyingSourceCancelCallback;\n    pull?: UnderlyingSourcePullCallback<R>;\n    start?: UnderlyingSourceStartCallback<R>;\n    type?: undefined;\n}\n\ninterface WebGLContextAttributes {\n    alpha?: boolean;\n    antialias?: boolean;\n    depth?: boolean;\n    desynchronized?: boolean;\n    failIfMajorPerformanceCaveat?: boolean;\n    powerPreference?: WebGLPowerPreference;\n    premultipliedAlpha?: boolean;\n    preserveDrawingBuffer?: boolean;\n    stencil?: boolean;\n}\n\ninterface WebGLContextEventInit extends EventInit {\n    statusMessage?: string;\n}\n\ninterface WorkerOptions {\n    credentials?: RequestCredentials;\n    name?: string;\n    type?: WorkerType;\n}\n\ninterface EventListener {\n    (evt: Event): void;\n}\n\n/** The ANGLE_instanced_arrays extension is part of the WebGL API and allows to draw the same object, or groups of similar objects multiple times, if they share the same vertex data, primitive count and type. */\ninterface ANGLE_instanced_arrays {\n    drawArraysInstancedANGLE(mode: GLenum, first: GLint, count: GLsizei, primcount: GLsizei): void;\n    drawElementsInstancedANGLE(mode: GLenum, count: GLsizei, type: GLenum, offset: GLintptr, primcount: GLsizei): void;\n    vertexAttribDivisorANGLE(index: GLuint, divisor: GLuint): void;\n    readonly VERTEX_ATTRIB_ARRAY_DIVISOR_ANGLE: GLenum;\n}\n\n/** A controller object that allows you to abort one or more DOM requests as and when desired. */\ninterface AbortController {\n    /**\n     * Returns the AbortSignal object associated with this object.\n     */\n    readonly signal: AbortSignal;\n    /**\n     * Invoking this method will set this object\'s AbortSignal\'s aborted flag and signal to any observers that the associated activity is to be aborted.\n     */\n    abort(): void;\n}\n\ndeclare var AbortController: {\n    prototype: AbortController;\n    new(): AbortController;\n};\n\ninterface AbortSignalEventMap {\n    "abort": Event;\n}\n\n/** A signal object that allows you to communicate with a DOM request (such as a Fetch) and abort it if required via an AbortController object. */\ninterface AbortSignal extends EventTarget {\n    /**\n     * Returns true if this AbortSignal\'s AbortController has signaled to abort, and false otherwise.\n     */\n    readonly aborted: boolean;\n    onabort: ((this: AbortSignal, ev: Event) => any) | null;\n    addEventListener<K extends keyof AbortSignalEventMap>(type: K, listener: (this: AbortSignal, ev: AbortSignalEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof AbortSignalEventMap>(type: K, listener: (this: AbortSignal, ev: AbortSignalEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var AbortSignal: {\n    prototype: AbortSignal;\n    new(): AbortSignal;\n};\n\ninterface AbstractWorkerEventMap {\n    "error": ErrorEvent;\n}\n\ninterface AbstractWorker {\n    onerror: ((this: AbstractWorker, ev: ErrorEvent) => any) | null;\n    addEventListener<K extends keyof AbstractWorkerEventMap>(type: K, listener: (this: AbstractWorker, ev: AbstractWorkerEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof AbstractWorkerEventMap>(type: K, listener: (this: AbstractWorker, ev: AbstractWorkerEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ninterface AesCfbParams extends Algorithm {\n    iv: Int8Array | Int16Array | Int32Array | Uint8Array | Uint16Array | Uint32Array | Uint8ClampedArray | Float32Array | Float64Array | DataView | ArrayBuffer;\n}\n\ninterface AesCmacParams extends Algorithm {\n    length: number;\n}\n\ninterface AnimationFrameProvider {\n    cancelAnimationFrame(handle: number): void;\n    requestAnimationFrame(callback: FrameRequestCallback): number;\n}\n\n/** A file-like object of immutable, raw data. Blobs represent data that isn\'t necessarily in a JavaScript-native format. The File interface is based on Blob, inheriting blob functionality and expanding it to support files on the user\'s system. */\ninterface Blob {\n    readonly size: number;\n    readonly type: string;\n    arrayBuffer(): Promise<ArrayBuffer>;\n    slice(start?: number, end?: number, contentType?: string): Blob;\n    stream(): ReadableStream;\n    text(): Promise<string>;\n}\n\ndeclare var Blob: {\n    prototype: Blob;\n    new(blobParts?: BlobPart[], options?: BlobPropertyBag): Blob;\n};\n\ninterface Body {\n    readonly body: ReadableStream<Uint8Array> | null;\n    readonly bodyUsed: boolean;\n    arrayBuffer(): Promise<ArrayBuffer>;\n    blob(): Promise<Blob>;\n    formData(): Promise<FormData>;\n    json(): Promise<any>;\n    text(): Promise<string>;\n}\n\ninterface BroadcastChannelEventMap {\n    "message": MessageEvent;\n    "messageerror": MessageEvent;\n}\n\ninterface BroadcastChannel extends EventTarget {\n    /**\n     * Returns the channel name (as passed to the constructor).\n     */\n    readonly name: string;\n    onmessage: ((this: BroadcastChannel, ev: MessageEvent) => any) | null;\n    onmessageerror: ((this: BroadcastChannel, ev: MessageEvent) => any) | null;\n    /**\n     * Closes the BroadcastChannel object, opening it up to garbage collection.\n     */\n    close(): void;\n    /**\n     * Sends the given message to other BroadcastChannel objects set up for this channel. Messages can be structured objects, e.g. nested objects and arrays.\n     */\n    postMessage(message: any): void;\n    addEventListener<K extends keyof BroadcastChannelEventMap>(type: K, listener: (this: BroadcastChannel, ev: BroadcastChannelEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof BroadcastChannelEventMap>(type: K, listener: (this: BroadcastChannel, ev: BroadcastChannelEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var BroadcastChannel: {\n    prototype: BroadcastChannel;\n    new(name: string): BroadcastChannel;\n};\n\n/** This Streams API interface provides a built-in byte length queuing strategy that can be used when constructing streams. */\ninterface ByteLengthQueuingStrategy extends QueuingStrategy<ArrayBufferView> {\n    readonly highWaterMark: number;\n    readonly size: QueuingStrategySize<ArrayBufferView>;\n}\n\ndeclare var ByteLengthQueuingStrategy: {\n    prototype: ByteLengthQueuingStrategy;\n    new(init: QueuingStrategyInit): ByteLengthQueuingStrategy;\n};\n\n/** Provides a storage mechanism for Request / Response object pairs that are cached, for example as part of the ServiceWorker life cycle. Note that the Cache interface is exposed to windowed scopes as well as workers. You don\'t have to use it in conjunction with service workers, even though it is defined in the service worker spec. */\ninterface Cache {\n    add(request: RequestInfo): Promise<void>;\n    addAll(requests: RequestInfo[]): Promise<void>;\n    delete(request: RequestInfo, options?: CacheQueryOptions): Promise<boolean>;\n    keys(request?: RequestInfo, options?: CacheQueryOptions): Promise<ReadonlyArray<Request>>;\n    match(request: RequestInfo, options?: CacheQueryOptions): Promise<Response | undefined>;\n    matchAll(request?: RequestInfo, options?: CacheQueryOptions): Promise<ReadonlyArray<Response>>;\n    put(request: RequestInfo, response: Response): Promise<void>;\n}\n\ndeclare var Cache: {\n    prototype: Cache;\n    new(): Cache;\n};\n\n/** The storage for Cache objects. */\ninterface CacheStorage {\n    delete(cacheName: string): Promise<boolean>;\n    has(cacheName: string): Promise<boolean>;\n    keys(): Promise<string[]>;\n    match(request: RequestInfo, options?: MultiCacheQueryOptions): Promise<Response | undefined>;\n    open(cacheName: string): Promise<Cache>;\n}\n\ndeclare var CacheStorage: {\n    prototype: CacheStorage;\n    new(): CacheStorage;\n};\n\ninterface CanvasCompositing {\n    globalAlpha: number;\n    globalCompositeOperation: string;\n}\n\ninterface CanvasDrawImage {\n    drawImage(image: CanvasImageSource, dx: number, dy: number): void;\n    drawImage(image: CanvasImageSource, dx: number, dy: number, dw: number, dh: number): void;\n    drawImage(image: CanvasImageSource, sx: number, sy: number, sw: number, sh: number, dx: number, dy: number, dw: number, dh: number): void;\n}\n\ninterface CanvasDrawPath {\n    beginPath(): void;\n    clip(fillRule?: CanvasFillRule): void;\n    clip(path: Path2D, fillRule?: CanvasFillRule): void;\n    fill(fillRule?: CanvasFillRule): void;\n    fill(path: Path2D, fillRule?: CanvasFillRule): void;\n    isPointInPath(x: number, y: number, fillRule?: CanvasFillRule): boolean;\n    isPointInPath(path: Path2D, x: number, y: number, fillRule?: CanvasFillRule): boolean;\n    isPointInStroke(x: number, y: number): boolean;\n    isPointInStroke(path: Path2D, x: number, y: number): boolean;\n    stroke(): void;\n    stroke(path: Path2D): void;\n}\n\ninterface CanvasFillStrokeStyles {\n    fillStyle: string | CanvasGradient | CanvasPattern;\n    strokeStyle: string | CanvasGradient | CanvasPattern;\n    createLinearGradient(x0: number, y0: number, x1: number, y1: number): CanvasGradient;\n    createPattern(image: CanvasImageSource, repetition: string | null): CanvasPattern | null;\n    createRadialGradient(x0: number, y0: number, r0: number, x1: number, y1: number, r1: number): CanvasGradient;\n}\n\ninterface CanvasFilters {\n    filter: string;\n}\n\n/** An opaque object describing a gradient. It is returned by the methods CanvasRenderingContext2D.createLinearGradient() or CanvasRenderingContext2D.createRadialGradient(). */\ninterface CanvasGradient {\n    /**\n     * Adds a color stop with the given color to the gradient at the given offset. 0.0 is the offset at one end of the gradient, 1.0 is the offset at the other end.\n     *\n     * Throws an "IndexSizeError" DOMException if the offset is out of range. Throws a "SyntaxError" DOMException if the color cannot be parsed.\n     */\n    addColorStop(offset: number, color: string): void;\n}\n\ndeclare var CanvasGradient: {\n    prototype: CanvasGradient;\n    new(): CanvasGradient;\n};\n\ninterface CanvasImageData {\n    createImageData(sw: number, sh: number): ImageData;\n    createImageData(imagedata: ImageData): ImageData;\n    getImageData(sx: number, sy: number, sw: number, sh: number): ImageData;\n    putImageData(imagedata: ImageData, dx: number, dy: number): void;\n    putImageData(imagedata: ImageData, dx: number, dy: number, dirtyX: number, dirtyY: number, dirtyWidth: number, dirtyHeight: number): void;\n}\n\ninterface CanvasImageSmoothing {\n    imageSmoothingEnabled: boolean;\n    imageSmoothingQuality: ImageSmoothingQuality;\n}\n\ninterface CanvasPath {\n    arc(x: number, y: number, radius: number, startAngle: number, endAngle: number, anticlockwise?: boolean): void;\n    arcTo(x1: number, y1: number, x2: number, y2: number, radius: number): void;\n    bezierCurveTo(cp1x: number, cp1y: number, cp2x: number, cp2y: number, x: number, y: number): void;\n    closePath(): void;\n    ellipse(x: number, y: number, radiusX: number, radiusY: number, rotation: number, startAngle: number, endAngle: number, anticlockwise?: boolean): void;\n    lineTo(x: number, y: number): void;\n    moveTo(x: number, y: number): void;\n    quadraticCurveTo(cpx: number, cpy: number, x: number, y: number): void;\n    rect(x: number, y: number, w: number, h: number): void;\n}\n\ninterface CanvasPathDrawingStyles {\n    lineCap: CanvasLineCap;\n    lineDashOffset: number;\n    lineJoin: CanvasLineJoin;\n    lineWidth: number;\n    miterLimit: number;\n    getLineDash(): number[];\n    setLineDash(segments: number[]): void;\n}\n\n/** An opaque object describing a pattern, based on an image, a canvas, or a video, created by the CanvasRenderingContext2D.createPattern() method. */\ninterface CanvasPattern {\n    /**\n     * Sets the transformation matrix that will be used when rendering the pattern during a fill or stroke painting operation.\n     */\n    setTransform(transform?: DOMMatrix2DInit): void;\n}\n\ndeclare var CanvasPattern: {\n    prototype: CanvasPattern;\n    new(): CanvasPattern;\n};\n\ninterface CanvasRect {\n    clearRect(x: number, y: number, w: number, h: number): void;\n    fillRect(x: number, y: number, w: number, h: number): void;\n    strokeRect(x: number, y: number, w: number, h: number): void;\n}\n\ninterface CanvasShadowStyles {\n    shadowBlur: number;\n    shadowColor: string;\n    shadowOffsetX: number;\n    shadowOffsetY: number;\n}\n\ninterface CanvasState {\n    restore(): void;\n    save(): void;\n}\n\ninterface CanvasText {\n    fillText(text: string, x: number, y: number, maxWidth?: number): void;\n    measureText(text: string): TextMetrics;\n    strokeText(text: string, x: number, y: number, maxWidth?: number): void;\n}\n\ninterface CanvasTextDrawingStyles {\n    direction: CanvasDirection;\n    font: string;\n    textAlign: CanvasTextAlign;\n    textBaseline: CanvasTextBaseline;\n}\n\ninterface CanvasTransform {\n    getTransform(): DOMMatrix;\n    resetTransform(): void;\n    rotate(angle: number): void;\n    scale(x: number, y: number): void;\n    setTransform(a: number, b: number, c: number, d: number, e: number, f: number): void;\n    setTransform(transform?: DOMMatrix2DInit): void;\n    transform(a: number, b: number, c: number, d: number, e: number, f: number): void;\n    translate(x: number, y: number): void;\n}\n\n/** The Client interface represents an executable context such as a Worker, or a SharedWorker. Window clients are represented by the more-specific WindowClient. You can get Client/WindowClient objects from methods such as Clients.matchAll() and Clients.get(). */\ninterface Client {\n    readonly frameType: FrameType;\n    readonly id: string;\n    readonly type: ClientTypes;\n    readonly url: string;\n    postMessage(message: any, transfer?: Transferable[]): void;\n}\n\ndeclare var Client: {\n    prototype: Client;\n    new(): Client;\n};\n\n/** Provides access to Client objects. Access it via self.clients within a service worker. */\ninterface Clients {\n    claim(): Promise<void>;\n    get(id: string): Promise<Client | undefined>;\n    matchAll<T extends ClientQueryOptions>(options?: T): Promise<ReadonlyArray<T["type"] extends "window" ? WindowClient : Client>>;\n    openWindow(url: string): Promise<WindowClient | null>;\n}\n\ndeclare var Clients: {\n    prototype: Clients;\n    new(): Clients;\n};\n\n/** A CloseEvent is sent to clients using WebSockets when the connection is closed. This is delivered to the listener indicated by the WebSocket object\'s onclose attribute. */\ninterface CloseEvent extends Event {\n    /**\n     * Returns the WebSocket connection close code provided by the server.\n     */\n    readonly code: number;\n    /**\n     * Returns the WebSocket connection close reason provided by the server.\n     */\n    readonly reason: string;\n    /**\n     * Returns true if the connection closed cleanly; false otherwise.\n     */\n    readonly wasClean: boolean;\n}\n\ndeclare var CloseEvent: {\n    prototype: CloseEvent;\n    new(type: string, eventInitDict?: CloseEventInit): CloseEvent;\n};\n\ninterface ConcatParams extends Algorithm {\n    algorithmId: Uint8Array;\n    hash?: string | Algorithm;\n    partyUInfo: Uint8Array;\n    partyVInfo: Uint8Array;\n    privateInfo?: Uint8Array;\n    publicInfo?: Uint8Array;\n}\n\n/** This Streams API interface provides a built-in byte length queuing strategy that can be used when constructing streams. */\ninterface CountQueuingStrategy extends QueuingStrategy {\n    readonly highWaterMark: number;\n    readonly size: QueuingStrategySize;\n}\n\ndeclare var CountQueuingStrategy: {\n    prototype: CountQueuingStrategy;\n    new(init: QueuingStrategyInit): CountQueuingStrategy;\n};\n\n/** Basic cryptography features available in the current context. It allows access to a cryptographically strong random number generator and to cryptographic primitives. */\ninterface Crypto {\n    readonly subtle: SubtleCrypto;\n    getRandomValues<T extends Int8Array | Int16Array | Int32Array | Uint8Array | Uint16Array | Uint32Array | Uint8ClampedArray | Float32Array | Float64Array | DataView | null>(array: T): T;\n}\n\ndeclare var Crypto: {\n    prototype: Crypto;\n    new(): Crypto;\n};\n\n/** The CryptoKey dictionary of the Web Crypto API represents a cryptographic key. */\ninterface CryptoKey {\n    readonly algorithm: KeyAlgorithm;\n    readonly extractable: boolean;\n    readonly type: KeyType;\n    readonly usages: KeyUsage[];\n}\n\ndeclare var CryptoKey: {\n    prototype: CryptoKey;\n    new(): CryptoKey;\n};\n\ninterface CustomEvent<T = any> extends Event {\n    /**\n     * Returns any custom data event was created with. Typically used for synthetic events.\n     */\n    readonly detail: T;\n    initCustomEvent(typeArg: string, canBubbleArg: boolean, cancelableArg: boolean, detailArg: T): void;\n}\n\ndeclare var CustomEvent: {\n    prototype: CustomEvent;\n    new<T>(typeArg: string, eventInitDict?: CustomEventInit<T>): CustomEvent<T>;\n};\n\n/** An abnormal event (called an exception) which occurs as a result of calling a method or accessing a property of a web API. */\ninterface DOMException {\n    readonly code: number;\n    readonly message: string;\n    readonly name: string;\n    readonly ABORT_ERR: number;\n    readonly DATA_CLONE_ERR: number;\n    readonly DOMSTRING_SIZE_ERR: number;\n    readonly HIERARCHY_REQUEST_ERR: number;\n    readonly INDEX_SIZE_ERR: number;\n    readonly INUSE_ATTRIBUTE_ERR: number;\n    readonly INVALID_ACCESS_ERR: number;\n    readonly INVALID_CHARACTER_ERR: number;\n    readonly INVALID_MODIFICATION_ERR: number;\n    readonly INVALID_NODE_TYPE_ERR: number;\n    readonly INVALID_STATE_ERR: number;\n    readonly NAMESPACE_ERR: number;\n    readonly NETWORK_ERR: number;\n    readonly NOT_FOUND_ERR: number;\n    readonly NOT_SUPPORTED_ERR: number;\n    readonly NO_DATA_ALLOWED_ERR: number;\n    readonly NO_MODIFICATION_ALLOWED_ERR: number;\n    readonly QUOTA_EXCEEDED_ERR: number;\n    readonly SECURITY_ERR: number;\n    readonly SYNTAX_ERR: number;\n    readonly TIMEOUT_ERR: number;\n    readonly TYPE_MISMATCH_ERR: number;\n    readonly URL_MISMATCH_ERR: number;\n    readonly VALIDATION_ERR: number;\n    readonly WRONG_DOCUMENT_ERR: number;\n}\n\ndeclare var DOMException: {\n    prototype: DOMException;\n    new(message?: string, name?: string): DOMException;\n    readonly ABORT_ERR: number;\n    readonly DATA_CLONE_ERR: number;\n    readonly DOMSTRING_SIZE_ERR: number;\n    readonly HIERARCHY_REQUEST_ERR: number;\n    readonly INDEX_SIZE_ERR: number;\n    readonly INUSE_ATTRIBUTE_ERR: number;\n    readonly INVALID_ACCESS_ERR: number;\n    readonly INVALID_CHARACTER_ERR: number;\n    readonly INVALID_MODIFICATION_ERR: number;\n    readonly INVALID_NODE_TYPE_ERR: number;\n    readonly INVALID_STATE_ERR: number;\n    readonly NAMESPACE_ERR: number;\n    readonly NETWORK_ERR: number;\n    readonly NOT_FOUND_ERR: number;\n    readonly NOT_SUPPORTED_ERR: number;\n    readonly NO_DATA_ALLOWED_ERR: number;\n    readonly NO_MODIFICATION_ALLOWED_ERR: number;\n    readonly QUOTA_EXCEEDED_ERR: number;\n    readonly SECURITY_ERR: number;\n    readonly SYNTAX_ERR: number;\n    readonly TIMEOUT_ERR: number;\n    readonly TYPE_MISMATCH_ERR: number;\n    readonly URL_MISMATCH_ERR: number;\n    readonly VALIDATION_ERR: number;\n    readonly WRONG_DOCUMENT_ERR: number;\n};\n\ninterface DOMMatrix extends DOMMatrixReadOnly {\n    a: number;\n    b: number;\n    c: number;\n    d: number;\n    e: number;\n    f: number;\n    m11: number;\n    m12: number;\n    m13: number;\n    m14: number;\n    m21: number;\n    m22: number;\n    m23: number;\n    m24: number;\n    m31: number;\n    m32: number;\n    m33: number;\n    m34: number;\n    m41: number;\n    m42: number;\n    m43: number;\n    m44: number;\n    invertSelf(): DOMMatrix;\n    multiplySelf(other?: DOMMatrixInit): DOMMatrix;\n    preMultiplySelf(other?: DOMMatrixInit): DOMMatrix;\n    rotateAxisAngleSelf(x?: number, y?: number, z?: number, angle?: number): DOMMatrix;\n    rotateFromVectorSelf(x?: number, y?: number): DOMMatrix;\n    rotateSelf(rotX?: number, rotY?: number, rotZ?: number): DOMMatrix;\n    scale3dSelf(scale?: number, originX?: number, originY?: number, originZ?: number): DOMMatrix;\n    scaleSelf(scaleX?: number, scaleY?: number, scaleZ?: number, originX?: number, originY?: number, originZ?: number): DOMMatrix;\n    skewXSelf(sx?: number): DOMMatrix;\n    skewYSelf(sy?: number): DOMMatrix;\n    translateSelf(tx?: number, ty?: number, tz?: number): DOMMatrix;\n}\n\ndeclare var DOMMatrix: {\n    prototype: DOMMatrix;\n    new(init?: string | number[]): DOMMatrix;\n    fromFloat32Array(array32: Float32Array): DOMMatrix;\n    fromFloat64Array(array64: Float64Array): DOMMatrix;\n    fromMatrix(other?: DOMMatrixInit): DOMMatrix;\n};\n\ninterface DOMMatrixReadOnly {\n    readonly a: number;\n    readonly b: number;\n    readonly c: number;\n    readonly d: number;\n    readonly e: number;\n    readonly f: number;\n    readonly is2D: boolean;\n    readonly isIdentity: boolean;\n    readonly m11: number;\n    readonly m12: number;\n    readonly m13: number;\n    readonly m14: number;\n    readonly m21: number;\n    readonly m22: number;\n    readonly m23: number;\n    readonly m24: number;\n    readonly m31: number;\n    readonly m32: number;\n    readonly m33: number;\n    readonly m34: number;\n    readonly m41: number;\n    readonly m42: number;\n    readonly m43: number;\n    readonly m44: number;\n    flipX(): DOMMatrix;\n    flipY(): DOMMatrix;\n    inverse(): DOMMatrix;\n    multiply(other?: DOMMatrixInit): DOMMatrix;\n    rotate(rotX?: number, rotY?: number, rotZ?: number): DOMMatrix;\n    rotateAxisAngle(x?: number, y?: number, z?: number, angle?: number): DOMMatrix;\n    rotateFromVector(x?: number, y?: number): DOMMatrix;\n    scale(scaleX?: number, scaleY?: number, scaleZ?: number, originX?: number, originY?: number, originZ?: number): DOMMatrix;\n    scale3d(scale?: number, originX?: number, originY?: number, originZ?: number): DOMMatrix;\n    /** @deprecated */\n    scaleNonUniform(scaleX?: number, scaleY?: number): DOMMatrix;\n    skewX(sx?: number): DOMMatrix;\n    skewY(sy?: number): DOMMatrix;\n    toFloat32Array(): Float32Array;\n    toFloat64Array(): Float64Array;\n    toJSON(): any;\n    transformPoint(point?: DOMPointInit): DOMPoint;\n    translate(tx?: number, ty?: number, tz?: number): DOMMatrix;\n}\n\ndeclare var DOMMatrixReadOnly: {\n    prototype: DOMMatrixReadOnly;\n    new(init?: string | number[]): DOMMatrixReadOnly;\n    fromFloat32Array(array32: Float32Array): DOMMatrixReadOnly;\n    fromFloat64Array(array64: Float64Array): DOMMatrixReadOnly;\n    fromMatrix(other?: DOMMatrixInit): DOMMatrixReadOnly;\n};\n\ninterface DOMPoint extends DOMPointReadOnly {\n    w: number;\n    x: number;\n    y: number;\n    z: number;\n}\n\ndeclare var DOMPoint: {\n    prototype: DOMPoint;\n    new(x?: number, y?: number, z?: number, w?: number): DOMPoint;\n    fromPoint(other?: DOMPointInit): DOMPoint;\n};\n\ninterface DOMPointReadOnly {\n    readonly w: number;\n    readonly x: number;\n    readonly y: number;\n    readonly z: number;\n    matrixTransform(matrix?: DOMMatrixInit): DOMPoint;\n    toJSON(): any;\n}\n\ndeclare var DOMPointReadOnly: {\n    prototype: DOMPointReadOnly;\n    new(x?: number, y?: number, z?: number, w?: number): DOMPointReadOnly;\n    fromPoint(other?: DOMPointInit): DOMPointReadOnly;\n};\n\ninterface DOMQuad {\n    readonly p1: DOMPoint;\n    readonly p2: DOMPoint;\n    readonly p3: DOMPoint;\n    readonly p4: DOMPoint;\n    getBounds(): DOMRect;\n    toJSON(): any;\n}\n\ndeclare var DOMQuad: {\n    prototype: DOMQuad;\n    new(p1?: DOMPointInit, p2?: DOMPointInit, p3?: DOMPointInit, p4?: DOMPointInit): DOMQuad;\n    fromQuad(other?: DOMQuadInit): DOMQuad;\n    fromRect(other?: DOMRectInit): DOMQuad;\n};\n\ninterface DOMRect extends DOMRectReadOnly {\n    height: number;\n    width: number;\n    x: number;\n    y: number;\n}\n\ndeclare var DOMRect: {\n    prototype: DOMRect;\n    new(x?: number, y?: number, width?: number, height?: number): DOMRect;\n    fromRect(other?: DOMRectInit): DOMRect;\n};\n\ninterface DOMRectReadOnly {\n    readonly bottom: number;\n    readonly height: number;\n    readonly left: number;\n    readonly right: number;\n    readonly top: number;\n    readonly width: number;\n    readonly x: number;\n    readonly y: number;\n    toJSON(): any;\n}\n\ndeclare var DOMRectReadOnly: {\n    prototype: DOMRectReadOnly;\n    new(x?: number, y?: number, width?: number, height?: number): DOMRectReadOnly;\n    fromRect(other?: DOMRectInit): DOMRectReadOnly;\n};\n\n/** A type returned by some APIs which contains a list of DOMString (strings). */\ninterface DOMStringList {\n    /**\n     * Returns the number of strings in strings.\n     */\n    readonly length: number;\n    /**\n     * Returns true if strings contains string, and false otherwise.\n     */\n    contains(string: string): boolean;\n    /**\n     * Returns the string with index index from strings.\n     */\n    item(index: number): string | null;\n    [index: number]: string;\n}\n\ndeclare var DOMStringList: {\n    prototype: DOMStringList;\n    new(): DOMStringList;\n};\n\ninterface DedicatedWorkerGlobalScopeEventMap extends WorkerGlobalScopeEventMap {\n    "message": MessageEvent;\n    "messageerror": MessageEvent;\n}\n\n/** (the Worker global scope) is accessible through the self keyword. Some additional global functions, namespaces objects, and constructors, not typically associated with the worker global scope, but available on it, are listed in the JavaScript Reference. See also: Functions available to workers. */\ninterface DedicatedWorkerGlobalScope extends WorkerGlobalScope, AnimationFrameProvider {\n    /**\n     * Returns dedicatedWorkerGlobal\'s name, i.e. the value given to the Worker constructor. Primarily useful for debugging.\n     */\n    readonly name: string;\n    onmessage: ((this: DedicatedWorkerGlobalScope, ev: MessageEvent) => any) | null;\n    onmessageerror: ((this: DedicatedWorkerGlobalScope, ev: MessageEvent) => any) | null;\n    /**\n     * Aborts dedicatedWorkerGlobal.\n     */\n    close(): void;\n    /**\n     * Clones message and transmits it to the Worker object associated with dedicatedWorkerGlobal. transfer can be passed as a list of objects that are to be transferred rather than cloned.\n     */\n    postMessage(message: any, transfer: Transferable[]): void;\n    postMessage(message: any, options?: PostMessageOptions): void;\n    addEventListener<K extends keyof DedicatedWorkerGlobalScopeEventMap>(type: K, listener: (this: DedicatedWorkerGlobalScope, ev: DedicatedWorkerGlobalScopeEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof DedicatedWorkerGlobalScopeEventMap>(type: K, listener: (this: DedicatedWorkerGlobalScope, ev: DedicatedWorkerGlobalScopeEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var DedicatedWorkerGlobalScope: {\n    prototype: DedicatedWorkerGlobalScope;\n    new(): DedicatedWorkerGlobalScope;\n};\n\ninterface DhImportKeyParams extends Algorithm {\n    generator: Uint8Array;\n    prime: Uint8Array;\n}\n\ninterface DhKeyAlgorithm extends KeyAlgorithm {\n    generator: Uint8Array;\n    prime: Uint8Array;\n}\n\ninterface DhKeyDeriveParams extends Algorithm {\n    public: CryptoKey;\n}\n\ninterface DhKeyGenParams extends Algorithm {\n    generator: Uint8Array;\n    prime: Uint8Array;\n}\n\ninterface EXT_blend_minmax {\n    readonly MAX_EXT: GLenum;\n    readonly MIN_EXT: GLenum;\n}\n\n/** The EXT_frag_depth extension is part of the WebGL API and enables to set a depth value of a fragment from within the fragment shader. */\ninterface EXT_frag_depth {\n}\n\ninterface EXT_sRGB {\n    readonly FRAMEBUFFER_ATTACHMENT_COLOR_ENCODING_EXT: GLenum;\n    readonly SRGB8_ALPHA8_EXT: GLenum;\n    readonly SRGB_ALPHA_EXT: GLenum;\n    readonly SRGB_EXT: GLenum;\n}\n\ninterface EXT_shader_texture_lod {\n}\n\n/** The EXT_texture_filter_anisotropic extension is part of the WebGL API and exposes two constants for anisotropic filtering (AF). */\ninterface EXT_texture_filter_anisotropic {\n    readonly MAX_TEXTURE_MAX_ANISOTROPY_EXT: GLenum;\n    readonly TEXTURE_MAX_ANISOTROPY_EXT: GLenum;\n}\n\n/** Events providing information related to errors in scripts or in files. */\ninterface ErrorEvent extends Event {\n    readonly colno: number;\n    readonly error: any;\n    readonly filename: string;\n    readonly lineno: number;\n    readonly message: string;\n}\n\ndeclare var ErrorEvent: {\n    prototype: ErrorEvent;\n    new(type: string, eventInitDict?: ErrorEventInit): ErrorEvent;\n};\n\n/** An event which takes place in the DOM. */\ninterface Event {\n    /**\n     * Returns true or false depending on how event was initialized. True if event goes through its target\'s ancestors in reverse tree order, and false otherwise.\n     */\n    readonly bubbles: boolean;\n    cancelBubble: boolean;\n    /**\n     * Returns true or false depending on how event was initialized. Its return value does not always carry meaning, but true can indicate that part of the operation during which event was dispatched, can be canceled by invoking the preventDefault() method.\n     */\n    readonly cancelable: boolean;\n    /**\n     * Returns true or false depending on how event was initialized. True if event invokes listeners past a ShadowRoot node that is the root of its target, and false otherwise.\n     */\n    readonly composed: boolean;\n    /**\n     * Returns the object whose event listener\'s callback is currently being invoked.\n     */\n    readonly currentTarget: EventTarget | null;\n    /**\n     * Returns true if preventDefault() was invoked successfully to indicate cancelation, and false otherwise.\n     */\n    readonly defaultPrevented: boolean;\n    /**\n     * Returns the event\'s phase, which is one of NONE, CAPTURING_PHASE, AT_TARGET, and BUBBLING_PHASE.\n     */\n    readonly eventPhase: number;\n    /**\n     * Returns true if event was dispatched by the user agent, and false otherwise.\n     */\n    readonly isTrusted: boolean;\n    returnValue: boolean;\n    /** @deprecated */\n    readonly srcElement: EventTarget | null;\n    /**\n     * Returns the object to which event is dispatched (its target).\n     */\n    readonly target: EventTarget | null;\n    /**\n     * Returns the event\'s timestamp as the number of milliseconds measured relative to the time origin.\n     */\n    readonly timeStamp: number;\n    /**\n     * Returns the type of event, e.g. "click", "hashchange", or "submit".\n     */\n    readonly type: string;\n    /**\n     * Returns the invocation target objects of event\'s path (objects on which listeners will be invoked), except for any nodes in shadow trees of which the shadow root\'s mode is "closed" that are not reachable from event\'s currentTarget.\n     */\n    composedPath(): EventTarget[];\n    initEvent(type: string, bubbles?: boolean, cancelable?: boolean): void;\n    /**\n     * If invoked when the cancelable attribute value is true, and while executing a listener for the event with passive set to false, signals to the operation that caused event to be dispatched that it needs to be canceled.\n     */\n    preventDefault(): void;\n    /**\n     * Invoking this method prevents event from reaching any registered event listeners after the current one finishes running and, when dispatched in a tree, also prevents event from reaching any other objects.\n     */\n    stopImmediatePropagation(): void;\n    /**\n     * When dispatched in a tree, invoking this method prevents event from reaching any objects other than the current object.\n     */\n    stopPropagation(): void;\n    readonly AT_TARGET: number;\n    readonly BUBBLING_PHASE: number;\n    readonly CAPTURING_PHASE: number;\n    readonly NONE: number;\n}\n\ndeclare var Event: {\n    prototype: Event;\n    new(type: string, eventInitDict?: EventInit): Event;\n    readonly AT_TARGET: number;\n    readonly BUBBLING_PHASE: number;\n    readonly CAPTURING_PHASE: number;\n    readonly NONE: number;\n};\n\ninterface EventListenerObject {\n    handleEvent(evt: Event): void;\n}\n\ninterface EventSourceEventMap {\n    "error": Event;\n    "message": MessageEvent;\n    "open": Event;\n}\n\ninterface EventSource extends EventTarget {\n    onerror: ((this: EventSource, ev: Event) => any) | null;\n    onmessage: ((this: EventSource, ev: MessageEvent) => any) | null;\n    onopen: ((this: EventSource, ev: Event) => any) | null;\n    /**\n     * Returns the state of this EventSource object\'s connection. It can have the values described below.\n     */\n    readonly readyState: number;\n    /**\n     * Returns the URL providing the event stream.\n     */\n    readonly url: string;\n    /**\n     * Returns true if the credentials mode for connection requests to the URL providing the event stream is set to "include", and false otherwise.\n     */\n    readonly withCredentials: boolean;\n    /**\n     * Aborts any instances of the fetch algorithm started for this EventSource object, and sets the readyState attribute to CLOSED.\n     */\n    close(): void;\n    readonly CLOSED: number;\n    readonly CONNECTING: number;\n    readonly OPEN: number;\n    addEventListener<K extends keyof EventSourceEventMap>(type: K, listener: (this: EventSource, ev: EventSourceEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof EventSourceEventMap>(type: K, listener: (this: EventSource, ev: EventSourceEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var EventSource: {\n    prototype: EventSource;\n    new(url: string, eventSourceInitDict?: EventSourceInit): EventSource;\n    readonly CLOSED: number;\n    readonly CONNECTING: number;\n    readonly OPEN: number;\n};\n\n/** EventTarget is a DOM interface implemented by objects that can receive events and may have listeners for them. */\ninterface EventTarget {\n    /**\n     * Appends an event listener for events whose type attribute value is type. The callback argument sets the callback that will be invoked when the event is dispatched.\n     *\n     * The options argument sets listener-specific options. For compatibility this can be a boolean, in which case the method behaves exactly as if the value was specified as options\'s capture.\n     *\n     * When set to true, options\'s capture prevents callback from being invoked when the event\'s eventPhase attribute value is BUBBLING_PHASE. When false (or not present), callback will not be invoked when event\'s eventPhase attribute value is CAPTURING_PHASE. Either way, callback will be invoked if event\'s eventPhase attribute value is AT_TARGET.\n     *\n     * When set to true, options\'s passive indicates that the callback will not cancel the event by invoking preventDefault(). This is used to enable performance optimizations described in § 2.8 Observing event listeners.\n     *\n     * When set to true, options\'s once indicates that the callback will only be invoked once after which the event listener will be removed.\n     *\n     * The event listener is appended to target\'s event listener list and is not appended if it has the same type, callback, and capture.\n     */\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject | null, options?: boolean | AddEventListenerOptions): void;\n    /**\n     * Dispatches a synthetic event event to target and returns true if either event\'s cancelable attribute value is false or its preventDefault() method was not invoked, and false otherwise.\n     */\n    dispatchEvent(event: Event): boolean;\n    /**\n     * Removes the event listener in target\'s event listener list with the same type, callback, and options.\n     */\n    removeEventListener(type: string, callback: EventListenerOrEventListenerObject | null, options?: EventListenerOptions | boolean): void;\n}\n\ndeclare var EventTarget: {\n    prototype: EventTarget;\n    new(): EventTarget;\n};\n\n/** Extends the lifetime of the install and activate events dispatched on the global scope as part of the service worker lifecycle. This ensures that any functional events (like FetchEvent) are not dispatched until it upgrades database schemas and deletes the outdated cache entries. */\ninterface ExtendableEvent extends Event {\n    waitUntil(f: any): void;\n}\n\ndeclare var ExtendableEvent: {\n    prototype: ExtendableEvent;\n    new(type: string, eventInitDict?: ExtendableEventInit): ExtendableEvent;\n};\n\n/** This ServiceWorker API interface represents the event object of a message event fired on a service worker (when a channel message is received on the ServiceWorkerGlobalScope from another context) — extends the lifetime of such events. */\ninterface ExtendableMessageEvent extends ExtendableEvent {\n    readonly data: any;\n    readonly lastEventId: string;\n    readonly origin: string;\n    readonly ports: ReadonlyArray<MessagePort>;\n    readonly source: Client | ServiceWorker | MessagePort | null;\n}\n\ndeclare var ExtendableMessageEvent: {\n    prototype: ExtendableMessageEvent;\n    new(type: string, eventInitDict?: ExtendableMessageEventInit): ExtendableMessageEvent;\n};\n\n/** This is the event type for fetch events dispatched on the service worker global scope. It contains information about the fetch, including the request and how the receiver will treat the response. It provides the event.respondWith() method, which allows us to provide a response to this fetch. */\ninterface FetchEvent extends ExtendableEvent {\n    readonly clientId: string;\n    readonly preloadResponse: Promise<any>;\n    readonly request: Request;\n    readonly resultingClientId: string;\n    respondWith(r: Response | Promise<Response>): void;\n}\n\ndeclare var FetchEvent: {\n    prototype: FetchEvent;\n    new(type: string, eventInitDict: FetchEventInit): FetchEvent;\n};\n\n/** Provides information about files and allows JavaScript in a web page to access their content. */\ninterface File extends Blob {\n    readonly lastModified: number;\n    readonly name: string;\n}\n\ndeclare var File: {\n    prototype: File;\n    new(fileBits: BlobPart[], fileName: string, options?: FilePropertyBag): File;\n};\n\n/** An object of this type is returned by the files property of the HTML <input> element; this lets you access the list of files selected with the <input type="file"> element. It\'s also used for a list of files dropped into web content when using the drag and drop API; see the DataTransfer object for details on this usage. */\ninterface FileList {\n    readonly length: number;\n    item(index: number): File | null;\n    [index: number]: File;\n}\n\ndeclare var FileList: {\n    prototype: FileList;\n    new(): FileList;\n};\n\ninterface FileReaderEventMap {\n    "abort": ProgressEvent<FileReader>;\n    "error": ProgressEvent<FileReader>;\n    "load": ProgressEvent<FileReader>;\n    "loadend": ProgressEvent<FileReader>;\n    "loadstart": ProgressEvent<FileReader>;\n    "progress": ProgressEvent<FileReader>;\n}\n\n/** Lets web applications asynchronously read the contents of files (or raw data buffers) stored on the user\'s computer, using File or Blob objects to specify the file or data to read. */\ninterface FileReader extends EventTarget {\n    readonly error: DOMException | null;\n    onabort: ((this: FileReader, ev: ProgressEvent<FileReader>) => any) | null;\n    onerror: ((this: FileReader, ev: ProgressEvent<FileReader>) => any) | null;\n    onload: ((this: FileReader, ev: ProgressEvent<FileReader>) => any) | null;\n    onloadend: ((this: FileReader, ev: ProgressEvent<FileReader>) => any) | null;\n    onloadstart: ((this: FileReader, ev: ProgressEvent<FileReader>) => any) | null;\n    onprogress: ((this: FileReader, ev: ProgressEvent<FileReader>) => any) | null;\n    readonly readyState: number;\n    readonly result: string | ArrayBuffer | null;\n    abort(): void;\n    readAsArrayBuffer(blob: Blob): void;\n    readAsBinaryString(blob: Blob): void;\n    readAsDataURL(blob: Blob): void;\n    readAsText(blob: Blob, encoding?: string): void;\n    readonly DONE: number;\n    readonly EMPTY: number;\n    readonly LOADING: number;\n    addEventListener<K extends keyof FileReaderEventMap>(type: K, listener: (this: FileReader, ev: FileReaderEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof FileReaderEventMap>(type: K, listener: (this: FileReader, ev: FileReaderEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var FileReader: {\n    prototype: FileReader;\n    new(): FileReader;\n    readonly DONE: number;\n    readonly EMPTY: number;\n    readonly LOADING: number;\n};\n\n/** Allows to read File or Blob objects in a synchronous way. */\ninterface FileReaderSync {\n    readAsArrayBuffer(blob: Blob): ArrayBuffer;\n    readAsBinaryString(blob: Blob): string;\n    readAsDataURL(blob: Blob): string;\n    readAsText(blob: Blob, encoding?: string): string;\n}\n\ndeclare var FileReaderSync: {\n    prototype: FileReaderSync;\n    new(): FileReaderSync;\n};\n\n/** Provides a way to easily construct a set of key/value pairs representing form fields and their values, which can then be easily sent using the XMLHttpRequest.send() method. It uses the same format a form would use if the encoding type were set to "multipart/form-data". */\ninterface FormData {\n    append(name: string, value: string | Blob, fileName?: string): void;\n    delete(name: string): void;\n    get(name: string): FormDataEntryValue | null;\n    getAll(name: string): FormDataEntryValue[];\n    has(name: string): boolean;\n    set(name: string, value: string | Blob, fileName?: string): void;\n    forEach(callbackfn: (value: FormDataEntryValue, key: string, parent: FormData) => void, thisArg?: any): void;\n}\n\ndeclare var FormData: {\n    prototype: FormData;\n    new(): FormData;\n};\n\ninterface GenericTransformStream {\n    readonly readable: ReadableStream;\n    readonly writable: WritableStream;\n}\n\n/** This Fetch API interface allows you to perform various actions on HTTP request and response headers. These actions include retrieving, setting, adding to, and removing. A Headers object has an associated header list, which is initially empty and consists of zero or more name and value pairs.  You can add to this using methods like append() (see Examples.) In all methods of this interface, header names are matched by case-insensitive byte sequence. */\ninterface Headers {\n    append(name: string, value: string): void;\n    delete(name: string): void;\n    get(name: string): string | null;\n    has(name: string): boolean;\n    set(name: string, value: string): void;\n    forEach(callbackfn: (value: string, key: string, parent: Headers) => void, thisArg?: any): void;\n}\n\ndeclare var Headers: {\n    prototype: Headers;\n    new(init?: HeadersInit): Headers;\n};\n\ninterface IDBArrayKey extends Array<IDBValidKey> {\n}\n\n/** This IndexedDB API interface represents a cursor for traversing or iterating over multiple records in a database. */\ninterface IDBCursor {\n    /**\n     * Returns the direction ("next", "nextunique", "prev" or "prevunique") of the cursor.\n     */\n    readonly direction: IDBCursorDirection;\n    /**\n     * Returns the key of the cursor. Throws a "InvalidStateError" DOMException if the cursor is advancing or is finished.\n     */\n    readonly key: IDBValidKey;\n    /**\n     * Returns the effective key of the cursor. Throws a "InvalidStateError" DOMException if the cursor is advancing or is finished.\n     */\n    readonly primaryKey: IDBValidKey;\n    /**\n     * Returns the IDBObjectStore or IDBIndex the cursor was opened from.\n     */\n    readonly source: IDBObjectStore | IDBIndex;\n    /**\n     * Advances the cursor through the next count records in range.\n     */\n    advance(count: number): void;\n    /**\n     * Advances the cursor to the next record in range.\n     */\n    continue(key?: IDBValidKey): void;\n    /**\n     * Advances the cursor to the next record in range matching or after key and primaryKey. Throws an "InvalidAccessError" DOMException if the source is not an index.\n     */\n    continuePrimaryKey(key: IDBValidKey, primaryKey: IDBValidKey): void;\n    /**\n     * Delete the record pointed at by the cursor with a new value.\n     *\n     * If successful, request\'s result will be undefined.\n     */\n    delete(): IDBRequest<undefined>;\n    /**\n     * Updated the record pointed at by the cursor with a new value.\n     *\n     * Throws a "DataError" DOMException if the effective object store uses in-line keys and the key would have changed.\n     *\n     * If successful, request\'s result will be the record\'s key.\n     */\n    update(value: any): IDBRequest<IDBValidKey>;\n}\n\ndeclare var IDBCursor: {\n    prototype: IDBCursor;\n    new(): IDBCursor;\n};\n\n/** This IndexedDB API interface represents a cursor for traversing or iterating over multiple records in a database. It is the same as the IDBCursor, except that it includes the value property. */\ninterface IDBCursorWithValue extends IDBCursor {\n    /**\n     * Returns the cursor\'s current value.\n     */\n    readonly value: any;\n}\n\ndeclare var IDBCursorWithValue: {\n    prototype: IDBCursorWithValue;\n    new(): IDBCursorWithValue;\n};\n\ninterface IDBDatabaseEventMap {\n    "abort": Event;\n    "close": Event;\n    "error": Event;\n    "versionchange": IDBVersionChangeEvent;\n}\n\n/** This IndexedDB API interface provides a connection to a database; you can use an IDBDatabase object to open a transaction on your database then create, manipulate, and delete objects (data) in that database. The interface provides the only way to get and manage versions of the database. */\ninterface IDBDatabase extends EventTarget {\n    /**\n     * Returns the name of the database.\n     */\n    readonly name: string;\n    /**\n     * Returns a list of the names of object stores in the database.\n     */\n    readonly objectStoreNames: DOMStringList;\n    onabort: ((this: IDBDatabase, ev: Event) => any) | null;\n    onclose: ((this: IDBDatabase, ev: Event) => any) | null;\n    onerror: ((this: IDBDatabase, ev: Event) => any) | null;\n    onversionchange: ((this: IDBDatabase, ev: IDBVersionChangeEvent) => any) | null;\n    /**\n     * Returns the version of the database.\n     */\n    readonly version: number;\n    /**\n     * Closes the connection once all running transactions have finished.\n     */\n    close(): void;\n    /**\n     * Creates a new object store with the given name and options and returns a new IDBObjectStore.\n     *\n     * Throws a "InvalidStateError" DOMException if not called within an upgrade transaction.\n     */\n    createObjectStore(name: string, options?: IDBObjectStoreParameters): IDBObjectStore;\n    /**\n     * Deletes the object store with the given name.\n     *\n     * Throws a "InvalidStateError" DOMException if not called within an upgrade transaction.\n     */\n    deleteObjectStore(name: string): void;\n    /**\n     * Returns a new transaction with the given mode ("readonly" or "readwrite") and scope which can be a single object store name or an array of names.\n     */\n    transaction(storeNames: string | string[], mode?: IDBTransactionMode): IDBTransaction;\n    addEventListener<K extends keyof IDBDatabaseEventMap>(type: K, listener: (this: IDBDatabase, ev: IDBDatabaseEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof IDBDatabaseEventMap>(type: K, listener: (this: IDBDatabase, ev: IDBDatabaseEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var IDBDatabase: {\n    prototype: IDBDatabase;\n    new(): IDBDatabase;\n};\n\n/** In the following code snippet, we make a request to open a database, and include handlers for the success and error cases. For a full working example, see our To-do Notifications app (view example live.) */\ninterface IDBFactory {\n    /**\n     * Compares two values as keys. Returns -1 if key1 precedes key2, 1 if key2 precedes key1, and 0 if the keys are equal.\n     *\n     * Throws a "DataError" DOMException if either input is not a valid key.\n     */\n    cmp(first: any, second: any): number;\n    /**\n     * Attempts to delete the named database. If the database already exists and there are open connections that don\'t close in response to a versionchange event, the request will be blocked until all they close. If the request is successful request\'s result will be null.\n     */\n    deleteDatabase(name: string): IDBOpenDBRequest;\n    /**\n     * Attempts to open a connection to the named database with the current version, or 1 if it does not already exist. If the request is successful request\'s result will be the connection.\n     */\n    open(name: string, version?: number): IDBOpenDBRequest;\n}\n\ndeclare var IDBFactory: {\n    prototype: IDBFactory;\n    new(): IDBFactory;\n};\n\n/** IDBIndex interface of the IndexedDB API provides asynchronous access to an index in a database. An index is a kind of object store for looking up records in another object store, called the referenced object store. You use this interface to retrieve data. */\ninterface IDBIndex {\n    readonly keyPath: string | string[];\n    readonly multiEntry: boolean;\n    /**\n     * Returns the name of the index.\n     */\n    name: string;\n    /**\n     * Returns the IDBObjectStore the index belongs to.\n     */\n    readonly objectStore: IDBObjectStore;\n    readonly unique: boolean;\n    /**\n     * Retrieves the number of records matching the given key or key range in query.\n     *\n     * If successful, request\'s result will be the count.\n     */\n    count(key?: IDBValidKey | IDBKeyRange): IDBRequest<number>;\n    /**\n     * Retrieves the value of the first record matching the given key or key range in query.\n     *\n     * If successful, request\'s result will be the value, or undefined if there was no matching record.\n     */\n    get(key: IDBValidKey | IDBKeyRange): IDBRequest<any | undefined>;\n    /**\n     * Retrieves the values of the records matching the given key or key range in query (up to count if given).\n     *\n     * If successful, request\'s result will be an Array of the values.\n     */\n    getAll(query?: IDBValidKey | IDBKeyRange | null, count?: number): IDBRequest<any[]>;\n    /**\n     * Retrieves the keys of records matching the given key or key range in query (up to count if given).\n     *\n     * If successful, request\'s result will be an Array of the keys.\n     */\n    getAllKeys(query?: IDBValidKey | IDBKeyRange | null, count?: number): IDBRequest<IDBValidKey[]>;\n    /**\n     * Retrieves the key of the first record matching the given key or key range in query.\n     *\n     * If successful, request\'s result will be the key, or undefined if there was no matching record.\n     */\n    getKey(key: IDBValidKey | IDBKeyRange): IDBRequest<IDBValidKey | undefined>;\n    /**\n     * Opens a cursor over the records matching query, ordered by direction. If query is null, all records in index are matched.\n     *\n     * If successful, request\'s result will be an IDBCursorWithValue, or null if there were no matching records.\n     */\n    openCursor(query?: IDBValidKey | IDBKeyRange | null, direction?: IDBCursorDirection): IDBRequest<IDBCursorWithValue | null>;\n    /**\n     * Opens a cursor with key only flag set over the records matching query, ordered by direction. If query is null, all records in index are matched.\n     *\n     * If successful, request\'s result will be an IDBCursor, or null if there were no matching records.\n     */\n    openKeyCursor(query?: IDBValidKey | IDBKeyRange | null, direction?: IDBCursorDirection): IDBRequest<IDBCursor | null>;\n}\n\ndeclare var IDBIndex: {\n    prototype: IDBIndex;\n    new(): IDBIndex;\n};\n\n/** A key range can be a single value or a range with upper and lower bounds or endpoints. If the key range has both upper and lower bounds, then it is bounded; if it has no bounds, it is unbounded. A bounded key range can either be open (the endpoints are excluded) or closed (the endpoints are included). To retrieve all keys within a certain range, you can use the following code constructs: */\ninterface IDBKeyRange {\n    /**\n     * Returns lower bound, or undefined if none.\n     */\n    readonly lower: any;\n    /**\n     * Returns true if the lower open flag is set, and false otherwise.\n     */\n    readonly lowerOpen: boolean;\n    /**\n     * Returns upper bound, or undefined if none.\n     */\n    readonly upper: any;\n    /**\n     * Returns true if the upper open flag is set, and false otherwise.\n     */\n    readonly upperOpen: boolean;\n    /**\n     * Returns true if key is included in the range, and false otherwise.\n     */\n    includes(key: any): boolean;\n}\n\ndeclare var IDBKeyRange: {\n    prototype: IDBKeyRange;\n    new(): IDBKeyRange;\n    /**\n     * Returns a new IDBKeyRange spanning from lower to upper. If lowerOpen is true, lower is not included in the range. If upperOpen is true, upper is not included in the range.\n     */\n    bound(lower: any, upper: any, lowerOpen?: boolean, upperOpen?: boolean): IDBKeyRange;\n    /**\n     * Returns a new IDBKeyRange starting at key with no upper bound. If open is true, key is not included in the range.\n     */\n    lowerBound(lower: any, open?: boolean): IDBKeyRange;\n    /**\n     * Returns a new IDBKeyRange spanning only key.\n     */\n    only(value: any): IDBKeyRange;\n    /**\n     * Returns a new IDBKeyRange with no lower bound and ending at key. If open is true, key is not included in the range.\n     */\n    upperBound(upper: any, open?: boolean): IDBKeyRange;\n};\n\n/** This example shows a variety of different uses of object stores, from updating the data structure with IDBObjectStore.createIndex inside an onupgradeneeded function, to adding a new item to our object store with IDBObjectStore.add. For a full working example, see our To-do Notifications app (view example live.) */\ninterface IDBObjectStore {\n    /**\n     * Returns true if the store has a key generator, and false otherwise.\n     */\n    readonly autoIncrement: boolean;\n    /**\n     * Returns a list of the names of indexes in the store.\n     */\n    readonly indexNames: DOMStringList;\n    /**\n     * Returns the key path of the store, or null if none.\n     */\n    readonly keyPath: string | string[];\n    /**\n     * Returns the name of the store.\n     */\n    name: string;\n    /**\n     * Returns the associated transaction.\n     */\n    readonly transaction: IDBTransaction;\n    /**\n     * Adds or updates a record in store with the given value and key.\n     *\n     * If the store uses in-line keys and key is specified a "DataError" DOMException will be thrown.\n     *\n     * If put() is used, any existing record with the key will be replaced. If add() is used, and if a record with the key already exists the request will fail, with request\'s error set to a "ConstraintError" DOMException.\n     *\n     * If successful, request\'s result will be the record\'s key.\n     */\n    add(value: any, key?: IDBValidKey): IDBRequest<IDBValidKey>;\n    /**\n     * Deletes all records in store.\n     *\n     * If successful, request\'s result will be undefined.\n     */\n    clear(): IDBRequest<undefined>;\n    /**\n     * Retrieves the number of records matching the given key or key range in query.\n     *\n     * If successful, request\'s result will be the count.\n     */\n    count(key?: IDBValidKey | IDBKeyRange): IDBRequest<number>;\n    /**\n     * Creates a new index in store with the given name, keyPath and options and returns a new IDBIndex. If the keyPath and options define constraints that cannot be satisfied with the data already in store the upgrade transaction will abort with a "ConstraintError" DOMException.\n     *\n     * Throws an "InvalidStateError" DOMException if not called within an upgrade transaction.\n     */\n    createIndex(name: string, keyPath: string | string[], options?: IDBIndexParameters): IDBIndex;\n    /**\n     * Deletes records in store with the given key or in the given key range in query.\n     *\n     * If successful, request\'s result will be undefined.\n     */\n    delete(key: IDBValidKey | IDBKeyRange): IDBRequest<undefined>;\n    /**\n     * Deletes the index in store with the given name.\n     *\n     * Throws an "InvalidStateError" DOMException if not called within an upgrade transaction.\n     */\n    deleteIndex(name: string): void;\n    /**\n     * Retrieves the value of the first record matching the given key or key range in query.\n     *\n     * If successful, request\'s result will be the value, or undefined if there was no matching record.\n     */\n    get(query: IDBValidKey | IDBKeyRange): IDBRequest<any | undefined>;\n    /**\n     * Retrieves the values of the records matching the given key or key range in query (up to count if given).\n     *\n     * If successful, request\'s result will be an Array of the values.\n     */\n    getAll(query?: IDBValidKey | IDBKeyRange | null, count?: number): IDBRequest<any[]>;\n    /**\n     * Retrieves the keys of records matching the given key or key range in query (up to count if given).\n     *\n     * If successful, request\'s result will be an Array of the keys.\n     */\n    getAllKeys(query?: IDBValidKey | IDBKeyRange | null, count?: number): IDBRequest<IDBValidKey[]>;\n    /**\n     * Retrieves the key of the first record matching the given key or key range in query.\n     *\n     * If successful, request\'s result will be the key, or undefined if there was no matching record.\n     */\n    getKey(query: IDBValidKey | IDBKeyRange): IDBRequest<IDBValidKey | undefined>;\n    index(name: string): IDBIndex;\n    /**\n     * Opens a cursor over the records matching query, ordered by direction. If query is null, all records in store are matched.\n     *\n     * If successful, request\'s result will be an IDBCursorWithValue pointing at the first matching record, or null if there were no matching records.\n     */\n    openCursor(query?: IDBValidKey | IDBKeyRange | null, direction?: IDBCursorDirection): IDBRequest<IDBCursorWithValue | null>;\n    /**\n     * Opens a cursor with key only flag set over the records matching query, ordered by direction. If query is null, all records in store are matched.\n     *\n     * If successful, request\'s result will be an IDBCursor pointing at the first matching record, or null if there were no matching records.\n     */\n    openKeyCursor(query?: IDBValidKey | IDBKeyRange | null, direction?: IDBCursorDirection): IDBRequest<IDBCursor | null>;\n    /**\n     * Adds or updates a record in store with the given value and key.\n     *\n     * If the store uses in-line keys and key is specified a "DataError" DOMException will be thrown.\n     *\n     * If put() is used, any existing record with the key will be replaced. If add() is used, and if a record with the key already exists the request will fail, with request\'s error set to a "ConstraintError" DOMException.\n     *\n     * If successful, request\'s result will be the record\'s key.\n     */\n    put(value: any, key?: IDBValidKey): IDBRequest<IDBValidKey>;\n}\n\ndeclare var IDBObjectStore: {\n    prototype: IDBObjectStore;\n    new(): IDBObjectStore;\n};\n\ninterface IDBOpenDBRequestEventMap extends IDBRequestEventMap {\n    "blocked": Event;\n    "upgradeneeded": IDBVersionChangeEvent;\n}\n\n/** Also inherits methods from its parents IDBRequest and EventTarget. */\ninterface IDBOpenDBRequest extends IDBRequest<IDBDatabase> {\n    onblocked: ((this: IDBOpenDBRequest, ev: Event) => any) | null;\n    onupgradeneeded: ((this: IDBOpenDBRequest, ev: IDBVersionChangeEvent) => any) | null;\n    addEventListener<K extends keyof IDBOpenDBRequestEventMap>(type: K, listener: (this: IDBOpenDBRequest, ev: IDBOpenDBRequestEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof IDBOpenDBRequestEventMap>(type: K, listener: (this: IDBOpenDBRequest, ev: IDBOpenDBRequestEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var IDBOpenDBRequest: {\n    prototype: IDBOpenDBRequest;\n    new(): IDBOpenDBRequest;\n};\n\ninterface IDBRequestEventMap {\n    "error": Event;\n    "success": Event;\n}\n\n/** The request object does not initially contain any information about the result of the operation, but once information becomes available, an event is fired on the request, and the information becomes available through the properties of the IDBRequest instance. */\ninterface IDBRequest<T = any> extends EventTarget {\n    /**\n     * When a request is completed, returns the error (a DOMException), or null if the request succeeded. Throws a "InvalidStateError" DOMException if the request is still pending.\n     */\n    readonly error: DOMException | null;\n    onerror: ((this: IDBRequest<T>, ev: Event) => any) | null;\n    onsuccess: ((this: IDBRequest<T>, ev: Event) => any) | null;\n    /**\n     * Returns "pending" until a request is complete, then returns "done".\n     */\n    readonly readyState: IDBRequestReadyState;\n    /**\n     * When a request is completed, returns the result, or undefined if the request failed. Throws a "InvalidStateError" DOMException if the request is still pending.\n     */\n    readonly result: T;\n    /**\n     * Returns the IDBObjectStore, IDBIndex, or IDBCursor the request was made against, or null if is was an open request.\n     */\n    readonly source: IDBObjectStore | IDBIndex | IDBCursor;\n    /**\n     * Returns the IDBTransaction the request was made within. If this as an open request, then it returns an upgrade transaction while it is running, or null otherwise.\n     */\n    readonly transaction: IDBTransaction | null;\n    addEventListener<K extends keyof IDBRequestEventMap>(type: K, listener: (this: IDBRequest<T>, ev: IDBRequestEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof IDBRequestEventMap>(type: K, listener: (this: IDBRequest<T>, ev: IDBRequestEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var IDBRequest: {\n    prototype: IDBRequest;\n    new(): IDBRequest;\n};\n\ninterface IDBTransactionEventMap {\n    "abort": Event;\n    "complete": Event;\n    "error": Event;\n}\n\ninterface IDBTransaction extends EventTarget {\n    /**\n     * Returns the transaction\'s connection.\n     */\n    readonly db: IDBDatabase;\n    /**\n     * If the transaction was aborted, returns the error (a DOMException) providing the reason.\n     */\n    readonly error: DOMException;\n    /**\n     * Returns the mode the transaction was created with ("readonly" or "readwrite"), or "versionchange" for an upgrade transaction.\n     */\n    readonly mode: IDBTransactionMode;\n    /**\n     * Returns a list of the names of object stores in the transaction\'s scope. For an upgrade transaction this is all object stores in the database.\n     */\n    readonly objectStoreNames: DOMStringList;\n    onabort: ((this: IDBTransaction, ev: Event) => any) | null;\n    oncomplete: ((this: IDBTransaction, ev: Event) => any) | null;\n    onerror: ((this: IDBTransaction, ev: Event) => any) | null;\n    /**\n     * Aborts the transaction. All pending requests will fail with a "AbortError" DOMException and all changes made to the database will be reverted.\n     */\n    abort(): void;\n    /**\n     * Returns an IDBObjectStore in the transaction\'s scope.\n     */\n    objectStore(name: string): IDBObjectStore;\n    addEventListener<K extends keyof IDBTransactionEventMap>(type: K, listener: (this: IDBTransaction, ev: IDBTransactionEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof IDBTransactionEventMap>(type: K, listener: (this: IDBTransaction, ev: IDBTransactionEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var IDBTransaction: {\n    prototype: IDBTransaction;\n    new(): IDBTransaction;\n};\n\n/** This IndexedDB API interface indicates that the version of the database has changed, as the result of an IDBOpenDBRequest.onupgradeneeded event handler function. */\ninterface IDBVersionChangeEvent extends Event {\n    readonly newVersion: number | null;\n    readonly oldVersion: number;\n}\n\ndeclare var IDBVersionChangeEvent: {\n    prototype: IDBVersionChangeEvent;\n    new(type: string, eventInitDict?: IDBVersionChangeEventInit): IDBVersionChangeEvent;\n};\n\ninterface ImageBitmap {\n    /**\n     * Returns the intrinsic height of the image, in CSS pixels.\n     */\n    readonly height: number;\n    /**\n     * Returns the intrinsic width of the image, in CSS pixels.\n     */\n    readonly width: number;\n    /**\n     * Releases imageBitmap\'s underlying bitmap data.\n     */\n    close(): void;\n}\n\ndeclare var ImageBitmap: {\n    prototype: ImageBitmap;\n    new(): ImageBitmap;\n};\n\ninterface ImageBitmapRenderingContext {\n    /**\n     * Returns the canvas element that the context is bound to.\n     */\n    readonly canvas: OffscreenCanvas;\n    /**\n     * Transfers the underlying bitmap data from imageBitmap to context, and the bitmap becomes the contents of the canvas element to which context is bound.\n     */\n    transferFromImageBitmap(bitmap: ImageBitmap | null): void;\n}\n\ndeclare var ImageBitmapRenderingContext: {\n    prototype: ImageBitmapRenderingContext;\n    new(): ImageBitmapRenderingContext;\n};\n\n/** The underlying pixel data of an area of a <canvas> element. It is created using the ImageData() constructor or creator methods on the CanvasRenderingContext2D object associated with a canvas: createImageData() and getImageData(). It can also be used to set a part of the canvas by using putImageData(). */\ninterface ImageData {\n    /**\n     * Returns the one-dimensional array containing the data in RGBA order, as integers in the range 0 to 255.\n     */\n    readonly data: Uint8ClampedArray;\n    /**\n     * Returns the actual dimensions of the data in the ImageData object, in pixels.\n     */\n    readonly height: number;\n    /**\n     * Returns the actual dimensions of the data in the ImageData object, in pixels.\n     */\n    readonly width: number;\n}\n\ndeclare var ImageData: {\n    prototype: ImageData;\n    new(sw: number, sh: number): ImageData;\n    new(data: Uint8ClampedArray, sw: number, sh?: number): ImageData;\n};\n\n/** This Channel Messaging API interface allows us to create a new message channel and send data through it via its two MessagePort properties. */\ninterface MessageChannel {\n    /**\n     * Returns the first MessagePort object.\n     */\n    readonly port1: MessagePort;\n    /**\n     * Returns the second MessagePort object.\n     */\n    readonly port2: MessagePort;\n}\n\ndeclare var MessageChannel: {\n    prototype: MessageChannel;\n    new(): MessageChannel;\n};\n\n/** A message received by a target object. */\ninterface MessageEvent<T = any> extends Event {\n    /**\n     * Returns the data of the message.\n     */\n    readonly data: T;\n    /**\n     * Returns the last event ID string, for server-sent events.\n     */\n    readonly lastEventId: string;\n    /**\n     * Returns the origin of the message, for server-sent events and cross-document messaging.\n     */\n    readonly origin: string;\n    /**\n     * Returns the MessagePort array sent with the message, for cross-document messaging and channel messaging.\n     */\n    readonly ports: ReadonlyArray<MessagePort>;\n    /**\n     * Returns the WindowProxy of the source window, for cross-document messaging, and the MessagePort being attached, in the connect event fired at SharedWorkerGlobalScope objects.\n     */\n    readonly source: MessageEventSource | null;\n}\n\ndeclare var MessageEvent: {\n    prototype: MessageEvent;\n    new<T>(type: string, eventInitDict?: MessageEventInit<T>): MessageEvent<T>;\n};\n\ninterface MessagePortEventMap {\n    "message": MessageEvent;\n    "messageerror": MessageEvent;\n}\n\n/** This Channel Messaging API interface represents one of the two ports of a MessageChannel, allowing messages to be sent from one port and listening out for them arriving at the other. */\ninterface MessagePort extends EventTarget {\n    onmessage: ((this: MessagePort, ev: MessageEvent) => any) | null;\n    onmessageerror: ((this: MessagePort, ev: MessageEvent) => any) | null;\n    /**\n     * Disconnects the port, so that it is no longer active.\n     */\n    close(): void;\n    /**\n     * Posts a message through the channel. Objects listed in transfer are transferred, not just cloned, meaning that they are no longer usable on the sending side.\n     *\n     * Throws a "DataCloneError" DOMException if transfer contains duplicate objects or port, or if message could not be cloned.\n     */\n    postMessage(message: any, transfer: Transferable[]): void;\n    postMessage(message: any, options?: PostMessageOptions): void;\n    /**\n     * Begins dispatching messages received on the port.\n     */\n    start(): void;\n    addEventListener<K extends keyof MessagePortEventMap>(type: K, listener: (this: MessagePort, ev: MessagePortEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof MessagePortEventMap>(type: K, listener: (this: MessagePort, ev: MessagePortEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var MessagePort: {\n    prototype: MessagePort;\n    new(): MessagePort;\n};\n\ninterface NavigationPreloadManager {\n    disable(): Promise<void>;\n    enable(): Promise<void>;\n    getState(): Promise<NavigationPreloadState>;\n    setHeaderValue(value: string): Promise<void>;\n}\n\ndeclare var NavigationPreloadManager: {\n    prototype: NavigationPreloadManager;\n    new(): NavigationPreloadManager;\n};\n\ninterface NavigatorConcurrentHardware {\n    readonly hardwareConcurrency: number;\n}\n\ninterface NavigatorID {\n    readonly appCodeName: string;\n    readonly appName: string;\n    readonly appVersion: string;\n    readonly platform: string;\n    readonly product: string;\n    readonly userAgent: string;\n}\n\ninterface NavigatorLanguage {\n    readonly language: string;\n    readonly languages: ReadonlyArray<string>;\n}\n\ninterface NavigatorOnLine {\n    readonly onLine: boolean;\n}\n\ninterface NavigatorStorage {\n    readonly storage: StorageManager;\n}\n\ninterface NotificationEventMap {\n    "click": Event;\n    "close": Event;\n    "error": Event;\n    "show": Event;\n}\n\n/** This Notifications API interface is used to configure and display desktop notifications to the user. */\ninterface Notification extends EventTarget {\n    readonly actions: ReadonlyArray<NotificationAction>;\n    readonly badge: string;\n    readonly body: string;\n    readonly data: any;\n    readonly dir: NotificationDirection;\n    readonly icon: string;\n    readonly image: string;\n    readonly lang: string;\n    onclick: ((this: Notification, ev: Event) => any) | null;\n    onclose: ((this: Notification, ev: Event) => any) | null;\n    onerror: ((this: Notification, ev: Event) => any) | null;\n    onshow: ((this: Notification, ev: Event) => any) | null;\n    readonly renotify: boolean;\n    readonly requireInteraction: boolean;\n    readonly silent: boolean;\n    readonly tag: string;\n    readonly timestamp: number;\n    readonly title: string;\n    readonly vibrate: ReadonlyArray<number>;\n    close(): void;\n    addEventListener<K extends keyof NotificationEventMap>(type: K, listener: (this: Notification, ev: NotificationEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof NotificationEventMap>(type: K, listener: (this: Notification, ev: NotificationEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var Notification: {\n    prototype: Notification;\n    new(title: string, options?: NotificationOptions): Notification;\n    readonly maxActions: number;\n    readonly permission: NotificationPermission;\n};\n\n/** The parameter passed into the onnotificationclick handler, the NotificationEvent interface represents a notification click event that is dispatched on the ServiceWorkerGlobalScope of a ServiceWorker. */\ninterface NotificationEvent extends ExtendableEvent {\n    readonly action: string;\n    readonly notification: Notification;\n}\n\ndeclare var NotificationEvent: {\n    prototype: NotificationEvent;\n    new(type: string, eventInitDict: NotificationEventInit): NotificationEvent;\n};\n\n/** The OES_element_index_uint extension is part of the WebGL API and adds support for gl.UNSIGNED_INT types to WebGLRenderingContext.drawElements(). */\ninterface OES_element_index_uint {\n}\n\n/** The OES_standard_derivatives extension is part of the WebGL API and adds the GLSL derivative functions dFdx, dFdy, and fwidth. */\ninterface OES_standard_derivatives {\n    readonly FRAGMENT_SHADER_DERIVATIVE_HINT_OES: GLenum;\n}\n\n/** The OES_texture_float extension is part of the WebGL API and exposes floating-point pixel types for textures. */\ninterface OES_texture_float {\n}\n\n/** The OES_texture_float_linear extension is part of the WebGL API and allows linear filtering with floating-point pixel types for textures. */\ninterface OES_texture_float_linear {\n}\n\n/** The OES_texture_half_float extension is part of the WebGL API and adds texture formats with 16- (aka half float) and 32-bit floating-point components. */\ninterface OES_texture_half_float {\n    readonly HALF_FLOAT_OES: GLenum;\n}\n\n/** The OES_texture_half_float_linear extension is part of the WebGL API and allows linear filtering with half floating-point pixel types for textures. */\ninterface OES_texture_half_float_linear {\n}\n\ninterface OES_vertex_array_object {\n    bindVertexArrayOES(arrayObject: WebGLVertexArrayObjectOES | null): void;\n    createVertexArrayOES(): WebGLVertexArrayObjectOES | null;\n    deleteVertexArrayOES(arrayObject: WebGLVertexArrayObjectOES | null): void;\n    isVertexArrayOES(arrayObject: WebGLVertexArrayObjectOES | null): GLboolean;\n    readonly VERTEX_ARRAY_BINDING_OES: GLenum;\n}\n\ninterface OffscreenCanvas extends EventTarget {\n    /**\n     * These attributes return the dimensions of the OffscreenCanvas object\'s bitmap.\n     *\n     * They can be set, to replace the bitmap with a new, transparent black bitmap of the specified dimensions (effectively resizing it).\n     */\n    height: number;\n    /**\n     * These attributes return the dimensions of the OffscreenCanvas object\'s bitmap.\n     *\n     * They can be set, to replace the bitmap with a new, transparent black bitmap of the specified dimensions (effectively resizing it).\n     */\n    width: number;\n    /**\n     * Returns a promise that will fulfill with a new Blob object representing a file containing the image in the OffscreenCanvas object.\n     *\n     * The argument, if provided, is a dictionary that controls the encoding options of the image file to be created. The type field specifies the file format and has a default value of "image/png"; that type is also used if the requested type isn\'t supported. If the image format supports variable quality (such as "image/jpeg"), then the quality field is a number in the range 0.0 to 1.0 inclusive indicating the desired quality level for the resulting image.\n     */\n    convertToBlob(options?: ImageEncodeOptions): Promise<Blob>;\n    /**\n     * Returns an object that exposes an API for drawing on the OffscreenCanvas object. contextId specifies the desired API: "2d", "bitmaprenderer", "webgl", or "webgl2". options is handled by that API.\n     *\n     * This specification defines the "2d" context below, which is similar but distinct from the "2d" context that is created from a canvas element. The WebGL specifications define the "webgl" and "webgl2" contexts. [WEBGL]\n     *\n     * Returns null if the canvas has already been initialized with another context type (e.g., trying to get a "2d" context after getting a "webgl" context).\n     */\n    getContext(contextId: "2d", options?: CanvasRenderingContext2DSettings): OffscreenCanvasRenderingContext2D | null;\n    getContext(contextId: "bitmaprenderer", options?: ImageBitmapRenderingContextSettings): ImageBitmapRenderingContext | null;\n    getContext(contextId: "webgl", options?: WebGLContextAttributes): WebGLRenderingContext | null;\n    getContext(contextId: "webgl2", options?: WebGLContextAttributes): WebGL2RenderingContext | null;\n    getContext(contextId: OffscreenRenderingContextId, options?: any): OffscreenRenderingContext | null;\n    /**\n     * Returns a newly created ImageBitmap object with the image in the OffscreenCanvas object. The image in the OffscreenCanvas object is replaced with a new blank image.\n     */\n    transferToImageBitmap(): ImageBitmap;\n}\n\ndeclare var OffscreenCanvas: {\n    prototype: OffscreenCanvas;\n    new(width: number, height: number): OffscreenCanvas;\n};\n\ninterface OffscreenCanvasRenderingContext2D extends CanvasCompositing, CanvasDrawImage, CanvasDrawPath, CanvasFillStrokeStyles, CanvasFilters, CanvasImageData, CanvasImageSmoothing, CanvasPath, CanvasPathDrawingStyles, CanvasRect, CanvasShadowStyles, CanvasState, CanvasText, CanvasTextDrawingStyles, CanvasTransform {\n    readonly canvas: OffscreenCanvas;\n    commit(): void;\n}\n\ndeclare var OffscreenCanvasRenderingContext2D: {\n    prototype: OffscreenCanvasRenderingContext2D;\n    new(): OffscreenCanvasRenderingContext2D;\n};\n\n/** This Canvas 2D API interface is used to declare a path that can then be used on a CanvasRenderingContext2D object. The path methods of the CanvasRenderingContext2D interface are also present on this interface, which gives you the convenience of being able to retain and replay your path whenever desired. */\ninterface Path2D extends CanvasPath {\n    /**\n     * Adds to the path the path given by the argument.\n     */\n    addPath(path: Path2D, transform?: DOMMatrix2DInit): void;\n}\n\ndeclare var Path2D: {\n    prototype: Path2D;\n    new(path?: Path2D | string): Path2D;\n};\n\ninterface PerformanceEventMap {\n    "resourcetimingbufferfull": Event;\n}\n\n/** Provides access to performance-related information for the current page. It\'s part of the High Resolution Time API, but is enhanced by the Performance Timeline API, the Navigation Timing API, the User Timing API, and the Resource Timing API. */\ninterface Performance extends EventTarget {\n    onresourcetimingbufferfull: ((this: Performance, ev: Event) => any) | null;\n    readonly timeOrigin: number;\n    clearMarks(markName?: string): void;\n    clearMeasures(measureName?: string): void;\n    clearResourceTimings(): void;\n    getEntries(): PerformanceEntryList;\n    getEntriesByName(name: string, type?: string): PerformanceEntryList;\n    getEntriesByType(type: string): PerformanceEntryList;\n    mark(markName: string): void;\n    measure(measureName: string, startMark?: string, endMark?: string): void;\n    now(): number;\n    setResourceTimingBufferSize(maxSize: number): void;\n    toJSON(): any;\n    addEventListener<K extends keyof PerformanceEventMap>(type: K, listener: (this: Performance, ev: PerformanceEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof PerformanceEventMap>(type: K, listener: (this: Performance, ev: PerformanceEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var Performance: {\n    prototype: Performance;\n    new(): Performance;\n};\n\n/** Encapsulates a single performance metric that is part of the performance timeline. A performance entry can be directly created by making a performance mark or measure (for example by calling the mark() method) at an explicit point in an application. Performance entries are also created in indirect ways such as loading a resource (such as an image). */\ninterface PerformanceEntry {\n    readonly duration: number;\n    readonly entryType: string;\n    readonly name: string;\n    readonly startTime: number;\n    toJSON(): any;\n}\n\ndeclare var PerformanceEntry: {\n    prototype: PerformanceEntry;\n    new(): PerformanceEntry;\n};\n\n/** PerformanceMark is an abstract interface for PerformanceEntry objects with an entryType of "mark". Entries of this type are created by calling performance.mark() to add a named DOMHighResTimeStamp (the mark) to the browser\'s performance timeline. */\ninterface PerformanceMark extends PerformanceEntry {\n}\n\ndeclare var PerformanceMark: {\n    prototype: PerformanceMark;\n    new(): PerformanceMark;\n};\n\n/** PerformanceMeasure is an abstract interface for PerformanceEntry objects with an entryType of "measure". Entries of this type are created by calling performance.measure() to add a named DOMHighResTimeStamp (the measure) between two marks to the browser\'s performance timeline. */\ninterface PerformanceMeasure extends PerformanceEntry {\n}\n\ndeclare var PerformanceMeasure: {\n    prototype: PerformanceMeasure;\n    new(): PerformanceMeasure;\n};\n\ninterface PerformanceObserver {\n    disconnect(): void;\n    observe(options?: PerformanceObserverInit): void;\n    takeRecords(): PerformanceEntryList;\n}\n\ndeclare var PerformanceObserver: {\n    prototype: PerformanceObserver;\n    new(callback: PerformanceObserverCallback): PerformanceObserver;\n    readonly supportedEntryTypes: ReadonlyArray<string>;\n};\n\ninterface PerformanceObserverEntryList {\n    getEntries(): PerformanceEntryList;\n    getEntriesByName(name: string, type?: string): PerformanceEntryList;\n    getEntriesByType(type: string): PerformanceEntryList;\n}\n\ndeclare var PerformanceObserverEntryList: {\n    prototype: PerformanceObserverEntryList;\n    new(): PerformanceObserverEntryList;\n};\n\n/** Enables retrieval and analysis of detailed network timing data regarding the loading of an application\'s resources. An application can use the timing metrics to determine, for example, the length of time it takes to fetch a specific resource, such as an XMLHttpRequest, <SVG>, image, or script. */\ninterface PerformanceResourceTiming extends PerformanceEntry {\n    readonly connectEnd: number;\n    readonly connectStart: number;\n    readonly decodedBodySize: number;\n    readonly domainLookupEnd: number;\n    readonly domainLookupStart: number;\n    readonly encodedBodySize: number;\n    readonly fetchStart: number;\n    readonly initiatorType: string;\n    readonly nextHopProtocol: string;\n    readonly redirectEnd: number;\n    readonly redirectStart: number;\n    readonly requestStart: number;\n    readonly responseEnd: number;\n    readonly responseStart: number;\n    readonly secureConnectionStart: number;\n    readonly transferSize: number;\n    readonly workerStart: number;\n    toJSON(): any;\n}\n\ndeclare var PerformanceResourceTiming: {\n    prototype: PerformanceResourceTiming;\n    new(): PerformanceResourceTiming;\n};\n\ninterface PermissionStatusEventMap {\n    "change": Event;\n}\n\ninterface PermissionStatus extends EventTarget {\n    onchange: ((this: PermissionStatus, ev: Event) => any) | null;\n    readonly state: PermissionState;\n    addEventListener<K extends keyof PermissionStatusEventMap>(type: K, listener: (this: PermissionStatus, ev: PermissionStatusEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof PermissionStatusEventMap>(type: K, listener: (this: PermissionStatus, ev: PermissionStatusEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var PermissionStatus: {\n    prototype: PermissionStatus;\n    new(): PermissionStatus;\n};\n\ninterface Permissions {\n    query(permissionDesc: PermissionDescriptor | DevicePermissionDescriptor | MidiPermissionDescriptor | PushPermissionDescriptor): Promise<PermissionStatus>;\n}\n\ndeclare var Permissions: {\n    prototype: Permissions;\n    new(): Permissions;\n};\n\n/** Events measuring progress of an underlying process, like an HTTP request (for an XMLHttpRequest, or the loading of the underlying resource of an <img>, <audio>, <video>, <style> or <link>). */\ninterface ProgressEvent<T extends EventTarget = EventTarget> extends Event {\n    readonly lengthComputable: boolean;\n    readonly loaded: number;\n    readonly target: T | null;\n    readonly total: number;\n}\n\ndeclare var ProgressEvent: {\n    prototype: ProgressEvent;\n    new(type: string, eventInitDict?: ProgressEventInit): ProgressEvent;\n};\n\ninterface PromiseRejectionEvent extends Event {\n    readonly promise: Promise<any>;\n    readonly reason: any;\n}\n\ndeclare var PromiseRejectionEvent: {\n    prototype: PromiseRejectionEvent;\n    new(type: string, eventInitDict: PromiseRejectionEventInit): PromiseRejectionEvent;\n};\n\n/** This Push API interface represents a push message that has been received. This event is sent to the global scope of a ServiceWorker. It contains the information sent from an application server to a PushSubscription. */\ninterface PushEvent extends ExtendableEvent {\n    readonly data: PushMessageData | null;\n}\n\ndeclare var PushEvent: {\n    prototype: PushEvent;\n    new(type: string, eventInitDict?: PushEventInit): PushEvent;\n};\n\n/** This Push API interface provides a way to receive notifications from third-party servers as well as request URLs for push notifications. */\ninterface PushManager {\n    getSubscription(): Promise<PushSubscription | null>;\n    permissionState(options?: PushSubscriptionOptionsInit): Promise<PushPermissionState>;\n    subscribe(options?: PushSubscriptionOptionsInit): Promise<PushSubscription>;\n}\n\ndeclare var PushManager: {\n    prototype: PushManager;\n    new(): PushManager;\n    readonly supportedContentEncodings: ReadonlyArray<string>;\n};\n\n/** This Push API interface provides methods which let you retrieve the push data sent by a server in various formats. */\ninterface PushMessageData {\n    arrayBuffer(): ArrayBuffer;\n    blob(): Blob;\n    json(): any;\n    text(): string;\n}\n\ndeclare var PushMessageData: {\n    prototype: PushMessageData;\n    new(): PushMessageData;\n};\n\n/** This Push API interface provides a subcription\'s URL endpoint and allows unsubscription from a push service. */\ninterface PushSubscription {\n    readonly endpoint: string;\n    readonly expirationTime: number | null;\n    readonly options: PushSubscriptionOptions;\n    getKey(name: PushEncryptionKeyName): ArrayBuffer | null;\n    toJSON(): PushSubscriptionJSON;\n    unsubscribe(): Promise<boolean>;\n}\n\ndeclare var PushSubscription: {\n    prototype: PushSubscription;\n    new(): PushSubscription;\n};\n\ninterface PushSubscriptionOptions {\n    readonly applicationServerKey: ArrayBuffer | null;\n    readonly userVisibleOnly: boolean;\n}\n\ndeclare var PushSubscriptionOptions: {\n    prototype: PushSubscriptionOptions;\n    new(): PushSubscriptionOptions;\n};\n\n/** This Streams API interface represents a readable stream of byte data. The Fetch API offers a concrete instance of a ReadableStream through the body property of a Response object. */\ninterface ReadableStream<R = any> {\n    readonly locked: boolean;\n    cancel(reason?: any): Promise<void>;\n    getReader(): ReadableStreamDefaultReader<R>;\n    pipeThrough<T>(transform: ReadableWritablePair<T, R>, options?: StreamPipeOptions): ReadableStream<T>;\n    pipeTo(dest: WritableStream<R>, options?: StreamPipeOptions): Promise<void>;\n    tee(): [ReadableStream<R>, ReadableStream<R>];\n}\n\ndeclare var ReadableStream: {\n    prototype: ReadableStream;\n    new<R = any>(underlyingSource?: UnderlyingSource<R>, strategy?: QueuingStrategy<R>): ReadableStream<R>;\n};\n\ninterface ReadableStreamDefaultController<R = any> {\n    readonly desiredSize: number | null;\n    close(): void;\n    enqueue(chunk: R): void;\n    error(e?: any): void;\n}\n\ndeclare var ReadableStreamDefaultController: {\n    prototype: ReadableStreamDefaultController;\n    new(): ReadableStreamDefaultController;\n};\n\ninterface ReadableStreamDefaultReader<R = any> extends ReadableStreamGenericReader {\n    read(): Promise<ReadableStreamDefaultReadResult<R>>;\n    releaseLock(): void;\n}\n\ndeclare var ReadableStreamDefaultReader: {\n    prototype: ReadableStreamDefaultReader;\n    new<R = any>(stream: ReadableStream<R>): ReadableStreamDefaultReader<R>;\n};\n\ninterface ReadableStreamGenericReader {\n    readonly closed: Promise<undefined>;\n    cancel(reason?: any): Promise<void>;\n}\n\n/** This Fetch API interface represents a resource request. */\ninterface Request extends Body {\n    /**\n     * Returns the cache mode associated with request, which is a string indicating how the request will interact with the browser\'s cache when fetching.\n     */\n    readonly cache: RequestCache;\n    /**\n     * Returns the credentials mode associated with request, which is a string indicating whether credentials will be sent with the request always, never, or only when sent to a same-origin URL.\n     */\n    readonly credentials: RequestCredentials;\n    /**\n     * Returns the kind of resource requested by request, e.g., "document" or "script".\n     */\n    readonly destination: RequestDestination;\n    /**\n     * Returns a Headers object consisting of the headers associated with request. Note that headers added in the network layer by the user agent will not be accounted for in this object, e.g., the "Host" header.\n     */\n    readonly headers: Headers;\n    /**\n     * Returns request\'s subresource integrity metadata, which is a cryptographic hash of the resource being fetched. Its value consists of multiple hashes separated by whitespace. [SRI]\n     */\n    readonly integrity: string;\n    /**\n     * Returns a boolean indicating whether or not request is for a history navigation (a.k.a. back-foward navigation).\n     */\n    readonly isHistoryNavigation: boolean;\n    /**\n     * Returns a boolean indicating whether or not request is for a reload navigation.\n     */\n    readonly isReloadNavigation: boolean;\n    /**\n     * Returns a boolean indicating whether or not request can outlive the global in which it was created.\n     */\n    readonly keepalive: boolean;\n    /**\n     * Returns request\'s HTTP method, which is "GET" by default.\n     */\n    readonly method: string;\n    /**\n     * Returns the mode associated with request, which is a string indicating whether the request will use CORS, or will be restricted to same-origin URLs.\n     */\n    readonly mode: RequestMode;\n    /**\n     * Returns the redirect mode associated with request, which is a string indicating how redirects for the request will be handled during fetching. A request will follow redirects by default.\n     */\n    readonly redirect: RequestRedirect;\n    /**\n     * Returns the referrer of request. Its value can be a same-origin URL if explicitly set in init, the empty string to indicate no referrer, and "about:client" when defaulting to the global\'s default. This is used during fetching to determine the value of the `Referer` header of the request being made.\n     */\n    readonly referrer: string;\n    /**\n     * Returns the referrer policy associated with request. This is used during fetching to compute the value of the request\'s referrer.\n     */\n    readonly referrerPolicy: ReferrerPolicy;\n    /**\n     * Returns the signal associated with request, which is an AbortSignal object indicating whether or not request has been aborted, and its abort event handler.\n     */\n    readonly signal: AbortSignal;\n    /**\n     * Returns the URL of request as a string.\n     */\n    readonly url: string;\n    clone(): Request;\n}\n\ndeclare var Request: {\n    prototype: Request;\n    new(input: RequestInfo, init?: RequestInit): Request;\n};\n\n/** This Fetch API interface represents the response to a request. */\ninterface Response extends Body {\n    readonly headers: Headers;\n    readonly ok: boolean;\n    readonly redirected: boolean;\n    readonly status: number;\n    readonly statusText: string;\n    readonly trailer: Promise<Headers>;\n    readonly type: ResponseType;\n    readonly url: string;\n    clone(): Response;\n}\n\ndeclare var Response: {\n    prototype: Response;\n    new(body?: BodyInit | null, init?: ResponseInit): Response;\n    error(): Response;\n    redirect(url: string, status?: number): Response;\n};\n\ninterface ServiceWorkerEventMap extends AbstractWorkerEventMap {\n    "statechange": Event;\n}\n\n/** This ServiceWorker API interface provides a reference to a service worker. Multiple browsing contexts (e.g. pages, workers, etc.) can be associated with the same service worker, each through a unique ServiceWorker object. */\ninterface ServiceWorker extends EventTarget, AbstractWorker {\n    onstatechange: ((this: ServiceWorker, ev: Event) => any) | null;\n    readonly scriptURL: string;\n    readonly state: ServiceWorkerState;\n    postMessage(message: any, transfer: Transferable[]): void;\n    postMessage(message: any, options?: PostMessageOptions): void;\n    addEventListener<K extends keyof ServiceWorkerEventMap>(type: K, listener: (this: ServiceWorker, ev: ServiceWorkerEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof ServiceWorkerEventMap>(type: K, listener: (this: ServiceWorker, ev: ServiceWorkerEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var ServiceWorker: {\n    prototype: ServiceWorker;\n    new(): ServiceWorker;\n};\n\ninterface ServiceWorkerContainerEventMap {\n    "controllerchange": Event;\n    "message": MessageEvent;\n    "messageerror": MessageEvent;\n}\n\n/** The ServiceWorkerContainer interface of the ServiceWorker API provides an object representing the service worker as an overall unit in the network ecosystem, including facilities to register, unregister and update service workers, and access the state of service workers and their registrations. */\ninterface ServiceWorkerContainer extends EventTarget {\n    readonly controller: ServiceWorker | null;\n    oncontrollerchange: ((this: ServiceWorkerContainer, ev: Event) => any) | null;\n    onmessage: ((this: ServiceWorkerContainer, ev: MessageEvent) => any) | null;\n    onmessageerror: ((this: ServiceWorkerContainer, ev: MessageEvent) => any) | null;\n    readonly ready: Promise<ServiceWorkerRegistration>;\n    getRegistration(clientURL?: string): Promise<ServiceWorkerRegistration | undefined>;\n    getRegistrations(): Promise<ReadonlyArray<ServiceWorkerRegistration>>;\n    register(scriptURL: string | URL, options?: RegistrationOptions): Promise<ServiceWorkerRegistration>;\n    startMessages(): void;\n    addEventListener<K extends keyof ServiceWorkerContainerEventMap>(type: K, listener: (this: ServiceWorkerContainer, ev: ServiceWorkerContainerEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof ServiceWorkerContainerEventMap>(type: K, listener: (this: ServiceWorkerContainer, ev: ServiceWorkerContainerEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var ServiceWorkerContainer: {\n    prototype: ServiceWorkerContainer;\n    new(): ServiceWorkerContainer;\n};\n\ninterface ServiceWorkerGlobalScopeEventMap extends WorkerGlobalScopeEventMap {\n    "activate": ExtendableEvent;\n    "fetch": FetchEvent;\n    "install": ExtendableEvent;\n    "message": ExtendableMessageEvent;\n    "messageerror": MessageEvent;\n    "notificationclick": NotificationEvent;\n    "notificationclose": NotificationEvent;\n    "push": PushEvent;\n    "sync": SyncEvent;\n}\n\n/** This ServiceWorker API interface represents the global execution context of a service worker. */\ninterface ServiceWorkerGlobalScope extends WorkerGlobalScope {\n    readonly clients: Clients;\n    onactivate: ((this: ServiceWorkerGlobalScope, ev: ExtendableEvent) => any) | null;\n    onfetch: ((this: ServiceWorkerGlobalScope, ev: FetchEvent) => any) | null;\n    oninstall: ((this: ServiceWorkerGlobalScope, ev: ExtendableEvent) => any) | null;\n    onmessage: ((this: ServiceWorkerGlobalScope, ev: ExtendableMessageEvent) => any) | null;\n    onmessageerror: ((this: ServiceWorkerGlobalScope, ev: MessageEvent) => any) | null;\n    onnotificationclick: ((this: ServiceWorkerGlobalScope, ev: NotificationEvent) => any) | null;\n    onnotificationclose: ((this: ServiceWorkerGlobalScope, ev: NotificationEvent) => any) | null;\n    onpush: ((this: ServiceWorkerGlobalScope, ev: PushEvent) => any) | null;\n    onsync: ((this: ServiceWorkerGlobalScope, ev: SyncEvent) => any) | null;\n    readonly registration: ServiceWorkerRegistration;\n    readonly serviceWorker: ServiceWorker;\n    skipWaiting(): Promise<void>;\n    addEventListener<K extends keyof ServiceWorkerGlobalScopeEventMap>(type: K, listener: (this: ServiceWorkerGlobalScope, ev: ServiceWorkerGlobalScopeEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof ServiceWorkerGlobalScopeEventMap>(type: K, listener: (this: ServiceWorkerGlobalScope, ev: ServiceWorkerGlobalScopeEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var ServiceWorkerGlobalScope: {\n    prototype: ServiceWorkerGlobalScope;\n    new(): ServiceWorkerGlobalScope;\n};\n\ninterface ServiceWorkerRegistrationEventMap {\n    "updatefound": Event;\n}\n\n/** This ServiceWorker API interface represents the service worker registration. You register a service worker to control one or more pages that share the same origin. */\ninterface ServiceWorkerRegistration extends EventTarget {\n    readonly active: ServiceWorker | null;\n    readonly installing: ServiceWorker | null;\n    readonly navigationPreload: NavigationPreloadManager;\n    onupdatefound: ((this: ServiceWorkerRegistration, ev: Event) => any) | null;\n    readonly pushManager: PushManager;\n    readonly scope: string;\n    readonly sync: SyncManager;\n    readonly updateViaCache: ServiceWorkerUpdateViaCache;\n    readonly waiting: ServiceWorker | null;\n    getNotifications(filter?: GetNotificationOptions): Promise<Notification[]>;\n    showNotification(title: string, options?: NotificationOptions): Promise<void>;\n    unregister(): Promise<boolean>;\n    update(): Promise<void>;\n    addEventListener<K extends keyof ServiceWorkerRegistrationEventMap>(type: K, listener: (this: ServiceWorkerRegistration, ev: ServiceWorkerRegistrationEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof ServiceWorkerRegistrationEventMap>(type: K, listener: (this: ServiceWorkerRegistration, ev: ServiceWorkerRegistrationEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var ServiceWorkerRegistration: {\n    prototype: ServiceWorkerRegistration;\n    new(): ServiceWorkerRegistration;\n};\n\ninterface SharedWorker extends EventTarget, AbstractWorker {\n    /**\n     * Returns sharedWorker\'s MessagePort object which can be used to communicate with the global environment.\n     */\n    readonly port: MessagePort;\n    addEventListener<K extends keyof AbstractWorkerEventMap>(type: K, listener: (this: SharedWorker, ev: AbstractWorkerEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof AbstractWorkerEventMap>(type: K, listener: (this: SharedWorker, ev: AbstractWorkerEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SharedWorker: {\n    prototype: SharedWorker;\n    new(scriptURL: string, options?: string | WorkerOptions): SharedWorker;\n};\n\ninterface SharedWorkerGlobalScopeEventMap extends WorkerGlobalScopeEventMap {\n    "connect": MessageEvent;\n}\n\ninterface SharedWorkerGlobalScope extends WorkerGlobalScope {\n    /**\n     * Returns sharedWorkerGlobal\'s name, i.e. the value given to the SharedWorker constructor. Multiple SharedWorker objects can correspond to the same shared worker (and SharedWorkerGlobalScope), by reusing the same name.\n     */\n    readonly name: string;\n    onconnect: ((this: SharedWorkerGlobalScope, ev: MessageEvent) => any) | null;\n    /**\n     * Aborts sharedWorkerGlobal.\n     */\n    close(): void;\n    addEventListener<K extends keyof SharedWorkerGlobalScopeEventMap>(type: K, listener: (this: SharedWorkerGlobalScope, ev: SharedWorkerGlobalScopeEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof SharedWorkerGlobalScopeEventMap>(type: K, listener: (this: SharedWorkerGlobalScope, ev: SharedWorkerGlobalScopeEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var SharedWorkerGlobalScope: {\n    prototype: SharedWorkerGlobalScope;\n    new(): SharedWorkerGlobalScope;\n};\n\ninterface StorageManager {\n    estimate(): Promise<StorageEstimate>;\n    persisted(): Promise<boolean>;\n}\n\ndeclare var StorageManager: {\n    prototype: StorageManager;\n    new(): StorageManager;\n};\n\n/** This Web Crypto API interface provides a number of low-level cryptographic functions. It is accessed via the Crypto.subtle properties available in a window context (via Window.crypto). */\ninterface SubtleCrypto {\n    decrypt(algorithm: AlgorithmIdentifier | RsaOaepParams | AesCtrParams | AesCbcParams | AesCmacParams | AesGcmParams | AesCfbParams, key: CryptoKey, data: Int8Array | Int16Array | Int32Array | Uint8Array | Uint16Array | Uint32Array | Uint8ClampedArray | Float32Array | Float64Array | DataView | ArrayBuffer): Promise<ArrayBuffer>;\n    deriveBits(algorithm: AlgorithmIdentifier | EcdhKeyDeriveParams | DhKeyDeriveParams | ConcatParams | HkdfParams | Pbkdf2Params, baseKey: CryptoKey, length: number): Promise<ArrayBuffer>;\n    deriveKey(algorithm: AlgorithmIdentifier | EcdhKeyDeriveParams | DhKeyDeriveParams | ConcatParams | HkdfParams | Pbkdf2Params, baseKey: CryptoKey, derivedKeyType: string | AesDerivedKeyParams | HmacImportParams | ConcatParams | HkdfParams | Pbkdf2Params, extractable: boolean, keyUsages: KeyUsage[]): Promise<CryptoKey>;\n    digest(algorithm: AlgorithmIdentifier, data: Int8Array | Int16Array | Int32Array | Uint8Array | Uint16Array | Uint32Array | Uint8ClampedArray | Float32Array | Float64Array | DataView | ArrayBuffer): Promise<ArrayBuffer>;\n    encrypt(algorithm: AlgorithmIdentifier | RsaOaepParams | AesCtrParams | AesCbcParams | AesCmacParams | AesGcmParams | AesCfbParams, key: CryptoKey, data: Int8Array | Int16Array | Int32Array | Uint8Array | Uint16Array | Uint32Array | Uint8ClampedArray | Float32Array | Float64Array | DataView | ArrayBuffer): Promise<ArrayBuffer>;\n    exportKey(format: "jwk", key: CryptoKey): Promise<JsonWebKey>;\n    exportKey(format: "raw" | "pkcs8" | "spki", key: CryptoKey): Promise<ArrayBuffer>;\n    exportKey(format: string, key: CryptoKey): Promise<JsonWebKey | ArrayBuffer>;\n    generateKey(algorithm: RsaHashedKeyGenParams | EcKeyGenParams | DhKeyGenParams, extractable: boolean, keyUsages: KeyUsage[]): Promise<CryptoKeyPair>;\n    generateKey(algorithm: AesKeyGenParams | HmacKeyGenParams | Pbkdf2Params, extractable: boolean, keyUsages: KeyUsage[]): Promise<CryptoKey>;\n    generateKey(algorithm: AlgorithmIdentifier, extractable: boolean, keyUsages: KeyUsage[]): Promise<CryptoKeyPair | CryptoKey>;\n    importKey(format: "jwk", keyData: JsonWebKey, algorithm: AlgorithmIdentifier | RsaHashedImportParams | EcKeyImportParams | HmacImportParams | DhImportKeyParams | AesKeyAlgorithm, extractable: boolean, keyUsages: KeyUsage[]): Promise<CryptoKey>;\n    importKey(format: "raw" | "pkcs8" | "spki", keyData: Int8Array | Int16Array | Int32Array | Uint8Array | Uint16Array | Uint32Array | Uint8ClampedArray | Float32Array | Float64Array | DataView | ArrayBuffer, algorithm: AlgorithmIdentifier | RsaHashedImportParams | EcKeyImportParams | HmacImportParams | DhImportKeyParams | AesKeyAlgorithm, extractable: boolean, keyUsages: KeyUsage[]): Promise<CryptoKey>;\n    importKey(format: string, keyData: JsonWebKey | Int8Array | Int16Array | Int32Array | Uint8Array | Uint16Array | Uint32Array | Uint8ClampedArray | Float32Array | Float64Array | DataView | ArrayBuffer, algorithm: AlgorithmIdentifier | RsaHashedImportParams | EcKeyImportParams | HmacImportParams | DhImportKeyParams | AesKeyAlgorithm, extractable: boolean, keyUsages: KeyUsage[]): Promise<CryptoKey>;\n    sign(algorithm: AlgorithmIdentifier | RsaPssParams | EcdsaParams | AesCmacParams, key: CryptoKey, data: Int8Array | Int16Array | Int32Array | Uint8Array | Uint16Array | Uint32Array | Uint8ClampedArray | Float32Array | Float64Array | DataView | ArrayBuffer): Promise<ArrayBuffer>;\n    unwrapKey(format: "raw" | "pkcs8" | "spki" | "jwk" | string, wrappedKey: Int8Array | Int16Array | Int32Array | Uint8Array | Uint16Array | Uint32Array | Uint8ClampedArray | Float32Array | Float64Array | DataView | ArrayBuffer, unwrappingKey: CryptoKey, unwrapAlgorithm: AlgorithmIdentifier | RsaOaepParams | AesCtrParams | AesCbcParams | AesCmacParams | AesGcmParams | AesCfbParams, unwrappedKeyAlgorithm: AlgorithmIdentifier | RsaHashedImportParams | EcKeyImportParams | HmacImportParams | DhImportKeyParams | AesKeyAlgorithm, extractable: boolean, keyUsages: KeyUsage[]): Promise<CryptoKey>;\n    verify(algorithm: AlgorithmIdentifier | RsaPssParams | EcdsaParams | AesCmacParams, key: CryptoKey, signature: Int8Array | Int16Array | Int32Array | Uint8Array | Uint16Array | Uint32Array | Uint8ClampedArray | Float32Array | Float64Array | DataView | ArrayBuffer, data: Int8Array | Int16Array | Int32Array | Uint8Array | Uint16Array | Uint32Array | Uint8ClampedArray | Float32Array | Float64Array | DataView | ArrayBuffer): Promise<boolean>;\n    wrapKey(format: "raw" | "pkcs8" | "spki" | "jwk" | string, key: CryptoKey, wrappingKey: CryptoKey, wrapAlgorithm: AlgorithmIdentifier | RsaOaepParams | AesCtrParams | AesCbcParams | AesCmacParams | AesGcmParams | AesCfbParams): Promise<ArrayBuffer>;\n}\n\ndeclare var SubtleCrypto: {\n    prototype: SubtleCrypto;\n    new(): SubtleCrypto;\n};\n\n/** A sync action that is dispatched on the ServiceWorkerGlobalScope of a ServiceWorker.  */\ninterface SyncEvent extends ExtendableEvent {\n    readonly lastChance: boolean;\n    readonly tag: string;\n}\n\ndeclare var SyncEvent: {\n    prototype: SyncEvent;\n    new(type: string, init: SyncEventInit): SyncEvent;\n};\n\n/** This ServiceWorker API interface provides an interface for registering and listing sync registrations. */\ninterface SyncManager {\n    getTags(): Promise<string[]>;\n    register(tag: string): Promise<void>;\n}\n\ndeclare var SyncManager: {\n    prototype: SyncManager;\n    new(): SyncManager;\n};\n\n/** A decoder for a specific method, that is a specific character encoding, like utf-8, iso-8859-2, koi8, cp1261, gbk, etc. A decoder takes a stream of bytes as input and emits a stream of code points. For a more scalable, non-native library, see StringView – a C-like representation of strings based on typed arrays. */\ninterface TextDecoder extends TextDecoderCommon {\n    /**\n     * Returns the result of running encoding\'s decoder. The method can be invoked zero or more times with options\'s stream set to true, and then once without options\'s stream (or set to false), to process a fragmented input. If the invocation without options\'s stream (or set to false) has no input, it\'s clearest to omit both arguments.\n     *\n     * ```\n     * var string = "", decoder = new TextDecoder(encoding), buffer;\n     * while(buffer = next_chunk()) {\n     *   string += decoder.decode(buffer, {stream:true});\n     * }\n     * string += decoder.decode(); // end-of-queue\n     * ```\n     *\n     * If the error mode is "fatal" and encoding\'s decoder returns error, throws a TypeError.\n     */\n    decode(input?: BufferSource, options?: TextDecodeOptions): string;\n}\n\ndeclare var TextDecoder: {\n    prototype: TextDecoder;\n    new(label?: string, options?: TextDecoderOptions): TextDecoder;\n};\n\ninterface TextDecoderCommon {\n    /**\n     * Returns encoding\'s name, lowercased.\n     */\n    readonly encoding: string;\n    /**\n     * Returns true if error mode is "fatal", otherwise false.\n     */\n    readonly fatal: boolean;\n    /**\n     * Returns the value of ignore BOM.\n     */\n    readonly ignoreBOM: boolean;\n}\n\ninterface TextDecoderStream extends GenericTransformStream, TextDecoderCommon {\n    readonly readable: ReadableStream<string>;\n    readonly writable: WritableStream<BufferSource>;\n}\n\ndeclare var TextDecoderStream: {\n    prototype: TextDecoderStream;\n    new(label?: string, options?: TextDecoderOptions): TextDecoderStream;\n};\n\n/** TextEncoder takes a stream of code points as input and emits a stream of bytes. For a more scalable, non-native library, see StringView – a C-like representation of strings based on typed arrays. */\ninterface TextEncoder extends TextEncoderCommon {\n    /**\n     * Returns the result of running UTF-8\'s encoder.\n     */\n    encode(input?: string): Uint8Array;\n    /**\n     * Runs the UTF-8 encoder on source, stores the result of that operation into destination, and returns the progress made as an object wherein read is the number of converted code units of source and written is the number of bytes modified in destination.\n     */\n    encodeInto(source: string, destination: Uint8Array): TextEncoderEncodeIntoResult;\n}\n\ndeclare var TextEncoder: {\n    prototype: TextEncoder;\n    new(): TextEncoder;\n};\n\ninterface TextEncoderCommon {\n    /**\n     * Returns "utf-8".\n     */\n    readonly encoding: string;\n}\n\ninterface TextEncoderStream extends GenericTransformStream, TextEncoderCommon {\n    readonly readable: ReadableStream<Uint8Array>;\n    readonly writable: WritableStream<string>;\n}\n\ndeclare var TextEncoderStream: {\n    prototype: TextEncoderStream;\n    new(): TextEncoderStream;\n};\n\n/** The dimensions of a piece of text in the canvas, as created by the CanvasRenderingContext2D.measureText() method. */\ninterface TextMetrics {\n    /**\n     * Returns the measurement described below.\n     */\n    readonly actualBoundingBoxAscent: number;\n    /**\n     * Returns the measurement described below.\n     */\n    readonly actualBoundingBoxDescent: number;\n    /**\n     * Returns the measurement described below.\n     */\n    readonly actualBoundingBoxLeft: number;\n    /**\n     * Returns the measurement described below.\n     */\n    readonly actualBoundingBoxRight: number;\n    /**\n     * Returns the measurement described below.\n     */\n    readonly width: number;\n}\n\ndeclare var TextMetrics: {\n    prototype: TextMetrics;\n    new(): TextMetrics;\n};\n\ninterface TransformStream<I = any, O = any> {\n    readonly readable: ReadableStream<O>;\n    readonly writable: WritableStream<I>;\n}\n\ndeclare var TransformStream: {\n    prototype: TransformStream;\n    new<I = any, O = any>(transformer?: Transformer<I, O>, writableStrategy?: QueuingStrategy<I>, readableStrategy?: QueuingStrategy<O>): TransformStream<I, O>;\n};\n\ninterface TransformStreamDefaultController<O = any> {\n    readonly desiredSize: number | null;\n    enqueue(chunk: O): void;\n    error(reason?: any): void;\n    terminate(): void;\n}\n\ndeclare var TransformStreamDefaultController: {\n    prototype: TransformStreamDefaultController;\n    new(): TransformStreamDefaultController;\n};\n\n/** The URL interface represents an object providing static methods used for creating object URLs. */\ninterface URL {\n    hash: string;\n    host: string;\n    hostname: string;\n    href: string;\n    toString(): string;\n    readonly origin: string;\n    password: string;\n    pathname: string;\n    port: string;\n    protocol: string;\n    search: string;\n    readonly searchParams: URLSearchParams;\n    username: string;\n    toJSON(): string;\n}\n\ndeclare var URL: {\n    prototype: URL;\n    new(url: string, base?: string | URL): URL;\n    createObjectURL(object: any): string;\n    revokeObjectURL(url: string): void;\n};\n\ninterface URLSearchParams {\n    /**\n     * Appends a specified key/value pair as a new search parameter.\n     */\n    append(name: string, value: string): void;\n    /**\n     * Deletes the given search parameter, and its associated value, from the list of all search parameters.\n     */\n    delete(name: string): void;\n    /**\n     * Returns the first value associated to the given search parameter.\n     */\n    get(name: string): string | null;\n    /**\n     * Returns all the values association with a given search parameter.\n     */\n    getAll(name: string): string[];\n    /**\n     * Returns a Boolean indicating if such a search parameter exists.\n     */\n    has(name: string): boolean;\n    /**\n     * Sets the value associated to a given search parameter to the given value. If there were several values, delete the others.\n     */\n    set(name: string, value: string): void;\n    sort(): void;\n    /**\n     * Returns a string containing a query string suitable for use in a URL. Does not include the question mark.\n     */\n    toString(): string;\n    forEach(callbackfn: (value: string, key: string, parent: URLSearchParams) => void, thisArg?: any): void;\n}\n\ndeclare var URLSearchParams: {\n    prototype: URLSearchParams;\n    new(init?: string[][] | Record<string, string> | string | URLSearchParams): URLSearchParams;\n    toString(): string;\n};\n\ninterface WEBGL_color_buffer_float {\n    readonly FRAMEBUFFER_ATTACHMENT_COMPONENT_TYPE_EXT: GLenum;\n    readonly RGBA32F_EXT: GLenum;\n    readonly UNSIGNED_NORMALIZED_EXT: GLenum;\n}\n\ninterface WEBGL_compressed_texture_astc {\n    getSupportedProfiles(): string[];\n    readonly COMPRESSED_RGBA_ASTC_10x10_KHR: GLenum;\n    readonly COMPRESSED_RGBA_ASTC_10x5_KHR: GLenum;\n    readonly COMPRESSED_RGBA_ASTC_10x6_KHR: GLenum;\n    readonly COMPRESSED_RGBA_ASTC_10x8_KHR: GLenum;\n    readonly COMPRESSED_RGBA_ASTC_12x10_KHR: GLenum;\n    readonly COMPRESSED_RGBA_ASTC_12x12_KHR: GLenum;\n    readonly COMPRESSED_RGBA_ASTC_4x4_KHR: GLenum;\n    readonly COMPRESSED_RGBA_ASTC_5x4_KHR: GLenum;\n    readonly COMPRESSED_RGBA_ASTC_5x5_KHR: GLenum;\n    readonly COMPRESSED_RGBA_ASTC_6x5_KHR: GLenum;\n    readonly COMPRESSED_RGBA_ASTC_6x6_KHR: GLenum;\n    readonly COMPRESSED_RGBA_ASTC_8x5_KHR: GLenum;\n    readonly COMPRESSED_RGBA_ASTC_8x6_KHR: GLenum;\n    readonly COMPRESSED_RGBA_ASTC_8x8_KHR: GLenum;\n    readonly COMPRESSED_SRGB8_ALPHA8_ASTC_10x10_KHR: GLenum;\n    readonly COMPRESSED_SRGB8_ALPHA8_ASTC_10x5_KHR: GLenum;\n    readonly COMPRESSED_SRGB8_ALPHA8_ASTC_10x6_KHR: GLenum;\n    readonly COMPRESSED_SRGB8_ALPHA8_ASTC_10x8_KHR: GLenum;\n    readonly COMPRESSED_SRGB8_ALPHA8_ASTC_12x10_KHR: GLenum;\n    readonly COMPRESSED_SRGB8_ALPHA8_ASTC_12x12_KHR: GLenum;\n    readonly COMPRESSED_SRGB8_ALPHA8_ASTC_4x4_KHR: GLenum;\n    readonly COMPRESSED_SRGB8_ALPHA8_ASTC_5x4_KHR: GLenum;\n    readonly COMPRESSED_SRGB8_ALPHA8_ASTC_5x5_KHR: GLenum;\n    readonly COMPRESSED_SRGB8_ALPHA8_ASTC_6x5_KHR: GLenum;\n    readonly COMPRESSED_SRGB8_ALPHA8_ASTC_6x6_KHR: GLenum;\n    readonly COMPRESSED_SRGB8_ALPHA8_ASTC_8x5_KHR: GLenum;\n    readonly COMPRESSED_SRGB8_ALPHA8_ASTC_8x6_KHR: GLenum;\n    readonly COMPRESSED_SRGB8_ALPHA8_ASTC_8x8_KHR: GLenum;\n}\n\n/** The WEBGL_compressed_texture_s3tc extension is part of the WebGL API and exposes four S3TC compressed texture formats. */\ninterface WEBGL_compressed_texture_s3tc {\n    readonly COMPRESSED_RGBA_S3TC_DXT1_EXT: GLenum;\n    readonly COMPRESSED_RGBA_S3TC_DXT3_EXT: GLenum;\n    readonly COMPRESSED_RGBA_S3TC_DXT5_EXT: GLenum;\n    readonly COMPRESSED_RGB_S3TC_DXT1_EXT: GLenum;\n}\n\ninterface WEBGL_compressed_texture_s3tc_srgb {\n    readonly COMPRESSED_SRGB_ALPHA_S3TC_DXT1_EXT: GLenum;\n    readonly COMPRESSED_SRGB_ALPHA_S3TC_DXT3_EXT: GLenum;\n    readonly COMPRESSED_SRGB_ALPHA_S3TC_DXT5_EXT: GLenum;\n    readonly COMPRESSED_SRGB_S3TC_DXT1_EXT: GLenum;\n}\n\n/** The WEBGL_debug_renderer_info extension is part of the WebGL API and exposes two constants with information about the graphics driver for debugging purposes. */\ninterface WEBGL_debug_renderer_info {\n    readonly UNMASKED_RENDERER_WEBGL: GLenum;\n    readonly UNMASKED_VENDOR_WEBGL: GLenum;\n}\n\ninterface WEBGL_debug_shaders {\n    getTranslatedShaderSource(shader: WebGLShader): string;\n}\n\n/** The WEBGL_depth_texture extension is part of the WebGL API and defines 2D depth and depth-stencil textures. */\ninterface WEBGL_depth_texture {\n    readonly UNSIGNED_INT_24_8_WEBGL: GLenum;\n}\n\ninterface WEBGL_draw_buffers {\n    drawBuffersWEBGL(buffers: GLenum[]): void;\n    readonly COLOR_ATTACHMENT0_WEBGL: GLenum;\n    readonly COLOR_ATTACHMENT10_WEBGL: GLenum;\n    readonly COLOR_ATTACHMENT11_WEBGL: GLenum;\n    readonly COLOR_ATTACHMENT12_WEBGL: GLenum;\n    readonly COLOR_ATTACHMENT13_WEBGL: GLenum;\n    readonly COLOR_ATTACHMENT14_WEBGL: GLenum;\n    readonly COLOR_ATTACHMENT15_WEBGL: GLenum;\n    readonly COLOR_ATTACHMENT1_WEBGL: GLenum;\n    readonly COLOR_ATTACHMENT2_WEBGL: GLenum;\n    readonly COLOR_ATTACHMENT3_WEBGL: GLenum;\n    readonly COLOR_ATTACHMENT4_WEBGL: GLenum;\n    readonly COLOR_ATTACHMENT5_WEBGL: GLenum;\n    readonly COLOR_ATTACHMENT6_WEBGL: GLenum;\n    readonly COLOR_ATTACHMENT7_WEBGL: GLenum;\n    readonly COLOR_ATTACHMENT8_WEBGL: GLenum;\n    readonly COLOR_ATTACHMENT9_WEBGL: GLenum;\n    readonly DRAW_BUFFER0_WEBGL: GLenum;\n    readonly DRAW_BUFFER10_WEBGL: GLenum;\n    readonly DRAW_BUFFER11_WEBGL: GLenum;\n    readonly DRAW_BUFFER12_WEBGL: GLenum;\n    readonly DRAW_BUFFER13_WEBGL: GLenum;\n    readonly DRAW_BUFFER14_WEBGL: GLenum;\n    readonly DRAW_BUFFER15_WEBGL: GLenum;\n    readonly DRAW_BUFFER1_WEBGL: GLenum;\n    readonly DRAW_BUFFER2_WEBGL: GLenum;\n    readonly DRAW_BUFFER3_WEBGL: GLenum;\n    readonly DRAW_BUFFER4_WEBGL: GLenum;\n    readonly DRAW_BUFFER5_WEBGL: GLenum;\n    readonly DRAW_BUFFER6_WEBGL: GLenum;\n    readonly DRAW_BUFFER7_WEBGL: GLenum;\n    readonly DRAW_BUFFER8_WEBGL: GLenum;\n    readonly DRAW_BUFFER9_WEBGL: GLenum;\n    readonly MAX_COLOR_ATTACHMENTS_WEBGL: GLenum;\n    readonly MAX_DRAW_BUFFERS_WEBGL: GLenum;\n}\n\ninterface WEBGL_lose_context {\n    loseContext(): void;\n    restoreContext(): void;\n}\n\ninterface WebGL2RenderingContext extends WebGL2RenderingContextBase, WebGL2RenderingContextOverloads, WebGLRenderingContextBase {\n}\n\ndeclare var WebGL2RenderingContext: {\n    prototype: WebGL2RenderingContext;\n    new(): WebGL2RenderingContext;\n    readonly ACTIVE_ATTRIBUTES: GLenum;\n    readonly ACTIVE_TEXTURE: GLenum;\n    readonly ACTIVE_UNIFORMS: GLenum;\n    readonly ALIASED_LINE_WIDTH_RANGE: GLenum;\n    readonly ALIASED_POINT_SIZE_RANGE: GLenum;\n    readonly ALPHA: GLenum;\n    readonly ALPHA_BITS: GLenum;\n    readonly ALWAYS: GLenum;\n    readonly ARRAY_BUFFER: GLenum;\n    readonly ARRAY_BUFFER_BINDING: GLenum;\n    readonly ATTACHED_SHADERS: GLenum;\n    readonly BACK: GLenum;\n    readonly BLEND: GLenum;\n    readonly BLEND_COLOR: GLenum;\n    readonly BLEND_DST_ALPHA: GLenum;\n    readonly BLEND_DST_RGB: GLenum;\n    readonly BLEND_EQUATION: GLenum;\n    readonly BLEND_EQUATION_ALPHA: GLenum;\n    readonly BLEND_EQUATION_RGB: GLenum;\n    readonly BLEND_SRC_ALPHA: GLenum;\n    readonly BLEND_SRC_RGB: GLenum;\n    readonly BLUE_BITS: GLenum;\n    readonly BOOL: GLenum;\n    readonly BOOL_VEC2: GLenum;\n    readonly BOOL_VEC3: GLenum;\n    readonly BOOL_VEC4: GLenum;\n    readonly BROWSER_DEFAULT_WEBGL: GLenum;\n    readonly BUFFER_SIZE: GLenum;\n    readonly BUFFER_USAGE: GLenum;\n    readonly BYTE: GLenum;\n    readonly CCW: GLenum;\n    readonly CLAMP_TO_EDGE: GLenum;\n    readonly COLOR_ATTACHMENT0: GLenum;\n    readonly COLOR_BUFFER_BIT: GLenum;\n    readonly COLOR_CLEAR_VALUE: GLenum;\n    readonly COLOR_WRITEMASK: GLenum;\n    readonly COMPILE_STATUS: GLenum;\n    readonly COMPRESSED_TEXTURE_FORMATS: GLenum;\n    readonly CONSTANT_ALPHA: GLenum;\n    readonly CONSTANT_COLOR: GLenum;\n    readonly CONTEXT_LOST_WEBGL: GLenum;\n    readonly CULL_FACE: GLenum;\n    readonly CULL_FACE_MODE: GLenum;\n    readonly CURRENT_PROGRAM: GLenum;\n    readonly CURRENT_VERTEX_ATTRIB: GLenum;\n    readonly CW: GLenum;\n    readonly DECR: GLenum;\n    readonly DECR_WRAP: GLenum;\n    readonly DELETE_STATUS: GLenum;\n    readonly DEPTH_ATTACHMENT: GLenum;\n    readonly DEPTH_BITS: GLenum;\n    readonly DEPTH_BUFFER_BIT: GLenum;\n    readonly DEPTH_CLEAR_VALUE: GLenum;\n    readonly DEPTH_COMPONENT: GLenum;\n    readonly DEPTH_COMPONENT16: GLenum;\n    readonly DEPTH_FUNC: GLenum;\n    readonly DEPTH_RANGE: GLenum;\n    readonly DEPTH_STENCIL: GLenum;\n    readonly DEPTH_STENCIL_ATTACHMENT: GLenum;\n    readonly DEPTH_TEST: GLenum;\n    readonly DEPTH_WRITEMASK: GLenum;\n    readonly DITHER: GLenum;\n    readonly DONT_CARE: GLenum;\n    readonly DST_ALPHA: GLenum;\n    readonly DST_COLOR: GLenum;\n    readonly DYNAMIC_DRAW: GLenum;\n    readonly ELEMENT_ARRAY_BUFFER: GLenum;\n    readonly ELEMENT_ARRAY_BUFFER_BINDING: GLenum;\n    readonly EQUAL: GLenum;\n    readonly FASTEST: GLenum;\n    readonly FLOAT: GLenum;\n    readonly FLOAT_MAT2: GLenum;\n    readonly FLOAT_MAT3: GLenum;\n    readonly FLOAT_MAT4: GLenum;\n    readonly FLOAT_VEC2: GLenum;\n    readonly FLOAT_VEC3: GLenum;\n    readonly FLOAT_VEC4: GLenum;\n    readonly FRAGMENT_SHADER: GLenum;\n    readonly FRAMEBUFFER: GLenum;\n    readonly FRAMEBUFFER_ATTACHMENT_OBJECT_NAME: GLenum;\n    readonly FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE: GLenum;\n    readonly FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE: GLenum;\n    readonly FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL: GLenum;\n    readonly FRAMEBUFFER_BINDING: GLenum;\n    readonly FRAMEBUFFER_COMPLETE: GLenum;\n    readonly FRAMEBUFFER_INCOMPLETE_ATTACHMENT: GLenum;\n    readonly FRAMEBUFFER_INCOMPLETE_DIMENSIONS: GLenum;\n    readonly FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT: GLenum;\n    readonly FRAMEBUFFER_UNSUPPORTED: GLenum;\n    readonly FRONT: GLenum;\n    readonly FRONT_AND_BACK: GLenum;\n    readonly FRONT_FACE: GLenum;\n    readonly FUNC_ADD: GLenum;\n    readonly FUNC_REVERSE_SUBTRACT: GLenum;\n    readonly FUNC_SUBTRACT: GLenum;\n    readonly GENERATE_MIPMAP_HINT: GLenum;\n    readonly GEQUAL: GLenum;\n    readonly GREATER: GLenum;\n    readonly GREEN_BITS: GLenum;\n    readonly HIGH_FLOAT: GLenum;\n    readonly HIGH_INT: GLenum;\n    readonly IMPLEMENTATION_COLOR_READ_FORMAT: GLenum;\n    readonly IMPLEMENTATION_COLOR_READ_TYPE: GLenum;\n    readonly INCR: GLenum;\n    readonly INCR_WRAP: GLenum;\n    readonly INT: GLenum;\n    readonly INT_VEC2: GLenum;\n    readonly INT_VEC3: GLenum;\n    readonly INT_VEC4: GLenum;\n    readonly INVALID_ENUM: GLenum;\n    readonly INVALID_FRAMEBUFFER_OPERATION: GLenum;\n    readonly INVALID_OPERATION: GLenum;\n    readonly INVALID_VALUE: GLenum;\n    readonly INVERT: GLenum;\n    readonly KEEP: GLenum;\n    readonly LEQUAL: GLenum;\n    readonly LESS: GLenum;\n    readonly LINEAR: GLenum;\n    readonly LINEAR_MIPMAP_LINEAR: GLenum;\n    readonly LINEAR_MIPMAP_NEAREST: GLenum;\n    readonly LINES: GLenum;\n    readonly LINE_LOOP: GLenum;\n    readonly LINE_STRIP: GLenum;\n    readonly LINE_WIDTH: GLenum;\n    readonly LINK_STATUS: GLenum;\n    readonly LOW_FLOAT: GLenum;\n    readonly LOW_INT: GLenum;\n    readonly LUMINANCE: GLenum;\n    readonly LUMINANCE_ALPHA: GLenum;\n    readonly MAX_COMBINED_TEXTURE_IMAGE_UNITS: GLenum;\n    readonly MAX_CUBE_MAP_TEXTURE_SIZE: GLenum;\n    readonly MAX_FRAGMENT_UNIFORM_VECTORS: GLenum;\n    readonly MAX_RENDERBUFFER_SIZE: GLenum;\n    readonly MAX_TEXTURE_IMAGE_UNITS: GLenum;\n    readonly MAX_TEXTURE_SIZE: GLenum;\n    readonly MAX_VARYING_VECTORS: GLenum;\n    readonly MAX_VERTEX_ATTRIBS: GLenum;\n    readonly MAX_VERTEX_TEXTURE_IMAGE_UNITS: GLenum;\n    readonly MAX_VERTEX_UNIFORM_VECTORS: GLenum;\n    readonly MAX_VIEWPORT_DIMS: GLenum;\n    readonly MEDIUM_FLOAT: GLenum;\n    readonly MEDIUM_INT: GLenum;\n    readonly MIRRORED_REPEAT: GLenum;\n    readonly NEAREST: GLenum;\n    readonly NEAREST_MIPMAP_LINEAR: GLenum;\n    readonly NEAREST_MIPMAP_NEAREST: GLenum;\n    readonly NEVER: GLenum;\n    readonly NICEST: GLenum;\n    readonly NONE: GLenum;\n    readonly NOTEQUAL: GLenum;\n    readonly NO_ERROR: GLenum;\n    readonly ONE: GLenum;\n    readonly ONE_MINUS_CONSTANT_ALPHA: GLenum;\n    readonly ONE_MINUS_CONSTANT_COLOR: GLenum;\n    readonly ONE_MINUS_DST_ALPHA: GLenum;\n    readonly ONE_MINUS_DST_COLOR: GLenum;\n    readonly ONE_MINUS_SRC_ALPHA: GLenum;\n    readonly ONE_MINUS_SRC_COLOR: GLenum;\n    readonly OUT_OF_MEMORY: GLenum;\n    readonly PACK_ALIGNMENT: GLenum;\n    readonly POINTS: GLenum;\n    readonly POLYGON_OFFSET_FACTOR: GLenum;\n    readonly POLYGON_OFFSET_FILL: GLenum;\n    readonly POLYGON_OFFSET_UNITS: GLenum;\n    readonly RED_BITS: GLenum;\n    readonly RENDERBUFFER: GLenum;\n    readonly RENDERBUFFER_ALPHA_SIZE: GLenum;\n    readonly RENDERBUFFER_BINDING: GLenum;\n    readonly RENDERBUFFER_BLUE_SIZE: GLenum;\n    readonly RENDERBUFFER_DEPTH_SIZE: GLenum;\n    readonly RENDERBUFFER_GREEN_SIZE: GLenum;\n    readonly RENDERBUFFER_HEIGHT: GLenum;\n    readonly RENDERBUFFER_INTERNAL_FORMAT: GLenum;\n    readonly RENDERBUFFER_RED_SIZE: GLenum;\n    readonly RENDERBUFFER_STENCIL_SIZE: GLenum;\n    readonly RENDERBUFFER_WIDTH: GLenum;\n    readonly RENDERER: GLenum;\n    readonly REPEAT: GLenum;\n    readonly REPLACE: GLenum;\n    readonly RGB: GLenum;\n    readonly RGB565: GLenum;\n    readonly RGB5_A1: GLenum;\n    readonly RGBA: GLenum;\n    readonly RGBA4: GLenum;\n    readonly SAMPLER_2D: GLenum;\n    readonly SAMPLER_CUBE: GLenum;\n    readonly SAMPLES: GLenum;\n    readonly SAMPLE_ALPHA_TO_COVERAGE: GLenum;\n    readonly SAMPLE_BUFFERS: GLenum;\n    readonly SAMPLE_COVERAGE: GLenum;\n    readonly SAMPLE_COVERAGE_INVERT: GLenum;\n    readonly SAMPLE_COVERAGE_VALUE: GLenum;\n    readonly SCISSOR_BOX: GLenum;\n    readonly SCISSOR_TEST: GLenum;\n    readonly SHADER_TYPE: GLenum;\n    readonly SHADING_LANGUAGE_VERSION: GLenum;\n    readonly SHORT: GLenum;\n    readonly SRC_ALPHA: GLenum;\n    readonly SRC_ALPHA_SATURATE: GLenum;\n    readonly SRC_COLOR: GLenum;\n    readonly STATIC_DRAW: GLenum;\n    readonly STENCIL_ATTACHMENT: GLenum;\n    readonly STENCIL_BACK_FAIL: GLenum;\n    readonly STENCIL_BACK_FUNC: GLenum;\n    readonly STENCIL_BACK_PASS_DEPTH_FAIL: GLenum;\n    readonly STENCIL_BACK_PASS_DEPTH_PASS: GLenum;\n    readonly STENCIL_BACK_REF: GLenum;\n    readonly STENCIL_BACK_VALUE_MASK: GLenum;\n    readonly STENCIL_BACK_WRITEMASK: GLenum;\n    readonly STENCIL_BITS: GLenum;\n    readonly STENCIL_BUFFER_BIT: GLenum;\n    readonly STENCIL_CLEAR_VALUE: GLenum;\n    readonly STENCIL_FAIL: GLenum;\n    readonly STENCIL_FUNC: GLenum;\n    readonly STENCIL_INDEX8: GLenum;\n    readonly STENCIL_PASS_DEPTH_FAIL: GLenum;\n    readonly STENCIL_PASS_DEPTH_PASS: GLenum;\n    readonly STENCIL_REF: GLenum;\n    readonly STENCIL_TEST: GLenum;\n    readonly STENCIL_VALUE_MASK: GLenum;\n    readonly STENCIL_WRITEMASK: GLenum;\n    readonly STREAM_DRAW: GLenum;\n    readonly SUBPIXEL_BITS: GLenum;\n    readonly TEXTURE: GLenum;\n    readonly TEXTURE0: GLenum;\n    readonly TEXTURE1: GLenum;\n    readonly TEXTURE10: GLenum;\n    readonly TEXTURE11: GLenum;\n    readonly TEXTURE12: GLenum;\n    readonly TEXTURE13: GLenum;\n    readonly TEXTURE14: GLenum;\n    readonly TEXTURE15: GLenum;\n    readonly TEXTURE16: GLenum;\n    readonly TEXTURE17: GLenum;\n    readonly TEXTURE18: GLenum;\n    readonly TEXTURE19: GLenum;\n    readonly TEXTURE2: GLenum;\n    readonly TEXTURE20: GLenum;\n    readonly TEXTURE21: GLenum;\n    readonly TEXTURE22: GLenum;\n    readonly TEXTURE23: GLenum;\n    readonly TEXTURE24: GLenum;\n    readonly TEXTURE25: GLenum;\n    readonly TEXTURE26: GLenum;\n    readonly TEXTURE27: GLenum;\n    readonly TEXTURE28: GLenum;\n    readonly TEXTURE29: GLenum;\n    readonly TEXTURE3: GLenum;\n    readonly TEXTURE30: GLenum;\n    readonly TEXTURE31: GLenum;\n    readonly TEXTURE4: GLenum;\n    readonly TEXTURE5: GLenum;\n    readonly TEXTURE6: GLenum;\n    readonly TEXTURE7: GLenum;\n    readonly TEXTURE8: GLenum;\n    readonly TEXTURE9: GLenum;\n    readonly TEXTURE_2D: GLenum;\n    readonly TEXTURE_BINDING_2D: GLenum;\n    readonly TEXTURE_BINDING_CUBE_MAP: GLenum;\n    readonly TEXTURE_CUBE_MAP: GLenum;\n    readonly TEXTURE_CUBE_MAP_NEGATIVE_X: GLenum;\n    readonly TEXTURE_CUBE_MAP_NEGATIVE_Y: GLenum;\n    readonly TEXTURE_CUBE_MAP_NEGATIVE_Z: GLenum;\n    readonly TEXTURE_CUBE_MAP_POSITIVE_X: GLenum;\n    readonly TEXTURE_CUBE_MAP_POSITIVE_Y: GLenum;\n    readonly TEXTURE_CUBE_MAP_POSITIVE_Z: GLenum;\n    readonly TEXTURE_MAG_FILTER: GLenum;\n    readonly TEXTURE_MIN_FILTER: GLenum;\n    readonly TEXTURE_WRAP_S: GLenum;\n    readonly TEXTURE_WRAP_T: GLenum;\n    readonly TRIANGLES: GLenum;\n    readonly TRIANGLE_FAN: GLenum;\n    readonly TRIANGLE_STRIP: GLenum;\n    readonly UNPACK_ALIGNMENT: GLenum;\n    readonly UNPACK_COLORSPACE_CONVERSION_WEBGL: GLenum;\n    readonly UNPACK_FLIP_Y_WEBGL: GLenum;\n    readonly UNPACK_PREMULTIPLY_ALPHA_WEBGL: GLenum;\n    readonly UNSIGNED_BYTE: GLenum;\n    readonly UNSIGNED_INT: GLenum;\n    readonly UNSIGNED_SHORT: GLenum;\n    readonly UNSIGNED_SHORT_4_4_4_4: GLenum;\n    readonly UNSIGNED_SHORT_5_5_5_1: GLenum;\n    readonly UNSIGNED_SHORT_5_6_5: GLenum;\n    readonly VALIDATE_STATUS: GLenum;\n    readonly VENDOR: GLenum;\n    readonly VERSION: GLenum;\n    readonly VERTEX_ATTRIB_ARRAY_BUFFER_BINDING: GLenum;\n    readonly VERTEX_ATTRIB_ARRAY_ENABLED: GLenum;\n    readonly VERTEX_ATTRIB_ARRAY_NORMALIZED: GLenum;\n    readonly VERTEX_ATTRIB_ARRAY_POINTER: GLenum;\n    readonly VERTEX_ATTRIB_ARRAY_SIZE: GLenum;\n    readonly VERTEX_ATTRIB_ARRAY_STRIDE: GLenum;\n    readonly VERTEX_ATTRIB_ARRAY_TYPE: GLenum;\n    readonly VERTEX_SHADER: GLenum;\n    readonly VIEWPORT: GLenum;\n    readonly ZERO: GLenum;\n    readonly ACTIVE_UNIFORM_BLOCKS: GLenum;\n    readonly ALREADY_SIGNALED: GLenum;\n    readonly ANY_SAMPLES_PASSED: GLenum;\n    readonly ANY_SAMPLES_PASSED_CONSERVATIVE: GLenum;\n    readonly COLOR: GLenum;\n    readonly COLOR_ATTACHMENT1: GLenum;\n    readonly COLOR_ATTACHMENT10: GLenum;\n    readonly COLOR_ATTACHMENT11: GLenum;\n    readonly COLOR_ATTACHMENT12: GLenum;\n    readonly COLOR_ATTACHMENT13: GLenum;\n    readonly COLOR_ATTACHMENT14: GLenum;\n    readonly COLOR_ATTACHMENT15: GLenum;\n    readonly COLOR_ATTACHMENT2: GLenum;\n    readonly COLOR_ATTACHMENT3: GLenum;\n    readonly COLOR_ATTACHMENT4: GLenum;\n    readonly COLOR_ATTACHMENT5: GLenum;\n    readonly COLOR_ATTACHMENT6: GLenum;\n    readonly COLOR_ATTACHMENT7: GLenum;\n    readonly COLOR_ATTACHMENT8: GLenum;\n    readonly COLOR_ATTACHMENT9: GLenum;\n    readonly COMPARE_REF_TO_TEXTURE: GLenum;\n    readonly CONDITION_SATISFIED: GLenum;\n    readonly COPY_READ_BUFFER: GLenum;\n    readonly COPY_READ_BUFFER_BINDING: GLenum;\n    readonly COPY_WRITE_BUFFER: GLenum;\n    readonly COPY_WRITE_BUFFER_BINDING: GLenum;\n    readonly CURRENT_QUERY: GLenum;\n    readonly DEPTH: GLenum;\n    readonly DEPTH24_STENCIL8: GLenum;\n    readonly DEPTH32F_STENCIL8: GLenum;\n    readonly DEPTH_COMPONENT24: GLenum;\n    readonly DEPTH_COMPONENT32F: GLenum;\n    readonly DRAW_BUFFER0: GLenum;\n    readonly DRAW_BUFFER1: GLenum;\n    readonly DRAW_BUFFER10: GLenum;\n    readonly DRAW_BUFFER11: GLenum;\n    readonly DRAW_BUFFER12: GLenum;\n    readonly DRAW_BUFFER13: GLenum;\n    readonly DRAW_BUFFER14: GLenum;\n    readonly DRAW_BUFFER15: GLenum;\n    readonly DRAW_BUFFER2: GLenum;\n    readonly DRAW_BUFFER3: GLenum;\n    readonly DRAW_BUFFER4: GLenum;\n    readonly DRAW_BUFFER5: GLenum;\n    readonly DRAW_BUFFER6: GLenum;\n    readonly DRAW_BUFFER7: GLenum;\n    readonly DRAW_BUFFER8: GLenum;\n    readonly DRAW_BUFFER9: GLenum;\n    readonly DRAW_FRAMEBUFFER: GLenum;\n    readonly DRAW_FRAMEBUFFER_BINDING: GLenum;\n    readonly DYNAMIC_COPY: GLenum;\n    readonly DYNAMIC_READ: GLenum;\n    readonly FLOAT_32_UNSIGNED_INT_24_8_REV: GLenum;\n    readonly FLOAT_MAT2x3: GLenum;\n    readonly FLOAT_MAT2x4: GLenum;\n    readonly FLOAT_MAT3x2: GLenum;\n    readonly FLOAT_MAT3x4: GLenum;\n    readonly FLOAT_MAT4x2: GLenum;\n    readonly FLOAT_MAT4x3: GLenum;\n    readonly FRAGMENT_SHADER_DERIVATIVE_HINT: GLenum;\n    readonly FRAMEBUFFER_ATTACHMENT_ALPHA_SIZE: GLenum;\n    readonly FRAMEBUFFER_ATTACHMENT_BLUE_SIZE: GLenum;\n    readonly FRAMEBUFFER_ATTACHMENT_COLOR_ENCODING: GLenum;\n    readonly FRAMEBUFFER_ATTACHMENT_COMPONENT_TYPE: GLenum;\n    readonly FRAMEBUFFER_ATTACHMENT_DEPTH_SIZE: GLenum;\n    readonly FRAMEBUFFER_ATTACHMENT_GREEN_SIZE: GLenum;\n    readonly FRAMEBUFFER_ATTACHMENT_RED_SIZE: GLenum;\n    readonly FRAMEBUFFER_ATTACHMENT_STENCIL_SIZE: GLenum;\n    readonly FRAMEBUFFER_ATTACHMENT_TEXTURE_LAYER: GLenum;\n    readonly FRAMEBUFFER_DEFAULT: GLenum;\n    readonly FRAMEBUFFER_INCOMPLETE_MULTISAMPLE: GLenum;\n    readonly HALF_FLOAT: GLenum;\n    readonly INTERLEAVED_ATTRIBS: GLenum;\n    readonly INT_2_10_10_10_REV: GLenum;\n    readonly INT_SAMPLER_2D: GLenum;\n    readonly INT_SAMPLER_2D_ARRAY: GLenum;\n    readonly INT_SAMPLER_3D: GLenum;\n    readonly INT_SAMPLER_CUBE: GLenum;\n    readonly INVALID_INDEX: GLenum;\n    readonly MAX: GLenum;\n    readonly MAX_3D_TEXTURE_SIZE: GLenum;\n    readonly MAX_ARRAY_TEXTURE_LAYERS: GLenum;\n    readonly MAX_CLIENT_WAIT_TIMEOUT_WEBGL: GLenum;\n    readonly MAX_COLOR_ATTACHMENTS: GLenum;\n    readonly MAX_COMBINED_FRAGMENT_UNIFORM_COMPONENTS: GLenum;\n    readonly MAX_COMBINED_UNIFORM_BLOCKS: GLenum;\n    readonly MAX_COMBINED_VERTEX_UNIFORM_COMPONENTS: GLenum;\n    readonly MAX_DRAW_BUFFERS: GLenum;\n    readonly MAX_ELEMENTS_INDICES: GLenum;\n    readonly MAX_ELEMENTS_VERTICES: GLenum;\n    readonly MAX_ELEMENT_INDEX: GLenum;\n    readonly MAX_FRAGMENT_INPUT_COMPONENTS: GLenum;\n    readonly MAX_FRAGMENT_UNIFORM_BLOCKS: GLenum;\n    readonly MAX_FRAGMENT_UNIFORM_COMPONENTS: GLenum;\n    readonly MAX_PROGRAM_TEXEL_OFFSET: GLenum;\n    readonly MAX_SAMPLES: GLenum;\n    readonly MAX_SERVER_WAIT_TIMEOUT: GLenum;\n    readonly MAX_TEXTURE_LOD_BIAS: GLenum;\n    readonly MAX_TRANSFORM_FEEDBACK_INTERLEAVED_COMPONENTS: GLenum;\n    readonly MAX_TRANSFORM_FEEDBACK_SEPARATE_ATTRIBS: GLenum;\n    readonly MAX_TRANSFORM_FEEDBACK_SEPARATE_COMPONENTS: GLenum;\n    readonly MAX_UNIFORM_BLOCK_SIZE: GLenum;\n    readonly MAX_UNIFORM_BUFFER_BINDINGS: GLenum;\n    readonly MAX_VARYING_COMPONENTS: GLenum;\n    readonly MAX_VERTEX_OUTPUT_COMPONENTS: GLenum;\n    readonly MAX_VERTEX_UNIFORM_BLOCKS: GLenum;\n    readonly MAX_VERTEX_UNIFORM_COMPONENTS: GLenum;\n    readonly MIN: GLenum;\n    readonly MIN_PROGRAM_TEXEL_OFFSET: GLenum;\n    readonly OBJECT_TYPE: GLenum;\n    readonly PACK_ROW_LENGTH: GLenum;\n    readonly PACK_SKIP_PIXELS: GLenum;\n    readonly PACK_SKIP_ROWS: GLenum;\n    readonly PIXEL_PACK_BUFFER: GLenum;\n    readonly PIXEL_PACK_BUFFER_BINDING: GLenum;\n    readonly PIXEL_UNPACK_BUFFER: GLenum;\n    readonly PIXEL_UNPACK_BUFFER_BINDING: GLenum;\n    readonly QUERY_RESULT: GLenum;\n    readonly QUERY_RESULT_AVAILABLE: GLenum;\n    readonly R11F_G11F_B10F: GLenum;\n    readonly R16F: GLenum;\n    readonly R16I: GLenum;\n    readonly R16UI: GLenum;\n    readonly R32F: GLenum;\n    readonly R32I: GLenum;\n    readonly R32UI: GLenum;\n    readonly R8: GLenum;\n    readonly R8I: GLenum;\n    readonly R8UI: GLenum;\n    readonly R8_SNORM: GLenum;\n    readonly RASTERIZER_DISCARD: GLenum;\n    readonly READ_BUFFER: GLenum;\n    readonly READ_FRAMEBUFFER: GLenum;\n    readonly READ_FRAMEBUFFER_BINDING: GLenum;\n    readonly RED: GLenum;\n    readonly RED_INTEGER: GLenum;\n    readonly RENDERBUFFER_SAMPLES: GLenum;\n    readonly RG: GLenum;\n    readonly RG16F: GLenum;\n    readonly RG16I: GLenum;\n    readonly RG16UI: GLenum;\n    readonly RG32F: GLenum;\n    readonly RG32I: GLenum;\n    readonly RG32UI: GLenum;\n    readonly RG8: GLenum;\n    readonly RG8I: GLenum;\n    readonly RG8UI: GLenum;\n    readonly RG8_SNORM: GLenum;\n    readonly RGB10_A2: GLenum;\n    readonly RGB10_A2UI: GLenum;\n    readonly RGB16F: GLenum;\n    readonly RGB16I: GLenum;\n    readonly RGB16UI: GLenum;\n    readonly RGB32F: GLenum;\n    readonly RGB32I: GLenum;\n    readonly RGB32UI: GLenum;\n    readonly RGB8: GLenum;\n    readonly RGB8I: GLenum;\n    readonly RGB8UI: GLenum;\n    readonly RGB8_SNORM: GLenum;\n    readonly RGB9_E5: GLenum;\n    readonly RGBA16F: GLenum;\n    readonly RGBA16I: GLenum;\n    readonly RGBA16UI: GLenum;\n    readonly RGBA32F: GLenum;\n    readonly RGBA32I: GLenum;\n    readonly RGBA32UI: GLenum;\n    readonly RGBA8: GLenum;\n    readonly RGBA8I: GLenum;\n    readonly RGBA8UI: GLenum;\n    readonly RGBA8_SNORM: GLenum;\n    readonly RGBA_INTEGER: GLenum;\n    readonly RGB_INTEGER: GLenum;\n    readonly RG_INTEGER: GLenum;\n    readonly SAMPLER_2D_ARRAY: GLenum;\n    readonly SAMPLER_2D_ARRAY_SHADOW: GLenum;\n    readonly SAMPLER_2D_SHADOW: GLenum;\n    readonly SAMPLER_3D: GLenum;\n    readonly SAMPLER_BINDING: GLenum;\n    readonly SAMPLER_CUBE_SHADOW: GLenum;\n    readonly SEPARATE_ATTRIBS: GLenum;\n    readonly SIGNALED: GLenum;\n    readonly SIGNED_NORMALIZED: GLenum;\n    readonly SRGB: GLenum;\n    readonly SRGB8: GLenum;\n    readonly SRGB8_ALPHA8: GLenum;\n    readonly STATIC_COPY: GLenum;\n    readonly STATIC_READ: GLenum;\n    readonly STENCIL: GLenum;\n    readonly STREAM_COPY: GLenum;\n    readonly STREAM_READ: GLenum;\n    readonly SYNC_CONDITION: GLenum;\n    readonly SYNC_FENCE: GLenum;\n    readonly SYNC_FLAGS: GLenum;\n    readonly SYNC_FLUSH_COMMANDS_BIT: GLenum;\n    readonly SYNC_GPU_COMMANDS_COMPLETE: GLenum;\n    readonly SYNC_STATUS: GLenum;\n    readonly TEXTURE_2D_ARRAY: GLenum;\n    readonly TEXTURE_3D: GLenum;\n    readonly TEXTURE_BASE_LEVEL: GLenum;\n    readonly TEXTURE_BINDING_2D_ARRAY: GLenum;\n    readonly TEXTURE_BINDING_3D: GLenum;\n    readonly TEXTURE_COMPARE_FUNC: GLenum;\n    readonly TEXTURE_COMPARE_MODE: GLenum;\n    readonly TEXTURE_IMMUTABLE_FORMAT: GLenum;\n    readonly TEXTURE_IMMUTABLE_LEVELS: GLenum;\n    readonly TEXTURE_MAX_LEVEL: GLenum;\n    readonly TEXTURE_MAX_LOD: GLenum;\n    readonly TEXTURE_MIN_LOD: GLenum;\n    readonly TEXTURE_WRAP_R: GLenum;\n    readonly TIMEOUT_EXPIRED: GLenum;\n    readonly TIMEOUT_IGNORED: GLint64;\n    readonly TRANSFORM_FEEDBACK: GLenum;\n    readonly TRANSFORM_FEEDBACK_ACTIVE: GLenum;\n    readonly TRANSFORM_FEEDBACK_BINDING: GLenum;\n    readonly TRANSFORM_FEEDBACK_BUFFER: GLenum;\n    readonly TRANSFORM_FEEDBACK_BUFFER_BINDING: GLenum;\n    readonly TRANSFORM_FEEDBACK_BUFFER_MODE: GLenum;\n    readonly TRANSFORM_FEEDBACK_BUFFER_SIZE: GLenum;\n    readonly TRANSFORM_FEEDBACK_BUFFER_START: GLenum;\n    readonly TRANSFORM_FEEDBACK_PAUSED: GLenum;\n    readonly TRANSFORM_FEEDBACK_PRIMITIVES_WRITTEN: GLenum;\n    readonly TRANSFORM_FEEDBACK_VARYINGS: GLenum;\n    readonly UNIFORM_ARRAY_STRIDE: GLenum;\n    readonly UNIFORM_BLOCK_ACTIVE_UNIFORMS: GLenum;\n    readonly UNIFORM_BLOCK_ACTIVE_UNIFORM_INDICES: GLenum;\n    readonly UNIFORM_BLOCK_BINDING: GLenum;\n    readonly UNIFORM_BLOCK_DATA_SIZE: GLenum;\n    readonly UNIFORM_BLOCK_INDEX: GLenum;\n    readonly UNIFORM_BLOCK_REFERENCED_BY_FRAGMENT_SHADER: GLenum;\n    readonly UNIFORM_BLOCK_REFERENCED_BY_VERTEX_SHADER: GLenum;\n    readonly UNIFORM_BUFFER: GLenum;\n    readonly UNIFORM_BUFFER_BINDING: GLenum;\n    readonly UNIFORM_BUFFER_OFFSET_ALIGNMENT: GLenum;\n    readonly UNIFORM_BUFFER_SIZE: GLenum;\n    readonly UNIFORM_BUFFER_START: GLenum;\n    readonly UNIFORM_IS_ROW_MAJOR: GLenum;\n    readonly UNIFORM_MATRIX_STRIDE: GLenum;\n    readonly UNIFORM_OFFSET: GLenum;\n    readonly UNIFORM_SIZE: GLenum;\n    readonly UNIFORM_TYPE: GLenum;\n    readonly UNPACK_IMAGE_HEIGHT: GLenum;\n    readonly UNPACK_ROW_LENGTH: GLenum;\n    readonly UNPACK_SKIP_IMAGES: GLenum;\n    readonly UNPACK_SKIP_PIXELS: GLenum;\n    readonly UNPACK_SKIP_ROWS: GLenum;\n    readonly UNSIGNALED: GLenum;\n    readonly UNSIGNED_INT_10F_11F_11F_REV: GLenum;\n    readonly UNSIGNED_INT_24_8: GLenum;\n    readonly UNSIGNED_INT_2_10_10_10_REV: GLenum;\n    readonly UNSIGNED_INT_5_9_9_9_REV: GLenum;\n    readonly UNSIGNED_INT_SAMPLER_2D: GLenum;\n    readonly UNSIGNED_INT_SAMPLER_2D_ARRAY: GLenum;\n    readonly UNSIGNED_INT_SAMPLER_3D: GLenum;\n    readonly UNSIGNED_INT_SAMPLER_CUBE: GLenum;\n    readonly UNSIGNED_INT_VEC2: GLenum;\n    readonly UNSIGNED_INT_VEC3: GLenum;\n    readonly UNSIGNED_INT_VEC4: GLenum;\n    readonly UNSIGNED_NORMALIZED: GLenum;\n    readonly VERTEX_ARRAY_BINDING: GLenum;\n    readonly VERTEX_ATTRIB_ARRAY_DIVISOR: GLenum;\n    readonly VERTEX_ATTRIB_ARRAY_INTEGER: GLenum;\n    readonly WAIT_FAILED: GLenum;\n};\n\ninterface WebGL2RenderingContextBase {\n    beginQuery(target: GLenum, query: WebGLQuery): void;\n    beginTransformFeedback(primitiveMode: GLenum): void;\n    bindBufferBase(target: GLenum, index: GLuint, buffer: WebGLBuffer | null): void;\n    bindBufferRange(target: GLenum, index: GLuint, buffer: WebGLBuffer | null, offset: GLintptr, size: GLsizeiptr): void;\n    bindSampler(unit: GLuint, sampler: WebGLSampler | null): void;\n    bindTransformFeedback(target: GLenum, tf: WebGLTransformFeedback | null): void;\n    bindVertexArray(array: WebGLVertexArrayObject | null): void;\n    blitFramebuffer(srcX0: GLint, srcY0: GLint, srcX1: GLint, srcY1: GLint, dstX0: GLint, dstY0: GLint, dstX1: GLint, dstY1: GLint, mask: GLbitfield, filter: GLenum): void;\n    clearBufferfi(buffer: GLenum, drawbuffer: GLint, depth: GLfloat, stencil: GLint): void;\n    clearBufferfv(buffer: GLenum, drawbuffer: GLint, values: Float32List, srcOffset?: GLuint): void;\n    clearBufferiv(buffer: GLenum, drawbuffer: GLint, values: Int32List, srcOffset?: GLuint): void;\n    clearBufferuiv(buffer: GLenum, drawbuffer: GLint, values: Uint32List, srcOffset?: GLuint): void;\n    clientWaitSync(sync: WebGLSync, flags: GLbitfield, timeout: GLuint64): GLenum;\n    compressedTexImage3D(target: GLenum, level: GLint, internalformat: GLenum, width: GLsizei, height: GLsizei, depth: GLsizei, border: GLint, imageSize: GLsizei, offset: GLintptr): void;\n    compressedTexImage3D(target: GLenum, level: GLint, internalformat: GLenum, width: GLsizei, height: GLsizei, depth: GLsizei, border: GLint, srcData: ArrayBufferView, srcOffset?: GLuint, srcLengthOverride?: GLuint): void;\n    compressedTexSubImage3D(target: GLenum, level: GLint, xoffset: GLint, yoffset: GLint, zoffset: GLint, width: GLsizei, height: GLsizei, depth: GLsizei, format: GLenum, imageSize: GLsizei, offset: GLintptr): void;\n    compressedTexSubImage3D(target: GLenum, level: GLint, xoffset: GLint, yoffset: GLint, zoffset: GLint, width: GLsizei, height: GLsizei, depth: GLsizei, format: GLenum, srcData: ArrayBufferView, srcOffset?: GLuint, srcLengthOverride?: GLuint): void;\n    copyBufferSubData(readTarget: GLenum, writeTarget: GLenum, readOffset: GLintptr, writeOffset: GLintptr, size: GLsizeiptr): void;\n    copyTexSubImage3D(target: GLenum, level: GLint, xoffset: GLint, yoffset: GLint, zoffset: GLint, x: GLint, y: GLint, width: GLsizei, height: GLsizei): void;\n    createQuery(): WebGLQuery | null;\n    createSampler(): WebGLSampler | null;\n    createTransformFeedback(): WebGLTransformFeedback | null;\n    createVertexArray(): WebGLVertexArrayObject | null;\n    deleteQuery(query: WebGLQuery | null): void;\n    deleteSampler(sampler: WebGLSampler | null): void;\n    deleteSync(sync: WebGLSync | null): void;\n    deleteTransformFeedback(tf: WebGLTransformFeedback | null): void;\n    deleteVertexArray(vertexArray: WebGLVertexArrayObject | null): void;\n    drawArraysInstanced(mode: GLenum, first: GLint, count: GLsizei, instanceCount: GLsizei): void;\n    drawBuffers(buffers: GLenum[]): void;\n    drawElementsInstanced(mode: GLenum, count: GLsizei, type: GLenum, offset: GLintptr, instanceCount: GLsizei): void;\n    drawRangeElements(mode: GLenum, start: GLuint, end: GLuint, count: GLsizei, type: GLenum, offset: GLintptr): void;\n    endQuery(target: GLenum): void;\n    endTransformFeedback(): void;\n    fenceSync(condition: GLenum, flags: GLbitfield): WebGLSync | null;\n    framebufferTextureLayer(target: GLenum, attachment: GLenum, texture: WebGLTexture | null, level: GLint, layer: GLint): void;\n    getActiveUniformBlockName(program: WebGLProgram, uniformBlockIndex: GLuint): string | null;\n    getActiveUniformBlockParameter(program: WebGLProgram, uniformBlockIndex: GLuint, pname: GLenum): any;\n    getActiveUniforms(program: WebGLProgram, uniformIndices: GLuint[], pname: GLenum): any;\n    getBufferSubData(target: GLenum, srcByteOffset: GLintptr, dstBuffer: ArrayBufferView, dstOffset?: GLuint, length?: GLuint): void;\n    getFragDataLocation(program: WebGLProgram, name: string): GLint;\n    getIndexedParameter(target: GLenum, index: GLuint): any;\n    getInternalformatParameter(target: GLenum, internalformat: GLenum, pname: GLenum): any;\n    getQuery(target: GLenum, pname: GLenum): WebGLQuery | null;\n    getQueryParameter(query: WebGLQuery, pname: GLenum): any;\n    getSamplerParameter(sampler: WebGLSampler, pname: GLenum): any;\n    getSyncParameter(sync: WebGLSync, pname: GLenum): any;\n    getTransformFeedbackVarying(program: WebGLProgram, index: GLuint): WebGLActiveInfo | null;\n    getUniformBlockIndex(program: WebGLProgram, uniformBlockName: string): GLuint;\n    getUniformIndices(program: WebGLProgram, uniformNames: string[]): GLuint[] | null;\n    invalidateFramebuffer(target: GLenum, attachments: GLenum[]): void;\n    invalidateSubFramebuffer(target: GLenum, attachments: GLenum[], x: GLint, y: GLint, width: GLsizei, height: GLsizei): void;\n    isQuery(query: WebGLQuery | null): GLboolean;\n    isSampler(sampler: WebGLSampler | null): GLboolean;\n    isSync(sync: WebGLSync | null): GLboolean;\n    isTransformFeedback(tf: WebGLTransformFeedback | null): GLboolean;\n    isVertexArray(vertexArray: WebGLVertexArrayObject | null): GLboolean;\n    pauseTransformFeedback(): void;\n    readBuffer(src: GLenum): void;\n    renderbufferStorageMultisample(target: GLenum, samples: GLsizei, internalformat: GLenum, width: GLsizei, height: GLsizei): void;\n    resumeTransformFeedback(): void;\n    samplerParameterf(sampler: WebGLSampler, pname: GLenum, param: GLfloat): void;\n    samplerParameteri(sampler: WebGLSampler, pname: GLenum, param: GLint): void;\n    texImage3D(target: GLenum, level: GLint, internalformat: GLint, width: GLsizei, height: GLsizei, depth: GLsizei, border: GLint, format: GLenum, type: GLenum, pboOffset: GLintptr): void;\n    texImage3D(target: GLenum, level: GLint, internalformat: GLint, width: GLsizei, height: GLsizei, depth: GLsizei, border: GLint, format: GLenum, type: GLenum, source: TexImageSource): void;\n    texImage3D(target: GLenum, level: GLint, internalformat: GLint, width: GLsizei, height: GLsizei, depth: GLsizei, border: GLint, format: GLenum, type: GLenum, srcData: ArrayBufferView | null): void;\n    texImage3D(target: GLenum, level: GLint, internalformat: GLint, width: GLsizei, height: GLsizei, depth: GLsizei, border: GLint, format: GLenum, type: GLenum, srcData: ArrayBufferView, srcOffset: GLuint): void;\n    texStorage2D(target: GLenum, levels: GLsizei, internalformat: GLenum, width: GLsizei, height: GLsizei): void;\n    texStorage3D(target: GLenum, levels: GLsizei, internalformat: GLenum, width: GLsizei, height: GLsizei, depth: GLsizei): void;\n    texSubImage3D(target: GLenum, level: GLint, xoffset: GLint, yoffset: GLint, zoffset: GLint, width: GLsizei, height: GLsizei, depth: GLsizei, format: GLenum, type: GLenum, pboOffset: GLintptr): void;\n    texSubImage3D(target: GLenum, level: GLint, xoffset: GLint, yoffset: GLint, zoffset: GLint, width: GLsizei, height: GLsizei, depth: GLsizei, format: GLenum, type: GLenum, source: TexImageSource): void;\n    texSubImage3D(target: GLenum, level: GLint, xoffset: GLint, yoffset: GLint, zoffset: GLint, width: GLsizei, height: GLsizei, depth: GLsizei, format: GLenum, type: GLenum, srcData: ArrayBufferView | null, srcOffset?: GLuint): void;\n    transformFeedbackVaryings(program: WebGLProgram, varyings: string[], bufferMode: GLenum): void;\n    uniform1ui(location: WebGLUniformLocation | null, v0: GLuint): void;\n    uniform1uiv(location: WebGLUniformLocation | null, data: Uint32List, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniform2ui(location: WebGLUniformLocation | null, v0: GLuint, v1: GLuint): void;\n    uniform2uiv(location: WebGLUniformLocation | null, data: Uint32List, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniform3ui(location: WebGLUniformLocation | null, v0: GLuint, v1: GLuint, v2: GLuint): void;\n    uniform3uiv(location: WebGLUniformLocation | null, data: Uint32List, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniform4ui(location: WebGLUniformLocation | null, v0: GLuint, v1: GLuint, v2: GLuint, v3: GLuint): void;\n    uniform4uiv(location: WebGLUniformLocation | null, data: Uint32List, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniformBlockBinding(program: WebGLProgram, uniformBlockIndex: GLuint, uniformBlockBinding: GLuint): void;\n    uniformMatrix2x3fv(location: WebGLUniformLocation | null, transpose: GLboolean, data: Float32List, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniformMatrix2x4fv(location: WebGLUniformLocation | null, transpose: GLboolean, data: Float32List, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniformMatrix3x2fv(location: WebGLUniformLocation | null, transpose: GLboolean, data: Float32List, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniformMatrix3x4fv(location: WebGLUniformLocation | null, transpose: GLboolean, data: Float32List, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniformMatrix4x2fv(location: WebGLUniformLocation | null, transpose: GLboolean, data: Float32List, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniformMatrix4x3fv(location: WebGLUniformLocation | null, transpose: GLboolean, data: Float32List, srcOffset?: GLuint, srcLength?: GLuint): void;\n    vertexAttribDivisor(index: GLuint, divisor: GLuint): void;\n    vertexAttribI4i(index: GLuint, x: GLint, y: GLint, z: GLint, w: GLint): void;\n    vertexAttribI4iv(index: GLuint, values: Int32List): void;\n    vertexAttribI4ui(index: GLuint, x: GLuint, y: GLuint, z: GLuint, w: GLuint): void;\n    vertexAttribI4uiv(index: GLuint, values: Uint32List): void;\n    vertexAttribIPointer(index: GLuint, size: GLint, type: GLenum, stride: GLsizei, offset: GLintptr): void;\n    waitSync(sync: WebGLSync, flags: GLbitfield, timeout: GLint64): void;\n    readonly ACTIVE_UNIFORM_BLOCKS: GLenum;\n    readonly ALREADY_SIGNALED: GLenum;\n    readonly ANY_SAMPLES_PASSED: GLenum;\n    readonly ANY_SAMPLES_PASSED_CONSERVATIVE: GLenum;\n    readonly COLOR: GLenum;\n    readonly COLOR_ATTACHMENT1: GLenum;\n    readonly COLOR_ATTACHMENT10: GLenum;\n    readonly COLOR_ATTACHMENT11: GLenum;\n    readonly COLOR_ATTACHMENT12: GLenum;\n    readonly COLOR_ATTACHMENT13: GLenum;\n    readonly COLOR_ATTACHMENT14: GLenum;\n    readonly COLOR_ATTACHMENT15: GLenum;\n    readonly COLOR_ATTACHMENT2: GLenum;\n    readonly COLOR_ATTACHMENT3: GLenum;\n    readonly COLOR_ATTACHMENT4: GLenum;\n    readonly COLOR_ATTACHMENT5: GLenum;\n    readonly COLOR_ATTACHMENT6: GLenum;\n    readonly COLOR_ATTACHMENT7: GLenum;\n    readonly COLOR_ATTACHMENT8: GLenum;\n    readonly COLOR_ATTACHMENT9: GLenum;\n    readonly COMPARE_REF_TO_TEXTURE: GLenum;\n    readonly CONDITION_SATISFIED: GLenum;\n    readonly COPY_READ_BUFFER: GLenum;\n    readonly COPY_READ_BUFFER_BINDING: GLenum;\n    readonly COPY_WRITE_BUFFER: GLenum;\n    readonly COPY_WRITE_BUFFER_BINDING: GLenum;\n    readonly CURRENT_QUERY: GLenum;\n    readonly DEPTH: GLenum;\n    readonly DEPTH24_STENCIL8: GLenum;\n    readonly DEPTH32F_STENCIL8: GLenum;\n    readonly DEPTH_COMPONENT24: GLenum;\n    readonly DEPTH_COMPONENT32F: GLenum;\n    readonly DRAW_BUFFER0: GLenum;\n    readonly DRAW_BUFFER1: GLenum;\n    readonly DRAW_BUFFER10: GLenum;\n    readonly DRAW_BUFFER11: GLenum;\n    readonly DRAW_BUFFER12: GLenum;\n    readonly DRAW_BUFFER13: GLenum;\n    readonly DRAW_BUFFER14: GLenum;\n    readonly DRAW_BUFFER15: GLenum;\n    readonly DRAW_BUFFER2: GLenum;\n    readonly DRAW_BUFFER3: GLenum;\n    readonly DRAW_BUFFER4: GLenum;\n    readonly DRAW_BUFFER5: GLenum;\n    readonly DRAW_BUFFER6: GLenum;\n    readonly DRAW_BUFFER7: GLenum;\n    readonly DRAW_BUFFER8: GLenum;\n    readonly DRAW_BUFFER9: GLenum;\n    readonly DRAW_FRAMEBUFFER: GLenum;\n    readonly DRAW_FRAMEBUFFER_BINDING: GLenum;\n    readonly DYNAMIC_COPY: GLenum;\n    readonly DYNAMIC_READ: GLenum;\n    readonly FLOAT_32_UNSIGNED_INT_24_8_REV: GLenum;\n    readonly FLOAT_MAT2x3: GLenum;\n    readonly FLOAT_MAT2x4: GLenum;\n    readonly FLOAT_MAT3x2: GLenum;\n    readonly FLOAT_MAT3x4: GLenum;\n    readonly FLOAT_MAT4x2: GLenum;\n    readonly FLOAT_MAT4x3: GLenum;\n    readonly FRAGMENT_SHADER_DERIVATIVE_HINT: GLenum;\n    readonly FRAMEBUFFER_ATTACHMENT_ALPHA_SIZE: GLenum;\n    readonly FRAMEBUFFER_ATTACHMENT_BLUE_SIZE: GLenum;\n    readonly FRAMEBUFFER_ATTACHMENT_COLOR_ENCODING: GLenum;\n    readonly FRAMEBUFFER_ATTACHMENT_COMPONENT_TYPE: GLenum;\n    readonly FRAMEBUFFER_ATTACHMENT_DEPTH_SIZE: GLenum;\n    readonly FRAMEBUFFER_ATTACHMENT_GREEN_SIZE: GLenum;\n    readonly FRAMEBUFFER_ATTACHMENT_RED_SIZE: GLenum;\n    readonly FRAMEBUFFER_ATTACHMENT_STENCIL_SIZE: GLenum;\n    readonly FRAMEBUFFER_ATTACHMENT_TEXTURE_LAYER: GLenum;\n    readonly FRAMEBUFFER_DEFAULT: GLenum;\n    readonly FRAMEBUFFER_INCOMPLETE_MULTISAMPLE: GLenum;\n    readonly HALF_FLOAT: GLenum;\n    readonly INTERLEAVED_ATTRIBS: GLenum;\n    readonly INT_2_10_10_10_REV: GLenum;\n    readonly INT_SAMPLER_2D: GLenum;\n    readonly INT_SAMPLER_2D_ARRAY: GLenum;\n    readonly INT_SAMPLER_3D: GLenum;\n    readonly INT_SAMPLER_CUBE: GLenum;\n    readonly INVALID_INDEX: GLenum;\n    readonly MAX: GLenum;\n    readonly MAX_3D_TEXTURE_SIZE: GLenum;\n    readonly MAX_ARRAY_TEXTURE_LAYERS: GLenum;\n    readonly MAX_CLIENT_WAIT_TIMEOUT_WEBGL: GLenum;\n    readonly MAX_COLOR_ATTACHMENTS: GLenum;\n    readonly MAX_COMBINED_FRAGMENT_UNIFORM_COMPONENTS: GLenum;\n    readonly MAX_COMBINED_UNIFORM_BLOCKS: GLenum;\n    readonly MAX_COMBINED_VERTEX_UNIFORM_COMPONENTS: GLenum;\n    readonly MAX_DRAW_BUFFERS: GLenum;\n    readonly MAX_ELEMENTS_INDICES: GLenum;\n    readonly MAX_ELEMENTS_VERTICES: GLenum;\n    readonly MAX_ELEMENT_INDEX: GLenum;\n    readonly MAX_FRAGMENT_INPUT_COMPONENTS: GLenum;\n    readonly MAX_FRAGMENT_UNIFORM_BLOCKS: GLenum;\n    readonly MAX_FRAGMENT_UNIFORM_COMPONENTS: GLenum;\n    readonly MAX_PROGRAM_TEXEL_OFFSET: GLenum;\n    readonly MAX_SAMPLES: GLenum;\n    readonly MAX_SERVER_WAIT_TIMEOUT: GLenum;\n    readonly MAX_TEXTURE_LOD_BIAS: GLenum;\n    readonly MAX_TRANSFORM_FEEDBACK_INTERLEAVED_COMPONENTS: GLenum;\n    readonly MAX_TRANSFORM_FEEDBACK_SEPARATE_ATTRIBS: GLenum;\n    readonly MAX_TRANSFORM_FEEDBACK_SEPARATE_COMPONENTS: GLenum;\n    readonly MAX_UNIFORM_BLOCK_SIZE: GLenum;\n    readonly MAX_UNIFORM_BUFFER_BINDINGS: GLenum;\n    readonly MAX_VARYING_COMPONENTS: GLenum;\n    readonly MAX_VERTEX_OUTPUT_COMPONENTS: GLenum;\n    readonly MAX_VERTEX_UNIFORM_BLOCKS: GLenum;\n    readonly MAX_VERTEX_UNIFORM_COMPONENTS: GLenum;\n    readonly MIN: GLenum;\n    readonly MIN_PROGRAM_TEXEL_OFFSET: GLenum;\n    readonly OBJECT_TYPE: GLenum;\n    readonly PACK_ROW_LENGTH: GLenum;\n    readonly PACK_SKIP_PIXELS: GLenum;\n    readonly PACK_SKIP_ROWS: GLenum;\n    readonly PIXEL_PACK_BUFFER: GLenum;\n    readonly PIXEL_PACK_BUFFER_BINDING: GLenum;\n    readonly PIXEL_UNPACK_BUFFER: GLenum;\n    readonly PIXEL_UNPACK_BUFFER_BINDING: GLenum;\n    readonly QUERY_RESULT: GLenum;\n    readonly QUERY_RESULT_AVAILABLE: GLenum;\n    readonly R11F_G11F_B10F: GLenum;\n    readonly R16F: GLenum;\n    readonly R16I: GLenum;\n    readonly R16UI: GLenum;\n    readonly R32F: GLenum;\n    readonly R32I: GLenum;\n    readonly R32UI: GLenum;\n    readonly R8: GLenum;\n    readonly R8I: GLenum;\n    readonly R8UI: GLenum;\n    readonly R8_SNORM: GLenum;\n    readonly RASTERIZER_DISCARD: GLenum;\n    readonly READ_BUFFER: GLenum;\n    readonly READ_FRAMEBUFFER: GLenum;\n    readonly READ_FRAMEBUFFER_BINDING: GLenum;\n    readonly RED: GLenum;\n    readonly RED_INTEGER: GLenum;\n    readonly RENDERBUFFER_SAMPLES: GLenum;\n    readonly RG: GLenum;\n    readonly RG16F: GLenum;\n    readonly RG16I: GLenum;\n    readonly RG16UI: GLenum;\n    readonly RG32F: GLenum;\n    readonly RG32I: GLenum;\n    readonly RG32UI: GLenum;\n    readonly RG8: GLenum;\n    readonly RG8I: GLenum;\n    readonly RG8UI: GLenum;\n    readonly RG8_SNORM: GLenum;\n    readonly RGB10_A2: GLenum;\n    readonly RGB10_A2UI: GLenum;\n    readonly RGB16F: GLenum;\n    readonly RGB16I: GLenum;\n    readonly RGB16UI: GLenum;\n    readonly RGB32F: GLenum;\n    readonly RGB32I: GLenum;\n    readonly RGB32UI: GLenum;\n    readonly RGB8: GLenum;\n    readonly RGB8I: GLenum;\n    readonly RGB8UI: GLenum;\n    readonly RGB8_SNORM: GLenum;\n    readonly RGB9_E5: GLenum;\n    readonly RGBA16F: GLenum;\n    readonly RGBA16I: GLenum;\n    readonly RGBA16UI: GLenum;\n    readonly RGBA32F: GLenum;\n    readonly RGBA32I: GLenum;\n    readonly RGBA32UI: GLenum;\n    readonly RGBA8: GLenum;\n    readonly RGBA8I: GLenum;\n    readonly RGBA8UI: GLenum;\n    readonly RGBA8_SNORM: GLenum;\n    readonly RGBA_INTEGER: GLenum;\n    readonly RGB_INTEGER: GLenum;\n    readonly RG_INTEGER: GLenum;\n    readonly SAMPLER_2D_ARRAY: GLenum;\n    readonly SAMPLER_2D_ARRAY_SHADOW: GLenum;\n    readonly SAMPLER_2D_SHADOW: GLenum;\n    readonly SAMPLER_3D: GLenum;\n    readonly SAMPLER_BINDING: GLenum;\n    readonly SAMPLER_CUBE_SHADOW: GLenum;\n    readonly SEPARATE_ATTRIBS: GLenum;\n    readonly SIGNALED: GLenum;\n    readonly SIGNED_NORMALIZED: GLenum;\n    readonly SRGB: GLenum;\n    readonly SRGB8: GLenum;\n    readonly SRGB8_ALPHA8: GLenum;\n    readonly STATIC_COPY: GLenum;\n    readonly STATIC_READ: GLenum;\n    readonly STENCIL: GLenum;\n    readonly STREAM_COPY: GLenum;\n    readonly STREAM_READ: GLenum;\n    readonly SYNC_CONDITION: GLenum;\n    readonly SYNC_FENCE: GLenum;\n    readonly SYNC_FLAGS: GLenum;\n    readonly SYNC_FLUSH_COMMANDS_BIT: GLenum;\n    readonly SYNC_GPU_COMMANDS_COMPLETE: GLenum;\n    readonly SYNC_STATUS: GLenum;\n    readonly TEXTURE_2D_ARRAY: GLenum;\n    readonly TEXTURE_3D: GLenum;\n    readonly TEXTURE_BASE_LEVEL: GLenum;\n    readonly TEXTURE_BINDING_2D_ARRAY: GLenum;\n    readonly TEXTURE_BINDING_3D: GLenum;\n    readonly TEXTURE_COMPARE_FUNC: GLenum;\n    readonly TEXTURE_COMPARE_MODE: GLenum;\n    readonly TEXTURE_IMMUTABLE_FORMAT: GLenum;\n    readonly TEXTURE_IMMUTABLE_LEVELS: GLenum;\n    readonly TEXTURE_MAX_LEVEL: GLenum;\n    readonly TEXTURE_MAX_LOD: GLenum;\n    readonly TEXTURE_MIN_LOD: GLenum;\n    readonly TEXTURE_WRAP_R: GLenum;\n    readonly TIMEOUT_EXPIRED: GLenum;\n    readonly TIMEOUT_IGNORED: GLint64;\n    readonly TRANSFORM_FEEDBACK: GLenum;\n    readonly TRANSFORM_FEEDBACK_ACTIVE: GLenum;\n    readonly TRANSFORM_FEEDBACK_BINDING: GLenum;\n    readonly TRANSFORM_FEEDBACK_BUFFER: GLenum;\n    readonly TRANSFORM_FEEDBACK_BUFFER_BINDING: GLenum;\n    readonly TRANSFORM_FEEDBACK_BUFFER_MODE: GLenum;\n    readonly TRANSFORM_FEEDBACK_BUFFER_SIZE: GLenum;\n    readonly TRANSFORM_FEEDBACK_BUFFER_START: GLenum;\n    readonly TRANSFORM_FEEDBACK_PAUSED: GLenum;\n    readonly TRANSFORM_FEEDBACK_PRIMITIVES_WRITTEN: GLenum;\n    readonly TRANSFORM_FEEDBACK_VARYINGS: GLenum;\n    readonly UNIFORM_ARRAY_STRIDE: GLenum;\n    readonly UNIFORM_BLOCK_ACTIVE_UNIFORMS: GLenum;\n    readonly UNIFORM_BLOCK_ACTIVE_UNIFORM_INDICES: GLenum;\n    readonly UNIFORM_BLOCK_BINDING: GLenum;\n    readonly UNIFORM_BLOCK_DATA_SIZE: GLenum;\n    readonly UNIFORM_BLOCK_INDEX: GLenum;\n    readonly UNIFORM_BLOCK_REFERENCED_BY_FRAGMENT_SHADER: GLenum;\n    readonly UNIFORM_BLOCK_REFERENCED_BY_VERTEX_SHADER: GLenum;\n    readonly UNIFORM_BUFFER: GLenum;\n    readonly UNIFORM_BUFFER_BINDING: GLenum;\n    readonly UNIFORM_BUFFER_OFFSET_ALIGNMENT: GLenum;\n    readonly UNIFORM_BUFFER_SIZE: GLenum;\n    readonly UNIFORM_BUFFER_START: GLenum;\n    readonly UNIFORM_IS_ROW_MAJOR: GLenum;\n    readonly UNIFORM_MATRIX_STRIDE: GLenum;\n    readonly UNIFORM_OFFSET: GLenum;\n    readonly UNIFORM_SIZE: GLenum;\n    readonly UNIFORM_TYPE: GLenum;\n    readonly UNPACK_IMAGE_HEIGHT: GLenum;\n    readonly UNPACK_ROW_LENGTH: GLenum;\n    readonly UNPACK_SKIP_IMAGES: GLenum;\n    readonly UNPACK_SKIP_PIXELS: GLenum;\n    readonly UNPACK_SKIP_ROWS: GLenum;\n    readonly UNSIGNALED: GLenum;\n    readonly UNSIGNED_INT_10F_11F_11F_REV: GLenum;\n    readonly UNSIGNED_INT_24_8: GLenum;\n    readonly UNSIGNED_INT_2_10_10_10_REV: GLenum;\n    readonly UNSIGNED_INT_5_9_9_9_REV: GLenum;\n    readonly UNSIGNED_INT_SAMPLER_2D: GLenum;\n    readonly UNSIGNED_INT_SAMPLER_2D_ARRAY: GLenum;\n    readonly UNSIGNED_INT_SAMPLER_3D: GLenum;\n    readonly UNSIGNED_INT_SAMPLER_CUBE: GLenum;\n    readonly UNSIGNED_INT_VEC2: GLenum;\n    readonly UNSIGNED_INT_VEC3: GLenum;\n    readonly UNSIGNED_INT_VEC4: GLenum;\n    readonly UNSIGNED_NORMALIZED: GLenum;\n    readonly VERTEX_ARRAY_BINDING: GLenum;\n    readonly VERTEX_ATTRIB_ARRAY_DIVISOR: GLenum;\n    readonly VERTEX_ATTRIB_ARRAY_INTEGER: GLenum;\n    readonly WAIT_FAILED: GLenum;\n}\n\ninterface WebGL2RenderingContextOverloads {\n    bufferData(target: GLenum, size: GLsizeiptr, usage: GLenum): void;\n    bufferData(target: GLenum, srcData: BufferSource | null, usage: GLenum): void;\n    bufferData(target: GLenum, srcData: ArrayBufferView, usage: GLenum, srcOffset: GLuint, length?: GLuint): void;\n    bufferSubData(target: GLenum, dstByteOffset: GLintptr, srcData: BufferSource): void;\n    bufferSubData(target: GLenum, dstByteOffset: GLintptr, srcData: ArrayBufferView, srcOffset: GLuint, length?: GLuint): void;\n    compressedTexImage2D(target: GLenum, level: GLint, internalformat: GLenum, width: GLsizei, height: GLsizei, border: GLint, imageSize: GLsizei, offset: GLintptr): void;\n    compressedTexImage2D(target: GLenum, level: GLint, internalformat: GLenum, width: GLsizei, height: GLsizei, border: GLint, srcData: ArrayBufferView, srcOffset?: GLuint, srcLengthOverride?: GLuint): void;\n    compressedTexSubImage2D(target: GLenum, level: GLint, xoffset: GLint, yoffset: GLint, width: GLsizei, height: GLsizei, format: GLenum, imageSize: GLsizei, offset: GLintptr): void;\n    compressedTexSubImage2D(target: GLenum, level: GLint, xoffset: GLint, yoffset: GLint, width: GLsizei, height: GLsizei, format: GLenum, srcData: ArrayBufferView, srcOffset?: GLuint, srcLengthOverride?: GLuint): void;\n    readPixels(x: GLint, y: GLint, width: GLsizei, height: GLsizei, format: GLenum, type: GLenum, dstData: ArrayBufferView | null): void;\n    readPixels(x: GLint, y: GLint, width: GLsizei, height: GLsizei, format: GLenum, type: GLenum, offset: GLintptr): void;\n    readPixels(x: GLint, y: GLint, width: GLsizei, height: GLsizei, format: GLenum, type: GLenum, dstData: ArrayBufferView, dstOffset: GLuint): void;\n    texImage2D(target: GLenum, level: GLint, internalformat: GLint, width: GLsizei, height: GLsizei, border: GLint, format: GLenum, type: GLenum, pixels: ArrayBufferView | null): void;\n    texImage2D(target: GLenum, level: GLint, internalformat: GLint, format: GLenum, type: GLenum, source: TexImageSource): void;\n    texImage2D(target: GLenum, level: GLint, internalformat: GLint, width: GLsizei, height: GLsizei, border: GLint, format: GLenum, type: GLenum, pboOffset: GLintptr): void;\n    texImage2D(target: GLenum, level: GLint, internalformat: GLint, width: GLsizei, height: GLsizei, border: GLint, format: GLenum, type: GLenum, source: TexImageSource): void;\n    texImage2D(target: GLenum, level: GLint, internalformat: GLint, width: GLsizei, height: GLsizei, border: GLint, format: GLenum, type: GLenum, srcData: ArrayBufferView, srcOffset: GLuint): void;\n    texSubImage2D(target: GLenum, level: GLint, xoffset: GLint, yoffset: GLint, width: GLsizei, height: GLsizei, format: GLenum, type: GLenum, pixels: ArrayBufferView | null): void;\n    texSubImage2D(target: GLenum, level: GLint, xoffset: GLint, yoffset: GLint, format: GLenum, type: GLenum, source: TexImageSource): void;\n    texSubImage2D(target: GLenum, level: GLint, xoffset: GLint, yoffset: GLint, width: GLsizei, height: GLsizei, format: GLenum, type: GLenum, pboOffset: GLintptr): void;\n    texSubImage2D(target: GLenum, level: GLint, xoffset: GLint, yoffset: GLint, width: GLsizei, height: GLsizei, format: GLenum, type: GLenum, source: TexImageSource): void;\n    texSubImage2D(target: GLenum, level: GLint, xoffset: GLint, yoffset: GLint, width: GLsizei, height: GLsizei, format: GLenum, type: GLenum, srcData: ArrayBufferView, srcOffset: GLuint): void;\n    uniform1fv(location: WebGLUniformLocation | null, data: Float32List, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniform1iv(location: WebGLUniformLocation | null, data: Int32List, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniform2fv(location: WebGLUniformLocation | null, data: Float32List, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniform2iv(location: WebGLUniformLocation | null, data: Int32List, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniform3fv(location: WebGLUniformLocation | null, data: Float32List, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniform3iv(location: WebGLUniformLocation | null, data: Int32List, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniform4fv(location: WebGLUniformLocation | null, data: Float32List, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniform4iv(location: WebGLUniformLocation | null, data: Int32List, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniformMatrix2fv(location: WebGLUniformLocation | null, transpose: GLboolean, data: Float32List, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniformMatrix3fv(location: WebGLUniformLocation | null, transpose: GLboolean, data: Float32List, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniformMatrix4fv(location: WebGLUniformLocation | null, transpose: GLboolean, data: Float32List, srcOffset?: GLuint, srcLength?: GLuint): void;\n}\n\n/** Part of the WebGL API and represents the information returned by calling the WebGLRenderingContext.getActiveAttrib() and WebGLRenderingContext.getActiveUniform() methods. */\ninterface WebGLActiveInfo {\n    readonly name: string;\n    readonly size: GLint;\n    readonly type: GLenum;\n}\n\ndeclare var WebGLActiveInfo: {\n    prototype: WebGLActiveInfo;\n    new(): WebGLActiveInfo;\n};\n\n/** Part of the WebGL API and represents an opaque buffer object storing data such as vertices or colors. */\ninterface WebGLBuffer {\n}\n\ndeclare var WebGLBuffer: {\n    prototype: WebGLBuffer;\n    new(): WebGLBuffer;\n};\n\n/** The WebContextEvent interface is part of the WebGL API and is an interface for an event that is generated in response to a status change to the WebGL rendering context. */\ninterface WebGLContextEvent extends Event {\n    readonly statusMessage: string;\n}\n\ndeclare var WebGLContextEvent: {\n    prototype: WebGLContextEvent;\n    new(type: string, eventInit?: WebGLContextEventInit): WebGLContextEvent;\n};\n\n/** Part of the WebGL API and represents a collection of buffers that serve as a rendering destination. */\ninterface WebGLFramebuffer {\n}\n\ndeclare var WebGLFramebuffer: {\n    prototype: WebGLFramebuffer;\n    new(): WebGLFramebuffer;\n};\n\n/** The WebGLProgram is part of the WebGL API and is a combination of two compiled WebGLShaders consisting of a vertex shader and a fragment shader (both written in GLSL). */\ninterface WebGLProgram {\n}\n\ndeclare var WebGLProgram: {\n    prototype: WebGLProgram;\n    new(): WebGLProgram;\n};\n\ninterface WebGLQuery {\n}\n\ndeclare var WebGLQuery: {\n    prototype: WebGLQuery;\n    new(): WebGLQuery;\n};\n\n/** Part of the WebGL API and represents a buffer that can contain an image, or can be source or target of an rendering operation. */\ninterface WebGLRenderbuffer {\n}\n\ndeclare var WebGLRenderbuffer: {\n    prototype: WebGLRenderbuffer;\n    new(): WebGLRenderbuffer;\n};\n\n/** Provides an interface to the OpenGL ES 2.0 graphics rendering context for the drawing surface of an HTML <canvas> element. */\ninterface WebGLRenderingContext extends WebGLRenderingContextBase, WebGLRenderingContextOverloads {\n}\n\ndeclare var WebGLRenderingContext: {\n    prototype: WebGLRenderingContext;\n    new(): WebGLRenderingContext;\n    readonly ACTIVE_ATTRIBUTES: GLenum;\n    readonly ACTIVE_TEXTURE: GLenum;\n    readonly ACTIVE_UNIFORMS: GLenum;\n    readonly ALIASED_LINE_WIDTH_RANGE: GLenum;\n    readonly ALIASED_POINT_SIZE_RANGE: GLenum;\n    readonly ALPHA: GLenum;\n    readonly ALPHA_BITS: GLenum;\n    readonly ALWAYS: GLenum;\n    readonly ARRAY_BUFFER: GLenum;\n    readonly ARRAY_BUFFER_BINDING: GLenum;\n    readonly ATTACHED_SHADERS: GLenum;\n    readonly BACK: GLenum;\n    readonly BLEND: GLenum;\n    readonly BLEND_COLOR: GLenum;\n    readonly BLEND_DST_ALPHA: GLenum;\n    readonly BLEND_DST_RGB: GLenum;\n    readonly BLEND_EQUATION: GLenum;\n    readonly BLEND_EQUATION_ALPHA: GLenum;\n    readonly BLEND_EQUATION_RGB: GLenum;\n    readonly BLEND_SRC_ALPHA: GLenum;\n    readonly BLEND_SRC_RGB: GLenum;\n    readonly BLUE_BITS: GLenum;\n    readonly BOOL: GLenum;\n    readonly BOOL_VEC2: GLenum;\n    readonly BOOL_VEC3: GLenum;\n    readonly BOOL_VEC4: GLenum;\n    readonly BROWSER_DEFAULT_WEBGL: GLenum;\n    readonly BUFFER_SIZE: GLenum;\n    readonly BUFFER_USAGE: GLenum;\n    readonly BYTE: GLenum;\n    readonly CCW: GLenum;\n    readonly CLAMP_TO_EDGE: GLenum;\n    readonly COLOR_ATTACHMENT0: GLenum;\n    readonly COLOR_BUFFER_BIT: GLenum;\n    readonly COLOR_CLEAR_VALUE: GLenum;\n    readonly COLOR_WRITEMASK: GLenum;\n    readonly COMPILE_STATUS: GLenum;\n    readonly COMPRESSED_TEXTURE_FORMATS: GLenum;\n    readonly CONSTANT_ALPHA: GLenum;\n    readonly CONSTANT_COLOR: GLenum;\n    readonly CONTEXT_LOST_WEBGL: GLenum;\n    readonly CULL_FACE: GLenum;\n    readonly CULL_FACE_MODE: GLenum;\n    readonly CURRENT_PROGRAM: GLenum;\n    readonly CURRENT_VERTEX_ATTRIB: GLenum;\n    readonly CW: GLenum;\n    readonly DECR: GLenum;\n    readonly DECR_WRAP: GLenum;\n    readonly DELETE_STATUS: GLenum;\n    readonly DEPTH_ATTACHMENT: GLenum;\n    readonly DEPTH_BITS: GLenum;\n    readonly DEPTH_BUFFER_BIT: GLenum;\n    readonly DEPTH_CLEAR_VALUE: GLenum;\n    readonly DEPTH_COMPONENT: GLenum;\n    readonly DEPTH_COMPONENT16: GLenum;\n    readonly DEPTH_FUNC: GLenum;\n    readonly DEPTH_RANGE: GLenum;\n    readonly DEPTH_STENCIL: GLenum;\n    readonly DEPTH_STENCIL_ATTACHMENT: GLenum;\n    readonly DEPTH_TEST: GLenum;\n    readonly DEPTH_WRITEMASK: GLenum;\n    readonly DITHER: GLenum;\n    readonly DONT_CARE: GLenum;\n    readonly DST_ALPHA: GLenum;\n    readonly DST_COLOR: GLenum;\n    readonly DYNAMIC_DRAW: GLenum;\n    readonly ELEMENT_ARRAY_BUFFER: GLenum;\n    readonly ELEMENT_ARRAY_BUFFER_BINDING: GLenum;\n    readonly EQUAL: GLenum;\n    readonly FASTEST: GLenum;\n    readonly FLOAT: GLenum;\n    readonly FLOAT_MAT2: GLenum;\n    readonly FLOAT_MAT3: GLenum;\n    readonly FLOAT_MAT4: GLenum;\n    readonly FLOAT_VEC2: GLenum;\n    readonly FLOAT_VEC3: GLenum;\n    readonly FLOAT_VEC4: GLenum;\n    readonly FRAGMENT_SHADER: GLenum;\n    readonly FRAMEBUFFER: GLenum;\n    readonly FRAMEBUFFER_ATTACHMENT_OBJECT_NAME: GLenum;\n    readonly FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE: GLenum;\n    readonly FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE: GLenum;\n    readonly FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL: GLenum;\n    readonly FRAMEBUFFER_BINDING: GLenum;\n    readonly FRAMEBUFFER_COMPLETE: GLenum;\n    readonly FRAMEBUFFER_INCOMPLETE_ATTACHMENT: GLenum;\n    readonly FRAMEBUFFER_INCOMPLETE_DIMENSIONS: GLenum;\n    readonly FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT: GLenum;\n    readonly FRAMEBUFFER_UNSUPPORTED: GLenum;\n    readonly FRONT: GLenum;\n    readonly FRONT_AND_BACK: GLenum;\n    readonly FRONT_FACE: GLenum;\n    readonly FUNC_ADD: GLenum;\n    readonly FUNC_REVERSE_SUBTRACT: GLenum;\n    readonly FUNC_SUBTRACT: GLenum;\n    readonly GENERATE_MIPMAP_HINT: GLenum;\n    readonly GEQUAL: GLenum;\n    readonly GREATER: GLenum;\n    readonly GREEN_BITS: GLenum;\n    readonly HIGH_FLOAT: GLenum;\n    readonly HIGH_INT: GLenum;\n    readonly IMPLEMENTATION_COLOR_READ_FORMAT: GLenum;\n    readonly IMPLEMENTATION_COLOR_READ_TYPE: GLenum;\n    readonly INCR: GLenum;\n    readonly INCR_WRAP: GLenum;\n    readonly INT: GLenum;\n    readonly INT_VEC2: GLenum;\n    readonly INT_VEC3: GLenum;\n    readonly INT_VEC4: GLenum;\n    readonly INVALID_ENUM: GLenum;\n    readonly INVALID_FRAMEBUFFER_OPERATION: GLenum;\n    readonly INVALID_OPERATION: GLenum;\n    readonly INVALID_VALUE: GLenum;\n    readonly INVERT: GLenum;\n    readonly KEEP: GLenum;\n    readonly LEQUAL: GLenum;\n    readonly LESS: GLenum;\n    readonly LINEAR: GLenum;\n    readonly LINEAR_MIPMAP_LINEAR: GLenum;\n    readonly LINEAR_MIPMAP_NEAREST: GLenum;\n    readonly LINES: GLenum;\n    readonly LINE_LOOP: GLenum;\n    readonly LINE_STRIP: GLenum;\n    readonly LINE_WIDTH: GLenum;\n    readonly LINK_STATUS: GLenum;\n    readonly LOW_FLOAT: GLenum;\n    readonly LOW_INT: GLenum;\n    readonly LUMINANCE: GLenum;\n    readonly LUMINANCE_ALPHA: GLenum;\n    readonly MAX_COMBINED_TEXTURE_IMAGE_UNITS: GLenum;\n    readonly MAX_CUBE_MAP_TEXTURE_SIZE: GLenum;\n    readonly MAX_FRAGMENT_UNIFORM_VECTORS: GLenum;\n    readonly MAX_RENDERBUFFER_SIZE: GLenum;\n    readonly MAX_TEXTURE_IMAGE_UNITS: GLenum;\n    readonly MAX_TEXTURE_SIZE: GLenum;\n    readonly MAX_VARYING_VECTORS: GLenum;\n    readonly MAX_VERTEX_ATTRIBS: GLenum;\n    readonly MAX_VERTEX_TEXTURE_IMAGE_UNITS: GLenum;\n    readonly MAX_VERTEX_UNIFORM_VECTORS: GLenum;\n    readonly MAX_VIEWPORT_DIMS: GLenum;\n    readonly MEDIUM_FLOAT: GLenum;\n    readonly MEDIUM_INT: GLenum;\n    readonly MIRRORED_REPEAT: GLenum;\n    readonly NEAREST: GLenum;\n    readonly NEAREST_MIPMAP_LINEAR: GLenum;\n    readonly NEAREST_MIPMAP_NEAREST: GLenum;\n    readonly NEVER: GLenum;\n    readonly NICEST: GLenum;\n    readonly NONE: GLenum;\n    readonly NOTEQUAL: GLenum;\n    readonly NO_ERROR: GLenum;\n    readonly ONE: GLenum;\n    readonly ONE_MINUS_CONSTANT_ALPHA: GLenum;\n    readonly ONE_MINUS_CONSTANT_COLOR: GLenum;\n    readonly ONE_MINUS_DST_ALPHA: GLenum;\n    readonly ONE_MINUS_DST_COLOR: GLenum;\n    readonly ONE_MINUS_SRC_ALPHA: GLenum;\n    readonly ONE_MINUS_SRC_COLOR: GLenum;\n    readonly OUT_OF_MEMORY: GLenum;\n    readonly PACK_ALIGNMENT: GLenum;\n    readonly POINTS: GLenum;\n    readonly POLYGON_OFFSET_FACTOR: GLenum;\n    readonly POLYGON_OFFSET_FILL: GLenum;\n    readonly POLYGON_OFFSET_UNITS: GLenum;\n    readonly RED_BITS: GLenum;\n    readonly RENDERBUFFER: GLenum;\n    readonly RENDERBUFFER_ALPHA_SIZE: GLenum;\n    readonly RENDERBUFFER_BINDING: GLenum;\n    readonly RENDERBUFFER_BLUE_SIZE: GLenum;\n    readonly RENDERBUFFER_DEPTH_SIZE: GLenum;\n    readonly RENDERBUFFER_GREEN_SIZE: GLenum;\n    readonly RENDERBUFFER_HEIGHT: GLenum;\n    readonly RENDERBUFFER_INTERNAL_FORMAT: GLenum;\n    readonly RENDERBUFFER_RED_SIZE: GLenum;\n    readonly RENDERBUFFER_STENCIL_SIZE: GLenum;\n    readonly RENDERBUFFER_WIDTH: GLenum;\n    readonly RENDERER: GLenum;\n    readonly REPEAT: GLenum;\n    readonly REPLACE: GLenum;\n    readonly RGB: GLenum;\n    readonly RGB565: GLenum;\n    readonly RGB5_A1: GLenum;\n    readonly RGBA: GLenum;\n    readonly RGBA4: GLenum;\n    readonly SAMPLER_2D: GLenum;\n    readonly SAMPLER_CUBE: GLenum;\n    readonly SAMPLES: GLenum;\n    readonly SAMPLE_ALPHA_TO_COVERAGE: GLenum;\n    readonly SAMPLE_BUFFERS: GLenum;\n    readonly SAMPLE_COVERAGE: GLenum;\n    readonly SAMPLE_COVERAGE_INVERT: GLenum;\n    readonly SAMPLE_COVERAGE_VALUE: GLenum;\n    readonly SCISSOR_BOX: GLenum;\n    readonly SCISSOR_TEST: GLenum;\n    readonly SHADER_TYPE: GLenum;\n    readonly SHADING_LANGUAGE_VERSION: GLenum;\n    readonly SHORT: GLenum;\n    readonly SRC_ALPHA: GLenum;\n    readonly SRC_ALPHA_SATURATE: GLenum;\n    readonly SRC_COLOR: GLenum;\n    readonly STATIC_DRAW: GLenum;\n    readonly STENCIL_ATTACHMENT: GLenum;\n    readonly STENCIL_BACK_FAIL: GLenum;\n    readonly STENCIL_BACK_FUNC: GLenum;\n    readonly STENCIL_BACK_PASS_DEPTH_FAIL: GLenum;\n    readonly STENCIL_BACK_PASS_DEPTH_PASS: GLenum;\n    readonly STENCIL_BACK_REF: GLenum;\n    readonly STENCIL_BACK_VALUE_MASK: GLenum;\n    readonly STENCIL_BACK_WRITEMASK: GLenum;\n    readonly STENCIL_BITS: GLenum;\n    readonly STENCIL_BUFFER_BIT: GLenum;\n    readonly STENCIL_CLEAR_VALUE: GLenum;\n    readonly STENCIL_FAIL: GLenum;\n    readonly STENCIL_FUNC: GLenum;\n    readonly STENCIL_INDEX8: GLenum;\n    readonly STENCIL_PASS_DEPTH_FAIL: GLenum;\n    readonly STENCIL_PASS_DEPTH_PASS: GLenum;\n    readonly STENCIL_REF: GLenum;\n    readonly STENCIL_TEST: GLenum;\n    readonly STENCIL_VALUE_MASK: GLenum;\n    readonly STENCIL_WRITEMASK: GLenum;\n    readonly STREAM_DRAW: GLenum;\n    readonly SUBPIXEL_BITS: GLenum;\n    readonly TEXTURE: GLenum;\n    readonly TEXTURE0: GLenum;\n    readonly TEXTURE1: GLenum;\n    readonly TEXTURE10: GLenum;\n    readonly TEXTURE11: GLenum;\n    readonly TEXTURE12: GLenum;\n    readonly TEXTURE13: GLenum;\n    readonly TEXTURE14: GLenum;\n    readonly TEXTURE15: GLenum;\n    readonly TEXTURE16: GLenum;\n    readonly TEXTURE17: GLenum;\n    readonly TEXTURE18: GLenum;\n    readonly TEXTURE19: GLenum;\n    readonly TEXTURE2: GLenum;\n    readonly TEXTURE20: GLenum;\n    readonly TEXTURE21: GLenum;\n    readonly TEXTURE22: GLenum;\n    readonly TEXTURE23: GLenum;\n    readonly TEXTURE24: GLenum;\n    readonly TEXTURE25: GLenum;\n    readonly TEXTURE26: GLenum;\n    readonly TEXTURE27: GLenum;\n    readonly TEXTURE28: GLenum;\n    readonly TEXTURE29: GLenum;\n    readonly TEXTURE3: GLenum;\n    readonly TEXTURE30: GLenum;\n    readonly TEXTURE31: GLenum;\n    readonly TEXTURE4: GLenum;\n    readonly TEXTURE5: GLenum;\n    readonly TEXTURE6: GLenum;\n    readonly TEXTURE7: GLenum;\n    readonly TEXTURE8: GLenum;\n    readonly TEXTURE9: GLenum;\n    readonly TEXTURE_2D: GLenum;\n    readonly TEXTURE_BINDING_2D: GLenum;\n    readonly TEXTURE_BINDING_CUBE_MAP: GLenum;\n    readonly TEXTURE_CUBE_MAP: GLenum;\n    readonly TEXTURE_CUBE_MAP_NEGATIVE_X: GLenum;\n    readonly TEXTURE_CUBE_MAP_NEGATIVE_Y: GLenum;\n    readonly TEXTURE_CUBE_MAP_NEGATIVE_Z: GLenum;\n    readonly TEXTURE_CUBE_MAP_POSITIVE_X: GLenum;\n    readonly TEXTURE_CUBE_MAP_POSITIVE_Y: GLenum;\n    readonly TEXTURE_CUBE_MAP_POSITIVE_Z: GLenum;\n    readonly TEXTURE_MAG_FILTER: GLenum;\n    readonly TEXTURE_MIN_FILTER: GLenum;\n    readonly TEXTURE_WRAP_S: GLenum;\n    readonly TEXTURE_WRAP_T: GLenum;\n    readonly TRIANGLES: GLenum;\n    readonly TRIANGLE_FAN: GLenum;\n    readonly TRIANGLE_STRIP: GLenum;\n    readonly UNPACK_ALIGNMENT: GLenum;\n    readonly UNPACK_COLORSPACE_CONVERSION_WEBGL: GLenum;\n    readonly UNPACK_FLIP_Y_WEBGL: GLenum;\n    readonly UNPACK_PREMULTIPLY_ALPHA_WEBGL: GLenum;\n    readonly UNSIGNED_BYTE: GLenum;\n    readonly UNSIGNED_INT: GLenum;\n    readonly UNSIGNED_SHORT: GLenum;\n    readonly UNSIGNED_SHORT_4_4_4_4: GLenum;\n    readonly UNSIGNED_SHORT_5_5_5_1: GLenum;\n    readonly UNSIGNED_SHORT_5_6_5: GLenum;\n    readonly VALIDATE_STATUS: GLenum;\n    readonly VENDOR: GLenum;\n    readonly VERSION: GLenum;\n    readonly VERTEX_ATTRIB_ARRAY_BUFFER_BINDING: GLenum;\n    readonly VERTEX_ATTRIB_ARRAY_ENABLED: GLenum;\n    readonly VERTEX_ATTRIB_ARRAY_NORMALIZED: GLenum;\n    readonly VERTEX_ATTRIB_ARRAY_POINTER: GLenum;\n    readonly VERTEX_ATTRIB_ARRAY_SIZE: GLenum;\n    readonly VERTEX_ATTRIB_ARRAY_STRIDE: GLenum;\n    readonly VERTEX_ATTRIB_ARRAY_TYPE: GLenum;\n    readonly VERTEX_SHADER: GLenum;\n    readonly VIEWPORT: GLenum;\n    readonly ZERO: GLenum;\n};\n\ninterface WebGLRenderingContextBase {\n    readonly canvas: OffscreenCanvas;\n    readonly drawingBufferHeight: GLsizei;\n    readonly drawingBufferWidth: GLsizei;\n    activeTexture(texture: GLenum): void;\n    attachShader(program: WebGLProgram, shader: WebGLShader): void;\n    bindAttribLocation(program: WebGLProgram, index: GLuint, name: string): void;\n    bindBuffer(target: GLenum, buffer: WebGLBuffer | null): void;\n    bindFramebuffer(target: GLenum, framebuffer: WebGLFramebuffer | null): void;\n    bindRenderbuffer(target: GLenum, renderbuffer: WebGLRenderbuffer | null): void;\n    bindTexture(target: GLenum, texture: WebGLTexture | null): void;\n    blendColor(red: GLclampf, green: GLclampf, blue: GLclampf, alpha: GLclampf): void;\n    blendEquation(mode: GLenum): void;\n    blendEquationSeparate(modeRGB: GLenum, modeAlpha: GLenum): void;\n    blendFunc(sfactor: GLenum, dfactor: GLenum): void;\n    blendFuncSeparate(srcRGB: GLenum, dstRGB: GLenum, srcAlpha: GLenum, dstAlpha: GLenum): void;\n    checkFramebufferStatus(target: GLenum): GLenum;\n    clear(mask: GLbitfield): void;\n    clearColor(red: GLclampf, green: GLclampf, blue: GLclampf, alpha: GLclampf): void;\n    clearDepth(depth: GLclampf): void;\n    clearStencil(s: GLint): void;\n    colorMask(red: GLboolean, green: GLboolean, blue: GLboolean, alpha: GLboolean): void;\n    compileShader(shader: WebGLShader): void;\n    copyTexImage2D(target: GLenum, level: GLint, internalformat: GLenum, x: GLint, y: GLint, width: GLsizei, height: GLsizei, border: GLint): void;\n    copyTexSubImage2D(target: GLenum, level: GLint, xoffset: GLint, yoffset: GLint, x: GLint, y: GLint, width: GLsizei, height: GLsizei): void;\n    createBuffer(): WebGLBuffer | null;\n    createFramebuffer(): WebGLFramebuffer | null;\n    createProgram(): WebGLProgram | null;\n    createRenderbuffer(): WebGLRenderbuffer | null;\n    createShader(type: GLenum): WebGLShader | null;\n    createTexture(): WebGLTexture | null;\n    cullFace(mode: GLenum): void;\n    deleteBuffer(buffer: WebGLBuffer | null): void;\n    deleteFramebuffer(framebuffer: WebGLFramebuffer | null): void;\n    deleteProgram(program: WebGLProgram | null): void;\n    deleteRenderbuffer(renderbuffer: WebGLRenderbuffer | null): void;\n    deleteShader(shader: WebGLShader | null): void;\n    deleteTexture(texture: WebGLTexture | null): void;\n    depthFunc(func: GLenum): void;\n    depthMask(flag: GLboolean): void;\n    depthRange(zNear: GLclampf, zFar: GLclampf): void;\n    detachShader(program: WebGLProgram, shader: WebGLShader): void;\n    disable(cap: GLenum): void;\n    disableVertexAttribArray(index: GLuint): void;\n    drawArrays(mode: GLenum, first: GLint, count: GLsizei): void;\n    drawElements(mode: GLenum, count: GLsizei, type: GLenum, offset: GLintptr): void;\n    enable(cap: GLenum): void;\n    enableVertexAttribArray(index: GLuint): void;\n    finish(): void;\n    flush(): void;\n    framebufferRenderbuffer(target: GLenum, attachment: GLenum, renderbuffertarget: GLenum, renderbuffer: WebGLRenderbuffer | null): void;\n    framebufferTexture2D(target: GLenum, attachment: GLenum, textarget: GLenum, texture: WebGLTexture | null, level: GLint): void;\n    frontFace(mode: GLenum): void;\n    generateMipmap(target: GLenum): void;\n    getActiveAttrib(program: WebGLProgram, index: GLuint): WebGLActiveInfo | null;\n    getActiveUniform(program: WebGLProgram, index: GLuint): WebGLActiveInfo | null;\n    getAttachedShaders(program: WebGLProgram): WebGLShader[] | null;\n    getAttribLocation(program: WebGLProgram, name: string): GLint;\n    getBufferParameter(target: GLenum, pname: GLenum): any;\n    getContextAttributes(): WebGLContextAttributes | null;\n    getError(): GLenum;\n    getExtension(extensionName: "EXT_blend_minmax"): EXT_blend_minmax | null;\n    getExtension(extensionName: "EXT_texture_filter_anisotropic"): EXT_texture_filter_anisotropic | null;\n    getExtension(extensionName: "EXT_frag_depth"): EXT_frag_depth | null;\n    getExtension(extensionName: "EXT_shader_texture_lod"): EXT_shader_texture_lod | null;\n    getExtension(extensionName: "EXT_sRGB"): EXT_sRGB | null;\n    getExtension(extensionName: "OES_vertex_array_object"): OES_vertex_array_object | null;\n    getExtension(extensionName: "WEBGL_color_buffer_float"): WEBGL_color_buffer_float | null;\n    getExtension(extensionName: "WEBGL_compressed_texture_astc"): WEBGL_compressed_texture_astc | null;\n    getExtension(extensionName: "WEBGL_compressed_texture_s3tc_srgb"): WEBGL_compressed_texture_s3tc_srgb | null;\n    getExtension(extensionName: "WEBGL_debug_shaders"): WEBGL_debug_shaders | null;\n    getExtension(extensionName: "WEBGL_draw_buffers"): WEBGL_draw_buffers | null;\n    getExtension(extensionName: "WEBGL_lose_context"): WEBGL_lose_context | null;\n    getExtension(extensionName: "WEBGL_depth_texture"): WEBGL_depth_texture | null;\n    getExtension(extensionName: "WEBGL_debug_renderer_info"): WEBGL_debug_renderer_info | null;\n    getExtension(extensionName: "WEBGL_compressed_texture_s3tc"): WEBGL_compressed_texture_s3tc | null;\n    getExtension(extensionName: "OES_texture_half_float_linear"): OES_texture_half_float_linear | null;\n    getExtension(extensionName: "OES_texture_half_float"): OES_texture_half_float | null;\n    getExtension(extensionName: "OES_texture_float_linear"): OES_texture_float_linear | null;\n    getExtension(extensionName: "OES_texture_float"): OES_texture_float | null;\n    getExtension(extensionName: "OES_standard_derivatives"): OES_standard_derivatives | null;\n    getExtension(extensionName: "OES_element_index_uint"): OES_element_index_uint | null;\n    getExtension(extensionName: "ANGLE_instanced_arrays"): ANGLE_instanced_arrays | null;\n    getExtension(extensionName: string): any;\n    getFramebufferAttachmentParameter(target: GLenum, attachment: GLenum, pname: GLenum): any;\n    getParameter(pname: GLenum): any;\n    getProgramInfoLog(program: WebGLProgram): string | null;\n    getProgramParameter(program: WebGLProgram, pname: GLenum): any;\n    getRenderbufferParameter(target: GLenum, pname: GLenum): any;\n    getShaderInfoLog(shader: WebGLShader): string | null;\n    getShaderParameter(shader: WebGLShader, pname: GLenum): any;\n    getShaderPrecisionFormat(shadertype: GLenum, precisiontype: GLenum): WebGLShaderPrecisionFormat | null;\n    getShaderSource(shader: WebGLShader): string | null;\n    getSupportedExtensions(): string[] | null;\n    getTexParameter(target: GLenum, pname: GLenum): any;\n    getUniform(program: WebGLProgram, location: WebGLUniformLocation): any;\n    getUniformLocation(program: WebGLProgram, name: string): WebGLUniformLocation | null;\n    getVertexAttrib(index: GLuint, pname: GLenum): any;\n    getVertexAttribOffset(index: GLuint, pname: GLenum): GLintptr;\n    hint(target: GLenum, mode: GLenum): void;\n    isBuffer(buffer: WebGLBuffer | null): GLboolean;\n    isContextLost(): boolean;\n    isEnabled(cap: GLenum): GLboolean;\n    isFramebuffer(framebuffer: WebGLFramebuffer | null): GLboolean;\n    isProgram(program: WebGLProgram | null): GLboolean;\n    isRenderbuffer(renderbuffer: WebGLRenderbuffer | null): GLboolean;\n    isShader(shader: WebGLShader | null): GLboolean;\n    isTexture(texture: WebGLTexture | null): GLboolean;\n    lineWidth(width: GLfloat): void;\n    linkProgram(program: WebGLProgram): void;\n    pixelStorei(pname: GLenum, param: GLint | GLboolean): void;\n    polygonOffset(factor: GLfloat, units: GLfloat): void;\n    renderbufferStorage(target: GLenum, internalformat: GLenum, width: GLsizei, height: GLsizei): void;\n    sampleCoverage(value: GLclampf, invert: GLboolean): void;\n    scissor(x: GLint, y: GLint, width: GLsizei, height: GLsizei): void;\n    shaderSource(shader: WebGLShader, source: string): void;\n    stencilFunc(func: GLenum, ref: GLint, mask: GLuint): void;\n    stencilFuncSeparate(face: GLenum, func: GLenum, ref: GLint, mask: GLuint): void;\n    stencilMask(mask: GLuint): void;\n    stencilMaskSeparate(face: GLenum, mask: GLuint): void;\n    stencilOp(fail: GLenum, zfail: GLenum, zpass: GLenum): void;\n    stencilOpSeparate(face: GLenum, fail: GLenum, zfail: GLenum, zpass: GLenum): void;\n    texParameterf(target: GLenum, pname: GLenum, param: GLfloat): void;\n    texParameteri(target: GLenum, pname: GLenum, param: GLint): void;\n    uniform1f(location: WebGLUniformLocation | null, x: GLfloat): void;\n    uniform1i(location: WebGLUniformLocation | null, x: GLint): void;\n    uniform2f(location: WebGLUniformLocation | null, x: GLfloat, y: GLfloat): void;\n    uniform2i(location: WebGLUniformLocation | null, x: GLint, y: GLint): void;\n    uniform3f(location: WebGLUniformLocation | null, x: GLfloat, y: GLfloat, z: GLfloat): void;\n    uniform3i(location: WebGLUniformLocation | null, x: GLint, y: GLint, z: GLint): void;\n    uniform4f(location: WebGLUniformLocation | null, x: GLfloat, y: GLfloat, z: GLfloat, w: GLfloat): void;\n    uniform4i(location: WebGLUniformLocation | null, x: GLint, y: GLint, z: GLint, w: GLint): void;\n    useProgram(program: WebGLProgram | null): void;\n    validateProgram(program: WebGLProgram): void;\n    vertexAttrib1f(index: GLuint, x: GLfloat): void;\n    vertexAttrib1fv(index: GLuint, values: Float32List): void;\n    vertexAttrib2f(index: GLuint, x: GLfloat, y: GLfloat): void;\n    vertexAttrib2fv(index: GLuint, values: Float32List): void;\n    vertexAttrib3f(index: GLuint, x: GLfloat, y: GLfloat, z: GLfloat): void;\n    vertexAttrib3fv(index: GLuint, values: Float32List): void;\n    vertexAttrib4f(index: GLuint, x: GLfloat, y: GLfloat, z: GLfloat, w: GLfloat): void;\n    vertexAttrib4fv(index: GLuint, values: Float32List): void;\n    vertexAttribPointer(index: GLuint, size: GLint, type: GLenum, normalized: GLboolean, stride: GLsizei, offset: GLintptr): void;\n    viewport(x: GLint, y: GLint, width: GLsizei, height: GLsizei): void;\n    readonly ACTIVE_ATTRIBUTES: GLenum;\n    readonly ACTIVE_TEXTURE: GLenum;\n    readonly ACTIVE_UNIFORMS: GLenum;\n    readonly ALIASED_LINE_WIDTH_RANGE: GLenum;\n    readonly ALIASED_POINT_SIZE_RANGE: GLenum;\n    readonly ALPHA: GLenum;\n    readonly ALPHA_BITS: GLenum;\n    readonly ALWAYS: GLenum;\n    readonly ARRAY_BUFFER: GLenum;\n    readonly ARRAY_BUFFER_BINDING: GLenum;\n    readonly ATTACHED_SHADERS: GLenum;\n    readonly BACK: GLenum;\n    readonly BLEND: GLenum;\n    readonly BLEND_COLOR: GLenum;\n    readonly BLEND_DST_ALPHA: GLenum;\n    readonly BLEND_DST_RGB: GLenum;\n    readonly BLEND_EQUATION: GLenum;\n    readonly BLEND_EQUATION_ALPHA: GLenum;\n    readonly BLEND_EQUATION_RGB: GLenum;\n    readonly BLEND_SRC_ALPHA: GLenum;\n    readonly BLEND_SRC_RGB: GLenum;\n    readonly BLUE_BITS: GLenum;\n    readonly BOOL: GLenum;\n    readonly BOOL_VEC2: GLenum;\n    readonly BOOL_VEC3: GLenum;\n    readonly BOOL_VEC4: GLenum;\n    readonly BROWSER_DEFAULT_WEBGL: GLenum;\n    readonly BUFFER_SIZE: GLenum;\n    readonly BUFFER_USAGE: GLenum;\n    readonly BYTE: GLenum;\n    readonly CCW: GLenum;\n    readonly CLAMP_TO_EDGE: GLenum;\n    readonly COLOR_ATTACHMENT0: GLenum;\n    readonly COLOR_BUFFER_BIT: GLenum;\n    readonly COLOR_CLEAR_VALUE: GLenum;\n    readonly COLOR_WRITEMASK: GLenum;\n    readonly COMPILE_STATUS: GLenum;\n    readonly COMPRESSED_TEXTURE_FORMATS: GLenum;\n    readonly CONSTANT_ALPHA: GLenum;\n    readonly CONSTANT_COLOR: GLenum;\n    readonly CONTEXT_LOST_WEBGL: GLenum;\n    readonly CULL_FACE: GLenum;\n    readonly CULL_FACE_MODE: GLenum;\n    readonly CURRENT_PROGRAM: GLenum;\n    readonly CURRENT_VERTEX_ATTRIB: GLenum;\n    readonly CW: GLenum;\n    readonly DECR: GLenum;\n    readonly DECR_WRAP: GLenum;\n    readonly DELETE_STATUS: GLenum;\n    readonly DEPTH_ATTACHMENT: GLenum;\n    readonly DEPTH_BITS: GLenum;\n    readonly DEPTH_BUFFER_BIT: GLenum;\n    readonly DEPTH_CLEAR_VALUE: GLenum;\n    readonly DEPTH_COMPONENT: GLenum;\n    readonly DEPTH_COMPONENT16: GLenum;\n    readonly DEPTH_FUNC: GLenum;\n    readonly DEPTH_RANGE: GLenum;\n    readonly DEPTH_STENCIL: GLenum;\n    readonly DEPTH_STENCIL_ATTACHMENT: GLenum;\n    readonly DEPTH_TEST: GLenum;\n    readonly DEPTH_WRITEMASK: GLenum;\n    readonly DITHER: GLenum;\n    readonly DONT_CARE: GLenum;\n    readonly DST_ALPHA: GLenum;\n    readonly DST_COLOR: GLenum;\n    readonly DYNAMIC_DRAW: GLenum;\n    readonly ELEMENT_ARRAY_BUFFER: GLenum;\n    readonly ELEMENT_ARRAY_BUFFER_BINDING: GLenum;\n    readonly EQUAL: GLenum;\n    readonly FASTEST: GLenum;\n    readonly FLOAT: GLenum;\n    readonly FLOAT_MAT2: GLenum;\n    readonly FLOAT_MAT3: GLenum;\n    readonly FLOAT_MAT4: GLenum;\n    readonly FLOAT_VEC2: GLenum;\n    readonly FLOAT_VEC3: GLenum;\n    readonly FLOAT_VEC4: GLenum;\n    readonly FRAGMENT_SHADER: GLenum;\n    readonly FRAMEBUFFER: GLenum;\n    readonly FRAMEBUFFER_ATTACHMENT_OBJECT_NAME: GLenum;\n    readonly FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE: GLenum;\n    readonly FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE: GLenum;\n    readonly FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL: GLenum;\n    readonly FRAMEBUFFER_BINDING: GLenum;\n    readonly FRAMEBUFFER_COMPLETE: GLenum;\n    readonly FRAMEBUFFER_INCOMPLETE_ATTACHMENT: GLenum;\n    readonly FRAMEBUFFER_INCOMPLETE_DIMENSIONS: GLenum;\n    readonly FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT: GLenum;\n    readonly FRAMEBUFFER_UNSUPPORTED: GLenum;\n    readonly FRONT: GLenum;\n    readonly FRONT_AND_BACK: GLenum;\n    readonly FRONT_FACE: GLenum;\n    readonly FUNC_ADD: GLenum;\n    readonly FUNC_REVERSE_SUBTRACT: GLenum;\n    readonly FUNC_SUBTRACT: GLenum;\n    readonly GENERATE_MIPMAP_HINT: GLenum;\n    readonly GEQUAL: GLenum;\n    readonly GREATER: GLenum;\n    readonly GREEN_BITS: GLenum;\n    readonly HIGH_FLOAT: GLenum;\n    readonly HIGH_INT: GLenum;\n    readonly IMPLEMENTATION_COLOR_READ_FORMAT: GLenum;\n    readonly IMPLEMENTATION_COLOR_READ_TYPE: GLenum;\n    readonly INCR: GLenum;\n    readonly INCR_WRAP: GLenum;\n    readonly INT: GLenum;\n    readonly INT_VEC2: GLenum;\n    readonly INT_VEC3: GLenum;\n    readonly INT_VEC4: GLenum;\n    readonly INVALID_ENUM: GLenum;\n    readonly INVALID_FRAMEBUFFER_OPERATION: GLenum;\n    readonly INVALID_OPERATION: GLenum;\n    readonly INVALID_VALUE: GLenum;\n    readonly INVERT: GLenum;\n    readonly KEEP: GLenum;\n    readonly LEQUAL: GLenum;\n    readonly LESS: GLenum;\n    readonly LINEAR: GLenum;\n    readonly LINEAR_MIPMAP_LINEAR: GLenum;\n    readonly LINEAR_MIPMAP_NEAREST: GLenum;\n    readonly LINES: GLenum;\n    readonly LINE_LOOP: GLenum;\n    readonly LINE_STRIP: GLenum;\n    readonly LINE_WIDTH: GLenum;\n    readonly LINK_STATUS: GLenum;\n    readonly LOW_FLOAT: GLenum;\n    readonly LOW_INT: GLenum;\n    readonly LUMINANCE: GLenum;\n    readonly LUMINANCE_ALPHA: GLenum;\n    readonly MAX_COMBINED_TEXTURE_IMAGE_UNITS: GLenum;\n    readonly MAX_CUBE_MAP_TEXTURE_SIZE: GLenum;\n    readonly MAX_FRAGMENT_UNIFORM_VECTORS: GLenum;\n    readonly MAX_RENDERBUFFER_SIZE: GLenum;\n    readonly MAX_TEXTURE_IMAGE_UNITS: GLenum;\n    readonly MAX_TEXTURE_SIZE: GLenum;\n    readonly MAX_VARYING_VECTORS: GLenum;\n    readonly MAX_VERTEX_ATTRIBS: GLenum;\n    readonly MAX_VERTEX_TEXTURE_IMAGE_UNITS: GLenum;\n    readonly MAX_VERTEX_UNIFORM_VECTORS: GLenum;\n    readonly MAX_VIEWPORT_DIMS: GLenum;\n    readonly MEDIUM_FLOAT: GLenum;\n    readonly MEDIUM_INT: GLenum;\n    readonly MIRRORED_REPEAT: GLenum;\n    readonly NEAREST: GLenum;\n    readonly NEAREST_MIPMAP_LINEAR: GLenum;\n    readonly NEAREST_MIPMAP_NEAREST: GLenum;\n    readonly NEVER: GLenum;\n    readonly NICEST: GLenum;\n    readonly NONE: GLenum;\n    readonly NOTEQUAL: GLenum;\n    readonly NO_ERROR: GLenum;\n    readonly ONE: GLenum;\n    readonly ONE_MINUS_CONSTANT_ALPHA: GLenum;\n    readonly ONE_MINUS_CONSTANT_COLOR: GLenum;\n    readonly ONE_MINUS_DST_ALPHA: GLenum;\n    readonly ONE_MINUS_DST_COLOR: GLenum;\n    readonly ONE_MINUS_SRC_ALPHA: GLenum;\n    readonly ONE_MINUS_SRC_COLOR: GLenum;\n    readonly OUT_OF_MEMORY: GLenum;\n    readonly PACK_ALIGNMENT: GLenum;\n    readonly POINTS: GLenum;\n    readonly POLYGON_OFFSET_FACTOR: GLenum;\n    readonly POLYGON_OFFSET_FILL: GLenum;\n    readonly POLYGON_OFFSET_UNITS: GLenum;\n    readonly RED_BITS: GLenum;\n    readonly RENDERBUFFER: GLenum;\n    readonly RENDERBUFFER_ALPHA_SIZE: GLenum;\n    readonly RENDERBUFFER_BINDING: GLenum;\n    readonly RENDERBUFFER_BLUE_SIZE: GLenum;\n    readonly RENDERBUFFER_DEPTH_SIZE: GLenum;\n    readonly RENDERBUFFER_GREEN_SIZE: GLenum;\n    readonly RENDERBUFFER_HEIGHT: GLenum;\n    readonly RENDERBUFFER_INTERNAL_FORMAT: GLenum;\n    readonly RENDERBUFFER_RED_SIZE: GLenum;\n    readonly RENDERBUFFER_STENCIL_SIZE: GLenum;\n    readonly RENDERBUFFER_WIDTH: GLenum;\n    readonly RENDERER: GLenum;\n    readonly REPEAT: GLenum;\n    readonly REPLACE: GLenum;\n    readonly RGB: GLenum;\n    readonly RGB565: GLenum;\n    readonly RGB5_A1: GLenum;\n    readonly RGBA: GLenum;\n    readonly RGBA4: GLenum;\n    readonly SAMPLER_2D: GLenum;\n    readonly SAMPLER_CUBE: GLenum;\n    readonly SAMPLES: GLenum;\n    readonly SAMPLE_ALPHA_TO_COVERAGE: GLenum;\n    readonly SAMPLE_BUFFERS: GLenum;\n    readonly SAMPLE_COVERAGE: GLenum;\n    readonly SAMPLE_COVERAGE_INVERT: GLenum;\n    readonly SAMPLE_COVERAGE_VALUE: GLenum;\n    readonly SCISSOR_BOX: GLenum;\n    readonly SCISSOR_TEST: GLenum;\n    readonly SHADER_TYPE: GLenum;\n    readonly SHADING_LANGUAGE_VERSION: GLenum;\n    readonly SHORT: GLenum;\n    readonly SRC_ALPHA: GLenum;\n    readonly SRC_ALPHA_SATURATE: GLenum;\n    readonly SRC_COLOR: GLenum;\n    readonly STATIC_DRAW: GLenum;\n    readonly STENCIL_ATTACHMENT: GLenum;\n    readonly STENCIL_BACK_FAIL: GLenum;\n    readonly STENCIL_BACK_FUNC: GLenum;\n    readonly STENCIL_BACK_PASS_DEPTH_FAIL: GLenum;\n    readonly STENCIL_BACK_PASS_DEPTH_PASS: GLenum;\n    readonly STENCIL_BACK_REF: GLenum;\n    readonly STENCIL_BACK_VALUE_MASK: GLenum;\n    readonly STENCIL_BACK_WRITEMASK: GLenum;\n    readonly STENCIL_BITS: GLenum;\n    readonly STENCIL_BUFFER_BIT: GLenum;\n    readonly STENCIL_CLEAR_VALUE: GLenum;\n    readonly STENCIL_FAIL: GLenum;\n    readonly STENCIL_FUNC: GLenum;\n    readonly STENCIL_INDEX8: GLenum;\n    readonly STENCIL_PASS_DEPTH_FAIL: GLenum;\n    readonly STENCIL_PASS_DEPTH_PASS: GLenum;\n    readonly STENCIL_REF: GLenum;\n    readonly STENCIL_TEST: GLenum;\n    readonly STENCIL_VALUE_MASK: GLenum;\n    readonly STENCIL_WRITEMASK: GLenum;\n    readonly STREAM_DRAW: GLenum;\n    readonly SUBPIXEL_BITS: GLenum;\n    readonly TEXTURE: GLenum;\n    readonly TEXTURE0: GLenum;\n    readonly TEXTURE1: GLenum;\n    readonly TEXTURE10: GLenum;\n    readonly TEXTURE11: GLenum;\n    readonly TEXTURE12: GLenum;\n    readonly TEXTURE13: GLenum;\n    readonly TEXTURE14: GLenum;\n    readonly TEXTURE15: GLenum;\n    readonly TEXTURE16: GLenum;\n    readonly TEXTURE17: GLenum;\n    readonly TEXTURE18: GLenum;\n    readonly TEXTURE19: GLenum;\n    readonly TEXTURE2: GLenum;\n    readonly TEXTURE20: GLenum;\n    readonly TEXTURE21: GLenum;\n    readonly TEXTURE22: GLenum;\n    readonly TEXTURE23: GLenum;\n    readonly TEXTURE24: GLenum;\n    readonly TEXTURE25: GLenum;\n    readonly TEXTURE26: GLenum;\n    readonly TEXTURE27: GLenum;\n    readonly TEXTURE28: GLenum;\n    readonly TEXTURE29: GLenum;\n    readonly TEXTURE3: GLenum;\n    readonly TEXTURE30: GLenum;\n    readonly TEXTURE31: GLenum;\n    readonly TEXTURE4: GLenum;\n    readonly TEXTURE5: GLenum;\n    readonly TEXTURE6: GLenum;\n    readonly TEXTURE7: GLenum;\n    readonly TEXTURE8: GLenum;\n    readonly TEXTURE9: GLenum;\n    readonly TEXTURE_2D: GLenum;\n    readonly TEXTURE_BINDING_2D: GLenum;\n    readonly TEXTURE_BINDING_CUBE_MAP: GLenum;\n    readonly TEXTURE_CUBE_MAP: GLenum;\n    readonly TEXTURE_CUBE_MAP_NEGATIVE_X: GLenum;\n    readonly TEXTURE_CUBE_MAP_NEGATIVE_Y: GLenum;\n    readonly TEXTURE_CUBE_MAP_NEGATIVE_Z: GLenum;\n    readonly TEXTURE_CUBE_MAP_POSITIVE_X: GLenum;\n    readonly TEXTURE_CUBE_MAP_POSITIVE_Y: GLenum;\n    readonly TEXTURE_CUBE_MAP_POSITIVE_Z: GLenum;\n    readonly TEXTURE_MAG_FILTER: GLenum;\n    readonly TEXTURE_MIN_FILTER: GLenum;\n    readonly TEXTURE_WRAP_S: GLenum;\n    readonly TEXTURE_WRAP_T: GLenum;\n    readonly TRIANGLES: GLenum;\n    readonly TRIANGLE_FAN: GLenum;\n    readonly TRIANGLE_STRIP: GLenum;\n    readonly UNPACK_ALIGNMENT: GLenum;\n    readonly UNPACK_COLORSPACE_CONVERSION_WEBGL: GLenum;\n    readonly UNPACK_FLIP_Y_WEBGL: GLenum;\n    readonly UNPACK_PREMULTIPLY_ALPHA_WEBGL: GLenum;\n    readonly UNSIGNED_BYTE: GLenum;\n    readonly UNSIGNED_INT: GLenum;\n    readonly UNSIGNED_SHORT: GLenum;\n    readonly UNSIGNED_SHORT_4_4_4_4: GLenum;\n    readonly UNSIGNED_SHORT_5_5_5_1: GLenum;\n    readonly UNSIGNED_SHORT_5_6_5: GLenum;\n    readonly VALIDATE_STATUS: GLenum;\n    readonly VENDOR: GLenum;\n    readonly VERSION: GLenum;\n    readonly VERTEX_ATTRIB_ARRAY_BUFFER_BINDING: GLenum;\n    readonly VERTEX_ATTRIB_ARRAY_ENABLED: GLenum;\n    readonly VERTEX_ATTRIB_ARRAY_NORMALIZED: GLenum;\n    readonly VERTEX_ATTRIB_ARRAY_POINTER: GLenum;\n    readonly VERTEX_ATTRIB_ARRAY_SIZE: GLenum;\n    readonly VERTEX_ATTRIB_ARRAY_STRIDE: GLenum;\n    readonly VERTEX_ATTRIB_ARRAY_TYPE: GLenum;\n    readonly VERTEX_SHADER: GLenum;\n    readonly VIEWPORT: GLenum;\n    readonly ZERO: GLenum;\n}\n\ninterface WebGLRenderingContextOverloads {\n    bufferData(target: GLenum, size: GLsizeiptr, usage: GLenum): void;\n    bufferData(target: GLenum, data: BufferSource | null, usage: GLenum): void;\n    bufferSubData(target: GLenum, offset: GLintptr, data: BufferSource): void;\n    compressedTexImage2D(target: GLenum, level: GLint, internalformat: GLenum, width: GLsizei, height: GLsizei, border: GLint, data: ArrayBufferView): void;\n    compressedTexSubImage2D(target: GLenum, level: GLint, xoffset: GLint, yoffset: GLint, width: GLsizei, height: GLsizei, format: GLenum, data: ArrayBufferView): void;\n    readPixels(x: GLint, y: GLint, width: GLsizei, height: GLsizei, format: GLenum, type: GLenum, pixels: ArrayBufferView | null): void;\n    texImage2D(target: GLenum, level: GLint, internalformat: GLint, width: GLsizei, height: GLsizei, border: GLint, format: GLenum, type: GLenum, pixels: ArrayBufferView | null): void;\n    texImage2D(target: GLenum, level: GLint, internalformat: GLint, format: GLenum, type: GLenum, source: TexImageSource): void;\n    texSubImage2D(target: GLenum, level: GLint, xoffset: GLint, yoffset: GLint, width: GLsizei, height: GLsizei, format: GLenum, type: GLenum, pixels: ArrayBufferView | null): void;\n    texSubImage2D(target: GLenum, level: GLint, xoffset: GLint, yoffset: GLint, format: GLenum, type: GLenum, source: TexImageSource): void;\n    uniform1fv(location: WebGLUniformLocation | null, v: Float32List): void;\n    uniform1iv(location: WebGLUniformLocation | null, v: Int32List): void;\n    uniform2fv(location: WebGLUniformLocation | null, v: Float32List): void;\n    uniform2iv(location: WebGLUniformLocation | null, v: Int32List): void;\n    uniform3fv(location: WebGLUniformLocation | null, v: Float32List): void;\n    uniform3iv(location: WebGLUniformLocation | null, v: Int32List): void;\n    uniform4fv(location: WebGLUniformLocation | null, v: Float32List): void;\n    uniform4iv(location: WebGLUniformLocation | null, v: Int32List): void;\n    uniformMatrix2fv(location: WebGLUniformLocation | null, transpose: GLboolean, value: Float32List): void;\n    uniformMatrix3fv(location: WebGLUniformLocation | null, transpose: GLboolean, value: Float32List): void;\n    uniformMatrix4fv(location: WebGLUniformLocation | null, transpose: GLboolean, value: Float32List): void;\n}\n\ninterface WebGLSampler {\n}\n\ndeclare var WebGLSampler: {\n    prototype: WebGLSampler;\n    new(): WebGLSampler;\n};\n\n/** The WebGLShader is part of the WebGL API and can either be a vertex or a fragment shader. A WebGLProgram requires both types of shaders. */\ninterface WebGLShader {\n}\n\ndeclare var WebGLShader: {\n    prototype: WebGLShader;\n    new(): WebGLShader;\n};\n\n/** Part of the WebGL API and represents the information returned by calling the WebGLRenderingContext.getShaderPrecisionFormat() method. */\ninterface WebGLShaderPrecisionFormat {\n    readonly precision: GLint;\n    readonly rangeMax: GLint;\n    readonly rangeMin: GLint;\n}\n\ndeclare var WebGLShaderPrecisionFormat: {\n    prototype: WebGLShaderPrecisionFormat;\n    new(): WebGLShaderPrecisionFormat;\n};\n\ninterface WebGLSync {\n}\n\ndeclare var WebGLSync: {\n    prototype: WebGLSync;\n    new(): WebGLSync;\n};\n\n/** Part of the WebGL API and represents an opaque texture object providing storage and state for texturing operations. */\ninterface WebGLTexture {\n}\n\ndeclare var WebGLTexture: {\n    prototype: WebGLTexture;\n    new(): WebGLTexture;\n};\n\ninterface WebGLTransformFeedback {\n}\n\ndeclare var WebGLTransformFeedback: {\n    prototype: WebGLTransformFeedback;\n    new(): WebGLTransformFeedback;\n};\n\n/** Part of the WebGL API and represents the location of a uniform variable in a shader program. */\ninterface WebGLUniformLocation {\n}\n\ndeclare var WebGLUniformLocation: {\n    prototype: WebGLUniformLocation;\n    new(): WebGLUniformLocation;\n};\n\ninterface WebGLVertexArrayObject {\n}\n\ndeclare var WebGLVertexArrayObject: {\n    prototype: WebGLVertexArrayObject;\n    new(): WebGLVertexArrayObject;\n};\n\ninterface WebGLVertexArrayObjectOES {\n}\n\ninterface WebSocketEventMap {\n    "close": CloseEvent;\n    "error": Event;\n    "message": MessageEvent;\n    "open": Event;\n}\n\n/** Provides the API for creating and managing a WebSocket connection to a server, as well as for sending and receiving data on the connection. */\ninterface WebSocket extends EventTarget {\n    /**\n     * Returns a string that indicates how binary data from the WebSocket object is exposed to scripts:\n     *\n     * Can be set, to change how binary data is returned. The default is "blob".\n     */\n    binaryType: BinaryType;\n    /**\n     * Returns the number of bytes of application data (UTF-8 text and binary data) that have been queued using send() but not yet been transmitted to the network.\n     *\n     * If the WebSocket connection is closed, this attribute\'s value will only increase with each call to the send() method. (The number does not reset to zero once the connection closes.)\n     */\n    readonly bufferedAmount: number;\n    /**\n     * Returns the extensions selected by the server, if any.\n     */\n    readonly extensions: string;\n    onclose: ((this: WebSocket, ev: CloseEvent) => any) | null;\n    onerror: ((this: WebSocket, ev: Event) => any) | null;\n    onmessage: ((this: WebSocket, ev: MessageEvent) => any) | null;\n    onopen: ((this: WebSocket, ev: Event) => any) | null;\n    /**\n     * Returns the subprotocol selected by the server, if any. It can be used in conjunction with the array form of the constructor\'s second argument to perform subprotocol negotiation.\n     */\n    readonly protocol: string;\n    /**\n     * Returns the state of the WebSocket object\'s connection. It can have the values described below.\n     */\n    readonly readyState: number;\n    /**\n     * Returns the URL that was used to establish the WebSocket connection.\n     */\n    readonly url: string;\n    /**\n     * Closes the WebSocket connection, optionally using code as the the WebSocket connection close code and reason as the the WebSocket connection close reason.\n     */\n    close(code?: number, reason?: string): void;\n    /**\n     * Transmits data using the WebSocket connection. data can be a string, a Blob, an ArrayBuffer, or an ArrayBufferView.\n     */\n    send(data: string | ArrayBufferLike | Blob | ArrayBufferView): void;\n    readonly CLOSED: number;\n    readonly CLOSING: number;\n    readonly CONNECTING: number;\n    readonly OPEN: number;\n    addEventListener<K extends keyof WebSocketEventMap>(type: K, listener: (this: WebSocket, ev: WebSocketEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof WebSocketEventMap>(type: K, listener: (this: WebSocket, ev: WebSocketEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var WebSocket: {\n    prototype: WebSocket;\n    new(url: string, protocols?: string | string[]): WebSocket;\n    readonly CLOSED: number;\n    readonly CLOSING: number;\n    readonly CONNECTING: number;\n    readonly OPEN: number;\n};\n\n/** This ServiceWorker API interface represents the scope of a service worker client that is a document in a browser context, controlled by an active worker. The service worker client independently selects and uses a service worker for its own loading and sub-resources. */\ninterface WindowClient extends Client {\n    readonly focused: boolean;\n    readonly visibilityState: VisibilityState;\n    focus(): Promise<WindowClient>;\n    navigate(url: string): Promise<WindowClient | null>;\n}\n\ndeclare var WindowClient: {\n    prototype: WindowClient;\n    new(): WindowClient;\n};\n\ninterface WindowOrWorkerGlobalScope {\n    readonly caches: CacheStorage;\n    readonly crypto: Crypto;\n    readonly indexedDB: IDBFactory;\n    readonly isSecureContext: boolean;\n    readonly origin: string;\n    readonly performance: Performance;\n    atob(data: string): string;\n    btoa(data: string): string;\n    clearInterval(handle?: number): void;\n    clearTimeout(handle?: number): void;\n    createImageBitmap(image: ImageBitmapSource, options?: ImageBitmapOptions): Promise<ImageBitmap>;\n    createImageBitmap(image: ImageBitmapSource, sx: number, sy: number, sw: number, sh: number, options?: ImageBitmapOptions): Promise<ImageBitmap>;\n    fetch(input: RequestInfo, init?: RequestInit): Promise<Response>;\n    queueMicrotask(callback: VoidFunction): void;\n    setInterval(handler: TimerHandler, timeout?: number, ...arguments: any[]): number;\n    setTimeout(handler: TimerHandler, timeout?: number, ...arguments: any[]): number;\n}\n\ninterface WorkerEventMap extends AbstractWorkerEventMap {\n    "message": MessageEvent;\n    "messageerror": MessageEvent;\n}\n\n/** This Web Workers API interface represents a background task that can be easily created and can send messages back to its creator. Creating a worker is as simple as calling the Worker() constructor and specifying a script to be run in the worker thread. */\ninterface Worker extends EventTarget, AbstractWorker {\n    onmessage: ((this: Worker, ev: MessageEvent) => any) | null;\n    onmessageerror: ((this: Worker, ev: MessageEvent) => any) | null;\n    /**\n     * Clones message and transmits it to worker\'s global environment. transfer can be passed as a list of objects that are to be transferred rather than cloned.\n     */\n    postMessage(message: any, transfer: Transferable[]): void;\n    postMessage(message: any, options?: PostMessageOptions): void;\n    /**\n     * Aborts worker\'s associated global environment.\n     */\n    terminate(): void;\n    addEventListener<K extends keyof WorkerEventMap>(type: K, listener: (this: Worker, ev: WorkerEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof WorkerEventMap>(type: K, listener: (this: Worker, ev: WorkerEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var Worker: {\n    prototype: Worker;\n    new(stringUrl: string | URL, options?: WorkerOptions): Worker;\n};\n\ninterface WorkerGlobalScopeEventMap {\n    "error": ErrorEvent;\n    "languagechange": Event;\n    "offline": Event;\n    "online": Event;\n    "rejectionhandled": PromiseRejectionEvent;\n    "unhandledrejection": PromiseRejectionEvent;\n}\n\n/** This Web Workers API interface is an interface representing the scope of any worker. Workers have no browsing context; this scope contains the information usually conveyed by Window objects — in this case event handlers, the console or the associated WorkerNavigator object. Each WorkerGlobalScope has its own event loop. */\ninterface WorkerGlobalScope extends EventTarget, WindowOrWorkerGlobalScope {\n    /**\n     * Returns workerGlobal\'s WorkerLocation object.\n     */\n    readonly location: WorkerLocation;\n    readonly navigator: WorkerNavigator;\n    onerror: ((this: WorkerGlobalScope, ev: ErrorEvent) => any) | null;\n    onlanguagechange: ((this: WorkerGlobalScope, ev: Event) => any) | null;\n    onoffline: ((this: WorkerGlobalScope, ev: Event) => any) | null;\n    ononline: ((this: WorkerGlobalScope, ev: Event) => any) | null;\n    onrejectionhandled: ((this: WorkerGlobalScope, ev: PromiseRejectionEvent) => any) | null;\n    onunhandledrejection: ((this: WorkerGlobalScope, ev: PromiseRejectionEvent) => any) | null;\n    /**\n     * Returns workerGlobal.\n     */\n    readonly self: WorkerGlobalScope & typeof globalThis;\n    /**\n     * Fetches each URL in urls, executes them one-by-one in the order they are passed, and then returns (or throws if something went amiss).\n     */\n    importScripts(...urls: string[]): void;\n    addEventListener<K extends keyof WorkerGlobalScopeEventMap>(type: K, listener: (this: WorkerGlobalScope, ev: WorkerGlobalScopeEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof WorkerGlobalScopeEventMap>(type: K, listener: (this: WorkerGlobalScope, ev: WorkerGlobalScopeEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var WorkerGlobalScope: {\n    prototype: WorkerGlobalScope;\n    new(): WorkerGlobalScope;\n};\n\n/** The absolute location of the script executed by the Worker. Such an object is initialized for each worker and is available via the WorkerGlobalScope.location property obtained by calling self.location. */\ninterface WorkerLocation {\n    readonly hash: string;\n    readonly host: string;\n    readonly hostname: string;\n    readonly href: string;\n    toString(): string;\n    readonly origin: string;\n    readonly pathname: string;\n    readonly port: string;\n    readonly protocol: string;\n    readonly search: string;\n}\n\ndeclare var WorkerLocation: {\n    prototype: WorkerLocation;\n    new(): WorkerLocation;\n};\n\n/** A subset of the Navigator interface allowed to be accessed from a Worker. Such an object is initialized for each worker and is available via the WorkerGlobalScope.navigator property obtained by calling window.self.navigator. */\ninterface WorkerNavigator extends NavigatorConcurrentHardware, NavigatorID, NavigatorLanguage, NavigatorOnLine, NavigatorStorage {\n    readonly permissions: Permissions;\n}\n\ndeclare var WorkerNavigator: {\n    prototype: WorkerNavigator;\n    new(): WorkerNavigator;\n};\n\n/** This Streams API interface provides a standard abstraction for writing streaming data to a destination, known as a sink. This object comes with built-in backpressure and queuing. */\ninterface WritableStream<W = any> {\n    readonly locked: boolean;\n    abort(reason?: any): Promise<void>;\n    getWriter(): WritableStreamDefaultWriter<W>;\n}\n\ndeclare var WritableStream: {\n    prototype: WritableStream;\n    new<W = any>(underlyingSink?: UnderlyingSink<W>, strategy?: QueuingStrategy<W>): WritableStream<W>;\n};\n\n/** This Streams API interface represents a controller allowing control of a WritableStream\'s state. When constructing a WritableStream, the underlying sink is given a corresponding WritableStreamDefaultController instance to manipulate. */\ninterface WritableStreamDefaultController {\n    error(e?: any): void;\n}\n\ndeclare var WritableStreamDefaultController: {\n    prototype: WritableStreamDefaultController;\n    new(): WritableStreamDefaultController;\n};\n\n/** This Streams API interface is the object returned by WritableStream.getWriter() and once created locks the < writer to the WritableStream ensuring that no other streams can write to the underlying sink. */\ninterface WritableStreamDefaultWriter<W = any> {\n    readonly closed: Promise<undefined>;\n    readonly desiredSize: number | null;\n    readonly ready: Promise<undefined>;\n    abort(reason?: any): Promise<void>;\n    close(): Promise<void>;\n    releaseLock(): void;\n    write(chunk: W): Promise<void>;\n}\n\ndeclare var WritableStreamDefaultWriter: {\n    prototype: WritableStreamDefaultWriter;\n    new<W = any>(stream: WritableStream<W>): WritableStreamDefaultWriter<W>;\n};\n\ninterface XMLHttpRequestEventMap extends XMLHttpRequestEventTargetEventMap {\n    "readystatechange": Event;\n}\n\n/** Use XMLHttpRequest (XHR) objects to interact with servers. You can retrieve data from a URL without having to do a full page refresh. This enables a Web page to update just part of a page without disrupting what the user is doing. */\ninterface XMLHttpRequest extends XMLHttpRequestEventTarget {\n    onreadystatechange: ((this: XMLHttpRequest, ev: Event) => any) | null;\n    /**\n     * Returns client\'s state.\n     */\n    readonly readyState: number;\n    /**\n     * Returns the response\'s body.\n     */\n    readonly response: any;\n    /**\n     * Returns the text response.\n     *\n     * Throws an "InvalidStateError" DOMException if responseType is not the empty string or "text".\n     */\n    readonly responseText: string;\n    /**\n     * Returns the response type.\n     *\n     * Can be set to change the response type. Values are: the empty string (default), "arraybuffer", "blob", "document", "json", and "text".\n     *\n     * When set: setting to "document" is ignored if current global object is not a Window object.\n     *\n     * When set: throws an "InvalidStateError" DOMException if state is loading or done.\n     *\n     * When set: throws an "InvalidAccessError" DOMException if the synchronous flag is set and current global object is a Window object.\n     */\n    responseType: XMLHttpRequestResponseType;\n    readonly responseURL: string;\n    readonly status: number;\n    readonly statusText: string;\n    /**\n     * Can be set to a time in milliseconds. When set to a non-zero value will cause fetching to terminate after the given time has passed. When the time has passed, the request has not yet completed, and the synchronous flag is unset, a timeout event will then be dispatched, or a "TimeoutError" DOMException will be thrown otherwise (for the send() method).\n     *\n     * When set: throws an "InvalidAccessError" DOMException if the synchronous flag is set and current global object is a Window object.\n     */\n    timeout: number;\n    /**\n     * Returns the associated XMLHttpRequestUpload object. It can be used to gather transmission information when data is transferred to a server.\n     */\n    readonly upload: XMLHttpRequestUpload;\n    /**\n     * True when credentials are to be included in a cross-origin request. False when they are to be excluded in a cross-origin request and when cookies are to be ignored in its response. Initially false.\n     *\n     * When set: throws an "InvalidStateError" DOMException if state is not unsent or opened, or if the send() flag is set.\n     */\n    withCredentials: boolean;\n    /**\n     * Cancels any network activity.\n     */\n    abort(): void;\n    getAllResponseHeaders(): string;\n    getResponseHeader(name: string): string | null;\n    /**\n     * Sets the request method, request URL, and synchronous flag.\n     *\n     * Throws a "SyntaxError" DOMException if either method is not a valid HTTP method or url cannot be parsed.\n     *\n     * Throws a "SecurityError" DOMException if method is a case-insensitive match for `CONNECT`, `TRACE`, or `TRACK`.\n     *\n     * Throws an "InvalidAccessError" DOMException if async is false, current global object is a Window object, and the timeout attribute is not zero or the responseType attribute is not the empty string.\n     */\n    open(method: string, url: string): void;\n    open(method: string, url: string, async: boolean, username?: string | null, password?: string | null): void;\n    /**\n     * Acts as if the `Content-Type` header value for response is mime. (It does not actually change the header though.)\n     *\n     * Throws an "InvalidStateError" DOMException if state is loading or done.\n     */\n    overrideMimeType(mime: string): void;\n    /**\n     * Initiates the request. The body argument provides the request body, if any, and is ignored if the request method is GET or HEAD.\n     *\n     * Throws an "InvalidStateError" DOMException if either state is not opened or the send() flag is set.\n     */\n    send(body?: BodyInit | null): void;\n    /**\n     * Combines a header in author request headers.\n     *\n     * Throws an "InvalidStateError" DOMException if either state is not opened or the send() flag is set.\n     *\n     * Throws a "SyntaxError" DOMException if name is not a header name or if value is not a header value.\n     */\n    setRequestHeader(name: string, value: string): void;\n    readonly DONE: number;\n    readonly HEADERS_RECEIVED: number;\n    readonly LOADING: number;\n    readonly OPENED: number;\n    readonly UNSENT: number;\n    addEventListener<K extends keyof XMLHttpRequestEventMap>(type: K, listener: (this: XMLHttpRequest, ev: XMLHttpRequestEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof XMLHttpRequestEventMap>(type: K, listener: (this: XMLHttpRequest, ev: XMLHttpRequestEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var XMLHttpRequest: {\n    prototype: XMLHttpRequest;\n    new(): XMLHttpRequest;\n    readonly DONE: number;\n    readonly HEADERS_RECEIVED: number;\n    readonly LOADING: number;\n    readonly OPENED: number;\n    readonly UNSENT: number;\n};\n\ninterface XMLHttpRequestEventTargetEventMap {\n    "abort": ProgressEvent<XMLHttpRequestEventTarget>;\n    "error": ProgressEvent<XMLHttpRequestEventTarget>;\n    "load": ProgressEvent<XMLHttpRequestEventTarget>;\n    "loadend": ProgressEvent<XMLHttpRequestEventTarget>;\n    "loadstart": ProgressEvent<XMLHttpRequestEventTarget>;\n    "progress": ProgressEvent<XMLHttpRequestEventTarget>;\n    "timeout": ProgressEvent<XMLHttpRequestEventTarget>;\n}\n\ninterface XMLHttpRequestEventTarget extends EventTarget {\n    onabort: ((this: XMLHttpRequest, ev: ProgressEvent) => any) | null;\n    onerror: ((this: XMLHttpRequest, ev: ProgressEvent) => any) | null;\n    onload: ((this: XMLHttpRequest, ev: ProgressEvent) => any) | null;\n    onloadend: ((this: XMLHttpRequest, ev: ProgressEvent) => any) | null;\n    onloadstart: ((this: XMLHttpRequest, ev: ProgressEvent) => any) | null;\n    onprogress: ((this: XMLHttpRequest, ev: ProgressEvent) => any) | null;\n    ontimeout: ((this: XMLHttpRequest, ev: ProgressEvent) => any) | null;\n    addEventListener<K extends keyof XMLHttpRequestEventTargetEventMap>(type: K, listener: (this: XMLHttpRequestEventTarget, ev: XMLHttpRequestEventTargetEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof XMLHttpRequestEventTargetEventMap>(type: K, listener: (this: XMLHttpRequestEventTarget, ev: XMLHttpRequestEventTargetEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var XMLHttpRequestEventTarget: {\n    prototype: XMLHttpRequestEventTarget;\n    new(): XMLHttpRequestEventTarget;\n};\n\ninterface XMLHttpRequestUpload extends XMLHttpRequestEventTarget {\n    addEventListener<K extends keyof XMLHttpRequestEventTargetEventMap>(type: K, listener: (this: XMLHttpRequestUpload, ev: XMLHttpRequestEventTargetEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\n    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\n    removeEventListener<K extends keyof XMLHttpRequestEventTargetEventMap>(type: K, listener: (this: XMLHttpRequestUpload, ev: XMLHttpRequestEventTargetEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\n    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\n}\n\ndeclare var XMLHttpRequestUpload: {\n    prototype: XMLHttpRequestUpload;\n    new(): XMLHttpRequestUpload;\n};\n\ndeclare type EventListenerOrEventListenerObject = EventListener | EventListenerObject;\n\ninterface Console {\n    memory: any;\n    assert(condition?: boolean, ...data: any[]): void;\n    clear(): void;\n    count(label?: string): void;\n    countReset(label?: string): void;\n    debug(...data: any[]): void;\n    dir(item?: any, options?: any): void;\n    dirxml(...data: any[]): void;\n    error(...data: any[]): void;\n    exception(message?: string, ...optionalParams: any[]): void;\n    group(...data: any[]): void;\n    groupCollapsed(...data: any[]): void;\n    groupEnd(): void;\n    info(...data: any[]): void;\n    log(...data: any[]): void;\n    table(tabularData?: any, properties?: string[]): void;\n    time(label?: string): void;\n    timeEnd(label?: string): void;\n    timeLog(label?: string, ...data: any[]): void;\n    timeStamp(label?: string): void;\n    trace(...data: any[]): void;\n    warn(...data: any[]): void;\n}\n\ndeclare var console: Console;\n\ndeclare namespace WebAssembly {\n    interface Global {\n        value: any;\n        valueOf(): any;\n    }\n\n    var Global: {\n        prototype: Global;\n        new(descriptor: GlobalDescriptor, v?: any): Global;\n    };\n\n    interface Instance {\n        readonly exports: Exports;\n    }\n\n    var Instance: {\n        prototype: Instance;\n        new(module: Module, importObject?: Imports): Instance;\n    };\n\n    interface Memory {\n        readonly buffer: ArrayBuffer;\n        grow(delta: number): number;\n    }\n\n    var Memory: {\n        prototype: Memory;\n        new(descriptor: MemoryDescriptor): Memory;\n    };\n\n    interface Module {\n    }\n\n    var Module: {\n        prototype: Module;\n        new(bytes: BufferSource): Module;\n        customSections(moduleObject: Module, sectionName: string): ArrayBuffer[];\n        exports(moduleObject: Module): ModuleExportDescriptor[];\n        imports(moduleObject: Module): ModuleImportDescriptor[];\n    };\n\n    interface Table {\n        readonly length: number;\n        get(index: number): Function | null;\n        grow(delta: number): number;\n        set(index: number, value: Function | null): void;\n    }\n\n    var Table: {\n        prototype: Table;\n        new(descriptor: TableDescriptor): Table;\n    };\n\n    interface GlobalDescriptor {\n        mutable?: boolean;\n        value: ValueType;\n    }\n\n    interface MemoryDescriptor {\n        initial: number;\n        maximum?: number;\n        shared?: boolean;\n    }\n\n    interface ModuleExportDescriptor {\n        kind: ImportExportKind;\n        name: string;\n    }\n\n    interface ModuleImportDescriptor {\n        kind: ImportExportKind;\n        module: string;\n        name: string;\n    }\n\n    interface TableDescriptor {\n        element: TableKind;\n        initial: number;\n        maximum?: number;\n    }\n\n    interface WebAssemblyInstantiatedSource {\n        instance: Instance;\n        module: Module;\n    }\n\n    type ImportExportKind = "function" | "global" | "memory" | "table";\n    type TableKind = "anyfunc";\n    type ValueType = "f32" | "f64" | "i32" | "i64";\n    type ExportValue = Function | Global | Memory | Table;\n    type Exports = Record<string, ExportValue>;\n    type ImportValue = ExportValue | number;\n    type ModuleImports = Record<string, ImportValue>;\n    type Imports = Record<string, ModuleImports>;\n    function compile(bytes: BufferSource): Promise<Module>;\n    function compileStreaming(source: Response | Promise<Response>): Promise<Module>;\n    function instantiate(bytes: BufferSource, importObject?: Imports): Promise<WebAssemblyInstantiatedSource>;\n    function instantiate(moduleObject: Module, importObject?: Imports): Promise<Instance>;\n    function instantiateStreaming(response: Response | PromiseLike<Response>, importObject?: Imports): Promise<WebAssemblyInstantiatedSource>;\n    function validate(bytes: BufferSource): boolean;\n}\n\ninterface FrameRequestCallback {\n    (time: number): void;\n}\n\ninterface OnErrorEventHandlerNonNull {\n    (event: Event | string, source?: string, lineno?: number, colno?: number, error?: Error): any;\n}\n\ninterface PerformanceObserverCallback {\n    (entries: PerformanceObserverEntryList, observer: PerformanceObserver): void;\n}\n\ninterface QueuingStrategySize<T = any> {\n    (chunk: T): number;\n}\n\ninterface TransformerFlushCallback<O> {\n    (controller: TransformStreamDefaultController<O>): void | PromiseLike<void>;\n}\n\ninterface TransformerStartCallback<O> {\n    (controller: TransformStreamDefaultController<O>): void | PromiseLike<void>;\n}\n\ninterface TransformerTransformCallback<I, O> {\n    (chunk: I, controller: TransformStreamDefaultController<O>): void | PromiseLike<void>;\n}\n\ninterface UnderlyingSinkAbortCallback {\n    (reason: any): void | PromiseLike<void>;\n}\n\ninterface UnderlyingSinkCloseCallback {\n    (): void | PromiseLike<void>;\n}\n\ninterface UnderlyingSinkStartCallback {\n    (controller: WritableStreamDefaultController): void | PromiseLike<void>;\n}\n\ninterface UnderlyingSinkWriteCallback<W> {\n    (chunk: W, controller: WritableStreamDefaultController): void | PromiseLike<void>;\n}\n\ninterface UnderlyingSourceCancelCallback {\n    (reason: any): void | PromiseLike<void>;\n}\n\ninterface UnderlyingSourcePullCallback<R> {\n    (controller: ReadableStreamController<R>): void | PromiseLike<void>;\n}\n\ninterface UnderlyingSourceStartCallback<R> {\n    (controller: ReadableStreamController<R>): void | PromiseLike<void>;\n}\n\ninterface VoidFunction {\n    (): void;\n}\n\n/**\n * Returns dedicatedWorkerGlobal\'s name, i.e. the value given to the Worker constructor. Primarily useful for debugging.\n */\ndeclare var name: string;\ndeclare var onmessage: ((this: DedicatedWorkerGlobalScope, ev: MessageEvent) => any) | null;\ndeclare var onmessageerror: ((this: DedicatedWorkerGlobalScope, ev: MessageEvent) => any) | null;\n/**\n * Aborts dedicatedWorkerGlobal.\n */\ndeclare function close(): void;\n/**\n * Clones message and transmits it to the Worker object associated with dedicatedWorkerGlobal. transfer can be passed as a list of objects that are to be transferred rather than cloned.\n */\ndeclare function postMessage(message: any, transfer: Transferable[]): void;\ndeclare function postMessage(message: any, options?: PostMessageOptions): void;\n/**\n * Dispatches a synthetic event event to target and returns true if either event\'s cancelable attribute value is false or its preventDefault() method was not invoked, and false otherwise.\n */\ndeclare function dispatchEvent(event: Event): boolean;\n/**\n * Returns workerGlobal\'s WorkerLocation object.\n */\ndeclare var location: WorkerLocation;\ndeclare var navigator: WorkerNavigator;\ndeclare var onerror: ((this: DedicatedWorkerGlobalScope, ev: ErrorEvent) => any) | null;\ndeclare var onlanguagechange: ((this: DedicatedWorkerGlobalScope, ev: Event) => any) | null;\ndeclare var onoffline: ((this: DedicatedWorkerGlobalScope, ev: Event) => any) | null;\ndeclare var ononline: ((this: DedicatedWorkerGlobalScope, ev: Event) => any) | null;\ndeclare var onrejectionhandled: ((this: DedicatedWorkerGlobalScope, ev: PromiseRejectionEvent) => any) | null;\ndeclare var onunhandledrejection: ((this: DedicatedWorkerGlobalScope, ev: PromiseRejectionEvent) => any) | null;\n/**\n * Returns workerGlobal.\n */\ndeclare var self: WorkerGlobalScope & typeof globalThis;\n/**\n * Fetches each URL in urls, executes them one-by-one in the order they are passed, and then returns (or throws if something went amiss).\n */\ndeclare function importScripts(...urls: string[]): void;\n/**\n * Dispatches a synthetic event event to target and returns true if either event\'s cancelable attribute value is false or its preventDefault() method was not invoked, and false otherwise.\n */\ndeclare function dispatchEvent(event: Event): boolean;\ndeclare var caches: CacheStorage;\ndeclare var crypto: Crypto;\ndeclare var indexedDB: IDBFactory;\ndeclare var isSecureContext: boolean;\ndeclare var origin: string;\ndeclare var performance: Performance;\ndeclare function atob(data: string): string;\ndeclare function btoa(data: string): string;\ndeclare function clearInterval(handle?: number): void;\ndeclare function clearTimeout(handle?: number): void;\ndeclare function createImageBitmap(image: ImageBitmapSource, options?: ImageBitmapOptions): Promise<ImageBitmap>;\ndeclare function createImageBitmap(image: ImageBitmapSource, sx: number, sy: number, sw: number, sh: number, options?: ImageBitmapOptions): Promise<ImageBitmap>;\ndeclare function fetch(input: RequestInfo, init?: RequestInit): Promise<Response>;\ndeclare function queueMicrotask(callback: VoidFunction): void;\ndeclare function setInterval(handler: TimerHandler, timeout?: number, ...arguments: any[]): number;\ndeclare function setTimeout(handler: TimerHandler, timeout?: number, ...arguments: any[]): number;\ndeclare function cancelAnimationFrame(handle: number): void;\ndeclare function requestAnimationFrame(callback: FrameRequestCallback): number;\ndeclare function addEventListener<K extends keyof DedicatedWorkerGlobalScopeEventMap>(type: K, listener: (this: DedicatedWorkerGlobalScope, ev: DedicatedWorkerGlobalScopeEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;\ndeclare function addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;\ndeclare function removeEventListener<K extends keyof DedicatedWorkerGlobalScopeEventMap>(type: K, listener: (this: DedicatedWorkerGlobalScope, ev: DedicatedWorkerGlobalScopeEventMap[K]) => any, options?: boolean | EventListenerOptions): void;\ndeclare function removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;\ntype HeadersInit = Headers | string[][] | Record<string, string>;\ntype BodyInit = Blob | BufferSource | FormData | URLSearchParams | ReadableStream<Uint8Array> | string;\ntype RequestInfo = Request | string;\ntype BlobPart = BufferSource | Blob | string;\ntype DOMHighResTimeStamp = number;\ntype CanvasImageSource = ImageBitmap | OffscreenCanvas;\ntype OffscreenRenderingContext = OffscreenCanvasRenderingContext2D | ImageBitmapRenderingContext | WebGLRenderingContext | WebGL2RenderingContext;\ntype MessageEventSource = MessagePort | ServiceWorker;\ntype ImageBitmapSource = CanvasImageSource | Blob | ImageData;\ntype OnErrorEventHandler = OnErrorEventHandlerNonNull | null;\ntype TimerHandler = string | Function;\ntype PerformanceEntryList = PerformanceEntry[];\ntype PushMessageDataInit = BufferSource | string;\ntype ReadableStreamReader<T> = ReadableStreamDefaultReader<T>;\ntype ReadableStreamController<T> = ReadableStreamDefaultController<T>;\ntype VibratePattern = number | number[];\ntype AlgorithmIdentifier = string | Algorithm;\ntype HashAlgorithmIdentifier = AlgorithmIdentifier;\ntype BigInteger = Uint8Array;\ntype NamedCurve = string;\ntype GLenum = number;\ntype GLboolean = boolean;\ntype GLbitfield = number;\ntype GLint = number;\ntype GLsizei = number;\ntype GLintptr = number;\ntype GLsizeiptr = number;\ntype GLuint = number;\ntype GLfloat = number;\ntype GLclampf = number;\ntype TexImageSource = ImageBitmap | ImageData | OffscreenCanvas;\ntype Float32List = Float32Array | GLfloat[];\ntype Int32List = Int32Array | GLint[];\ntype GLint64 = number;\ntype GLuint64 = number;\ntype Uint32List = Uint32Array | GLuint[];\ntype BufferSource = ArrayBufferView | ArrayBuffer;\ntype DOMTimeStamp = number;\ntype FormDataEntryValue = File | string;\ntype IDBValidKey = number | string | Date | BufferSource | IDBArrayKey;\ntype Transferable = ArrayBuffer | MessagePort | ImageBitmap | OffscreenCanvas;\ntype ReadableStreamDefaultReadResult<T> = ReadableStreamDefaultReadValueResult<T> | ReadableStreamDefaultReadDoneResult;\ntype BinaryType = "arraybuffer" | "blob";\ntype CanvasDirection = "inherit" | "ltr" | "rtl";\ntype CanvasFillRule = "evenodd" | "nonzero";\ntype CanvasLineCap = "butt" | "round" | "square";\ntype CanvasLineJoin = "bevel" | "miter" | "round";\ntype CanvasTextAlign = "center" | "end" | "left" | "right" | "start";\ntype CanvasTextBaseline = "alphabetic" | "bottom" | "hanging" | "ideographic" | "middle" | "top";\ntype ClientTypes = "all" | "sharedworker" | "window" | "worker";\ntype ColorSpaceConversion = "default" | "none";\ntype EndingType = "native" | "transparent";\ntype FrameType = "auxiliary" | "nested" | "none" | "top-level";\ntype IDBCursorDirection = "next" | "nextunique" | "prev" | "prevunique";\ntype IDBRequestReadyState = "done" | "pending";\ntype IDBTransactionMode = "readonly" | "readwrite" | "versionchange";\ntype ImageOrientation = "flipY" | "none";\ntype ImageSmoothingQuality = "high" | "low" | "medium";\ntype KeyFormat = "jwk" | "pkcs8" | "raw" | "spki";\ntype KeyType = "private" | "public" | "secret";\ntype KeyUsage = "decrypt" | "deriveBits" | "deriveKey" | "encrypt" | "sign" | "unwrapKey" | "verify" | "wrapKey";\ntype NotificationDirection = "auto" | "ltr" | "rtl";\ntype NotificationPermission = "default" | "denied" | "granted";\ntype OffscreenRenderingContextId = "2d" | "bitmaprenderer" | "webgl" | "webgl2";\ntype PermissionName = "accelerometer" | "ambient-light-sensor" | "background-fetch" | "background-sync" | "bluetooth" | "camera" | "clipboard-read" | "clipboard-write" | "device-info" | "display-capture" | "geolocation" | "gyroscope" | "magnetometer" | "microphone" | "midi" | "nfc" | "notifications" | "persistent-storage" | "push" | "speaker";\ntype PermissionState = "denied" | "granted" | "prompt";\ntype PremultiplyAlpha = "default" | "none" | "premultiply";\ntype PushEncryptionKeyName = "auth" | "p256dh";\ntype PushPermissionState = "denied" | "granted" | "prompt";\ntype ReferrerPolicy = "" | "no-referrer" | "no-referrer-when-downgrade" | "origin" | "origin-when-cross-origin" | "same-origin" | "strict-origin" | "strict-origin-when-cross-origin" | "unsafe-url";\ntype RequestCache = "default" | "force-cache" | "no-cache" | "no-store" | "only-if-cached" | "reload";\ntype RequestCredentials = "include" | "omit" | "same-origin";\ntype RequestDestination = "" | "audio" | "audioworklet" | "document" | "embed" | "font" | "image" | "manifest" | "object" | "paintworklet" | "report" | "script" | "sharedworker" | "style" | "track" | "video" | "worker" | "xslt";\ntype RequestMode = "cors" | "navigate" | "no-cors" | "same-origin";\ntype RequestRedirect = "error" | "follow" | "manual";\ntype ResizeQuality = "high" | "low" | "medium" | "pixelated";\ntype ResponseType = "basic" | "cors" | "default" | "error" | "opaque" | "opaqueredirect";\ntype ServiceWorkerState = "activated" | "activating" | "installed" | "installing" | "parsed" | "redundant";\ntype ServiceWorkerUpdateViaCache = "all" | "imports" | "none";\ntype VisibilityState = "hidden" | "visible";\ntype WebGLPowerPreference = "default" | "high-performance" | "low-power";\ntype WorkerType = "classic" | "module";\ntype XMLHttpRequestResponseType = "" | "arraybuffer" | "blob" | "document" | "json" | "text";\n',"lib.webworker.importscripts.d.ts":'/*! *****************************************************************************\nCopyright (c) Microsoft Corporation. All rights reserved.\nLicensed under the Apache License, Version 2.0 (the "License"); you may not use\nthis file except in compliance with the License. You may obtain a copy of the\nLicense at http://www.apache.org/licenses/LICENSE-2.0\n\nTHIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\nKIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED\nWARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,\nMERCHANTABLITY OR NON-INFRINGEMENT.\n\nSee the Apache Version 2.0 License for specific language governing permissions\nand limitations under the License.\n***************************************************************************** */\n\n\n\n/// <reference no-default-lib="true"/>\n\n\n\n/////////////////////////////\n/// WorkerGlobalScope APIs\n/////////////////////////////\n// These are only available in a Web Worker\ndeclare function importScripts(...urls: string[]): void;\n',"lib.webworker.iterable.d.ts":'/*! *****************************************************************************\nCopyright (c) Microsoft Corporation. All rights reserved.\nLicensed under the Apache License, Version 2.0 (the "License"); you may not use\nthis file except in compliance with the License. You may obtain a copy of the\nLicense at http://www.apache.org/licenses/LICENSE-2.0\n\nTHIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY\nKIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED\nWARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,\nMERCHANTABLITY OR NON-INFRINGEMENT.\n\nSee the Apache Version 2.0 License for specific language governing permissions\nand limitations under the License.\n***************************************************************************** */\n\n\n\n/// <reference no-default-lib="true"/>\n\n\n/////////////////////////////\n/// Worker Iterable APIs\n/////////////////////////////\n\ninterface Cache {\n    addAll(requests: Iterable<RequestInfo>): Promise<void>;\n}\n\ninterface CanvasPathDrawingStyles {\n    setLineDash(segments: Iterable<number>): void;\n}\n\ninterface DOMStringList {\n    [Symbol.iterator](): IterableIterator<string>;\n}\n\ninterface FileList {\n    [Symbol.iterator](): IterableIterator<File>;\n}\n\ninterface FormData {\n    [Symbol.iterator](): IterableIterator<[string, FormDataEntryValue]>;\n    /**\n     * Returns an array of key, value pairs for every entry in the list.\n     */\n    entries(): IterableIterator<[string, FormDataEntryValue]>;\n    /**\n     * Returns a list of keys in the list.\n     */\n    keys(): IterableIterator<string>;\n    /**\n     * Returns a list of values in the list.\n     */\n    values(): IterableIterator<FormDataEntryValue>;\n}\n\ninterface Headers {\n    [Symbol.iterator](): IterableIterator<[string, string]>;\n    /**\n     * Returns an iterator allowing to go through all key/value pairs contained in this object.\n     */\n    entries(): IterableIterator<[string, string]>;\n    /**\n     * Returns an iterator allowing to go through all keys of the key/value pairs contained in this object.\n     */\n    keys(): IterableIterator<string>;\n    /**\n     * Returns an iterator allowing to go through all values of the key/value pairs contained in this object.\n     */\n    values(): IterableIterator<string>;\n}\n\ninterface IDBDatabase {\n    /**\n     * Returns a new transaction with the given mode ("readonly" or "readwrite") and scope which can be a single object store name or an array of names.\n     */\n    transaction(storeNames: string | Iterable<string>, mode?: IDBTransactionMode): IDBTransaction;\n}\n\ninterface IDBObjectStore {\n    /**\n     * Creates a new index in store with the given name, keyPath and options and returns a new IDBIndex. If the keyPath and options define constraints that cannot be satisfied with the data already in store the upgrade transaction will abort with a "ConstraintError" DOMException.\n     *\n     * Throws an "InvalidStateError" DOMException if not called within an upgrade transaction.\n     */\n    createIndex(name: string, keyPath: string | Iterable<string>, options?: IDBIndexParameters): IDBIndex;\n}\n\ninterface URLSearchParams {\n    [Symbol.iterator](): IterableIterator<[string, string]>;\n    /**\n     * Returns an array of key, value pairs for every entry in the search params.\n     */\n    entries(): IterableIterator<[string, string]>;\n    /**\n     * Returns a list of keys in the search params.\n     */\n    keys(): IterableIterator<string>;\n    /**\n     * Returns a list of values in the search params.\n     */\n    values(): IterableIterator<string>;\n}\n\ninterface WEBGL_draw_buffers {\n    drawBuffersWEBGL(buffers: Iterable<GLenum>): void;\n}\n\ninterface WebGL2RenderingContextBase {\n    clearBufferfv(buffer: GLenum, drawbuffer: GLint, values: Iterable<GLfloat>, srcOffset?: GLuint): void;\n    clearBufferiv(buffer: GLenum, drawbuffer: GLint, values: Iterable<GLint>, srcOffset?: GLuint): void;\n    clearBufferuiv(buffer: GLenum, drawbuffer: GLint, values: Iterable<GLuint>, srcOffset?: GLuint): void;\n    drawBuffers(buffers: Iterable<GLenum>): void;\n    getActiveUniforms(program: WebGLProgram, uniformIndices: Iterable<GLuint>, pname: GLenum): any;\n    getUniformIndices(program: WebGLProgram, uniformNames: Iterable<string>): Iterable<GLuint> | null;\n    invalidateFramebuffer(target: GLenum, attachments: Iterable<GLenum>): void;\n    invalidateSubFramebuffer(target: GLenum, attachments: Iterable<GLenum>, x: GLint, y: GLint, width: GLsizei, height: GLsizei): void;\n    transformFeedbackVaryings(program: WebGLProgram, varyings: Iterable<string>, bufferMode: GLenum): void;\n    uniform1uiv(location: WebGLUniformLocation | null, data: Iterable<GLuint>, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniform2uiv(location: WebGLUniformLocation | null, data: Iterable<GLuint>, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniform3uiv(location: WebGLUniformLocation | null, data: Iterable<GLuint>, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniform4uiv(location: WebGLUniformLocation | null, data: Iterable<GLuint>, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniformMatrix2x3fv(location: WebGLUniformLocation | null, transpose: GLboolean, data: Iterable<GLfloat>, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniformMatrix2x4fv(location: WebGLUniformLocation | null, transpose: GLboolean, data: Iterable<GLfloat>, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniformMatrix3x2fv(location: WebGLUniformLocation | null, transpose: GLboolean, data: Iterable<GLfloat>, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniformMatrix3x4fv(location: WebGLUniformLocation | null, transpose: GLboolean, data: Iterable<GLfloat>, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniformMatrix4x2fv(location: WebGLUniformLocation | null, transpose: GLboolean, data: Iterable<GLfloat>, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniformMatrix4x3fv(location: WebGLUniformLocation | null, transpose: GLboolean, data: Iterable<GLfloat>, srcOffset?: GLuint, srcLength?: GLuint): void;\n    vertexAttribI4iv(index: GLuint, values: Iterable<GLint>): void;\n    vertexAttribI4uiv(index: GLuint, values: Iterable<GLuint>): void;\n}\n\ninterface WebGL2RenderingContextOverloads {\n    uniform1fv(location: WebGLUniformLocation | null, data: Iterable<GLfloat>, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniform1iv(location: WebGLUniformLocation | null, data: Iterable<GLint>, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniform2fv(location: WebGLUniformLocation | null, data: Iterable<GLfloat>, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniform2iv(location: WebGLUniformLocation | null, data: Iterable<GLint>, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniform3fv(location: WebGLUniformLocation | null, data: Iterable<GLfloat>, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniform3iv(location: WebGLUniformLocation | null, data: Iterable<GLint>, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniform4fv(location: WebGLUniformLocation | null, data: Iterable<GLfloat>, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniform4iv(location: WebGLUniformLocation | null, data: Iterable<GLint>, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniformMatrix2fv(location: WebGLUniformLocation | null, transpose: GLboolean, data: Iterable<GLfloat>, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniformMatrix3fv(location: WebGLUniformLocation | null, transpose: GLboolean, data: Iterable<GLfloat>, srcOffset?: GLuint, srcLength?: GLuint): void;\n    uniformMatrix4fv(location: WebGLUniformLocation | null, transpose: GLboolean, data: Iterable<GLfloat>, srcOffset?: GLuint, srcLength?: GLuint): void;\n}\n\ninterface WebGLRenderingContextBase {\n    vertexAttrib1fv(index: GLuint, values: Iterable<GLfloat>): void;\n    vertexAttrib2fv(index: GLuint, values: Iterable<GLfloat>): void;\n    vertexAttrib3fv(index: GLuint, values: Iterable<GLfloat>): void;\n    vertexAttrib4fv(index: GLuint, values: Iterable<GLfloat>): void;\n}\n\ninterface WebGLRenderingContextOverloads {\n    uniform1fv(location: WebGLUniformLocation | null, v: Iterable<GLfloat>): void;\n    uniform1iv(location: WebGLUniformLocation | null, v: Iterable<GLint>): void;\n    uniform2fv(location: WebGLUniformLocation | null, v: Iterable<GLfloat>): void;\n    uniform2iv(location: WebGLUniformLocation | null, v: Iterable<GLint>): void;\n    uniform3fv(location: WebGLUniformLocation | null, v: Iterable<GLfloat>): void;\n    uniform3iv(location: WebGLUniformLocation | null, v: Iterable<GLint>): void;\n    uniform4fv(location: WebGLUniformLocation | null, v: Iterable<GLfloat>): void;\n    uniform4iv(location: WebGLUniformLocation | null, v: Iterable<GLint>): void;\n    uniformMatrix2fv(location: WebGLUniformLocation | null, transpose: GLboolean, value: Iterable<GLfloat>): void;\n    uniformMatrix3fv(location: WebGLUniformLocation | null, transpose: GLboolean, value: Iterable<GLfloat>): void;\n    uniformMatrix4fv(location: WebGLUniformLocation | null, transpose: GLboolean, value: Iterable<GLfloat>): void;\n}\n'},At=function(){return At=Object.assign||function(e){for(var n,t=1,r=arguments.length;t<r;t++)for(var a in n=arguments[t],n)Object.prototype.hasOwnProperty.call(n,a)&&(e[a]=n[a]);return e},At.apply(this,arguments)},Ct=function(e,n,t,r){function a(e){return e instanceof t?e:new t((function(n){n(e)}))}return new(t||(t=Promise))((function(t,i){function o(e){try{c(r.next(e))}catch(n){i(n)}}function s(e){try{c(r["throw"](e))}catch(n){i(n)}}function c(e){e.done?t(e.value):a(e.value).then(o,s)}c((r=r.apply(e,n||[])).next())}))},It=function(e,n){var t,r,a,i,o={label:0,sent:function(){if(1&a[0])throw a[1];return a[1]},trys:[],ops:[]};return i={next:s(0),throw:s(1),return:s(2)},"function"===typeof Symbol&&(i[Symbol.iterator]=function(){return this}),i;function s(e){return function(n){return c([e,n])}}function c(i){if(t)throw new TypeError("Generator is already executing.");while(o)try{if(t=1,r&&(a=2&i[0]?r["return"]:i[0]?r["throw"]||((a=r["return"])&&a.call(r),0):r.next)&&!(a=a.call(r,i[1])).done)return a;switch(r=0,a&&(i=[2&i[0],a.value]),i[0]){case 0:case 1:a=i;break;case 4:return o.label++,{value:i[1],done:!1};case 5:o.label++,r=i[1],i=[0];continue;case 7:i=o.ops.pop(),o.trys.pop();continue;default:if(a=o.trys,!(a=a.length>0&&a[a.length-1])&&(6===i[0]||2===i[0])){o=0;continue}if(3===i[0]&&(!a||i[1]>a[0]&&i[1]<a[3])){o.label=i[1];break}if(6===i[0]&&o.label<a[1]){o.label=a[1],a=i;break}if(a&&o.label<a[2]){o.label=a[2],o.ops.push(i);break}a[2]&&o.ops.pop(),o.trys.pop();continue}i=n.call(e,o)}catch(s){i=[6,s],r=0}finally{t=a=0}if(5&i[0])throw i[1];return{value:i[0]?i[1]:void 0,done:!0}}};function Nt(e){return"string"===typeof e?!!/^file:\/\/\//.test(e)&&!!Dt[e.substr(8)]:0===e.path.indexOf("/lib.")&&!!Dt[e.path.slice(1)]}var kt=function(){function e(e,n){this._extraLibs=Object.create(null),this._languageService=Lt["createLanguageService"](this),this._ctx=e,this._compilerOptions=n.compilerOptions,this._extraLibs=n.extraLibs}return e.prototype.getCompilationSettings=function(){return this._compilerOptions},e.prototype.getScriptFileNames=function(){var e=this._ctx.getMirrorModels().map((function(e){return e.uri})),n=e.filter((function(e){return!Nt(e)})).map((function(e){return e.toString()}));return n.concat(Object.keys(this._extraLibs))},e.prototype._getModel=function(e){for(var n=this._ctx.getMirrorModels(),t=0;t<n.length;t++)if(n[t].uri.toString()===e)return n[t];return null},e.prototype.getScriptVersion=function(e){var n=this._getModel(e);return n?n.version.toString():this.isDefaultLibFileName(e)?"1":e in this._extraLibs?String(this._extraLibs[e].version):""},e.prototype.getScriptText=function(e){return Ct(this,void 0,void 0,(function(){return It(this,(function(n){return[2,this._getScriptText(e)]}))}))},e.prototype._getScriptText=function(e){var n,t=this._getModel(e),r="lib."+e+".d.ts";if(t)n=t.getValue();else if(e in Dt)n=Dt[e];else if(r in Dt)n=Dt[r];else{if(!(e in this._extraLibs))return;n=this._extraLibs[e].content}return n},e.prototype.getScriptSnapshot=function(e){var n=this._getScriptText(e);if(void 0!==n)return{getText:function(e,t){return n.substring(e,t)},getLength:function(){return n.length},getChangeRange:function(){}}},e.prototype.getScriptKind=function(e){var n=e.substr(e.lastIndexOf(".")+1);switch(n){case"ts":return Lt["ScriptKind"].TS;case"tsx":return Lt["ScriptKind"].TSX;case"js":return Lt["ScriptKind"].JS;case"jsx":return Lt["ScriptKind"].JSX;default:return this.getCompilationSettings().allowJs?Lt["ScriptKind"].JS:Lt["ScriptKind"].TS}},e.prototype.getCurrentDirectory=function(){return""},e.prototype.getDefaultLibFileName=function(e){switch(e.target){case 99:var n="lib.esnext.full.d.ts";if(n in Dt||n in this._extraLibs)return n;case 7:case 6:case 5:case 4:case 3:case 2:default:var t="lib.es"+(2013+(e.target||99))+".full.d.ts";return t in Dt||t in this._extraLibs?t:"lib.es6.d.ts";case 1:case 0:return"lib.d.ts"}},e.prototype.isDefaultLibFileName=function(e){return e===this.getDefaultLibFileName(this._compilerOptions)},e.prototype.getLibFiles=function(){return Ct(this,void 0,void 0,(function(){return It(this,(function(e){return[2,Dt]}))}))},e.clearFiles=function(e){for(var n=[],t=0,r=e;t<r.length;t++){var a=r[t],i=At({},a);if(i.file=i.file?{fileName:i.file.fileName}:void 0,a.relatedInformation){i.relatedInformation=[];for(var o=0,s=a.relatedInformation;o<s.length;o++){var c=s[o],l=At({},c);l.file=l.file?{fileName:l.file.fileName}:void 0,i.relatedInformation.push(l)}}n.push(i)}return n},e.prototype.getSyntacticDiagnostics=function(n){return Ct(this,void 0,void 0,(function(){var t;return It(this,(function(r){return Nt(n)?[2,[]]:(t=this._languageService.getSyntacticDiagnostics(n),[2,e.clearFiles(t)])}))}))},e.prototype.getSemanticDiagnostics=function(n){return Ct(this,void 0,void 0,(function(){var t;return It(this,(function(r){return Nt(n)?[2,[]]:(t=this._languageService.getSemanticDiagnostics(n),[2,e.clearFiles(t)])}))}))},e.prototype.getSuggestionDiagnostics=function(n){return Ct(this,void 0,void 0,(function(){var t;return It(this,(function(r){return Nt(n)?[2,[]]:(t=this._languageService.getSuggestionDiagnostics(n),[2,e.clearFiles(t)])}))}))},e.prototype.getCompilerOptionsDiagnostics=function(n){return Ct(this,void 0,void 0,(function(){var t;return It(this,(function(r){return Nt(n)?[2,[]]:(t=this._languageService.getCompilerOptionsDiagnostics(),[2,e.clearFiles(t)])}))}))},e.prototype.getCompletionsAtPosition=function(e,n){return Ct(this,void 0,void 0,(function(){return It(this,(function(t){return Nt(e)?[2,void 0]:[2,this._languageService.getCompletionsAtPosition(e,n,void 0)]}))}))},e.prototype.getCompletionEntryDetails=function(e,n,t){return Ct(this,void 0,void 0,(function(){return It(this,(function(r){return[2,this._languageService.getCompletionEntryDetails(e,n,t,void 0,void 0,void 0,void 0)]}))}))},e.prototype.getSignatureHelpItems=function(e,n,t){return Ct(this,void 0,void 0,(function(){return It(this,(function(r){return Nt(e)?[2,void 0]:[2,this._languageService.getSignatureHelpItems(e,n,t)]}))}))},e.prototype.getQuickInfoAtPosition=function(e,n){return Ct(this,void 0,void 0,(function(){return It(this,(function(t){return Nt(e)?[2,void 0]:[2,this._languageService.getQuickInfoAtPosition(e,n)]}))}))},e.prototype.getOccurrencesAtPosition=function(e,n){return Ct(this,void 0,void 0,(function(){return It(this,(function(t){return Nt(e)?[2,void 0]:[2,this._languageService.getOccurrencesAtPosition(e,n)]}))}))},e.prototype.getDefinitionAtPosition=function(e,n){return Ct(this,void 0,void 0,(function(){return It(this,(function(t){return Nt(e)?[2,void 0]:[2,this._languageService.getDefinitionAtPosition(e,n)]}))}))},e.prototype.getReferencesAtPosition=function(e,n){return Ct(this,void 0,void 0,(function(){return It(this,(function(t){return Nt(e)?[2,void 0]:[2,this._languageService.getReferencesAtPosition(e,n)]}))}))},e.prototype.getNavigationBarItems=function(e){return Ct(this,void 0,void 0,(function(){return It(this,(function(n){return Nt(e)?[2,[]]:[2,this._languageService.getNavigationBarItems(e)]}))}))},e.prototype.getFormattingEditsForDocument=function(e,n){return Ct(this,void 0,void 0,(function(){return It(this,(function(t){return Nt(e)?[2,[]]:[2,this._languageService.getFormattingEditsForDocument(e,n)]}))}))},e.prototype.getFormattingEditsForRange=function(e,n,t,r){return Ct(this,void 0,void 0,(function(){return It(this,(function(a){return Nt(e)?[2,[]]:[2,this._languageService.getFormattingEditsForRange(e,n,t,r)]}))}))},e.prototype.getFormattingEditsAfterKeystroke=function(e,n,t,r){return Ct(this,void 0,void 0,(function(){return It(this,(function(a){return Nt(e)?[2,[]]:[2,this._languageService.getFormattingEditsAfterKeystroke(e,n,t,r)]}))}))},e.prototype.findRenameLocations=function(e,n,t,r,a){return Ct(this,void 0,void 0,(function(){return It(this,(function(i){return Nt(e)?[2,void 0]:[2,this._languageService.findRenameLocations(e,n,t,r,a)]}))}))},e.prototype.getRenameInfo=function(e,n,t){return Ct(this,void 0,void 0,(function(){return It(this,(function(r){return Nt(e)?[2,{canRename:!1,localizedErrorMessage:"Cannot rename in lib file"}]:[2,this._languageService.getRenameInfo(e,n,t)]}))}))},e.prototype.getEmitOutput=function(e){return Ct(this,void 0,void 0,(function(){return It(this,(function(n){return Nt(e)?[2,{outputFiles:[],emitSkipped:!0}]:[2,this._languageService.getEmitOutput(e)]}))}))},e.prototype.getCodeFixesAtPosition=function(e,n,t,r,a){return Ct(this,void 0,void 0,(function(){var i;return It(this,(function(o){if(Nt(e))return[2,[]];i={};try{return[2,this._languageService.getCodeFixesAtPosition(e,n,t,r,a,i)]}catch(s){return[2,[]]}return[2]}))}))},e.prototype.updateExtraLibs=function(e){return Ct(this,void 0,void 0,(function(){return It(this,(function(n){return this._extraLibs=e,[2]}))}))},e}();self.onmessage=function(){xt((function(e,n){return new kt(e,n)}))}},dd40:function(e,n){e.exports=function(e){if(!e.webpackPolyfill){var n=Object.create(e);n.children||(n.children=[]),Object.defineProperty(n,"loaded",{enumerable:!0,get:function(){return n.l}}),Object.defineProperty(n,"id",{enumerable:!0,get:function(){return n.i}}),Object.defineProperty(n,"exports",{enumerable:!0}),n.webpackPolyfill=1}return n}},f28c:function(e,n){var t,r,a=e.exports={};function i(){throw new Error("setTimeout has not been defined")}function o(){throw new Error("clearTimeout has not been defined")}function s(e){if(t===setTimeout)return setTimeout(e,0);if((t===i||!t)&&setTimeout)return t=setTimeout,setTimeout(e,0);try{return t(e,0)}catch(n){try{return t.call(null,e,0)}catch(n){return t.call(this,e,0)}}}function c(e){if(r===clearTimeout)return clearTimeout(e);if((r===o||!r)&&clearTimeout)return r=clearTimeout,clearTimeout(e);try{return r(e)}catch(n){try{return r.call(null,e)}catch(n){return r.call(this,e)}}}(function(){try{t="function"===typeof setTimeout?setTimeout:i}catch(e){t=i}try{r="function"===typeof clearTimeout?clearTimeout:o}catch(e){r=o}})();var l,u=[],d=!1,p=-1;function f(){d&&l&&(d=!1,l.length?u=l.concat(u):p=-1,u.length&&m())}function m(){if(!d){var e=s(f);d=!0;var n=u.length;while(n){l=u,u=[];while(++p<n)l&&l[p].run();p=-1,n=u.length}l=null,d=!1,c(e)}}function _(e,n){this.fun=e,this.array=n}function g(){}a.nextTick=function(e){var n=new Array(arguments.length-1);if(arguments.length>1)for(var t=1;t<arguments.length;t++)n[t-1]=arguments[t];u.push(new _(e,n)),1!==u.length||d||s(m)},_.prototype.run=function(){this.fun.apply(null,this.array)},a.title="browser",a.browser=!0,a.env={},a.argv=[],a.version="",a.versions={},a.on=g,a.addListener=g,a.once=g,a.off=g,a.removeListener=g,a.removeAllListeners=g,a.emit=g,a.prependListener=g,a.prependOnceListener=g,a.listeners=function(e){return[]},a.binding=function(e){throw new Error("process.binding is not supported")},a.cwd=function(){return"/"},a.chdir=function(e){throw new Error("process.chdir is not supported")},a.umask=function(){return 0}}});